"""EDINETコード (edinetCode) のモデル定義。

AUTO-GENERATED by tools/generate_edinet_codes.py. DO NOT EDIT.
Source: data/source/EdinetcodeDlInfo.csv
"""
from __future__ import annotations

import warnings

from pydantic import BaseModel, ConfigDict

from edinet.exceptions import EdinetWarning


class EdinetCodeEntry(BaseModel):
    """EDINETコードリストの1行。"""

    model_config = ConfigDict(frozen=True)

    edinet_code: str
    submitter_type: str
    listing_status: str | None
    consolidated: str | None
    capital_million_yen: int | None
    fiscal_year_end: str | None
    submitter_name: str
    submitter_name_en: str | None
    submitter_name_yomi: str | None
    address: str | None
    industry: str | None
    sec_code: str | None
    corporate_number: str | None

    def __str__(self) -> str:
        return f"EdinetCodeEntry({self.edinet_code} | {self.submitter_name} | {self.sec_code})"


_EDINET_CODE_TABLE: dict[str, EdinetCodeEntry] = {
    'E00004': EdinetCodeEntry(
        edinet_code='E00004',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1491,
        fiscal_year_end='5月31日',
        submitter_name='カネコ種苗株式会社',
        submitter_name_en='KANEKO SEEDS CO., LTD.',
        submitter_name_yomi='カネコシュビョウカブシキガイシャ',
        address='前橋市古市町一丁目５０番地１２',
        industry='水産・農林業',
        sec_code='13760',
        corporate_number='5070001000715',
    ),
    'E00006': EdinetCodeEntry(
        edinet_code='E00006',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13500,
        fiscal_year_end='5月31日',
        submitter_name='株式会社\u3000サカタのタネ',
        submitter_name_en='SAKATA SEED CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000サカタノタネ',
        address='横浜市都筑区仲町台２－７－１',
        industry='水産・農林業',
        sec_code='13770',
        corporate_number='6020001008662',
    ),
    'E00007': EdinetCodeEntry(
        edinet_code='E00007',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ユキグニファクトリー株式会社',
        submitter_name_en='YUKIGUNI FACTORY CO.,LTD.',
        submitter_name_yomi='ユニグニファクトリーカブシキガイシャ',
        address='南魚沼市余川８９番地',
        industry='水産・農林業',
        sec_code='13750',
        corporate_number='1010001185037',
    ),
    'E00008': EdinetCodeEntry(
        edinet_code='E00008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5500,
        fiscal_year_end='3月31日',
        submitter_name='ホクト株式会社',
        submitter_name_en='HOKUTO CORPORATION',
        submitter_name_yomi='ホクトカブシキガイシャ',
        address='長野市南堀１３８番地１',
        industry='水産・農林業',
        sec_code='13790',
        corporate_number='6100001003151',
    ),
    'E00009': EdinetCodeEntry(
        edinet_code='E00009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=452,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アクシーズ',
        submitter_name_en='AXYZ Co., Ltd',
        submitter_name_yomi='カブシキガイシャアクシーズ',
        address='鹿児島市草牟田二丁目１番８号',
        industry='水産・農林業',
        sec_code='13810',
        corporate_number='5340001000258',
    ),
    'E00010': EdinetCodeEntry(
        edinet_code='E00010',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=421,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ホーブ',
        submitter_name_en='HOB Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャホーブ',
        address='上川郡東神楽町１４号北１番地',
        industry='水産・農林業',
        sec_code='13820',
        corporate_number='9450001002677',
    ),
    'E00011': EdinetCodeEntry(
        edinet_code='E00011',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50074,
        fiscal_year_end='12月31日',
        submitter_name='住友林業株式会社',
        submitter_name_en='Sumitomo Forestry Co.,Ltd.',
        submitter_name_yomi='スミトモリンギョウカブシキガイシャ',
        address='千代田区大手町一丁目３番２号',
        industry='建設業',
        sec_code='19110',
        corporate_number='4010001090011',
    ),
    'E00012': EdinetCodeEntry(
        edinet_code='E00012',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7527,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000極洋',
        submitter_name_en='KYOKUYO CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000キョクヨウ',
        address='港区赤坂三丁目３番５号',
        industry='水産・農林業',
        sec_code='13010',
        corporate_number='1010401033225',
    ),
    'E00014': EdinetCodeEntry(
        edinet_code='E00014',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30685,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッスイ',
        submitter_name_en='Nissui Corporation',
        submitter_name_yomi='カブシキガイシャニッスイ',
        address='港区西新橋一丁目３番１号',
        industry='水産・農林業',
        sec_code='13320',
        corporate_number='1010001016860',
    ),
    'E00015': EdinetCodeEntry(
        edinet_code='E00015',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='マルハニチロ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルハニチロカブシキガイシャ',
        address='江東区豊洲三丁目２番２０号',
        industry='水産・農林業',
        sec_code='13330',
        corporate_number='2010601040697',
    ),
    'E00017': EdinetCodeEntry(
        edinet_code='E00017',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2485,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホウスイ',
        submitter_name_en='HOHSUI  CORPORATION',
        submitter_name_yomi='カブシキガイシャホウスイ',
        address='江東区豊洲六丁目６番３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='9010001034921',
    ),
    'E00021': EdinetCodeEntry(
        edinet_code='E00021',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=119457,
        fiscal_year_end='3月31日',
        submitter_name='三菱マテリアル株式会社',
        submitter_name_en='MITSUBISHI MATERIALS CORPORATION',
        submitter_name_yomi='ミツビシマテリアルカブシキガイシャ',
        address='千代田区丸の内三丁目２番３号',
        industry='非鉄金属',
        sec_code='57110',
        corporate_number='6010001023786',
    ),
    'E00023': EdinetCodeEntry(
        edinet_code='E00023',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=93242,
        fiscal_year_end='3月31日',
        submitter_name='住友金属鉱山株式会社',
        submitter_name_en='Sumitomo Metal Mining Co., Ltd.',
        submitter_name_yomi='スミトモキンゾクコウザンカブシキカイシャ',
        address='港区新橋５丁目１１番３号',
        industry='非鉄金属',
        sec_code='57130',
        corporate_number='9010401015273',
    ),
    'E00024': EdinetCodeEntry(
        edinet_code='E00024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=42377,
        fiscal_year_end='3月31日',
        submitter_name='三井金属株式会社',
        submitter_name_en='Mitsui Kinzoku Company, Limited',
        submitter_name_yomi='ミツイキンゾクカブシキガイシャ',
        address='品川区大崎一丁目１１番１号',
        industry='非鉄金属',
        sec_code='57060',
        corporate_number='7010701011370',
    ),
    'E00026': EdinetCodeEntry(
        edinet_code='E00026',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1018,
        fiscal_year_end='3月31日',
        submitter_name='日本精鉱株式会社',
        submitter_name_en='NIHON SEIKO CO.,LTD.',
        submitter_name_yomi='ニホンセイコウカブシキガイシャ',
        address='新宿区下宮比町３－２',
        industry='非鉄金属',
        sec_code='57290',
        corporate_number='2011101016386',
    ),
    'E00027': EdinetCodeEntry(
        edinet_code='E00027',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='中外鉱業株式会社',
        submitter_name_en='Chugai Mining Co.,Ltd.',
        submitter_name_yomi='チュウガイコウギョウカブシキガイシャ',
        address='千代田区丸の内２丁目４番１号',
        industry='非鉄金属',
        sec_code='14910',
        corporate_number='7010001008720',
    ),
    'E00028': EdinetCodeEntry(
        edinet_code='E00028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36437,
        fiscal_year_end='3月31日',
        submitter_name='ＤＯＷＡホールディングス株式会社',
        submitter_name_en='DOWA HOLDINGS CO.,LTD.',
        submitter_name_yomi='ドウワホールディングスカブシキガイシャ',
        address='千代田区外神田四丁目１４番１号',
        industry='非鉄金属',
        sec_code='57140',
        corporate_number='1010001008750',
    ),
    'E00030': EdinetCodeEntry(
        edinet_code='E00030',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='3月31日',
        submitter_name='日本コークス工業株式会社',
        submitter_name_en='NIPPON COKE & ENGINEERING CO., LTD.',
        submitter_name_yomi='ニホンコークスコウギョウカブシキガイシャ',
        address='江東区豊洲三丁目３番３号',
        industry='石油・石炭製品',
        sec_code='33150',
        corporate_number='5010601029770',
    ),
    'E00032': EdinetCodeEntry(
        edinet_code='E00032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28208,
        fiscal_year_end='3月31日',
        submitter_name='古河機械金属株式会社',
        submitter_name_en='FURUKAWA CO.,LTD.',
        submitter_name_yomi='フルカワキカイキンゾクカブシキガイシャ',
        address='千代田区大手町二丁目６番４号',
        industry='非鉄金属',
        sec_code='57150',
        corporate_number='7010001008803',
    ),
    'E00033': EdinetCodeEntry(
        edinet_code='E00033',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2141,
        fiscal_year_end='3月31日',
        submitter_name='常磐興産株式会社',
        submitter_name_en='Joban Kosan Co.,Ltd.',
        submitter_name_yomi='ジョウバンコウサンカブシキガイシャ',
        address='いわき市常磐藤原町蕨平５０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9380001014473',
    ),
    'E00034': EdinetCodeEntry(
        edinet_code='E00034',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4244,
        fiscal_year_end='3月31日',
        submitter_name='太平洋興発株式会社',
        submitter_name_en='TAIHEIYO KOUHATSU INCORPORATED',
        submitter_name_yomi='タイヘイヨウコウハツカブシキガイシャ',
        address='台東区元浅草二丁目６番７号',
        industry='卸売業',
        sec_code='88350',
        corporate_number='8010501031238',
    ),
    'E00035': EdinetCodeEntry(
        edinet_code='E00035',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッチツ',
        submitter_name_en='NITCHITSU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャニッチツ',
        address='港区赤坂一丁目１１番３０号',
        industry='機械',
        sec_code='70210',
        corporate_number='4010401054508',
    ),
    'E00036': EdinetCodeEntry(
        edinet_code='E00036',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4176,
        fiscal_year_end='3月31日',
        submitter_name='日鉄鉱業株式会社',
        submitter_name_en='Nittetsu Mining CO.,Ltd.',
        submitter_name_yomi='ニッテツコウギョウカブシキガイシャ',
        address='千代田区丸の内二丁目３番２号',
        industry='鉱業',
        sec_code='15150',
        corporate_number='5010001008730',
    ),
    'E00037': EdinetCodeEntry(
        edinet_code='E00037',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8571,
        fiscal_year_end='3月31日',
        submitter_name='三井松島ホールディングス株式会社',
        submitter_name_en='MITSUI MATSUSHIMA HOLDINGS CO.,LTD.',
        submitter_name_yomi='ミツイマツシマホールディングスカブシキガイシャ',
        address='福岡市中央区大手門一丁目１番１２号',
        industry='その他製品',
        sec_code='15180',
        corporate_number='5290001010634',
    ),
    'E00041': EdinetCodeEntry(
        edinet_code='E00041',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14288,
        fiscal_year_end='3月31日',
        submitter_name='石油資源開発株式会社',
        submitter_name_en='Japan Petroleum Exploration Co., Ltd.',
        submitter_name_yomi='セキユシゲンカイハツカブシキガイシャ',
        address='千代田区丸の内一丁目７番１２号',
        industry='鉱業',
        sec_code='16620',
        corporate_number='3010001108219',
    ),
    'E00043': EdinetCodeEntry(
        edinet_code='E00043',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=290809,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＩＮＰＥＸ',
        submitter_name_en='INPEX CORPORATION',
        submitter_name_yomi='カブシキガイシャインペックス',
        address='港区赤坂五丁目３番１号',
        industry='鉱業',
        sec_code='16050',
        corporate_number='7010401078520',
    ),
    'E00045': EdinetCodeEntry(
        edinet_code='E00045',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=68,
        fiscal_year_end='3月31日',
        submitter_name='大室温泉株式会社',
        submitter_name_en='Omuro spa Co. , Ltd',
        submitter_name_yomi='オオムロオンセンカブシキガイシャ',
        address='伊東市富戸字先原１３１７番４５６２',
        industry='鉱業',
        sec_code=None,
        corporate_number='6080101013425',
    ),
    'E00048': EdinetCodeEntry(
        edinet_code='E00048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=161699,
        fiscal_year_end='3月31日',
        submitter_name='大和ハウス工業株式会社',
        submitter_name_en='DAIWA HOUSE INDUSTRY CO., LTD.',
        submitter_name_yomi='ダイワハウスコウギョウカブシキガイシャ',
        address='大阪市北区梅田三丁目３番５号',
        industry='建設業',
        sec_code='19250',
        corporate_number='6120001059662',
    ),
    'E00049': EdinetCodeEntry(
        edinet_code='E00049',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15324,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＩＰＰＯ',
        submitter_name_en='NIPPO CORPORATION',
        submitter_name_yomi='カブシキガイシャニッポ',
        address='中央区京橋一丁目１９番１１号',
        industry='建設業',
        sec_code=None,
        corporate_number='9010001034987',
    ),
    'E00050': EdinetCodeEntry(
        edinet_code='E00050',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='日本コムシス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンコムシスカブシキガイシャ',
        address='品川区東五反田２丁目１７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010701022825',
    ),
    'E00051': EdinetCodeEntry(
        edinet_code='E00051',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=28463,
        fiscal_year_end='3月31日',
        submitter_name='前田建設工業株式会社',
        submitter_name_en='MAEDA CORPORATION',
        submitter_name_yomi='マエダケンセツコウギョウカブシキガイシャ',
        address='千代田区富士見二丁目１０番２号',
        industry='建設業',
        sec_code=None,
        corporate_number='4010001008789',
    ),
    'E00052': EdinetCodeEntry(
        edinet_code='E00052',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=122742,
        fiscal_year_end='3月31日',
        submitter_name='大成建設株式会社',
        submitter_name_en='taisei corporation',
        submitter_name_yomi='タイセイケンセツカブシキガイシャ',
        address='新宿区西新宿一丁目２５番１号',
        industry='建設業',
        sec_code='18010',
        corporate_number='4011101011880',
    ),
    'E00053': EdinetCodeEntry(
        edinet_code='E00053',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=74365,
        fiscal_year_end='3月31日',
        submitter_name='清水建設株式会社',
        submitter_name_en='SHIMIZU CORPORATION',
        submitter_name_yomi='シミズケンセツカブシキガイシャ',
        address='中央区京橋二丁目１６番１号',
        industry='建設業',
        sec_code='18030',
        corporate_number='1010401013565',
    ),
    'E00055': EdinetCodeEntry(
        edinet_code='E00055',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=57752,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大林組',
        submitter_name_en='OBAYASHI  CORPORATION',
        submitter_name_yomi='カブシキガイシャオオバヤシグミ',
        address='港区港南二丁目１５番２号',
        industry='建設業',
        sec_code='18020',
        corporate_number='7010401088742',
    ),
    'E00056': EdinetCodeEntry(
        edinet_code='E00056',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30108,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000熊谷組',
        submitter_name_en='Kumagaigumi Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクマガイグミ',
        address='福井市中央２丁目６番８号',
        industry='建設業',
        sec_code='18610',
        corporate_number='1210001001082',
    ),
    'E00057': EdinetCodeEntry(
        edinet_code='E00057',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='佐藤工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サトウコウギョウカブシキガイシャ',
        address='富山市桜木町１番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2230001001055',
    ),
    'E00058': EdinetCodeEntry(
        edinet_code='E00058',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=81447,
        fiscal_year_end='3月31日',
        submitter_name='鹿島建設株式会社',
        submitter_name_en='KAJIMA  CORPORATION',
        submitter_name_yomi='カジマケンセツカブシキガイシャ',
        address='港区元赤坂一丁目３番１号',
        industry='建設業',
        sec_code='18120',
        corporate_number='8010401006744',
    ),
    'E00059': EdinetCodeEntry(
        edinet_code='E00059',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5012,
        fiscal_year_end='5月31日',
        submitter_name='日本国土開発株式会社',
        submitter_name_en='JDC CORPORATION',
        submitter_name_yomi='ニホンコクドカイハツカブシキガイシャ',
        address='港区虎ノ門四丁目３番１３号',
        industry='建設業',
        sec_code='18870',
        corporate_number='3010401022812',
    ),
    'E00060': EdinetCodeEntry(
        edinet_code='E00060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23513,
        fiscal_year_end='3月31日',
        submitter_name='西松建設株式会社',
        submitter_name_en='Nishimatsu Construction  Co., Ltd.',
        submitter_name_yomi='ニシマツケンセツカブシキガイシャ',
        address='港区虎ノ門一丁目１７番１号',
        industry='建設業',
        sec_code='18200',
        corporate_number='8010401021454',
    ),
    'E00061': EdinetCodeEntry(
        edinet_code='E00061',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19350,
        fiscal_year_end='3月31日',
        submitter_name='前田道路株式会社',
        submitter_name_en='MAEDA ROAD CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='マエダドウロカブシキガイシャ',
        address='品川区大崎１丁目１１番３号',
        industry='建設業',
        sec_code=None,
        corporate_number='6010701009184',
    ),
    'E00063': EdinetCodeEntry(
        edinet_code='E00063',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5519,
        fiscal_year_end='3月31日',
        submitter_name='飛島建設株式会社',
        submitter_name_en='TOBISHIMA CORPORATION',
        submitter_name_yomi='トビシマケンセツカブシキガイシャ',
        address='港区港南１丁目８番１５号',
        industry='建設業',
        sec_code=None,
        corporate_number='8010001008703',
    ),
    'E00064': EdinetCodeEntry(
        edinet_code='E00064',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4000,
        fiscal_year_end='3月31日',
        submitter_name='松井建設株式会社',
        submitter_name_en='MATSUI CONSTRUCTION CO., LTD.',
        submitter_name_yomi='マツイケンセツカブシキガイシャ',
        address='中央区新川一丁目１７番２２号',
        industry='建設業',
        sec_code='18100',
        corporate_number='7010001034956',
    ),
    'E00065': EdinetCodeEntry(
        edinet_code='E00065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18293,
        fiscal_year_end='3月31日',
        submitter_name='鉄建建設株式会社',
        submitter_name_en='TEKKEN CORPORATION',
        submitter_name_yomi='テッケンケンセツカブシキガイシャ',
        address='千代田区神田三崎町二丁目５番３号',
        industry='建設業',
        sec_code='18150',
        corporate_number='2010001008709',
    ),
    'E00066': EdinetCodeEntry(
        edinet_code='E00066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7584,
        fiscal_year_end='3月31日',
        submitter_name='東亜道路工業株式会社',
        submitter_name_en='TOA ROAD CORPORATION',
        submitter_name_yomi='トウアドウロコウギョウカブシキガイシャ',
        address='港区六本木七丁目３番７号',
        industry='建設業',
        sec_code='18820',
        corporate_number='7010401020201',
    ),
    'E00067': EdinetCodeEntry(
        edinet_code='E00067',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12290,
        fiscal_year_end='3月31日',
        submitter_name='日本道路株式会社',
        submitter_name_en='THE NIPPON ROAD CO.,LTD.',
        submitter_name_yomi='ニッポンドウロカブシキガイシャ',
        address='港区芝浦一丁目２番３号',
        industry='建設業',
        sec_code=None,
        corporate_number='9010401023409',
    ),
    'E00069': EdinetCodeEntry(
        edinet_code='E00069',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3695,
        fiscal_year_end='3月31日',
        submitter_name='株式会社錢高組',
        submitter_name_en='THE ZENITAKA CORPORATION',
        submitter_name_yomi='カブシキガイシャゼニタカグミ',
        address='大阪市西区西本町二丁目２番４号',
        industry='建設業',
        sec_code='18110',
        corporate_number='5120001049004',
    ),
    'E00073': EdinetCodeEntry(
        edinet_code='E00073',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3481,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中電工',
        submitter_name_en='CHUDENKO CORPORATION',
        submitter_name_yomi='カブシキガイシャチュウデンコウ',
        address='広島市中区小網町６番１２号',
        industry='建設業',
        sec_code='19410',
        corporate_number='9240001006971',
    ),
    'E00074': EdinetCodeEntry(
        edinet_code='E00074',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10264,
        fiscal_year_end='3月31日',
        submitter_name='株式会社関電工',
        submitter_name_en='KANDENKO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャカンデンコウ',
        address='港区芝浦４丁目８番３３号',
        industry='建設業',
        sec_code='19420',
        corporate_number='9010401006818',
    ),
    'E00075': EdinetCodeEntry(
        edinet_code='E00075',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26411,
        fiscal_year_end='3月31日',
        submitter_name='株式会社きんでん',
        submitter_name_en='KINDEN CORPORATION',
        submitter_name_yomi='カブシキガイシャキンデン',
        address='大阪市北区本庄東二丁目３番４１号',
        industry='建設業',
        sec_code='19440',
        corporate_number='1120001063033',
    ),
    'E00076': EdinetCodeEntry(
        edinet_code='E00076',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7680,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーエネック',
        submitter_name_en='TOENEC CORPORATION',
        submitter_name_yomi='カブシキガイシャトーエネック',
        address='名古屋市中区栄一丁目３１番２３号',
        industry='建設業',
        sec_code='19460',
        corporate_number='8180001038758',
    ),
    'E00078': EdinetCodeEntry(
        edinet_code='E00078',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7480,
        fiscal_year_end='6月30日',
        submitter_name='日本工営株式会社',
        submitter_name_en='Nippon Koei Co., Ltd.',
        submitter_name_yomi='ニホンコウエイカブシキガイシャ',
        address='千代田区麹町５丁目４番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010001016851',
    ),
    'E00079': EdinetCodeEntry(
        edinet_code='E00079',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2368,
        fiscal_year_end='3月31日',
        submitter_name='徳倉建設株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トクラケンセツカブシキガイシャ',
        address='名古屋市中区錦三丁目１３番５号',
        industry='建設業',
        sec_code='18920',
        corporate_number='5180001038835',
    ),
    'E00080': EdinetCodeEntry(
        edinet_code='E00080',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18976,
        fiscal_year_end='3月31日',
        submitter_name='東亜建設工業株式会社',
        submitter_name_en='TOA CORPORATION',
        submitter_name_yomi='トウアケンセツコウギョウカブシキガイシャ',
        address='新宿区西新宿三丁目７番１号',
        industry='建設業',
        sec_code='18850',
        corporate_number='3011101055078',
    ),
    'E00081': EdinetCodeEntry(
        edinet_code='E00081',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11374,
        fiscal_year_end='3月31日',
        submitter_name='若築建設株式会社',
        submitter_name_en='WAKACHIKU CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='ワカチクケンセツカブシキガイシャ',
        address='北九州市若松区浜町１－４－７',
        industry='建設業',
        sec_code='18880',
        corporate_number='6290801012011',
    ),
    'E00082': EdinetCodeEntry(
        edinet_code='E00082',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=14049,
        fiscal_year_end='3月31日',
        submitter_name='東洋建設株式会社',
        submitter_name_en='TOYO CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='トウヨウケンセツカブシキガイシャ',
        address='大阪市中央区高麗橋４丁目１番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='9120001077496',
    ),
    'E00083': EdinetCodeEntry(
        edinet_code='E00083',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19838,
        fiscal_year_end='3月31日',
        submitter_name='株式会社奥村組',
        submitter_name_en='OKUMURA CORPORATION',
        submitter_name_yomi='カブシキガイシャオクムラグミ',
        address='大阪市阿倍野区松崎町二丁目２番２号',
        industry='建設業',
        sec_code='18330',
        corporate_number='7120001004931',
    ),
    'E00085': EdinetCodeEntry(
        edinet_code='E00085',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12003,
        fiscal_year_end='3月31日',
        submitter_name='三井住友建設株式会社',
        submitter_name_en='Sumitomo Mitsui Construction Co.,Ltd.',
        submitter_name_yomi='ミツイスミトモケンセツカブシキガイシャ',
        address='中央区佃二丁目１番６号',
        industry='建設業',
        sec_code=None,
        corporate_number='2010001131477',
    ),
    'E00086': EdinetCodeEntry(
        edinet_code='E00086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30449,
        fiscal_year_end='3月31日',
        submitter_name='五洋建設株式会社',
        submitter_name_en='PENTA-OCEAN CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='ゴヨウケンセツカブシキガイシャ',
        address='文京区後楽二丁目２番８号',
        industry='建設業',
        sec_code='18930',
        corporate_number='1010001000006',
    ),
    'E00090': EdinetCodeEntry(
        edinet_code='E00090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=57500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000長谷工コーポレーション',
        submitter_name_en='HASEKO Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000ハセコウコーポレーション',
        address='港区芝二丁目３２番１号',
        industry='建設業',
        sec_code='18080',
        corporate_number='7010401024061',
    ),
    'E00091': EdinetCodeEntry(
        edinet_code='E00091',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='中央ビルト工業株式会社',
        submitter_name_en='CHUO BUILD INDUSTRY CO.,LTD.',
        submitter_name_yomi='チュウオウビルトコウギョウカブシキガイシャ',
        address='中央区日本橋富沢町１１番１２号',
        industry='金属製品',
        sec_code=None,
        corporate_number='2010001034861',
    ),
    'E00092': EdinetCodeEntry(
        edinet_code='E00092',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2881,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京エネシス',
        submitter_name_en='TOKYO ENERGY & SYSTEMS INC.',
        submitter_name_yomi='カブシキガイシャトウキョウエネシス',
        address='中央区日本橋茅場町一丁目３番１号',
        industry='建設業',
        sec_code='19450',
        corporate_number='6010401020680',
    ),
    'E00093': EdinetCodeEntry(
        edinet_code='E00093',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4324,
        fiscal_year_end='3月31日',
        submitter_name='大末建設株式会社',
        submitter_name_en='DAISUE CONSTRUCTION CO., LTD.',
        submitter_name_yomi='ダイスエケンセツカブシキガイシャ',
        address='大阪市中央区久太郎町二丁目５番２８号',
        industry='建設業',
        sec_code='18140',
        corporate_number='5120001083408',
    ),
    'E00094': EdinetCodeEntry(
        edinet_code='E00094',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6888,
        fiscal_year_end='3月31日',
        submitter_name='エクシオグループ株式会社',
        submitter_name_en='EXEO Group, Inc.',
        submitter_name_yomi='エクシオグループカブシキガイシャ',
        address='渋谷区渋谷三丁目２９番２０号',
        industry='建設業',
        sec_code='19510',
        corporate_number='3011001031955',
    ),
    'E00095': EdinetCodeEntry(
        edinet_code='E00095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='大豊建設株式会社',
        submitter_name_en='DAIHO CORPORATION',
        submitter_name_yomi='ダイホウケンセツカブシキガイシャ',
        address='中央区新川一丁目２４番４号',
        industry='建設業',
        sec_code='18220',
        corporate_number='3010001034869',
    ),
    'E00097': EdinetCodeEntry(
        edinet_code='E00097',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社不動テトラ',
        submitter_name_en='Fudo Tetra Corporation',
        submitter_name_yomi='カブシキガイシャフドウテトラ',
        address='中央区日本橋小網町７番２号',
        industry='建設業',
        sec_code='18130',
        corporate_number='4010001141053',
    ),
    'E00098': EdinetCodeEntry(
        edinet_code='E00098',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6119,
        fiscal_year_end='3月31日',
        submitter_name='ライト工業株式会社',
        submitter_name_en='RAITO KOGYO CO., LTD.',
        submitter_name_yomi='ライトコウギョウカブシキガイシャ',
        address='千代田区九段北４－２－３５',
        industry='建設業',
        sec_code='19260',
        corporate_number='7010001008811',
    ),
    'E00099': EdinetCodeEntry(
        edinet_code='E00099',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=635,
        fiscal_year_end='3月31日',
        submitter_name='鈴縫工業株式会社',
        submitter_name_en='SUZUNUI CORPORATION',
        submitter_name_yomi='スズヌイコウギョウカブシキガイシャ',
        address='日立市城南町１丁目１１番３１号',
        industry='建設業',
        sec_code=None,
        corporate_number='6050001023270',
    ),
    'E00101': EdinetCodeEntry(
        edinet_code='E00101',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='サンユー建設株式会社',
        submitter_name_en='SANYU CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='サンユーケンセツカブシキガイシャ',
        address='大田区南雪谷２丁目１７番８号',
        industry='建設業',
        sec_code='18410',
        corporate_number='9010801004850',
    ),
    'E00105': EdinetCodeEntry(
        edinet_code='E00105',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5061,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナカノフドー建設',
        submitter_name_en='NAKANO CORPORATION',
        submitter_name_yomi='カブシキガイシャナカノフドーケンセツ',
        address='千代田区九段北四丁目２番２８号',
        industry='建設業',
        sec_code='18270',
        corporate_number='4010001008731',
    ),
    'E00107': EdinetCodeEntry(
        edinet_code='E00107',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8105,
        fiscal_year_end='3月31日',
        submitter_name='三機工業株式会社',
        submitter_name_en='SANKI ENGINEERING CO.,LTD.',
        submitter_name_yomi='サンキコウギョウカブシキガイシャ',
        address='中央区明石町８番１号',
        industry='建設業',
        sec_code='19610',
        corporate_number='2010001008683',
    ),
    'E00109': EdinetCodeEntry(
        edinet_code='E00109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1980,
        fiscal_year_end='3月31日',
        submitter_name='三晃金属工業株式会社',
        submitter_name_en='Sanko Metal Industrial Co., Ltd.',
        submitter_name_yomi='サンコウキンゾクコウギョウカブシキガイシャ',
        address='港区芝浦４丁目１３番２３号',
        industry='建設業',
        sec_code='19720',
        corporate_number='9010401038472',
    ),
    'E00112': EdinetCodeEntry(
        edinet_code='E00112',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2810,
        fiscal_year_end='3月31日',
        submitter_name='東鉄工業株式会社',
        submitter_name_en='TOTETSU KOGYO CO.,LTD.',
        submitter_name_yomi='トウテツコウギョウカブシキガイシャ',
        address='新宿区信濃町３４番地',
        industry='建設業',
        sec_code='18350',
        corporate_number='6011101014147',
    ),
    'E00113': EdinetCodeEntry(
        edinet_code='E00113',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7070,
        fiscal_year_end='3月31日',
        submitter_name='太平電業株式会社',
        submitter_name_en='TAIHEI DENGYO KAISHA,LTD.',
        submitter_name_yomi='タイヘイデンギョウカブシキガイシャ',
        address='千代田区神田神保町二丁目４番地',
        industry='建設業',
        sec_code='19680',
        corporate_number='4010001008748',
    ),
    'E00114': EdinetCodeEntry(
        edinet_code='E00114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6440,
        fiscal_year_end='3月31日',
        submitter_name='住友電設株式会社',
        submitter_name_en='SUMITOMO DENSETSU CO.,LTD.',
        submitter_name_yomi='スミトモデンセツカブシキガイシャ',
        address='大阪市西区阿波座２丁目１番４号',
        industry='建設業',
        sec_code='19490',
        corporate_number='7120001044515',
    ),
    'E00115': EdinetCodeEntry(
        edinet_code='E00115',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8494,
        fiscal_year_end='3月31日',
        submitter_name='日本電設工業株式会社',
        submitter_name_en='NIPPON DENSETSU KOGYO CO.,LTD',
        submitter_name_yomi='ニッポンデンセツコウギョウカブシキガイシャ',
        address='台東区池之端一丁目２番２３号',
        industry='建設業',
        sec_code='19500',
        corporate_number='6010501016240',
    ),
    'E00116': EdinetCodeEntry(
        edinet_code='E00116',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1120,
        fiscal_year_end='3月31日',
        submitter_name='技研興業株式会社',
        submitter_name_en='Giken Kogyo CO.,LTD',
        submitter_name_yomi='ギケンコウギョウカブシキガイシャ',
        address='杉並区阿佐谷南三丁目７番２号',
        industry='建設業',
        sec_code=None,
        corporate_number='7011301012899',
    ),
    'E00117': EdinetCodeEntry(
        edinet_code='E00117',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4329,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イチケン',
        submitter_name_en='ICHIKEN Co., Ltd.',
        submitter_name_yomi='カブシキガイシャイチケン',
        address='港区港南二丁目１５番１号',
        industry='建設業',
        sec_code='18470',
        corporate_number='7010501028268',
    ),
    'E00118': EdinetCodeEntry(
        edinet_code='E00118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='南海辰村建設株式会社',
        submitter_name_en='Nankai Tatsumura Construction Co., Ltd.',
        submitter_name_yomi='ナンカイタツムラケンセツカブシキガイシャ',
        address='大阪市浪速区難波中三丁目５番１９号',
        industry='建設業',
        sec_code='18500',
        corporate_number='3120001039386',
    ),
    'E00119': EdinetCodeEntry(
        edinet_code='E00119',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6176,
        fiscal_year_end='3月31日',
        submitter_name='中外炉工業株式会社',
        submitter_name_en='Chugai Ro Co.,Ltd.',
        submitter_name_yomi='チュウガイロコウギョウカブシキガイシャ',
        address='大阪市中央区平野町３丁目６番１号',
        industry='建設業',
        sec_code='19640',
        corporate_number='2120001049015',
    ),
    'E00120': EdinetCodeEntry(
        edinet_code='E00120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9614,
        fiscal_year_end='3月31日',
        submitter_name='株式会社淺沼組',
        submitter_name_en='ASANUMA CORPORATION',
        submitter_name_yomi='カブシキガイシャアサヌマグミ',
        address='大阪市浪速区湊町一丁目２番３号\u3000マルイト難波ビル',
        industry='建設業',
        sec_code='18520',
        corporate_number='8120001022651',
    ),
    'E00121': EdinetCodeEntry(
        edinet_code='E00121',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1886,
        fiscal_year_end='3月31日',
        submitter_name='佐田建設株式会社',
        submitter_name_en='Sata Construction Co.,Ltd.',
        submitter_name_yomi='サタケンセツカブシキガイシャ',
        address='前橋市元総社町一丁目１番地の７',
        industry='建設業',
        sec_code='18260',
        corporate_number='9070001001420',
    ),
    'E00127': EdinetCodeEntry(
        edinet_code='E00127',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1493,
        fiscal_year_end=None,
        submitter_name='日本電通株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンデンツウカブシキガイシャ',
        address='大阪市港区磯路２丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001030138',
    ),
    'E00129': EdinetCodeEntry(
        edinet_code='E00129',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5676,
        fiscal_year_end=None,
        submitter_name='ＮＤＳ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌディエスカブシキガイシャ',
        address='名古屋市中区千代田二丁目１５番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001039415',
    ),
    'E00130': EdinetCodeEntry(
        edinet_code='E00130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1640,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000森組',
        submitter_name_en='Mori-Gumi Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000モリグミ',
        address='大阪市中央区道修町４丁目５番１７号',
        industry='建設業',
        sec_code='18530',
        corporate_number='4120001077567',
    ),
    'E00133': EdinetCodeEntry(
        edinet_code='E00133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月31日',
        submitter_name='金下建設株式会社',
        submitter_name_en='The Kaneshita Construction Co.,Ltd.',
        submitter_name_yomi='カネシタケンセツカブシキガイシャ',
        address='宮津市字須津４７１番地の１',
        industry='建設業',
        sec_code='18970',
        corporate_number='8130001040495',
    ),
    'E00135': EdinetCodeEntry(
        edinet_code='E00135',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1091,
        fiscal_year_end='3月31日',
        submitter_name='新生テクノス株式会社',
        submitter_name_en='shinsei technos co., ltd.',
        submitter_name_yomi='シンセイテクノスカブシキガイシャ',
        address='港区芝五丁目２９番１１号',
        industry='建設業',
        sec_code=None,
        corporate_number='7010401013114',
    ),
    'E00137': EdinetCodeEntry(
        edinet_code='E00137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7803,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユアテック',
        submitter_name_en='YURTEC CORPORATION',
        submitter_name_yomi='カブシキガイシャユアテック',
        address='仙台市宮城野区榴岡４丁目１番１号',
        industry='建設業',
        sec_code='19340',
        corporate_number='4370001006286',
    ),
    'E00138': EdinetCodeEntry(
        edinet_code='E00138',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月20日',
        submitter_name='株式会社ヤマト',
        submitter_name_en='YAMATO CORPORATION',
        submitter_name_yomi='カブシキガイシャヤマト',
        address='前橋市古市町１１８番地',
        industry='建設業',
        sec_code='19670',
        corporate_number='5070001001977',
    ),
    'E00142': EdinetCodeEntry(
        edinet_code='E00142',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6052,
        fiscal_year_end='3月31日',
        submitter_name='日特建設株式会社',
        submitter_name_en='NITTOC CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='ニットクケンセツカブシキガイシャ',
        address='中央区東日本橋３丁目１０番６号',
        industry='建設業',
        sec_code='19290',
        corporate_number='7010001053304',
    ),
    'E00143': EdinetCodeEntry(
        edinet_code='E00143',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=203094,
        fiscal_year_end='1月31日',
        submitter_name='積水ハウス株式会社',
        submitter_name_en='Sekisui House,Ltd.',
        submitter_name_yomi='セキスイハウスカブシキガイシャ',
        address='大阪市北区大淀中一丁目１番８８号',
        industry='建設業',
        sec_code='19280',
        corporate_number='8120001059652',
    ),
    'E00144': EdinetCodeEntry(
        edinet_code='E00144',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='松尾建設株式会社',
        submitter_name_en='matsuo construction co.,ltd.',
        submitter_name_yomi='マツオケンセツカブシキガイシャ',
        address='佐賀市多布施一丁目４番２７号',
        industry='建設業',
        sec_code=None,
        corporate_number='6300001000905',
    ),
    'E00146': EdinetCodeEntry(
        edinet_code='E00146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12561,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クラフティア',
        submitter_name_en='KRAFTIA CORPORATION',
        submitter_name_yomi='カブシキガイシャクラフティア',
        address='福岡市中央区天神一丁目１１番１号ＯＮＥＦＵＫＵＯＫＡＢＬＤＧ．１４階',
        industry='建設業',
        sec_code='19590',
        corporate_number='6290001001120',
    ),
    'E00147': EdinetCodeEntry(
        edinet_code='E00147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23001,
        fiscal_year_end='3月31日',
        submitter_name='戸田建設株式会社',
        submitter_name_en='TODA CORPORATION',
        submitter_name_yomi='トダケンセツカブシキガイシャ',
        address='中央区京橋１－７－１',
        industry='建設業',
        sec_code='18600',
        corporate_number='6010001034874',
    ),
    'E00148': EdinetCodeEntry(
        edinet_code='E00148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6808,
        fiscal_year_end='3月31日',
        submitter_name='矢作建設工業株式会社',
        submitter_name_en='YAHAGI CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='ヤハギケンセツコウギョウカブシキガイシャ',
        address='名古屋市東区葵三丁目１９番７号',
        industry='建設業',
        sec_code='18700',
        corporate_number='6180001018506',
    ),
    'E00149': EdinetCodeEntry(
        edinet_code='E00149',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13134,
        fiscal_year_end='3月31日',
        submitter_name='高砂熱学工業株式会社',
        submitter_name_en='Takasago Thermal Engineering Co., Ltd.',
        submitter_name_yomi='タカサゴネツガクコウギョウカブシキガイシャ',
        address='新宿区新宿六丁目２７番３０号',
        industry='建設業',
        sec_code='19690',
        corporate_number='3010001008749',
    ),
    'E00153': EdinetCodeEntry(
        edinet_code='E00153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3857,
        fiscal_year_end='3月31日',
        submitter_name='株式会社朝日工業社',
        submitter_name_en='ASAHI KOGYOSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアサヒコウギョウシャ',
        address='港区浜松町一丁目２５番７号',
        industry='建設業',
        sec_code='19750',
        corporate_number='5010401000023',
    ),
    'E00156': EdinetCodeEntry(
        edinet_code='E00156',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6293,
        fiscal_year_end='3月31日',
        submitter_name='大林道路株式会社',
        submitter_name_en='OBAYASHI ROAD CORPORATION',
        submitter_name_yomi='オオバヤシドウロカブシキカイシャ',
        address='千代田区猿楽町二丁目８番８号',
        industry='建設業',
        sec_code=None,
        corporate_number='4010601028815',
    ),
    'E00157': EdinetCodeEntry(
        edinet_code='E00157',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9812,
        fiscal_year_end='3月31日',
        submitter_name='都築電気株式会社',
        submitter_name_en='TSUZUKI DENKI CO., LTD.',
        submitter_name_yomi='ツヅキデンキカブシキガイシャ',
        address='港区新橋六丁目１９番１５号',
        industry='卸売業',
        sec_code='81570',
        corporate_number='9010401054908',
    ),
    'E00161': EdinetCodeEntry(
        edinet_code='E00161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6889,
        fiscal_year_end='3月31日',
        submitter_name='明星工業株式会社',
        submitter_name_en='MEISEI INDUSTRIAL Co.,Ltd.',
        submitter_name_yomi='メイセイコウギョウカブシキガイシャ',
        address='大阪市西区京町堀１丁目８番５号',
        industry='建設業',
        sec_code='19760',
        corporate_number='1120001049032',
    ),
    'E00165': EdinetCodeEntry(
        edinet_code='E00165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＲＩＳＥ',
        submitter_name_en='RISE Inc.',
        submitter_name_yomi='カブシキガイシャライズ',
        address='港区西新橋三丁目１６番１１号\u3000愛宕イーストビル３階',
        industry='不動産業',
        sec_code='88360',
        corporate_number='8010001128641',
    ),
    'E00167': EdinetCodeEntry(
        edinet_code='E00167',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1751,
        fiscal_year_end='3月31日',
        submitter_name='株式会社佐藤渡辺',
        submitter_name_en='WATANABE SATO CO., LTD.',
        submitter_name_yomi='カブシキガイシャサトウワタナベ',
        address='港区南麻布一丁目１８番４号',
        industry='建設業',
        sec_code='18070',
        corporate_number='5010401031200',
    ),
    'E00168': EdinetCodeEntry(
        edinet_code='E00168',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5753,
        fiscal_year_end='3月31日',
        submitter_name='日比谷総合設備株式会社',
        submitter_name_en='Hibiya Engineering,Ltd.',
        submitter_name_yomi='ヒビヤソウゴウセツビカブシキガイシャ',
        address='港区三田三丁目５番２７号',
        industry='建設業',
        sec_code='19820',
        corporate_number='9010401025405',
    ),
    'E00169': EdinetCodeEntry(
        edinet_code='E00169',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社竹中工務店',
        submitter_name_en='TAKENAKA CORPORATION',
        submitter_name_yomi='カブシキガイシャタケナカコウムテン',
        address='大阪市中央区本町四丁目１番１３号',
        industry='建設業',
        sec_code=None,
        corporate_number='3120001077469',
    ),
    'E00170': EdinetCodeEntry(
        edinet_code='E00170',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9068,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ヤマダ・エスバイエルホーム',
        submitter_name_en='YAMADA SXL HOME CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤマダエスバイエルホーム',
        address='高崎市栄町１－１',
        industry='建設業',
        sec_code=None,
        corporate_number='7120001061675',
    ),
    'E00173': EdinetCodeEntry(
        edinet_code='E00173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1190,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンテック',
        submitter_name_en='Sanyo Engineering & Construction Inc.',
        submitter_name_yomi='カブシキガイシャサンテック',
        address='千代田区二番町３番地１３',
        industry='建設業',
        sec_code='19600',
        corporate_number='4010001008681',
    ),
    'E00174': EdinetCodeEntry(
        edinet_code='E00174',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='青木あすなろ建設株式会社',
        submitter_name_en='Asunaro Aoki Construction Co.,Ltd.',
        submitter_name_yomi='アオキアスナロケンセツカブシキガイシャ',
        address='港区芝四丁目８－２',
        industry='建設業',
        sec_code=None,
        corporate_number='4010401010452',
    ),
    'E00175': EdinetCodeEntry(
        edinet_code='E00175',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9116,
        fiscal_year_end='3月31日',
        submitter_name='北野建設株式会社',
        submitter_name_en='KITANO CONSTRUCTION CORP.',
        submitter_name_yomi='キタノケンセツカブシキガイシャ',
        address='長野市県町５２４番地',
        industry='建設業',
        sec_code='18660',
        corporate_number='7100001000742',
    ),
    'E00176': EdinetCodeEntry(
        edinet_code='E00176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='世紀東急工業株式会社',
        submitter_name_en='SEIKITOKYU KOGYO CO.,LTD.',
        submitter_name_yomi='セイキトウキュウコウギョウカブシキガイシャ',
        address='港区芝公園二丁目９番３号',
        industry='建設業',
        sec_code='18980',
        corporate_number='1010401015438',
    ),
    'E00178': EdinetCodeEntry(
        edinet_code='E00178',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=490,
        fiscal_year_end='3月31日',
        submitter_name='日成ビルド工業株式会社',
        submitter_name_en='NISSEI BUILD KOGYO CO.,LTD.',
        submitter_name_yomi='ニッセイビルドコウギョウカブシキガイシャ',
        address='金沢市金石北３丁目１６番１０号',
        industry='建設業',
        sec_code=None,
        corporate_number='2220001004983',
    ),
    'E00179': EdinetCodeEntry(
        edinet_code='E00179',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5315,
        fiscal_year_end='3月31日',
        submitter_name='株式会社植木組',
        submitter_name_en='UEKI  CORPORATION',
        submitter_name_yomi='カブシキガイシャウエキグミ',
        address='柏崎市駅前１丁目５番４５号',
        industry='建設業',
        sec_code='18670',
        corporate_number='8110001017149',
    ),
    'E00181': EdinetCodeEntry(
        edinet_code='E00181',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3451,
        fiscal_year_end='3月31日',
        submitter_name='株式会社四電工',
        submitter_name_en='YONDENKO CORPORATION',
        submitter_name_yomi='カブシキガイシャヨンデンコウ',
        address='高松市花ノ宮町２丁目３番９号',
        industry='建設業',
        sec_code='19390',
        corporate_number='7470001004244',
    ),
    'E00182': EdinetCodeEntry(
        edinet_code='E00182',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1310,
        fiscal_year_end='3月31日',
        submitter_name='神田通信機株式会社',
        submitter_name_en='KANDA TSUSHINKI CO.,LTD.',
        submitter_name_yomi='カンダツウシンキカブシキガイシャ',
        address='千代田区神田錦町１丁目１９番１',
        industry='建設業',
        sec_code='19920',
        corporate_number='6010001013597',
    ),
    'E00183': EdinetCodeEntry(
        edinet_code='E00183',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6455,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大気社',
        submitter_name_en='Taikisha Ltd.',
        submitter_name_yomi='カブシキガイシャタイキシャ',
        address='新宿区西新宿八丁目１７番１号',
        industry='建設業',
        sec_code='19790',
        corporate_number='7011101011812',
    ),
    'E00184': EdinetCodeEntry(
        edinet_code='E00184',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1600,
        fiscal_year_end='3月31日',
        submitter_name='西部電気工業株式会社',
        submitter_name_en='Seibu Electric Industry Co.,Ltd.',
        submitter_name_yomi='セイブデンキコウギョウカブシキガイシャ',
        address='福岡市博多区博多駅東三丁目７番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='5290001037925',
    ),
    'E00185': EdinetCodeEntry(
        edinet_code='E00185',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1430,
        fiscal_year_end='3月31日',
        submitter_name='日本リーテック株式会社',
        submitter_name_en='NIPPON RIETEC CO.,LTD.',
        submitter_name_yomi='ニッポンリーテックカブシキガイシャ',
        address='千代田区神田錦町一丁目６番地',
        industry='建設業',
        sec_code='19380',
        corporate_number='5011501002891',
    ),
    'E00187': EdinetCodeEntry(
        edinet_code='E00187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1004,
        fiscal_year_end='3月31日',
        submitter_name='日建工学株式会社',
        submitter_name_en='NIKKEN KOGAKU CO., LTD.',
        submitter_name_yomi='ニッケンコウガクカブシキガイシャ',
        address='新宿区西新宿６丁目１０番１号',
        industry='サービス業',
        sec_code='97670',
        corporate_number='1011101015686',
    ),
    'E00189': EdinetCodeEntry(
        edinet_code='E00189',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=590,
        fiscal_year_end='3月31日',
        submitter_name='株式会社協和日成',
        submitter_name_en='KYOWANISSEI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウワニッセイ',
        address='中央区入船三丁目８番５号',
        industry='建設業',
        sec_code='19810',
        corporate_number='5011001006550',
    ),
    'E00191': EdinetCodeEntry(
        edinet_code='E00191',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4104,
        fiscal_year_end=None,
        submitter_name='シーキューブ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーキューブカブシキガイシャ',
        address='名古屋市中区門前町１番５１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001036656',
    ),
    'E00193': EdinetCodeEntry(
        edinet_code='E00193',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2847,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴＴＫ',
        submitter_name_en='TTK Co., Ltd.',
        submitter_name_yomi='カブシキガイシャティティケイ',
        address='仙台市若林区新寺１丁目２番２３号',
        industry='建設業',
        sec_code=None,
        corporate_number='5370001004355',
    ),
    'E00194': EdinetCodeEntry(
        edinet_code='E00194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4479,
        fiscal_year_end='3月31日',
        submitter_name='ダイダン株式会社',
        submitter_name_en='DAI-DAN CO.,LTD.',
        submitter_name_yomi='ダイダンカブシキガイシャ',
        address='大阪市西区江戸堀１丁目９番２５号',
        industry='建設業',
        sec_code='19800',
        corporate_number='6120001045084',
    ),
    'E00196': EdinetCodeEntry(
        edinet_code='E00196',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5158,
        fiscal_year_end='12月31日',
        submitter_name='株式会社福田組',
        submitter_name_en='FUKUDA CORPORATION',
        submitter_name_yomi='カブシキガイシャフクダグミ',
        address='新潟市中央区一番堀通町３番地１０',
        industry='建設業',
        sec_code='18990',
        corporate_number='9110001004880',
    ),
    'E00197': EdinetCodeEntry(
        edinet_code='E00197',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3873,
        fiscal_year_end='4月30日',
        submitter_name='株式会社日本ハウスホールディングス',
        submitter_name_en='NIHON HOUSE HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャニホンハウスホールディングス',
        address='千代田区飯田橋四丁目３番８',
        industry='建設業',
        sec_code='18730',
        corporate_number='6400001001397',
    ),
    'E00198': EdinetCodeEntry(
        edinet_code='E00198',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=801,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＹＳＫＥＮ',
        submitter_name_en='SYSKEN Corporation',
        submitter_name_yomi='カブシキガイシャシスケン',
        address='熊本市中央区萩原町１４番４５号',
        industry='建設業',
        sec_code=None,
        corporate_number='3330001003635',
    ),
    'E00200': EdinetCodeEntry(
        edinet_code='E00200',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=11876,
        fiscal_year_end='3月31日',
        submitter_name='東芝プラントシステム株式会社',
        submitter_name_en='TOSHIBA PLANT SYSTEMS & SERVICES CORPORATION',
        submitter_name_yomi='トウシバプラントシステムカブシキガイシャ',
        address='川崎市幸区堀川町７２番地３４',
        industry='建設業',
        sec_code=None,
        corporate_number='2020001086464',
    ),
    'E00201': EdinetCodeEntry(
        edinet_code='E00201',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1594,
        fiscal_year_end='3月31日',
        submitter_name='名工建設株式会社',
        submitter_name_en='MEIKO CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='メイコウケンセツカブシキガイシャ',
        address='名古屋市中村区名駅一丁目１番４号\u3000ＪＲセントラルタワーズ３４階',
        industry='建設業',
        sec_code='18690',
        corporate_number='1180001027354',
    ),
    'E00202': EdinetCodeEntry(
        edinet_code='E00202',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='三信建設工業株式会社',
        submitter_name_en='SANSHIN CORPORATION',
        submitter_name_yomi='サンシンケンセツコウギョウカブシキガイシャ',
        address='台東区柳橋２丁目１９番６号',
        industry='建設業',
        sec_code=None,
        corporate_number='6010501029787',
    ),
    'E00204': EdinetCodeEntry(
        edinet_code='E00204',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5907,
        fiscal_year_end='3月31日',
        submitter_name='日本基礎技術株式会社',
        submitter_name_en='japan foundation engineering co.,ltd.',
        submitter_name_yomi='ニホンキソギジュツカブシキガイシャ',
        address='大阪市北区天満１丁目９番１４号',
        industry='建設業',
        sec_code='19140',
        corporate_number='9120001072753',
    ),
    'E00207': EdinetCodeEntry(
        edinet_code='E00207',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3328,
        fiscal_year_end='3月31日',
        submitter_name='北陸電気工事株式会社',
        submitter_name_en='hokuriku electrical construction co.,ltd.',
        submitter_name_yomi='ホクリクデンキコウジカブシキガイシャ',
        address='富山市小中２６９番',
        industry='建設業',
        sec_code='19300',
        corporate_number='6230001003007',
    ),
    'E00208': EdinetCodeEntry(
        edinet_code='E00208',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4026,
        fiscal_year_end='1月31日',
        submitter_name='株式会社丹青社',
        submitter_name_en='tanseisha co.,ltd.',
        submitter_name_yomi='カブシキガイシャタンセイシャ',
        address='港区港南１丁目２番７０号',
        industry='サービス業',
        sec_code='97430',
        corporate_number='3010501007440',
    ),
    'E00209': EdinetCodeEntry(
        edinet_code='E00209',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3642,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000高田工業所',
        submitter_name_en='TAKADA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000タカダコウギョウショ',
        address='北九州市八幡西区築地町１番１号',
        industry='建設業',
        sec_code='19660',
        corporate_number='4290801010231',
    ),
    'E00210': EdinetCodeEntry(
        edinet_code='E00210',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13122,
        fiscal_year_end='3月31日',
        submitter_name='ＮＥＣネッツエスアイ株式会社',
        submitter_name_en='NEC Networks & System Integration Corporation',
        submitter_name_yomi='エヌイーシーネッツエスアイカブシキガイシャ',
        address='港区芝浦三丁目９番１４号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6010001135680',
    ),
    'E00211': EdinetCodeEntry(
        edinet_code='E00211',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2324,
        fiscal_year_end=None,
        submitter_name='株式会社ソルコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソルコム',
        address='広島市中区南千田東町２番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001009220',
    ),
    'E00213': EdinetCodeEntry(
        edinet_code='E00213',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=611,
        fiscal_year_end='3月31日',
        submitter_name='北陸電話工事株式会社',
        submitter_name_en='Hokuriku Denwa Kouji Co.,Ltd.',
        submitter_name_yomi='ホクリクデンワコウジカブシキガイシャ',
        address='金沢市米泉町１０丁目１番地１５３',
        industry='建設業',
        sec_code=None,
        corporate_number='6220001006423',
    ),
    'E00218': EdinetCodeEntry(
        edinet_code='E00218',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=29060,
        fiscal_year_end='3月31日',
        submitter_name='大東建託株式会社',
        submitter_name_en='DAITO TRUST CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='ダイトウケンタクカブシキガイシャ',
        address='港区港南二丁目１６番１号',
        industry='建設業',
        sec_code='18780',
        corporate_number='4010401016607',
    ),
    'E00221': EdinetCodeEntry(
        edinet_code='E00221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3665,
        fiscal_year_end='3月31日',
        submitter_name='新日本建設株式会社',
        submitter_name_en='SHINNIHON CORPORATION',
        submitter_name_yomi='シンニホンケンセツカブシキカイシャ',
        address='千葉市美浜区ひび野一丁目４番３',
        industry='建設業',
        sec_code='18790',
        corporate_number='2040001003186',
    ),
    'E00222': EdinetCodeEntry(
        edinet_code='E00222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='高橋カーテンウォール工業株式会社',
        submitter_name_en='TAKAHASHI  CURTAIN  WALL  CORPORATION',
        submitter_name_yomi='タカハシカーテンウォールコウギョウカブシキガイシャ',
        address='中央区日本橋本町１丁目５番４号',
        industry='建設業',
        sec_code='19940',
        corporate_number='1010001049480',
    ),
    'E00225': EdinetCodeEntry(
        edinet_code='E00225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2746,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノ菱和',
        submitter_name_en='TECHNO RYOWA LTD.',
        submitter_name_yomi='カブシキガイシャテクノリョウワ',
        address='港区芝大門二丁目１２番８号',
        industry='建設業',
        sec_code='19650',
        corporate_number='3010401018661',
    ),
    'E00227': EdinetCodeEntry(
        edinet_code='E00227',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5158,
        fiscal_year_end='3月31日',
        submitter_name='新日本空調株式会社',
        submitter_name_en='Shin Nippon Air Technologies Co., Ltd.',
        submitter_name_yomi='シンニッポンクウチョウカブシキガイシャ',
        address='中央区日本橋浜町二丁目３１番１号',
        industry='建設業',
        sec_code='19520',
        corporate_number='2010001062912',
    ),
    'E00231': EdinetCodeEntry(
        edinet_code='E00231',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6820,
        fiscal_year_end='3月31日',
        submitter_name='株式会社細田工務店',
        submitter_name_en='HOSODA CORPORATION',
        submitter_name_yomi='カブシキガイシャホソダコウムテン',
        address='杉並区阿佐谷南３丁目３５番２１号',
        industry='建設業',
        sec_code=None,
        corporate_number='6011301006506',
    ),
    'E00232': EdinetCodeEntry(
        edinet_code='E00232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1710,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テノックス',
        submitter_name_en='tenox corporation',
        submitter_name_yomi='カブシキガイシャテノックス',
        address='港区芝五丁目２５番１１号',
        industry='建設業',
        sec_code='19050',
        corporate_number='7010401018815',
    ),
    'E00233': EdinetCodeEntry(
        edinet_code='E00233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5195,
        fiscal_year_end='3月31日',
        submitter_name='大成温調株式会社',
        submitter_name_en='taisei oncho co.,ltd.',
        submitter_name_yomi='タイセイオンチョウカブシキガイシャ',
        address='品川区大井一丁目４９番１０号',
        industry='建設業',
        sec_code='19040',
        corporate_number='3010701005946',
    ),
    'E00235': EdinetCodeEntry(
        edinet_code='E00235',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13900,
        fiscal_year_end='3月31日',
        submitter_name='三井ホーム株式会社',
        submitter_name_en='Mitsui Home Co.,Ltd.',
        submitter_name_yomi='ミツイホームカブシキカイシャ',
        address='新宿区西新宿二丁目１番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='2011101020537',
    ),
    'E00238': EdinetCodeEntry(
        edinet_code='E00238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2379,
        fiscal_year_end='3月31日',
        submitter_name='株式会社富士ピー・エス',
        submitter_name_en='FUJI P.S CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000フジピーエス',
        address='福岡市中央区薬院一丁目１３番８号',
        industry='建設業',
        sec_code='18480',
        corporate_number='6290001010204',
    ),
    'E00239': EdinetCodeEntry(
        edinet_code='E00239',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3101,
        fiscal_year_end='7月31日',
        submitter_name='株式会社大盛工業',
        submitter_name_en='OHMORI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオオモリコウギョウ',
        address='千代田区神田多町二丁目１番地',
        industry='建設業',
        sec_code='18440',
        corporate_number='9011801002605',
    ),
    'E00240': EdinetCodeEntry(
        edinet_code='E00240',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7114,
        fiscal_year_end='10月31日',
        submitter_name='株式会社土屋ホールディングス',
        submitter_name_en='TSUCHIYA HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャツチヤホールディングス',
        address='札幌市北区北９条西３丁目７番地',
        industry='建設業',
        sec_code='18400',
        corporate_number='7430001010659',
    ),
    'E00242': EdinetCodeEntry(
        edinet_code='E00242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=885,
        fiscal_year_end='3月31日',
        submitter_name='田辺工業株式会社',
        submitter_name_en='TANABE ENGINEERING CORPORATION',
        submitter_name_yomi='タナベコウギョウカブシキガイシャ',
        address='上越市大字福田２０番地',
        industry='建設業',
        sec_code='18280',
        corporate_number='5110001019890',
    ),
    'E00246': EdinetCodeEntry(
        edinet_code='E00246',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1408,
        fiscal_year_end='8月31日',
        submitter_name='暁飯島工業株式会社',
        submitter_name_en='AKATSUKI EAZIMA CO., LTD.',
        submitter_name_yomi='アカツキイイジマコウギョウカブシキガイシャ',
        address='水戸市千波町２７７０番地の５',
        industry='建設業',
        sec_code='19970',
        corporate_number='7050001000351',
    ),
    'E00248': EdinetCodeEntry(
        edinet_code='E00248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=942,
        fiscal_year_end='6月30日',
        submitter_name='サイタホールディングス株式会社',
        submitter_name_en='SAITA CORPORATION',
        submitter_name_yomi='サイタホールディングスカブシキガイシャ',
        address='朝倉市下渕４７２番地',
        industry='建設業',
        sec_code='19990',
        corporate_number='5290001044368',
    ),
    'E00250': EdinetCodeEntry(
        edinet_code='E00250',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3302,
        fiscal_year_end='3月31日',
        submitter_name='第一建設工業株式会社',
        submitter_name_en='DAIICHI KENSETSU CORPORATION',
        submitter_name_yomi='ダイイチケンセツコウギョウカブシキガイシャ',
        address='新潟市中央区八千代一丁目４番３４号',
        industry='建設業',
        sec_code='17990',
        corporate_number='4110001002922',
    ),
    'E00251': EdinetCodeEntry(
        edinet_code='E00251',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1712,
        fiscal_year_end='3月31日',
        submitter_name='株式会社守谷商会',
        submitter_name_en='MORIYA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000モリヤショウカイ',
        address='長野市南千歳町８７８番地',
        industry='建設業',
        sec_code='17980',
        corporate_number='7100001003530',
    ),
    'E00252': EdinetCodeEntry(
        edinet_code='E00252',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2204,
        fiscal_year_end='3月31日',
        submitter_name='東邦電気工業株式会社',
        submitter_name_en='TOHO ELECTRICAL CONSTRUCTION CO., LTD.',
        submitter_name_yomi='トウホウデンキコウギョウカブシキカイシャ',
        address='渋谷区恵比寿一丁目１９番２３号',
        industry='建設業',
        sec_code=None,
        corporate_number='5011001015568',
    ),
    'E00253': EdinetCodeEntry(
        edinet_code='E00253',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4694,
        fiscal_year_end='3月31日',
        submitter_name='株式会社藤木工務店',
        submitter_name_en='Fujiki Komuten Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフジキコウムテン',
        address='大阪市中央区備後町一丁目７番１０号',
        industry='建設業',
        sec_code=None,
        corporate_number='8120001077539',
    ),
    'E00254': EdinetCodeEntry(
        edinet_code='E00254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=885,
        fiscal_year_end='9月30日',
        submitter_name='株式会社マサル',
        submitter_name_en='MASARU CORPORATION',
        submitter_name_yomi='カブシキガイシャマサル',
        address='江東区佐賀一丁目９番１４号',
        industry='建設業',
        sec_code='17950',
        corporate_number='7010601006280',
    ),
    'E00255': EdinetCodeEntry(
        edinet_code='E00255',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5296,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大本組',
        submitter_name_en='OHMOTO GUMI CO.,LTD',
        submitter_name_yomi='カブシキガイシャオオモトグミ',
        address='岡山市北区内山下１丁目１番１３号',
        industry='建設業',
        sec_code='17930',
        corporate_number='7260001001493',
    ),
    'E00258': EdinetCodeEntry(
        edinet_code='E00258',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=989,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＥＴＳホールディングス',
        submitter_name_en='ETS Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイーティーエスホールディングス',
        address='豊島区南池袋一丁目１０番１３号',
        industry='建設業',
        sec_code=None,
        corporate_number='3011101040583',
    ),
    'E00259': EdinetCodeEntry(
        edinet_code='E00259',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=849,
        fiscal_year_end='6月30日',
        submitter_name='株式会社三東工業社',
        submitter_name_en='santo co.,ltd',
        submitter_name_yomi='カブシキガイシャサントウコウギョウシャ',
        address='甲賀郡信楽町大字江田６１０番地',
        industry='建設業',
        sec_code='17880',
        corporate_number='7160001005521',
    ),
    'E00260': EdinetCodeEntry(
        edinet_code='E00260',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=866,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナカボーテック',
        submitter_name_en='Nakabohtec Corrosion Protecting Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャナカボーテック',
        address='中央区新川二丁目５番２号',
        industry='建設業',
        sec_code='17870',
        corporate_number='7010001053015',
    ),
    'E00263': EdinetCodeEntry(
        edinet_code='E00263',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6633,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ｆａｎｔａｓｉｓｔａ',
        submitter_name_en='Fantasista Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ファンタジスタ',
        address='港区赤坂五丁目３番１号',
        industry='建設業',
        sec_code='17830',
        corporate_number='7010401066847',
    ),
    'E00264': EdinetCodeEntry(
        edinet_code='E00264',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1232,
        fiscal_year_end=None,
        submitter_name='大鉄工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイテツコウギョウカブシキガイシャ',
        address='大阪市淀川区西中島三丁目９番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001056577',
    ),
    'E00265': EdinetCodeEntry(
        edinet_code='E00265',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1134,
        fiscal_year_end='3月31日',
        submitter_name='東光電気工事株式会社',
        submitter_name_en='TOKO ELECTRICAL CONSTRUCTION CO., LTD.',
        submitter_name_yomi='トウコウデンキコウジカブシキガイシャ',
        address='千代田区西神田一丁目４番５号',
        industry='建設業',
        sec_code=None,
        corporate_number='1010001024087',
    ),
    'E00267': EdinetCodeEntry(
        edinet_code='E00267',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='常磐開発株式会社',
        submitter_name_en='Joban Kaihatsu Co.,Ltd.',
        submitter_name_yomi='ジョウバンカイハツカブシキカイシャ',
        address='いわき市常磐湯本町辰ノ口１番地',
        industry='建設業',
        sec_code=None,
        corporate_number='5380001012984',
    ),
    'E00268': EdinetCodeEntry(
        edinet_code='E00268',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2888,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ヤマウラ',
        submitter_name_en='YAMAURA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマウラ',
        address='駒ヶ根市北町２２番１号',
        industry='建設業',
        sec_code='17800',
        corporate_number='6100001021418',
    ),
    'E00271': EdinetCodeEntry(
        edinet_code='E00271',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1581,
        fiscal_year_end='3月31日',
        submitter_name='川崎設備工業株式会社',
        submitter_name_en='KAWASAKI SETSUBI KOGYO CO., LTD.',
        submitter_name_yomi='カワサキセツビコウギョウカブシキガイシャ',
        address='名古屋市中区大須一丁目６番４７号',
        industry='建設業',
        sec_code='17770',
        corporate_number='2180001035307',
    ),
    'E00272': EdinetCodeEntry(
        edinet_code='E00272',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1329,
        fiscal_year_end='3月31日',
        submitter_name='三井住建道路株式会社',
        submitter_name_en='SUMIKEN MITSUI ROAD CO.,LTD.',
        submitter_name_yomi='ミツイスミケンドウロカブシキガイシャ',
        address='新宿区西新宿６丁目２４番１号',
        industry='建設業',
        sec_code='17760',
        corporate_number='1011101036179',
    ),
    'E00273': EdinetCodeEntry(
        edinet_code='E00273',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1970,
        fiscal_year_end='3月31日',
        submitter_name='富士電機Ｅ＆Ｃ株式会社',
        submitter_name_en='FUJI ELECTRIC ENGINEERING & CONSTRUCTION CO.LTD.',
        submitter_name_yomi='フジデンキイーアンドシーカブシキガイシャ',
        address='川崎市幸区堀川町５８０番地',
        industry='建設業',
        sec_code=None,
        corporate_number='6020001077096',
    ),
    'E00276': EdinetCodeEntry(
        edinet_code='E00276',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=413,
        fiscal_year_end='9月30日',
        submitter_name='日本乾溜工業株式会社',
        submitter_name_en='NIPPON  KANRYU  INDUSTRY  CO.,LTD.',
        submitter_name_yomi='ニホンカンリユウコウギヨウカブシキガイシヤ',
        address='福岡市東区馬出１丁目１１番１１号',
        industry='建設業',
        sec_code='17710',
        corporate_number='1290001028382',
    ),
    'E00277': EdinetCodeEntry(
        edinet_code='E00277',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1029,
        fiscal_year_end='3月31日',
        submitter_name='藤田エンジニアリング株式会社',
        submitter_name_en='FUJITA ENGINEERING CO.,LTD.',
        submitter_name_yomi='フジタエンジニアリングカブシキガイシャ',
        address='高崎市飯塚町１１７４番地５',
        industry='建設業',
        sec_code='17700',
        corporate_number='6070001008237',
    ),
    'E00279': EdinetCodeEntry(
        edinet_code='E00279',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=723,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソネック',
        submitter_name_en='SONEC CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ソネック',
        address='高砂市曽根町２２５７番地の１',
        industry='建設業',
        sec_code='17680',
        corporate_number='6140001044324',
    ),
    'E00281': EdinetCodeEntry(
        edinet_code='E00281',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4800,
        fiscal_year_end='4月30日',
        submitter_name='東建コーポレーション株式会社',
        submitter_name_en='TOKEN CORPORATION',
        submitter_name_yomi='トウケンコーポレーションカブシキガイシャ',
        address='名古屋市中区丸の内二丁目１番３３号',
        industry='建設業',
        sec_code='17660',
        corporate_number='1180001054828',
    ),
    'E00282': EdinetCodeEntry(
        edinet_code='E00282',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=867,
        fiscal_year_end='6月30日',
        submitter_name='工藤建設株式会社',
        submitter_name_en='KUDO CORPORATION',
        submitter_name_yomi='クドウケンセツカブシキガイシャ',
        address='横浜市青葉区新石川四丁目３３番地１０',
        industry='建設業',
        sec_code='17640',
        corporate_number='5020001011279',
    ),
    'E00285': EdinetCodeEntry(
        edinet_code='E00285',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社髙松コンストラクショングループ',
        submitter_name_en='TAKAMATSU CONSTRUCTION GROUP',
        submitter_name_yomi='カブシキガイシャタカマツコンストラクショングループ',
        address='大阪市淀川区新北野一丁目２番３号',
        industry='建設業',
        sec_code='17620',
        corporate_number='2120001056705',
    ),
    'E00287': EdinetCodeEntry(
        edinet_code='E00287',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=456,
        fiscal_year_end='1月31日',
        submitter_name='太洋基礎工業株式会社',
        submitter_name_en='Taiyo Kisokogyo Co.,Ltd.',
        submitter_name_yomi='タイヨウキソコウギョウカブシキガイシャ',
        address='名古屋市中川区柳森町１０７番地',
        industry='建設業',
        sec_code='17580',
        corporate_number='7180001019940',
    ),
    'E00288': EdinetCodeEntry(
        edinet_code='E00288',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10670,
        fiscal_year_end='3月31日',
        submitter_name='株式会社創建エース',
        submitter_name_en='Souken Ace Co., Ltd',
        submitter_name_yomi='ソウケンエース',
        address='新宿区西新宿一丁目２５番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='7010401063241',
    ),
    'E00299': EdinetCodeEntry(
        edinet_code='E00299',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1319,
        fiscal_year_end='9月30日',
        submitter_name='コーアツ工業株式会社',
        submitter_name_en='KOATSU KOGYO CO., LTD.',
        submitter_name_yomi='コーアツコウギョウカブシキガイシャ',
        address='鹿児島市伊敷五丁目１７番５号',
        industry='建設業',
        sec_code=None,
        corporate_number='8340001001600',
    ),
    'E00302': EdinetCodeEntry(
        edinet_code='E00302',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社メルディアＤＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガシャメルディアディーシー',
        address='京都市山科区椥辻中在家町８番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9130001012782',
    ),
    'E00303': EdinetCodeEntry(
        edinet_code='E00303',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1085,
        fiscal_year_end='3月31日',
        submitter_name='三井金属エンジニアリング株式会社',
        submitter_name_en='MESCO,Inc.',
        submitter_name_yomi='ミツイキンゾクエンジニアリングカブシキガイシャ',
        address='墨田区錦糸三丁目２番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='9010601015759',
    ),
    'E00304': EdinetCodeEntry(
        edinet_code='E00304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=599,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000オーテック',
        submitter_name_en='OTEC CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000オーテック',
        address='江東区東陽２－４－２',
        industry='建設業',
        sec_code='17360',
        corporate_number='8010601001272',
    ),
    'E00306': EdinetCodeEntry(
        edinet_code='E00306',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=840,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北弘電社',
        submitter_name_en='KITAKOUDENSHACorporation',
        submitter_name_yomi='カブシキガイシャキタコウデンシャ',
        address='札幌市中央区北１１条西２３丁目２番１０号',
        industry='建設業',
        sec_code=None,
        corporate_number='4430001015751',
    ),
    'E00308': EdinetCodeEntry(
        edinet_code='E00308',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=209,
        fiscal_year_end='3月31日',
        submitter_name='麻生フオームクリート株式会社',
        submitter_name_en='ASO FOAM CRETE Co.,Ltd.',
        submitter_name_yomi='アソウフオームクリートカブシキガイシャ',
        address='川崎市中原区苅宿３６番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='7020001068771',
    ),
    'E00309': EdinetCodeEntry(
        edinet_code='E00309',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1369,
        fiscal_year_end=None,
        submitter_name='ミサワホーム中国株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミサワホームチュウゴクカブシキガイシャ',
        address='岡山市北区野田二丁目１３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7260001023158',
    ),
    'E00311': EdinetCodeEntry(
        edinet_code='E00311',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3732,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ＡＶＡＮＴＩＡ',
        submitter_name_en='AVANTIA CO., LTD.',
        submitter_name_yomi='カブシキガイシャアバンティア',
        address='名古屋市中区錦二丁目２０番１５号\u3000広小路クロスタワー１２階',
        industry='不動産業',
        sec_code='89040',
        corporate_number='8180001036547',
    ),
    'E00312': EdinetCodeEntry(
        edinet_code='E00312',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4813,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビーアールホールディングス',
        submitter_name_en='Br.Holdings Corporation',
        submitter_name_yomi='カブシキガイシャビーアールホールディングス',
        address='広島市東区光町二丁目６番３１号',
        industry='建設業',
        sec_code='17260',
        corporate_number='1240001015542',
    ),
    'E00313': EdinetCodeEntry(
        edinet_code='E00313',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=470,
        fiscal_year_end='3月31日',
        submitter_name='日本電技株式会社',
        submitter_name_en='NIHON DENGI CO., LTD.',
        submitter_name_yomi='ニホンデンギカブシキガイシャ',
        address='墨田区両国二丁目１０番１４号',
        industry='建設業',
        sec_code='17230',
        corporate_number='1010601021483',
    ),
    'E00315': EdinetCodeEntry(
        edinet_code='E00315',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=764,
        fiscal_year_end='12月31日',
        submitter_name='美樹工業株式会社',
        submitter_name_en='MIKIKOGYO CO.,LTD.',
        submitter_name_yomi='ミキコウギョウカブシキガイシャ',
        address='姫路市北条９５１番地１',
        industry='建設業',
        sec_code='17180',
        corporate_number='8140001061763',
    ),
    'E00316': EdinetCodeEntry(
        edinet_code='E00316',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16354,
        fiscal_year_end='3月31日',
        submitter_name='東急建設株式会社',
        submitter_name_en='TOKYU CONSTRUCTION CO.,LTD.',
        submitter_name_yomi='トウキュウケンセツカブシキガイシャ',
        address='渋谷区渋谷一丁目１６番１４号',
        industry='建設業',
        sec_code='17200',
        corporate_number='9011001040166',
    ),
    'E00317': EdinetCodeEntry(
        edinet_code='E00317',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17006,
        fiscal_year_end='3月31日',
        submitter_name='株式会社安藤・間',
        submitter_name_en='HAZAMA ANDO CORPORATION',
        submitter_name_yomi='カブシキガイシャアンドウハザマ',
        address='港区東新橋１丁目９番１号',
        industry='建設業',
        sec_code='17190',
        corporate_number='2010401051696',
    ),
    'E00318': EdinetCodeEntry(
        edinet_code='E00318',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11892,
        fiscal_year_end=None,
        submitter_name='ミサワホーム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミサワホームカブシキガイシャ',
        address='新宿区西新宿二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011101035813',
    ),
    'E00320': EdinetCodeEntry(
        edinet_code='E00320',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=470,
        fiscal_year_end='6月30日',
        submitter_name='第一カッター興業株式会社',
        submitter_name_en='DAI-ICHI CUTTER KOGYO K.K.',
        submitter_name_yomi='ダイイチカッターコウギョウカブシキガイシャ',
        address='茅ヶ崎市萩園８３３番地',
        industry='建設業',
        sec_code='17160',
        corporate_number='5021001007060',
    ),
    'E00322': EdinetCodeEntry(
        edinet_code='E00322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='コムシスホールディングス株式会社',
        submitter_name_en='COMSYS Holdings Corporation',
        submitter_name_yomi='コムシスホールディングスカブシキガイシャ',
        address='品川区東五反田二丁目１７番１号',
        industry='建設業',
        sec_code='17210',
        corporate_number='3010701014889',
    ),
    'E00323': EdinetCodeEntry(
        edinet_code='E00323',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=391,
        fiscal_year_end='5月31日',
        submitter_name='株式会社エムビーエス',
        submitter_name_en='mbs,inc.',
        submitter_name_yomi='カブシキガイシャエムビーエス',
        address='宇部市西岐波１１７３番地１６２',
        industry='建設業',
        sec_code='14010',
        corporate_number='9250001004074',
    ),
    'E00325': EdinetCodeEntry(
        edinet_code='E00325',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ヒノキヤグループ',
        submitter_name_en='Hinokiya Group Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャヒノキヤグループ',
        address='千代田区丸の内一丁目８番３号\u3000丸の内トラストタワー本館',
        industry='建設業',
        sec_code=None,
        corporate_number='2030001032649',
    ),
    'E00327': EdinetCodeEntry(
        edinet_code='E00327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2020,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ウエストホールディングス',
        submitter_name_en='West Holdings corporation',
        submitter_name_yomi='カブシキガイシャウエストホールディングス',
        address='広島市西区楠木町一丁目１５番２４号',
        industry='建設業',
        sec_code='14070',
        corporate_number='9240001016913',
    ),
    'E00329': EdinetCodeEntry(
        edinet_code='E00329',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='6月30日',
        submitter_name='ショーボンドホールディングス株式会社',
        submitter_name_en='SHO-BOND Holdings Co.,  Ltd.',
        submitter_name_yomi='ショーボンドホールディングスカブシキガイシャ',
        address='中央区日本橋箱崎町７番８号',
        industry='建設業',
        sec_code='14140',
        corporate_number='8010001135778',
    ),
    'E00331': EdinetCodeEntry(
        edinet_code='E00331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21821,
        fiscal_year_end='3月31日',
        submitter_name='森永乳業株式会社',
        submitter_name_en='MORINAGA MILK INDUSTRY CO.,LTD',
        submitter_name_yomi='モリナガニュウギョウカブシキガイシャ',
        address='港区東新橋一丁目五番二号',
        industry='食料品',
        sec_code='22640',
        corporate_number='8010401029662',
    ),
    'E00334': EdinetCodeEntry(
        edinet_code='E00334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36294,
        fiscal_year_end='3月31日',
        submitter_name='日本ハム株式会社',
        submitter_name_en='NH Foods Ltd.',
        submitter_name_yomi='ニッポンハムカブシキガイシャ',
        address='大阪市北区梅田二丁目４番９号',
        industry='食料品',
        sec_code='22820',
        corporate_number='6120001077615',
    ),
    'E00335': EdinetCodeEntry(
        edinet_code='E00335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7908,
        fiscal_year_end='3月31日',
        submitter_name='プリマハム株式会社',
        submitter_name_en='Prima Meat Packers, Ltd.',
        submitter_name_yomi='プリマハムカブシキガイシャ',
        address='品川区東大井三丁目１７番４号',
        industry='食料品',
        sec_code='22810',
        corporate_number='6010701008888',
    ),
    'E00336': EdinetCodeEntry(
        edinet_code='E00336',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28427,
        fiscal_year_end=None,
        submitter_name='伊藤ハム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イトウハムカブシキガイシャ',
        address='神戸市灘区備後町三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001018996',
    ),
    'E00337': EdinetCodeEntry(
        edinet_code='E00337',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2843,
        fiscal_year_end='12月31日',
        submitter_name='六甲バター株式会社',
        submitter_name_en='ROKKO BUTTER CO., LTD.',
        submitter_name_yomi='ロッコウバターカブシキガイシャ',
        address='神戸市中央区坂口通一丁目３番１３号',
        industry='食料品',
        sec_code='22660',
        corporate_number='6140001011869',
    ),
    'E00341': EdinetCodeEntry(
        edinet_code='E00341',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2691,
        fiscal_year_end='3月31日',
        submitter_name='福留ハム株式会社',
        submitter_name_en='FUKUTOME MEAT PACKERS, LTD.',
        submitter_name_yomi='フクトメハムカブシキガイシャ',
        address='広島市西区草津港二丁目６番７５号',
        industry='食料品',
        sec_code='22910',
        corporate_number='6240001010290',
    ),
    'E00342': EdinetCodeEntry(
        edinet_code='E00342',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4298,
        fiscal_year_end='2月末日',
        submitter_name='エスフーズ株式会社',
        submitter_name_en='s foods inc.',
        submitter_name_yomi='エスフーズカブシキガイシャ',
        address='西宮市鳴尾浜１－２２－１３',
        industry='食料品',
        sec_code='22920',
        corporate_number='6140001069164',
    ),
    'E00343': EdinetCodeEntry(
        edinet_code='E00343',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1080,
        fiscal_year_end='3月31日',
        submitter_name='滝沢ハム株式会社',
        submitter_name_en='TAKIZAWA HAM CO.,LTD.',
        submitter_name_yomi='タキザワハムカブシキガイシャ',
        address='栃木市泉川町５５６番地',
        industry='食料品',
        sec_code='22930',
        corporate_number='4060001017356',
    ),
    'E00344': EdinetCodeEntry(
        edinet_code='E00344',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=714,
        fiscal_year_end='3月31日',
        submitter_name='株式会社秋川牧園',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアキカワボクエン',
        address='山口市仁保下郷１０３１７番地',
        industry='水産・農林業',
        sec_code='13800',
        corporate_number='9250001000008',
    ),
    'E00345': EdinetCodeEntry(
        edinet_code='E00345',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12240,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニップン',
        submitter_name_en='NIPPN CORPORATION',
        submitter_name_yomi='カブシキガイシャニップン',
        address='千代田区麹町四丁目８番地',
        industry='食料品',
        sec_code='20010',
        corporate_number='9011001017684',
    ),
    'E00346': EdinetCodeEntry(
        edinet_code='E00346',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17117,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日清製粉グループ本社',
        submitter_name_en='NISSHIN SEIFUN GROUP INC.',
        submitter_name_yomi='カブシキガイシャニッシンセイフングループホンシャ',
        address='千代田区神田錦町一丁目２５番地',
        industry='食料品',
        sec_code='20020',
        corporate_number='8010001008736',
    ),
    'E00347': EdinetCodeEntry(
        edinet_code='E00347',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2500,
        fiscal_year_end='3月31日',
        submitter_name='日東富士製粉株式会社',
        submitter_name_en='NITTO FUJI FLOUR MILLING CO.,LTD.',
        submitter_name_yomi='ニットウフジセイフンカブシキガイシャ',
        address='中央区新川一丁目２８番２３号',
        industry='食料品',
        sec_code='20030',
        corporate_number='3010001034893',
    ),
    'E00348': EdinetCodeEntry(
        edinet_code='E00348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14293,
        fiscal_year_end='3月31日',
        submitter_name='昭和産業株式会社',
        submitter_name_en='Showa Sangyo Co., Ltd.',
        submitter_name_yomi='ショウワサンギョウカブシキガイシャ',
        address='千代田区内神田２丁目２番１号',
        industry='食料品',
        sec_code='20040',
        corporate_number='3010001008690',
    ),
    'E00350': EdinetCodeEntry(
        edinet_code='E00350',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=400,
        fiscal_year_end='3月末日',
        submitter_name='東福製粉株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウフクセイフンカブシキガイシャ',
        address='福岡市中央区那の津４丁目９番２０号',
        industry='食料品',
        sec_code=None,
        corporate_number='6290001008982',
    ),
    'E00351': EdinetCodeEntry(
        edinet_code='E00351',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2805,
        fiscal_year_end='12月31日',
        submitter_name='鳥越製粉株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トリゴエセイフンカブシキガイシャ',
        address='うきは市吉井町２７６番地の１',
        industry='食料品',
        sec_code='20090',
        corporate_number='5290001055183',
    ),
    'E00352': EdinetCodeEntry(
        edinet_code='E00352',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='株式会社増田製粉所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマスダセイフンショ',
        address='神戸市長田区梅ヶ香町１丁目１番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001016851',
    ),
    'E00354': EdinetCodeEntry(
        edinet_code='E00354',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2904,
        fiscal_year_end='3月31日',
        submitter_name='東洋精糖株式会社',
        submitter_name_en='Toyo Sugar Refining Co., Ltd.',
        submitter_name_yomi='トウヨウセイトウカブシキガイシャ',
        address='中央区日本橋小網町１８番２０号',
        industry='食料品',
        sec_code=None,
        corporate_number='2010001034845',
    ),
    'E00355': EdinetCodeEntry(
        edinet_code='E00355',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8279,
        fiscal_year_end='3月31日',
        submitter_name='日本甜菜製糖株式会社',
        submitter_name_en='Nippon Beet Sugar Manufacturing Co.,Ltd.',
        submitter_name_yomi='ニッポンテンサイセイトウカブシキカイシャ',
        address='中央区京橋二丁目６番４号',
        industry='食料品',
        sec_code='21080',
        corporate_number='8010401054826',
    ),
    'E00356': EdinetCodeEntry(
        edinet_code='E00356',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7083,
        fiscal_year_end='3月31日',
        submitter_name='ＤＭ三井製糖株式会社',
        submitter_name_en='Mitsui DM Sugar Co., Ltd.',
        submitter_name_yomi='ディーエムミツイセイトウカブシキガイシャ',
        address='港区芝五丁目２６番１６号',
        industry='食料品',
        sec_code='21090',
        corporate_number='1010001034929',
    ),
    'E00360': EdinetCodeEntry(
        edinet_code='E00360',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1524,
        fiscal_year_end='3月31日',
        submitter_name='フジ日本株式会社',
        submitter_name_en='Fuji Nihon Corporation',
        submitter_name_yomi='フジニホンカブシキガイシャ',
        address='中央区日本橋兜町６番７号',
        industry='食料品',
        sec_code='21140',
        corporate_number='5010001034982',
    ),
    'E00361': EdinetCodeEntry(
        edinet_code='E00361',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1750,
        fiscal_year_end='3月31日',
        submitter_name='塩水港精糖株式会社',
        submitter_name_en='Ensuiko Sugar Refining Co.,Ltd.',
        submitter_name_yomi='エンスイコウセイトウカブシキガイシャ',
        address='中央区日本橋堀留町二丁目９番６号',
        industry='食料品',
        sec_code='21120',
        corporate_number='7010001079324',
    ),
    'E00362': EdinetCodeEntry(
        edinet_code='E00362',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=457,
        fiscal_year_end='6月30日',
        submitter_name='新中糖産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンチュウトウサンギョウカブシキガイシャ',
        address='中頭郡西原町字小那覇６２８番地１',
        industry='不動産業',
        sec_code=None,
        corporate_number='9360001004352',
    ),
    'E00365': EdinetCodeEntry(
        edinet_code='E00365',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=380,
        fiscal_year_end='6月30日',
        submitter_name='北部製糖株式会社',
        submitter_name_en='hokubu seito co:ltd',
        submitter_name_yomi='ホクブセイトウカブシキガイシャ',
        address='浦添市伊奈武瀬１丁目９番９号',
        industry='食料品',
        sec_code=None,
        corporate_number='5360001009149',
    ),
    'E00366': EdinetCodeEntry(
        edinet_code='E00366',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=152,
        fiscal_year_end='6月30日',
        submitter_name='株式会社\u3000りゅうとう',
        submitter_name_en='ryutou incorporation',
        submitter_name_yomi='カブシキカイシャ\u3000リュウトウ',
        address='島尻郡南風原町字津嘉山１４９０',
        industry='食料品',
        sec_code=None,
        corporate_number='6360001006500',
    ),
    'E00367': EdinetCodeEntry(
        edinet_code='E00367',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='久米島製糖株式会社',
        submitter_name_en='KUMESHIMA  SUGAR  CO.,LTD.',
        submitter_name_yomi='クメジマセイトウカブシキカイシャ',
        address='那覇市久茂地一丁目７番１号\u3000琉球リース総合ビル５階',
        industry='食料品',
        sec_code=None,
        corporate_number='5360001000834',
    ),
    'E00368': EdinetCodeEntry(
        edinet_code='E00368',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=262,
        fiscal_year_end='6月30日',
        submitter_name='石垣島製糖株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イシガキジマセイトウカブシキカイシャ',
        address='石垣市字名蔵２４３番地',
        industry='食料品',
        sec_code=None,
        corporate_number='5360001013035',
    ),
    'E00369': EdinetCodeEntry(
        edinet_code='E00369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18612,
        fiscal_year_end='3月31日',
        submitter_name='森永製菓株式会社',
        submitter_name_en='Morinaga&Co.,Ltd.',
        submitter_name_yomi='モリナガセイカカブシキガイシャ',
        address='港区芝浦一丁目１３番１６号',
        industry='食料品',
        sec_code='22010',
        corporate_number='1010401029660',
    ),
    'E00371': EdinetCodeEntry(
        edinet_code='E00371',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2576,
        fiscal_year_end='3月31日',
        submitter_name='井村屋グループ株式会社',
        submitter_name_en='IMURAYA GROUP CO., LTD.',
        submitter_name_yomi='イムラヤグループカブシキガイシャ',
        address='津市高茶屋七丁目１番１号',
        industry='食料品',
        sec_code='22090',
        corporate_number='5190001000125',
    ),
    'E00372': EdinetCodeEntry(
        edinet_code='E00372',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=7469,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中村屋',
        submitter_name_en='NAKAMURAYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャナカムラヤ',
        address='新宿区新宿三丁目２６番１３号',
        industry='食料品',
        sec_code='22040',
        corporate_number='6011101015442',
    ),
    'E00373': EdinetCodeEntry(
        edinet_code='E00373',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7773,
        fiscal_year_end='12月31日',
        submitter_name='江崎グリコ株式会社',
        submitter_name_en='EZAKI GLICO CO.,LTD.',
        submitter_name_yomi='エザキグリコカブシキガイシャ',
        address='大阪市西淀川区歌島４丁目６番５号',
        industry='食料品',
        sec_code='22060',
        corporate_number='5120001049268',
    ),
    'E00374': EdinetCodeEntry(
        edinet_code='E00374',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18280,
        fiscal_year_end='12月31日',
        submitter_name='株式会社不二家',
        submitter_name_en='Fujiya Co.,Ltd',
        submitter_name_yomi='カブシキガイシャフジヤ',
        address='文京区大塚２丁目１５番６号',
        industry='食料品',
        sec_code='22110',
        corporate_number='3010001034910',
    ),
    'E00375': EdinetCodeEntry(
        edinet_code='E00375',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11014,
        fiscal_year_end='12月31日',
        submitter_name='山崎製パン株式会社',
        submitter_name_en='YAMAZAKI BAKING CO., LTD.',
        submitter_name_yomi='ヤマザキセイパンカブシキガイシャ',
        address='千代田区岩本町三丁目１０番１号',
        industry='食料品',
        sec_code='22120',
        corporate_number='4010001008806',
    ),
    'E00376': EdinetCodeEntry(
        edinet_code='E00376',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1335,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ｍｅｉｔｏ',
        submitter_name_en='MEITO CO., LTD.',
        submitter_name_yomi='カブシキガイシャメイトー',
        address='名古屋市西区笹塚町２丁目４１番地',
        industry='食料品',
        sec_code='22070',
        corporate_number='5180001027409',
    ),
    'E00377': EdinetCodeEntry(
        edinet_code='E00377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3305,
        fiscal_year_end='12月31日',
        submitter_name='第一屋製パン株式会社',
        submitter_name_en='FIRST BAKING CO.,LTD.',
        submitter_name_yomi='ダイイチヤセイパンカブシキガイシャ',
        address='小平市小川東町３丁目６番１号',
        industry='食料品',
        sec_code='22150',
        corporate_number='8012701009955',
    ),
    'E00378': EdinetCodeEntry(
        edinet_code='E00378',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2864,
        fiscal_year_end='12月31日',
        submitter_name='カンロ株式会社',
        submitter_name_en='Kanro Inc.',
        submitter_name_yomi='カンロカブシキガイシャ',
        address='新宿区西新宿３丁目２０番２号',
        industry='食料品',
        sec_code='22160',
        corporate_number='9011201001240',
    ),
    'E00380': EdinetCodeEntry(
        edinet_code='E00380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1036,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ブルボン',
        submitter_name_en='BOURBON CORPORATION',
        submitter_name_yomi='カブシキガイシャブルボン',
        address='柏崎市駅前１丁目３番１号',
        industry='食料品',
        sec_code='22080',
        corporate_number='6110001017563',
    ),
    'E00381': EdinetCodeEntry(
        edinet_code='E00381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3737,
        fiscal_year_end='1月31日',
        submitter_name='モロゾフ株式会社',
        submitter_name_en='Morozoff Limited',
        submitter_name_yomi='モロゾフカブシキガイシャ',
        address='神戸市東灘区御影本町六丁目１１番１９号',
        industry='食料品',
        sec_code='22170',
        corporate_number='2140001002665',
    ),
    'E00382': EdinetCodeEntry(
        edinet_code='E00382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1051,
        fiscal_year_end='3月31日',
        submitter_name='日糧製パン株式会社',
        submitter_name_en='NICHIRYO BAKING CO.,LTD.',
        submitter_name_yomi='ニチリョウセイパンカブシキガイシャ',
        address='札幌市豊平区月寒東１条１８丁目５番１号',
        industry='食料品',
        sec_code='22180',
        corporate_number='8430001012919',
    ),
    'E00384': EdinetCodeEntry(
        edinet_code='E00384',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4682,
        fiscal_year_end=None,
        submitter_name='フジパングループ本社株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジパングループホンシャカブシキガイシャ',
        address='名古屋市瑞穂区松園町一丁目５０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001010971',
    ),
    'E00385': EdinetCodeEntry(
        edinet_code='E00385',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1946,
        fiscal_year_end='3月31日',
        submitter_name='亀田製菓株式会社',
        submitter_name_en='KAMEDA SEIKA CO.,LTD.',
        submitter_name_yomi='カメダセイカカブシキガイシャ',
        address='新潟市江南区亀田工業団地３丁目１番１号',
        industry='食料品',
        sec_code='22200',
        corporate_number='4110001006378',
    ),
    'E00386': EdinetCodeEntry(
        edinet_code='E00386',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1634,
        fiscal_year_end='3月31日',
        submitter_name='岩塚製菓株式会社',
        submitter_name_en='IWATSUKA CONFECTIONERY CO.,LTD.',
        submitter_name_yomi='イワツカセイカカブシキガイシャ',
        address='長岡市浦９７５０',
        industry='食料品',
        sec_code='22210',
        corporate_number='5110001023736',
    ),
    'E00387': EdinetCodeEntry(
        edinet_code='E00387',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1217,
        fiscal_year_end='3月31日',
        submitter_name='寿スピリッツ株式会社',
        submitter_name_en='Kotobuki Spirits Co.,Ltd.',
        submitter_name_yomi='コトブキスピリッツカブシキガイシャ',
        address='米子市旗ヶ崎２０２８',
        industry='食料品',
        sec_code='22220',
        corporate_number='1270001003263',
    ),
    'E00388': EdinetCodeEntry(
        edinet_code='E00388',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=222,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コモ',
        submitter_name_en='COMO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャコモ',
        address='小牧市大字村中字下之坪５０５番地の１',
        industry='食料品',
        sec_code='22240',
        corporate_number='1180001075799',
    ),
    'E00389': EdinetCodeEntry(
        edinet_code='E00389',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2269,
        fiscal_year_end='3月31日',
        submitter_name='株式会社湖池屋',
        submitter_name_en='KOIKE-YA Inc.',
        submitter_name_yomi='カブシキガイシャコイケヤ',
        address='板橋区成増五丁目９番７号',
        industry='食料品',
        sec_code='22260',
        corporate_number='9011401005578',
    ),
    'E00390': EdinetCodeEntry(
        edinet_code='E00390',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ヒロタグループホールディングス株式会社',
        submitter_name_en='HIROTA GROUP HOLDINGS Co.,Ltd.',
        submitter_name_yomi='ヒロタグループホールディングスカブシキガイシャ',
        address='港区東新橋一丁目１番１９号',
        industry='小売業',
        sec_code='33460',
        corporate_number='3010001067927',
    ),
    'E00392': EdinetCodeEntry(
        edinet_code='E00392',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=488,
        fiscal_year_end='8月31日',
        submitter_name='株式会社シベール',
        submitter_name_en='CYBELE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシベール',
        address='山形市あこや町二丁目２番３２号',
        industry='食料品',
        sec_code=None,
        corporate_number='5390001000864',
    ),
    'E00393': EdinetCodeEntry(
        edinet_code='E00393',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=53887,
        fiscal_year_end='12月31日',
        submitter_name='サッポロホールディングス株式会社',
        submitter_name_en='SAPPORO HOLDINGS LIMITED',
        submitter_name_yomi='サッポロホールディングスカブシキガイシャ',
        address='渋谷区恵比寿四丁目２０番１号',
        industry='食料品',
        sec_code='25010',
        corporate_number='4011001009265',
    ),
    'E00394': EdinetCodeEntry(
        edinet_code='E00394',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=220044,
        fiscal_year_end='12月31日',
        submitter_name='アサヒグループホールディングス株式会社',
        submitter_name_en='ASAHI GROUP HOLDINGS,LTD.',
        submitter_name_yomi='アサヒグループホールディングスカブシキガイシャ',
        address='墨田区吾妻橋一丁目２３番１号',
        industry='食料品',
        sec_code='25020',
        corporate_number='6010601036386',
    ),
    'E00395': EdinetCodeEntry(
        edinet_code='E00395',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=102046,
        fiscal_year_end='12月31日',
        submitter_name='キリンホールディングス株式会社',
        submitter_name_en='Kirin Holdings Company, Limited',
        submitter_name_yomi='キリンホールディングスカブシキガイシャ',
        address='中野区中野四丁目１０番２号',
        industry='食料品',
        sec_code='25030',
        corporate_number='5010001034768',
    ),
    'E00396': EdinetCodeEntry(
        edinet_code='E00396',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13226,
        fiscal_year_end='3月31日',
        submitter_name='宝ホールディングス株式会社',
        submitter_name_en='TAKARA HOLDINGS INC.',
        submitter_name_yomi='タカラホールディングスカブシキガイシャ',
        address='京都市下京区四条通烏丸東入長刀鉾町２０番地',
        industry='食料品',
        sec_code='25310',
        corporate_number='4130001014981',
    ),
    'E00397': EdinetCodeEntry(
        edinet_code='E00397',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6946,
        fiscal_year_end='12月31日',
        submitter_name='オエノンホールディングス株式会社',
        submitter_name_en='Oenon Holdings, Inc.',
        submitter_name_yomi='オエノンホールディングスカブシキガイシャ',
        address='墨田区東駒形一丁目１７番６号',
        industry='食料品',
        sec_code='25330',
        corporate_number='2010001034770',
    ),
    'E00399': EdinetCodeEntry(
        edinet_code='E00399',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5357,
        fiscal_year_end=None,
        submitter_name='ジャパン・フード＆リカー・アライアンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンフードアンドリカーアライアンスカブシキガイシャ',
        address='小豆郡小豆島町苗羽甲１８５０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1470001012376',
    ),
    'E00400': EdinetCodeEntry(
        edinet_code='E00400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1650,
        fiscal_year_end='3月31日',
        submitter_name='養命酒製造株式会社',
        submitter_name_en='YOMEISHU SEIZO CO.,LTD.',
        submitter_name_yomi='ヨウメイシュセイゾウカブシキガイシャ',
        address='渋谷区南平台町１６番２５号',
        industry='食料品',
        sec_code='25400',
        corporate_number='2011001024084',
    ),
    'E00405': EdinetCodeEntry(
        edinet_code='E00405',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=28,
        fiscal_year_end='3月31日',
        submitter_name='モンデ酒造株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モンデシュゾウカブシキガイシャ',
        address='笛吹市石和町市部４７６番地',
        industry='食料品',
        sec_code=None,
        corporate_number='9090001006194',
    ),
    'E00406': EdinetCodeEntry(
        edinet_code='E00406',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31117,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤクルト本社',
        submitter_name_en='YAKULT HONSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤクルトホンシャ',
        address='港区海岸１丁目１０番３０号',
        industry='食料品',
        sec_code='22670',
        corporate_number='7010401029746',
    ),
    'E00408': EdinetCodeEntry(
        edinet_code='E00408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2935,
        fiscal_year_end='12月31日',
        submitter_name='北海道コカ・コーラボトリング株式会社',
        submitter_name_en='HOKKAIDO COCA-COLA BOTTLING CO.,LTD.',
        submitter_name_yomi='ホッカイドウコカコーラボトリングカブシキガイシャ',
        address='札幌市清田区清田一条一丁目２番１号',
        industry='食料品',
        sec_code='25730',
        corporate_number='9430001021794',
    ),
    'E00410': EdinetCodeEntry(
        edinet_code='E00410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=378,
        fiscal_year_end='3月31日',
        submitter_name='オリオンビール株式会社',
        submitter_name_en='orion breweries,ltd.',
        submitter_name_yomi='オリオンビールカブシキガイシャ',
        address='豊見城市字豊崎１番地４１１',
        industry='食料品',
        sec_code='409A0',
        corporate_number='7360001008504',
    ),
    'E00411': EdinetCodeEntry(
        edinet_code='E00411',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15000,
        fiscal_year_end=None,
        submitter_name='サントリー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サントリーカブシキカイシャ',
        address='港区台場二丁目３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401081444',
    ),
    'E00414': EdinetCodeEntry(
        edinet_code='E00414',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19912,
        fiscal_year_end='4月30日',
        submitter_name='株式会社伊藤園',
        submitter_name_en='ITO EN,LTD.',
        submitter_name_yomi='カブシキガイシャイトウエン',
        address='渋谷区本町３丁目４７番１０号',
        industry='食料品',
        sec_code='25930',
        corporate_number='3011001002279',
    ),
    'E00417': EdinetCodeEntry(
        edinet_code='E00417',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15231,
        fiscal_year_end='12月31日',
        submitter_name='コカ・コーラボトラーズジャパンホールディングス株式会社',
        submitter_name_en='Coca-Cola Bottlers Japan Holdings Inc.',
        submitter_name_yomi='コカコーラボトラーズジャパンホールディングスカブシキガイシャ',
        address='港区赤坂九丁目７番１号',
        industry='食料品',
        sec_code='25790',
        corporate_number='4290001002946',
    ),
    'E00421': EdinetCodeEntry(
        edinet_code='E00421',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=628,
        fiscal_year_end='3月31日',
        submitter_name='ジャパンフーズ株式会社',
        submitter_name_en='JAPAN FOODS CO.,LTD.',
        submitter_name_yomi='ジャパンフーズカブシキガイシャ',
        address='長生郡長柄町皿木２０３番地１',
        industry='食料品',
        sec_code=None,
        corporate_number='2040001059014',
    ),
    'E00422': EdinetCodeEntry(
        edinet_code='E00422',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=865,
        fiscal_year_end='9月20日',
        submitter_name='マルサンアイ株式会社',
        submitter_name_en='MARUSAN-AI  CO.,LTD.',
        submitter_name_yomi='マルサンアイカブシキガイシャ',
        address='岡崎市仁木町字荒下１番地',
        industry='食料品',
        sec_code='25510',
        corporate_number='9180301001869',
    ),
    'E00423': EdinetCodeEntry(
        edinet_code='E00423',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='コカ・コーラ\u3000ボトラーズジャパン株式会社',
        submitter_name_en='Coca-Cola Bottlers Japan Inc.',
        submitter_name_yomi='コカコーラ\u3000ボトラーズジャパンカブシキガイシャ',
        address='港区赤坂九丁目７番１号',
        industry='食料品',
        sec_code=None,
        corporate_number='9020001043244',
    ),
    'E00424': EdinetCodeEntry(
        edinet_code='E00424',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1924,
        fiscal_year_end='1月20日',
        submitter_name='ダイドーグループホールディングス株式会社',
        submitter_name_en='DyDo GROUP HOLDINGS,INC.',
        submitter_name_yomi='ダイドーグループホールディングスカブシキガイシャ',
        address='大阪市北区中之島二丁目２番７号',
        industry='食料品',
        sec_code='25900',
        corporate_number='2120001083154',
    ),
    'E00428': EdinetCodeEntry(
        edinet_code='E00428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16332,
        fiscal_year_end='3月31日',
        submitter_name='日清オイリオグループ株式会社',
        submitter_name_en='The Nisshin OilliO Group, Ltd.',
        submitter_name_yomi='ニッシンオイリオグループカブシキガイシャ',
        address='中央区新川一丁目２３番１号',
        industry='食料品',
        sec_code='26020',
        corporate_number='1010001034887',
    ),
    'E00430': EdinetCodeEntry(
        edinet_code='E00430',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1351,
        fiscal_year_end='3月31日',
        submitter_name='ボーソー油脂株式会社',
        submitter_name_en='BOSO OIL&FAT CO.,LTD.',
        submitter_name_yomi='ボーソーユシカブシキガイシャ',
        address='中央区日本橋本石町四丁目５番１２号',
        industry='食料品',
        sec_code=None,
        corporate_number='8010001034914',
    ),
    'E00431': EdinetCodeEntry(
        edinet_code='E00431',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13208,
        fiscal_year_end='3月31日',
        submitter_name='不二製油株式会社',
        submitter_name_en='FUJI OIL CO., LTD.',
        submitter_name_yomi='フジセイユカブシキガイシャ',
        address='泉佐野市住吉町１番地',
        industry='食料品',
        sec_code='26070',
        corporate_number='8120001088461',
    ),
    'E00432': EdinetCodeEntry(
        edinet_code='E00432',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1299,
        fiscal_year_end=None,
        submitter_name='攝津製油株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セッツセイユカブシキガイシャ',
        address='大阪市福島区野田六丁目２番３９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001035377',
    ),
    'E00433': EdinetCodeEntry(
        edinet_code='E00433',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2160,
        fiscal_year_end='3月31日',
        submitter_name='かどや製油株式会社',
        submitter_name_en='KADOYA SESAME MILLS INCORPORATED',
        submitter_name_yomi='カドヤセイユカブシキガイシャ',
        address='品川区北品川五丁目１番１８号',
        industry='食料品',
        sec_code='26120',
        corporate_number='9010701002351',
    ),
    'E00434': EdinetCodeEntry(
        edinet_code='E00434',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｊ－オイルミルズ',
        submitter_name_en='J-OIL MILLS, INC.',
        submitter_name_yomi='カブシキガイシャジェイオイルミルズ',
        address='中央区明石町８番１号',
        industry='食料品',
        sec_code='26130',
        corporate_number='6010001078021',
    ),
    'E00435': EdinetCodeEntry(
        edinet_code='E00435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11599,
        fiscal_year_end='3月31日',
        submitter_name='キッコーマン株式会社',
        submitter_name_en='KIKKOMAN CORPORATION',
        submitter_name_yomi='キッコーマンカブシキガイシャ',
        address='野田市野田２５０番地',
        industry='食料品',
        sec_code='28010',
        corporate_number='2040001071167',
    ),
    'E00436': EdinetCodeEntry(
        edinet_code='E00436',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=79863,
        fiscal_year_end='3月31日',
        submitter_name='味の素株式会社',
        submitter_name_en='Ajinomoto Co., Inc.',
        submitter_name_yomi='アジノモトカブシキガイシャ',
        address='中央区京橋一丁目１５番１号',
        industry='食料品',
        sec_code='28020',
        corporate_number='8010001034740',
    ),
    'E00437': EdinetCodeEntry(
        edinet_code='E00437',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=396,
        fiscal_year_end='3月31日',
        submitter_name='ヒゲタ醤油株式会社',
        submitter_name_en='HIGETA SHOYU CO., LTD',
        submitter_name_yomi='ヒゲタショウユ\u3000カブシキガイシャ',
        address='中央区日本橋小網町２番３号',
        industry='食料品',
        sec_code=None,
        corporate_number='1010001055066',
    ),
    'E00439': EdinetCodeEntry(
        edinet_code='E00439',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4736,
        fiscal_year_end='3月31日',
        submitter_name='中部飼料株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウブシリョウカブシキガイシャ',
        address='名古屋市中区錦二丁目１３番１９号',
        industry='食料品',
        sec_code='20530',
        corporate_number='2180001094757',
    ),
    'E00442': EdinetCodeEntry(
        edinet_code='E00442',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1600,
        fiscal_year_end='3月31日',
        submitter_name='日本食品化工株式会社',
        submitter_name_en='NIHON SHOKUHIN KAKO CO., LTD.',
        submitter_name_yomi='ニホンショクヒンカコウカブシキガイシャ',
        address='千代田区丸の内一丁目６番５号',
        industry='食料品',
        sec_code='28920',
        corporate_number='8010001133971',
    ),
    'E00443': EdinetCodeEntry(
        edinet_code='E00443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3415,
        fiscal_year_end='3月31日',
        submitter_name='林兼産業株式会社',
        submitter_name_en='Hayashikane Sangyo Co., Ltd.',
        submitter_name_yomi='ハヤシカネサンギョウカブシキガイシャ',
        address='下関市大和町二丁目４番８号',
        industry='食料品',
        sec_code='22860',
        corporate_number='8250001006179',
    ),
    'E00444': EdinetCodeEntry(
        edinet_code='E00444',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19985,
        fiscal_year_end='12月31日',
        submitter_name='カゴメ株式会社',
        submitter_name_en='KAGOME CO.,LTD.',
        submitter_name_yomi='カゴメカブシキガイシャ',
        address='名古屋市中区錦三丁目１４番１５号',
        industry='食料品',
        sec_code='28110',
        corporate_number='2180001035109',
    ),
    'E00446': EdinetCodeEntry(
        edinet_code='E00446',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30472,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニチレイ',
        submitter_name_en='NICHIREI CORPORATION',
        submitter_name_yomi='カブシキガイシャニチレイ',
        address='中央区築地六丁目１９番２０号',
        industry='食料品',
        sec_code='28710',
        corporate_number='8010001034889',
    ),
    'E00447': EdinetCodeEntry(
        edinet_code='E00447',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=377,
        fiscal_year_end='2月末日',
        submitter_name='株式会社セイヒョー',
        submitter_name_en='SEIHYO CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャセイヒョー',
        address='新潟市北区島見町２４３４番地１０（同所は登記上の本店所在地で実際の業務は「最寄りの連絡場所」で行っております。）',
        industry='食料品',
        sec_code='28720',
        corporate_number='3110001002790',
    ),
    'E00448': EdinetCodeEntry(
        edinet_code='E00448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='群栄化学工業株式会社',
        submitter_name_en='Gun Ei Chemical Industry Co., Ltd.',
        submitter_name_yomi='グンエイカガクコウギョウカブシキガイシャ',
        address='高崎市宿大類町７００番地',
        industry='化学',
        sec_code='42290',
        corporate_number='7070001006735',
    ),
    'E00449': EdinetCodeEntry(
        edinet_code='E00449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2617,
        fiscal_year_end=None,
        submitter_name='オリエンタル酵母工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オリエンタルコウボコウギョウカブシキカイシャ',
        address='板橋区小豆沢三丁目６番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011401001273',
    ),
    'E00452': EdinetCodeEntry(
        edinet_code='E00452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1744,
        fiscal_year_end='3月31日',
        submitter_name='ヱスビー食品株式会社',
        submitter_name_en='S&B FOODS INC.',
        submitter_name_yomi='エスビーショクヒンカブシキガイシャ',
        address='中央区日本橋兜町１８番６号',
        industry='食料品',
        sec_code='28050',
        corporate_number='6010001034750',
    ),
    'E00453': EdinetCodeEntry(
        edinet_code='E00453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=919,
        fiscal_year_end='3月31日',
        submitter_name='石井食品株式会社',
        submitter_name_en='Ishii Food Co.,Ltd.',
        submitter_name_yomi='イシイショクヒンカブシキガイシャ',
        address='船橋市本町二丁目７番１７号',
        industry='食料品',
        sec_code='28940',
        corporate_number='7040001016687',
    ),
    'E00454': EdinetCodeEntry(
        edinet_code='E00454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2011,
        fiscal_year_end='3月31日',
        submitter_name='日和産業株式会社',
        submitter_name_en='NICHIWA SANGYO CO., LTD.',
        submitter_name_yomi='ニチワサンギョウカブシキガイシャ',
        address='神戸市東灘区住吉浜町１９番地の５',
        industry='食料品',
        sec_code='20550',
        corporate_number='7140001002355',
    ),
    'E00456': EdinetCodeEntry(
        edinet_code='E00456',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5599,
        fiscal_year_end='3月31日',
        submitter_name='ユアサ・フナショク株式会社',
        submitter_name_en='YUASA FUNASHOKU CO.,LTD.',
        submitter_name_yomi='ユアサ\u3000フナショクカブシキガイシャ',
        address='船橋市宮本四丁目１８番６号',
        industry='卸売業',
        sec_code='80060',
        corporate_number='6040001019014',
    ),
    'E00457': EdinetCodeEntry(
        edinet_code='E00457',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25122,
        fiscal_year_end='3月31日',
        submitter_name='日清食品ホールディングス株式会社',
        submitter_name_en='NISSIN FOODS HOLDINGS CO.,LTD.',
        submitter_name_yomi='ニッシンショクヒンホールディングスカブシキガイシャ',
        address='大阪市淀川区西中島四丁目１番１号',
        industry='食料品',
        sec_code='28970',
        corporate_number='7120001057574',
    ),
    'E00458': EdinetCodeEntry(
        edinet_code='E00458',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6716,
        fiscal_year_end='3月31日',
        submitter_name='丸大食品株式会社',
        submitter_name_en='MARUDAI FOOD CO.,LTD.',
        submitter_name_yomi='マルダイショクヒンカブシキガイシャ',
        address='高槻市緑町２１番３号',
        industry='食料品',
        sec_code='22880',
        corporate_number='3120901012046',
    ),
    'E00461': EdinetCodeEntry(
        edinet_code='E00461',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18969,
        fiscal_year_end='3月31日',
        submitter_name='東洋水産株式会社',
        submitter_name_en='TOYO SUISAN KAISHA, LTD.',
        submitter_name_yomi='トウヨウスイサンカブシキガイシャ',
        address='港区港南二丁目１３番４０号',
        industry='食料品',
        sec_code='28750',
        corporate_number='2010401020321',
    ),
    'E00462': EdinetCodeEntry(
        edinet_code='E00462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9948,
        fiscal_year_end='3月31日',
        submitter_name='ハウス食品グループ本社株式会社',
        submitter_name_en='HOUSE FOODS GROUP INC.',
        submitter_name_yomi='ハウスショクヒングループホンシャカブシキガイシャ',
        address='東大阪市\u3000御厨栄町１丁目５番７号',
        industry='食料品',
        sec_code='28100',
        corporate_number='2122001005872',
    ),
    'E00464': EdinetCodeEntry(
        edinet_code='E00464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24104,
        fiscal_year_end='11月30日',
        submitter_name='キユーピー株式会社',
        submitter_name_en='Kewpie Corporation',
        submitter_name_yomi='キューピーカブシキガイシャ',
        address='渋谷区渋谷１丁目４番１３号',
        industry='食料品',
        sec_code='28090',
        corporate_number='6011001006277',
    ),
    'E00465': EdinetCodeEntry(
        edinet_code='E00465',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1160,
        fiscal_year_end='3月31日',
        submitter_name='ユタカフーズ株式会社',
        submitter_name_en='YUTAKA FOODS CORPORATION',
        submitter_name_yomi='ユタカフーズカブシキガイシャ',
        address='知多郡武豊町字川脇３４番地の１',
        industry='食料品',
        sec_code='28060',
        corporate_number='7180001092285',
    ),
    'E00466': EdinetCodeEntry(
        edinet_code='E00466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1044,
        fiscal_year_end='3月31日',
        submitter_name='ブルドックソース株式会社',
        submitter_name_en='BULL-DOG SAUCE CO.,LTD.',
        submitter_name_yomi='ブルドックソース\u3000カブシキガイシャ',
        address='中央区日本橋兜町１１番５号',
        industry='食料品',
        sec_code='28040',
        corporate_number='6010001034924',
    ),
    'E00467': EdinetCodeEntry(
        edinet_code='E00467',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='シマダヤ株式会社',
        submitter_name_en='Shimadaya Corporation',
        submitter_name_yomi='シマダヤカブシキガイシャ',
        address='渋谷区恵比寿西１－３３－１１',
        industry='食料品',
        sec_code='250A0',
        corporate_number='3011001010678',
    ),
    'E00469': EdinetCodeEntry(
        edinet_code='E00469',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3502,
        fiscal_year_end='3月31日',
        submitter_name='株式会社永谷園ホールディングス',
        submitter_name_en='NAGATANIEN HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャナガタニエンホールディングス',
        address='港区西新橋二丁目３６番１号',
        industry='食料品',
        sec_code=None,
        corporate_number='6010401021134',
    ),
    'E00471': EdinetCodeEntry(
        edinet_code='E00471',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=989,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウェルディッシュ',
        submitter_name_en='Wel-Dish. Incorporated',
        submitter_name_yomi='カブシキガイシャウェルディッシュ',
        address='港区白金台５丁目１８番９号',
        industry='食料品',
        sec_code='29010',
        corporate_number='6010001010603',
    ),
    'E00472': EdinetCodeEntry(
        edinet_code='E00472',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7730,
        fiscal_year_end='3月31日',
        submitter_name='太陽化学株式会社',
        submitter_name_en='TAIYOKAGAKU CO.,LTD.',
        submitter_name_yomi='タイヨウカガクカブシキガイシャ',
        address='四日市市山田町８００番',
        industry='食料品',
        sec_code='29020',
        corporate_number='3190001015397',
    ),
    'E00473': EdinetCodeEntry(
        edinet_code='E00473',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4693,
        fiscal_year_end='3月31日',
        submitter_name='シノブフーズ株式会社',
        submitter_name_en='shinobu foods products co., ltd',
        submitter_name_yomi='シノブフーズカブシキガイシャ',
        address='大阪市西淀川区竹島２丁目３番１８号',
        industry='食料品',
        sec_code='29030',
        corporate_number='2120001049881',
    ),
    'E00474': EdinetCodeEntry(
        edinet_code='E00474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=735,
        fiscal_year_end='12月31日',
        submitter_name='Ｂ－Ｒ\u3000サーティワン\u3000アイスクリーム株式会社',
        submitter_name_en='B-R 31 ICE CREAM CO.,LTD.',
        submitter_name_yomi='ビーアールサーティワンアイスクリームカブシキガイシャ',
        address='品川区上大崎三丁目１番１号',
        industry='食料品',
        sec_code='22680',
        corporate_number='8010701008226',
    ),
    'E00475': EdinetCodeEntry(
        edinet_code='E00475',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3617,
        fiscal_year_end='3月31日',
        submitter_name='焼津水産化学工業株式会社',
        submitter_name_en='YAIZU  SUISANKAGAKU  INDUSTRY  CO.,LTD.',
        submitter_name_yomi='ヤイヅスイサンカガクコウギョウカブシキガイシャ',
        address='焼津市小川新町５丁目８番１３号',
        industry='食料品',
        sec_code=None,
        corporate_number='1080001015385',
    ),
    'E00476': EdinetCodeEntry(
        edinet_code='E00476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=940,
        fiscal_year_end='6月30日',
        submitter_name='一正蒲鉾株式会社',
        submitter_name_en='ICHIMASA KAMABOKO CO.,LTD.',
        submitter_name_yomi='イチマサカマボコカブシキカイシャ',
        address='新潟市東区津島屋７丁目７７番地',
        industry='食料品',
        sec_code='29040',
        corporate_number='5110001001304',
    ),
    'E00477': EdinetCodeEntry(
        edinet_code='E00477',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1859,
        fiscal_year_end='3月31日',
        submitter_name='オーケー食品工業株式会社',
        submitter_name_en='OK Food Industry Co., Ltd.',
        submitter_name_yomi='オーケーショクヒンコウギョウカブシキガイシャ',
        address='朝倉市小田１０８０番地１',
        industry='食料品',
        sec_code=None,
        corporate_number='3290001043990',
    ),
    'E00478': EdinetCodeEntry(
        edinet_code='E00478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1413,
        fiscal_year_end='3月31日',
        submitter_name='和弘食品株式会社',
        submitter_name_en='Wakou Shokuhin Co.,Ltd.',
        submitter_name_yomi='ワコウショクヒンカブシキガイシャ',
        address='小樽市銭函３丁目５０４番地１',
        industry='食料品',
        sec_code='28130',
        corporate_number='9430001050661',
    ),
    'E00480': EdinetCodeEntry(
        edinet_code='E00480',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1102,
        fiscal_year_end='3月31日',
        submitter_name='株式会社あじかん',
        submitter_name_en='ahjikanco.,ltd',
        submitter_name_yomi='カブシキガイシャアジカン',
        address='広島市西区商工センター七丁目３番９号',
        industry='食料品',
        sec_code='29070',
        corporate_number='4240001000392',
    ),
    'E00481': EdinetCodeEntry(
        edinet_code='E00481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6566,
        fiscal_year_end='3月31日',
        submitter_name='フジッコ株式会社',
        submitter_name_en='FUJICCO CO., LTD.',
        submitter_name_yomi='フジッコカブシキガイシャ',
        address='神戸市中央区港島中町６丁目１３番地４',
        industry='食料品',
        sec_code='29080',
        corporate_number='9140001010604',
    ),
    'E00482': EdinetCodeEntry(
        edinet_code='E00482',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5544,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ロック・フィールド',
        submitter_name_en='ROCK FIELD CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ロックフィールド',
        address='神戸市東灘区魚崎浜町１５番地２',
        industry='食料品',
        sec_code='29100',
        corporate_number='4140001002820',
    ),
    'E00484': EdinetCodeEntry(
        edinet_code='E00484',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3672,
        fiscal_year_end='3月31日',
        submitter_name='佐藤食品工業株式会社',
        submitter_name_en='SATO FOODS INDUSTRIES CO.,LTD.',
        submitter_name_yomi='サトウショクヒンコウギョウカブシキガイシャ',
        address='小牧市堀の内四丁目１５４番地',
        industry='食料品',
        sec_code='28140',
        corporate_number='5180001075845',
    ),
    'E00485': EdinetCodeEntry(
        edinet_code='E00485',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=375,
        fiscal_year_end='3月31日',
        submitter_name='ジャパンローヤルゼリー株式会社',
        submitter_name_en='JAPAN ROYAL JELLY Co., LTD.',
        submitter_name_yomi='ジャパンローヤルゼリーカブシキガイシャ',
        address='新宿区西新宿一丁目２５番１号\u3000新宿センタービル',
        industry='食料品',
        sec_code=None,
        corporate_number='4010001134180',
    ),
    'E00486': EdinetCodeEntry(
        edinet_code='E00486',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7095,
        fiscal_year_end='3月31日',
        submitter_name='アリアケジャパン株式会社',
        submitter_name_en='ARIAKE JAPAN Co.,Ltd.',
        submitter_name_yomi='アリアケジャパンカブシキガイシャ',
        address='渋谷区恵比寿南三丁目２番１７号',
        industry='食料品',
        sec_code='28150',
        corporate_number='3011001030833',
    ),
    'E00487': EdinetCodeEntry(
        edinet_code='E00487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1617,
        fiscal_year_end='3月31日',
        submitter_name='旭松食品株式会社',
        submitter_name_en='ASAHIMATSU FOODS CO.,LTD.',
        submitter_name_yomi='アサヒマツショクヒンカブシキガイシャ',
        address='飯田市駄科１００８番地',
        industry='食料品',
        sec_code='29110',
        corporate_number='5100001022185',
    ),
    'E00488': EdinetCodeEntry(
        edinet_code='E00488',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=922,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デルソーレ',
        submitter_name_en='Delsole Corporation',
        submitter_name_yomi='カブシキガイシャデルソーレ',
        address='江東区有明三丁目４番１０号',
        industry='食料品',
        sec_code='28760',
        corporate_number='7011001041298',
    ),
    'E00491': EdinetCodeEntry(
        edinet_code='E00491',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4628,
        fiscal_year_end='3月31日',
        submitter_name='キーコーヒー株式会社',
        submitter_name_en='key coffee inc',
        submitter_name_yomi='キーコーヒーカブシキガイシャ',
        address='港区西新橋二丁目３４番４号',
        industry='食料品',
        sec_code='25940',
        corporate_number='4010401007523',
    ),
    'E00492': EdinetCodeEntry(
        edinet_code='E00492',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100000,
        fiscal_year_end='12月31日',
        submitter_name='日本たばこ産業株式会社',
        submitter_name_en='JAPAN TOBACCO INC.',
        submitter_name_yomi='ニホンタバコサンギョウカブシキガイシャ',
        address='港区虎ノ門四丁目１番１号',
        industry='食料品',
        sec_code='29140',
        corporate_number='4010401023000',
    ),
    'E00493': EdinetCodeEntry(
        edinet_code='E00493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5424,
        fiscal_year_end='3月31日',
        submitter_name='ケンコーマヨネーズ株式会社',
        submitter_name_en='KENKO Mayonnaise Co., Ltd.',
        submitter_name_yomi='ケンコーマヨネーズカブシキガイシャ',
        address='神戸市灘区都通三丁目３番１６号',
        industry='食料品',
        sec_code='29150',
        corporate_number='6140001003305',
    ),
    'E00494': EdinetCodeEntry(
        edinet_code='E00494',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1500,
        fiscal_year_end='3月31日',
        submitter_name='仙波糖化工業株式会社',
        submitter_name_en='Semba Tohka Industries Co. ,Ltd',
        submitter_name_yomi='センバトウカコウギョウカブシキガイシャ',
        address='真岡市並木町２丁目１番地１０',
        industry='食料品',
        sec_code='29160',
        corporate_number='6060001009351',
    ),
    'E00495': EdinetCodeEntry(
        edinet_code='E00495',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=814,
        fiscal_year_end='9月30日',
        submitter_name='株式会社大森屋',
        submitter_name_en='OHMORIYA Co., LTD',
        submitter_name_yomi='カブシキガイシャオオモリヤ',
        address='大阪市此花区西九条１丁目１番６０号',
        industry='食料品',
        sec_code='29170',
        corporate_number='1120001034595',
    ),
    'E00496': EdinetCodeEntry(
        edinet_code='E00496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8049,
        fiscal_year_end='2月末日',
        submitter_name='わらべや日洋ホールディングス株式会社',
        submitter_name_en='WARABEYA NICHIYO HOLDINGS CO.,LTD.',
        submitter_name_yomi='ワラベヤニチヨウホールディングスカブシキガイシャ',
        address='新宿区富久町１３番１９号',
        industry='食料品',
        sec_code='29180',
        corporate_number='9012701001077',
    ),
    'E00497': EdinetCodeEntry(
        edinet_code='E00497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1989,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000マルタイ',
        submitter_name_en='marutai co.,ltd',
        submitter_name_yomi='カブシキガイシャマルタイ',
        address='福岡市西区今宿青木１０４２番１',
        industry='食料品',
        sec_code='29190',
        corporate_number='5290001000577',
    ),
    'E00498': EdinetCodeEntry(
        edinet_code='E00498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1474,
        fiscal_year_end='3月31日',
        submitter_name='日東ベスト株式会社',
        submitter_name_en='NittoBest Corporation',
        submitter_name_yomi='ニットウベストカブシキガイシャ',
        address='寒河江市幸町４番２７号',
        industry='食料品',
        sec_code='28770',
        corporate_number='6390001011877',
    ),
    'E00501': EdinetCodeEntry(
        edinet_code='E00501',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=870,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイショー',
        submitter_name_en='DAISHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイショー',
        address='墨田区亀沢一丁目１７番３号',
        industry='食料品',
        sec_code='28160',
        corporate_number='8010601023878',
    ),
    'E00502': EdinetCodeEntry(
        edinet_code='E00502',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=603,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヒガシマル',
        submitter_name_en='HIGASHIMARU CO., LTD.',
        submitter_name_yomi='カブシキガイシャヒガシマル',
        address='日置市伊集院町猪鹿倉２０番地',
        industry='食料品',
        sec_code='20580',
        corporate_number='1340001000162',
    ),
    'E00503': EdinetCodeEntry(
        edinet_code='E00503',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=915,
        fiscal_year_end='11月30日',
        submitter_name='アヲハタ株式会社',
        submitter_name_en='AOHATA Corporation',
        submitter_name_yomi='アオハタカブシキガイシャ',
        address='竹原市忠海中町一丁目１番２５号',
        industry='食料品',
        sec_code=None,
        corporate_number='3240001037171',
    ),
    'E00505': EdinetCodeEntry(
        edinet_code='E00505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2520,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ユニカフェ',
        submitter_name_en='UNICAFE INC.',
        submitter_name_yomi='カブシキガイシャユニカフェ',
        address='港区赤坂八丁目５番２６号',
        industry='食料品',
        sec_code='25970',
        corporate_number='9010401030413',
    ),
    'E00506': EdinetCodeEntry(
        edinet_code='E00506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1975,
        fiscal_year_end='3月31日',
        submitter_name='株式会社なとり',
        submitter_name_en='NATORI CO., LTD.',
        submitter_name_yomi='カブシキガイシャナトリ',
        address='北区王子５丁目５番１号',
        industry='食料品',
        sec_code='29220',
        corporate_number='9011501003449',
    ),
    'E00507': EdinetCodeEntry(
        edinet_code='E00507',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2827,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ギャバン',
        submitter_name_en='GABAN CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャギャバン',
        address='中央区入船一丁目９番１２号',
        industry='食料品',
        sec_code=None,
        corporate_number='5010001041582',
    ),
    'E00508': EdinetCodeEntry(
        edinet_code='E00508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1441,
        fiscal_year_end='3月31日',
        submitter_name='はごろもフーズ株式会社',
        submitter_name_en='HAGOROMO FOODS CORPORATION',
        submitter_name_yomi='ハゴロモフーズカブシキガイシャ',
        address='静岡市清水区島崎町１５１番地',
        industry='食料品',
        sec_code='28310',
        corporate_number='3080001008932',
    ),
    'E00510': EdinetCodeEntry(
        edinet_code='E00510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=543,
        fiscal_year_end='4月30日',
        submitter_name='サトウ食品株式会社',
        submitter_name_en='SATO FOODS CO., LTD.',
        submitter_name_yomi='サトウショクヒンカブシキガイシャ',
        address='新潟市東区宝町１３番５号',
        industry='食料品',
        sec_code='29230',
        corporate_number='8110001002068',
    ),
    'E00511': EdinetCodeEntry(
        edinet_code='E00511',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=455,
        fiscal_year_end='3月31日',
        submitter_name='イフジ産業株式会社',
        submitter_name_en='Ifuji Sangyo Co., Ltd.',
        submitter_name_yomi='イフジサンギョウカブシキガイシャ',
        address='糟屋郡粕屋町戸原東二丁目１番２９号',
        industry='食料品',
        sec_code='29240',
        corporate_number='7290001038112',
    ),
    'E00512': EdinetCodeEntry(
        edinet_code='E00512',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=740,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ピックルスコーポレーション',
        submitter_name_en='PICKLES CORPORATION',
        submitter_name_yomi='カブシキガイシャピックルスコーポレーション',
        address='所沢市東住吉７番８号',
        industry='食料品',
        sec_code=None,
        corporate_number='2030001024893',
    ),
    'E00513': EdinetCodeEntry(
        edinet_code='E00513',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1042,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ピエトロ',
        submitter_name_en='PIETRO Co., Ltd.',
        submitter_name_yomi='カブシキガイシャピエトロ',
        address='福岡市中央区天神三丁目４番５号',
        industry='食料品',
        sec_code='28180',
        corporate_number='3290001018662',
    ),
    'E00514': EdinetCodeEntry(
        edinet_code='E00514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1387,
        fiscal_year_end='3月31日',
        submitter_name='エバラ食品工業株式会社',
        submitter_name_en='EBARAFoodsIndustry,Inc.',
        submitter_name_yomi='エバラショクヒンコウギョウカブシキガイシャ',
        address='横浜市西区みなとみらい四丁目４番５号\u3000横浜アイマークプレイス',
        industry='食料品',
        sec_code='28190',
        corporate_number='5020001022870',
    ),
    'E00515': EdinetCodeEntry(
        edinet_code='E00515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1000,
        fiscal_year_end='9月30日',
        submitter_name='株式会社\u3000篠崎屋',
        submitter_name_en='SHINOZAKIYA,INC.',
        submitter_name_yomi='カブシキガイシャ\u3000シノザキヤ',
        address='春日部市大字赤沼８７０番地１',
        industry='食料品',
        sec_code='29260',
        corporate_number='5030001051126',
    ),
    'E00518': EdinetCodeEntry(
        edinet_code='E00518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25303,
        fiscal_year_end='3月31日',
        submitter_name='ＲＩＺＡＰグループ株式会社',
        submitter_name_en='RIZAP GROUP,Inc.',
        submitter_name_yomi='ライザップグループカブシキガイシャ',
        address='新宿区西新宿八丁目１７番１号',
        industry='小売業',
        sec_code='29280',
        corporate_number='2011201012987',
    ),
    'E00520': EdinetCodeEntry(
        edinet_code='E00520',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26071,
        fiscal_year_end='3月31日',
        submitter_name='グンゼ株式会社',
        submitter_name_en='GUNZE LIMITED',
        submitter_name_yomi='グンゼカブシキガイシャ',
        address='綾部市青野町膳所１番地',
        industry='繊維製品',
        sec_code='30020',
        corporate_number='7130001041734',
    ),
    'E00521': EdinetCodeEntry(
        edinet_code='E00521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26,
        fiscal_year_end='3月31日',
        submitter_name='ポラリス・ホールディングス株式会社',
        submitter_name_en='Polaris Holdings Co., Ltd.',
        submitter_name_yomi='ポラリスホールディングスカブシキガイシャ',
        address='中央区新川一丁目２３番５号',
        industry='サービス業',
        sec_code='30100',
        corporate_number='5010001128140',
    ),
    'E00523': EdinetCodeEntry(
        edinet_code='E00523',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=111609,
        fiscal_year_end='12月31日',
        submitter_name='ヒューリック株式会社',
        submitter_name_en='Hulic Co.,Ltd.',
        submitter_name_yomi='ヒューリックカブシキガイシャ',
        address='中央区日本橋大伝馬町７番３号',
        industry='不動産業',
        sec_code='30030',
        corporate_number='9010001008702',
    ),
    'E00524': EdinetCodeEntry(
        edinet_code='E00524',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1817,
        fiscal_year_end='12月31日',
        submitter_name='片倉工業株式会社',
        submitter_name_en='Katakura  Industries  Co.,Ltd.',
        submitter_name_yomi='カタクラコウギョウカブシキガイシャ',
        address='中央区明石町６番４号',
        industry='繊維製品',
        sec_code='30010',
        corporate_number='9010001034764',
    ),
    'E00525': EdinetCodeEntry(
        edinet_code='E00525',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=51730,
        fiscal_year_end='3月31日',
        submitter_name='東洋紡株式会社',
        submitter_name_en='TOYOBO CO.,LTD.',
        submitter_name_yomi='トウヨウボウカブシキガイシヤ',
        address='大阪市北区梅田一丁目１３番１号',
        industry='化学',
        sec_code='31010',
        corporate_number='2120001059666',
    ),
    'E00527': EdinetCodeEntry(
        edinet_code='E00527',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ユニチカ株式会社',
        submitter_name_en='UNITIKA LTD.',
        submitter_name_yomi='ユニチカカブシキガイシャ',
        address='大阪市中央区久太郎町４丁目１番３号',
        industry='繊維製品',
        sec_code='31030',
        corporate_number='8140001051822',
    ),
    'E00528': EdinetCodeEntry(
        edinet_code='E00528',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22040,
        fiscal_year_end='3月31日',
        submitter_name='倉敷紡績株式会社',
        submitter_name_en='KURABO INDUSTRIES LTD.',
        submitter_name_yomi='クラシキボウセキカブシキガイシャ',
        address='倉敷市本町７番１号',
        industry='繊維製品',
        sec_code='31060',
        corporate_number='4260001013120',
    ),
    'E00529': EdinetCodeEntry(
        edinet_code='E00529',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21696,
        fiscal_year_end='3月31日',
        submitter_name='ダイワボウホールディングス株式会社',
        submitter_name_en='Daiwabo Holdings Co.,Ltd.',
        submitter_name_yomi='ダイワボウホールディングスカブシキガイシャ',
        address='大阪市北区中之島３丁目２番４号（中之島フェスティバルタワー・ウェスト２８階）',
        industry='卸売業',
        sec_code='31070',
        corporate_number='7120001077473',
    ),
    'E00530': EdinetCodeEntry(
        edinet_code='E00530',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11820,
        fiscal_year_end='3月31日',
        submitter_name='シキボウ株式会社',
        submitter_name_en='SHIKIBO LTD.',
        submitter_name_yomi='シキボウカブシキガイシャ',
        address='大阪市中央区備後町３丁目２番６号',
        industry='繊維製品',
        sec_code='31090',
        corporate_number='7120001077432',
    ),
    'E00531': EdinetCodeEntry(
        edinet_code='E00531',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='オーミケンシ株式会社',
        submitter_name_en='OMIKENSHI CO.,LTD.',
        submitter_name_yomi='オーミケンシカブシキガイシャ',
        address='大阪市中央区南本町四丁目１番１号',
        industry='繊維製品',
        sec_code='31110',
        corporate_number='9120001077372',
    ),
    'E00534': EdinetCodeEntry(
        edinet_code='E00534',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1402,
        fiscal_year_end='3月31日',
        submitter_name='サイボー株式会社',
        submitter_name_en='SAIBO Co.,Ltd.',
        submitter_name_yomi='サイボーカブシキガイシャ',
        address='川口市前川１丁目１番７０号',
        industry='繊維製品',
        sec_code='31230',
        corporate_number='7030001075016',
    ),
    'E00536': EdinetCodeEntry(
        edinet_code='E00536',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=731,
        fiscal_year_end=None,
        submitter_name='新内外綿株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンナイガイメンカブシキガイシャ',
        address='大阪市中央区備後町三丁目２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001082007',
    ),
    'E00540': EdinetCodeEntry(
        edinet_code='E00540',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8400,
        fiscal_year_end='3月31日',
        submitter_name='トヨタ紡織株式会社',
        submitter_name_en='TOYOTA BOSHOKU CORPORATION',
        submitter_name_yomi='トヨタボウショクカブシキガイシャ',
        address='刈谷市豊田町１丁目１番地',
        industry='輸送用機器',
        sec_code='31160',
        corporate_number='2180301014324',
    ),
    'E00541': EdinetCodeEntry(
        edinet_code='E00541',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4787,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＵＮＩＶＡ・Ｏａｋホールディングス',
        submitter_name_en='UNIVA Oak Holdings Limited',
        submitter_name_yomi='カブシキガイシャユニヴァオークホールディングス',
        address='港区虎ノ門一丁目３番１号',
        industry='証券、商品先物取引業',
        sec_code='31130',
        corporate_number='3010401054921',
    ),
    'E00542': EdinetCodeEntry(
        edinet_code='E00542',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19699,
        fiscal_year_end='3月31日',
        submitter_name='日東紡績株式会社',
        submitter_name_en='NITTO BOSEKI CO.,LTD.',
        submitter_name_yomi='ニットウボウセキカブシキガイシャ',
        address='福島市郷野目字東１番地',
        industry='ガラス・土石製品',
        sec_code='31100',
        corporate_number='4380001001146',
    ),
    'E00543': EdinetCodeEntry(
        edinet_code='E00543',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6673,
        fiscal_year_end='3月31日',
        submitter_name='富士紡ホールディングス株式会社',
        submitter_name_en='Fujibo Holdings, Inc.',
        submitter_name_yomi='フジボウホールディングスカブシキガイシャ',
        address='中央区日本橋人形町一丁目１８番１２号',
        industry='繊維製品',
        sec_code='31040',
        corporate_number='3010001034927',
    ),
    'E00544': EdinetCodeEntry(
        edinet_code='E00544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27841,
        fiscal_year_end='12月31日',
        submitter_name='日清紡ホールディングス株式会社',
        submitter_name_en='Nisshinbo Holdings Inc.',
        submitter_name_yomi='ニッシンボウホールディングスカブシキガイシャ',
        address='中央区日本橋人形町二丁目３１番１１号',
        industry='電気機器',
        sec_code='31050',
        corporate_number='6010001034882',
    ),
    'E00545': EdinetCodeEntry(
        edinet_code='E00545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3190,
        fiscal_year_end='10月31日',
        submitter_name='マーチャント・バンカーズ株式会社',
        submitter_name_en='MBK Co.,Ltd.',
        submitter_name_yomi='マーチャントバンカーズカブシキガイシャ',
        address='港区西麻布三丁目３番１号',
        industry='サービス業',
        sec_code='31210',
        corporate_number='7010001101599',
    ),
    'E00547': EdinetCodeEntry(
        edinet_code='E00547',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ダイトウボウ株式会社',
        submitter_name_en='Daitobo Co., Ltd.',
        submitter_name_yomi='ダイトウボウカブシキガイシャ',
        address='中央区日本橋本町一丁目６番１号',
        industry='繊維製品',
        sec_code='32020',
        corporate_number='7010001034832',
    ),
    'E00550': EdinetCodeEntry(
        edinet_code='E00550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6891,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイドーリミテッド',
        submitter_name_en='DAIDOH LIMITED',
        submitter_name_yomi='カブシキガイシャダイドーリミテッド',
        address='千代田区外神田３－１－１６',
        industry='繊維製品',
        sec_code='32050',
        corporate_number='4010001008715',
    ),
    'E00551': EdinetCodeEntry(
        edinet_code='E00551',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=703,
        fiscal_year_end=None,
        submitter_name='カネヨウ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カネヨウカブシキガイシャ',
        address='大阪市中央区久太郎町４丁目１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001077387',
    ),
    'E00552': EdinetCodeEntry(
        edinet_code='E00552',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6465,
        fiscal_year_end='11月30日',
        submitter_name='日本毛織株式会社',
        submitter_name_en='THE JAPAN WOOL TEXTILE CO., LTD.',
        submitter_name_yomi='ニッポンケオリカブシキカイシャ',
        address='神戸市中央区明石町４７番地',
        industry='繊維製品',
        sec_code='32010',
        corporate_number='2140001012193',
    ),
    'E00555': EdinetCodeEntry(
        edinet_code='E00555',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='太陽毛絲紡績株式会社',
        submitter_name_en='TAIYO WOOLEN SPINNING Co.,Ltd',
        submitter_name_yomi='タイヨウケイトボウセキカブシキガイシャ',
        address='川口市上青木五丁目５番地９号',
        industry='繊維製品',
        sec_code=None,
        corporate_number='3030001075837',
    ),
    'E00556': EdinetCodeEntry(
        edinet_code='E00556',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3940,
        fiscal_year_end='12月31日',
        submitter_name='株式会社トーア紡コーポレーション',
        submitter_name_en='Toabo Corporation',
        submitter_name_yomi='カブシキガイシャトーアボウコーポレーション',
        address='大阪市中央区城見一丁目２番２７号クリスタルタワー１８階',
        industry='繊維製品',
        sec_code='32040',
        corporate_number='2120001104579',
    ),
    'E00558': EdinetCodeEntry(
        edinet_code='E00558',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=301,
        fiscal_year_end='3月31日',
        submitter_name='日本製麻株式会社',
        submitter_name_en='THE NIHON SEIMA CO.,LTD',
        submitter_name_yomi='ニホンセイマカブシキガイシャ',
        address='砺波市下中３番地３',
        industry='卸売業',
        sec_code='33060',
        corporate_number='6230001008369',
    ),
    'E00559': EdinetCodeEntry(
        edinet_code='E00559',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1689,
        fiscal_year_end='12月31日',
        submitter_name='帝国繊維株式会社',
        submitter_name_en='TEIKOKU SEN-I Co.,Ltd.',
        submitter_name_yomi='テイコクセンイカブシキガイシャ',
        address='中央区日本橋二丁目５番１号',
        industry='繊維製品',
        sec_code='33020',
        corporate_number='7010001034840',
    ),
    'E00562': EdinetCodeEntry(
        edinet_code='E00562',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17514,
        fiscal_year_end='3月31日',
        submitter_name='セーレン株式会社',
        submitter_name_en='seiren co.,ltd.',
        submitter_name_yomi='セーレンカブシキガイシャ',
        address='福井市毛矢１丁目１０番１号',
        industry='繊維製品',
        sec_code='35690',
        corporate_number='9210001001785',
    ),
    'E00563': EdinetCodeEntry(
        edinet_code='E00563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4300,
        fiscal_year_end='3月31日',
        submitter_name='東海染工株式会社',
        submitter_name_en='Tokai Senko K.K.',
        submitter_name_yomi='トウカイセンコウカブシキガイシャ',
        address='清須市西枇杷島町子新田１番地の２',
        industry='繊維製品',
        sec_code='35770',
        corporate_number='6180001031533',
    ),
    'E00565': EdinetCodeEntry(
        edinet_code='E00565',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4655,
        fiscal_year_end='3月31日',
        submitter_name='サカイオーベックス株式会社',
        submitter_name_en='SAKAIOVEX  CO.,LTD.',
        submitter_name_yomi='サカイオーベックスカブシキガイシャ',
        address='福井市花堂中２丁目１５番１号',
        industry='繊維製品',
        sec_code=None,
        corporate_number='4210001001352',
    ),
    'E00566': EdinetCodeEntry(
        edinet_code='E00566',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1379,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北紡',
        submitter_name_en='KITABO CO.,Ltd',
        submitter_name_yomi='カブシキガイシャキタボウ',
        address='白山市福留町２０１番地１',
        industry='繊維製品',
        sec_code='34090',
        corporate_number='5220001002217',
    ),
    'E00567': EdinetCodeEntry(
        edinet_code='E00567',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='アツギ株式会社',
        submitter_name_en='ATSUGI  CO., LTD.',
        submitter_name_yomi='アツギカブシキガイシャ',
        address='海老名市大谷北一丁目３番２号',
        industry='繊維製品',
        sec_code='35290',
        corporate_number='4021001026648',
    ),
    'E00568': EdinetCodeEntry(
        edinet_code='E00568',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミライノベート',
        submitter_name_en='Mirainovate Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャミライノベート',
        address='品川区西五反田七丁目１７番７号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6011001005923',
    ),
    'E00569': EdinetCodeEntry(
        edinet_code='E00569',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソトー',
        submitter_name_en='SOTOHCO.,LTD.',
        submitter_name_yomi='カブシキガイシャソトー',
        address='一宮市篭屋五丁目１番１号',
        industry='繊維製品',
        sec_code='35710',
        corporate_number='8180001084265',
    ),
    'E00570': EdinetCodeEntry(
        edinet_code='E00570',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6354,
        fiscal_year_end='3月31日',
        submitter_name='ニチモウ株式会社',
        submitter_name_en='NICHIMO CO.,LTD.',
        submitter_name_yomi='ニチモウカブシキガイシャ',
        address='品川区東品川二丁目２番２０号',
        industry='卸売業',
        sec_code='80910',
        corporate_number='7010701011833',
    ),
    'E00571': EdinetCodeEntry(
        edinet_code='E00571',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ナイガイ',
        submitter_name_en='NAIGAI  CO.,LTD.',
        submitter_name_yomi='カブシキガイシャナイガイ',
        address='港区赤坂７丁目８番５号',
        industry='繊維製品',
        sec_code='80130',
        corporate_number='3010501024502',
    ),
    'E00572': EdinetCodeEntry(
        edinet_code='E00572',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3594,
        fiscal_year_end='3月31日',
        submitter_name='イチカワ株式会社',
        submitter_name_en='ICHIKAWA CO., LTD.',
        submitter_name_yomi='イチカワカブシキガイシャ',
        address='文京区本郷二丁目１４番１５号',
        industry='繊維製品',
        sec_code='35130',
        corporate_number='1010001000708',
    ),
    'E00573': EdinetCodeEntry(
        edinet_code='E00573',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2435,
        fiscal_year_end='3月31日',
        submitter_name='日本フエルト株式会社',
        submitter_name_en='NIPPON FELT CO.,LTD.',
        submitter_name_yomi='ニホンフエルトカブシキガイシャ',
        address='北区赤羽西一丁目７番１号',
        industry='繊維製品',
        sec_code='35120',
        corporate_number='4011501003552',
    ),
    'E00574': EdinetCodeEntry(
        edinet_code='E00574',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9554,
        fiscal_year_end='5月31日',
        submitter_name='ＳＵＭＩＮＯＥ株式会社',
        submitter_name_en='SUMINOE Co., Ltd.',
        submitter_name_yomi='スミノエカブシキカイシャ',
        address='大阪市中央区南船場三丁目１１番２０号',
        industry='繊維製品',
        sec_code='35010',
        corporate_number='3120001082312',
    ),
    'E00576': EdinetCodeEntry(
        edinet_code='E00576',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='テルマー湯ホールディングス株式会社',
        submitter_name_en='THERMAE-YU HOLDINGS CO.,LTD.',
        submitter_name_yomi='テルマーユホールディングスカブシキガイシャ',
        address='港区南青山７丁目８番４号\u3000高樹ハイツ',
        industry='不動産業',
        sec_code='35210',
        corporate_number='7010001076098',
    ),
    'E00577': EdinetCodeEntry(
        edinet_code='E00577',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8388,
        fiscal_year_end='3月31日',
        submitter_name='芦森工業株式会社',
        submitter_name_en='Ashimori Industry Co.,Ltd',
        submitter_name_yomi='アシモリコウギョウカブシキガイシャ',
        address='摂津市千里丘７丁目１１番６１号',
        industry='繊維製品',
        sec_code='35260',
        corporate_number='3120001048973',
    ),
    'E00578': EdinetCodeEntry(
        edinet_code='E00578',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1378,
        fiscal_year_end='4月30日',
        submitter_name='日東製網株式会社',
        submitter_name_en='NITTO SEIMO CO., LTD.',
        submitter_name_yomi='ニットウセイモウカブシキガイシャ',
        address='港区新橋二丁目２０番１５‐７０１号新橋駅前ビル',
        industry='繊維製品',
        sec_code='35240',
        corporate_number='3010401022044',
    ),
    'E00584': EdinetCodeEntry(
        edinet_code='E00584',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1939,
        fiscal_year_end='3月31日',
        submitter_name='オーベクス株式会社',
        submitter_name_en='AuBEX CORPORATION',
        submitter_name_yomi='オーベクスカブシキガイシャ',
        address='墨田区両国四丁目３１番１１号',
        industry='繊維製品',
        sec_code='35830',
        corporate_number='6010601009020',
    ),
    'E00585': EdinetCodeEntry(
        edinet_code='E00585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=307,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バナーズ',
        submitter_name_en='BANNERS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000バナーズ',
        address='熊谷市石原一丁目１０２番地',
        industry='小売業',
        sec_code='30110',
        corporate_number='6030001085230',
    ),
    'E00590': EdinetCodeEntry(
        edinet_code='E00590',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13260,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワコールホールディングス',
        submitter_name_en='WACOAL HOLDINGS CORP.',
        submitter_name_yomi='カブシキガイシャワコールホールディングス',
        address='京都市南区吉祥院中島町２９番地',
        industry='繊維製品',
        sec_code='35910',
        corporate_number='5130001012084',
    ),
    'E00591': EdinetCodeEntry(
        edinet_code='E00591',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4680,
        fiscal_year_end='3月31日',
        submitter_name='小松マテーレ株式会社',
        submitter_name_en='KOMATSU MATERE Co., Ltd.',
        submitter_name_yomi='コマツマテーレカブシキガイシャ',
        address='能美市浜町ヌ１６７番地',
        industry='繊維製品',
        sec_code='35800',
        corporate_number='1220001012764',
    ),
    'E00593': EdinetCodeEntry(
        edinet_code='E00593',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15002,
        fiscal_year_end='2月末日',
        submitter_name='株式会社三陽商会',
        submitter_name_en='SANYO SHOKAI LTD.',
        submitter_name_yomi='カブシキガイシャサンヨウショウカイ',
        address='新宿区四谷本塩町６番１４号',
        industry='繊維製品',
        sec_code='80110',
        corporate_number='1010401075845',
    ),
    'E00596': EdinetCodeEntry(
        edinet_code='E00596',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=506,
        fiscal_year_end='3月31日',
        submitter_name='倉庫精練株式会社',
        submitter_name_en='SOKO SEIREN CO.,LTD.',
        submitter_name_yomi='ソウコセイレンカブシキガイシャ',
        address='金沢市古府町南４５９番地',
        industry='繊維製品',
        sec_code=None,
        corporate_number='6220001003750',
    ),
    'E00598': EdinetCodeEntry(
        edinet_code='E00598',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='岐セン株式会社',
        submitter_name_en='GISEN CO.,LTD.',
        submitter_name_yomi='ギセンカブシキガイシャ',
        address='瑞穂市牛牧７５８番地',
        industry='繊維製品',
        sec_code=None,
        corporate_number='4200001010379',
    ),
    'E00600': EdinetCodeEntry(
        edinet_code='E00600',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4917,
        fiscal_year_end='8月31日',
        submitter_name='ヤマトインターナショナル株式会社',
        submitter_name_en='YAMATOINTERNATIONALINC.',
        submitter_name_yomi='ヤマトインターナショナルカブシキガイシャ',
        address='大阪市中央区博労町二丁目３番９号',
        industry='繊維製品',
        sec_code='81270',
        corporate_number='3120001077584',
    ),
    'E00601': EdinetCodeEntry(
        edinet_code='E00601',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3846,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デサント',
        submitter_name_en='DESCENTE,LTD.',
        submitter_name_yomi='カブシキガイシャデサント',
        address='大阪市浪速区湊１丁目２番３号マルイト難波ビル１３階',
        industry='繊維製品',
        sec_code=None,
        corporate_number='6120001024419',
    ),
    'E00603': EdinetCodeEntry(
        edinet_code='E00603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7079,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゴールドウイン',
        submitter_name_en='GOLDWIN INC.',
        submitter_name_yomi='カブシキガイシャゴールドウイン',
        address='小矢部市清沢２１０番地',
        industry='繊維製品',
        sec_code='81110',
        corporate_number='3230001008974',
    ),
    'E00604': EdinetCodeEntry(
        edinet_code='E00604',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6447,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ルックホールディングス',
        submitter_name_en='LOOK HOLDINGS INCORPORATED',
        submitter_name_yomi='カブシキガイシャ\u3000ルックホールディングス',
        address='港区赤坂八丁目５番３０号',
        industry='繊維製品',
        sec_code='80290',
        corporate_number='5013201006462',
    ),
    'E00605': EdinetCodeEntry(
        edinet_code='E00605',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ラピーヌ',
        submitter_name_en='LAPINE CO.,LTD',
        submitter_name_yomi='カブシキガイシャラピーヌ',
        address='千代田区神田東松下町１７番地',
        industry='繊維製品',
        sec_code='81430',
        corporate_number='3120001071942',
    ),
    'E00607': EdinetCodeEntry(
        edinet_code='E00607',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2982,
        fiscal_year_end='6月30日',
        submitter_name='株式会社自重堂',
        submitter_name_en='JICHODO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャジチョウドウ',
        address='福山市新市町大字戸手１６番地の２',
        industry='繊維製品',
        sec_code='35970',
        corporate_number='1240001033610',
    ),
    'E00609': EdinetCodeEntry(
        edinet_code='E00609',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6491,
        fiscal_year_end='3月31日',
        submitter_name='ＭＲＫホールディングス株式会社',
        submitter_name_en='MRK HOLDINGS INC.',
        submitter_name_yomi='エムアールケイホールディングスカブシキガイシャ',
        address='大阪市北区大淀中一丁目１番３０号',
        industry='小売業',
        sec_code='99800',
        corporate_number='1120001120362',
    ),
    'E00610': EdinetCodeEntry(
        edinet_code='E00610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=923,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジックス',
        submitter_name_en='FUJIX Ltd.',
        submitter_name_yomi='カブシキガイシャフジックス',
        address='京都市北区平野宮本町５番地',
        industry='繊維製品',
        sec_code='36000',
        corporate_number='5130001005385',
    ),
    'E00612': EdinetCodeEntry(
        edinet_code='E00612',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1716,
        fiscal_year_end=None,
        submitter_name='株式会社フジコー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジコー',
        address='伊丹市行基町１丁目５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001078870',
    ),
    'E00614': EdinetCodeEntry(
        edinet_code='E00614',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=883,
        fiscal_year_end='3月末日',
        submitter_name='川本産業株式会社',
        submitter_name_en='KAWAMOTO CORPORATION',
        submitter_name_yomi='カワモトサンギョウカブシキガイシャ',
        address='大阪市中央区谷町二丁目６番４号',
        industry='繊維製品',
        sec_code=None,
        corporate_number='9120001077174',
    ),
    'E00616': EdinetCodeEntry(
        edinet_code='E00616',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=18471,
        fiscal_year_end='12月末日',
        submitter_name='株式会社レナウン',
        submitter_name_en='RENOWN INCORPORATED',
        submitter_name_yomi='カブシキガイシャレナウン',
        address='江東区有明三丁目６番１１号ＴＦＴビル東館６階',
        industry='繊維製品',
        sec_code=None,
        corporate_number='6010701015232',
    ),
    'E00617': EdinetCodeEntry(
        edinet_code='E00617',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='8月31日',
        submitter_name='株式会社クラウディアホールディングス',
        submitter_name_en='KURAUDIA HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクラウディアホールディングス',
        address='京都市右京区西院高田町３４番地',
        industry='繊維製品',
        sec_code='36070',
        corporate_number='9130001000639',
    ),
    'E00619': EdinetCodeEntry(
        edinet_code='E00619',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15300,
        fiscal_year_end='3月31日',
        submitter_name='ＤＡＩＫＥＮ株式会社',
        submitter_name_en='DAIKEN CORPORATION',
        submitter_name_yomi='ダイケンカブシキガイシャ',
        address='南砺市井波１番地１',
        industry='その他製品',
        sec_code=None,
        corporate_number='7230001008590',
    ),
    'E00621': EdinetCodeEntry(
        edinet_code='E00621',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3325,
        fiscal_year_end='3月31日',
        submitter_name='兼松サステック株式会社',
        submitter_name_en='KANEMATSU SUSTECH CORPORATION',
        submitter_name_yomi='カネマツサステックカブシキガイシャ',
        address='中央区日本橋浜町三丁目３番２号',
        industry='その他製品',
        sec_code=None,
        corporate_number='8010001083713',
    ),
    'E00623': EdinetCodeEntry(
        edinet_code='E00623',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=207,
        fiscal_year_end=None,
        submitter_name='大日本木材防腐株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイニホンモクザイボウフカブシキガイシャ',
        address='名古屋市港区千鳥一丁目３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001006717',
    ),
    'E00624': EdinetCodeEntry(
        edinet_code='E00624',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28375,
        fiscal_year_end=None,
        submitter_name='パナホーム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パナホームカブシキガイシャ',
        address='豊中市新千里西町１丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120901024972',
    ),
    'E00628': EdinetCodeEntry(
        edinet_code='E00628',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='名古屋木材株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナゴヤモクザイカブシキガイシャ',
        address='名古屋市中川区山王二丁目６番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001020450',
    ),
    'E00630': EdinetCodeEntry(
        edinet_code='E00630',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7324,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウッドワン',
        submitter_name_en='WOOD ONE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャウッドワン',
        address='廿日市市木材港南１番１号',
        industry='その他製品',
        sec_code='78980',
        corporate_number='4240001027972',
    ),
    'E00631': EdinetCodeEntry(
        edinet_code='E00631',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3285,
        fiscal_year_end='3月31日',
        submitter_name='永大産業株式会社',
        submitter_name_en='Eidai Co.,Ltd.',
        submitter_name_yomi='エイダイサンギョウカブシキガイシャ',
        address='大阪市住之江区平林南２丁目１０番６０号',
        industry='その他製品',
        sec_code='78220',
        corporate_number='7120001030374',
    ),
    'E00632': EdinetCodeEntry(
        edinet_code='E00632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2343,
        fiscal_year_end='3月31日',
        submitter_name='ホクシン株式会社',
        submitter_name_en='HOKUSHIN CO.,LTD.',
        submitter_name_yomi='ホクシンカブシキガイシャ',
        address='岸和田市木材町１７番地２',
        industry='その他製品',
        sec_code='78970',
        corporate_number='5120101037593',
    ),
    'E00633': EdinetCodeEntry(
        edinet_code='E00633',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2473,
        fiscal_year_end='3月31日',
        submitter_name='セブン工業株式会社',
        submitter_name_en='SEVEN INDUSTRIES CO.,LTD.',
        submitter_name_yomi='セブンコウギョウカブシキガイシャ',
        address='美濃加茂市牧野１００６番地',
        industry='その他製品',
        sec_code='78960',
        corporate_number='1200001017170',
    ),
    'E00635': EdinetCodeEntry(
        edinet_code='E00635',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2121,
        fiscal_year_end='3月31日',
        submitter_name='南海プライウッド株式会社',
        submitter_name_en='NANKAI PLYWOOD CO.,LTD',
        submitter_name_yomi='ナンカイプライウッドカブシキガイシャ',
        address='高松市松福町一丁目１５番１０号',
        industry='その他製品',
        sec_code='78870',
        corporate_number='9470001003062',
    ),
    'E00636': EdinetCodeEntry(
        edinet_code='E00636',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2141,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ノダ',
        submitter_name_en='NODA CORPORATION',
        submitter_name_yomi='カブシキガイシャノダ',
        address='台東区浅草橋５－１３－６',
        industry='その他製品',
        sec_code='78790',
        corporate_number='6010501010276',
    ),
    'E00639': EdinetCodeEntry(
        edinet_code='E00639',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=684,
        fiscal_year_end='10月31日',
        submitter_name='株式会社オービス',
        submitter_name_en='ORVIS CORPORATION',
        submitter_name_yomi='カブシキガイシャオービス',
        address='福山市松永町六丁目１０番１号',
        industry='その他製品',
        sec_code='78270',
        corporate_number='1240001030054',
    ),
    'E00640': EdinetCodeEntry(
        edinet_code='E00640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1117,
        fiscal_year_end='3月31日',
        submitter_name='ニホンフラッシュ株式会社',
        submitter_name_en='NIHON FLUSH CO.,LTD.',
        submitter_name_yomi='ニホンフラッシュカブシキガイシャ',
        address='小松島市横須町５番２６号',
        industry='その他製品',
        sec_code='78200',
        corporate_number='8480001003475',
    ),
    'E00642': EdinetCodeEntry(
        edinet_code='E00642',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=103880,
        fiscal_year_end='3月31日',
        submitter_name='王子ホールディングス株式会社',
        submitter_name_en='Oji Holdings Corporation',
        submitter_name_yomi='オウジホールディングスカブシキガイシャ',
        address='中央区銀座四丁目７番５号',
        industry='パルプ・紙',
        sec_code='38610',
        corporate_number='5010001034743',
    ),
    'E00644': EdinetCodeEntry(
        edinet_code='E00644',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36561,
        fiscal_year_end='3月31日',
        submitter_name='三菱製紙株式会社',
        submitter_name_en='MITSUBISHI PAPER MILLS LIMITED',
        submitter_name_yomi='ミツビシセイシカブシキガイシャ',
        address='墨田区両国二丁目１０番１４号',
        industry='パルプ・紙',
        sec_code='38640',
        corporate_number='8010001008769',
    ),
    'E00645': EdinetCodeEntry(
        edinet_code='E00645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=42020,
        fiscal_year_end='3月31日',
        submitter_name='北越コーポレーション株式会社',
        submitter_name_en='Hokuetsu Corporation',
        submitter_name_yomi='ホクエツコーポレーションカブシキガイシャ',
        address='長岡市西蔵王三丁目５番１号',
        industry='パルプ・紙',
        sec_code='38650',
        corporate_number='6110001023149',
    ),
    'E00649': EdinetCodeEntry(
        edinet_code='E00649',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18864,
        fiscal_year_end='3月31日',
        submitter_name='中越パルプ工業株式会社',
        submitter_name_en='Chuetsu Pulp & Paper Co.,Ltd.',
        submitter_name_yomi='チュウエツパルプコウギョウカブシキガイシャ',
        address='中央区銀座二丁目１０番６号',
        industry='パルプ・紙',
        sec_code='38770',
        corporate_number='3010001034877',
    ),
    'E00650': EdinetCodeEntry(
        edinet_code='E00650',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2122,
        fiscal_year_end='3月31日',
        submitter_name='株式会社巴川コーポレーション',
        submitter_name_en='TOMOEGAWA CORPORATION',
        submitter_name_yomi='カブシキガイシャトモエガワコーポレーション',
        address='中央区京橋二丁目１番３号',
        industry='パルプ・紙',
        sec_code='38780',
        corporate_number='9010001034871',
    ),
    'E00652': EdinetCodeEntry(
        edinet_code='E00652',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1570,
        fiscal_year_end='3月31日',
        submitter_name='野崎印刷紙業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノザキインサツシギョウカブシキガイシャ',
        address='京都市北区小山下総町５４番地の５',
        industry='その他製品',
        sec_code='79190',
        corporate_number='8130001005275',
    ),
    'E00659': EdinetCodeEntry(
        edinet_code='E00659',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31066,
        fiscal_year_end='3月31日',
        submitter_name='レンゴー株式会社',
        submitter_name_en='Rengo Co., Ltd.',
        submitter_name_yomi='レンゴーカブシキガイシャ',
        address='大阪市福島区大開４丁目１番１８６号（上記の住所は登記上のものであり、実際の業務は下記の場所で行っている。）大阪市北区中之島２丁目２番７号\u3000中之島セントラルタワー',
        industry='パルプ・紙',
        sec_code='39410',
        corporate_number='1120001036880',
    ),
    'E00660': EdinetCodeEntry(
        edinet_code='E00660',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=53884,
        fiscal_year_end='3月31日',
        submitter_name='大王製紙株式会社',
        submitter_name_en='Daio Paper Corporation',
        submitter_name_yomi='ダイオウセイシカブシキガイシャ',
        address='四国中央市三島紙屋町２番６０号',
        industry='パルプ・紙',
        sec_code='38800',
        corporate_number='9500001014345',
    ),
    'E00664': EdinetCodeEntry(
        edinet_code='E00664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2151,
        fiscal_year_end='12月31日',
        submitter_name='古林紙工株式会社',
        submitter_name_en='FURUBAYASHI SHIKO CO.,LTD.',
        submitter_name_yomi='フルバヤシシコウカブシキガイシャ',
        address='大阪市中央区大手通三丁目１番１２号',
        industry='パルプ・紙',
        sec_code='39440',
        corporate_number='6120001088901',
    ),
    'E00667': EdinetCodeEntry(
        edinet_code='E00667',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1830,
        fiscal_year_end='2月末日',
        submitter_name='株式会社リヒトラブ',
        submitter_name_en='LIHIT LAB.,INC.',
        submitter_name_yomi='カブシキガイシャリヒトラブ',
        address='大阪市中央区農人橋１丁目１番２２号',
        industry='その他製品',
        sec_code='79750',
        corporate_number='1120001077594',
    ),
    'E00668': EdinetCodeEntry(
        edinet_code='E00668',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4000,
        fiscal_year_end='12月31日',
        submitter_name='ダイナパック株式会社',
        submitter_name_en='Dynapac Co., Ltd.',
        submitter_name_yomi='ダイナパックカブシキガイシャ',
        address='名古屋市中区錦三丁目１４番１５号',
        industry='パルプ・紙',
        sec_code='39470',
        corporate_number='1180001037535',
    ),
    'E00669': EdinetCodeEntry(
        edinet_code='E00669',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13669,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーモク',
        submitter_name_en='TOMOKU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトーモク',
        address='千代田区丸の内２－２－２丸の内三井ビル４階',
        industry='パルプ・紙',
        sec_code='39460',
        corporate_number='7010001024692',
    ),
    'E00670': EdinetCodeEntry(
        edinet_code='E00670',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15847,
        fiscal_year_end='12月31日',
        submitter_name='コクヨ株式会社',
        submitter_name_en='KOKUYO CO.,LTD.',
        submitter_name_yomi='コクヨカブシキガイシャ',
        address='大阪市東成区大今里南６丁目１番１号',
        industry='その他製品',
        sec_code='79840',
        corporate_number='6120001012282',
    ),
    'E00674': EdinetCodeEntry(
        edinet_code='E00674',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2553,
        fiscal_year_end='12月31日',
        submitter_name='ザ・パック株式会社',
        submitter_name_en='THE PACK CORPORATION',
        submitter_name_yomi='ザパックカブシキカイシャ',
        address='大阪市東成区東小橋２丁目９番３号',
        industry='パルプ・紙',
        sec_code='39500',
        corporate_number='5120001012382',
    ),
    'E00675': EdinetCodeEntry(
        edinet_code='E00675',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1375,
        fiscal_year_end='3月31日',
        submitter_name='スーパーバッグ株式会社',
        submitter_name_en='Superbag Company,Limited',
        submitter_name_yomi='スーパーバッグカブシキガイシャ',
        address='豊島区西池袋５丁目１８番１１号',
        industry='パルプ・紙',
        sec_code='39450',
        corporate_number='8013301005766',
    ),
    'E00677': EdinetCodeEntry(
        edinet_code='E00677',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=466,
        fiscal_year_end='3月31日',
        submitter_name='大石産業株式会社',
        submitter_name_en='OHISHI SANGYO CO.,LTD.',
        submitter_name_yomi='オオイシサンギョウカブシキガイシャ',
        address='北九州市八幡東区桃園二丁目７番１号',
        industry='パルプ・紙',
        sec_code='39430',
        corporate_number='9290801009087',
    ),
    'E00678': EdinetCodeEntry(
        edinet_code='E00678',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15992,
        fiscal_year_end='12月31日',
        submitter_name='ユニ・チャーム株式会社',
        submitter_name_en='UNICHARM CORPORATION',
        submitter_name_yomi='ユニチャームカブシキガイシャ',
        address='四国中央市金生町下分１８２番地',
        industry='化学',
        sec_code='81130',
        corporate_number='8500001014833',
    ),
    'E00679': EdinetCodeEntry(
        edinet_code='E00679',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6666,
        fiscal_year_end='3月31日',
        submitter_name='ナカバヤシ株式会社',
        submitter_name_en='NAKABAYASHI CO.,LTD.',
        submitter_name_yomi='ナカバヤシカブシキガイシャ',
        address='大阪市中央区北浜東１番２０号',
        industry='その他製品',
        sec_code='79870',
        corporate_number='4120001086023',
    ),
    'E00681': EdinetCodeEntry(
        edinet_code='E00681',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1077,
        fiscal_year_end='3月31日',
        submitter_name='中央紙器工業株式会社',
        submitter_name_en='CHUOH PACK INDUSTRY CO.,LTD.',
        submitter_name_yomi='チュウオウシキコウギョウカブシキガイシャ',
        address='清須市春日宮重町３６３番地',
        industry='パルプ・紙',
        sec_code=None,
        corporate_number='1180001045224',
    ),
    'E00682': EdinetCodeEntry(
        edinet_code='E00682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=554,
        fiscal_year_end='3月31日',
        submitter_name='大村紙業株式会社',
        submitter_name_en='OHMURA SHIGYO CO.,LTD',
        submitter_name_yomi='オオムラシギョウカブシキガイシャ',
        address='茅ヶ崎市甘沼１６３の１',
        industry='パルプ・紙',
        sec_code='39530',
        corporate_number='8021001006662',
    ),
    'E00685': EdinetCodeEntry(
        edinet_code='E00685',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2241,
        fiscal_year_end='3月31日',
        submitter_name='ニッポン高度紙工業株式会社',
        submitter_name_en='NIPPON KODOSHI CORPORATION',
        submitter_name_yomi='ニッポンコウドシコウギョウカブシキガイシャ',
        address='高知市春野町弘岡上６４８番地',
        industry='パルプ・紙',
        sec_code='38910',
        corporate_number='2490001001698',
    ),
    'E00686': EdinetCodeEntry(
        edinet_code='E00686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=640,
        fiscal_year_end='3月31日',
        submitter_name='昭和パックス株式会社',
        submitter_name_en='SHOWA PAXXS CORPORATION',
        submitter_name_yomi='ショウワパックスカブシキカイシャ',
        address='新宿区市谷本村町２－１２',
        industry='パルプ・紙',
        sec_code='39540',
        corporate_number='9011101009961',
    ),
    'E00687': EdinetCodeEntry(
        edinet_code='E00687',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=821,
        fiscal_year_end='5月31日',
        submitter_name='株式会社岡山製紙',
        submitter_name_en='Okayama Paper Industries Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000オカヤマセイシ',
        address='岡山市浜野１丁目４番３４号',
        industry='パルプ・紙',
        sec_code='38920',
        corporate_number='1260001001078',
    ),
    'E00688': EdinetCodeEntry(
        edinet_code='E00688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1197,
        fiscal_year_end='1月31日',
        submitter_name='株式会社イムラ',
        submitter_name_en='IMURA & Co., Ltd.',
        submitter_name_yomi='カブシキガイシャイムラ',
        address='大阪市中央区難波五丁目１番６０号',
        industry='パルプ・紙',
        sec_code='39550',
        corporate_number='1120001074740',
    ),
    'E00690': EdinetCodeEntry(
        edinet_code='E00690',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=593,
        fiscal_year_end='3月31日',
        submitter_name='ハビックス株式会社',
        submitter_name_en='HAVIX CORPORATION',
        submitter_name_yomi='ハビックスカブシキガイシャ',
        address='岐阜市福光東三丁目５番７号',
        industry='パルプ・紙',
        sec_code='38950',
        corporate_number='6200001004239',
    ),
    'E00691': EdinetCodeEntry(
        edinet_code='E00691',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11485,
        fiscal_year_end='3月31日',
        submitter_name='特種東海製紙株式会社',
        submitter_name_en='Tokushu Tokai Paper Co.,Ltd.',
        submitter_name_yomi='トクシュトウカイセイシカブシキガイシャ',
        address='島田市向島町４３７９番地',
        industry='パルプ・紙',
        sec_code='37080',
        corporate_number='3080001014336',
    ),
    'E00692': EdinetCodeEntry(
        edinet_code='E00692',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=104986,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＰＰＡＮホールディングス株式会社',
        submitter_name_en='TOPPAN Holdings Inc.',
        submitter_name_yomi='トッパンホールディングスカブシキガイシャ',
        address='台東区台東一丁目５番１号',
        industry='その他製品',
        sec_code='79110',
        corporate_number='7010501016231',
    ),
    'E00693': EdinetCodeEntry(
        edinet_code='E00693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=114464,
        fiscal_year_end='3月31日',
        submitter_name='大日本印刷株式会社',
        submitter_name_en='Dai Nippon Printing Co.,Ltd.',
        submitter_name_yomi='ダイニッポンインサツカブシキガイシャ',
        address='新宿区市谷加賀町一丁目１番１号',
        industry='その他製品',
        sec_code='79120',
        corporate_number='5011101012069',
    ),
    'E00694': EdinetCodeEntry(
        edinet_code='E00694',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13898,
        fiscal_year_end='3月31日',
        submitter_name='図書印刷株式会社',
        submitter_name_en='Tosho Printing Company,Limited',
        submitter_name_yomi='トショインサツカブシキガイシャ',
        address='北区東十条三丁目１０番３６号',
        industry='その他製品',
        sec_code=None,
        corporate_number='4011501015399',
    ),
    'E00695': EdinetCodeEntry(
        edinet_code='E00695',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4510,
        fiscal_year_end='3月31日',
        submitter_name='共同印刷株式会社',
        submitter_name_en='Kyodo Printing Co., Ltd.',
        submitter_name_yomi='キョウドウインサツカブシキガイシャ',
        address='文京区小石川四丁目１４番１２号',
        industry='その他製品',
        sec_code='79140',
        corporate_number='8010001002136',
    ),
    'E00696': EdinetCodeEntry(
        edinet_code='E00696',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5607,
        fiscal_year_end='3月31日',
        submitter_name='光村印刷株式会社',
        submitter_name_en='MITSUMURA PRINTING CO.,LTD.',
        submitter_name_yomi='ミツムラインサツカブシキガイシャ',
        address='品川区大崎一丁目１５番９号',
        industry='その他製品',
        sec_code='79160',
        corporate_number='4010701009442',
    ),
    'E00697': EdinetCodeEntry(
        edinet_code='E00697',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社西日本新聞社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシヤニシニツポンシンブンシヤ',
        address='福岡市中央区天神一丁目４番１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='8290001009392',
    ),
    'E00698': EdinetCodeEntry(
        edinet_code='E00698',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='11月30日',
        submitter_name='株式会社神戸新聞社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウベシンブンシャ',
        address='神戸市中央区東川崎町一丁目５番７号',
        industry='その他製品',
        sec_code=None,
        corporate_number='1140001012021',
    ),
    'E00699': EdinetCodeEntry(
        edinet_code='E00699',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社東洋経済新報社',
        submitter_name_en='TOYO KEIZAI INC.',
        submitter_name_yomi='カブシキガイシャトウヨウケイザイシンポウシャ',
        address='中央区日本橋本石町一丁目２番１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='1010001051874',
    ),
    'E00701': EdinetCodeEntry(
        edinet_code='E00701',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社岩手日報社',
        submitter_name_en='THE IWATE NIPPO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイワテニッポウシャ',
        address='盛岡市内丸３番７号',
        industry='その他製品',
        sec_code=None,
        corporate_number='9400001000207',
    ),
    'E00703': EdinetCodeEntry(
        edinet_code='E00703',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12119,
        fiscal_year_end='12月31日',
        submitter_name='ＮＩＳＳＨＡ株式会社',
        submitter_name_en='Nissha Co., Ltd.',
        submitter_name_yomi='ニッシャカブシキガイシャ',
        address='京都市中京区壬生花井町３番地',
        industry='その他製品',
        sec_code='79150',
        corporate_number='9130001023441',
    ),
    'E00704': EdinetCodeEntry(
        edinet_code='E00704',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2524,
        fiscal_year_end='3月31日',
        submitter_name='三浦印刷株式会社',
        submitter_name_en='MIURA PRINTING CORPORATION',
        submitter_name_yomi='ミウラインサツカブシキガイシャ',
        address='墨田区千歳二丁目３番９号',
        industry='その他製品',
        sec_code=None,
        corporate_number='6010601015695',
    ),
    'E00705': EdinetCodeEntry(
        edinet_code='E00705',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4935,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヴィア・ホールディングス',
        submitter_name_en='VIA Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャヴィアホールディングス',
        address='新宿区早稲田鶴巻町５１９',
        industry='小売業',
        sec_code='79180',
        corporate_number='6010001000249',
    ),
    'E00707': EdinetCodeEntry(
        edinet_code='E00707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19817,
        fiscal_year_end='9月30日',
        submitter_name='株式会社学研ホールディングス',
        submitter_name_en='GAKKEN  HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャガッケンホールディングス',
        address='品川区西五反田二丁目１１番８号',
        industry='情報・通信業',
        sec_code='94700',
        corporate_number='7010701021114',
    ),
    'E00708': EdinetCodeEntry(
        edinet_code='E00708',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=798,
        fiscal_year_end='12月31日',
        submitter_name='光ビジネスフォーム株式会社',
        submitter_name_en='HIKARI BUSINESS FORM CO., LTD.',
        submitter_name_yomi='ヒカリビジネスフォームカブシキガイシャ',
        address='八王子市東浅川町５５３番地',
        industry='パルプ・紙',
        sec_code='39480',
        corporate_number='5010101003318',
    ),
    'E00709': EdinetCodeEntry(
        edinet_code='E00709',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1917,
        fiscal_year_end='3月31日',
        submitter_name='株式会社文溪堂',
        submitter_name_en='BUNKEIDO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャブンケイドウ',
        address='羽島市江吉良町江中七丁目１番地',
        industry='情報・通信業',
        sec_code='94710',
        corporate_number='2200001011461',
    ),
    'E00710': EdinetCodeEntry(
        edinet_code='E00710',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2278,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ＴＡＫＡＲＡ\u3000＆\u3000ＣＯＭＰＡＮＹ',
        submitter_name_en='TAKARA & COMPANY LTD.',
        submitter_name_yomi='カブシキガイシャタカラアンドカンパニー',
        address='豊島区高田３丁目２８番８号',
        industry='その他製品',
        sec_code='79210',
        corporate_number='1013301013404',
    ),
    'E00711': EdinetCodeEntry(
        edinet_code='E00711',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社光陽社',
        submitter_name_en='KOYOSHA INC.',
        submitter_name_yomi='カブシキガイシャコウヨウシャ',
        address='文京区湯島二丁目１６番１６号',
        industry='その他製品',
        sec_code='79460',
        corporate_number='2120001077412',
    ),
    'E00712': EdinetCodeEntry(
        edinet_code='E00712',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1850,
        fiscal_year_end='3月31日',
        submitter_name='三光産業株式会社',
        submitter_name_en='SANKO SANGYO CO.,LTD.',
        submitter_name_yomi='サンコウサンギョウカブシキガイシャ',
        address='渋谷区神宮前三丁目４２番６号',
        industry='その他製品',
        sec_code='79220',
        corporate_number='8011001034045',
    ),
    'E00713': EdinetCodeEntry(
        edinet_code='E00713',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2244,
        fiscal_year_end='3月31日',
        submitter_name='トーイン株式会社',
        submitter_name_en='TOIN  CORPORATION',
        submitter_name_yomi='トーインカブシキガイシャ',
        address='柏市新十余二１６番地１',
        industry='その他製品',
        sec_code='79230',
        corporate_number='2040001066043',
    ),
    'E00714': EdinetCodeEntry(
        edinet_code='E00714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2228,
        fiscal_year_end='3月31日',
        submitter_name='朝日印刷株式会社',
        submitter_name_en='ASAHI PRINTING CO.,LTD.',
        submitter_name_yomi='アサヒインサツカブシキガイシャ',
        address='富山市一番町１番１号\u3000一番町スクエアビル',
        industry='パルプ・紙',
        sec_code='39510',
        corporate_number='3230001000097',
    ),
    'E00715': EdinetCodeEntry(
        edinet_code='E00715',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='4月30日',
        submitter_name='株式会社マツモト',
        submitter_name_en='MATSUMOTO INC.',
        submitter_name_yomi='カブシキガイシャマツモト',
        address='北九州市門司区社ノ木一丁目２番１号',
        industry='その他製品',
        sec_code='79010',
        corporate_number='9290801005722',
    ),
    'E00716': EdinetCodeEntry(
        edinet_code='E00716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3058,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プロネクサス',
        submitter_name_en='PRONEXUS INC.',
        submitter_name_yomi='カブシキガイシャプロネクサス',
        address='港区海岸一丁目２番２０号',
        industry='その他製品',
        sec_code='78930',
        corporate_number='4010401001245',
    ),
    'E00717': EdinetCodeEntry(
        edinet_code='E00717',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6557,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゼンリン',
        submitter_name_en='ZENRIN CO., LTD.',
        submitter_name_yomi='カブシキガイシャゼンリン',
        address='北九州市小倉北区室町一丁目１番１号',
        industry='情報・通信業',
        sec_code='94740',
        corporate_number='5290801002046',
    ),
    'E00718': EdinetCodeEntry(
        edinet_code='E00718',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=650,
        fiscal_year_end='3月31日',
        submitter_name='株式会社朝日新聞社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアサヒシンブンシャ',
        address='大阪市北区中之島二丁目３番１８号',
        industry='その他製品',
        sec_code=None,
        corporate_number='6120001059605',
    ),
    'E00719': EdinetCodeEntry(
        edinet_code='E00719',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1236,
        fiscal_year_end='3月31日',
        submitter_name='サンメッセ株式会社',
        submitter_name_en='Sun Messe Co.,Ltd.',
        submitter_name_yomi='サンメッセカブシキガイシャ',
        address='大垣市久瀬川町７丁目５番地の１',
        industry='その他製品',
        sec_code='78830',
        corporate_number='9200001013658',
    ),
    'E00720': EdinetCodeEntry(
        edinet_code='E00720',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1937,
        fiscal_year_end='3月31日',
        submitter_name='竹田ｉＰホールディングス株式会社',
        submitter_name_en='TAKEDA iP HOLDINGS CO., LTD.',
        submitter_name_yomi='タケダアイピーホールディングスカブシキガイシャ',
        address='名古屋市昭和区白金一丁目１１番１０号',
        industry='その他製品',
        sec_code='78750',
        corporate_number='5180001008739',
    ),
    'E00721': EdinetCodeEntry(
        edinet_code='E00721',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社昭文社ホールディングス',
        submitter_name_en='Shobunsha Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャショウブンシャホールディングス',
        address='千代田区麹町三丁目１番地',
        industry='情報・通信業',
        sec_code='94750',
        corporate_number='7010001018224',
    ),
    'E00722': EdinetCodeEntry(
        edinet_code='E00722',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=460,
        fiscal_year_end='8月20日',
        submitter_name='福島印刷株式会社',
        submitter_name_en='FUKUSHIMA PRINTING CO.,LTD.',
        submitter_name_yomi='フクシマインサツカブシキカイシャ',
        address='金沢市佐奇森町ル６',
        industry='その他製品',
        sec_code='78700',
        corporate_number='2220001005602',
    ),
    'E00723': EdinetCodeEntry(
        edinet_code='E00723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=383,
        fiscal_year_end='9月30日',
        submitter_name='株式会社中央経済社ホールディングス',
        submitter_name_en='CHUOKEIZAI-SHA HOLDINGS,INC.',
        submitter_name_yomi='カブシキガイシャチュウオウケイザイシャホールディングス',
        address='千代田区神田神保町１－３１－２',
        industry='情報・通信業',
        sec_code='94760',
        corporate_number='1010001022710',
    ),
    'E00724': EdinetCodeEntry(
        edinet_code='E00724',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=437,
        fiscal_year_end='3月31日',
        submitter_name='株式会社広済堂ホールディングス',
        submitter_name_en='KOSAIDO Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャコウサイドウホールディングス',
        address='港区芝浦一丁目２番３号\u3000シーバンスＳ館１３階',
        industry='その他製品',
        sec_code='78680',
        corporate_number='7010401009665',
    ),
    'E00725': EdinetCodeEntry(
        edinet_code='E00725',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5990,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジシールインターナショナル',
        submitter_name_en='FUJI SEAL INTERNATIONAL,INC.',
        submitter_name_yomi='カブシキガイシャフジシールインターナショナル',
        address='大阪市淀川区宮原４丁目１番９号',
        industry='その他製品',
        sec_code='78640',
        corporate_number='1120001002503',
    ),
    'E00726': EdinetCodeEntry(
        edinet_code='E00726',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＰＰＡＮエッジ株式会社',
        submitter_name_en='TOPPAN Edge Inc.',
        submitter_name_yomi='トッパンエッジブシキガイシャ',
        address='港区東新橋１－７－３',
        industry='その他製品',
        sec_code=None,
        corporate_number='4010401050341',
    ),
    'E00728': EdinetCodeEntry(
        edinet_code='E00728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1406,
        fiscal_year_end='3月31日',
        submitter_name='ＳＥホールディングス・アンド・インキュベーションズ株式会社',
        submitter_name_en='SE Holdings and Incubations Co., Ltd.',
        submitter_name_yomi='エスイーホールディングスアンドインキュベーションズカブシキカイシャ',
        address='新宿区舟町５',
        industry='情報・通信業',
        sec_code='94780',
        corporate_number='8011101028203',
    ),
    'E00730': EdinetCodeEntry(
        edinet_code='E00730',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1201,
        fiscal_year_end='3月31日',
        submitter_name='セキ株式会社',
        submitter_name_en='SEKI CO.,LTD.',
        submitter_name_yomi='セキカブシキガイシャ',
        address='松山市湊町７丁目７番地１',
        industry='その他製品',
        sec_code='78570',
        corporate_number='9500001002341',
    ),
    'E00732': EdinetCodeEntry(
        edinet_code='E00732',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='カーディナル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カーディナルカブシキガイシャ',
        address='大阪市城東区新喜多２丁目６番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001014561',
    ),
    'E00733': EdinetCodeEntry(
        edinet_code='E00733',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5341,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インプレスホールディングス',
        submitter_name_en='Impress Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャインプレスホールディングス',
        address='千代田区神田神保町一丁目１０５番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010001066320',
    ),
    'E00734': EdinetCodeEntry(
        edinet_code='E00734',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=434,
        fiscal_year_end='3月31日',
        submitter_name='株式会社平賀',
        submitter_name_en='HIRAGA CO., LTD.',
        submitter_name_yomi='カブシキガイシャヒラガ',
        address='練馬区豊玉北三丁目３番１０号',
        industry='その他製品',
        sec_code='78630',
        corporate_number='5011601005828',
    ),
    'E00735': EdinetCodeEntry(
        edinet_code='E00735',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=411,
        fiscal_year_end='7月31日',
        submitter_name='総合商研株式会社',
        submitter_name_en='SOUGOU SHOUKEN CO.,LTD.',
        submitter_name_yomi='ソウゴウショウケンカブシキガイシャ',
        address='札幌市東区東苗穂二条三丁目４番４８号',
        industry='その他製品',
        sec_code='78500',
        corporate_number='8430001009031',
    ),
    'E00736': EdinetCodeEntry(
        edinet_code='E00736',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=540,
        fiscal_year_end='12月31日',
        submitter_name='スターツ出版株式会社',
        submitter_name_en='Starts Publishing Corporation',
        submitter_name_yomi='スターツシュッパンカブシキガイシャ',
        address='江戸川区中葛西五丁目３３番１４号',
        industry='情報・通信業',
        sec_code='78490',
        corporate_number='7011701004273',
    ),
    'E00737': EdinetCodeEntry(
        edinet_code='E00737',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=376,
        fiscal_year_end='3月31日',
        submitter_name='国際チャート株式会社',
        submitter_name_en='Kokusai Chart Corporation',
        submitter_name_yomi='コクサイチャートカブシキガイシャ',
        address='桶川市赤堀一丁目３０番地',
        industry='パルプ・紙',
        sec_code=None,
        corporate_number='2030001041996',
    ),
    'E00738': EdinetCodeEntry(
        edinet_code='E00738',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2500,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本経済新聞社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニホンケイザイシンブンシャ',
        address='千代田区大手町一丁目３番７号',
        industry='その他製品',
        sec_code=None,
        corporate_number='3010001033086',
    ),
    'E00740': EdinetCodeEntry(
        edinet_code='E00740',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=335,
        fiscal_year_end=None,
        submitter_name='株式会社幻冬舎',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャゲントウシャ',
        address='渋谷区千駄ヶ谷４－９－７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001029520',
    ),
    'E00744': EdinetCodeEntry(
        edinet_code='E00744',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=750,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000サイネックス',
        submitter_name_en='SCINEX CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000サイネックス',
        address='大阪市天王寺区上本町５丁目３番１５号',
        industry='サービス業',
        sec_code='23760',
        corporate_number='1120001079723',
    ),
    'E00745': EdinetCodeEntry(
        edinet_code='E00745',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4007,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ウェッジホールディングス',
        submitter_name_en='Wedge Holdings CO., LTD.',
        submitter_name_yomi='カブシキガイシャウェッジホールディングス',
        address='中央区日本橋本町一丁目９番４号\u3000Ｄａｉｗａ日本橋本町ビル',
        industry='その他金融業',
        sec_code='23880',
        corporate_number='7010001085875',
    ),
    'E00746': EdinetCodeEntry(
        edinet_code='E00746',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3374,
        fiscal_year_end='3月31日',
        submitter_name='共立印刷株式会社',
        submitter_name_en='KYORITSU PRINTING CO., LTD.',
        submitter_name_yomi='キョウリツインサツカブシキガイシャ',
        address='板橋区清水町３６番１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='2011401001699',
    ),
    'E00748': EdinetCodeEntry(
        edinet_code='E00748',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1667,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ウイルコホールディングス',
        submitter_name_en='WellcoHoldings Corporation',
        submitter_name_yomi='カブシキガイシャウイルコホールディングス',
        address='白山市福留町３７０番地',
        industry='その他製品',
        sec_code='78310',
        corporate_number='7220001008889',
    ),
    'E00751': EdinetCodeEntry(
        edinet_code='E00751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=182146,
        fiscal_year_end='12月31日',
        submitter_name='株式会社レゾナック・ホールディングス',
        submitter_name_en='Resonac Holdings Corporation',
        submitter_name_yomi='カブシキガイシャレゾナックホールディングス',
        address='港区東新橋一丁目９番１号',
        industry='化学',
        sec_code='40040',
        corporate_number='9010401014548',
    ),
    'E00752': EdinetCodeEntry(
        edinet_code='E00752',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90179,
        fiscal_year_end='3月31日',
        submitter_name='住友化学株式会社',
        submitter_name_en='SUMITOMO CHEMICAL COMPANY, LIMITED',
        submitter_name_yomi='スミトモカガクカブシキガイシャ',
        address='中央区日本橋二丁目７番１号',
        industry='化学',
        sec_code='40050',
        corporate_number='2010001071327',
    ),
    'E00753': EdinetCodeEntry(
        edinet_code='E00753',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7813,
        fiscal_year_end='3月31日',
        submitter_name='チッソ株式会社',
        submitter_name_en='CHISSO CORPORATION',
        submitter_name_yomi='チッソカブシキガイシャ',
        address='大阪市北区中之島三丁目３番２３号',
        industry='化学',
        sec_code=None,
        corporate_number='5120001067055',
    ),
    'E00754': EdinetCodeEntry(
        edinet_code='E00754',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6593,
        fiscal_year_end='3月31日',
        submitter_name='日本化成株式会社',
        submitter_name_en='Nippon Kasei Chemical Company Limited',
        submitter_name_yomi='ニッポンカセイカブシキガイシャ',
        address='いわき市小名浜字高山３４',
        industry='化学',
        sec_code=None,
        corporate_number='6380001013585',
    ),
    'E00755': EdinetCodeEntry(
        edinet_code='E00755',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9742,
        fiscal_year_end='3月31日',
        submitter_name='住友精化株式会社',
        submitter_name_en='Sumitomo Seika Chemicals Company,Limited.',
        submitter_name_yomi='スミトモセイカカブシキガイシャ',
        address='加古郡播磨町宮西３４６番地の１',
        industry='化学',
        sec_code='40080',
        corporate_number='6140001044373',
    ),
    'E00759': EdinetCodeEntry(
        edinet_code='E00759',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18942,
        fiscal_year_end='3月31日',
        submitter_name='日産化学株式会社',
        submitter_name_en='Nissan Chemical Corporation',
        submitter_name_yomi='ニッサンカガクカブシキガイシャ',
        address='中央区日本橋二丁目５番１号',
        industry='化学',
        sec_code='40210',
        corporate_number='1010001008734',
    ),
    'E00760': EdinetCodeEntry(
        edinet_code='E00760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8443,
        fiscal_year_end='3月31日',
        submitter_name='ラサ工業株式会社',
        submitter_name_en='Rasa Industries,Ltd.',
        submitter_name_yomi='ラサコウギョウカブシキガイシャ',
        address='千代田区外神田一丁目１８番１３号',
        industry='化学',
        sec_code='40220',
        corporate_number='8010001034971',
    ),
    'E00761': EdinetCodeEntry(
        edinet_code='E00761',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18169,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クレハ',
        submitter_name_en='KUREHA CORPORATION',
        submitter_name_yomi='カブシキガイシャクレハ',
        address='中央区日本橋浜町三丁目３番２号',
        industry='化学',
        sec_code='40230',
        corporate_number='7010001034766',
    ),
    'E00762': EdinetCodeEntry(
        edinet_code='E00762',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2147,
        fiscal_year_end='12月31日',
        submitter_name='多木化学株式会社',
        submitter_name_en='Taki Chemical Co., Ltd.',
        submitter_name_yomi='タキカガクカブシキガイシャ',
        address='加古川市別府町緑町２番地',
        industry='化学',
        sec_code='40250',
        corporate_number='5140001043137',
    ),
    'E00763': EdinetCodeEntry(
        edinet_code='E00763',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1320,
        fiscal_year_end='4月30日',
        submitter_name='神島化学工業株式会社',
        submitter_name_en='Konoshima Chemical Co.,Ltd.',
        submitter_name_yomi='コウノシマカガクコウギョウカブシキガイシャ',
        address='大阪市中央区今橋４丁目４番７号',
        industry='ガラス・土石製品',
        sec_code='40260',
        corporate_number='2120001077049',
    ),
    'E00764': EdinetCodeEntry(
        edinet_code='E00764',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9855,
        fiscal_year_end='3月31日',
        submitter_name='テイカ株式会社',
        submitter_name_en='TAYCA CORPORATION',
        submitter_name_yomi='テイカカブシキガイシャ',
        address='大阪市大正区船町１丁目３番４７号',
        industry='化学',
        sec_code='40270',
        corporate_number='7120001027825',
    ),
    'E00765': EdinetCodeEntry(
        edinet_code='E00765',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=43420,
        fiscal_year_end='3月31日',
        submitter_name='石原産業株式会社',
        submitter_name_en='ISHIHARA SANGYO KAISHA, LTD.',
        submitter_name_yomi='イシハラサンギョウカブシキガイシャ',
        address='大阪市西区江戸堀１丁目３番１５号',
        industry='化学',
        sec_code='40280',
        corporate_number='9120001048976',
    ),
    'E00766': EdinetCodeEntry(
        edinet_code='E00766',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=29166,
        fiscal_year_end='3月31日',
        submitter_name='日本曹達株式会社',
        submitter_name_en='Nippon Soda Co.,Ltd.',
        submitter_name_yomi='ニホンソーダカブシキガイシャ',
        address='千代田区丸の内二丁目７番２号',
        industry='化学',
        sec_code='40410',
        corporate_number='1010001008833',
    ),
    'E00767': EdinetCodeEntry(
        edinet_code='E00767',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=55173,
        fiscal_year_end='3月31日',
        submitter_name='東ソー株式会社',
        submitter_name_en='TOSOH CORPORATION',
        submitter_name_yomi='トウソーカブシキガイシャ',
        address='周南市開成町４５６０番地',
        industry='化学',
        sec_code='40420',
        corporate_number='5250001010002',
    ),
    'E00768': EdinetCodeEntry(
        edinet_code='E00768',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トクヤマ',
        submitter_name_en='Tokuyama Corporation',
        submitter_name_yomi='カブシキガイシャトクヤマ',
        address='周南市御影町１番１号',
        industry='化学',
        sec_code='40430',
        corporate_number='1250001009080',
    ),
    'E00769': EdinetCodeEntry(
        edinet_code='E00769',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18168,
        fiscal_year_end='3月31日',
        submitter_name='セントラル硝子株式会社',
        submitter_name_en='Central Glass Co.,Ltd.',
        submitter_name_yomi='セントラルガラスカブシキガイシャ',
        address='宇部市大字沖宇部５２５３番地',
        industry='化学',
        sec_code='40440',
        corporate_number='4250001003329',
    ),
    'E00770': EdinetCodeEntry(
        edinet_code='E00770',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20886,
        fiscal_year_end='12月31日',
        submitter_name='東亞合成株式会社',
        submitter_name_en='TOAGOSEI CO., LTD.',
        submitter_name_yomi='トウアゴウセイカブシキガイシャ',
        address='港区西新橋一丁目１４番１号',
        industry='化学',
        sec_code='40450',
        corporate_number='5010401020186',
    ),
    'E00771': EdinetCodeEntry(
        edinet_code='E00771',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15871,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大阪ソーダ',
        submitter_name_en='OSAKA SODA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオオサカソーダ',
        address='大阪市北区梅田三丁目２番２号ＪＰタワー大阪１９階',
        industry='化学',
        sec_code='40460',
        corporate_number='4120001049013',
    ),
    'E00772': EdinetCodeEntry(
        edinet_code='E00772',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2877,
        fiscal_year_end='3月31日',
        submitter_name='関東電化工業株式会社',
        submitter_name_en='KANTO DENKA KOGYO CO.,LTD.',
        submitter_name_yomi='カントウデンカコウギョウカブシキガイシャ',
        address='千代田区丸の内二丁目３番２号',
        industry='化学',
        sec_code='40470',
        corporate_number='8010001013769',
    ),
    'E00773': EdinetCodeEntry(
        edinet_code='E00773',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1224,
        fiscal_year_end='12月31日',
        submitter_name='北海道曹達株式会社',
        submitter_name_en='Hokkaido Soda Co.,Ltd.',
        submitter_name_yomi='ホッカイドウソウダカブシキガイシャ',
        address='苫小牧市字沼ノ端１３４番地１２２',
        industry='化学',
        sec_code=None,
        corporate_number='3430001054362',
    ),
    'E00774': EdinetCodeEntry(
        edinet_code='E00774',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36998,
        fiscal_year_end='3月31日',
        submitter_name='デンカ株式会社',
        submitter_name_en='Denka Company Limited',
        submitter_name_yomi='デンカカブシキカイシャ',
        address='中央区日本橋室町二丁目１番１号',
        industry='化学',
        sec_code='40610',
        corporate_number='3010001008757',
    ),
    'E00775': EdinetCodeEntry(
        edinet_code='E00775',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=64152,
        fiscal_year_end='3月31日',
        submitter_name='イビデン株式会社',
        submitter_name_en='IBIDEN CO.,LTD.',
        submitter_name_yomi='イビデンカブシキガイシャ',
        address='大垣市神田町２丁目１番地',
        industry='電気機器',
        sec_code='40620',
        corporate_number='6200001013231',
    ),
    'E00776': EdinetCodeEntry(
        edinet_code='E00776',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=119419,
        fiscal_year_end='3月31日',
        submitter_name='信越化学工業株式会社',
        submitter_name_en='Shin-Etsu Chemical Co., Ltd.',
        submitter_name_yomi='シンエツカガクコウギョウカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号',
        industry='化学',
        sec_code='40630',
        corporate_number='5010001008680',
    ),
    'E00777': EdinetCodeEntry(
        edinet_code='E00777',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7797,
        fiscal_year_end='3月31日',
        submitter_name='日本カーバイド工業株式会社',
        submitter_name_en='NIPPON CARBIDE INDUSTRIES CO.,INC.',
        submitter_name_yomi='ニッポンカーバイドコウギョウカブシキガイシャ',
        address='港区港南二丁目１６番２号',
        industry='化学',
        sec_code='40640',
        corporate_number='6010401038624',
    ),
    'E00780': EdinetCodeEntry(
        edinet_code='E00780',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21838,
        fiscal_year_end='3月31日',
        submitter_name='堺化学工業株式会社',
        submitter_name_en='Sakai Chemical Industry Co.,Ltd.',
        submitter_name_yomi='サカイカガクコウギョウカブシキガイシャ',
        address='堺市堺区戎島町５丁２番地',
        industry='化学',
        sec_code='40780',
        corporate_number='4120101002532',
    ),
    'E00781': EdinetCodeEntry(
        edinet_code='E00781',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2885,
        fiscal_year_end='3月31日',
        submitter_name='高圧ガス工業株式会社',
        submitter_name_en='KOATSU GAS KOGYO CO., LTD.',
        submitter_name_yomi='コウアツガスコウギョウカブシキガイシャ',
        address='大阪市北区中崎西２丁目４番１２号',
        industry='化学',
        sec_code='40970',
        corporate_number='5120001059639',
    ),
    'E00783': EdinetCodeEntry(
        edinet_code='E00783',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37344,
        fiscal_year_end='3月31日',
        submitter_name='日本酸素ホールディングス株式会社',
        submitter_name_en='NIPPON SANSO HOLDINGS CORPORATION',
        submitter_name_yomi='ニッポンサンソホールディングスカブシキガイシャ',
        address='品川区小山一丁目３番２６号',
        industry='化学',
        sec_code='40910',
        corporate_number='7010701015826',
    ),
    'E00784': EdinetCodeEntry(
        edinet_code='E00784',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5757,
        fiscal_year_end='3月31日',
        submitter_name='日本化学工業株式会社',
        submitter_name_en='Nippon Chemical Industrial  Co.,Ltd.',
        submitter_name_yomi='ニホンカガクコウギョウカブシキガイシャ',
        address='江東区亀戸９丁目１１番１号',
        industry='化学',
        sec_code='40920',
        corporate_number='3010601005559',
    ),
    'E00786': EdinetCodeEntry(
        edinet_code='E00786',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1034,
        fiscal_year_end='3月31日',
        submitter_name='日本化学産業株式会社',
        submitter_name_en='NIHON KAGAKU SANGYO CO.,LTD.',
        submitter_name_yomi='ニホンカガクサンギョウカブシキガイシャ',
        address='台東区下谷二丁目２０番５号',
        industry='化学',
        sec_code='40940',
        corporate_number='8010501016239',
    ),
    'E00787': EdinetCodeEntry(
        edinet_code='E00787',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2261,
        fiscal_year_end='3月31日',
        submitter_name='東邦アセチレン株式会社',
        submitter_name_en='toho acetylene co.,ltd.',
        submitter_name_yomi='トウホウアセチレンカブシキガイシャ',
        address='多賀城市栄二丁目３番３２号',
        industry='化学',
        sec_code='40930',
        corporate_number='8010001034831',
    ),
    'E00788': EdinetCodeEntry(
        edinet_code='E00788',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2079,
        fiscal_year_end=None,
        submitter_name='昭和電工ガスプロダクツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウワデンコウガスプロダクツカブシキカイシャ',
        address='川崎市幸区大宮町１３１０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001092531',
    ),
    'E00789': EdinetCodeEntry(
        edinet_code='E00789',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4214,
        fiscal_year_end='3月31日',
        submitter_name='片倉コープアグリ株式会社',
        submitter_name_en='Katakura & Co-op Agri Corporation',
        submitter_name_yomi='カタクラコープアグリカブシキガイシャ',
        address='千代田区九段北一丁目８番１０号',
        industry='化学',
        sec_code='40310',
        corporate_number='4010001008665',
    ),
    'E00791': EdinetCodeEntry(
        edinet_code='E00791',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=876,
        fiscal_year_end='3月31日',
        submitter_name='丸尾カルシウム株式会社',
        submitter_name_en='Maruo Calcium Co., Ltd.',
        submitter_name_yomi='マルオカルシウムカブシキガイシャ',
        address='明石市魚住町西岡１４５５番地',
        industry='化学',
        sec_code='41020',
        corporate_number='5140001035506',
    ),
    'E00792': EdinetCodeEntry(
        edinet_code='E00792',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=55855,
        fiscal_year_end='3月31日',
        submitter_name='エア・ウォーター株式会社',
        submitter_name_en='AIR WATER INC.',
        submitter_name_yomi='エアウォーターカブシキガイシャ',
        address='大阪市中央区南船場二丁目１２番８号',
        industry='化学',
        sec_code='40880',
        corporate_number='1430001009475',
    ),
    'E00794': EdinetCodeEntry(
        edinet_code='E00794',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4028,
        fiscal_year_end='3月31日',
        submitter_name='小池酸素工業株式会社',
        submitter_name_en='KOIKE SANSO KOGYO CO.,LTD.',
        submitter_name_yomi='コイケサンソコウギョウカブシキガイシャ',
        address='墨田区太平三丁目４番８号ＫＯＩＫＥ\u3000Ｂｌｄ．７階',
        industry='機械',
        sec_code='61370',
        corporate_number='7011701002789',
    ),
    'E00796': EdinetCodeEntry(
        edinet_code='E00796',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3443,
        fiscal_year_end='3月31日',
        submitter_name='チタン工業株式会社',
        submitter_name_en='Titan Kogyo, Ltd.',
        submitter_name_yomi='チタンコウギョウカブシキカイシャ',
        address='宇部市大字小串１９７８番地の２５',
        industry='化学',
        sec_code='40980',
        corporate_number='3250001003412',
    ),
    'E00804': EdinetCodeEntry(
        edinet_code='E00804',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1980,
        fiscal_year_end='3月31日',
        submitter_name='石原ケミカル株式会社',
        submitter_name_en='ISHIHARA CHEMICAL CO.,LTD.',
        submitter_name_yomi='イシハラケミカルカブシキガイシャ',
        address='神戸市兵庫区西柳原町５番２６号',
        industry='化学',
        sec_code='44620',
        corporate_number='7140001012494',
    ),
    'E00805': EdinetCodeEntry(
        edinet_code='E00805',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4829,
        fiscal_year_end='3月31日',
        submitter_name='ステラケミファ株式会社',
        submitter_name_en='STELLA CHEMIFA CORPORATION',
        submitter_name_yomi='ステラケミファカブシキガイシャ',
        address='大阪市中央区伏見町４－１－１',
        industry='化学',
        sec_code='41090',
        corporate_number='8120001044472',
    ),
    'E00806': EdinetCodeEntry(
        edinet_code='E00806',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=787,
        fiscal_year_end='3月31日',
        submitter_name='第一稀元素化学工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイイチキゲンソカガクコウギョウカブシキガイシャ',
        address='大阪市中央区北浜４－４－９',
        industry='化学',
        sec_code='40820',
        corporate_number='8120001031181',
    ),
    'E00808': EdinetCodeEntry(
        edinet_code='E00808',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='三菱ケミカルグループ株式会社',
        submitter_name_en='Mitsubishi Chemical Gloup Corporation',
        submitter_name_yomi='ミツビシケミカルグループカブシキカイシャ',
        address='千代田区丸の内一丁目１番１号',
        industry='化学',
        sec_code='41880',
        corporate_number='8010401059206',
    ),
    'E00809': EdinetCodeEntry(
        edinet_code='E00809',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11196,
        fiscal_year_end='3月31日',
        submitter_name='保土谷化学工業株式会社',
        submitter_name_en='Hodogaya Chemical Co.,Ltd.',
        submitter_name_yomi='ホドガヤカガクコウギョウカブシキカイシャ',
        address='港区東新橋一丁目９番２号',
        industry='化学',
        sec_code='41120',
        corporate_number='2010401070762',
    ),
    'E00810': EdinetCodeEntry(
        edinet_code='E00810',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1572,
        fiscal_year_end='3月31日',
        submitter_name='田岡化学工業株式会社',
        submitter_name_en='TAOKA CHEMICAL COMPANY, LIMITED',
        submitter_name_yomi='タオカカガクコウギョウカブシキカイシャ',
        address='大阪市淀川区西三国４丁目２番１１号',
        industry='化学',
        sec_code='41130',
        corporate_number='9120001056384',
    ),
    'E00811': EdinetCodeEntry(
        edinet_code='E00811',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25038,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本触媒',
        submitter_name_en='NIPPON SHOKUBAI CO., LTD.',
        submitter_name_yomi='カブシキガイシャニッポンショクバイ',
        address='大阪市中央区高麗橋四丁目１番１号',
        industry='化学',
        sec_code='41140',
        corporate_number='9120001077620',
    ),
    'E00812': EdinetCodeEntry(
        edinet_code='E00812',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1500,
        fiscal_year_end='3月31日',
        submitter_name='本州化学工業株式会社',
        submitter_name_en='Honshu Chemical Industry Co.,Ltd.',
        submitter_name_yomi='ホンシュウカガクコウギョウカブシキガイシャ',
        address='中央区日本橋三丁目３番９号',
        industry='化学',
        sec_code=None,
        corporate_number='5010001034925',
    ),
    'E00813': EdinetCodeEntry(
        edinet_code='E00813',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6282,
        fiscal_year_end='3月31日',
        submitter_name='川崎化成工業株式会社',
        submitter_name_en='Kawasaki Kasei Chemicals Ltd.',
        submitter_name_yomi='カワサキカセイコウギョウカブシキガイシャ',
        address='川崎市幸区大宮町１３１０',
        industry='化学',
        sec_code=None,
        corporate_number='9020001076062',
    ),
    'E00815': EdinetCodeEntry(
        edinet_code='E00815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=41970,
        fiscal_year_end='3月31日',
        submitter_name='三菱瓦斯化学株式会社',
        submitter_name_en='MITSUBISHI GAS CHEMICAL COMPANY,INC.',
        submitter_name_yomi='ミツビシガスカガクカブシキガイシャ',
        address='千代田区丸の内二丁目５番２号',
        industry='化学',
        sec_code='41820',
        corporate_number='9010001008768',
    ),
    'E00816': EdinetCodeEntry(
        edinet_code='E00816',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26745,
        fiscal_year_end='12月31日',
        submitter_name='協和キリン株式会社',
        submitter_name_en='Kyowa Kirin Co.,Ltd.',
        submitter_name_yomi='キョウワキリンカブシキガイシャ',
        address='千代田区大手町一丁目９番２号',
        industry='医薬品',
        sec_code='41510',
        corporate_number='7010001008670',
    ),
    'E00817': EdinetCodeEntry(
        edinet_code='E00817',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17989,
        fiscal_year_end=None,
        submitter_name='日本合成化学工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンゴウセイカガクコウギョウカブシキガイシャ',
        address='大阪市北区小松原町２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001059676',
    ),
    'E00818': EdinetCodeEntry(
        edinet_code='E00818',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36275,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイセル',
        submitter_name_en='DAICEL CORPORATION',
        submitter_name_yomi='カブシキガイシャダイセル',
        address='大阪市北区大深町３番１号',
        industry='化学',
        sec_code='42020',
        corporate_number='4120001125937',
    ),
    'E00819': EdinetCodeEntry(
        edinet_code='E00819',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37143,
        fiscal_year_end='3月31日',
        submitter_name='住友ベークライト株式会社',
        submitter_name_en='Sumitomo Bakelite Company Limited',
        submitter_name_yomi='スミトモベークライトカブシキガイシャ',
        address='品川区東品川二丁目５番８号',
        industry='化学',
        sec_code='42030',
        corporate_number='9010701005073',
    ),
    'E00820': EdinetCodeEntry(
        edinet_code='E00820',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100002,
        fiscal_year_end='3月31日',
        submitter_name='積水化学工業株式会社',
        submitter_name_en='Sekisui Chemical Co.,Ltd.',
        submitter_name_yomi='セキスイカガクコウギョウカブシキガイシャ',
        address='大阪市北区西天満二丁目４番４号',
        industry='化学',
        sec_code='42040',
        corporate_number='1120001059650',
    ),
    'E00821': EdinetCodeEntry(
        edinet_code='E00821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24211,
        fiscal_year_end='3月31日',
        submitter_name='日本ゼオン株式会社',
        submitter_name_en='ZEON CORPORATION',
        submitter_name_yomi='ニッポンゼオンカブキシガイシャ',
        address='千代田区丸の内一丁目６番２号',
        industry='化学',
        sec_code='42050',
        corporate_number='9010001008834',
    ),
    'E00823': EdinetCodeEntry(
        edinet_code='E00823',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15216,
        fiscal_year_end='3月31日',
        submitter_name='タキロンシーアイ株式会社',
        submitter_name_en='C.I. TAKIRON Corporation',
        submitter_name_yomi='タキロンシーアイカブシキガイシャ',
        address='大阪市北区梅田三丁目１番３号',
        industry='化学',
        sec_code=None,
        corporate_number='3120001077460',
    ),
    'E00824': EdinetCodeEntry(
        edinet_code='E00824',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9891,
        fiscal_year_end='3月31日',
        submitter_name='アイカ工業株式会社',
        submitter_name_en='Aica Kogyo Company, Limited',
        submitter_name_yomi='アイカコウギョウカブシキガイシャ',
        address='清須市西堀江２２８８番地',
        industry='化学',
        sec_code='42060',
        corporate_number='6180001033620',
    ),
    'E00828': EdinetCodeEntry(
        edinet_code='E00828',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4534,
        fiscal_year_end='10月31日',
        submitter_name='クミアイ化学工業株式会社',
        submitter_name_en='KUMIAI CHEMICAL INDUSTRY CO., LTD.',
        submitter_name_yomi='クミアイカガクコウギョウカブシキカイシャ',
        address='台東区池之端一丁目４番２６号',
        industry='化学',
        sec_code='49960',
        corporate_number='1010501016022',
    ),
    'E00829': EdinetCodeEntry(
        edinet_code='E00829',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2194,
        fiscal_year_end='3月31日',
        submitter_name='フクビ化学工業株式会社',
        submitter_name_en='FUKUVI CHEMICAL INDUSTRY CO.,LTD.',
        submitter_name_yomi='フクビカガクコウギョウカブシキガイシャ',
        address='福井市三十八社町３３字６６番地',
        industry='化学',
        sec_code='78710',
        corporate_number='4210001003266',
    ),
    'E00830': EdinetCodeEntry(
        edinet_code='E00830',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='旭有機材株式会社',
        submitter_name_en='ASAHI YUKIZAI CORPORATION',
        submitter_name_yomi='アサヒユウキザイカブシキガイシャ',
        address='延岡市中の瀬町二丁目５９５５番地',
        industry='化学',
        sec_code='42160',
        corporate_number='7350001006608',
    ),
    'E00831': EdinetCodeEntry(
        edinet_code='E00831',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=870,
        fiscal_year_end='3月31日',
        submitter_name='プラス・テク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プラステクカブシキガイシャ',
        address='稲敷郡阿見町大字香澄の里１番地１',
        industry='化学',
        sec_code=None,
        corporate_number='3050001010255',
    ),
    'E00832': EdinetCodeEntry(
        edinet_code='E00832',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5352,
        fiscal_year_end='3月31日',
        submitter_name='藤倉化成株式会社',
        submitter_name_en='FUJIKURA KASEI CO,.LTD.',
        submitter_name_yomi='フジクラカセイカブシキガイシャ',
        address='板橋区蓮根三丁目２０番７号',
        industry='化学',
        sec_code='46200',
        corporate_number='1011401007292',
    ),
    'E00834': EdinetCodeEntry(
        edinet_code='E00834',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8619,
        fiscal_year_end='12月31日',
        submitter_name='大倉工業株式会社',
        submitter_name_en='Okura Industrial Co.,Ltd.',
        submitter_name_yomi='オオクラコウギョウカブシキガイシャ',
        address='丸亀市中津町１５１５番地',
        industry='化学',
        sec_code='42210',
        corporate_number='2470001007268',
    ),
    'E00836': EdinetCodeEntry(
        edinet_code='E00836',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14932,
        fiscal_year_end='3月31日',
        submitter_name='日本化薬株式会社',
        submitter_name_en='NIPPON KAYAKU CO.,LTD.',
        submitter_name_yomi='ニホンカヤクカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='化学',
        sec_code='42720',
        corporate_number='3010001016850',
    ),
    'E00837': EdinetCodeEntry(
        edinet_code='E00837',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2343,
        fiscal_year_end='3月31日',
        submitter_name='広栄化学株式会社',
        submitter_name_en='KOEI CHEMICAL COMPANY,LIMITED',
        submitter_name_yomi='コウエイカガクカブシキガイシャ',
        address='袖ケ浦市北袖２５番地',
        industry='化学',
        sec_code='43670',
        corporate_number='4120001077410',
    ),
    'E00838': EdinetCodeEntry(
        edinet_code='E00838',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8514,
        fiscal_year_end='3月31日',
        submitter_name='リケンテクノス株式会社',
        submitter_name_en='RIKEN TECHNOS CORPORATION',
        submitter_name_yomi='リケンテクノスカブシキガイシャ',
        address='千代田区神田淡路町二丁目１０１番地',
        industry='化学',
        sec_code='42200',
        corporate_number='9010001034970',
    ),
    'E00839': EdinetCodeEntry(
        edinet_code='E00839',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='児玉化学工業株式会社',
        submitter_name_en='KODAMA CHEMICAL INDUSTRY CO.,LTD.',
        submitter_name_yomi='コダマカガクコウギョウカブシキガイシャ',
        address='千代田区神田須田町二丁目２５番地１６',
        industry='化学',
        sec_code='42220',
        corporate_number='5010501016027',
    ),
    'E00840': EdinetCodeEntry(
        edinet_code='E00840',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=125572,
        fiscal_year_end='3月31日',
        submitter_name='三井化学株式会社',
        submitter_name_en='Mitsui Chemicals, Inc.',
        submitter_name_yomi='ミツイカガクカブシキガイシャ',
        address='中央区八重洲二丁目２番１号',
        industry='化学',
        sec_code='41830',
        corporate_number='4010401052081',
    ),
    'E00841': EdinetCodeEntry(
        edinet_code='E00841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6867,
        fiscal_year_end='12月31日',
        submitter_name='四国化成ホールディングス株式会社',
        submitter_name_en='SHIKOKU KASEI HOLDINGS CORPOLATION',
        submitter_name_yomi='シコクカセイホールディングスカブシキガイシャ',
        address='丸亀市土器町東八丁目５３７番地１',
        industry='化学',
        sec_code='40990',
        corporate_number='3470001007507',
    ),
    'E00842': EdinetCodeEntry(
        edinet_code='E00842',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7477,
        fiscal_year_end='3月31日',
        submitter_name='戸田工業株式会社',
        submitter_name_en='TODA KOGYO CORP.',
        submitter_name_yomi='トダコウギョウカブシキガイシャ',
        address='広島市南区京橋町１番２３号大樹生命広島駅前ビル',
        industry='化学',
        sec_code='41000',
        corporate_number='3240001028939',
    ),
    'E00844': EdinetCodeEntry(
        edinet_code='E00844',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1222,
        fiscal_year_end='3月31日',
        submitter_name='太平化学製品株式会社',
        submitter_name_en='TAIHEI  CHEMICALS  LIMITED.',
        submitter_name_yomi='タイヘイカガクセイヒンカブシキガイシャ',
        address='川口市領家４丁目５番１９号',
        industry='化学',
        sec_code=None,
        corporate_number='2030001075813',
    ),
    'E00845': EdinetCodeEntry(
        edinet_code='E00845',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16533,
        fiscal_year_end='3月31日',
        submitter_name='積水化成品工業株式会社',
        submitter_name_en='Sekisui Kasei Co.,Ltd.',
        submitter_name_yomi='セキスイカセイヒンコウギョウカブシキガイシャ',
        address='大阪市北区西天満２－４－４',
        industry='化学',
        sec_code='42280',
        corporate_number='7120001065932',
    ),
    'E00846': EdinetCodeEntry(
        edinet_code='E00846',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2323,
        fiscal_year_end='12月31日',
        submitter_name='オーナンバ株式会社',
        submitter_name_en='Onamba Co.,Ltd.',
        submitter_name_yomi='オーナンバカブシキガイシャ',
        address='大阪市中央区南久宝寺町四丁目１番２号',
        industry='非鉄金属',
        sec_code='58160',
        corporate_number='6120001011879',
    ),
    'E00848': EdinetCodeEntry(
        edinet_code='E00848',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3471,
        fiscal_year_end='3月31日',
        submitter_name='有機合成薬品工業株式会社',
        submitter_name_en='YUKI GOSEI KOGYO CO.,LTD.',
        submitter_name_yomi='ユウキゴウセイヤクヒンコウギョウカブシキガイシャ',
        address='中央区日本橋人形町三丁目１０番４号',
        industry='医薬品',
        sec_code='45310',
        corporate_number='9010001059621',
    ),
    'E00850': EdinetCodeEntry(
        edinet_code='E00850',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=201,
        fiscal_year_end='3月31日',
        submitter_name='細谷火工株式会社',
        submitter_name_en='HOSOYA PYRO-ENGINEERING CO., LTD.',
        submitter_name_yomi='ホソヤカコウカブシキガイシャ',
        address='あきる野市菅生１８４７番地',
        industry='化学',
        sec_code='42740',
        corporate_number='5013101001167',
    ),
    'E00851': EdinetCodeEntry(
        edinet_code='E00851',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=720,
        fiscal_year_end=None,
        submitter_name='株式会社イノアックコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイノアックコーポレーション',
        address='名古屋市中村区名駅南二丁目１３番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001029475',
    ),
    'E00852': EdinetCodeEntry(
        edinet_code='E00852',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5933,
        fiscal_year_end='3月31日',
        submitter_name='日本精化株式会社',
        submitter_name_en='Nippon Fine Chemical Co., Ltd.',
        submitter_name_yomi='ニッポンセイカカブシキガイシャ',
        address='大阪市中央区備後町２丁目４番９号',
        industry='化学',
        sec_code='43620',
        corporate_number='4120001093267',
    ),
    'E00854': EdinetCodeEntry(
        edinet_code='E00854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14640,
        fiscal_year_end='12月31日',
        submitter_name='東京応化工業株式会社',
        submitter_name_en='TOKYO OHKA KOGYO CO., LTD.',
        submitter_name_yomi='トウキョウオウカコウギョウカブシキガイシャ',
        address='川崎市中原区中丸子１５０番地',
        industry='化学',
        sec_code='41860',
        corporate_number='3020001069823',
    ),
    'E00855': EdinetCodeEntry(
        edinet_code='E00855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3600,
        fiscal_year_end='11月30日',
        submitter_name='大阪有機化学工業株式会社',
        submitter_name_en='OSAKA ORGANIC CHEMICAL INDUSTRY LTD.',
        submitter_name_yomi='オオサカユウキカガクコウギョウカブシキガイシャ',
        address='大阪市中央区安土町１丁目８番１５号',
        industry='化学',
        sec_code='41870',
        corporate_number='1120001093014',
    ),
    'E00857': EdinetCodeEntry(
        edinet_code='E00857',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19225,
        fiscal_year_end='3月31日',
        submitter_name='天馬株式会社',
        submitter_name_en='TENMA CORPORATION',
        submitter_name_yomi='テンマカブシキガイシャ',
        address='北区赤羽一丁目６３番６号',
        industry='化学',
        sec_code=None,
        corporate_number='2011501003026',
    ),
    'E00858': EdinetCodeEntry(
        edinet_code='E00858',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10128,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジェイエスピー',
        submitter_name_en='JSP Corporation',
        submitter_name_yomi='カブシキガイシャジェイエスピー',
        address='千代田区丸の内三丁目４番２号',
        industry='化学',
        sec_code='79420',
        corporate_number='9010001019484',
    ),
    'E00859': EdinetCodeEntry(
        edinet_code='E00859',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1757,
        fiscal_year_end=None,
        submitter_name='マナック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マナックカブシキガイシャ',
        address='福山市箕沖町９２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8240001032184',
    ),
    'E00860': EdinetCodeEntry(
        edinet_code='E00860',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1809,
        fiscal_year_end='12月31日',
        submitter_name='アグロ\u3000カネショウ株式会社',
        submitter_name_en='AGRO-KANESHO CO.,LTD.',
        submitter_name_yomi='アグロカネショウ\u3000カブシキガイシャ',
        address='千代田区丸の内一丁目８番３号\u3000丸の内トラストタワー本館２５階',
        industry='化学',
        sec_code=None,
        corporate_number='4010401001187',
    ),
    'E00861': EdinetCodeEntry(
        edinet_code='E00861',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3387,
        fiscal_year_end='3月31日',
        submitter_name='前澤化成工業株式会社',
        submitter_name_en='MAEZAWA KASEI INDUSTRIES CO.,LTD.',
        submitter_name_yomi='マエザワカセイコウギョウカブシキガイシャ',
        address='中央区日本橋小網町１７番１０号',
        industry='化学',
        sec_code='79250',
        corporate_number='3010001057580',
    ),
    'E00863': EdinetCodeEntry(
        edinet_code='E00863',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1807,
        fiscal_year_end='2月末日',
        submitter_name='丸東産業株式会社',
        submitter_name_en='Maruto Sangyo Co., Ltd',
        submitter_name_yomi='マルトウサンギョウカブシキガイシャ',
        address='小郡市干潟８９２番地１',
        industry='化学',
        sec_code='78940',
        corporate_number='5290001050416',
    ),
    'E00865': EdinetCodeEntry(
        edinet_code='E00865',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1100,
        fiscal_year_end='3月31日',
        submitter_name='日本ユピカ株式会社',
        submitter_name_en='JAPAN U-PICA COMPANY,LTD.',
        submitter_name_yomi='ニホンユピカカブシキガイシャ',
        address='千代田区紀尾井町４－１３',
        industry='化学',
        sec_code=None,
        corporate_number='2010001033789',
    ),
    'E00866': EdinetCodeEntry(
        edinet_code='E00866',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4008,
        fiscal_year_end='5月31日',
        submitter_name='三光合成株式会社',
        submitter_name_en='sanko gosei ltd.',
        submitter_name_yomi='サンコウゴウセイカブシキカイシャ',
        address='南砺市土生新１２００番地',
        industry='化学',
        sec_code='78880',
        corporate_number='5230001008725',
    ),
    'E00867': EdinetCodeEntry(
        edinet_code='E00867',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1168,
        fiscal_year_end='3月31日',
        submitter_name='ヤマト\u3000モビリティ\u3000＆\u3000Ｍｆｇ．株式会社',
        submitter_name_en='YAMATO Mobility & Mfg.Co.,Ltd.',
        submitter_name_yomi='ヤマトモビリティアンドマニュファクチャリングカブシキガイシャ',
        address='埼玉県川越市大字古谷上４２７４',
        industry='化学',
        sec_code='78860',
        corporate_number='8030001059463',
    ),
    'E00868': EdinetCodeEntry(
        edinet_code='E00868',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2155,
        fiscal_year_end='3月31日',
        submitter_name='ケミプロ化成株式会社',
        submitter_name_en='CHEMIPRO KASEI KAISHA,LTD',
        submitter_name_yomi='ケミプロカセイカブシキカイシャ',
        address='神戸市中央区京町８３番地',
        industry='化学',
        sec_code='49600',
        corporate_number='6140001007611',
    ),
    'E00871': EdinetCodeEntry(
        edinet_code='E00871',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2114,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タカギセイコー',
        submitter_name_en='TAKAGI SEIKO CORPORATION',
        submitter_name_yomi='カブシキガイシャタカギセイコー',
        address='高岡市二塚３２２番地の３',
        industry='化学',
        sec_code='42420',
        corporate_number='4230001010335',
    ),
    'E00872': EdinetCodeEntry(
        edinet_code='E00872',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=71833,
        fiscal_year_end='3月31日',
        submitter_name='帝人株式会社',
        submitter_name_en='TEIJIN LIMITED',
        submitter_name_yomi='テイジンカブシキガイシャ',
        address='大阪市北区中之島三丁目２番４号',
        industry='繊維製品',
        sec_code='34010',
        corporate_number='8120001077489',
    ),
    'E00873': EdinetCodeEntry(
        edinet_code='E00873',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=147873,
        fiscal_year_end='3月31日',
        submitter_name='東レ株式会社',
        submitter_name_en='TORAY INDUSTRIES,INC.',
        submitter_name_yomi='トウレカブシキガイシャ',
        address='中央区日本橋室町二丁目１番１号',
        industry='繊維製品',
        sec_code='34020',
        corporate_number='5010001034867',
    ),
    'E00875': EdinetCodeEntry(
        edinet_code='E00875',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=53230,
        fiscal_year_end=None,
        submitter_name='三菱ケミカル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシケミカルカブシキカイシャ',
        address='千代田区丸の内一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001146760',
    ),
    'E00876': EdinetCodeEntry(
        edinet_code='E00876',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=88955,
        fiscal_year_end='12月31日',
        submitter_name='株式会社クラレ',
        submitter_name_en='KURARAY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクラレ',
        address='倉敷市酒津１６２１番地',
        industry='化学',
        sec_code='34050',
        corporate_number='1260001013156',
    ),
    'E00877': EdinetCodeEntry(
        edinet_code='E00877',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=103389,
        fiscal_year_end='3月31日',
        submitter_name='旭化成株式会社',
        submitter_name_en='Asahi Kasei Corporation',
        submitter_name_yomi='アサヒカセイカブシキガイシャ',
        address='千代田区有楽町一丁目１番２号',
        industry='化学',
        sec_code='34070',
        corporate_number='5120001059606',
    ),
    'E00878': EdinetCodeEntry(
        edinet_code='E00878',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23048,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＤＥＫＡ',
        submitter_name_en='ADEKA CORPORATION',
        submitter_name_yomi='カブシキガイシャアデカ',
        address='荒川区東尾久七丁目２番３５号',
        industry='化学',
        sec_code='44010',
        corporate_number='1011501009437',
    ),
    'E00879': EdinetCodeEntry(
        edinet_code='E00879',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33046,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カネカ',
        submitter_name_en='KANEKA CORPORATION',
        submitter_name_yomi='カブシキガイシャカネカ',
        address='大阪市北区中之島二丁目３番１８号',
        industry='化学',
        sec_code='41180',
        corporate_number='8120001059628',
    ),
    'E00880': EdinetCodeEntry(
        edinet_code='E00880',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17742,
        fiscal_year_end='3月31日',
        submitter_name='日油株式会社',
        submitter_name_en='NOF CORPORATION',
        submitter_name_yomi='ニチユカブシキガイシャ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='化学',
        sec_code='44030',
        corporate_number='1011001025967',
    ),
    'E00881': EdinetCodeEntry(
        edinet_code='E00881',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9015,
        fiscal_year_end='12月31日',
        submitter_name='ミヨシ油脂株式会社',
        submitter_name_en='MiyoshiOil&FatCo.,Ltd.',
        submitter_name_yomi='ミヨシユシカブシキガイシャ',
        address='葛飾区堀切四丁目３６番５号',
        industry='食料品',
        sec_code='44040',
        corporate_number='2011801004789',
    ),
    'E00882': EdinetCodeEntry(
        edinet_code='E00882',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5660,
        fiscal_year_end='3月31日',
        submitter_name='新日本理化株式会社',
        submitter_name_en='New Japan Chemical Co., Ltd.',
        submitter_name_yomi='シンニホンリカカブシキガイシャ',
        address='京都市伏見区葭島矢倉町１３番地',
        industry='化学',
        sec_code='44060',
        corporate_number='5130001014766',
    ),
    'E00883': EdinetCodeEntry(
        edinet_code='E00883',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=85424,
        fiscal_year_end='12月31日',
        submitter_name='花王株式会社',
        submitter_name_en='Kao Corporation',
        submitter_name_yomi='カオウカブシキガイシャ',
        address='中央区日本橋茅場町一丁目１４番１０号',
        industry='化学',
        sec_code='44520',
        corporate_number='4010001034760',
    ),
    'E00884': EdinetCodeEntry(
        edinet_code='E00884',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13051,
        fiscal_year_end='3月31日',
        submitter_name='三洋化成工業株式会社',
        submitter_name_en='SANYO CHEMICAL INDUSTRIES,LTD.',
        submitter_name_yomi='サンヨウカセイコウギョウカブシキガイシャ',
        address='京都市東山区一橋野本町１１－１',
        industry='化学',
        sec_code='44710',
        corporate_number='3130001009314',
    ),
    'E00885': EdinetCodeEntry(
        edinet_code='E00885',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8895,
        fiscal_year_end='3月31日',
        submitter_name='第一工業製薬株式会社',
        submitter_name_en='DKS Co. Ltd.',
        submitter_name_yomi='ダイイチコウギョウセイヤクカブシガイシャ',
        address='京都市下京区西七条東久保町５５番地',
        industry='化学',
        sec_code='44610',
        corporate_number='7130001017809',
    ),
    'E00886': EdinetCodeEntry(
        edinet_code='E00886',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1755,
        fiscal_year_end='3月31日',
        submitter_name='東邦化学工業株式会社',
        submitter_name_en='TOHO CHEMICAL INDUSTRY COMPANY,LIMITED',
        submitter_name_yomi='トウホウカガクコウギョウカブシキガイシャ',
        address='中央区明石町６番４号',
        industry='化学',
        sec_code='44090',
        corporate_number='5010001034850',
    ),
    'E00887': EdinetCodeEntry(
        edinet_code='E00887',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2898,
        fiscal_year_end='12月31日',
        submitter_name='日華化学株式会社',
        submitter_name_en='NICCA CHEMICAL CO.,LTD.',
        submitter_name_yomi='ニッカカガクカブシキガイシャ',
        address='福井市文京４丁目２３番１号',
        industry='化学',
        sec_code='44630',
        corporate_number='1210001002667',
    ),
    'E00888': EdinetCodeEntry(
        edinet_code='E00888',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6090,
        fiscal_year_end='3月31日',
        submitter_name='松本油脂製薬株式会社',
        submitter_name_en='MATSUMOTO YUSHI-SEIYAKU CO.,LTD.',
        submitter_name_yomi='マツモトユシセイヤクカブシキガイシャ',
        address='八尾市渋川町２丁目１番３号',
        industry='化学',
        sec_code='43650',
        corporate_number='7122001020132',
    ),
    'E00889': EdinetCodeEntry(
        edinet_code='E00889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=842,
        fiscal_year_end=None,
        submitter_name='互応化学工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゴオウカガクコウギョウカブシキガイシャ',
        address='宇治市伊勢田町井尻５８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9130001032599',
    ),
    'E00890': EdinetCodeEntry(
        edinet_code='E00890',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=585,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ニイタカ',
        submitter_name_en='Niitaka Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニイタカ',
        address='大阪市淀川区新高一丁目８番１０号',
        industry='化学',
        sec_code='44650',
        corporate_number='9120001056079',
    ),
    'E00891': EdinetCodeEntry(
        edinet_code='E00891',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8827,
        fiscal_year_end='3月31日',
        submitter_name='大日本塗料株式会社',
        submitter_name_en='Dai Nippon Toryo Company, Limited',
        submitter_name_yomi='ダイニッポントリョウカブシキガイシャ',
        address='大阪市中央区南船場１－１８－１１',
        industry='化学',
        sec_code='46110',
        corporate_number='1120001026551',
    ),
    'E00892': EdinetCodeEntry(
        edinet_code='E00892',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=671432,
        fiscal_year_end='12月31日',
        submitter_name='日本ペイントホールディングス株式会社',
        submitter_name_en='NIPPON PAINT HOLDINGS CO.,LTD.',
        submitter_name_yomi='ニッポンペイントホールディングスカブシキガイシャ',
        address='大阪市北区大淀北２－１－２',
        industry='化学',
        sec_code='46120',
        corporate_number='7120001072994',
    ),
    'E00893': EdinetCodeEntry(
        edinet_code='E00893',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25658,
        fiscal_year_end='3月31日',
        submitter_name='関西ペイント株式会社',
        submitter_name_en='KANSAI PAINT CO.,LTD.',
        submitter_name_yomi='カンサイペイントカブシキガイシャ',
        address='尼崎市神崎町３３番１号',
        industry='化学',
        sec_code='46130',
        corporate_number='5140001048243',
    ),
    'E00895': EdinetCodeEntry(
        edinet_code='E00895',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2255,
        fiscal_year_end='3月31日',
        submitter_name='神東塗料株式会社',
        submitter_name_en='SHINTO PAINT COMPANY, LIMITED',
        submitter_name_yomi='シントウトリョウカブシキガイシャ',
        address='尼崎市南塚口町六丁目１０番７３号',
        industry='化学',
        sec_code='46150',
        corporate_number='7140001049181',
    ),
    'E00896': EdinetCodeEntry(
        edinet_code='E00896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='11月30日',
        submitter_name='川上塗料株式会社',
        submitter_name_en='KAWAKAMI PAINT MANUFACTURING CO.,LTD.',
        submitter_name_yomi='カワカミトリョウカブシキガイシャ',
        address='尼崎市塚口本町２丁目４１番１号',
        industry='化学',
        sec_code='46160',
        corporate_number='4140001048351',
    ),
    'E00897': EdinetCodeEntry(
        edinet_code='E00897',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11626,
        fiscal_year_end='3月31日',
        submitter_name='中国塗料株式会社',
        submitter_name_en='CHUGOKU MARINE PAINTS,LTD.',
        submitter_name_yomi='チュウゴクトリョウカブシキガイシャ',
        address='大竹市明治新開１番７',
        industry='化学',
        sec_code='46170',
        corporate_number='1240001028478',
    ),
    'E00898': EdinetCodeEntry(
        edinet_code='E00898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4560,
        fiscal_year_end='3月31日',
        submitter_name='日本パーカライジング株式会社',
        submitter_name_en='NIHON PARKERIZING CO., LTD.',
        submitter_name_yomi='ニホンパーカライジングカブシキガイシャ',
        address='中央区日本橋二丁目１６－８',
        industry='化学',
        sec_code='40950',
        corporate_number='1010001034994',
    ),
    'E00899': EdinetCodeEntry(
        edinet_code='E00899',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1481,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本ピグメントホールディングス',
        submitter_name_en='Nippon Pigment Holdings Company Limited',
        submitter_name_yomi='カブシキガイシャニホンピグメントホールディングス',
        address='千代田区神田錦町三丁目２０番',
        industry='化学',
        sec_code='41190',
        corporate_number='4010001008839',
    ),
    'E00900': EdinetCodeEntry(
        edinet_code='E00900',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4753,
        fiscal_year_end='3月31日',
        submitter_name='日本特殊塗料株式会社',
        submitter_name_en='Nihon Tokushu Toryo Co., Ltd.',
        submitter_name_yomi='ニホントクシュトリョウカブシキガイシャ',
        address='北区王子三丁目２３番２号',
        industry='化学',
        sec_code='46190',
        corporate_number='1011501003539',
    ),
    'E00901': EdinetCodeEntry(
        edinet_code='E00901',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=96557,
        fiscal_year_end='12月31日',
        submitter_name='ＤＩＣ株式会社',
        submitter_name_en='DIC Corporation',
        submitter_name_yomi='ディーアイシーカブシキガイシャ',
        address='板橋区坂下３丁目３５番５８号',
        industry='化学',
        sec_code='46310',
        corporate_number='7011401003807',
    ),
    'E00902': EdinetCodeEntry(
        edinet_code='E00902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10039,
        fiscal_year_end='3月31日',
        submitter_name='大日精化工業株式会社',
        submitter_name_en='Dainichiseika Color & Chemicals Mfg. Co., Ltd.',
        submitter_name_yomi='ダイニチセイカコウギョウカブシキガイシャ',
        address='中央区日本橋馬喰町一丁目７番６号',
        industry='化学',
        sec_code='41160',
        corporate_number='4010001034868',
    ),
    'E00903': EdinetCodeEntry(
        edinet_code='E00903',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31733,
        fiscal_year_end='12月31日',
        submitter_name='ａｒｔｉｅｎｃｅ株式会社',
        submitter_name_en='artience Co., Ltd.',
        submitter_name_yomi='アーティエンスカブシキガイシャ',
        address='中央区京橋二丁目２番１号',
        industry='化学',
        sec_code='46340',
        corporate_number='3010001034844',
    ),
    'E00904': EdinetCodeEntry(
        edinet_code='E00904',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3246,
        fiscal_year_end='3月31日',
        submitter_name='東京インキ株式会社',
        submitter_name_en='TOKYO PRINTING INK MFG. CO., LTD.',
        submitter_name_yomi='トウキョウインキカブシキガイシャ',
        address='北区王子１丁目１２番４号ＴＩＣ王子ビル',
        industry='化学',
        sec_code='46350',
        corporate_number='8011501003045',
    ),
    'E00905': EdinetCodeEntry(
        edinet_code='E00905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7472,
        fiscal_year_end='12月31日',
        submitter_name='サカタインクス株式会社',
        submitter_name_en='SAKATA INX CORPORATION',
        submitter_name_yomi='サカタインクスカブシキガイシャ',
        address='大阪市中央区淡路町４丁目２番１３号アーバンネット御堂筋ビル',
        industry='化学',
        sec_code='46330',
        corporate_number='2120001043471',
    ),
    'E00906': EdinetCodeEntry(
        edinet_code='E00906',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2510,
        fiscal_year_end='3月31日',
        submitter_name='スガイ化学工業株式会社',
        submitter_name_en='SUGAI CHEMICAL INDUSTRY CO., LTD.',
        submitter_name_yomi='スガイカガクコウギョウカブシキカイシャ',
        address='和歌山市宇須四丁目４番６号',
        industry='化学',
        sec_code='41200',
        corporate_number='4170001001687',
    ),
    'E00907': EdinetCodeEntry(
        edinet_code='E00907',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1100,
        fiscal_year_end=None,
        submitter_name='ロックペイント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ロックペイントカブシキガイシャ',
        address='大阪市西淀川区姫島３丁目１番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001050883',
    ),
    'E00909': EdinetCodeEntry(
        edinet_code='E00909',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アサヒペン',
        submitter_name_en='ASAHIPEN CORPORATION',
        submitter_name_yomi='カブシキガイシャアサヒペン',
        address='大阪市鶴見区鶴見４丁目１番１２号',
        industry='化学',
        sec_code='46230',
        corporate_number='4120001001403',
    ),
    'E00910': EdinetCodeEntry(
        edinet_code='E00910',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1290,
        fiscal_year_end='3月31日',
        submitter_name='イサム塗料株式会社',
        submitter_name_en='Isamu Paint co., Ltd.',
        submitter_name_yomi='イサムトリョウカブシキガイシャ',
        address='大阪市福島区鷺洲２丁目１５番２４号',
        industry='化学',
        sec_code='46240',
        corporate_number='8120001034242',
    ),
    'E00911': EdinetCodeEntry(
        edinet_code='E00911',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1040,
        fiscal_year_end='3月31日',
        submitter_name='アトミクス株式会社',
        submitter_name_en='ATOMIX CO., LTD.',
        submitter_name_yomi='アトミクスカブシキガイシャ',
        address='板橋区舟渡三丁目９番６号',
        industry='化学',
        sec_code='46250',
        corporate_number='5011401000351',
    ),
    'E00912': EdinetCodeEntry(
        edinet_code='E00912',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1972,
        fiscal_year_end='3月31日',
        submitter_name='菊水化学工業株式会社',
        submitter_name_en='KIKUSUI CHEMICAL INDUSTRIES CO.,LTD.',
        submitter_name_yomi='キクスイカガクコウギョウカブシキガイシャ',
        address='名古屋市中区栄一丁目３番３号ＡＭＭＮＡＴビル',
        industry='その他製品',
        sec_code='79530',
        corporate_number='9180001029938',
    ),
    'E00913': EdinetCodeEntry(
        edinet_code='E00913',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10206,
        fiscal_year_end='3月31日',
        submitter_name='太陽ホールディングス株式会社',
        submitter_name_en='TAIYO HOLDINGS CO., LTD.',
        submitter_name_yomi='タイヨウホールディングスカブシキガイシャ',
        address='比企郡嵐山町大字大蔵３８８番地',
        industry='化学',
        sec_code='46260',
        corporate_number='3011601003833',
    ),
    'E00915': EdinetCodeEntry(
        edinet_code='E00915',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1626,
        fiscal_year_end='10月31日',
        submitter_name='ナトコ株式会社',
        submitter_name_en='NATOCO CO.,LTD.',
        submitter_name_yomi='ナトコカブシキガイシャ',
        address='みよし市打越町生賀山１８番地',
        industry='化学',
        sec_code='46270',
        corporate_number='1180301019737',
    ),
    'E00916': EdinetCodeEntry(
        edinet_code='E00916',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2662,
        fiscal_year_end='3月31日',
        submitter_name='エスケー化研株式会社',
        submitter_name_en='SK KAKEN CO.,LTD.',
        submitter_name_yomi='エスケーカケンカブシキガイシャ',
        address='茨木市中穂積三丁目５番２５号',
        industry='化学',
        sec_code='46280',
        corporate_number='5120901000305',
    ),
    'E00917': EdinetCodeEntry(
        edinet_code='E00917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=729,
        fiscal_year_end='3月31日',
        submitter_name='大伸化学株式会社',
        submitter_name_en='DAISHIN CHEMICAL CO.,LTD.',
        submitter_name_yomi='ダイシンカガクカブシキガイシャ',
        address='港区芝大門１－９－９',
        industry='化学',
        sec_code='46290',
        corporate_number='6010401016497',
    ),
    'E00919': EdinetCodeEntry(
        edinet_code='E00919',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=77923,
        fiscal_year_end='3月31日',
        submitter_name='武田薬品工業株式会社',
        submitter_name_en='Takeda Pharmaceutical Company Limited',
        submitter_name_yomi='タケダヤクヒンコウギョウカブシキカイシャ',
        address='大阪市中央区道修町四丁目１番１号',
        industry='医薬品',
        sec_code='45020',
        corporate_number='2120001077461',
    ),
    'E00920': EdinetCodeEntry(
        edinet_code='E00920',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=103001,
        fiscal_year_end='3月31日',
        submitter_name='アステラス製薬株式会社',
        submitter_name_en='Astellas Pharma Inc.',
        submitter_name_yomi='アステラスセイヤクカブシキガイシャ',
        address='中央区日本橋本町二丁目５番１号',
        industry='医薬品',
        sec_code='45030',
        corporate_number='5010001034966',
    ),
    'E00922': EdinetCodeEntry(
        edinet_code='E00922',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22400,
        fiscal_year_end='3月31日',
        submitter_name='住友ファーマ株式会社',
        submitter_name_en='Sumitomo Pharma Co., Ltd.',
        submitter_name_yomi='スミトモファーマカブシキガイシャ',
        address='大阪市中央区道修町２丁目６番８号',
        industry='医薬品',
        sec_code='45060',
        corporate_number='3120001077477',
    ),
    'E00923': EdinetCodeEntry(
        edinet_code='E00923',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21279,
        fiscal_year_end='3月31日',
        submitter_name='塩野義製薬株式会社',
        submitter_name_en='Shionogi & Co.,Ltd.',
        submitter_name_yomi='シオノギセイヤクカブシキガイシャ',
        address='大阪市中央区道修町３丁目１番８号',
        industry='医薬品',
        sec_code='45070',
        corporate_number='9120001077430',
    ),
    'E00924': EdinetCodeEntry(
        edinet_code='E00924',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50000,
        fiscal_year_end=None,
        submitter_name='田辺三菱製薬株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タナベミツビシセイヤクカブシキガイシャ',
        address='大阪市中央区道修町三丁目２番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001077463',
    ),
    'E00926': EdinetCodeEntry(
        edinet_code='E00926',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11768,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テーオーシー',
        submitter_name_en='TOC Co.,Ltd',
        submitter_name_yomi='カブシキガイシャテーオーシー',
        address='品川区西五反田７－２２－１７',
        industry='不動産業',
        sec_code='88410',
        corporate_number='1010701006145',
    ),
    'E00928': EdinetCodeEntry(
        edinet_code='E00928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3395,
        fiscal_year_end='3月31日',
        submitter_name='わかもと製薬株式会社',
        submitter_name_en='WAKAMOTO PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='ワカモトセイヤクカブシキガイシャ',
        address='中央区日本橋本町二丁目２番２号',
        industry='医薬品',
        sec_code='45120',
        corporate_number='1010001035010',
    ),
    'E00929': EdinetCodeEntry(
        edinet_code='E00929',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1197,
        fiscal_year_end='3月31日',
        submitter_name='あすか製薬株式会社',
        submitter_name_en='ASKA pharmaceutical Co., Ltd.',
        submitter_name_yomi='アスカセイヤクカブシキガイシャ',
        address='港区芝浦二丁目５番１号',
        industry='医薬品',
        sec_code=None,
        corporate_number='9010401018375',
    ),
    'E00931': EdinetCodeEntry(
        edinet_code='E00931',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5174,
        fiscal_year_end='3月31日',
        submitter_name='日本新薬株式会社',
        submitter_name_en='Nippon Shinyaku Co.,Ltd.',
        submitter_name_yomi='ニッポンシンヤクカブシキガイシャ',
        address='京都市南区吉祥院西ノ庄門口町１４番地',
        industry='医薬品',
        sec_code='45160',
        corporate_number='2130001012236',
    ),
    'E00932': EdinetCodeEntry(
        edinet_code='E00932',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=73201,
        fiscal_year_end='12月31日',
        submitter_name='中外製薬株式会社',
        submitter_name_en='CHUGAI PHARMACEUTICAL CO., LTD.',
        submitter_name_yomi='チュウガイセイヤクカブシキガイシャ',
        address='北区浮間五丁目５番１号',
        industry='医薬品',
        sec_code='45190',
        corporate_number='5011501002900',
    ),
    'E00934': EdinetCodeEntry(
        edinet_code='E00934',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=5190,
        fiscal_year_end='3月31日',
        submitter_name='鳥居薬品株式会社',
        submitter_name_en='TORII PHARMACEUTICAL CO., LTD.',
        submitter_name_yomi='トリイヤクヒンカブシキガイシャ',
        address='中央区日本橋本町三丁目４番１号',
        industry='医薬品',
        sec_code=None,
        corporate_number='4010001052143',
    ),
    'E00935': EdinetCodeEntry(
        edinet_code='E00935',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23853,
        fiscal_year_end='3月31日',
        submitter_name='科研製薬株式会社',
        submitter_name_en='KAKEN PHARMACEUTIAL CO., LTD.',
        submitter_name_yomi='カケンセイヤクカブシキガイシャ',
        address='文京区本駒込二丁目２８番８号',
        industry='医薬品',
        sec_code='45210',
        corporate_number='4010001000003',
    ),
    'E00937': EdinetCodeEntry(
        edinet_code='E00937',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14939,
        fiscal_year_end='3月31日',
        submitter_name='日本農薬株式会社',
        submitter_name_en='NIHON NOHYAKU CO., LTD.',
        submitter_name_yomi='ニホンノウヤクカブシキガイシャ',
        address='中央区京橋一丁目１９番８号',
        industry='化学',
        sec_code='49970',
        corporate_number='2010001034985',
    ),
    'E00939': EdinetCodeEntry(
        edinet_code='E00939',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=44986,
        fiscal_year_end='3月31日',
        submitter_name='エーザイ株式会社',
        submitter_name_en='Eisai Co., Ltd.',
        submitter_name_yomi='エーザイカブシキガイシャ',
        address='文京区小石川４丁目６番１０号',
        industry='医薬品',
        sec_code='45230',
        corporate_number='6010001000001',
    ),
    'E00941': EdinetCodeEntry(
        edinet_code='E00941',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3537,
        fiscal_year_end='3月31日',
        submitter_name='森下仁丹株式会社',
        submitter_name_en='MORISHITA JINTAN CO.,LTD.',
        submitter_name_yomi='モリシタジンタンカブシキガイシャ',
        address='大阪市中央区玉造一丁目２番４０号',
        industry='医薬品',
        sec_code='45240',
        corporate_number='8120001077571',
    ),
    'E00942': EdinetCodeEntry(
        edinet_code='E00942',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6504,
        fiscal_year_end='3月31日',
        submitter_name='ロート製薬株式会社',
        submitter_name_en='ROHTO PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='ロートセイヤクカブシキガイシャ',
        address='大阪市生野区巽西１丁目８番１号',
        industry='医薬品',
        sec_code='45270',
        corporate_number='6120001019253',
    ),
    'E00944': EdinetCodeEntry(
        edinet_code='E00944',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8473,
        fiscal_year_end='2月末日',
        submitter_name='久光製薬株式会社',
        submitter_name_en='HISAMITSU PHARMACEUTICAL CO.,INC.',
        submitter_name_yomi='ヒサミツセイヤクカブシキガイシャ',
        address='鳥栖市田代大官町４０８番地',
        industry='医薬品',
        sec_code='45300',
        corporate_number='7300001006281',
    ),
    'E00945': EdinetCodeEntry(
        edinet_code='E00945',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17358,
        fiscal_year_end='3月31日',
        submitter_name='小野薬品工業株式会社',
        submitter_name_en='ONO PHARMACEUTICAL CO., LTD.',
        submitter_name_yomi='オノヤクヒンコウギョウカブシキガイシャ',
        address='大阪市中央区道修町二丁目１番５号',
        industry='医薬品',
        sec_code='45280',
        corporate_number='7120001077374',
    ),
    'E00947': EdinetCodeEntry(
        edinet_code='E00947',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7229,
        fiscal_year_end='3月31日',
        submitter_name='持田製薬株式会社',
        submitter_name_en='Mochida Pharmaceutical Co.,Ltd.',
        submitter_name_yomi='モチダセイヤクカブシキガイシャ',
        address='新宿区四谷一丁目７番地',
        industry='医薬品',
        sec_code='45340',
        corporate_number='9011101021173',
    ),
    'E00948': EdinetCodeEntry(
        edinet_code='E00948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6593,
        fiscal_year_end='3月31日',
        submitter_name='ゼリア新薬工業株式会社',
        submitter_name_en='ZERIA PHARMCEUTICAL CO., LTD.',
        submitter_name_yomi='ゼリアシンヤクコウギョウカブシキガイシャ',
        address='中央区日本橋小舟町１０番１１号',
        industry='医薬品',
        sec_code='45590',
        corporate_number='7010001034790',
    ),
    'E00949': EdinetCodeEntry(
        edinet_code='E00949',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8678,
        fiscal_year_end='3月31日',
        submitter_name='参天製薬株式会社',
        submitter_name_en='SANTEN PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='サンテンセイヤクカブシキガイシャ',
        address='大阪市北区大深町４番２０号',
        industry='医薬品',
        sec_code='45360',
        corporate_number='5120001051819',
    ),
    'E00952': EdinetCodeEntry(
        edinet_code='E00952',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2537,
        fiscal_year_end='3月31日',
        submitter_name='理研ビタミン株式会社',
        submitter_name_en='Riken Vitamin Co., Ltd.',
        submitter_name_yomi='リケンビタミンカブシキガイシャ',
        address='新宿区四谷一丁目６番１号',
        industry='食料品',
        sec_code='45260',
        corporate_number='3010001008815',
    ),
    'E00953': EdinetCodeEntry(
        edinet_code='E00953',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10758,
        fiscal_year_end='3月31日',
        submitter_name='扶桑薬品工業株式会社',
        submitter_name_en='Fuso Pharmaceutical Industries,Ltd.',
        submitter_name_yomi='フソウヤクヒンコウギョウカブシキガイシャ',
        address='大阪市中央区道修町一丁目７番１０号',
        industry='医薬品',
        sec_code='45380',
        corporate_number='5120001077541',
    ),
    'E00954': EdinetCodeEntry(
        edinet_code='E00954',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='7月31日',
        submitter_name='佐藤製薬株式会社',
        submitter_name_en='SATO PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='サトウセイヤクカブシキガイシャ',
        address='港区元赤坂１丁目５番２７号',
        industry='医薬品',
        sec_code=None,
        corporate_number='2010401011411',
    ),
    'E00955': EdinetCodeEntry(
        edinet_code='E00955',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='森田薬品工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モリタヤクヒンコウギョウカブシキガイシャ',
        address='福山市大門町野々浜１０５９番地',
        industry='医薬品',
        sec_code=None,
        corporate_number='3010001059008',
    ),
    'E00956': EdinetCodeEntry(
        edinet_code='E00956',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=20000,
        fiscal_year_end='12月31日',
        submitter_name='大塚製薬株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオツカセイヤクカブシキカイシャ',
        address='千代田区神田司町２－９',
        industry='医薬品',
        sec_code=None,
        corporate_number='7010001012986',
    ),
    'E00957': EdinetCodeEntry(
        edinet_code='E00957',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4304,
        fiscal_year_end='3月31日',
        submitter_name='日本ケミファ株式会社',
        submitter_name_en='NIPPON CHEMIPHAR CO., LTD.',
        submitter_name_yomi='ニッポンケミファカブシキガイシャ',
        address='千代田区岩本町二丁目２番３号',
        industry='医薬品',
        sec_code='45390',
        corporate_number='5010001033101',
    ),
    'E00959': EdinetCodeEntry(
        edinet_code='E00959',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000廣貫堂',
        submitter_name_en='KOKANDO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000コウカンドウ',
        address='富山市梅沢町２丁目９番１号',
        industry='医薬品',
        sec_code=None,
        corporate_number='4230001000864',
    ),
    'E00960': EdinetCodeEntry(
        edinet_code='E00960',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1227,
        fiscal_year_end=None,
        submitter_name='ビオフェルミン製薬株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビオフェルミンセイヤクカブシキガイシャ',
        address='神戸市中央区三宮町一丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001016697',
    ),
    'E00961': EdinetCodeEntry(
        edinet_code='E00961',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6897,
        fiscal_year_end='3月31日',
        submitter_name='栄研化学株式会社',
        submitter_name_en='EIKEN CHEMICAL CO.,LTD.',
        submitter_name_yomi='エイケンカガクカブシキガイシャ',
        address='千代田区神田駿河台四丁目６番地',
        industry='医薬品',
        sec_code='45490',
        corporate_number='2010501028231',
    ),
    'E00962': EdinetCodeEntry(
        edinet_code='E00962',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24356,
        fiscal_year_end='3月31日',
        submitter_name='キッセイ薬品工業株式会社',
        submitter_name_en='KISSEI PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='キッセイヤクヒンコウギョウカブシキガイシャ',
        address='松本市芳野１９番４８号',
        industry='医薬品',
        sec_code='45470',
        corporate_number='1100001012982',
    ),
    'E00963': EdinetCodeEntry(
        edinet_code='E00963',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日医工株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニチイコウカブシキカイシャ',
        address='富山市総曲輪一丁目６番２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1230001002236',
    ),
    'E00965': EdinetCodeEntry(
        edinet_code='E00965',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1415,
        fiscal_year_end='3月31日',
        submitter_name='千寿製薬株式会社',
        submitter_name_en='SENJU PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='センジュセイヤクカブシキガイシャ',
        address='大阪市中央区瓦町三丁目１番９号',
        industry='医薬品',
        sec_code=None,
        corporate_number='7120001082721',
    ),
    'E00966': EdinetCodeEntry(
        edinet_code='E00966',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2339,
        fiscal_year_end=None,
        submitter_name='和光純薬工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワコウジュンヤクコウギョウカブシキガイシャ',
        address='大阪市中央区道修町三丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001077597',
    ),
    'E00967': EdinetCodeEntry(
        edinet_code='E00967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9147,
        fiscal_year_end='3月31日',
        submitter_name='Ｈ．Ｕ．グループホールディングス株式会社',
        submitter_name_en='H.U. Group Holdings, Inc.',
        submitter_name_yomi='エイチユーグループホールディングスカブシキガイシャ',
        address='新宿区西新宿二丁目１番１号',
        industry='サービス業',
        sec_code='45440',
        corporate_number='1011101039628',
    ),
    'E00970': EdinetCodeEntry(
        edinet_code='E00970',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3840,
        fiscal_year_end='3月31日',
        submitter_name='生化学工業株式会社',
        submitter_name_en='SEIKAGAKU CORPORATION',
        submitter_name_yomi='セイカガクコウギョウカブシキガイシャ',
        address='千代田区丸の内一丁目６番１号',
        industry='医薬品',
        sec_code='45480',
        corporate_number='9010001048285',
    ),
    'E00971': EdinetCodeEntry(
        edinet_code='E00971',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4449,
        fiscal_year_end='3月31日',
        submitter_name='日水製薬株式会社',
        submitter_name_en='Nissui Pharmaceutical  Co.,  Ltd.',
        submitter_name_yomi='ニッスイセイヤクカブシキガイシャ',
        address='台東区上野三丁目２４番６号',
        industry='医薬品',
        sec_code=None,
        corporate_number='9010501023044',
    ),
    'E00973': EdinetCodeEntry(
        edinet_code='E00973',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9061,
        fiscal_year_end='3月31日',
        submitter_name='ＪＣＲファーマ株式会社',
        submitter_name_en='JCR Pharmaceuticals Co.,Ltd.',
        submitter_name_yomi='ジェーシーアールファーマカブシキガイシャ',
        address='芦屋市春日町３番１９号',
        industry='医薬品',
        sec_code='45520',
        corporate_number='6140001000905',
    ),
    'E00974': EdinetCodeEntry(
        edinet_code='E00974',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4717,
        fiscal_year_end='3月31日',
        submitter_name='東和薬品株式会社',
        submitter_name_en='TOWA PHARMACEUTICAL CO.,LTD.',
        submitter_name_yomi='トウワヤクヒンカブシキガイシャ',
        address='門真市新橋町２番１１号',
        industry='医薬品',
        sec_code='45530',
        corporate_number='4120001157872',
    ),
    'E00975': EdinetCodeEntry(
        edinet_code='E00975',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3799,
        fiscal_year_end='9月30日',
        submitter_name='富士製薬工業株式会社',
        submitter_name_en='Fuji Pharma Co.,Ltd.',
        submitter_name_yomi='フジセイヤクコウギョウカブシキガイシャ',
        address='千代田区三番町５番地７',
        industry='医薬品',
        sec_code='45540',
        corporate_number='5010001084045',
    ),
    'E00976': EdinetCodeEntry(
        edinet_code='E00976',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41218,
        fiscal_year_end=None,
        submitter_name='沢井製薬株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サワイセイヤクカブシキカイシャ',
        address='大阪市淀川区宮原五丁目２番３０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001000479',
    ),
    'E00977': EdinetCodeEntry(
        edinet_code='E00977',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=831,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カイノス',
        submitter_name_en='kainos loboratories,inc',
        submitter_name_yomi='カブシキガイシャカイノス',
        address='文京区本郷二丁目３８番１８号',
        industry='医薬品',
        sec_code='45560',
        corporate_number='5010001001710',
    ),
    'E00978': EdinetCodeEntry(
        edinet_code='E00978',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4482,
        fiscal_year_end='3月31日',
        submitter_name='株式会社医学生物学研究所',
        submitter_name_en='MEDICAL&BIOLOGICAL LABORATORIES CO., LTD.',
        submitter_name_yomi='カブシキガイシャイガクセイブツガクケンキュウショ',
        address='港区芝大門２丁目１１番８号',
        industry='医薬品',
        sec_code=None,
        corporate_number='7180001027794',
    ),
    'E00981': EdinetCodeEntry(
        edinet_code='E00981',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=46807,
        fiscal_year_end='12月31日',
        submitter_name='ネクセラファーマ株式会社',
        submitter_name_en='Nxera Pharma Co., Ltd.',
        submitter_name_yomi='ネクセラファーマカブシキガイシャ',
        address='港区赤坂９－７－２',
        industry='医薬品',
        sec_code='45650',
        corporate_number='4010001021288',
    ),
    'E00982': EdinetCodeEntry(
        edinet_code='E00982',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＬＴＴバイオファーマ',
        submitter_name_en='LTT Bio-Pharma Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエルティーティーバイオファーマ',
        address='港区海岸一丁目２番２０号',
        industry='医薬品',
        sec_code=None,
        corporate_number='8010401049314',
    ),
    'E00984': EdinetCodeEntry(
        edinet_code='E00984',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='第一三共株式会社',
        submitter_name_en='DAIICHI SANKYO COMPANY, LIMITED',
        submitter_name_yomi='ダイイチサンキョウカブシキガイシャ',
        address='中央区日本橋本町三丁目５番１号',
        industry='医薬品',
        sec_code='45680',
        corporate_number='1010001095640',
    ),
    'E00985': EdinetCodeEntry(
        edinet_code='E00985',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=700,
        fiscal_year_end='3月31日',
        submitter_name='杏林製薬株式会社',
        submitter_name_en='KYORIN Pharmaceutical Co., Ltd.',
        submitter_name_yomi='キョウリンセイヤクカブシキガイシャ',
        address='千代田区大手町一丁目３番７号',
        industry='医薬品',
        sec_code='45690',
        corporate_number='8010001096491',
    ),
    'E00986': EdinetCodeEntry(
        edinet_code='E00986',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社免疫生物研究所',
        submitter_name_en='Immuno-Biological Laboratories Co., Ltd.',
        submitter_name_yomi='カブシキガイシャメンエキセイブツケンキュウジョ',
        address='藤岡市中字東田１０９１番地１',
        industry='医薬品',
        sec_code='45700',
        corporate_number='8070001009687',
    ),
    'E00987': EdinetCodeEntry(
        edinet_code='E00987',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=558,
        fiscal_year_end='12月末日',
        submitter_name='カルナバイオサイエンス株式会社',
        submitter_name_en='Carna Biosciences, Inc.',
        submitter_name_yomi='カルナバイオサイエンスカブシキガイシャ',
        address='神戸市中央区港島南町一丁目５番５号',
        industry='医薬品',
        sec_code='45720',
        corporate_number='8140001022724',
    ),
    'E00988': EdinetCodeEntry(
        edinet_code='E00988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40363,
        fiscal_year_end='3月31日',
        submitter_name='富士フイルムホールディングス株式会社',
        submitter_name_en='FUJIFILM Holdings Corporation',
        submitter_name_yomi='フジフイルムホールディングスカブシキガイシャ',
        address='港区西麻布２丁目２６番３０号',
        industry='化学',
        sec_code='49010',
        corporate_number='6010401065370',
    ),
    'E00989': EdinetCodeEntry(
        edinet_code='E00989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37519,
        fiscal_year_end='3月31日',
        submitter_name='コニカミノルタ株式会社',
        submitter_name_en='KONICA MINOLTA, INC.',
        submitter_name_yomi='コニカミノルタカブシキガイシャ',
        address='千代田区丸の内二丁目７番２号',
        industry='電気機器',
        sec_code='49020',
        corporate_number='5010001084367',
    ),
    'E00990': EdinetCodeEntry(
        edinet_code='E00990',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=64506,
        fiscal_year_end='12月31日',
        submitter_name='株式会社資生堂',
        submitter_name_en='Shiseido Company, Limited',
        submitter_name_yomi='カブシキガイシャシセイドウ',
        address='中央区銀座七丁目５番５号',
        industry='化学',
        sec_code='49110',
        corporate_number='1010001034813',
    ),
    'E00991': EdinetCodeEntry(
        edinet_code='E00991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=34433,
        fiscal_year_end='12月31日',
        submitter_name='ライオン株式会社',
        submitter_name_en='Lion Corporation',
        submitter_name_yomi='ライオンカブシキガイシャ',
        address='台東区蔵前１－３－２８',
        industry='化学',
        sec_code='49120',
        corporate_number='1010601016863',
    ),
    'E00993': EdinetCodeEntry(
        edinet_code='E00993',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9248,
        fiscal_year_end='3月31日',
        submitter_name='高砂香料工業株式会社',
        submitter_name_en='TAKASAGO INTERNATIONAL CORPORATION',
        submitter_name_yomi='タカサゴコウリョウコウギョウカブシキガイシャ',
        address='大田区蒲田五丁目３７番１号',
        industry='化学',
        sec_code='49140',
        corporate_number='2010801006894',
    ),
    'E00994': EdinetCodeEntry(
        edinet_code='E00994',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1810,
        fiscal_year_end='3月31日',
        submitter_name='共和レザー株式会社',
        submitter_name_en='KYOWA LEATHER CLOTH CO.,LTD',
        submitter_name_yomi='キョウワレザーカブシキガイシャ',
        address='浜松市南区東町１８７６番地',
        industry='化学',
        sec_code='35530',
        corporate_number='9080401001465',
    ),
    'E00995': EdinetCodeEntry(
        edinet_code='E00995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6855,
        fiscal_year_end='3月31日',
        submitter_name='東リ株式会社',
        submitter_name_en='TOLI  Corporation',
        submitter_name_yomi='トウリカブシキガイシャ',
        address='伊丹市東有岡５丁目１２５番地',
        industry='化学',
        sec_code='79710',
        corporate_number='6140001078660',
    ),
    'E00996': EdinetCodeEntry(
        edinet_code='E00996',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5796,
        fiscal_year_end='3月31日',
        submitter_name='ダイニック株式会社',
        submitter_name_en='DYNIC CORPORATION',
        submitter_name_yomi='ダイニックカブシキガイシャ',
        address='京都市右京区西京極大門町２６番地',
        industry='繊維製品',
        sec_code='35510',
        corporate_number='1130001001198',
    ),
    'E01000': EdinetCodeEntry(
        edinet_code='E01000',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5451,
        fiscal_year_end='3月31日',
        submitter_name='ニチバン株式会社',
        submitter_name_en='NICHIBAN CO., LTD',
        submitter_name_yomi='ニチバンカブシキガイシャ',
        address='文京区関口二丁目３番３号',
        industry='化学',
        sec_code='42180',
        corporate_number='5010001000010',
    ),
    'E01001': EdinetCodeEntry(
        edinet_code='E01001',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3214,
        fiscal_year_end='11月30日',
        submitter_name='北興化学工業株式会社',
        submitter_name_en='HOKKO CHEMICAL INDUSTRY CO.,LTD.',
        submitter_name_yomi='ホクコウカガクコウギョウカブシキガイシャ',
        address='中央区日本橋本町一丁目５番４号',
        industry='化学',
        sec_code='49920',
        corporate_number='5010001034909',
    ),
    'E01002': EdinetCodeEntry(
        edinet_code='E01002',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=58434,
        fiscal_year_end='3月31日',
        submitter_name='ＵＢＥ株式会社',
        submitter_name_en='UBE Corporation',
        submitter_name_yomi='ユービーイーカブシキガイシャ',
        address='宇部市大字小串１９７８番地の９６',
        industry='化学',
        sec_code='42080',
        corporate_number='2250001002992',
    ),
    'E01003': EdinetCodeEntry(
        edinet_code='E01003',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=23370,
        fiscal_year_end='3月31日',
        submitter_name='ＪＳＲ株式会社',
        submitter_name_en='JSR Corporation',
        submitter_name_yomi='ジェイエスアールカブシキガイシャ',
        address='港区東新橋一丁目９番２号',
        industry='化学',
        sec_code=None,
        corporate_number='6010401082746',
    ),
    'E01005': EdinetCodeEntry(
        edinet_code='E01005',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='日本精蝋株式会社',
        submitter_name_en='NIPPON SEIRO CO., LTD.',
        submitter_name_yomi='ニホンセイロウカブシキガイシャ',
        address='中央区京橋二丁目５番１８号',
        industry='石油・石炭製品',
        sec_code='50100',
        corporate_number='4010001034983',
    ),
    'E01006': EdinetCodeEntry(
        edinet_code='E01006',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=610,
        fiscal_year_end='11月30日',
        submitter_name='川口化学工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カワグチカガクコウギョウカプシキガイシャ',
        address='千代田区内神田二丁目八番四号',
        industry='化学',
        sec_code='43610',
        corporate_number='5010001008672',
    ),
    'E01007': EdinetCodeEntry(
        edinet_code='E01007',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3698,
        fiscal_year_end='3月31日',
        submitter_name='フマキラー株式会社',
        submitter_name_en='FUMAKILLALIMITED',
        submitter_name_yomi='フマキラーカブシキガイシャ',
        address='千代田区神田美倉町１１番地',
        industry='化学',
        sec_code='49980',
        corporate_number='4010001008797',
    ),
    'E01008': EdinetCodeEntry(
        edinet_code='E01008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12334,
        fiscal_year_end='3月31日',
        submitter_name='積水樹脂株式会社',
        submitter_name_en='Sekisui Jushi Corporation',
        submitter_name_yomi='セキスイジュシカブシキガイシャ',
        address='大阪市北区西天満二丁目４番４号',
        industry='化学',
        sec_code='42120',
        corporate_number='9120001059651',
    ),
    'E01009': EdinetCodeEntry(
        edinet_code='E01009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=664,
        fiscal_year_end='11月30日',
        submitter_name='サンケイ化学株式会社',
        submitter_name_en='SANKEI CHEMICAL CO.,LTD.',
        submitter_name_yomi='サンケイカガクカブシキガイシャ',
        address='鹿児島市南栄２丁目９番地',
        industry='化学',
        sec_code='49950',
        corporate_number='8340001001781',
    ),
    'E01010': EdinetCodeEntry(
        edinet_code='E01010',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3050,
        fiscal_year_end='3月31日',
        submitter_name='セメダイン株式会社',
        submitter_name_en='CEMEDINE CO.,LTD.',
        submitter_name_yomi='セメダインカブシキガイシャ',
        address='品川区大崎一丁目１１番２号ゲートシティ大崎イーストタワー',
        industry='化学',
        sec_code=None,
        corporate_number='1010701005270',
    ),
    'E01011': EdinetCodeEntry(
        edinet_code='E01011',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5057,
        fiscal_year_end='3月31日',
        submitter_name='株式会社寺岡製作所',
        submitter_name_en='TERAOKA SEISAKUSHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000テラオカセイサクショ',
        address='品川区広町１丁目４番２２号',
        industry='化学',
        sec_code=None,
        corporate_number='4010701006398',
    ),
    'E01012': EdinetCodeEntry(
        edinet_code='E01012',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2764,
        fiscal_year_end='10月31日',
        submitter_name='イハラケミカル工業株式会社',
        submitter_name_en='IHARA CHEMICAL INDUSTRY CO., LTD',
        submitter_name_yomi='イハラケミカルコウギョウカブシキガイシャ',
        address='台東区池之端一丁目４番２６号',
        industry='化学',
        sec_code=None,
        corporate_number='3010501016004',
    ),
    'E01013': EdinetCodeEntry(
        edinet_code='E01013',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15554,
        fiscal_year_end='12月31日',
        submitter_name='株式会社レゾナック',
        submitter_name_en='Resonac Corporation',
        submitter_name_yomi='カブシキガイシャレゾナック',
        address='東京都港区芝大門一丁目１３番９号',
        industry='化学',
        sec_code=None,
        corporate_number='3011101018084',
    ),
    'E01014': EdinetCodeEntry(
        edinet_code='E01014',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2901,
        fiscal_year_end='3月31日',
        submitter_name='ダイトーケミックス株式会社',
        submitter_name_en='Daito Chemix Corporation',
        submitter_name_yomi='ダイトーケミックスカブシキガイシャ',
        address='大阪市鶴見区茨田大宮三丁目１番７号',
        industry='化学',
        sec_code='43660',
        corporate_number='4120001035442',
    ),
    'E01015': EdinetCodeEntry(
        edinet_code='E01015',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10192,
        fiscal_year_end='12月31日',
        submitter_name='アース製薬株式会社',
        submitter_name_en='Earth Corporation',
        submitter_name_yomi='アースセイヤクカブシキガイシャ',
        address='千代田区神田司町二丁目１２番地１',
        industry='化学',
        sec_code='49850',
        corporate_number='9010001009832',
    ),
    'E01016': EdinetCodeEntry(
        edinet_code='E01016',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=630,
        fiscal_year_end=None,
        submitter_name='株式会社合同資源',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゴウドウシゲン',
        address='長生郡長生村七井土１５４５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001043479',
    ),
    'E01018': EdinetCodeEntry(
        edinet_code='E01018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30142,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツムラ',
        submitter_name_en='TSUMURA & CO.',
        submitter_name_yomi='カブシキガイシャツムラ',
        address='港区赤坂二丁目１７番１１号',
        industry='医薬品',
        sec_code='45400',
        corporate_number='1010401069161',
    ),
    'E01019': EdinetCodeEntry(
        edinet_code='E01019',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7065,
        fiscal_year_end='3月31日',
        submitter_name='エステー株式会社',
        submitter_name_en='S.T.CORPORATION',
        submitter_name_yomi='エステーカブシキガイシャ',
        address='新宿区下落合１丁目４番１０号',
        industry='化学',
        sec_code='49510',
        corporate_number='8011101003057',
    ),
    'E01020': EdinetCodeEntry(
        edinet_code='E01020',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10012,
        fiscal_year_end='3月31日',
        submitter_name='ハリマ化成グループ株式会社',
        submitter_name_en='HARIMA CHEMICALS GROUP, INC.',
        submitter_name_yomi='ハリマカセイグループカブシキガイシャ',
        address='中央区日本橋３丁目８番４号',
        industry='化学',
        sec_code='44100',
        corporate_number='9140001043348',
    ),
    'E01021': EdinetCodeEntry(
        edinet_code='E01021',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1601,
        fiscal_year_end=None,
        submitter_name='株式会社ナリス化粧品',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャナリスケショウヒン',
        address='大阪市福島区海老江１－１１－１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001035958',
    ),
    'E01024': EdinetCodeEntry(
        edinet_code='E01024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4149,
        fiscal_year_end='3月31日',
        submitter_name='タイガースポリマー株式会社',
        submitter_name_en='TIGERS POLYMER CORPORATION',
        submitter_name_yomi='タイガースポリマーカブシキガイシャ',
        address='豊中市新千里東町１丁目４番１号',
        industry='化学',
        sec_code='42310',
        corporate_number='6120901024427',
    ),
    'E01027': EdinetCodeEntry(
        edinet_code='E01027',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11394,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マンダム',
        submitter_name_en='MANDOM CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000マンダム',
        address='大阪市中央区十二軒町５番１２号',
        industry='化学',
        sec_code='49170',
        corporate_number='1120001090234',
    ),
    'E01028': EdinetCodeEntry(
        edinet_code='E01028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3599,
        fiscal_year_end='12月31日',
        submitter_name='伊勢化学工業株式会社',
        submitter_name_en='ISE CHEMICALS CORPORATION',
        submitter_name_yomi='イセカガクコウギョウカブシキガイシャ',
        address='中央区京橋一丁目３番１号',
        industry='化学',
        sec_code='41070',
        corporate_number='9010001037370',
    ),
    'E01031': EdinetCodeEntry(
        edinet_code='E01031',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=671,
        fiscal_year_end='8月31日',
        submitter_name='旭化学工業株式会社',
        submitter_name_en='ASAHI KAGAKU KOGYO CO.,LTD',
        submitter_name_yomi='アサヒカガクコウギョウカブシキガイシャ',
        address='碧南市港南町２丁目８番地１４',
        industry='化学',
        sec_code='79280',
        corporate_number='5180301015006',
    ),
    'E01032': EdinetCodeEntry(
        edinet_code='E01032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2188,
        fiscal_year_end='3月31日',
        submitter_name='ムトー精工株式会社',
        submitter_name_en='MUTO SEIKO CO.',
        submitter_name_yomi='ムトーセイコウカブシキガイシャ',
        address='各務原市鵜沼川崎町一丁目６０番地の１',
        industry='化学',
        sec_code='79270',
        corporate_number='8200001007025',
    ),
    'E01033': EdinetCodeEntry(
        edinet_code='E01033',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1789,
        fiscal_year_end='3月31日',
        submitter_name='ヤスハラケミカル株式会社',
        submitter_name_en='YASUHARA CHEMICAL CO.,LTD.',
        submitter_name_yomi='ヤスハラケミカルカブシキガイシャ',
        address='府中市高木町１０７１番地',
        industry='化学',
        sec_code='49570',
        corporate_number='6240001034471',
    ),
    'E01034': EdinetCodeEntry(
        edinet_code='E01034',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5364,
        fiscal_year_end='9月30日',
        submitter_name='長谷川香料株式会社',
        submitter_name_en='T.HASEGAWA CO.,LTD.',
        submitter_name_yomi='ハセガワコウリヨウカブシキガイシヤ',
        address='中央区日本橋本町４丁目４番１４号',
        industry='化学',
        sec_code='49580',
        corporate_number='2010001063068',
    ),
    'E01035': EdinetCodeEntry(
        edinet_code='E01035',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1304,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイビー化粧品',
        submitter_name_en='IVY COSMETICS CORPORATION',
        submitter_name_yomi='カブシキガイシャアイビーケショウヒン',
        address='港区赤坂六丁目１８番３号',
        industry='化学',
        sec_code='49180',
        corporate_number='3010401000784',
    ),
    'E01037': EdinetCodeEntry(
        edinet_code='E01037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7410,
        fiscal_year_end=None,
        submitter_name='日東エフシー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニットウエフシーカブシキガイシャ',
        address='名古屋市港区いろは町一丁目２３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001007156',
    ),
    'E01039': EdinetCodeEntry(
        edinet_code='E01039',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ミルボン',
        submitter_name_en='Milbon Co., Ltd.',
        submitter_name_yomi='カブシキガイシャミルボン',
        address='大阪市都島区善源寺町２丁目３番３５号',
        industry='化学',
        sec_code='49190',
        corporate_number='3120001001206',
    ),
    'E01040': EdinetCodeEntry(
        edinet_code='E01040',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社日本色材工業研究所',
        submitter_name_en='Nippon Shikizai, Inc.',
        submitter_name_yomi='カブシキガイシャニホンシキザイコウギョウケンキュウショ',
        address='港区三田五丁目３番１３号',
        industry='化学',
        sec_code='49200',
        corporate_number='1010401022715',
    ),
    'E01041': EdinetCodeEntry(
        edinet_code='E01041',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='12月31日',
        submitter_name='星光ＰＭＣ株式会社',
        submitter_name_en='SEIKO PMC CORPORATION',
        submitter_name_yomi='セイコウピーエムシーカブシキガイシャ',
        address='中央区日本橋本町三丁目３番６号',
        industry='化学',
        sec_code=None,
        corporate_number='1010001033609',
    ),
    'E01043': EdinetCodeEntry(
        edinet_code='E01043',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1490,
        fiscal_year_end='3月31日',
        submitter_name='曽田香料株式会社',
        submitter_name_en='Soda Aromatic Co.,Ltd.',
        submitter_name_yomi='ソダコウリョウカブシキガイシャ',
        address='中央区日本橋本町四丁目１５番９号',
        industry='化学',
        sec_code=None,
        corporate_number='7010001048519',
    ),
    'E01044': EdinetCodeEntry(
        edinet_code='E01044',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2174,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｔ＆Ｋ\u3000ＴＯＫＡ',
        submitter_name_en='T&K TOKA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャティーアンドケイトオカ',
        address='入間郡三芳町大字竹間沢２８３番地１',
        industry='化学',
        sec_code=None,
        corporate_number='5011401004245',
    ),
    'E01045': EdinetCodeEntry(
        edinet_code='E01045',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1336,
        fiscal_year_end='3月31日',
        submitter_name='上村工業株式会社',
        submitter_name_en='C.Uyemura & Co.,Ltd.',
        submitter_name_yomi='ウエムラコウギョウカブシキガイシャ',
        address='大阪市中央区道修町三丁目２番６号',
        industry='化学',
        sec_code='49660',
        corporate_number='8120001077365',
    ),
    'E01046': EdinetCodeEntry(
        edinet_code='E01046',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10795,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファンケル',
        submitter_name_en='FANCL CORPORATION',
        submitter_name_yomi='カブシキガイシャファンケル',
        address='横浜市中区山下町８９番地１',
        industry='化学',
        sec_code=None,
        corporate_number='3020001000366',
    ),
    'E01047': EdinetCodeEntry(
        edinet_code='E01047',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3450,
        fiscal_year_end='12月31日',
        submitter_name='小林製薬株式会社',
        submitter_name_en='KOBAYASHI PHARMACEUTICAL  CO.,LTD.',
        submitter_name_yomi='コバヤシセイヤクカブシキガイシャ',
        address='大阪市中央区道修町４丁目４番１０号',
        industry='化学',
        sec_code='49670',
        corporate_number='4120001077402',
    ),
    'E01048': EdinetCodeEntry(
        edinet_code='E01048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3343,
        fiscal_year_end='3月31日',
        submitter_name='荒川化学工業株式会社',
        submitter_name_en='ARAKAWA CHEMICAL INDUSTRIES, LTD.',
        submitter_name_yomi='アラカワカガクコウギョウカブシキガイシャ',
        address='大阪市中央区平野町一丁目３番７号',
        industry='化学',
        sec_code='49680',
        corporate_number='4120001074060',
    ),
    'E01049': EdinetCodeEntry(
        edinet_code='E01049',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4848,
        fiscal_year_end='12月31日',
        submitter_name='株式会社コーセー',
        submitter_name_en='KOSE Corporation',
        submitter_name_yomi='カブシキガイシャコーセー',
        address='中央区日本橋三丁目６番２号',
        industry='化学',
        sec_code='49220',
        corporate_number='7010001043552',
    ),
    'E01050': EdinetCodeEntry(
        edinet_code='E01050',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=9155,
        fiscal_year_end='3月31日',
        submitter_name='株式会社田中化学研究所',
        submitter_name_en='TANAKA CHEMICAL CORPORATION',
        submitter_name_yomi='カブシキガイシャタナカカガクケンキュウショ',
        address='福井市白方町４５字砂浜割５番１０',
        industry='化学',
        sec_code='40800',
        corporate_number='2210001002377',
    ),
    'E01051': EdinetCodeEntry(
        edinet_code='E01051',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1618,
        fiscal_year_end='3月31日',
        submitter_name='東洋合成工業株式会社',
        submitter_name_en='toyo gosei co.,ltd.',
        submitter_name_yomi='トウヨウゴウセイコウギョウカブシキガイシャ',
        address='市川市上妙典１６０３番地',
        industry='化学',
        sec_code='49700',
        corporate_number='6040001027017',
    ),
    'E01052': EdinetCodeEntry(
        edinet_code='E01052',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2176,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンエー化研',
        submitter_name_en='Sun A.Kaken Company,Limited',
        submitter_name_yomi='カブシキガイシャサンエーカケン',
        address='中央区日本橋本町１丁目７番４号',
        industry='化学',
        sec_code='42340',
        corporate_number='2010001017602',
    ),
    'E01053': EdinetCodeEntry(
        edinet_code='E01053',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1778,
        fiscal_year_end='10月31日',
        submitter_name='萩原工業株式会社',
        submitter_name_en='HAGIHARA INDUSTRIES INC.',
        submitter_name_yomi='ハギハラコウギョウカブシキガイシャ',
        address='倉敷市水島中通１－４',
        industry='その他製品',
        sec_code='78560',
        corporate_number='7260001014438',
    ),
    'E01054': EdinetCodeEntry(
        edinet_code='E01054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=594,
        fiscal_year_end='12月31日',
        submitter_name='メック株式会社',
        submitter_name_en='MEC COMPANY LTD.',
        submitter_name_yomi='メックカブシキガイシャ',
        address='尼崎市杭瀬南新町３丁目４番１号',
        industry='化学',
        sec_code='49710',
        corporate_number='6140001051626',
    ),
    'E01055': EdinetCodeEntry(
        edinet_code='E01055',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3361,
        fiscal_year_end='3月31日',
        submitter_name='綜研化学株式会社',
        submitter_name_en='Soken Chemical & Engineering Co.,Ltd.',
        submitter_name_yomi='ソウケンカガクカブシキガイシャ',
        address='豊島区高田３－２９－５',
        industry='化学',
        sec_code='49720',
        corporate_number='8013301006500',
    ),
    'E01056': EdinetCodeEntry(
        edinet_code='E01056',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4334,
        fiscal_year_end='3月31日',
        submitter_name='扶桑化学工業株式会社',
        submitter_name_en='FUSO CHEMICAL CO.,LTD.',
        submitter_name_yomi='フソウカガクコウギョウカブシキガイシャ',
        address='大阪市中央区高麗橋四丁目３番１０号',
        industry='化学',
        sec_code='43680',
        corporate_number='6120001088372',
    ),
    'E01057': EdinetCodeEntry(
        edinet_code='E01057',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソフト９９コーポレーション',
        submitter_name_en='SOFT99corporation',
        submitter_name_yomi='カブシキガイシャソフトキュウキュウコーポレーション',
        address='大阪市中央区谷町二丁目６番５号',
        industry='化学',
        sec_code='44640',
        corporate_number='8120001083009',
    ),
    'E01058': EdinetCodeEntry(
        edinet_code='E01058',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3426,
        fiscal_year_end='3月31日',
        submitter_name='大成ラミックグループ株式会社',
        submitter_name_en='Taisei Lamick Group Head Quarter & Innovation Co., Ltd.',
        submitter_name_yomi='タイセイラミックグループカブシキガイシャ',
        address='白岡市下大崎８７３番地１',
        industry='化学',
        sec_code='49940',
        corporate_number='2030001031015',
    ),
    'E01059': EdinetCodeEntry(
        edinet_code='E01059',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=387,
        fiscal_year_end='3月31日',
        submitter_name='コタ株式会社',
        submitter_name_en='COTA CO.,LTD.',
        submitter_name_yomi='コタカブシキガイシャ',
        address='久世郡久御山町大字田井小字新荒見７７番地',
        industry='化学',
        sec_code='49230',
        corporate_number='9130001033317',
    ),
    'E01060': EdinetCodeEntry(
        edinet_code='E01060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1283,
        fiscal_year_end='3月31日',
        submitter_name='日本高純度化学株式会社',
        submitter_name_en='JAPAN PURE CHEMICAL CO.,LTD.',
        submitter_name_yomi='ニホンコウジュンドカガクカブシキガイシャ',
        address='練馬区北町三丁目１０番１８号',
        industry='化学',
        sec_code='49730',
        corporate_number='2011601007777',
    ),
    'E01061': EdinetCodeEntry(
        edinet_code='E01061',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1386,
        fiscal_year_end='12月31日',
        submitter_name='ウルトラファブリックス・ホールディングス株式会社',
        submitter_name_en='Ultrafabrics Holdings Co.,Ltd.',
        submitter_name_yomi='ウルトラファブリックスホールディングスカブシキガイシャ',
        address='八王子市明神町３－２０－６\u3000八王子ファーストスクエア６Ｆ',
        industry='化学',
        sec_code='42350',
        corporate_number='8010101002135',
    ),
    'E01062': EdinetCodeEntry(
        edinet_code='E01062',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1209,
        fiscal_year_end='7月31日',
        submitter_name='株式会社シーズ・ホールディングス',
        submitter_name_en='Ci:z Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャシーズホールディングス',
        address='渋谷区広尾一丁目１番３９号',
        industry='化学',
        sec_code=None,
        corporate_number='9011001031850',
    ),
    'E01063': EdinetCodeEntry(
        edinet_code='E01063',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=696,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハーバー研究所',
        submitter_name_en='HABA LABORATORIES, INC.',
        submitter_name_yomi='カブシキガイシャハーバーケンキュウジョ',
        address='千代田区神田須田町一丁目２４番地',
        industry='化学',
        sec_code='49250',
        corporate_number='5010001066200',
    ),
    'E01064': EdinetCodeEntry(
        edinet_code='E01064',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2131,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ＡＦＣ－ＨＤアムスライフサイエンス',
        submitter_name_en='AFC-HD AMS Life Science Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエーエフシーエイチディーアムスライフサイエンス',
        address='静岡市駿河区豊田３丁目６番３６号',
        industry='食料品',
        sec_code='29270',
        corporate_number='3080001005054',
    ),
    'E01065': EdinetCodeEntry(
        edinet_code='E01065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1245,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＣＵ',
        submitter_name_en='JCU CORPORATION',
        submitter_name_yomi='カブシキガイシャジェーシーユー',
        address='台東区東上野四丁目８番１号',
        industry='化学',
        sec_code='49750',
        corporate_number='3010501001864',
    ),
    'E01066': EdinetCodeEntry(
        edinet_code='E01066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=822,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アテクト',
        submitter_name_en='atect corporation',
        submitter_name_yomi='カブシキガイシャアテクト',
        address='東近江市上羽田町３２７５－１',
        industry='化学',
        sec_code='42410',
        corporate_number='5122001004491',
    ),
    'E01068': EdinetCodeEntry(
        edinet_code='E01068',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=375,
        fiscal_year_end='6月末日',
        submitter_name='東洋ドライルーブ株式会社',
        submitter_name_en='TOYO DRILUBE CO.,LTD',
        submitter_name_yomi='トウヨウドライルーブカブシキガイシャ',
        address='世田谷区代沢一丁目２６番４号',
        industry='化学',
        sec_code='49760',
        corporate_number='5010901008144',
    ),
    'E01069': EdinetCodeEntry(
        edinet_code='E01069',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30000,
        fiscal_year_end=None,
        submitter_name='ＥＮＥＯＳ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エネオスカブシキカイシャ',
        address='千代田区大手町一丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001133876',
    ),
    'E01070': EdinetCodeEntry(
        edinet_code='E01070',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='ＲＳエナジー株式会社',
        submitter_name_en='RS ENERGY K.K.',
        submitter_name_yomi='アールエスエナジーカブシキガイシャ',
        address='港区台場二丁目３番２号',
        industry='石油・石炭製品',
        sec_code=None,
        corporate_number='5010401014535',
    ),
    'E01073': EdinetCodeEntry(
        edinet_code='E01073',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8415,
        fiscal_year_end='3月31日',
        submitter_name='東亜石油株式会社',
        submitter_name_en='TOA OIL COMPANY,LIMITED',
        submitter_name_yomi='トウアセキユカブシキガイシャ',
        address='川崎市川崎区水江町３番１号',
        industry='石油・石炭製品',
        sec_code=None,
        corporate_number='2020001073982',
    ),
    'E01074': EdinetCodeEntry(
        edinet_code='E01074',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7077,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミツウロコグループホールディングス',
        submitter_name_en='Mitsuuroko Group Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャミツウロコグループホールディングス',
        address='中央区京橋三丁目１番１号',
        industry='卸売業',
        sec_code='81310',
        corporate_number='4010001034942',
    ),
    'E01075': EdinetCodeEntry(
        edinet_code='E01075',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15630,
        fiscal_year_end='3月31日',
        submitter_name='シナネンホールディングス株式会社',
        submitter_name_en='SINANEN HOLDINGS CO., LTD.',
        submitter_name_yomi='シナネンホールディングスカブシキガイシャ',
        address='品川区東品川１－３９－２０',
        industry='卸売業',
        sec_code='81320',
        corporate_number='5010401013396',
    ),
    'E01076': EdinetCodeEntry(
        edinet_code='E01076',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5527,
        fiscal_year_end='3月31日',
        submitter_name='富士興産株式会社',
        submitter_name_en='FUJI KOSAN COMPANY, LTD.',
        submitter_name_yomi='フジコウサンカブシキガイシャ',
        address='千代田区神田駿河台４丁目３番地',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010501020208',
    ),
    'E01077': EdinetCodeEntry(
        edinet_code='E01077',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2919,
        fiscal_year_end='3月31日',
        submitter_name='ニチレキグループ株式会社',
        submitter_name_en='NICHIREKI GROUP CO., LTD.',
        submitter_name_yomi='ニチレキグループカブシキガイシャ',
        address='千代田区九段北四丁目３番２９号',
        industry='石油・石炭製品',
        sec_code='50110',
        corporate_number='7010001008737',
    ),
    'E01078': EdinetCodeEntry(
        edinet_code='E01078',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1050,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000りゅうせき',
        submitter_name_en='Ryuseki Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000リュウセキ',
        address='浦添市西洲二丁目２番地３',
        industry='小売業',
        sec_code=None,
        corporate_number='5360001009256',
    ),
    'E01080': EdinetCodeEntry(
        edinet_code='E01080',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4249,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユシロ',
        submitter_name_en='Yushiro Inc.',
        submitter_name_yomi='カブシキガイシャユシロ',
        address='大田区千鳥２丁目３４番１６号',
        industry='石油・石炭製品',
        sec_code='50130',
        corporate_number='2010801012307',
    ),
    'E01081': EdinetCodeEntry(
        edinet_code='E01081',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=75000,
        fiscal_year_end='3月末日',
        submitter_name='ＪＸ金属株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイエックスキンゾクカブシキガイシャ',
        address='港区虎ノ門二丁目１０番４号',
        industry='非鉄金属',
        sec_code='50160',
        corporate_number='2010001133878',
    ),
    'E01082': EdinetCodeEntry(
        edinet_code='E01082',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=24467,
        fiscal_year_end='3月31日',
        submitter_name='富士石油株式会社',
        submitter_name_en='Fuji Oil Company, Ltd.',
        submitter_name_yomi='フジセキユカブシキガイシャ',
        address='品川区北品川六丁目７番２９号',
        industry='石油・石炭製品',
        sec_code=None,
        corporate_number='3010701015631',
    ),
    'E01083': EdinetCodeEntry(
        edinet_code='E01083',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2118,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＭＯＲＥＳＣＯ',
        submitter_name_en='MORESCO Corporation',
        submitter_name_yomi='カブシキガイシャモレスコ',
        address='神戸市中央区港島南町五丁目５番３号',
        industry='石油・石炭製品',
        sec_code='50180',
        corporate_number='7140001021198',
    ),
    'E01084': EdinetCodeEntry(
        edinet_code='E01084',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=168351,
        fiscal_year_end='3月31日',
        submitter_name='出光興産株式会社',
        submitter_name_en='Idemitsu Kosan Co.,Ltd.',
        submitter_name_yomi='イデミツコウサンカブシキカイシャ',
        address='千代田区大手町一丁目２番１号',
        industry='石油・石炭製品',
        sec_code='50190',
        corporate_number='9010001011318',
    ),
    'E01085': EdinetCodeEntry(
        edinet_code='E01085',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38909,
        fiscal_year_end='12月31日',
        submitter_name='横浜ゴム株式会社',
        submitter_name_en='The Yokohama Rubber Company,Limited',
        submitter_name_yomi='ヨコハマゴムカブシキガイシャ',
        address='平塚市追分２番１号',
        industry='ゴム製品',
        sec_code='51010',
        corporate_number='4010401030574',
    ),
    'E01086': EdinetCodeEntry(
        edinet_code='E01086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=126354,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ブリヂストン',
        submitter_name_en='BRIDGESTONE CORPORATION',
        submitter_name_yomi='カブシキガイシャブリヂストン',
        address='中央区京橋三丁目１番１号',
        industry='ゴム製品',
        sec_code='51080',
        corporate_number='3010001034943',
    ),
    'E01088': EdinetCodeEntry(
        edinet_code='E01088',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4036,
        fiscal_year_end='3月31日',
        submitter_name='昭和ホールディングス株式会社',
        submitter_name_en='Showa Holdings Co.,Ltd.',
        submitter_name_yomi='ショウワホールディングスカブシキガイシャ',
        address='柏市十余二３４８番地',
        industry='ゴム製品',
        sec_code='51030',
        corporate_number='3040001065779',
    ),
    'E01089': EdinetCodeEntry(
        edinet_code='E01089',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1920,
        fiscal_year_end='3月31日',
        submitter_name='日東化工株式会社',
        submitter_name_en='NITTOKAKO CO.,LTD.',
        submitter_name_yomi='ニットウカコウカブシキガイシャ',
        address='高座郡寒川町一之宮六丁目１番３号',
        industry='ゴム製品',
        sec_code=None,
        corporate_number='2021001006445',
    ),
    'E01090': EdinetCodeEntry(
        edinet_code='E01090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=55935,
        fiscal_year_end='12月31日',
        submitter_name='ＴＯＹＯ\u3000ＴＩＲＥ株式会社',
        submitter_name_en='Toyo Tire Corporation',
        submitter_name_yomi='トーヨータイヤカブシキガイシャ',
        address='伊丹市藤ノ木２丁目２番１３号',
        industry='ゴム製品',
        sec_code='51050',
        corporate_number='7120001049019',
    ),
    'E01092': EdinetCodeEntry(
        edinet_code='E01092',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10951,
        fiscal_year_end='3月31日',
        submitter_name='バンドー化学株式会社',
        submitter_name_en='Bando Chemical Industries, Ltd.',
        submitter_name_yomi='バンドーカガクカブシキガイシャ',
        address='神戸市中央区港島南町４丁目６番６号',
        industry='ゴム製品',
        sec_code='51950',
        corporate_number='5140001013916',
    ),
    'E01094': EdinetCodeEntry(
        edinet_code='E01094',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3804,
        fiscal_year_end='3月31日',
        submitter_name='藤倉コンポジット株式会社',
        submitter_name_en='FUJIKURA COMPOSITES Inc.',
        submitter_name_yomi='フジクラコンポジットカブシキガイシャ',
        address='品川区西五反田八丁目４番１３号五反田ＪＰビルディング',
        industry='ゴム製品',
        sec_code='51210',
        corporate_number='5010701008682',
    ),
    'E01095': EdinetCodeEntry(
        edinet_code='E01095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=547,
        fiscal_year_end='3月31日',
        submitter_name='相模ゴム工業株式会社',
        submitter_name_en='SAGAMI RUBBER INDUSTRIES CO.,LTD.',
        submitter_name_yomi='サガミゴムコウギョウカブシキガイシャ',
        address='厚木市元町２番１号',
        industry='ゴム製品',
        sec_code='51940',
        corporate_number='7021001019772',
    ),
    'E01096': EdinetCodeEntry(
        edinet_code='E01096',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14640,
        fiscal_year_end='3月31日',
        submitter_name='アキレス株式会社',
        submitter_name_en='Achilles Corporation',
        submitter_name_yomi='アキレスカブシキガイシャ',
        address='新宿区北新宿二丁目２１番１号',
        industry='化学',
        sec_code='51420',
        corporate_number='7011101000682',
    ),
    'E01097': EdinetCodeEntry(
        edinet_code='E01097',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12145,
        fiscal_year_end='3月31日',
        submitter_name='住友理工株式会社',
        submitter_name_en='Sumitomo Riko Company Limited',
        submitter_name_yomi='スミトモリコウカブシキガイシャ',
        address='小牧市東三丁目１番地',
        industry='ゴム製品',
        sec_code=None,
        corporate_number='6180001076207',
    ),
    'E01098': EdinetCodeEntry(
        edinet_code='E01098',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8150,
        fiscal_year_end='3月31日',
        submitter_name='三ツ星ベルト株式会社',
        submitter_name_en='Mitsuboshi Belting Ltd.',
        submitter_name_yomi='ミツボシベルトカブシキカイシャ',
        address='神戸市長田区浜添通４丁目１番２１号',
        industry='ゴム製品',
        sec_code='51920',
        corporate_number='6140001016934',
    ),
    'E01099': EdinetCodeEntry(
        edinet_code='E01099',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東洋クオリティワン',
        submitter_name_en='Toyo Quality One Corporation',
        submitter_name_yomi='カブシキガイシャトウヨウクオリティワン',
        address='川越市下小坂３２８番２号',
        industry='ゴム製品',
        sec_code=None,
        corporate_number='3030001058882',
    ),
    'E01100': EdinetCodeEntry(
        edinet_code='E01100',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13047,
        fiscal_year_end='3月31日',
        submitter_name='オカモト株式会社',
        submitter_name_en='OKAMOTO INDUSTRIES,INC.',
        submitter_name_yomi='オカモトカブシキガイシャ',
        address='文京区本郷三丁目２７番１２号',
        industry='ゴム製品',
        sec_code='51220',
        corporate_number='5010001000002',
    ),
    'E01103': EdinetCodeEntry(
        edinet_code='E01103',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5007,
        fiscal_year_end='3月31日',
        submitter_name='ロンシール工業株式会社',
        submitter_name_en='LONSEAL CORPORATION',
        submitter_name_yomi='ロンシールコウギョウカブシキガイシャ',
        address='港区東新橋二丁目３番１７号',
        industry='化学',
        sec_code='42240',
        corporate_number='5010601018451',
    ),
    'E01104': EdinetCodeEntry(
        edinet_code='E01104',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5654,
        fiscal_year_end='3月31日',
        submitter_name='鬼怒川ゴム工業株式会社',
        submitter_name_en='KINUGAWA RUBBER INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='キヌガワゴムコウギョウカブシキガイシャ',
        address='千葉市稲毛区長沼町３３０番地',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='7010001172987',
    ),
    'E01107': EdinetCodeEntry(
        edinet_code='E01107',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=506,
        fiscal_year_end='3月31日',
        submitter_name='櫻護謨株式会社',
        submitter_name_en='SAKURA RUBBER CO.,LTD.',
        submitter_name_yomi='サクラゴムカブシキガイシャ',
        address='渋谷区笹塚一丁目２１番１７号',
        industry='ゴム製品',
        sec_code='51890',
        corporate_number='3011001008986',
    ),
    'E01108': EdinetCodeEntry(
        edinet_code='E01108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28119,
        fiscal_year_end='3月31日',
        submitter_name='豊田合成株式会社',
        submitter_name_en='TOYODA GOSEI CO.,LTD.',
        submitter_name_yomi='トヨダゴウセイカブシキガイシャ',
        address='清須市春日長畑１番地',
        industry='輸送用機器',
        sec_code='72820',
        corporate_number='7180001045235',
    ),
    'E01109': EdinetCodeEntry(
        edinet_code='E01109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=643,
        fiscal_year_end='3月31日',
        submitter_name='不二ラテックス株式会社',
        submitter_name_en='FUJI LATEX CO.,LTD.',
        submitter_name_yomi='フジラテックスカブシキガイシャ',
        address='千代田区神田錦町三丁目１９番地１',
        industry='ゴム製品',
        sec_code='51990',
        corporate_number='5010001027937',
    ),
    'E01110': EdinetCodeEntry(
        edinet_code='E01110',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=42658,
        fiscal_year_end='12月31日',
        submitter_name='住友ゴム工業株式会社',
        submitter_name_en='Sumitomo Rubber Industries, Ltd.',
        submitter_name_yomi='スミトモゴムコウギョウカブシキガイシャ',
        address='神戸市中央区脇浜町３丁目６番９号',
        industry='ゴム製品',
        sec_code='51100',
        corporate_number='6140001008691',
    ),
    'E01111': EdinetCodeEntry(
        edinet_code='E01111',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8060,
        fiscal_year_end='3月31日',
        submitter_name='ニッタ株式会社',
        submitter_name_en='Nitta Corporation',
        submitter_name_yomi='ニッタカブシキガイシャ',
        address='大阪市浪速区桜川四丁目４番２６号',
        industry='ゴム製品',
        sec_code='51860',
        corporate_number='4120001039435',
    ),
    'E01112': EdinetCodeEntry(
        edinet_code='E01112',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3364,
        fiscal_year_end='3月31日',
        submitter_name='西川ゴム工業株式会社',
        submitter_name_en='NISHIKAWA RUBBER CO., LTD.',
        submitter_name_yomi='ニシカワゴムコウギョウカブシキガイシャ',
        address='広島市西区三篠町２丁目２番８号',
        industry='ゴム製品',
        sec_code='51610',
        corporate_number='8240001008325',
    ),
    'E01113': EdinetCodeEntry(
        edinet_code='E01113',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1395,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フコク',
        submitter_name_en='FUKOKU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャフコク',
        address='上尾市菅谷三丁目１０５番地',
        industry='ゴム製品',
        sec_code='51850',
        corporate_number='5030001044311',
    ),
    'E01114': EdinetCodeEntry(
        edinet_code='E01114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2158,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ニチリン',
        submitter_name_en='NICHIRIN CO., LTD.',
        submitter_name_yomi='カブシキガイシャニチリン',
        address='神戸市中央区江戸町９８番地１',
        industry='ゴム製品',
        sec_code='51840',
        corporate_number='1140001010033',
    ),
    'E01115': EdinetCodeEntry(
        edinet_code='E01115',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=516,
        fiscal_year_end='3月31日',
        submitter_name='株式会社朝日ラバー',
        submitter_name_en='ASAHI RUBBER INC.',
        submitter_name_yomi='カブシキガイシャアサヒラバー',
        address='さいたま市大宮区土手町２丁目７番２',
        industry='ゴム製品',
        sec_code='51620',
        corporate_number='9030001000319',
    ),
    'E01118': EdinetCodeEntry(
        edinet_code='E01118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5355,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リーガルコーポレーション',
        submitter_name_en='REGAL CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000リーガルコーポレーション',
        address='浦安市日の出二丁目１番８号',
        industry='その他製品',
        sec_code='79380',
        corporate_number='4040001034188',
    ),
    'E01120': EdinetCodeEntry(
        edinet_code='E01120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4404,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッピ',
        submitter_name_en='Nippi,Incorporated',
        submitter_name_yomi='カブシキガイシャニッピ',
        address='足立区千住緑町１－１－１',
        industry='その他製品',
        sec_code='79320',
        corporate_number='7011801011046',
    ),
    'E01121': EdinetCodeEntry(
        edinet_code='E01121',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=116913,
        fiscal_year_end='3月31日',
        submitter_name='日本板硝子株式会社',
        submitter_name_en='Nippon Sheet Glass Company,Limited',
        submitter_name_yomi='ニホンイタガラスカブシキガイシャ',
        address='港区三田三丁目５番２７号',
        industry='ガラス・土石製品',
        sec_code='52020',
        corporate_number='4010401054474',
    ),
    'E01122': EdinetCodeEntry(
        edinet_code='E01122',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90873,
        fiscal_year_end='12月31日',
        submitter_name='ＡＧＣ株式会社',
        submitter_name_en='AGC Inc.',
        submitter_name_yomi='エイジーシーカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号新丸の内ビルディング',
        industry='ガラス・土石製品',
        sec_code='52010',
        corporate_number='2010001008650',
    ),
    'E01123': EdinetCodeEntry(
        edinet_code='E01123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6344,
        fiscal_year_end='3月20日',
        submitter_name='石塚硝子株式会社',
        submitter_name_en='ISHIZUKA GLASS CO.,LTD.',
        submitter_name_yomi='イシヅカガラスカブシキガイシャ',
        address='岩倉市川井町１８８０番地',
        industry='ガラス・土石製品',
        sec_code='52040',
        corporate_number='4180001088187',
    ),
    'E01124': EdinetCodeEntry(
        edinet_code='E01124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6264,
        fiscal_year_end='3月31日',
        submitter_name='ＨＯＹＡ株式会社',
        submitter_name_en='HOYA CORPORATION',
        submitter_name_yomi='ホウヤカブシキガイシャ',
        address='新宿区西新宿六丁目１０番１号',
        industry='精密機器',
        sec_code='77410',
        corporate_number='7011101019599',
    ),
    'E01126': EdinetCodeEntry(
        edinet_code='E01126',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14074,
        fiscal_year_end='3月31日',
        submitter_name='日本山村硝子株式会社',
        submitter_name_en='Nihon Yamamura Glass Co., Ltd.',
        submitter_name_yomi='ニホンヤマムラガラスカブシキガイシャ',
        address='尼崎市西向島町１５番１',
        industry='ガラス・土石製品',
        sec_code='52100',
        corporate_number='1140001054947',
    ),
    'E01127': EdinetCodeEntry(
        edinet_code='E01127',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=41654,
        fiscal_year_end='3月31日',
        submitter_name='住友大阪セメント株式会社',
        submitter_name_en='Sumitomo Osaka Cement Co.,Ltd.',
        submitter_name_yomi='スミトモオオサカセメントカブシキカイシャ',
        address='港区東新橋一丁目９番２号',
        industry='ガラス・土石製品',
        sec_code='52320',
        corporate_number='5010001023779',
    ),
    'E01128': EdinetCodeEntry(
        edinet_code='E01128',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4013,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デイ・シイ',
        submitter_name_en='DC CO., LTD.',
        submitter_name_yomi='カブシキガイシャデイシイ',
        address='川崎市川崎区浅野町１番１号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='8020001073572',
    ),
    'E01130': EdinetCodeEntry(
        edinet_code='E01130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=86174,
        fiscal_year_end='3月31日',
        submitter_name='太平洋セメント株式会社',
        submitter_name_en='TAIHEIYO CEMENT CORPORATION',
        submitter_name_yomi='タイヘイヨウセメントカブシキガイシャ',
        address='文京区小石川一丁目１番１号',
        industry='ガラス・土石製品',
        sec_code='52330',
        corporate_number='4010401082995',
    ),
    'E01131': EdinetCodeEntry(
        edinet_code='E01131',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=704,
        fiscal_year_end='3月31日',
        submitter_name='日本坩堝株式会社',
        submitter_name_en='Nippon Crucible co.,Ltd.',
        submitter_name_yomi='ニホンルツボカブシキガイシャ',
        address='渋谷区恵比寿１－２１－３',
        industry='ガラス・土石製品',
        sec_code='53550',
        corporate_number='9011001018113',
    ),
    'E01132': EdinetCodeEntry(
        edinet_code='E01132',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='深川製磁株式会社',
        submitter_name_en='FUKAGAWA-SEIJI CO.,LTD.',
        submitter_name_yomi='フカガワセイジカブシキガイシャ',
        address='西松浦郡有田町原明乙１１１番地',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='3300001005790',
    ),
    'E01134': EdinetCodeEntry(
        edinet_code='E01134',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=960,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホクコン',
        submitter_name_en='HOKUKON CO.,LTD',
        submitter_name_yomi='カブシキガイシャホクコン',
        address='越前市北府一丁目２番３８号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='8210001011942',
    ),
    'E01135': EdinetCodeEntry(
        edinet_code='E01135',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3850,
        fiscal_year_end='3月31日',
        submitter_name='ニッコー株式会社',
        submitter_name_en='NIKKO COMPANY',
        submitter_name_yomi='ニッコーカブシキガイシャ',
        address='白山市相木町３８３番地',
        industry='ガラス・土石製品',
        sec_code='53430',
        corporate_number='2220001008794',
    ),
    'E01136': EdinetCodeEntry(
        edinet_code='E01136',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=47869,
        fiscal_year_end='3月31日',
        submitter_name='日本特殊陶業株式会社',
        submitter_name_en='Niterra Co., Ltd.',
        submitter_name_yomi='ニッポントクシュトウギョウカブシキガイシャ',
        address='名古屋市東区東桜一丁目１番１号',
        industry='ガラス・土石製品',
        sec_code='53340',
        corporate_number='3180001010845',
    ),
    'E01137': EdinetCodeEntry(
        edinet_code='E01137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=70064,
        fiscal_year_end='3月31日',
        submitter_name='日本碍子株式会社',
        submitter_name_en='NGK INSULATORS, LTD.',
        submitter_name_yomi='ニッポンガイシカブシキガイシャ',
        address='名古屋市瑞穂区須田町２番５６号',
        industry='ガラス・土石製品',
        sec_code='53330',
        corporate_number='3180001010829',
    ),
    'E01138': EdinetCodeEntry(
        edinet_code='E01138',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35579,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＴＯ株式会社',
        submitter_name_en='TOTO LTD.',
        submitter_name_yomi='トートーカブシキガイシャ',
        address='北九州市小倉北区中島二丁目１番１号',
        industry='ガラス・土石製品',
        sec_code='53320',
        corporate_number='1290801002603',
    ),
    'E01139': EdinetCodeEntry(
        edinet_code='E01139',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15632,
        fiscal_year_end='3月31日',
        submitter_name='ノリタケ株式会社',
        submitter_name_en='NORITAKE CO., LIMITED',
        submitter_name_yomi='ノリタケカブシキガイシャ',
        address='名古屋市西区則武新町三丁目１番３６号',
        industry='ガラス・土石製品',
        sec_code='53310',
        corporate_number='4180001026725',
    ),
    'E01140': EdinetCodeEntry(
        edinet_code='E01140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7402,
        fiscal_year_end='12月31日',
        submitter_name='日本カーボン株式会社',
        submitter_name_en='Nippon Carbon Co. , Ltd.',
        submitter_name_yomi='ニホンカーボンカブシキカイシャ',
        address='中央区八丁堀一丁目１０番７号',
        industry='ガラス・土石製品',
        sec_code='53020',
        corporate_number='9010001035011',
    ),
    'E01141': EdinetCodeEntry(
        edinet_code='E01141',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1635,
        fiscal_year_end='12月31日',
        submitter_name='ダントーホールディングス株式会社',
        submitter_name_en='DANTO HOLDINGS CORPORATION',
        submitter_name_yomi='ダントーホールディングスカブシキガイシャ',
        address='南あわじ市北阿万伊賀野１２９０番地',
        industry='ガラス・土石製品',
        sec_code='53370',
        corporate_number='9140001085662',
    ),
    'E01142': EdinetCodeEntry(
        edinet_code='E01142',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5111,
        fiscal_year_end='3月31日',
        submitter_name='日本コンクリート工業株式会社',
        submitter_name_en='NIPPON CONCRETE INDUSTRIES CO.,LTD.',
        submitter_name_yomi='ニホンコンクリートコウギョウカブシキガイシャ',
        address='港区芝浦４丁目６番１４号',
        industry='ガラス・土石製品',
        sec_code='52690',
        corporate_number='8010401022551',
    ),
    'E01143': EdinetCodeEntry(
        edinet_code='E01143',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1204,
        fiscal_year_end='3月31日',
        submitter_name='旭コンクリート工業株式会社',
        submitter_name_en='ASAHI CONCRETE WORKS CO.,LTD.',
        submitter_name_yomi='アサヒコンクリートコウギョウカブシキガイシャ',
        address='中央区築地１丁目８番２号',
        industry='ガラス・土石製品',
        sec_code='52680',
        corporate_number='5010001034751',
    ),
    'E01145': EdinetCodeEntry(
        edinet_code='E01145',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3196,
        fiscal_year_end=None,
        submitter_name='イソライト工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イソライトコウギョウカブシキガイシャ',
        address='大阪市北区中之島三丁目３番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001059610',
    ),
    'E01146': EdinetCodeEntry(
        edinet_code='E01146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3300,
        fiscal_year_end='3月31日',
        submitter_name='品川リフラ株式会社',
        submitter_name_en='SHINAGAWA REFRA CO., LTD.',
        submitter_name_yomi='シナガワリフラカブシキガイシャ',
        address='千代田区丸の内一丁目７番１２号',
        industry='ガラス・土石製品',
        sec_code='53510',
        corporate_number='9010001008685',
    ),
    'E01147': EdinetCodeEntry(
        edinet_code='E01147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2654,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ヨータイ',
        submitter_name_en='YOTAI REFRACTORIES CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ヨータイ',
        address='貝塚市二色中町８番１号',
        industry='ガラス・土石製品',
        sec_code='53570',
        corporate_number='8120101038845',
    ),
    'E01149': EdinetCodeEntry(
        edinet_code='E01149',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2398,
        fiscal_year_end='3月31日',
        submitter_name='東京窯業株式会社',
        submitter_name_en='TYK CORPORATION',
        submitter_name_yomi='トウキョウヨウギョウカブシキガイシャ',
        address='港区港南二丁目１１番１号',
        industry='ガラス・土石製品',
        sec_code='53630',
        corporate_number='2010001023781',
    ),
    'E01150': EdinetCodeEntry(
        edinet_code='E01150',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5537,
        fiscal_year_end='3月31日',
        submitter_name='黒崎播磨株式会社',
        submitter_name_en='KROSAKI HARIMA CORPORATION',
        submitter_name_yomi='クロサキハリマカブシキガイシャ',
        address='北九州市八幡西区東浜町１番１号',
        industry='ガラス・土石製品',
        sec_code='53520',
        corporate_number='3290801009910',
    ),
    'E01151': EdinetCodeEntry(
        edinet_code='E01151',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12128,
        fiscal_year_end='3月31日',
        submitter_name='ニチアス株式会社',
        submitter_name_en='NICHIAS CORPORATION',
        submitter_name_yomi='ニチアスカブシキガイシャ',
        address='中央区八丁堀一丁目６番１号',
        industry='ガラス・土石製品',
        sec_code='53930',
        corporate_number='9010401021486',
    ),
    'E01152': EdinetCodeEntry(
        edinet_code='E01152',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7881,
        fiscal_year_end='3月31日',
        submitter_name='株式会社有沢製作所',
        submitter_name_en='Arisawa Mfg. Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアリサワセイサクショ',
        address='上越市南本町１丁目５番５号',
        industry='化学',
        sec_code='52080',
        corporate_number='1110001018789',
    ),
    'E01156': EdinetCodeEntry(
        edinet_code='E01156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3948,
        fiscal_year_end='3月31日',
        submitter_name='リソルホールディングス株式会社',
        submitter_name_en='RESOL HOLDINGS Co.,Ltd.',
        submitter_name_yomi='リソルホールディングスカブシキガイシャ',
        address='新宿区西新宿六丁目２４番１号',
        industry='サービス業',
        sec_code='52610',
        corporate_number='6011101020517',
    ),
    'E01157': EdinetCodeEntry(
        edinet_code='E01157',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5251,
        fiscal_year_end='3月31日',
        submitter_name='日本ヒューム株式会社',
        submitter_name_en='Nippon Hume Corporation',
        submitter_name_yomi='ニッポンヒュームカブシキガイシャ',
        address='港区新橋五丁目３３番１１号',
        industry='ガラス・土石製品',
        sec_code='52620',
        corporate_number='6010401023196',
    ),
    'E01161': EdinetCodeEntry(
        edinet_code='E01161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4218,
        fiscal_year_end='3月31日',
        submitter_name='ピーエス・コンストラクション株式会社',
        submitter_name_en='PS Construction Co., Ltd.',
        submitter_name_yomi='ピーエスコンストラクションカブシキガイシャ',
        address='港区東新橋一丁目９番１号',
        industry='建設業',
        sec_code='18710',
        corporate_number='1010001008742',
    ),
    'E01162': EdinetCodeEntry(
        edinet_code='E01162',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20436,
        fiscal_year_end='12月31日',
        submitter_name='東海カーボン株式会社',
        submitter_name_en='TOKAI CARBON CO., LTD.',
        submitter_name_yomi='トウカイカーボンカブシキガイシャ',
        address='港区北青山一丁目２番３号',
        industry='ガラス・土石製品',
        sec_code='53010',
        corporate_number='6010401020094',
    ),
    'E01163': EdinetCodeEntry(
        edinet_code='E01163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3889,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エーアンドエーマテリアル',
        submitter_name_en='A&A Material Corporation',
        submitter_name_yomi='カブシキガイシャエーアンドエーマテリアル',
        address='横浜市鶴見区鶴見中央２－５－５',
        industry='ガラス・土石製品',
        sec_code='53910',
        corporate_number='9020001040448',
    ),
    'E01164': EdinetCodeEntry(
        edinet_code='E01164',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13957,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バルカー',
        submitter_name_en='VALQUA , LTD.',
        submitter_name_yomi='カブシキガイシャバルカー',
        address='品川区大崎２丁目１番１号',
        industry='化学',
        sec_code='79950',
        corporate_number='5010701020092',
    ),
    'E01165': EdinetCodeEntry(
        edinet_code='E01165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=720,
        fiscal_year_end='2月末日',
        submitter_name='株式会社トーヨーアサノ',
        submitter_name_en='Toyo Asano Foundation Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトーヨーアサノ',
        address='沼津市原３１５番地の２',
        industry='ガラス・土石製品',
        sec_code='52710',
        corporate_number='4080101001290',
    ),
    'E01166': EdinetCodeEntry(
        edinet_code='E01166',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2449,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ノザワ',
        submitter_name_en='NOZAWA CORPORATION',
        submitter_name_yomi='カブシキガイシャノザワ',
        address='神戸市中央区浪花町１５番地',
        industry='ガラス・土石製品',
        sec_code='52370',
        corporate_number='9140001010083',
    ),
    'E01168': EdinetCodeEntry(
        edinet_code='E01168',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='日本研紙株式会社',
        submitter_name_en='NIHON KENSHI CO.,LTD.',
        submitter_name_yomi='ニホンケンシカブシキガイシャ',
        address='福山市草戸町三丁目１３番２５号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='7120001049043',
    ),
    'E01169': EdinetCodeEntry(
        edinet_code='E01169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2146,
        fiscal_year_end='3月31日',
        submitter_name='三谷セキサン株式会社',
        submitter_name_en='mitanisekisanco.,ltd',
        submitter_name_yomi='ミタニセキサンカブシキカイシャ',
        address='福井市豊島１丁目３番１号',
        industry='ガラス・土石製品',
        sec_code='52730',
        corporate_number='9210001004020',
    ),
    'E01170': EdinetCodeEntry(
        edinet_code='E01170',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5855,
        fiscal_year_end='10月31日',
        submitter_name='株式会社オハラ',
        submitter_name_en='OHARA INC.',
        submitter_name_yomi='カブシキガイシャ\u3000オハラ',
        address='相模原市中央区小山１－１５－３０',
        industry='ガラス・土石製品',
        sec_code='52180',
        corporate_number='4021001011600',
    ),
    'E01172': EdinetCodeEntry(
        edinet_code='E01172',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=598,
        fiscal_year_end='3月31日',
        submitter_name='昭和化学工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウワカガクコウギョウカブシキガイシャ',
        address='港区赤坂二丁目１４番３２号',
        industry='化学',
        sec_code='49900',
        corporate_number='3013201002835',
    ),
    'E01173': EdinetCodeEntry(
        edinet_code='E01173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5913,
        fiscal_year_end='3月31日',
        submitter_name='ＳＥＣカーボン株式会社',
        submitter_name_en='SEC CARBON,LIMITED',
        submitter_name_yomi='エスイーシーカーボンカブシキガイシャ',
        address='尼崎市潮江一丁目２番６号ＪＲＥ尼崎フロントビル６階',
        industry='ガラス・土石製品',
        sec_code='53040',
        corporate_number='9140001047877',
    ),
    'E01174': EdinetCodeEntry(
        edinet_code='E01174',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3295,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スパンクリートコーポレーション',
        submitter_name_en='SPANCRETE CORPORATION',
        submitter_name_yomi='カブシキガイシャスパンクリートコーポレーション',
        address='文京区湯島二丁目４番３号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='9010001004016',
    ),
    'E01176': EdinetCodeEntry(
        edinet_code='E01176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2178,
        fiscal_year_end='11月30日',
        submitter_name='ＡＳＡＨＩ\u3000ＥＩＴＯホールディングス株式会社',
        submitter_name_en='ASAHI EITO HOLDINGS CO.,LTD.',
        submitter_name_yomi='アサヒエイトウホールディングスカブシキガイシャ',
        address='大阪市中央区常盤町一丁目３番８号',
        industry='ガラス・土石製品',
        sec_code='53410',
        corporate_number='2120101021352',
    ),
    'E01177': EdinetCodeEntry(
        edinet_code='E01177',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='ジャニス工業株式会社',
        submitter_name_en='Janis Ltd.',
        submitter_name_yomi='ジャニスコウギョウカブシキガイシャ',
        address='常滑市唐崎町２丁目８８番地',
        industry='ガラス・土石製品',
        sec_code='53420',
        corporate_number='9180001093174',
    ),
    'E01180': EdinetCodeEntry(
        edinet_code='E01180',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=877,
        fiscal_year_end='3月31日',
        submitter_name='美濃窯業株式会社',
        submitter_name_en='MINO CERAMIC CO., LTD.',
        submitter_name_yomi='ミノヨウギョウカブシキガイシャ',
        address='瑞浪市寺河戸町７１９番地',
        industry='ガラス・土石製品',
        sec_code='53560',
        corporate_number='5200001021920',
    ),
    'E01182': EdinetCodeEntry(
        edinet_code='E01182',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=115703,
        fiscal_year_end='3月31日',
        submitter_name='京セラ株式会社',
        submitter_name_en='KYOCERA CORPORATION',
        submitter_name_yomi='キョウセラカブシキガイシャ',
        address='京都市伏見区竹田鳥羽殿町６番地',
        industry='電気機器',
        sec_code='69710',
        corporate_number='4130001000049',
    ),
    'E01183': EdinetCodeEntry(
        edinet_code='E01183',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5968,
        fiscal_year_end='3月31日',
        submitter_name='株式会社松風',
        submitter_name_en='SHOFU INC.',
        submitter_name_yomi='カブシキガイシャショウフウ',
        address='京都市東山区福稲上高松町１１番地',
        industry='精密機器',
        sec_code='79790',
        corporate_number='6130001009674',
    ),
    'E01185': EdinetCodeEntry(
        edinet_code='E01185',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='12月31日',
        submitter_name='理研コランダム株式会社',
        submitter_name_en='Riken Corundum Company Limited',
        submitter_name_yomi='リケンコランダムカブシキガイシャ',
        address='鴻巣市宮前５４７番地の１',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='6030001061891',
    ),
    'E01186': EdinetCodeEntry(
        edinet_code='E01186',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=107,
        fiscal_year_end='3月31日',
        submitter_name='不二硝子株式会社',
        submitter_name_en='FUJI GLASS CO.,LTD.',
        submitter_name_yomi='フジガラスカブシキカイシャ',
        address='墨田区文花二丁目１５番９号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='1010601015163',
    ),
    'E01188': EdinetCodeEntry(
        edinet_code='E01188',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1320,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッカトー',
        submitter_name_en='NIKKATO CORPORATION',
        submitter_name_yomi='カブシキガイシャニッカトー',
        address='堺市堺区遠里小野町３丁２番２４号',
        industry='ガラス・土石製品',
        sec_code='53670',
        corporate_number='8120101006505',
    ),
    'E01190': EdinetCodeEntry(
        edinet_code='E01190',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32155,
        fiscal_year_end='12月31日',
        submitter_name='日本電気硝子株式会社',
        submitter_name_en='Nippon Electric Glass Co., Ltd.',
        submitter_name_yomi='ニッポンデンキガラスカブシキガイシャ',
        address='大津市晴嵐二丁目７番１号',
        industry='ガラス・土石製品',
        sec_code='52140',
        corporate_number='4160001001498',
    ),
    'E01191': EdinetCodeEntry(
        edinet_code='E01191',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1411,
        fiscal_year_end='3月31日',
        submitter_name='琉球セメント株式会社',
        submitter_name_en='ryukyu cement co.,ltd.',
        submitter_name_yomi='リュウキュウセメントカブシキガイシャ',
        address='浦添市西洲二丁目２番地２',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='9360001009277',
    ),
    'E01195': EdinetCodeEntry(
        edinet_code='E01195',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1617,
        fiscal_year_end='3月31日',
        submitter_name='クニミネ工業株式会社',
        submitter_name_en='KUNIMINE INDUSTRIES CO.,LTD',
        submitter_name_yomi='クニミネコウギョウカブシキガイシャ',
        address='千代田区岩本町一丁目１０番５号',
        industry='ガラス・土石製品',
        sec_code='53880',
        corporate_number='6010001015098',
    ),
    'E01197': EdinetCodeEntry(
        edinet_code='E01197',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5960,
        fiscal_year_end='3月31日',
        submitter_name='チヨダウーテ株式会社',
        submitter_name_en='CHIYODA UTE CO.,LTD.',
        submitter_name_yomi='チヨダウーテカブシキカイシャ',
        address='四日市市住吉町１５番２号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='1190001015556',
    ),
    'E01200': EdinetCodeEntry(
        edinet_code='E01200',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2019,
        fiscal_year_end='3月31日',
        submitter_name='日本興業株式会社',
        submitter_name_en='NIHON KOGYO CO., LTD.',
        submitter_name_yomi='ニホンコウギョウカブシキガイシャ',
        address='さぬき市志度４６１４番地１３',
        industry='ガラス・土石製品',
        sec_code='52790',
        corporate_number='3470001011236',
    ),
    'E01202': EdinetCodeEntry(
        edinet_code='E01202',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ヨシコン株式会社',
        submitter_name_en='Yoshicon Co.,Ltd',
        submitter_name_yomi='ヨシコンカブシキカイシャ',
        address='静岡市葵区常磐町一丁目４番地の１２',
        industry='不動産業',
        sec_code='52800',
        corporate_number='1080001010527',
    ),
    'E01204': EdinetCodeEntry(
        edinet_code='E01204',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2144,
        fiscal_year_end='3月31日',
        submitter_name='株式会社鶴弥',
        submitter_name_en='TSURUYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャツルヤ',
        address='半田市州の崎町２番地１２',
        industry='ガラス・土石製品',
        sec_code='53860',
        corporate_number='2180001091861',
    ),
    'E01205': EdinetCodeEntry(
        edinet_code='E01205',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=80,
        fiscal_year_end='12月31日',
        submitter_name='株式会社倉元製作所',
        submitter_name_en='KURAMOTO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクラモトセイサクショ',
        address='栗原市若柳武鎗字花水前１番地１',
        industry='ガラス・土石製品',
        sec_code='52160',
        corporate_number='1370201003004',
    ),
    'E01206': EdinetCodeEntry(
        edinet_code='E01206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3352,
        fiscal_year_end='3月31日',
        submitter_name='ジオスター株式会社',
        submitter_name_en='GEOSTR Corporation',
        submitter_name_yomi='ジオスターカブシキガイシャ',
        address='文京区小石川一丁目４番１号',
        industry='ガラス・土石製品',
        sec_code='52820',
        corporate_number='2010001083727',
    ),
    'E01207': EdinetCodeEntry(
        edinet_code='E01207',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4753,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジミインコーポレーテッド',
        submitter_name_en='FUJIMI  INCORPORATED',
        submitter_name_yomi='カブシキガイシャフジミインコーポレーテッド',
        address='清須市西枇杷島町地領２丁目１番地１',
        industry='ガラス・土石製品',
        sec_code='53840',
        corporate_number='7180001045697',
    ),
    'E01208': EdinetCodeEntry(
        edinet_code='E01208',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1264,
        fiscal_year_end='6月30日',
        submitter_name='株式会社高見澤',
        submitter_name_en='TAKAMISAWA CO., LTD.',
        submitter_name_yomi='カブシキガイシャタカミサワ',
        address='長野市大字鶴賀字苗間平１６０５番地１４',
        industry='卸売業',
        sec_code='52830',
        corporate_number='9100001001879',
    ),
    'E01209': EdinetCodeEntry(
        edinet_code='E01209',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3580,
        fiscal_year_end='3月31日',
        submitter_name='株式会社麻生',
        submitter_name_en='Aso Corporation',
        submitter_name_yomi='カブシキガイシャアソウ',
        address='飯塚市芳雄町７番１８号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='2290001045328',
    ),
    'E01210': EdinetCodeEntry(
        edinet_code='E01210',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8647,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＡＲＵＷＡ',
        submitter_name_en='MARUWA CO., LTD.',
        submitter_name_yomi='カブシキガイシャマルワ',
        address='尾張旭市南本地ヶ原町三丁目８３番地',
        industry='ガラス・土石製品',
        sec_code='53440',
        corporate_number='2180001079691',
    ),
    'E01211': EdinetCodeEntry(
        edinet_code='E01211',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='3月31日',
        submitter_name='ヤマウホールディングス株式会社',
        submitter_name_en='YAMAU HOLDINGS CO., LTD.',
        submitter_name_yomi='ヤマウホールディングスカブシキガイシャ',
        address='福岡市中央区舞鶴三丁目２番１号',
        industry='ガラス・土石製品',
        sec_code='52840',
        corporate_number='6290001010856',
    ),
    'E01212': EdinetCodeEntry(
        edinet_code='E01212',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1752,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤマックス',
        submitter_name_en='YAMAX Corp.',
        submitter_name_yomi='カブシキガイシャヤマックス',
        address='熊本市中央区水前寺３丁目９番５号',
        industry='ガラス・土石製品',
        sec_code='52850',
        corporate_number='5330001004739',
    ),
    'E01215': EdinetCodeEntry(
        edinet_code='E01215',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社武井工業所',
        submitter_name_en='TAKEI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタケイコウギョウショ',
        address='石岡市若松一丁目３番地２６号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='8050001011637',
    ),
    'E01216': EdinetCodeEntry(
        edinet_code='E01216',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イトーヨーギョー',
        submitter_name_en='ITO YOGYO CO.,  LTD.',
        submitter_name_yomi='カブシキガイシャイトーヨーギョー',
        address='神戸市中央区中山手通５丁目１番３号',
        industry='ガラス・土石製品',
        sec_code='52870',
        corporate_number='3140001003027',
    ),
    'E01217': EdinetCodeEntry(
        edinet_code='E01217',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=829,
        fiscal_year_end='3月31日',
        submitter_name='テクノクオーツ株式会社',
        submitter_name_en='Techno Quartz Inc.',
        submitter_name_yomi='テクノクオーツカブシキカイシャ',
        address='中野区本町一丁目３２番２号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='7011101033823',
    ),
    'E01218': EdinetCodeEntry(
        edinet_code='E01218',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3379,
        fiscal_year_end='3月31日',
        submitter_name='マイポックス株式会社',
        submitter_name_en='Mipox Corporation',
        submitter_name_yomi='マイポックスカブシキガイシャ',
        address='鹿沼市さつき町１８',
        industry='ガラス・土石製品',
        sec_code='53810',
        corporate_number='2012801002444',
    ),
    'E01219': EdinetCodeEntry(
        edinet_code='E01219',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=412,
        fiscal_year_end='6月30日',
        submitter_name='新東株式会社',
        submitter_name_en='SHINTO COMPANY LIMITED',
        submitter_name_yomi='シントウカブシキガイシャ',
        address='高浜市論地町四丁目７番地２',
        industry='ガラス・土石製品',
        sec_code='53800',
        corporate_number='9180301015778',
    ),
    'E01221': EdinetCodeEntry(
        edinet_code='E01221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2070,
        fiscal_year_end='3月31日',
        submitter_name='岡本硝子株式会社',
        submitter_name_en='OKAMOTO GLASS CO., LTD.',
        submitter_name_yomi='オカモトガラスカブシキガイシャ',
        address='柏市十余二３８０番地',
        industry='精密機器',
        sec_code='77460',
        corporate_number='2040001065334',
    ),
    'E01222': EdinetCodeEntry(
        edinet_code='E01222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6621,
        fiscal_year_end='3月31日',
        submitter_name='アジアパイルホールディングス株式会社',
        submitter_name_en='ASIA PILE HOLDINGS CORPORATION',
        submitter_name_yomi='アジアパイルホールディングスカブシキガイシャ',
        address='中央区日本橋箱崎町３６番２号\u3000Ｄａｉｗａリバーゲート',
        industry='ガラス・土石製品',
        sec_code='52880',
        corporate_number='2010001119497',
    ),
    'E01223': EdinetCodeEntry(
        edinet_code='E01223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7947,
        fiscal_year_end='12月31日',
        submitter_name='東洋炭素株式会社',
        submitter_name_en='TOYO TANSO CO.,LTD.',
        submitter_name_yomi='トウヨウタンソカブシキガイシャ',
        address='大阪市西淀川区竹島五丁目７番１２号',
        industry='ガラス・土石製品',
        sec_code='53100',
        corporate_number='1120001050238',
    ),
    'E01225': EdinetCodeEntry(
        edinet_code='E01225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=569519,
        fiscal_year_end='3月31日',
        submitter_name='日本製鉄株式会社',
        submitter_name_en='NIPPON STEEL CORPORATION',
        submitter_name_yomi='ニッポンセイテツカブシキガイシャ',
        address='千代田区丸の内二丁目６番１号',
        industry='鉄鋼',
        sec_code='54010',
        corporate_number='3010001008848',
    ),
    'E01226': EdinetCodeEntry(
        edinet_code='E01226',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=239644,
        fiscal_year_end=None,
        submitter_name='ＪＦＥスチール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイ\u3000エフ\u3000イー\u3000スチールカブシキガイシャ',
        address='千代田区内幸町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001008668',
    ),
    'E01229': EdinetCodeEntry(
        edinet_code='E01229',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20044,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中山製鋼所',
        submitter_name_en='NAKAYAMA STEEL WORKS, LTD.',
        submitter_name_yomi='カブシキガイシャナカヤマセイコウショ',
        address='大阪市大正区船町一丁目１番６６号',
        industry='鉄鋼',
        sec_code='54080',
        corporate_number='5120001027901',
    ),
    'E01230': EdinetCodeEntry(
        edinet_code='E01230',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20983,
        fiscal_year_end='3月31日',
        submitter_name='トピー工業株式会社',
        submitter_name_en='TOPY INDUSTRIES,LIMITED',
        submitter_name_yomi='トピーコウギョウカブシキガイシャ',
        address='品川区大崎一丁目２番２号',
        industry='輸送用機器',
        sec_code='72310',
        corporate_number='2010701019419',
    ),
    'E01231': EdinetCodeEntry(
        edinet_code='E01231',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=250930,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000神戸製鋼所',
        submitter_name_en='Kobe Steel, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000コウベセイコウショ',
        address='神戸市中央区脇浜海岸通２丁目２番４号',
        industry='鉄鋼',
        sec_code='54060',
        corporate_number='6140001005714',
    ),
    'E01232': EdinetCodeEntry(
        edinet_code='E01232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19865,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本製鋼所',
        submitter_name_en='The Japan Steel Works, Ltd.',
        submitter_name_yomi='カブシキガイシャニホンセイコウショ',
        address='品川区大崎一丁目１１番１号',
        industry='機械',
        sec_code='56310',
        corporate_number='5010701019531',
    ),
    'E01233': EdinetCodeEntry(
        edinet_code='E01233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10003,
        fiscal_year_end='3月31日',
        submitter_name='三菱製鋼株式会社',
        submitter_name_en='Mitsubishi Steel Mfg. Co.,Ltd.',
        submitter_name_yomi='ミツビシセイコウカブシキガイシャ',
        address='中央区月島四丁目１６番１３号',
        industry='鉄鋼',
        sec_code='56320',
        corporate_number='8010001058095',
    ),
    'E01234': EdinetCodeEntry(
        edinet_code='E01234',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25016,
        fiscal_year_end='3月31日',
        submitter_name='愛知製鋼株式会社',
        submitter_name_en='AICHI STEEL CORPORATION',
        submitter_name_yomi='アイチセイコウカブシキガイシャ',
        address='東海市荒尾町ワノ割１番地',
        industry='鉄鋼',
        sec_code='54820',
        corporate_number='9180001094156',
    ),
    'E01235': EdinetCodeEntry(
        edinet_code='E01235',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=34896,
        fiscal_year_end='3月31日',
        submitter_name='合同製鐵株式会社',
        submitter_name_en='Godo Steel,Ltd.',
        submitter_name_yomi='ゴウドウセイテツカブシキガイシャ',
        address='大阪市北区梅田三丁目２番２号\u3000ＪＰタワー大阪１９階',
        industry='鉄鋼',
        sec_code='54100',
        corporate_number='6120001049614',
    ),
    'E01236': EdinetCodeEntry(
        edinet_code='E01236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2627,
        fiscal_year_end='3月31日',
        submitter_name='日本鋳造株式会社',
        submitter_name_en='NIPPON CHUZO K. K.',
        submitter_name_yomi='ニッポンチュウゾウカブシキガイシャ',
        address='川崎市川崎区白石町２－１',
        industry='鉄鋼',
        sec_code='56090',
        corporate_number='8020001074100',
    ),
    'E01238': EdinetCodeEntry(
        edinet_code='E01238',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=651,
        fiscal_year_end='12月31日',
        submitter_name='大和重工株式会社',
        submitter_name_en='Daiwa Heavy Industry Co.,Ltd.',
        submitter_name_yomi='ダイワジュウコウカブシキガイシャ',
        address='広島市安佐北区可部１丁目２１－２３',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='9240001005817',
    ),
    'E01239': EdinetCodeEntry(
        edinet_code='E01239',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37172,
        fiscal_year_end='3月31日',
        submitter_name='大同特殊鋼株式会社',
        submitter_name_en='Daido Steel Co., Ltd.',
        submitter_name_yomi='ダイドウトクシュコウカブシキガイシャ',
        address='名古屋市東区東桜一丁目１番１０号',
        industry='鉄鋼',
        sec_code='54710',
        corporate_number='6180001037514',
    ),
    'E01240': EdinetCodeEntry(
        edinet_code='E01240',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12721,
        fiscal_year_end='3月31日',
        submitter_name='日本高周波鋼業株式会社',
        submitter_name_en='Nippon Koshuha Steel Co., Ltd.',
        submitter_name_yomi='ニッポンコウシュウハコウギョウカブシキガイシャ',
        address='千代田区岩本町一丁目１０番５号',
        industry='鉄鋼',
        sec_code='54760',
        corporate_number='1010001016852',
    ),
    'E01242': EdinetCodeEntry(
        edinet_code='E01242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24301,
        fiscal_year_end='3月31日',
        submitter_name='日本冶金工業株式会社',
        submitter_name_en='Nippon Yakin Kogyo Co.,Ltd.',
        submitter_name_yomi='ニッポンヤキンコウギョウカブシキガイシャ',
        address='中央区京橋一丁目５番８号',
        industry='鉄鋼',
        sec_code='54800',
        corporate_number='2010001034977',
    ),
    'E01243': EdinetCodeEntry(
        edinet_code='E01243',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=53800,
        fiscal_year_end='3月31日',
        submitter_name='山陽特殊製鋼株式会社',
        submitter_name_en='Sanyo Special Steel Co.,Ltd.',
        submitter_name_yomi='サンヨウトクシュセイコウカブシキガイシャ',
        address='姫路市飾磨区中島字一文字３００７番地',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='6140001058935',
    ),
    'E01244': EdinetCodeEntry(
        edinet_code='E01244',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プロテリアル',
        submitter_name_en='Proterial, Ltd.',
        submitter_name_yomi='カブシキガイシャプロテリアル',
        address='江東区豊洲五丁目６番３６号',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='3010401038783',
    ),
    'E01245': EdinetCodeEntry(
        edinet_code='E01245',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=827,
        fiscal_year_end='3月31日',
        submitter_name='東北特殊鋼株式会社',
        submitter_name_en='Tohoku Steel Co.,Ltd.',
        submitter_name_yomi='トウホクトクシュコウカブシキガイシャ',
        address='仙台市太白区長町七丁目２０番１号',
        industry='鉄鋼',
        sec_code='54840',
        corporate_number='2370001002444',
    ),
    'E01247': EdinetCodeEntry(
        edinet_code='E01247',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23220,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨドコウ',
        submitter_name_en='YODOKO,Ltd.',
        submitter_name_yomi='カブシキガイシャヨドコウ',
        address='大阪市中央区南本町四丁目１番１号',
        industry='鉄鋼',
        sec_code='54510',
        corporate_number='4120001077591',
    ),
    'E01249': EdinetCodeEntry(
        edinet_code='E01249',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5040,
        fiscal_year_end='3月31日',
        submitter_name='東洋鋼鈑株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウヨウコウハンカブシキガイシャ',
        address='品川区東五反田２－１８－１大崎フォレストビルディング',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='6010001008754',
    ),
    'E01251': EdinetCodeEntry(
        edinet_code='E01251',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5907,
        fiscal_year_end='3月31日',
        submitter_name='中部鋼鈑株式会社',
        submitter_name_en='Chubu Steel Plate Co.,Ltd.',
        submitter_name_yomi='チュウブコウハンカブシキガイシャ',
        address='名古屋市中川区小碓通五丁目１番地',
        industry='鉄鋼',
        sec_code='54610',
        corporate_number='2180001020102',
    ),
    'E01253': EdinetCodeEntry(
        edinet_code='E01253',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9595,
        fiscal_year_end='3月31日',
        submitter_name='丸一鋼管株式会社',
        submitter_name_en='Maruichi Steel Tube Ltd.',
        submitter_name_yomi='マルイチコウカンカブシキガイシャ',
        address='大阪市中央区難波五丁目１番６０号',
        industry='鉄鋼',
        sec_code='54630',
        corporate_number='5120001047593',
    ),
    'E01254': EdinetCodeEntry(
        edinet_code='E01254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13922,
        fiscal_year_end='3月31日',
        submitter_name='大平洋金属株式会社',
        submitter_name_en='Pacific Metals Co., Ltd.',
        submitter_name_yomi='タイヘイヨウキンゾクカブシキガイシャ',
        address='千代田区大手町一丁目６番１号',
        industry='鉄鋼',
        sec_code='55410',
        corporate_number='2010001008717',
    ),
    'E01256': EdinetCodeEntry(
        edinet_code='E01256',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11072,
        fiscal_year_end='12月31日',
        submitter_name='新日本電工株式会社',
        submitter_name_en='Nippon Denko Co., Ltd.',
        submitter_name_yomi='シンニッポンデンコウカブシキガイシャ',
        address='中央区八重洲一丁目４番１６号',
        industry='鉄鋼',
        sec_code='55630',
        corporate_number='9010001035003',
    ),
    'E01257': EdinetCodeEntry(
        edinet_code='E01257',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=175,
        fiscal_year_end='12月31日',
        submitter_name='新報国マテリアル株式会社',
        submitter_name_en='Shinhokoku Material Corp.',
        submitter_name_yomi='シンホウコクマテリアルカブシキガイシャ',
        address='川越市新宿町５丁目１３番地１',
        industry='鉄鋼',
        sec_code='55420',
        corporate_number='1030001054909',
    ),
    'E01259': EdinetCodeEntry(
        edinet_code='E01259',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7996,
        fiscal_year_end='3月31日',
        submitter_name='大和工業株式会社',
        submitter_name_en='YAMATO KOGYO CO.,LTD.',
        submitter_name_yomi='ヤマトコウギョウカブシキガイシャ',
        address='姫路市大津区吉美３８０番地',
        industry='鉄鋼',
        sec_code='54440',
        corporate_number='8140001059873',
    ),
    'E01260': EdinetCodeEntry(
        edinet_code='E01260',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1969,
        fiscal_year_end='3月31日',
        submitter_name='北越メタル株式会社',
        submitter_name_en='HOKUETSU METAL Co.,Ltd.',
        submitter_name_yomi='ホクエツメタルカブシキガイシャ',
        address='長岡市蔵王三丁目３番１号',
        industry='鉄鋼',
        sec_code='54460',
        corporate_number='9110001023162',
    ),
    'E01261': EdinetCodeEntry(
        edinet_code='E01261',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30894,
        fiscal_year_end='3月31日',
        submitter_name='東京製鐵株式会社',
        submitter_name_en='TOKYO STEEL MANUFACTURING CO., LTD.',
        submitter_name_yomi='トウキョウセイテツカブシキガイシャ',
        address='千代田区霞が関三丁目７番１号\u3000霞が関東急ビル',
        industry='鉄鋼',
        sec_code='54230',
        corporate_number='8010001008819',
    ),
    'E01262': EdinetCodeEntry(
        edinet_code='E01262',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=8769,
        fiscal_year_end='3月31日',
        submitter_name='大阪製鐵株式会社',
        submitter_name_en='OSAKA STEEL CO.,LTD.',
        submitter_name_yomi='オオサカセイテツカブシキガイシャ',
        address='大阪市大正区南恩加島一丁目９番３号',
        industry='鉄鋼',
        sec_code='54490',
        corporate_number='1120001028390',
    ),
    'E01263': EdinetCodeEntry(
        edinet_code='E01263',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2453,
        fiscal_year_end='3月31日',
        submitter_name='東京鋼鐵株式会社',
        submitter_name_en='TOKYO KOHTETSU CO.,Ltd',
        submitter_name_yomi='トウキョウコウテツカブシキガイシャ',
        address='千代田区内神田一丁目１７番９号',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='1010001034144',
    ),
    'E01264': EdinetCodeEntry(
        edinet_code='E01264',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=171310,
        fiscal_year_end='3月31日',
        submitter_name='ＪＦＥホールディングス株式会社',
        submitter_name_en='JFE Holdings,Inc.',
        submitter_name_yomi='ジェイエフイーホールディングスカブシキカイシャ',
        address='千代田区内幸町二丁目２番３号',
        industry='鉄鋼',
        sec_code='54110',
        corporate_number='6010001080308',
    ),
    'E01265': EdinetCodeEntry(
        edinet_code='E01265',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2190,
        fiscal_year_end='3月31日',
        submitter_name='朝日工業株式会社',
        submitter_name_en='ASAHI INDUSTRIES CO.,LTD.',
        submitter_name_yomi='アサヒコウギョウカブシキガイシャ',
        address='児玉郡神川町渡瀬２２２番地',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='2013301000418',
    ),
    'E01266': EdinetCodeEntry(
        edinet_code='E01266',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18516,
        fiscal_year_end='3月31日',
        submitter_name='共英製鋼株式会社',
        submitter_name_en='KYOEI STEEL LTD.',
        submitter_name_yomi='キョウエイセイコウカブシキガイシャ',
        address='大阪市北区堂島浜一丁目４番１６号',
        industry='鉄鋼',
        sec_code='54400',
        corporate_number='5120001062898',
    ),
    'E01267': EdinetCodeEntry(
        edinet_code='E01267',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=84130,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000クボタ',
        submitter_name_en='KUBOTA CORPORATION',
        submitter_name_yomi='カブシキガイシャクボタ',
        address='大阪市浪速区敷津東一丁目２番４７号',
        industry='機械',
        sec_code='63260',
        corporate_number='1120001037978',
    ),
    'E01268': EdinetCodeEntry(
        edinet_code='E01268',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31186,
        fiscal_year_end='3月31日',
        submitter_name='株式会社栗本鐵工所',
        submitter_name_en='Kurimoto,Ltd.',
        submitter_name_yomi='カブシキガイシャクリモトテッコウショ',
        address='大阪市西区北堀江１丁目１２番１９号',
        industry='鉄鋼',
        sec_code='56020',
        corporate_number='1120001048991',
    ),
    'E01269': EdinetCodeEntry(
        edinet_code='E01269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2002,
        fiscal_year_end='3月31日',
        submitter_name='虹技株式会社',
        submitter_name_en='KOGI CORPORATION',
        submitter_name_yomi='コウギカブシキガイシャ',
        address='姫路市大津区勘兵衛町４丁目１',
        industry='鉄鋼',
        sec_code='56030',
        corporate_number='6140001063844',
    ),
    'E01275': EdinetCodeEntry(
        edinet_code='E01275',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1504,
        fiscal_year_end='3月31日',
        submitter_name='高砂鐵工株式会社',
        submitter_name_en='TAKASAGO TEKKO K.K.',
        submitter_name_yomi='タカサゴテッコウカブシキガイシャ',
        address='板橋区新河岸一丁目１番１号',
        industry='鉄鋼',
        sec_code='54580',
        corporate_number='6011401003931',
    ),
    'E01276': EdinetCodeEntry(
        edinet_code='E01276',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6857,
        fiscal_year_end='3月31日',
        submitter_name='日本金属株式会社',
        submitter_name_en='NIPPON KINZOKU CO., LTD.',
        submitter_name_yomi='ニッポンキンゾクカブシキガイシャ',
        address='板橋区舟渡四丁目１０番１号',
        industry='鉄鋼',
        sec_code='54910',
        corporate_number='1011401011162',
    ),
    'E01277': EdinetCodeEntry(
        edinet_code='E01277',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='3月31日',
        submitter_name='中日本鋳工株式会社',
        submitter_name_en='NAKANIPPON CASTING CO.,LTD',
        submitter_name_yomi='ナカニッポンチュウコウカブシキガイシャ',
        address='西尾市港町６番地６',
        industry='機械',
        sec_code='64390',
        corporate_number='9180301022576',
    ),
    'E01280': EdinetCodeEntry(
        edinet_code='E01280',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='日本精線株式会社',
        submitter_name_en='Nippon Seisen Co., Ltd.',
        submitter_name_yomi='ニッポンセイセンカブシキガイシャ',
        address='大阪市中央区高麗橋四丁目１番１号',
        industry='鉄鋼',
        sec_code='56590',
        corporate_number='2120001093269',
    ),
    'E01282': EdinetCodeEntry(
        edinet_code='E01282',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8062,
        fiscal_year_end='3月31日',
        submitter_name='神鋼鋼線工業株式会社',
        submitter_name_en='KOBELCO WIRE COMPANY, LTD.',
        submitter_name_yomi='シンコウコウセンコウギョウカブシキガイシャ',
        address='尼崎市中浜町１０番地１',
        industry='鉄鋼',
        sec_code='56600',
        corporate_number='2140001049112',
    ),
    'E01283': EdinetCodeEntry(
        edinet_code='E01283',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1855,
        fiscal_year_end='3月31日',
        submitter_name='日本鋳鉄管株式会社',
        submitter_name_en='NIPPON CHUTETSUKAN K.K.',
        submitter_name_yomi='ニッポンチュウテツカンカブシキガイシャ',
        address='久喜市菖蒲町昭和沼１番地',
        industry='鉄鋼',
        sec_code='56120',
        corporate_number='3010001016859',
    ),
    'E01284': EdinetCodeEntry(
        edinet_code='E01284',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1036,
        fiscal_year_end='3月31日',
        submitter_name='中央可鍛工業株式会社',
        submitter_name_en='CHUO MALLEABLE IRON CO., LTD.',
        submitter_name_yomi='チュウオウカタンコウギョウカブシキガイシャ',
        address='名古屋市中川区富川町三丁目１番地の１',
        industry='鉄鋼',
        sec_code='56070',
        corporate_number='3180001020051',
    ),
    'E01287': EdinetCodeEntry(
        edinet_code='E01287',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10720,
        fiscal_year_end='3月31日',
        submitter_name='日亜鋼業株式会社',
        submitter_name_en='NICHIA STEEL WORKS,LTD.',
        submitter_name_yomi='ニチアコウギョウカブシキカイシャ',
        address='尼崎市中浜町１９番地',
        industry='鉄鋼',
        sec_code='56580',
        corporate_number='7140001050536',
    ),
    'E01289': EdinetCodeEntry(
        edinet_code='E01289',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7256,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シンニッタン',
        submitter_name_en='SNTCORPORATION',
        submitter_name_yomi='カブシキガイシャシンニッタン',
        address='高萩市上手綱３３３３番地３',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='2050001024009',
    ),
    'E01290': EdinetCodeEntry(
        edinet_code='E01290',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1093,
        fiscal_year_end='3月31日',
        submitter_name='尾張精機株式会社',
        submitter_name_en='OWARI PRECISE PRODUCTS CO.,LTD.',
        submitter_name_yomi='オワリセイキカブシキガイシャ',
        address='名古屋市東区矢田三丁目１６番８５号',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='6180001016360',
    ),
    'E01292': EdinetCodeEntry(
        edinet_code='E01292',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5839,
        fiscal_year_end='3月31日',
        submitter_name='東京鐵鋼株式会社',
        submitter_name_en='TOKYO TEKKO CO., LTD.',
        submitter_name_yomi='トウキョウテッコウカブシキガイシャ',
        address='小山市横倉新田５２０番地',
        industry='鉄鋼',
        sec_code='54450',
        corporate_number='8060001014498',
    ),
    'E01294': EdinetCodeEntry(
        edinet_code='E01294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1557,
        fiscal_year_end='3月31日',
        submitter_name='パウダーテック株式会社',
        submitter_name_en='Powdertech Co., Ltd.',
        submitter_name_yomi='パウダーテックカブシキガイシャ',
        address='柏市十余二２１７番地',
        industry='鉄鋼',
        sec_code='56950',
        corporate_number='7040001066245',
    ),
    'E01296': EdinetCodeEntry(
        edinet_code='E01296',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1513,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンユウ',
        submitter_name_en='SANYU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンユウ',
        address='枚方市春日北町３丁目１番１号',
        industry='鉄鋼',
        sec_code='56970',
        corporate_number='1120001149666',
    ),
    'E01297': EdinetCodeEntry(
        edinet_code='E01297',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3948,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイ・テック',
        submitter_name_en='ITEC CORPORATION',
        submitter_name_yomi='カブシキガイシャアイテック',
        address='静岡市清水区三保３８７番地７',
        industry='卸売業',
        sec_code=None,
        corporate_number='9080001007508',
    ),
    'E01298': EdinetCodeEntry(
        edinet_code='E01298',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1228,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エスイー',
        submitter_name_en='SE Corporation',
        submitter_name_yomi='カブシキガイシャエスイー',
        address='新宿区西新宿六丁目５番１号',
        industry='金属製品',
        sec_code='34230',
        corporate_number='4011101042505',
    ),
    'E01299': EdinetCodeEntry(
        edinet_code='E01299',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30000,
        fiscal_year_end=None,
        submitter_name='日本軽金属株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンケイキンゾクカブシキガイシャ',
        address='港区新橋１－１－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010701007662',
    ),
    'E01300': EdinetCodeEntry(
        edinet_code='E01300',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エス・サイエンス',
        submitter_name_en='S Science Company, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000エスサイエンス',
        address='中央区銀座八丁目９番１３号',
        industry='非鉄金属',
        sec_code='57210',
        corporate_number='6010001084903',
    ),
    'E01301': EdinetCodeEntry(
        edinet_code='E01301',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11963,
        fiscal_year_end='3月31日',
        submitter_name='東邦チタニウム株式会社',
        submitter_name_en='TOHO TITANIUM COMPANY LIMITED',
        submitter_name_yomi='トウホウチタニウムカブシキガイシャ',
        address='横浜市西区南幸一丁目１番１号',
        industry='非鉄金属',
        sec_code='57270',
        corporate_number='7021001007190',
    ),
    'E01303': EdinetCodeEntry(
        edinet_code='E01303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6964,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アーレスティ',
        submitter_name_en='AHRESTY CORPORATION',
        submitter_name_yomi='カブシキガイシャアーレスティ',
        address='豊橋市三弥町中原１番２号',
        industry='非鉄金属',
        sec_code='58520',
        corporate_number='7011201010490',
    ),
    'E01305': EdinetCodeEntry(
        edinet_code='E01305',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1595,
        fiscal_year_end='3月31日',
        submitter_name='日本伸銅株式会社',
        submitter_name_en='NIPPON SHINDO CO.,LTD.',
        submitter_name_yomi='ニホンシンドウカブシキガイシャ',
        address='堺市堺区匠町２０番地１',
        industry='非鉄金属',
        sec_code='57530',
        corporate_number='1120101008623',
    ),
    'E01308': EdinetCodeEntry(
        edinet_code='E01308',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='東邦亜鉛株式会社',
        submitter_name_en='Toho Zinc Co.,Ltd.',
        submitter_name_yomi='トウホウアエンカブシキガイシャ',
        address='港区虎ノ門三丁目１８番１９号',
        industry='非鉄金属',
        sec_code='57070',
        corporate_number='9010001034863',
    ),
    'E01315': EdinetCodeEntry(
        edinet_code='E01315',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7360,
        fiscal_year_end='3月31日',
        submitter_name='モリ工業株式会社',
        submitter_name_en='MORY INDUSTRIES INC.',
        submitter_name_yomi='モリコウギョウカブシキガイシャ',
        address='河内長野市楠町東１６１５番地',
        industry='鉄鋼',
        sec_code='54640',
        corporate_number='2120101034032',
    ),
    'E01317': EdinetCodeEntry(
        edinet_code='E01317',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=68806,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＬＩＸＩＬ',
        submitter_name_en='LIXIL Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000リクシル',
        address='品川区西品川一丁目１番１号\u3000大崎ガーデンタワー',
        industry='金属製品',
        sec_code='59380',
        corporate_number='5010601004914',
    ),
    'E01318': EdinetCodeEntry(
        edinet_code='E01318',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6346,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大紀アルミニウム工業所',
        submitter_name_en='DAIKI ALUMINIUM INDUSTRY CO.,LTD.',
        submitter_name_yomi='カブシキカイシャダイキアルミニウムコウギョウショ',
        address='大阪市北区中之島三丁目６番３２号',
        industry='非鉄金属',
        sec_code='57020',
        corporate_number='5120001125102',
    ),
    'E01320': EdinetCodeEntry(
        edinet_code='E01320',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2160,
        fiscal_year_end='3月31日',
        submitter_name='アルメタックス株式会社',
        submitter_name_en='ALMETAX MANUFACTURING CO.,LTD.',
        submitter_name_yomi='アルメタックスカブシキガイシャ',
        address='大阪市北区大淀中１丁目１番３０号',
        industry='金属製品',
        sec_code='59280',
        corporate_number='5120001060472',
    ),
    'E01321': EdinetCodeEntry(
        edinet_code='E01321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2756,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＣＫサンエツ',
        submitter_name_en='CK SAN-ETSU METALS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシーケーサンエツ',
        address='高岡市守護町二丁目１２番１号',
        industry='非鉄金属',
        sec_code='57570',
        corporate_number='7230001010051',
    ),
    'E01324': EdinetCodeEntry(
        edinet_code='E01324',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6842,
        fiscal_year_end='3月31日',
        submitter_name='小野建株式会社',
        submitter_name_en='ONOKEN CO.,LTD.',
        submitter_name_yomi='オノケンカブシキガイシャ',
        address='北九州市小倉北区西港町１２番地の１',
        industry='卸売業',
        sec_code='74140',
        corporate_number='6320001000746',
    ),
    'E01325': EdinetCodeEntry(
        edinet_code='E01325',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=481,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ダイケン',
        submitter_name_en='DAIKEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイケン',
        address='大阪市淀川区新高二丁目７番１３号',
        industry='金属製品',
        sec_code='59000',
        corporate_number='6120001056412',
    ),
    'E01327': EdinetCodeEntry(
        edinet_code='E01327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=8739,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大阪チタニウムテクノロジーズ',
        submitter_name_en='OSAKA Titanium technologies Co.,Ltd',
        submitter_name_yomi='カブシキガイシャ\u3000オオサカ\u3000チタニウム\u3000テクノロジーズ',
        address='尼崎市東浜町１番地',
        industry='非鉄金属',
        sec_code='57260',
        corporate_number='8140001052085',
    ),
    'E01329': EdinetCodeEntry(
        edinet_code='E01329',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エルアイイーエイチ',
        submitter_name_en='Life Intelligent Enterprise Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエルアイイーエイチ',
        address='中央区銀座八丁目９番１３号',
        industry='非鉄金属',
        sec_code='58560',
        corporate_number='3010001089995',
    ),
    'E01330': EdinetCodeEntry(
        edinet_code='E01330',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52277,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＵＡＣＪ',
        submitter_name_en='UACJ Corporation',
        submitter_name_yomi='カブシキガイシャユーエーシージェイ',
        address='港区三田３丁目５番１９号\u3000住友不動産東京三田ガーデンタワー',
        industry='非鉄金属',
        sec_code='57410',
        corporate_number='9010001098116',
    ),
    'E01331': EdinetCodeEntry(
        edinet_code='E01331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=156,
        fiscal_year_end='3月31日',
        submitter_name='エヌアイシ・オートテック株式会社',
        submitter_name_en='NIC Autotec,Inc.',
        submitter_name_yomi='エヌアイシオートテックカブシキガイシャ',
        address='江東区有明三丁目７番２６号有明フロンティアビルＢ棟１１階',
        industry='非鉄金属',
        sec_code='57420',
        corporate_number='2230001000412',
    ),
    'E01332': EdinetCodeEntry(
        edinet_code='E01332',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=69395,
        fiscal_year_end='3月31日',
        submitter_name='古河電気工業株式会社',
        submitter_name_en='Furukawa Electric Co., Ltd.',
        submitter_name_yomi='フルカワデンキコウギョウカブシキガイシャ',
        address='千代田区大手町二丁目６番４号',
        industry='非鉄金属',
        sec_code='58010',
        corporate_number='5010001008796',
    ),
    'E01333': EdinetCodeEntry(
        edinet_code='E01333',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99736,
        fiscal_year_end='3月31日',
        submitter_name='住友電気工業株式会社',
        submitter_name_en='Sumitomo Electric Industries, Ltd.',
        submitter_name_yomi='スミトモデンキコウギョウカブシキガイシャ',
        address='大阪市中央区北浜４丁目５番３３号',
        industry='非鉄金属',
        sec_code='58020',
        corporate_number='5120001077450',
    ),
    'E01334': EdinetCodeEntry(
        edinet_code='E01334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=53076,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジクラ',
        submitter_name_en='Fujikura Ltd.',
        submitter_name_yomi='カブシキガイシャフジクラ',
        address='江東区木場一丁目５番１号',
        industry='非鉄金属',
        sec_code='58030',
        corporate_number='2010601007861',
    ),
    'E01336': EdinetCodeEntry(
        edinet_code='E01336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24221,
        fiscal_year_end='3月31日',
        submitter_name='ＳＷＣＣ株式会社',
        submitter_name_en='SWCC Corporation',
        submitter_name_yomi='エスダブリューシーシーカブシキガイシャ',
        address='川崎市川崎区日進町１番１４号',
        industry='非鉄金属',
        sec_code='58050',
        corporate_number='7010401061336',
    ),
    'E01337': EdinetCodeEntry(
        edinet_code='E01337',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1925,
        fiscal_year_end='3月31日',
        submitter_name='東京特殊電線株式会社',
        submitter_name_en='TOTOKU ELECTRIC CO., LTD.',
        submitter_name_yomi='トウキョウトクシュデンセンカブシキガイシャ',
        address='港区西新橋３ー８ー３',
        industry='非鉄金属',
        sec_code=None,
        corporate_number='8010401084377',
    ),
    'E01338': EdinetCodeEntry(
        edinet_code='E01338',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6676,
        fiscal_year_end='3月31日',
        submitter_name='タツタ電線株式会社',
        submitter_name_en='TATSUTA ELECTRIC WIRE AND CABLE CO.,LTD',
        submitter_name_yomi='タツタデンセンカブシキガイシャ',
        address='東大阪市岩田町２丁目３番１号',
        industry='非鉄金属',
        sec_code=None,
        corporate_number='4122001004781',
    ),
    'E01343': EdinetCodeEntry(
        edinet_code='E01343',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4304,
        fiscal_year_end='3月31日',
        submitter_name='沖電線株式会社',
        submitter_name_en='Oki Electric Cable Co.,Ltd.',
        submitter_name_yomi='オキデンセンカブシキガイシャ',
        address='川崎市中原区下小田中２丁目１２番８号',
        industry='非鉄金属',
        sec_code=None,
        corporate_number='5020001069020',
    ),
    'E01348': EdinetCodeEntry(
        edinet_code='E01348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=647,
        fiscal_year_end='2月末日',
        submitter_name='ＪＭＡＣＳ株式会社',
        submitter_name_en='JMACS Japan Co.,Ltd.',
        submitter_name_yomi='ジェイマックスカブシキガイシャ',
        address='加東市森尾１２７番１',
        industry='非鉄金属',
        sec_code='58170',
        corporate_number='8122001015783',
    ),
    'E01350': EdinetCodeEntry(
        edinet_code='E01350',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1047,
        fiscal_year_end='12月31日',
        submitter_name='カナレ電気株式会社',
        submitter_name_en='Canare Electric Co., Ltd.',
        submitter_name_yomi='カナレデンキカブシキガイシャ',
        address='日進市藤枝町奥廻間１２０１番地１０',
        industry='非鉄金属',
        sec_code='58190',
        corporate_number='8180001067823',
    ),
    'E01351': EdinetCodeEntry(
        edinet_code='E01351',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1136,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三ッ星',
        submitter_name_en='MITSUBOSHI CO.,  LTD.',
        submitter_name_yomi='カブシキガイシャミツボシ',
        address='大阪市中央区本町一丁目４番８号',
        industry='非鉄金属',
        sec_code='58200',
        corporate_number='7120001025481',
    ),
    'E01352': EdinetCodeEntry(
        edinet_code='E01352',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1555,
        fiscal_year_end='3月31日',
        submitter_name='平河ヒューテック株式会社',
        submitter_name_en='HIRAKAWA HEWTECH CORP.',
        submitter_name_yomi='ヒラカワヒューテックカブシキガイシャ',
        address='港区芝四丁目１７番５号',
        industry='非鉄金属',
        sec_code='58210',
        corporate_number='1010701008364',
    ),
    'E01353': EdinetCodeEntry(
        edinet_code='E01353',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11094,
        fiscal_year_end='3月31日',
        submitter_name='東洋製罐グループホールディングス株式会社',
        submitter_name_en='Toyo Seikan Group Holdings, Ltd.',
        submitter_name_yomi='トウヨウセイカングループホールディングスカブシキガイシャ',
        address='品川区東五反田二丁目１８番１号',
        industry='金属製品',
        sec_code='59010',
        corporate_number='7010701026096',
    ),
    'E01354': EdinetCodeEntry(
        edinet_code='E01354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11086,
        fiscal_year_end='3月31日',
        submitter_name='ホッカンホールディングス株式会社',
        submitter_name_en='HOKKAN HOLDINGS LIMITED',
        submitter_name_yomi='ホッカンホールディングスカブシキガイシャ',
        address='中央区日本橋室町二丁目１番１号',
        industry='金属製品',
        sec_code='59020',
        corporate_number='6010001008804',
    ),
    'E01355': EdinetCodeEntry(
        edinet_code='E01355',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9435,
        fiscal_year_end='3月31日',
        submitter_name='株式会社横河ブリッジホールディングス',
        submitter_name_en='Yokogawa Bridge Holdings Corp.',
        submitter_name_yomi='カブシキガイシャヨコガワブリッジホールディングス',
        address='港区芝浦四丁目４番４４号',
        industry='金属製品',
        sec_code='59110',
        corporate_number='9010401030578',
    ),
    'E01358': EdinetCodeEntry(
        edinet_code='E01358',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='ＯＳＪＢホールディングス株式会社',
        submitter_name_en='OSJB Holdings Corporation',
        submitter_name_yomi='オーエスジェイビーホールディングスカブシキガイシャ',
        address='江東区豊洲五丁目６番５２号',
        industry='建設業',
        sec_code=None,
        corporate_number='3120001030147',
    ),
    'E01362': EdinetCodeEntry(
        edinet_code='E01362',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6619,
        fiscal_year_end='3月31日',
        submitter_name='株式会社駒井ハルテック',
        submitter_name_en='KOMAIHALTEC Inc.',
        submitter_name_yomi='カブシキガイシャコマイハルテック',
        address='大阪市西区立売堀四丁目２番２１号',
        industry='金属製品',
        sec_code='59150',
        corporate_number='2120001028927',
    ),
    'E01364': EdinetCodeEntry(
        edinet_code='E01364',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1361,
        fiscal_year_end='3月31日',
        submitter_name='瀧上工業株式会社',
        submitter_name_en='The Takigami Steel Construction Co.,Ltd.',
        submitter_name_yomi='タキガミコウギョウカブシキガイシャ',
        address='半田市神明町一丁目１番地',
        industry='金属製品',
        sec_code='59180',
        corporate_number='1180001089667',
    ),
    'E01365': EdinetCodeEntry(
        edinet_code='E01365',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='3月31日',
        submitter_name='那須電機鉄工株式会社',
        submitter_name_en='NASU DENKI-TEKKO CO.,LTD.',
        submitter_name_yomi='ナスデンキテッコウカブシキガイシャ',
        address='新宿区新宿二丁目１番１２号',
        industry='金属製品',
        sec_code='59220',
        corporate_number='5011101015468',
    ),
    'E01366': EdinetCodeEntry(
        edinet_code='E01366',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1710,
        fiscal_year_end='3月31日',
        submitter_name='中国工業株式会社',
        submitter_name_en='CHUGOKUKOGYO CO.,LTD.',
        submitter_name_yomi='チュウゴクコウギョウカブシキガイシャ',
        address='広島市中区小町２－２６',
        industry='金属製品',
        sec_code='59740',
        corporate_number='6240001006578',
    ),
    'E01367': EdinetCodeEntry(
        edinet_code='E01367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17009,
        fiscal_year_end='3月31日',
        submitter_name='日本発條株式会社',
        submitter_name_en='NHK SPRING CO., LTD.',
        submitter_name_yomi='ニッポンハツジョウカブシキガイシャ',
        address='横浜市金沢区福浦三丁目１０番地',
        industry='金属製品',
        sec_code='59910',
        corporate_number='7020001006616',
    ),
    'E01368': EdinetCodeEntry(
        edinet_code='E01368',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=615,
        fiscal_year_end='3月31日',
        submitter_name='アマテイ株式会社',
        submitter_name_en='Amatei Incorporated',
        submitter_name_yomi='アマテイカブシキガイシャ',
        address='尼崎市西高洲町９番地',
        industry='金属製品',
        sec_code='59520',
        corporate_number='5140001047550',
    ),
    'E01369': EdinetCodeEntry(
        edinet_code='E01369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワイズホールディングス',
        submitter_name_en='WISE HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシヤワイズホールディングス',
        address='京都市山科区東野狐藪町１６番地',
        industry='金属製品',
        sec_code='59550',
        corporate_number='2130001013473',
    ),
    'E01370': EdinetCodeEntry(
        edinet_code='E01370',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2685,
        fiscal_year_end='11月30日',
        submitter_name='日本フイルコン株式会社',
        submitter_name_en='NIPPON FILCON CO.,LTD.',
        submitter_name_yomi='ニホンフイルコンカブシキガイシャ',
        address='稲城市大丸２２２０番地',
        industry='金属製品',
        sec_code='59420',
        corporate_number='4013401002394',
    ),
    'E01372': EdinetCodeEntry(
        edinet_code='E01372',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9197,
        fiscal_year_end='3月31日',
        submitter_name='日工株式会社',
        submitter_name_en='NIKKO CO.,LTD.',
        submitter_name_yomi='ニッコウカブシキガイシャ',
        address='明石市大久保町江井島１０１３番地の１',
        industry='機械',
        sec_code='63060',
        corporate_number='6140001035281',
    ),
    'E01373': EdinetCodeEntry(
        edinet_code='E01373',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5178,
        fiscal_year_end='3月31日',
        submitter_name='高田機工株式会社',
        submitter_name_en='TAKADAKIKO(Steel Construction)CO.,LTD.',
        submitter_name_yomi='タカダキコウカブシキガイシャ',
        address='大阪市浪速区難波中２丁目１０番７０号',
        industry='金属製品',
        sec_code='59230',
        corporate_number='8120001038994',
    ),
    'E01375': EdinetCodeEntry(
        edinet_code='E01375',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=365,
        fiscal_year_end='11月30日',
        submitter_name='株式会社山本製作所',
        submitter_name_en='Yamamoto Mfg.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャヤマモトセイサクショ',
        address='板橋区清水町４番４号',
        industry='金属製品',
        sec_code=None,
        corporate_number='1011401006542',
    ),
    'E01376': EdinetCodeEntry(
        edinet_code='E01376',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=700,
        fiscal_year_end='3月31日',
        submitter_name='東洋刄物株式会社',
        submitter_name_en='TOYO KNIFE CO., LTD.',
        submitter_name_yomi='トウヨウハモノカブシキガイシャ',
        address='富谷市富谷日渡３４番地１１',
        industry='金属製品',
        sec_code=None,
        corporate_number='3370001005693',
    ),
    'E01377': EdinetCodeEntry(
        edinet_code='E01377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13044,
        fiscal_year_end='11月30日',
        submitter_name='オーエスジー株式会社',
        submitter_name_en='OSG Corporation',
        submitter_name_yomi='オーエスジーカブシキガイシャ',
        address='豊川市本野ケ原三丁目２２番地',
        industry='機械',
        sec_code='61360',
        corporate_number='1180301010019',
    ),
    'E01378': EdinetCodeEntry(
        edinet_code='E01378',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='東京製綱株式会社',
        submitter_name_en='TOKYO ROPE MFG. CO., LTD.',
        submitter_name_yomi='トウキョウセイコウカブシキガイシャ',
        address='江東区永代２－３７－２８',
        industry='金属製品',
        sec_code='59810',
        corporate_number='7010001034997',
    ),
    'E01379': EdinetCodeEntry(
        edinet_code='E01379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18472,
        fiscal_year_end='12月31日',
        submitter_name='リョービ株式会社',
        submitter_name_en='RYOBI LIMITED',
        submitter_name_yomi='リョービカブシキガイシャ',
        address='府中市目崎町７６２番地',
        industry='非鉄金属',
        sec_code='58510',
        corporate_number='8240001034478',
    ),
    'E01380': EdinetCodeEntry(
        edinet_code='E01380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=605,
        fiscal_year_end='5月31日',
        submitter_name='ＴＯＮＥ株式会社',
        submitter_name_en='TONE CO.,LTD.',
        submitter_name_yomi='トネカブシキガイシャ',
        address='河内長野市寿町６番２５号',
        industry='金属製品',
        sec_code='59670',
        corporate_number='9120001013625',
    ),
    'E01381': EdinetCodeEntry(
        edinet_code='E01381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=955,
        fiscal_year_end='9月30日',
        submitter_name='川岸工業株式会社',
        submitter_name_en='Kawagishi Bridge Works Co.,Ltd.',
        submitter_name_yomi='カワギシコウギョウカブシキガイシャ',
        address='港区東新橋一丁目２番１３号',
        industry='金属製品',
        sec_code='59210',
        corporate_number='1010401007286',
    ),
    'E01382': EdinetCodeEntry(
        edinet_code='E01382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5610,
        fiscal_year_end='3月31日',
        submitter_name='東プレ株式会社',
        submitter_name_en='Topre Corporation',
        submitter_name_yomi='トウプレカブシキガイシャ',
        address='中央区日本橋３丁目１２番２号',
        industry='金属製品',
        sec_code='59750',
        corporate_number='4010001036658',
    ),
    'E01385': EdinetCodeEntry(
        edinet_code='E01385',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38413,
        fiscal_year_end='3月31日',
        submitter_name='三和ホールディングス株式会社',
        submitter_name_en='Sanwa Holdings Corporation',
        submitter_name_yomi='サンワホールディングスカブシキガイシャ',
        address='新宿区西新宿２丁目１番１号',
        industry='金属製品',
        sec_code='59290',
        corporate_number='3011101010289',
    ),
    'E01391': EdinetCodeEntry(
        edinet_code='E01391',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=829,
        fiscal_year_end='3月31日',
        submitter_name='浅香工業株式会社',
        submitter_name_en='ASAKA INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='アサカコウギョウカブシキガイシャ',
        address='堺市堺区海山町２丁１１７番地',
        industry='その他製品',
        sec_code='59620',
        corporate_number='8120101000268',
    ),
    'E01393': EdinetCodeEntry(
        edinet_code='E01393',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000アドバネクス',
        submitter_name_en='Advanex inc.',
        submitter_name_yomi='カブシキガイシャ\u3000アドバネクス',
        address='北区田端六丁目１番１号',
        industry='金属製品',
        sec_code='59980',
        corporate_number='7011501000992',
    ),
    'E01394': EdinetCodeEntry(
        edinet_code='E01394',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000巴コーポレーション',
        submitter_name_en='TOMOE CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000トモエコーポレーション',
        address='中央区勝どき四丁目６番２号',
        industry='建設業',
        sec_code='19210',
        corporate_number='9010001034839',
    ),
    'E01395': EdinetCodeEntry(
        edinet_code='E01395',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1564,
        fiscal_year_end='3月31日',
        submitter_name='イハラサイエンス株式会社',
        submitter_name_en='IHARA SCIENCE CORPORATION',
        submitter_name_yomi='イハラサイエンスカブシキガイシャ',
        address='港区高輪３丁目１１番３号イハラ高輪ビル',
        industry='金属製品',
        sec_code=None,
        corporate_number='7010701001033',
    ),
    'E01396': EdinetCodeEntry(
        edinet_code='E01396',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2203,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファインシンター',
        submitter_name_en='FINESINTER CO.,LTD.',
        submitter_name_yomi='カブシキガイシャファインシンター',
        address='春日井市明知町西之洞１１８９番地１１',
        industry='金属製品',
        sec_code='59940',
        corporate_number='6180001078161',
    ),
    'E01397': EdinetCodeEntry(
        edinet_code='E01397',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社佐賀鉄工所',
        submitter_name_en='SAGA TEKKOHSHO CO.,LTD.',
        submitter_name_yomi='カブシキカイシャサガテッコウショ',
        address='佐賀市神園一丁目５番３０号',
        industry='金属製品',
        sec_code=None,
        corporate_number='2300001000504',
    ),
    'E01398': EdinetCodeEntry(
        edinet_code='E01398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3235,
        fiscal_year_end='3月31日',
        submitter_name='北沢産業株式会社',
        submitter_name_en='KITAZAWASANGYOco.,ltd.',
        submitter_name_yomi='キタザワサンギョウカブシキガイシャ',
        address='渋谷区東二丁目２３番１０号',
        industry='卸売業',
        sec_code='99300',
        corporate_number='3011001006107',
    ),
    'E01399': EdinetCodeEntry(
        edinet_code='E01399',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=645,
        fiscal_year_end='12月31日',
        submitter_name='株式会社協和',
        submitter_name_en='KYOWA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウワ',
        address='高崎市大八木町５８８番地',
        industry='金属製品',
        sec_code=None,
        corporate_number='1070001026169',
    ),
    'E01400': EdinetCodeEntry(
        edinet_code='E01400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6418,
        fiscal_year_end='3月31日',
        submitter_name='高周波熱錬株式会社',
        submitter_name_en='Neturen Co., Ltd.',
        submitter_name_yomi='コウシュウハネツレンカブシキガイシャ',
        address='品川区東五反田２丁目１７番１号',
        industry='金属製品',
        sec_code='59760',
        corporate_number='1010701003241',
    ),
    'E01401': EdinetCodeEntry(
        edinet_code='E01401',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='東邦金属株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウホウキンゾクカブシキガイシャ',
        address='大阪市中央区備後町二丁目４番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001077491',
    ),
    'E01402': EdinetCodeEntry(
        edinet_code='E01402',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4808,
        fiscal_year_end='3月31日',
        submitter_name='サンコール株式会社',
        submitter_name_en='SUNCALL CORPORATION',
        submitter_name_yomi='サンコールカブシキカイシャ',
        address='京都市右京区梅津西浦町１４番地',
        industry='金属製品',
        sec_code='59850',
        corporate_number='4130001000899',
    ),
    'E01403': EdinetCodeEntry(
        edinet_code='E01403',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=960,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ロブテックス',
        submitter_name_en='LOBTEX.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャロブテックス',
        address='東大阪市四条町１２－８',
        industry='金属製品',
        sec_code='59690',
        corporate_number='8122001008085',
    ),
    'E01405': EdinetCodeEntry(
        edinet_code='E01405',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10837,
        fiscal_year_end='3月31日',
        submitter_name='中央発條株式会社',
        submitter_name_en='CHUO SPRING CO.,LTD.',
        submitter_name_yomi='チュウオウハツジョウカブシキガイシャ',
        address='名古屋市緑区鳴海町字上汐田６８番地',
        industry='金属製品',
        sec_code='59920',
        corporate_number='9180001028444',
    ),
    'E01408': EdinetCodeEntry(
        edinet_code='E01408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=738,
        fiscal_year_end='3月31日',
        submitter_name='日本製罐株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイカンカブシキガイシャ',
        address='さいたま市北区吉野町２丁目２７５番地',
        industry='金属製品',
        sec_code='59050',
        corporate_number='4030001006527',
    ),
    'E01409': EdinetCodeEntry(
        edinet_code='E01409',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1760,
        fiscal_year_end='3月31日',
        submitter_name='三洋工業株式会社',
        submitter_name_en='SANYO INDUSTRIES, LTD.',
        submitter_name_yomi='サンヨウコウギョウカブシキガイシャ',
        address='墨田区太平二丁目９番４号',
        industry='金属製品',
        sec_code='59580',
        corporate_number='6010601002347',
    ),
    'E01411': EdinetCodeEntry(
        edinet_code='E01411',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1848,
        fiscal_year_end='3月31日',
        submitter_name='モリテックスチール株式会社',
        submitter_name_en='MOLITEC STEEL CO.,LTD.',
        submitter_name_yomi='モリテックスチールカブシキガイシャ',
        address='大阪市中央区谷町六丁目１８番３１号',
        industry='金属製品',
        sec_code='59860',
        corporate_number='7120001077572',
    ),
    'E01412': EdinetCodeEntry(
        edinet_code='E01412',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6911,
        fiscal_year_end='12月31日',
        submitter_name='岡部株式会社',
        submitter_name_en='OKABE CO., LTD.',
        submitter_name_yomi='オカベカブシキガイシャ',
        address='墨田区押上二丁目８番２号',
        industry='金属製品',
        sec_code='59590',
        corporate_number='7010601009878',
    ),
    'E01413': EdinetCodeEntry(
        edinet_code='E01413',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15051,
        fiscal_year_end='3月31日',
        submitter_name='文化シヤッター株式会社',
        submitter_name_en='Bunka Shutter Co.,Ltd.',
        submitter_name_yomi='ブンカシヤッターカブシキガイシャ',
        address='文京区西片１丁目１７番３号',
        industry='金属製品',
        sec_code='59300',
        corporate_number='3010001088907',
    ),
    'E01414': EdinetCodeEntry(
        edinet_code='E01414',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10490,
        fiscal_year_end='3月31日',
        submitter_name='イーグル工業株式会社',
        submitter_name_en='EAGLE INDUSTRY CO.,LTD.',
        submitter_name_yomi='イーグルコウギョウカブシキガイシャ',
        address='港区芝大門１丁目１２番１５号',
        industry='機械',
        sec_code='64860',
        corporate_number='2010401002451',
    ),
    'E01415': EdinetCodeEntry(
        edinet_code='E01415',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2024,
        fiscal_year_end='3月31日',
        submitter_name='東洋シヤッター株式会社',
        submitter_name_en='TOYO SHUTTER CO.,LTD.',
        submitter_name_yomi='トウヨウシヤッターカブシキガイシャ',
        address='大阪市中央区南船場二丁目３番２号',
        industry='金属製品',
        sec_code='59360',
        corporate_number='4120001085479',
    ),
    'E01417': EdinetCodeEntry(
        edinet_code='E01417',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6484,
        fiscal_year_end='3月31日',
        submitter_name='リンナイ株式会社',
        submitter_name_en='RINNAI CORPORATION',
        submitter_name_yomi='リンナイカブシキガイシャ',
        address='名古屋市中川区福住町２番２６号',
        industry='金属製品',
        sec_code='59470',
        corporate_number='2180001021323',
    ),
    'E01419': EdinetCodeEntry(
        edinet_code='E01419',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=819,
        fiscal_year_end='2月末日',
        submitter_name='知多鋼業株式会社',
        submitter_name_en='CHITAKOGYO CO.,LTD.',
        submitter_name_yomi='チタコウギョウカブシキガイシャ',
        address='春日井市前並町２丁目１２番地４',
        industry='金属製品',
        sec_code=None,
        corporate_number='6180001078368',
    ),
    'E01420': EdinetCodeEntry(
        edinet_code='E01420',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1032,
        fiscal_year_end='3月31日',
        submitter_name='京都機械工具株式会社',
        submitter_name_en='KYOTO TOOL CO.,LTD.',
        submitter_name_yomi='キョウトキカイコウグカブシキガイシャ',
        address='京都市伏見区下鳥羽渡瀬町１０１番地',
        industry='金属製品',
        sec_code='59660',
        corporate_number='6130001016191',
    ),
    'E01421': EdinetCodeEntry(
        edinet_code='E01421',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='日本パワーファスニング株式会社',
        submitter_name_en='JAPAN POWER FASTENING CO.,LTD',
        submitter_name_yomi='ニホンパワーファスニングカブシキガイシャ',
        address='箕面市船場西１丁目８番３号',
        industry='金属製品',
        sec_code='59500',
        corporate_number='5120001108081',
    ),
    'E01422': EdinetCodeEntry(
        edinet_code='E01422',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1709,
        fiscal_year_end='3月31日',
        submitter_name='不二サッシ株式会社',
        submitter_name_en='FUJISASH CO.,LTD.',
        submitter_name_yomi='フジサッシカブシキガイシャ',
        address='川崎市幸区鹿島田１丁目１番２号',
        industry='金属製品',
        sec_code='59400',
        corporate_number='7020001070117',
    ),
    'E01425': EdinetCodeEntry(
        edinet_code='E01425',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=655,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大谷工業',
        submitter_name_en='OTANI KOGYO CO., LTD.',
        submitter_name_yomi='カブシキガイシャオオタニコウギョウ',
        address='品川区西五反田７丁目２３番１号',
        industry='金属製品',
        sec_code='59390',
        corporate_number='5010701002074',
    ),
    'E01426': EdinetCodeEntry(
        edinet_code='E01426',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=581,
        fiscal_year_end='3月31日',
        submitter_name='天龍製鋸株式会社',
        submitter_name_en='Tenryu Saw Mfg. Co., Ltd.',
        submitter_name_yomi='テンリュウセイキョカブシキガイシャ',
        address='袋井市浅羽３７１１番地',
        industry='金属製品',
        sec_code='59450',
        corporate_number='3080401017392',
    ),
    'E01427': EdinetCodeEntry(
        edinet_code='E01427',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4058,
        fiscal_year_end='3月31日',
        submitter_name='ダイニチ工業株式会社',
        submitter_name_en='Dainichi Co., Ltd.',
        submitter_name_yomi='ダイニチコウギョウカブシキガイシャ',
        address='新潟市南区北田中７８０番地６',
        industry='金属製品',
        sec_code='59510',
        corporate_number='8110001007521',
    ),
    'E01428': EdinetCodeEntry(
        edinet_code='E01428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=664,
        fiscal_year_end='3月31日',
        submitter_name='株式会社研創',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケンソウ',
        address='広島市安佐北区上深川町４４８番地',
        industry='その他製品',
        sec_code='79390',
        corporate_number='9240001003119',
    ),
    'E01430': EdinetCodeEntry(
        edinet_code='E01430',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6361,
        fiscal_year_end='3月20日',
        submitter_name='アルインコ株式会社',
        submitter_name_en='ALINCO INCORPORATED',
        submitter_name_yomi='アルインコカブシキガイシャ',
        address='高槻市三島江１丁目１番１号',
        industry='金属製品',
        sec_code='59330',
        corporate_number='3120901010347',
    ),
    'E01431': EdinetCodeEntry(
        edinet_code='E01431',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1683,
        fiscal_year_end='12月31日',
        submitter_name='協立エアテック株式会社',
        submitter_name_en='KYORITSU AIR TECH INC.',
        submitter_name_yomi='キョウリツエアテックカブシキガイシャ',
        address='糟屋郡篠栗町和田五丁目７番１号',
        industry='金属製品',
        sec_code='59970',
        corporate_number='2290001038257',
    ),
    'E01433': EdinetCodeEntry(
        edinet_code='E01433',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='元旦ビューティ工業株式会社',
        submitter_name_en='GANTAN BEAUTY INDUSTRY CO.,LTD.',
        submitter_name_yomi='ガンタンビューティコウギョウカブシキガイシャ',
        address='藤沢市湘南台１丁目１番地２１',
        industry='金属製品',
        sec_code=None,
        corporate_number='6021001000469',
    ),
    'E01434': EdinetCodeEntry(
        edinet_code='E01434',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2854,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＶＫ',
        submitter_name_en='KVK CORPORATION',
        submitter_name_yomi='カブシキガイシャケーブイケー',
        address='加茂郡富加町高畑字稲荷６４１番地',
        industry='機械',
        sec_code='64840',
        corporate_number='6200001001871',
    ),
    'E01435': EdinetCodeEntry(
        edinet_code='E01435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2235,
        fiscal_year_end='3月15日',
        submitter_name='株式会社スーパーツール',
        submitter_name_en='SUPER TOOL CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスーパーツール',
        address='堺市中区見野山１５８番地',
        industry='金属製品',
        sec_code='59900',
        corporate_number='1120101003608',
    ),
    'E01436': EdinetCodeEntry(
        edinet_code='E01436',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2365,
        fiscal_year_end='3月31日',
        submitter_name='ＪＦＥコンテイナー株式会社',
        submitter_name_en='JFE Container Co.,Ltd.',
        submitter_name_yomi='ジェイエフイーコンテイナーカブシキカイシャ',
        address='千代田区神田猿楽町一丁目５番１５号',
        industry='金属製品',
        sec_code=None,
        corporate_number='6010001112820',
    ),
    'E01437': EdinetCodeEntry(
        edinet_code='E01437',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2142,
        fiscal_year_end='3月31日',
        submitter_name='兼房株式会社',
        submitter_name_en='KANEFUSA CORPORATION',
        submitter_name_yomi='カネフサカブシキガイシャ',
        address='丹羽郡大口町中小口一丁目１番地',
        industry='金属製品',
        sec_code='59840',
        corporate_number='6180001080984',
    ),
    'E01438': EdinetCodeEntry(
        edinet_code='E01438',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2960,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パイオラックス',
        submitter_name_en='PIOLAX,INC.',
        submitter_name_yomi='カブシキガイシャパイオラックス',
        address='横浜市西区花咲町六丁目１４５番地',
        industry='金属製品',
        sec_code='59880',
        corporate_number='7020001030260',
    ),
    'E01439': EdinetCodeEntry(
        edinet_code='E01439',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1496,
        fiscal_year_end='3月31日',
        submitter_name='イワブチ株式会社',
        submitter_name_en='IWABUCHI CORPORATION',
        submitter_name_yomi='イワブチカブシキガイシャ',
        address='松戸市上本郷１６７番地',
        industry='金属製品',
        sec_code='59830',
        corporate_number='9040001034893',
    ),
    'E01441': EdinetCodeEntry(
        edinet_code='E01441',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1290,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーアミ',
        submitter_name_en='TOAMI CORPORATION',
        submitter_name_yomi='カブシキガイシャトーアミ',
        address='四條畷市中野新町１０番２０号',
        industry='金属製品',
        sec_code='59730',
        corporate_number='5122001016280',
    ),
    'E01442': EdinetCodeEntry(
        edinet_code='E01442',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=592,
        fiscal_year_end='4月30日',
        submitter_name='株式会社共和工業所',
        submitter_name_en='KYOWAKOGYOSYO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウワコウギョウショ',
        address='小松市工業団地一丁目５７番地',
        industry='金属製品',
        sec_code='59710',
        corporate_number='1220001011873',
    ),
    'E01443': EdinetCodeEntry(
        edinet_code='E01443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2658,
        fiscal_year_end='3月31日',
        submitter_name='トーカロ株式会社',
        submitter_name_en='TOCALO Co.,Ltd.',
        submitter_name_yomi='トーカロカブシキガイシャ',
        address='神戸市中央区港島南町６丁目４番４号',
        industry='金属製品',
        sec_code='34330',
        corporate_number='6140001021397',
    ),
    'E01444': EdinetCodeEntry(
        edinet_code='E01444',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7449,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000コロナ',
        submitter_name_en='CORONA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000コロナ',
        address='三条市東新保７番７号',
        industry='金属製品',
        sec_code='59090',
        corporate_number='5110001014116',
    ),
    'E01445': EdinetCodeEntry(
        edinet_code='E01445',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1445,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000中西製作所',
        submitter_name_en='NAKANISHI MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャナカニシセイサクショ',
        address='大阪市生野区巽南五丁目４番１４号',
        industry='金属製品',
        sec_code='59410',
        corporate_number='3120001018349',
    ),
    'E01446': EdinetCodeEntry(
        edinet_code='E01446',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=878,
        fiscal_year_end='6月30日',
        submitter_name='株式会社オーネックス',
        submitter_name_en='ONEX Corporation',
        submitter_name_yomi='カブシキガイシャオーネックス',
        address='町田市森野１丁目７番２３号',
        industry='金属製品',
        sec_code='59870',
        corporate_number='2021001019513',
    ),
    'E01448': EdinetCodeEntry(
        edinet_code='E01448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1820,
        fiscal_year_end='3月31日',
        submitter_name='カネソウ株式会社',
        submitter_name_en='KANESO CO.,LTD.',
        submitter_name_yomi='カネソウカブシキガイシャ',
        address='三重郡朝日町大字縄生８１番地',
        industry='金属製品',
        sec_code='59790',
        corporate_number='5190001014604',
    ),
    'E01451': EdinetCodeEntry(
        edinet_code='E01451',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1132,
        fiscal_year_end='7月31日',
        submitter_name='株式会社稲葉製作所',
        submitter_name_en='INABA SEISAKUSHO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイナバセイサクショ',
        address='大田区矢口２丁目５番２５号',
        industry='金属製品',
        sec_code='34210',
        corporate_number='8010801001097',
    ),
    'E01452': EdinetCodeEntry(
        edinet_code='E01452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1950,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000Ｊ－ＭＡＸ',
        submitter_name_en='J-MAX Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ジェイマックス',
        address='大垣市上石津町乙坂１３０番地１',
        industry='金属製品',
        sec_code='34220',
        corporate_number='7200001014294',
    ),
    'E01454': EdinetCodeEntry(
        edinet_code='E01454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=889,
        fiscal_year_end='2月末日',
        submitter_name='株式会社\u3000放電精密加工研究所',
        submitter_name_en='HODEN SEIMITSU KAKO KENKYUSHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ホウデンセイミツカコウケンキュウショ',
        address='横浜市港北区新横浜３－１７－６\u3000イノテックビル１１階',
        industry='機械',
        sec_code='64690',
        corporate_number='6021001020459',
    ),
    'E01456': EdinetCodeEntry(
        edinet_code='E01456',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1429,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニチダイ',
        submitter_name_en='NICHIDAI CORPORATION',
        submitter_name_yomi='カブシキガイシャニチダイ',
        address='京田辺市薪北町田１３番地',
        industry='機械',
        sec_code='64670',
        corporate_number='2130001038818',
    ),
    'E01457': EdinetCodeEntry(
        edinet_code='E01457',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ミヤコ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミヤコカブシキガイシャ',
        address='大阪市北区天満１丁目６番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001070948',
    ),
    'E01459': EdinetCodeEntry(
        edinet_code='E01459',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1241,
        fiscal_year_end='12月31日',
        submitter_name='株式会社遠藤製作所',
        submitter_name_en='ENDO MANUFACTURING CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエンドウセイサクショ',
        address='燕市東太田９８７番地',
        industry='その他製品',
        sec_code='78410',
        corporate_number='6110001015567',
    ),
    'E01460': EdinetCodeEntry(
        edinet_code='E01460',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=228,
        fiscal_year_end='3月31日',
        submitter_name='佐藤鉄工株式会社',
        submitter_name_en='sato tekko co.,ltd.',
        submitter_name_yomi='サトウテッコウカブシキガイシャ',
        address='中新川郡立山町鉾木２２０番地',
        industry='金属製品',
        sec_code=None,
        corporate_number='3230001006466',
    ),
    'E01461': EdinetCodeEntry(
        edinet_code='E01461',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='宮地エンジニアリンググループ株式会社',
        submitter_name_en='MIYAJI ENGINEERING GROUP, INC.',
        submitter_name_yomi='ミヤヂエンジニアリンググループカブシキガイシャ',
        address='中央区日本橋富沢町９番１９号',
        industry='金属製品',
        sec_code='34310',
        corporate_number='7010001084761',
    ),
    'E01462': EdinetCodeEntry(
        edinet_code='E01462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=768,
        fiscal_year_end='3月31日',
        submitter_name='サンコーテクノ株式会社',
        submitter_name_en='SANKO TECHNO CO,.LTD.',
        submitter_name_yomi='サンコーテクノカブシキガイシャ',
        address='流山市南流山三丁目１０番地１６',
        industry='金属製品',
        sec_code='34350',
        corporate_number='2040001040188',
    ),
    'E01464': EdinetCodeEntry(
        edinet_code='E01464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=484,
        fiscal_year_end='3月31日',
        submitter_name='特殊電極株式会社',
        submitter_name_en='TOKUDEN CO.,LTD.',
        submitter_name_yomi='トクシュデンキョクカブシキガイシャ',
        address='加古川市平岡町土山８９９番地の５',
        industry='金属製品',
        sec_code='34370',
        corporate_number='8140001050221',
    ),
    'E01465': EdinetCodeEntry(
        edinet_code='E01465',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1241,
        fiscal_year_end='8月31日',
        submitter_name='株式会社マルマエ',
        submitter_name_en='Marumae Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャマルマエ',
        address='出水市大野原町２１４１番地',
        industry='機械',
        sec_code='62640',
        corporate_number='2340001011885',
    ),
    'E01466': EdinetCodeEntry(
        edinet_code='E01466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＩＥコーポレーション',
        submitter_name_en='MIE CORPORATION CO.,LTD',
        submitter_name_yomi='カブシキガイシャエムアイイーコーポレーション',
        address='桑名市大字星川１００１番地',
        industry='金属製品',
        sec_code='34420',
        corporate_number='9190001013718',
    ),
    'E01469': EdinetCodeEntry(
        edinet_code='E01469',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13367,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タクマ',
        submitter_name_en='TAKUMA CO., LTD.',
        submitter_name_yomi='カブシキガイシャタクマ',
        address='尼崎市金楽寺町二丁目二番三十三号',
        industry='機械',
        sec_code='60130',
        corporate_number='4140001053517',
    ),
    'E01470': EdinetCodeEntry(
        edinet_code='E01470',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=66,
        fiscal_year_end=None,
        submitter_name='株式会社サッパボイラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサッパボイラ',
        address='大阪市北区中津三丁目２５番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001064161',
    ),
    'E01471': EdinetCodeEntry(
        edinet_code='E01471',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=829,
        fiscal_year_end='3月31日',
        submitter_name='阪神内燃機工業株式会社',
        submitter_name_en='THE HANSHIN DIESEL WORKS, LTD',
        submitter_name_yomi='ハンシンナイネンキコウギョウカブシキガイシャ',
        address='神戸市中央区海岸通８番地神港ビル',
        industry='輸送用機器',
        sec_code='60180',
        corporate_number='1140001010149',
    ),
    'E01474': EdinetCodeEntry(
        edinet_code='E01474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2215,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャパンエンジンコーポレーション',
        submitter_name_en='Japan Engine Corporation',
        submitter_name_yomi='カブシキガイシャジャパンエンジンコーポレーション',
        address='明石市二見町南二見１番地３８',
        industry='輸送用機器',
        sec_code='60160',
        corporate_number='3140001036976',
    ),
    'E01475': EdinetCodeEntry(
        edinet_code='E01475',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1510,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000赤阪鐵工所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000アカサカテッコウジョ',
        address='千代田区丸の内三丁目４番１号',
        industry='機械',
        sec_code='60220',
        corporate_number='3010001008658',
    ),
    'E01477': EdinetCodeEntry(
        edinet_code='E01477',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2434,
        fiscal_year_end='3月31日',
        submitter_name='ダイハツインフィニアース株式会社',
        submitter_name_en='DAIHATSU INFINEARTH MFG.CO.,LTD.',
        submitter_name_yomi='ダイハツインフィニアースカブシキガイシャ',
        address='大阪市北区大淀中一丁目１番３０号',
        industry='輸送用機器',
        sec_code='60230',
        corporate_number='3120001083145',
    ),
    'E01478': EdinetCodeEntry(
        edinet_code='E01478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9544,
        fiscal_year_end='3月31日',
        submitter_name='三浦工業株式会社',
        submitter_name_en='MIURA CO.,LTD.',
        submitter_name_yomi='ミウラコウギョウカブシキガイシャ',
        address='松山市堀江町７番地',
        industry='機械',
        sec_code='60050',
        corporate_number='7500001003977',
    ),
    'E01480': EdinetCodeEntry(
        edinet_code='E01480',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12345,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツガミ',
        submitter_name_en='TSUGAMI CORPORATION',
        submitter_name_yomi='カブシキガイシャツガミ',
        address='中央区日本橋富沢町１２番２０号',
        industry='機械',
        sec_code='61010',
        corporate_number='3010001101264',
    ),
    'E01481': EdinetCodeEntry(
        edinet_code='E01481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18000,
        fiscal_year_end='3月31日',
        submitter_name='オークマ株式会社',
        submitter_name_en='OKUMA Corporation',
        submitter_name_yomi='オークマカブシキガイシャ',
        address='丹羽郡大口町下小口５丁目２５番地の１',
        industry='機械',
        sec_code='61030',
        corporate_number='1180001081319',
    ),
    'E01482': EdinetCodeEntry(
        edinet_code='E01482',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12484,
        fiscal_year_end='3月31日',
        submitter_name='芝浦機械株式会社',
        submitter_name_en='SHIBAURA MACHINE CO., LTD.',
        submitter_name_yomi='シバウラキカイカブシキガイシャ',
        address='千代田区内幸町二丁目２番２号',
        industry='機械',
        sec_code='61040',
        corporate_number='3010001034836',
    ),
    'E01484': EdinetCodeEntry(
        edinet_code='E01484',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=501,
        fiscal_year_end='11月30日',
        submitter_name='株式会社\u3000小島鐵工所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000コジマテッコウショ',
        address='高崎市剣崎町１５５番地',
        industry='機械',
        sec_code=None,
        corporate_number='2070001006905',
    ),
    'E01486': EdinetCodeEntry(
        edinet_code='E01486',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54768,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アマダ',
        submitter_name_en='AMADA CO., LTD.',
        submitter_name_yomi='カブシキガイシャアマダ',
        address='伊勢原市石田２００番地',
        industry='機械',
        sec_code='61130',
        corporate_number='7021001020895',
    ),
    'E01488': EdinetCodeEntry(
        edinet_code='E01488',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3099,
        fiscal_year_end='3月31日',
        submitter_name='ダイジェット工業株式会社',
        submitter_name_en='DIJET INDUSTRIAL CO., LTD.',
        submitter_name_yomi='ダイジェットコウギョウカブシキガイシャ',
        address='大阪市平野区加美東２丁目１番１８号',
        industry='機械',
        sec_code='61380',
        corporate_number='6120001020814',
    ),
    'E01490': EdinetCodeEntry(
        edinet_code='E01490',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2319,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＡＫＩＳＡＷＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタキサワ',
        address='岡山市北区撫川９８３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8260001008257',
    ),
    'E01492': EdinetCodeEntry(
        edinet_code='E01492',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='浜井産業株式会社',
        submitter_name_en='HAMAI CO.,LTD',
        submitter_name_yomi='ハマイサンギョウカブシキガイシャ',
        address='品川区西五反田五丁目５番１５号',
        industry='機械',
        sec_code=None,
        corporate_number='1010701008133',
    ),
    'E01493': EdinetCodeEntry(
        edinet_code='E01493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4880,
        fiscal_year_end='3月31日',
        submitter_name='株式会社岡本工作機械製作所',
        submitter_name_en='OKAMOTO MACHINE TOOL WORKS, LTD.',
        submitter_name_yomi='カブシキガイシャオカモトコウサクキカイセイサクショ',
        address='安中市郷原２９９３番地',
        industry='機械',
        sec_code='61250',
        corporate_number='7070001009787',
    ),
    'E01494': EdinetCodeEntry(
        edinet_code='E01494',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=255,
        fiscal_year_end=None,
        submitter_name='旭サナック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒサナックカブシキガイシャ',
        address='尾張旭市旭前町新田洞５０５０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180001079441',
    ),
    'E01495': EdinetCodeEntry(
        edinet_code='E01495',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5878,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＦＵＪＩ',
        submitter_name_en='FUJI CORPORATION',
        submitter_name_yomi='カブシキガイシャフジ',
        address='知立市山町茶碓山１９番地',
        industry='機械',
        sec_code='61340',
        corporate_number='2180301014885',
    ),
    'E01496': EdinetCodeEntry(
        edinet_code='E01496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21142,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000牧野フライス製作所',
        submitter_name_en='Makino Milling Machine Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000マキノフライスセイサクショ',
        address='目黒区中根２丁目３番１９号',
        industry='機械',
        sec_code='61350',
        corporate_number='7013201005504',
    ),
    'E01499': EdinetCodeEntry(
        edinet_code='E01499',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4102,
        fiscal_year_end='3月31日',
        submitter_name='旭ダイヤモンド工業株式会社',
        submitter_name_en='Asahi Diamond Industrial Co.,Ltd.',
        submitter_name_yomi='アサヒダイヤモンドコウギョウカブシキガイシャ',
        address='千代田区紀尾井町４番１号',
        industry='機械',
        sec_code='61400',
        corporate_number='4010001008954',
    ),
    'E01502': EdinetCodeEntry(
        edinet_code='E01502',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=71804,
        fiscal_year_end='12月31日',
        submitter_name='ＤＭＧ森精機株式会社',
        submitter_name_en='DMG MORI CO., LTD.',
        submitter_name_yomi='ディーエムジーモリセイキカブシキガイシャ',
        address='奈良市三条本町２番１号',
        industry='機械',
        sec_code='61410',
        corporate_number='1150001006212',
    ),
    'E01503': EdinetCodeEntry(
        edinet_code='E01503',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2882,
        fiscal_year_end='2月末日',
        submitter_name='富士精工株式会社',
        submitter_name_en='FUJI SEIKO LIMITED',
        submitter_name_yomi='フジセイコウカブシキガイシャ',
        address='豊田市吉原町平子２６番地',
        industry='機械',
        sec_code='61420',
        corporate_number='5180301019188',
    ),
    'E01504': EdinetCodeEntry(
        edinet_code='E01504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24618,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ソディック',
        submitter_name_en='Sodick Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャソディック',
        address='横浜市都筑区仲町台三丁目１２番１号',
        industry='機械',
        sec_code='61430',
        corporate_number='3020001020736',
    ),
    'E01505': EdinetCodeEntry(
        edinet_code='E01505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2998,
        fiscal_year_end='12月31日',
        submitter_name='ユニオンツール株式会社',
        submitter_name_en='UNION TOOL CO.',
        submitter_name_yomi='ユニオンツールカブシキガイシャ',
        address='品川区南大井六丁目十七番一号',
        industry='機械',
        sec_code='62780',
        corporate_number='5010701010077',
    ),
    'E01506': EdinetCodeEntry(
        edinet_code='E01506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22089,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディスコ',
        submitter_name_en='DISCO CORPORATION',
        submitter_name_yomi='カブシキガイシャディスコ',
        address='大田区大森北二丁目１３番１１号',
        industry='機械',
        sec_code='61460',
        corporate_number='6010801007501',
    ),
    'E01507': EdinetCodeEntry(
        edinet_code='E01507',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=972,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤマザキ',
        submitter_name_en='YAMAZAKI CO., LTD.',
        submitter_name_yomi='カブシキガイシャヤマザキ',
        address='浜松市中央区有玉北町４８９番地の２３',
        industry='機械',
        sec_code='61470',
        corporate_number='9080401005540',
    ),
    'E01508': EdinetCodeEntry(
        edinet_code='E01508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1874,
        fiscal_year_end='5月31日',
        submitter_name='タケダ機械株式会社',
        submitter_name_en='TAKEDA MACHINERY CO., LTD.',
        submitter_name_yomi='タケダキカイカブシキガイシャ',
        address='能美市粟生町西１３２番地',
        industry='機械',
        sec_code='61500',
        corporate_number='2220001012680',
    ),
    'E01509': EdinetCodeEntry(
        edinet_code='E01509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1850,
        fiscal_year_end='3月31日',
        submitter_name='日東工器株式会社',
        submitter_name_en='NITTO KOHKI CO.,LTD.',
        submitter_name_yomi='ニットウコウキカブシキガイシャ',
        address='大田区仲池上２丁目９番４号',
        industry='機械',
        sec_code='61510',
        corporate_number='3010801009129',
    ),
    'E01510': EdinetCodeEntry(
        edinet_code='E01510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1835,
        fiscal_year_end='3月31日',
        submitter_name='高松機械工業株式会社',
        submitter_name_en='TAKAMATSU MACHINERY CO., LTD.',
        submitter_name_yomi='タカマツキカイコウギョウカブシキガイシャ',
        address='白山市旭丘１丁目８番地',
        industry='機械',
        sec_code='61550',
        corporate_number='6220001009228',
    ),
    'E01511': EdinetCodeEntry(
        edinet_code='E01511',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=843,
        fiscal_year_end='3月31日',
        submitter_name='株式会社和井田製作所',
        submitter_name_en='WAIDA MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャワイダセイサクショ',
        address='高山市片野町２１２１番地',
        industry='機械',
        sec_code='61580',
        corporate_number='2200001025263',
    ),
    'E01513': EdinetCodeEntry(
        edinet_code='E01513',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1055,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エイチアンドエフ',
        submitter_name_en='Hitachi Zosen Fukui Corporation',
        submitter_name_yomi='カブシキガイシャエイチアンドエフ',
        address='あわら市自由ケ丘一丁目８番２８号',
        industry='機械',
        sec_code=None,
        corporate_number='2210001007087',
    ),
    'E01514': EdinetCodeEntry(
        edinet_code='E01514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=80462,
        fiscal_year_end='3月31日',
        submitter_name='株式会社豊田自動織機',
        submitter_name_en='TOYOTA INDUSTRIES CORPORATION',
        submitter_name_yomi='カブシキガイシャトヨタジドウショッキ',
        address='刈谷市豊田町２丁目１番地',
        industry='輸送用機器',
        sec_code='62010',
        corporate_number='3180301014273',
    ),
    'E01515': EdinetCodeEntry(
        edinet_code='E01515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9019,
        fiscal_year_end='3月31日',
        submitter_name='豊和工業株式会社',
        submitter_name_en='Howa Machinery, Ltd.',
        submitter_name_yomi='ホウワコウギョウカブシキガイシャ',
        address='清須市須ケ口１９００番地１',
        industry='機械',
        sec_code='62030',
        corporate_number='7180001032621',
    ),
    'E01516': EdinetCodeEntry(
        edinet_code='E01516',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9022,
        fiscal_year_end=None,
        submitter_name='ニデックオーケーケー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニデックオーケーケーカブシキガイシャ',
        address='伊丹市北伊丹八丁目１０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140001080310',
    ),
    'E01518': EdinetCodeEntry(
        edinet_code='E01518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社石川製作所',
        submitter_name_en='Ishikawa Seisakusho, Ltd.',
        submitter_name_yomi='カブシキガイシャイシカワセイサクショ',
        address='白山市福留町２００番地',
        industry='機械',
        sec_code='62080',
        corporate_number='6220001007685',
    ),
    'E01521': EdinetCodeEntry(
        edinet_code='E01521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4640,
        fiscal_year_end='3月31日',
        submitter_name='エンシュウ株式会社',
        submitter_name_en='ENSHU Limited',
        submitter_name_yomi='エンシュウカブシキガイシャ',
        address='浜松市南区高塚町４８８８番地',
        industry='機械',
        sec_code='62180',
        corporate_number='1080401000672',
    ),
    'E01524': EdinetCodeEntry(
        edinet_code='E01524',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12316,
        fiscal_year_end='11月30日',
        submitter_name='津田駒工業株式会社',
        submitter_name_en='TSUDAKOMA  Corp.',
        submitter_name_yomi='ツダコマコウギョウカブシキガイシャ',
        address='金沢市野町５丁目１８番１８号',
        industry='機械',
        sec_code='62170',
        corporate_number='3220001004330',
    ),
    'E01528': EdinetCodeEntry(
        edinet_code='E01528',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2506,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＹＯイノベックス株式会社',
        submitter_name_en='TOYO INNOVEX CO., LTD.',
        submitter_name_yomi='トーヨーイノベックスカブシキガイシャ',
        address='明石市二見町福里字西之山５２３番の１',
        industry='機械',
        sec_code='62100',
        corporate_number='5140001035200',
    ),
    'E01529': EdinetCodeEntry(
        edinet_code='E01529',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1440,
        fiscal_year_end='3月31日',
        submitter_name='株式会社加地テック',
        submitter_name_en='KAJI TECHNOLOGY CORPORATION',
        submitter_name_yomi='カブシキガイシャカヂテック',
        address='堺市美原区菩提６番地',
        industry='機械',
        sec_code='63910',
        corporate_number='2120101021427',
    ),
    'E01531': EdinetCodeEntry(
        edinet_code='E01531',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14859,
        fiscal_year_end='3月31日',
        submitter_name='株式会社島精機製作所',
        submitter_name_en='SHIMA SEIKI MFG., LTD.',
        submitter_name_yomi='カブシキガイシャシマセイキセイサクショ',
        address='和歌山市坂田８５番地',
        industry='機械',
        sec_code='62220',
        corporate_number='2170001001508',
    ),
    'E01532': EdinetCodeEntry(
        edinet_code='E01532',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=72795,
        fiscal_year_end='3月31日',
        submitter_name='株式会社小松製作所',
        submitter_name_en='KOMATSU LTD.',
        submitter_name_yomi='カブシキガイシャコマツセイサクショ',
        address='港区海岸一丁目２番２０号',
        industry='機械',
        sec_code='63010',
        corporate_number='1010401010455',
    ),
    'E01533': EdinetCodeEntry(
        edinet_code='E01533',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30872,
        fiscal_year_end='12月31日',
        submitter_name='住友重機械工業株式会社',
        submitter_name_en='SUMITOMO HEAVY INDUSTRIES,LTD.',
        submitter_name_yomi='スミトモジュウキカイコウギョウカブシキガイシャ',
        address='品川区大崎２－１－１\u3000（Ｔｈｉｎｋｐａｒｋ\u3000Ｔｏｗｅｒ）',
        industry='機械',
        sec_code='63020',
        corporate_number='9010701005032',
    ),
    'E01534': EdinetCodeEntry(
        edinet_code='E01534',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=954,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000東京自働機械製作所',
        submitter_name_en='TOKYO AUTOMATIC MACHINERY WORKS, LTD',
        submitter_name_yomi='カブシキガイシャ\u3000トウキョウジドウキカイセイサクショ',
        address='千代田区岩本町３丁目１０番７号',
        industry='機械',
        sec_code='63600',
        corporate_number='7010001034205',
    ),
    'E01536': EdinetCodeEntry(
        edinet_code='E01536',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3956,
        fiscal_year_end='3月31日',
        submitter_name='三菱化工機株式会社',
        submitter_name_en='Mitsubishi Kakoki Kaisha, Ltd.',
        submitter_name_yomi='ミツビシカコウキカブシキガイシャ',
        address='川崎市川崎区大川町２番１号',
        industry='機械',
        sec_code='63310',
        corporate_number='7020001074662',
    ),
    'E01537': EdinetCodeEntry(
        edinet_code='E01537',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6646,
        fiscal_year_end='3月31日',
        submitter_name='月島ホールディングス株式会社',
        submitter_name_en='TSUKISHIMA HOLDINGS CO., LTD.',
        submitter_name_yomi='ツキシマホールディングスカブシキガイシャ',
        address='中央区晴海三丁目５番１号',
        industry='機械',
        sec_code='63320',
        corporate_number='8010001034856',
    ),
    'E01538': EdinetCodeEntry(
        edinet_code='E01538',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1414,
        fiscal_year_end='3月31日',
        submitter_name='明治機械株式会社',
        submitter_name_en='Meiji Machine Co.,Ltd.',
        submitter_name_yomi='メイジキカイカブシキガイシャ',
        address='千代田区神田多町二丁目２番地２２',
        industry='機械',
        sec_code='63340',
        corporate_number='2010001030563',
    ),
    'E01539': EdinetCodeEntry(
        edinet_code='E01539',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4435,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京機械製作所',
        submitter_name_en='TOKYO KIKAI SEISAKUSHO,LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウキカイセイサクショ',
        address='港区三田三丁目１１番３６号',
        industry='機械',
        sec_code='63350',
        corporate_number='9010401020496',
    ),
    'E01541': EdinetCodeEntry(
        edinet_code='E01541',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5752,
        fiscal_year_end='3月31日',
        submitter_name='新東工業株式会社',
        submitter_name_en='Sintokogio,Ltd.',
        submitter_name_yomi='シントウコウギョウカブシキガイシャ',
        address='名古屋市中村区名駅三丁目２８番１２号',
        industry='機械',
        sec_code='63390',
        corporate_number='5180001030627',
    ),
    'E01542': EdinetCodeEntry(
        edinet_code='E01542',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=79451,
        fiscal_year_end='12月31日',
        submitter_name='株式会社荏原製作所',
        submitter_name_en='EBARA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000エバラセイサクショ',
        address='大田区羽田旭町１１番１号',
        industry='機械',
        sec_code='63610',
        corporate_number='1010801001748',
    ),
    'E01543': EdinetCodeEntry(
        edinet_code='E01543',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1892,
        fiscal_year_end='3月31日',
        submitter_name='株式会社石井鐵工所',
        submitter_name_en='Ishii Iron Works Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000イシイテッコウショ',
        address='中央区月島三丁目２６番１１号',
        industry='機械',
        sec_code=None,
        corporate_number='3010001034745',
    ),
    'E01544': EdinetCodeEntry(
        edinet_code='E01544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=810,
        fiscal_year_end='3月31日',
        submitter_name='株式会社電業社機械製作所',
        submitter_name_en='DMW CORPORATION',
        submitter_name_yomi='カブシキガイシャデンギョウシャキカイセイサクショ',
        address='大田区大森北１丁目５番１号',
        industry='機械',
        sec_code='63650',
        corporate_number='8010801007581',
    ),
    'E01545': EdinetCodeEntry(
        edinet_code='E01545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7831,
        fiscal_year_end='3月31日',
        submitter_name='アイダエンジニアリング株式会社',
        submitter_name_en='AIDA ENGINEERING,LTD.',
        submitter_name_yomi='アイダエンジニアリングカブシキガイシャ',
        address='相模原市緑区大山町２番１０号',
        industry='機械',
        sec_code='61180',
        corporate_number='6021001011037',
    ),
    'E01546': EdinetCodeEntry(
        edinet_code='E01546',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1030,
        fiscal_year_end='3月31日',
        submitter_name='木村化工機株式会社',
        submitter_name_en='KIMURA CHEMICAL PLANTS  CO., LTD.',
        submitter_name_yomi='キムラ\u3000\u3000カコウキ\u3000\u3000カブシキガイシャ',
        address='尼崎市杭瀬寺島２丁目１番２号',
        industry='機械',
        sec_code='63780',
        corporate_number='7140001048448',
    ),
    'E01547': EdinetCodeEntry(
        edinet_code='E01547',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=750,
        fiscal_year_end='3月31日',
        submitter_name='株式会社太平製作所',
        submitter_name_en='Taihei Machinery Works,Limited',
        submitter_name_yomi='カブシキガイシャタイヘイセイサクショ',
        address='小牧市大字入鹿出新田字宮前９５５番８',
        industry='機械',
        sec_code='63420',
        corporate_number='6180001076066',
    ),
    'E01548': EdinetCodeEntry(
        edinet_code='E01548',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1847,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヒラノテクシード',
        submitter_name_en='HIRANO TECSEED CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヒラノテクシード',
        address='北葛城郡河合町大字川合１０１番地の１',
        industry='機械',
        sec_code='62450',
        corporate_number='9150001013309',
    ),
    'E01550': EdinetCodeEntry(
        edinet_code='E01550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4175,
        fiscal_year_end='3月31日',
        submitter_name='旭精機工業株式会社',
        submitter_name_en='ASAHI-SEIKI MANUFACTURING CO.,LTD.',
        submitter_name_yomi='アサヒセイキコウギョウカブシキガイシャ',
        address='尾張旭市旭前町新田洞５０５０番地の１',
        industry='機械',
        sec_code='61110',
        corporate_number='7180001079431',
    ),
    'E01551': EdinetCodeEntry(
        edinet_code='E01551',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31865,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイフク',
        submitter_name_en='DAIFUKU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイフク',
        address='大阪市西淀川区御幣島３丁目２番１１号',
        industry='機械',
        sec_code='63830',
        corporate_number='5120001050011',
    ),
    'E01553': EdinetCodeEntry(
        edinet_code='E01553',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3851,
        fiscal_year_end=None,
        submitter_name='日本コンベヤ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンコンベヤカブシキガイシャ',
        address='千代田区鍛冶町一丁目７番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1122001015773',
    ),
    'E01554': EdinetCodeEntry(
        edinet_code='E01554',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3354,
        fiscal_year_end='3月31日',
        submitter_name='アネスト岩田株式会社',
        submitter_name_en='ANEST IWATA Corporation',
        submitter_name_yomi='アネストイワタカブシキガイシャ',
        address='横浜市港北区新吉田町３１７６番地',
        industry='機械',
        sec_code='63810',
        corporate_number='3020001043522',
    ),
    'E01562': EdinetCodeEntry(
        edinet_code='E01562',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1455,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＯＬＤＩＮＯ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモルディノ',
        address='墨田区両国四丁目３１番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401083204',
    ),
    'E01563': EdinetCodeEntry(
        edinet_code='E01563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23344,
        fiscal_year_end='12月31日',
        submitter_name='井関農機株式会社',
        submitter_name_en='ISEKI&CO.,LTD.',
        submitter_name_yomi='イセキノウキカブシキガイシャ',
        address='松山市馬木町７００番地',
        industry='機械',
        sec_code='63100',
        corporate_number='2500001000533',
    ),
    'E01566': EdinetCodeEntry(
        edinet_code='E01566',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=96,
        fiscal_year_end='3月31日',
        submitter_name='旭産業株式会社',
        submitter_name_en='Asahi Sangyo Co.,Ltd',
        submitter_name_yomi='アサヒサンギョウカブシキガイシャ',
        address='本庄市沼和田９４８番地',
        industry='機械',
        sec_code=None,
        corporate_number='1030001060114',
    ),
    'E01568': EdinetCodeEntry(
        edinet_code='E01568',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4651,
        fiscal_year_end='9月30日',
        submitter_name='株式会社丸山製作所',
        submitter_name_en='MARUYAMA MFG.CO.,INC.',
        submitter_name_yomi='カブシキガイシャマルヤマセイサクショ',
        address='千代田区内神田三丁目４番１５号',
        industry='機械',
        sec_code='63160',
        corporate_number='5010001008788',
    ),
    'E01569': EdinetCodeEntry(
        edinet_code='E01569',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15014,
        fiscal_year_end='3月31日',
        submitter_name='千代田化工建設株式会社',
        submitter_name_en='CHIYODA CORPORATION',
        submitter_name_yomi='チヨダカコウケンセツカブシキガイシャ',
        address='横浜市西区みなとみらい四丁目６番２号',
        industry='建設業',
        sec_code='63660',
        corporate_number='3020001018029',
    ),
    'E01570': EdinetCodeEntry(
        edinet_code='E01570',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=85032,
        fiscal_year_end='3月31日',
        submitter_name='ダイキン工業株式会社',
        submitter_name_en='DAIKIN INDUSTRIES, LTD.',
        submitter_name_yomi='ダイキンコウギョウカブシキガイシャ',
        address='大阪市北区梅田一丁目１３番１号',
        industry='機械',
        sec_code='63670',
        corporate_number='8120001059660',
    ),
    'E01571': EdinetCodeEntry(
        edinet_code='E01571',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8225,
        fiscal_year_end='3月31日',
        submitter_name='オルガノ株式会社',
        submitter_name_en='ORGANO CORPORATION',
        submitter_name_yomi='オルガノカブシキガイシャ',
        address='江東区新砂１丁目２番８号',
        industry='機械',
        sec_code='63680',
        corporate_number='3010601025111',
    ),
    'E01572': EdinetCodeEntry(
        edinet_code='E01572',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18580,
        fiscal_year_end='3月31日',
        submitter_name='トーヨーカネツ株式会社',
        submitter_name_en='TOYO KANETSU K.K.',
        submitter_name_yomi='トーヨーカネツカブシキガイシャ',
        address='江東区南砂二丁目１１番１号',
        industry='機械',
        sec_code='63690',
        corporate_number='2010601004909',
    ),
    'E01573': EdinetCodeEntry(
        edinet_code='E01573',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13450,
        fiscal_year_end='3月31日',
        submitter_name='栗田工業株式会社',
        submitter_name_en='Kurita Water Industries Ltd.',
        submitter_name_yomi='クリタコウギョウカブシキガイシャ',
        address='中野区中野四丁目１０番１号',
        industry='機械',
        sec_code='63700',
        corporate_number='8011101023170',
    ),
    'E01575': EdinetCodeEntry(
        edinet_code='E01575',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23733,
        fiscal_year_end='3月31日',
        submitter_name='日揮ホールディングス株式会社',
        submitter_name_en='JGC HOLDINGS CORPORATION',
        submitter_name_yomi='ニッキホールディングスカブシキガイシャ',
        address='横浜市西区みなとみらい２丁目３番１号',
        industry='建設業',
        sec_code='19630',
        corporate_number='3010001008732',
    ),
    'E01577': EdinetCodeEntry(
        edinet_code='E01577',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2754,
        fiscal_year_end='3月31日',
        submitter_name='レイズネクスト株式会社',
        submitter_name_en='RAIZNEXT Corporation',
        submitter_name_yomi='レイズネクストカブシキガイシャ',
        address='神奈川県横浜市中区桜木町一丁目１番地８（日石横浜ビル）',
        industry='建設業',
        sec_code='63790',
        corporate_number='3020001017402',
    ),
    'E01578': EdinetCodeEntry(
        edinet_code='E01578',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17076,
        fiscal_year_end='3月31日',
        submitter_name='株式会社椿本チエイン',
        submitter_name_en='TSUBAKIMOTO CHAIN CO.',
        submitter_name_yomi='カブシキガイシャツバキモトチエイン',
        address='大阪市北区中之島三丁目３番３号',
        industry='機械',
        sec_code='63710',
        corporate_number='2120001002188',
    ),
    'E01580': EdinetCodeEntry(
        edinet_code='E01580',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2726,
        fiscal_year_end='3月31日',
        submitter_name='大同工業株式会社',
        submitter_name_en='DAIDO KOGYO CO.,LTD.',
        submitter_name_yomi='ダイドウコウギョウカブシキガイシャ',
        address='加賀市熊坂町イ１９７番地',
        industry='機械',
        sec_code=None,
        corporate_number='4220001013264',
    ),
    'E01581': EdinetCodeEntry(
        edinet_code='E01581',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1066,
        fiscal_year_end='3月31日',
        submitter_name='オリエンタルチエン工業株式会社',
        submitter_name_en='ORIENTAL CHAIN MFG. CO., LTD.',
        submitter_name_yomi='オリエンタルチエンコウギョウカブシキガイシャ',
        address='白山市宮永市町４８５番地',
        industry='機械',
        sec_code='63800',
        corporate_number='8220001009044',
    ),
    'E01583': EdinetCodeEntry(
        edinet_code='E01583',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2935,
        fiscal_year_end='3月31日',
        submitter_name='株式会社加藤製作所',
        submitter_name_en='KATO WORKS CO., LTD.',
        submitter_name_yomi='カブシキガイシャカトウセイサクショ',
        address='品川区東大井１－９－３７',
        industry='機械',
        sec_code='63900',
        corporate_number='3010701002324',
    ),
    'E01584': EdinetCodeEntry(
        edinet_code='E01584',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8640,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北川鉄工所',
        submitter_name_en='Kitagawa Corporation',
        submitter_name_yomi='カブシキガイシャキタガワテッコウショ',
        address='府中市元町７７番地の１',
        industry='機械',
        sec_code='63170',
        corporate_number='4240001034184',
    ),
    'E01585': EdinetCodeEntry(
        edinet_code='E01585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=81577,
        fiscal_year_end='3月31日',
        submitter_name='日立建機株式会社',
        submitter_name_en='Hitachi Construction Machinery Co., Ltd.',
        submitter_name_yomi='ヒタチケンキカブシキガイシャ',
        address='台東区東上野二丁目１６番１号',
        industry='機械',
        sec_code='63050',
        corporate_number='3010001026998',
    ),
    'E01587': EdinetCodeEntry(
        edinet_code='E01587',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='2月末日',
        submitter_name='株式会社東京衡機',
        submitter_name_en='TOKYO KOKI CO. LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウコウキ',
        address='相模原市緑区三井３１５番地',
        industry='精密機器',
        sec_code='77190',
        corporate_number='2010001008816',
    ),
    'E01589': EdinetCodeEntry(
        edinet_code='E01589',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20873,
        fiscal_year_end='6月30日',
        submitter_name='株式会社\u3000アルバック',
        submitter_name_en='ULVAC,Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000アルバック',
        address='茅ヶ崎市萩園２５００',
        industry='電気機器',
        sec_code='67280',
        corporate_number='5021001007242',
    ),
    'E01590': EdinetCodeEntry(
        edinet_code='E01590',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18239,
        fiscal_year_end='3月31日',
        submitter_name='アマノ株式会社',
        submitter_name_en='Amano Corporation',
        submitter_name_yomi='アマノカブシキガイシャ',
        address='横浜市港北区大豆戸町２７５番地',
        industry='機械',
        sec_code='64360',
        corporate_number='3020001019365',
    ),
    'E01591': EdinetCodeEntry(
        edinet_code='E01591',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6544,
        fiscal_year_end='12月31日',
        submitter_name='日機装株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッキソウカブシキガイシャ',
        address='渋谷区恵比寿四丁目２０番地３号\u3000恵比寿ガーデンプレイスタワー２２階',
        industry='精密機器',
        sec_code='63760',
        corporate_number='7011001017109',
    ),
    'E01593': EdinetCodeEntry(
        edinet_code='E01593',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45049,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイシン',
        submitter_name_en='AISIN CORPORATION',
        submitter_name_yomi='カブシキガイシャアイシン',
        address='刈谷市朝日町２丁目１番地',
        industry='輸送用機器',
        sec_code='72590',
        corporate_number='6180301013611',
    ),
    'E01594': EdinetCodeEntry(
        edinet_code='E01594',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19209,
        fiscal_year_end='3月31日',
        submitter_name='ブラザー工業株式会社',
        submitter_name_en='BROTHER INDUSTRIES LTD.',
        submitter_name_yomi='ブラザーコウギョウカブシキガイシャ',
        address='名古屋市瑞穂区苗代町１５番１号',
        industry='電気機器',
        sec_code='64480',
        corporate_number='8180001010997',
    ),
    'E01595': EdinetCodeEntry(
        edinet_code='E01595',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11373,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャノメ',
        submitter_name_en='JANOME Corporation',
        submitter_name_yomi='カブシキガイシャジャノメ',
        address='八王子市狭間町１４６３番地',
        industry='機械',
        sec_code='64450',
        corporate_number='7010101008876',
    ),
    'E01596': EdinetCodeEntry(
        edinet_code='E01596',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18044,
        fiscal_year_end='12月31日',
        submitter_name='ＪＵＫＩ株式会社',
        submitter_name_en='JUKI CORPORATION',
        submitter_name_yomi='ジューキカブシキガイシャ',
        address='多摩市鶴牧二丁目１１番地１',
        industry='機械',
        sec_code='64400',
        corporate_number='8013401006169',
    ),
    'E01597': EdinetCodeEntry(
        edinet_code='E01597',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9839,
        fiscal_year_end='3月31日',
        submitter_name='日本ピストンリング株式会社',
        submitter_name_en='Nippon Piston Ring Co.,Ltd.',
        submitter_name_yomi='ニッポンピストンリングカブシキガイシャ',
        address='さいたま市中央区本町東五丁目１２番１０号',
        industry='機械',
        sec_code=None,
        corporate_number='8030001006457',
    ),
    'E01598': EdinetCodeEntry(
        edinet_code='E01598',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8573,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リケン',
        submitter_name_en='RIKEN CORPORATION',
        submitter_name_yomi='カブシキガイシャリケン',
        address='千代田区三番町８－１',
        industry='機械',
        sec_code=None,
        corporate_number='3010001032014',
    ),
    'E01599': EdinetCodeEntry(
        edinet_code='E01599',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4758,
        fiscal_year_end='3月31日',
        submitter_name='ＴＰＲ株式会社',
        submitter_name_en='TPR CO .,LTD.',
        submitter_name_yomi='ティーピーアールカブシキガイシャ',
        address='千代田区丸の内一丁目６番２号\u3000新丸の内センタービル',
        industry='機械',
        sec_code='64630',
        corporate_number='3010001034852',
    ),
    'E01600': EdinetCodeEntry(
        edinet_code='E01600',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=67176,
        fiscal_year_end='3月31日',
        submitter_name='日本精工株式会社',
        submitter_name_en='NSK Ltd.',
        submitter_name_yomi='ニッポンセイコウカブシキガイシャ',
        address='品川区大崎１－６－３',
        industry='機械',
        sec_code='64710',
        corporate_number='8010701007715',
    ),
    'E01601': EdinetCodeEntry(
        edinet_code='E01601',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54346,
        fiscal_year_end='3月31日',
        submitter_name='ＮＴＮ株式会社',
        submitter_name_en='NTN CORPORATION',
        submitter_name_yomi='エヌティエヌカブシキガイシャ',
        address='大阪市北区中之島三丁目６番３２号ダイビル本館',
        industry='機械',
        sec_code='64720',
        corporate_number='3120001048981',
    ),
    'E01602': EdinetCodeEntry(
        edinet_code='E01602',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45591,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジェイテクト',
        submitter_name_en='JTEKT Corporation',
        submitter_name_yomi='カブシキガイシャジェイテクト',
        address='刈谷市朝日町一丁目１番地',
        industry='機械',
        sec_code='64730',
        corporate_number='9120001079055',
    ),
    'E01603': EdinetCodeEntry(
        edinet_code='E01603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16074,
        fiscal_year_end='11月30日',
        submitter_name='株式会社不二越',
        submitter_name_en='NACHI-FUJIKOSHI CORP.',
        submitter_name_yomi='カブシキガイシャフジコシ',
        address='港区東新橋一丁目９番２号（汐留住友ビル）',
        industry='機械',
        sec_code='64740',
        corporate_number='4230001002687',
    ),
    'E01606': EdinetCodeEntry(
        edinet_code='E01606',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=660,
        fiscal_year_end='3月31日',
        submitter_name='旭精工株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒセイコウカブシキガイシャ',
        address='堺市西区鳳東町６丁５７０番地１',
        industry='機械',
        sec_code=None,
        corporate_number='5120101000824',
    ),
    'E01607': EdinetCodeEntry(
        edinet_code='E01607',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=68259,
        fiscal_year_end='3月31日',
        submitter_name='ミネベアミツミ株式会社',
        submitter_name_en='MINEBEA MITSUMI Inc.',
        submitter_name_yomi='ミネベアミツミカブシキガイシャ',
        address='北佐久郡御代田町大字御代田４１０６番地７３',
        industry='電気機器',
        sec_code='64790',
        corporate_number='8100001007753',
    ),
    'E01608': EdinetCodeEntry(
        edinet_code='E01608',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2317,
        fiscal_year_end=None,
        submitter_name='ダイベア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイベアカブシキガイシャ',
        address='和泉市あゆみ野２丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120101046413',
    ),
    'E01609': EdinetCodeEntry(
        edinet_code='E01609',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1286,
        fiscal_year_end='9月30日',
        submitter_name='岡野バルブ製造株式会社',
        submitter_name_en='okano valve mfg.co.ltd.',
        submitter_name_yomi='オカノバルブセイゾウカブシキガイシャ',
        address='北九州市門司区中町１番１４号',
        industry='機械',
        sec_code='64920',
        corporate_number='4290801005157',
    ),
    'E01610': EdinetCodeEntry(
        edinet_code='E01610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3115,
        fiscal_year_end='3月31日',
        submitter_name='酒井重工業株式会社',
        submitter_name_en='SAKAI HEAVY INDUSTRIES, LTD.',
        submitter_name_yomi='サカイジュウコウギョウカブシキガイシャ',
        address='港区芝大門１丁目９番９号',
        industry='機械',
        sec_code='63580',
        corporate_number='1010401011081',
    ),
    'E01612': EdinetCodeEntry(
        edinet_code='E01612',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4109,
        fiscal_year_end='3月31日',
        submitter_name='油研工業株式会社',
        submitter_name_en='YUKEN KOGYO CO., LTD.',
        submitter_name_yomi='ユケンコウギョウカブシキガイシャ',
        address='綾瀬市上土棚中四丁目４番３４号',
        industry='機械',
        sec_code='63930',
        corporate_number='7021001028468',
    ),
    'E01613': EdinetCodeEntry(
        edinet_code='E01613',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13021,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タダノ',
        submitter_name_en='TADANO LTD.',
        submitter_name_yomi='カブシキガイシャタダノ',
        address='高松市新田町甲３４番地',
        industry='機械',
        sec_code='63950',
        corporate_number='9470001002700',
    ),
    'E01615': EdinetCodeEntry(
        edinet_code='E01615',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=717,
        fiscal_year_end='3月31日',
        submitter_name='株式会社郷鉄工所',
        submitter_name_en='Go Iron Works Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャゴウテッコウショ',
        address='不破郡垂井町表佐字大持野５８番地の２',
        industry='機械',
        sec_code=None,
        corporate_number='5200001014775',
    ),
    'E01617': EdinetCodeEntry(
        edinet_code='E01617',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1350,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タカキタ',
        submitter_name_en='TAKAKITA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタカキタ',
        address='名張市夏見２８２８番地',
        industry='機械',
        sec_code='63250',
        corporate_number='4190001009381',
    ),
    'E01618': EdinetCodeEntry(
        edinet_code='E01618',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=948,
        fiscal_year_end='3月31日',
        submitter_name='三井精機工業株式会社',
        submitter_name_en='MITSUI SEIKI KOGYO CO., LTD.',
        submitter_name_yomi='ミツイセイキコウギョウカブシキガイシャ',
        address='台東区柳橋１丁目１１番１１号',
        industry='機械',
        sec_code=None,
        corporate_number='9010501031559',
    ),
    'E01619': EdinetCodeEntry(
        edinet_code='E01619',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3161,
        fiscal_year_end='3月31日',
        submitter_name='協栄産業株式会社',
        submitter_name_en='KYOEI SANGYO CO.,LTD.',
        submitter_name_yomi='キョウエイサンギョウカブシキガイシャ',
        address='品川区東品川４丁目１２番６号品川シーサイドキャナルタワー',
        industry='卸売業',
        sec_code=None,
        corporate_number='3011001006511',
    ),
    'E01620': EdinetCodeEntry(
        edinet_code='E01620',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2077,
        fiscal_year_end='3月31日',
        submitter_name='フリージア・マクロス株式会社',
        submitter_name_en='FREESIA MACROSS CORPORATION',
        submitter_name_yomi='フリージアマクロスカブシキカイシャ',
        address='千代田区神田東松下町１７番地',
        industry='機械',
        sec_code='63430',
        corporate_number='3010001000012',
    ),
    'E01622': EdinetCodeEntry(
        edinet_code='E01622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12533,
        fiscal_year_end='3月31日',
        submitter_name='フジテック株式会社',
        submitter_name_en='FUJITEC CO., LTD.',
        submitter_name_yomi='フジテックカブシキガイシャ',
        address='彦根市宮田町５９１－１',
        industry='機械',
        sec_code='64060',
        corporate_number='3160001009212',
    ),
    'E01624': EdinetCodeEntry(
        edinet_code='E01624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1993,
        fiscal_year_end='3月末日',
        submitter_name='株式会社宮入バルブ製作所',
        submitter_name_en='MIYAIRI VALVE MFG.CO., LTD.',
        submitter_name_yomi='カブシキガイシャミヤイリバルブセイサクショ',
        address='中央区銀座西一丁目２番地',
        industry='機械',
        sec_code='64950',
        corporate_number='8010001034955',
    ),
    'E01627': EdinetCodeEntry(
        edinet_code='E01627',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1311,
        fiscal_year_end='3月31日',
        submitter_name='トリニティ工業株式会社',
        submitter_name_en='TRINITY INDUSTRIAL CORPORATION',
        submitter_name_yomi='トリニティコウギョウカブシキガイシャ',
        address='豊田市柿本町１丁目９番地',
        industry='機械',
        sec_code='63820',
        corporate_number='6180301021663',
    ),
    'E01628': EdinetCodeEntry(
        edinet_code='E01628',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1953,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノスマート',
        submitter_name_en='Techno Smart Corp.',
        submitter_name_yomi='カブシキガイシャテクノスマート',
        address='大阪市中央区久太郎町２丁目５番２８号',
        industry='機械',
        sec_code='62460',
        corporate_number='4120001074705',
    ),
    'E01629': EdinetCodeEntry(
        edinet_code='E01629',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=660,
        fiscal_year_end='3月31日',
        submitter_name='キクカワエンタープライズ株式会社',
        submitter_name_en='KIKUKAWA ENTERPRISE,INC.',
        submitter_name_yomi='キクカワエンタープライズカブシキガイシャ',
        address='伊勢市朝熊町３４７７番地３６',
        industry='機械',
        sec_code='63460',
        corporate_number='8190001006573',
    ),
    'E01630': EdinetCodeEntry(
        edinet_code='E01630',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38716,
        fiscal_year_end='3月31日',
        submitter_name='テルモ株式会社',
        submitter_name_en='TERUMO CORPORATION',
        submitter_name_yomi='テルモカブシキガイシャ',
        address='渋谷区幡ヶ谷二丁目４４番１号',
        industry='精密機器',
        sec_code='45430',
        corporate_number='3011001015116',
    ),
    'E01631': EdinetCodeEntry(
        edinet_code='E01631',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9533,
        fiscal_year_end='3月31日',
        submitter_name='日本トムソン株式会社',
        submitter_name_en='NIPPON  THOMPSON CO., LTD.',
        submitter_name_yomi='ニッポントムソンカブシキガイシャ',
        address='港区高輪二丁目１９番１９号',
        industry='機械',
        sec_code='64800',
        corporate_number='4010401023033',
    ),
    'E01632': EdinetCodeEntry(
        edinet_code='E01632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3251,
        fiscal_year_end='3月31日',
        submitter_name='三精テクノロジーズ株式会社',
        submitter_name_en='Sansei Technologies,Inc.',
        submitter_name_yomi='サンセイテクノロジーズカブシキカイシャ',
        address='大阪市淀川区宮原４丁目３番２９号',
        industry='機械',
        sec_code='63570',
        corporate_number='3120901006634',
    ),
    'E01634': EdinetCodeEntry(
        edinet_code='E01634',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3976,
        fiscal_year_end='3月31日',
        submitter_name='株式会社キトー',
        submitter_name_en='KITO CORPORATION',
        submitter_name_yomi='カブシキガイシャキトー',
        address='中巨摩郡昭和町築地新居２０００番地',
        industry='機械',
        sec_code=None,
        corporate_number='1090001003075',
    ),
    'E01635': EdinetCodeEntry(
        edinet_code='E01635',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=785,
        fiscal_year_end='3月31日',
        submitter_name='株式会社宇野澤組鐵工所',
        submitter_name_en='Unozawa-gumi Iron Works,Limited',
        submitter_name_yomi='カブシキガイシャウノザワグミテッコウジョ',
        address='渋谷区恵比寿１－１９－１５',
        industry='機械',
        sec_code='63960',
        corporate_number='4011001003103',
    ),
    'E01636': EdinetCodeEntry(
        edinet_code='E01636',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1592,
        fiscal_year_end='3月31日',
        submitter_name='株式会社酉島製作所',
        submitter_name_en='Torishima Pump Mfg.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトリシマセイサクショ',
        address='高槻市宮田町一丁目１番８号',
        industry='機械',
        sec_code='63630',
        corporate_number='9120901011562',
    ),
    'E01641': EdinetCodeEntry(
        edinet_code='E01641',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3475,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッセイ',
        submitter_name_en='NISSEI CORPORATION',
        submitter_name_yomi='カブシキガイシャニッセイ',
        address='安城市和泉町井ノ上１番地１',
        industry='機械',
        sec_code=None,
        corporate_number='2180301013193',
    ),
    'E01642': EdinetCodeEntry(
        edinet_code='E01642',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8585,
        fiscal_year_end='3月31日',
        submitter_name='オイレス工業株式会社',
        submitter_name_en='OILES CORPORATION',
        submitter_name_yomi='オイレスコウギョウカブシキガイシャ',
        address='藤沢市桐原町８番地',
        industry='機械',
        sec_code='62820',
        corporate_number='1010401006049',
    ),
    'E01643': EdinetCodeEntry(
        edinet_code='E01643',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4150,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日阪製作所',
        submitter_name_en='HISAKA WORKS,LTD.',
        submitter_name_yomi='カブシキガイシャヒサカセイサクショ',
        address='大阪市北区曾根崎二丁目１２番７号',
        industry='機械',
        sec_code='62470',
        corporate_number='1120001087750',
    ),
    'E01644': EdinetCodeEntry(
        edinet_code='E01644',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000桜井製作所',
        submitter_name_en='SAKURAI LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000サクライセイサクショ',
        address='浜松市東区半田町７２０番地',
        industry='輸送用機器',
        sec_code='72550',
        corporate_number='9080401001936',
    ),
    'E01645': EdinetCodeEntry(
        edinet_code='E01645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4966,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＰＩＬＬＡＲ',
        submitter_name_en='PILLAR Corporation',
        submitter_name_yomi='カブシキガイシャピラー',
        address='大阪市西区新町一丁目７番１号',
        industry='機械',
        sec_code='64900',
        corporate_number='3120001059450',
    ),
    'E01646': EdinetCodeEntry(
        edinet_code='E01646',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1947,
        fiscal_year_end='3月31日',
        submitter_name='水道機工株式会社',
        submitter_name_en='SUIDO KIKO KAISHA,LTD',
        submitter_name_yomi='スイドウキコウカブシキガイシャ',
        address='世田谷区桜丘五丁目４８番１６号',
        industry='機械',
        sec_code='64030',
        corporate_number='5010901005975',
    ),
    'E01647': EdinetCodeEntry(
        edinet_code='E01647',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1858,
        fiscal_year_end='3月31日',
        submitter_name='小倉クラッチ株式会社',
        submitter_name_en='OGURA CLUTCH CO.,LTD.',
        submitter_name_yomi='オグラクラッチカブシキガイシャ',
        address='桐生市相生町二丁目６７８番地',
        industry='機械',
        sec_code='64080',
        corporate_number='1070001015725',
    ),
    'E01648': EdinetCodeEntry(
        edinet_code='E01648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＦＫホールディングス',
        submitter_name_en='NFK HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエヌエフケーホールディングス',
        address='港区南青山７－８－４',
        industry='機械',
        sec_code='64940',
        corporate_number='9020001018394',
    ),
    'E01649': EdinetCodeEntry(
        edinet_code='E01649',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1150,
        fiscal_year_end='5月31日',
        submitter_name='株式会社中北製作所',
        submitter_name_en='NAKAKITA SEISAKUSHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャナカキタセイサクショ',
        address='大東市深野南町１番１号',
        industry='機械',
        sec_code='64960',
        corporate_number='5122001015687',
    ),
    'E01650': EdinetCodeEntry(
        edinet_code='E01650',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12892,
        fiscal_year_end='3月31日',
        submitter_name='グローリー株式会社',
        submitter_name_en='GLORY LTD.',
        submitter_name_yomi='グローリーカブシキガイシャ',
        address='姫路市下手野一丁目３番１号',
        industry='機械',
        sec_code='64570',
        corporate_number='5140001058614',
    ),
    'E01651': EdinetCodeEntry(
        edinet_code='E01651',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=849,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プラコー',
        submitter_name_en='PLACO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャプラコー',
        address='さいたま市岩槻区笹久保新田５５０番地',
        industry='機械',
        sec_code='63470',
        corporate_number='6030001018165',
    ),
    'E01652': EdinetCodeEntry(
        edinet_code='E01652',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=395,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ハマイ',
        submitter_name_en='HAMAI INDUSTRIES LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ハマイ',
        address='品川区西五反田七丁目７番７号ＳＧスクエア２階',
        industry='機械',
        sec_code='64970',
        corporate_number='6010701008104',
    ),
    'E01653': EdinetCodeEntry(
        edinet_code='E01653',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4746,
        fiscal_year_end='3月31日',
        submitter_name='株式会社モリタホールディングス',
        submitter_name_en='MORITA HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャモリタホールディングス',
        address='大阪市中央区道修町三丁目６番１号',
        industry='輸送用機器',
        sec_code='64550',
        corporate_number='7120001019062',
    ),
    'E01654': EdinetCodeEntry(
        edinet_code='E01654',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8070,
        fiscal_year_end='12月31日',
        submitter_name='ホシザキ株式会社',
        submitter_name_en='HOSHIZAKI CORPORATION',
        submitter_name_yomi='ホシザキカブシキガイシャ',
        address='豊明市栄町南館３番の１６',
        industry='機械',
        sec_code='64650',
        corporate_number='4180001069484',
    ),
    'E01656': EdinetCodeEntry(
        edinet_code='E01656',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1090,
        fiscal_year_end='12月31日',
        submitter_name='日本アイ・エス・ケイ株式会社',
        submitter_name_en='NIHON ISK Company, Limited',
        submitter_name_yomi='ニホンアイエスケイカブシキガイシャ',
        address='台東区元浅草２丁目７番１３号',
        industry='その他製品',
        sec_code='79860',
        corporate_number='1010501003516',
    ),
    'E01657': EdinetCodeEntry(
        edinet_code='E01657',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10425,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイチコーポレーション',
        submitter_name_en='AICHI CORPORATION',
        submitter_name_yomi='カブシキガイシャアイチコーポレーション',
        address='上尾市大字領家字山下１１５２―１０',
        industry='機械',
        sec_code='63450',
        corporate_number='1030001042723',
    ),
    'E01658': EdinetCodeEntry(
        edinet_code='E01658',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3160,
        fiscal_year_end='3月31日',
        submitter_name='株式会社前田製作所',
        submitter_name_en='MAEDA SEISAKUSHO CO., LTD.',
        submitter_name_yomi='カブシキガイシャマエダセイサクショ',
        address='長野市篠ノ井御幣川１０９５番地',
        industry='機械',
        sec_code=None,
        corporate_number='8100001003190',
    ),
    'E01659': EdinetCodeEntry(
        edinet_code='E01659',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社長府製作所',
        submitter_name_en='CHOFU SEISAKUSHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャチョウフセイサクショ',
        address='下関市長府扇町２番１号',
        industry='金属製品',
        sec_code='59460',
        corporate_number='8250001005924',
    ),
    'E01660': EdinetCodeEntry(
        edinet_code='E01660',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21207,
        fiscal_year_end='12月31日',
        submitter_name='株式会社キッツ',
        submitter_name_en='KITZ CORPORATION',
        submitter_name_yomi='カブシキガイシャキッツ',
        address='千葉市美浜区中瀬１丁目１０番１',
        industry='機械',
        sec_code='64980',
        corporate_number='2040001001644',
    ),
    'E01661': EdinetCodeEntry(
        edinet_code='E01661',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18198,
        fiscal_year_end='3月31日',
        submitter_name='東洋エンジニアリング株式会社',
        submitter_name_en='TOYO ENGINEERING CORPORATION',
        submitter_name_yomi='トウヨウエンジニアリングカブシキガイシャ',
        address='港区西新橋１丁目１番１号',
        industry='建設業',
        sec_code='63300',
        corporate_number='9010001024113',
    ),
    'E01662': EdinetCodeEntry(
        edinet_code='E01662',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5188,
        fiscal_year_end='3月31日',
        submitter_name='株式会社鶴見製作所',
        submitter_name_en='TSURUMI MANUFACTURING CO.,LTD.',
        submitter_name_yomi='カブシキガイシャツルミセイサクショ',
        address='大阪市鶴見区鶴見４丁目１６番４０号',
        industry='機械',
        sec_code='63510',
        corporate_number='9120001002215',
    ),
    'E01663': EdinetCodeEntry(
        edinet_code='E01663',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3416,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＩＲＭＡＮ',
        submitter_name_en='AIRMAN CORPORATION',
        submitter_name_yomi='カブシキガイシャエアマン',
        address='燕市下粟生津３０７４番地',
        industry='機械',
        sec_code='63640',
        corporate_number='4110001016088',
    ),
    'E01666': EdinetCodeEntry(
        edinet_code='E01666',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11392,
        fiscal_year_end='6月30日',
        submitter_name='澁谷工業株式会社',
        submitter_name_en='SHIBUYA CORPORATION',
        submitter_name_yomi='シブヤコウギョウカブシキガイシャ',
        address='金沢市大豆田本町甲５８番地',
        industry='機械',
        sec_code='63400',
        corporate_number='7220001003337',
    ),
    'E01667': EdinetCodeEntry(
        edinet_code='E01667',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37714,
        fiscal_year_end='3月31日',
        submitter_name='株式会社小森コーポレーション',
        submitter_name_en='KOMORI  CORPORATION',
        submitter_name_yomi='カブシキガイシャコモリコーポレーション',
        address='墨田区吾妻橋３丁目１１番１号',
        industry='機械',
        sec_code='63490',
        corporate_number='9010601010719',
    ),
    'E01669': EdinetCodeEntry(
        edinet_code='E01669',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5822,
        fiscal_year_end='3月31日',
        submitter_name='新晃工業株式会社',
        submitter_name_en='SINKO INDUSTRIES LTD.',
        submitter_name_yomi='シンコウコウギョウカブシキガイシャ',
        address='大阪市北区南森町一丁目４番５号',
        industry='機械',
        sec_code='64580',
        corporate_number='6120001065727',
    ),
    'E01670': EdinetCodeEntry(
        edinet_code='E01670',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7351,
        fiscal_year_end='3月31日',
        submitter_name='レオン自動機株式会社',
        submitter_name_en='RHEON AUTOMATIC MACHINERY CO., LTD.',
        submitter_name_yomi='レオンジドウキカブシキガイシャ',
        address='宇都宮市野沢町２番地３',
        industry='機械',
        sec_code='62720',
        corporate_number='8060001004788',
    ),
    'E01671': EdinetCodeEntry(
        edinet_code='E01671',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=822,
        fiscal_year_end='12月31日',
        submitter_name='中野冷機株式会社',
        submitter_name_en='nakano refrigerators co.,ltd.',
        submitter_name_yomi='ナカノレイキカブシキガイシャ',
        address='港区芝浦二丁目１５番４号',
        industry='機械',
        sec_code=None,
        corporate_number='6010401021159',
    ),
    'E01672': EdinetCodeEntry(
        edinet_code='E01672',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5233,
        fiscal_year_end='5月31日',
        submitter_name='前澤工業株式会社',
        submitter_name_en='Maezawa Industries,Inc.',
        submitter_name_yomi='マエザワコウギョウカブシキガイシャ',
        address='中央区新川一丁目５番１７号',
        industry='機械',
        sec_code='64890',
        corporate_number='5010001057579',
    ),
    'E01673': EdinetCodeEntry(
        edinet_code='E01673',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=61005,
        fiscal_year_end='3月31日',
        submitter_name='ＳＭＣ株式会社',
        submitter_name_en='SMC CORPORATION',
        submitter_name_yomi='エスエムシーカブシキガイシャ',
        address='中央区京橋一丁目５番５号',
        industry='機械',
        sec_code='62730',
        corporate_number='3010001097635',
    ),
    'E01675': EdinetCodeEntry(
        edinet_code='E01675',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='シリウスビジョン株式会社',
        submitter_name_en='SiriusVision CO., LTD.',
        submitter_name_yomi='シリウスビジョンカブシキガイシャ',
        address='横浜市港北区新横浜二丁目４番１７',
        industry='機械',
        sec_code='62760',
        corporate_number='3120101005362',
    ),
    'E01676': EdinetCodeEntry(
        edinet_code='E01676',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14496,
        fiscal_year_end='9月30日',
        submitter_name='ホソカワミクロン株式会社',
        submitter_name_en='HOSOKAWA  MICRON  CORPORATION',
        submitter_name_yomi='ホソカワミクロンカブシキガイシャ',
        address='枚方市招提田近１丁目９番地',
        industry='機械',
        sec_code='62770',
        corporate_number='2120001151786',
    ),
    'E01677': EdinetCodeEntry(
        edinet_code='E01677',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1888,
        fiscal_year_end='2月20日',
        submitter_name='株式会社瑞光',
        submitter_name_en='ZUIKO CORPORATION',
        submitter_name_yomi='カブシキガイシャズイコウ',
        address='茨木市彩都はなだ２丁目１番２号',
        industry='機械',
        sec_code='62790',
        corporate_number='7120901009526',
    ),
    'E01678': EdinetCodeEntry(
        edinet_code='E01678',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=34606,
        fiscal_year_end='12月31日',
        submitter_name='ＴＨＫ株式会社',
        submitter_name_en='THK CO., LTD.',
        submitter_name_yomi='テイエチケーカブシキガイシャ',
        address='港区芝浦２－１２－１０',
        industry='機械',
        sec_code='64810',
        corporate_number='3010701006176',
    ),
    'E01681': EdinetCodeEntry(
        edinet_code='E01681',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1460,
        fiscal_year_end=None,
        submitter_name='川重冷熱工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カワジュウレイネツコウギョウカブシキガイシャ',
        address='草津市青地町１０００番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3160001012736',
    ),
    'E01682': EdinetCodeEntry(
        edinet_code='E01682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3860,
        fiscal_year_end='9月30日',
        submitter_name='日精エー・エス・ビー機械株式会社',
        submitter_name_en='NISSEI ASB MACHINE CO., LTD.',
        submitter_name_yomi='ニッセイエーエスビーキカイカブシキガイシャ',
        address='小諸市甲４５８６番地３',
        industry='機械',
        sec_code='62840',
        corporate_number='7100001008315',
    ),
    'E01683': EdinetCodeEntry(
        edinet_code='E01683',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1908,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨシタケ',
        submitter_name_en='Yoshitake Inc.',
        submitter_name_yomi='カブシキガイシャヨシタケ',
        address='名古屋市瑞穂区二野町７番３号',
        industry='機械',
        sec_code='64880',
        corporate_number='9180001011318',
    ),
    'E01684': EdinetCodeEntry(
        edinet_code='E01684',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='靜甲株式会社',
        submitter_name_en='SEIKO CORPORATION',
        submitter_name_yomi='セイコウカブシキガイシャ',
        address='静岡市清水区天神二丁目８番１号',
        industry='機械',
        sec_code='62860',
        corporate_number='5080001008518',
    ),
    'E01685': EdinetCodeEntry(
        edinet_code='E01685',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8468,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サトー',
        submitter_name_en='SATO CORPORATION',
        submitter_name_yomi='カブシキガイシャサトー',
        address='港区芝浦三丁目１番１号',
        industry='機械',
        sec_code='62870',
        corporate_number='7013201017276',
    ),
    'E01686': EdinetCodeEntry(
        edinet_code='E01686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4090,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コンセック',
        submitter_name_en='CONSEC CORPORATION',
        submitter_name_yomi='カブシキガイシャコンセック',
        address='広島市西区商工センター四丁目６番８号',
        industry='卸売業',
        sec_code='98950',
        corporate_number='8240001003540',
    ),
    'E01688': EdinetCodeEntry(
        edinet_code='E01688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1641,
        fiscal_year_end='3月31日',
        submitter_name='昭和鉄工株式会社',
        submitter_name_en='Showa Manufacturing Co.,Ltd.',
        submitter_name_yomi='ショウワテッコウカブシキガイシャ',
        address='糟屋郡宇美町大字宇美３３５１番地８',
        industry='金属製品',
        sec_code='59530',
        corporate_number='9290001003221',
    ),
    'E01690': EdinetCodeEntry(
        edinet_code='E01690',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5844,
        fiscal_year_end='8月31日',
        submitter_name='株式会社技研製作所',
        submitter_name_en='GIKEN LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ギケンセイサクショ',
        address='高知市布師田３９４８番地１',
        industry='機械',
        sec_code='62890',
        corporate_number='5490001000359',
    ),
    'E01692': EdinetCodeEntry(
        edinet_code='E01692',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1250,
        fiscal_year_end='12月31日',
        submitter_name='株式会社小田原エンジニアリング',
        submitter_name_en='ODAWARA ENGINEERING CO., LTD.',
        submitter_name_yomi='カブシキガイシャオダワラエンジニアリング',
        address='足柄上郡松田町松田惣領１５７７番地',
        industry='機械',
        sec_code='61490',
        corporate_number='6021001034104',
    ),
    'E01693': EdinetCodeEntry(
        edinet_code='E01693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3358,
        fiscal_year_end='3月31日',
        submitter_name='前澤給装工業株式会社',
        submitter_name_en='MAEZAWA KYUSO INDUSTRIES CO.,LTD.',
        submitter_name_yomi='マエザワキュウソウコウギョウカブシキガイシャ',
        address='目黒区鷹番二丁目１４番４号',
        industry='機械',
        sec_code='64850',
        corporate_number='8013201005478',
    ),
    'E01694': EdinetCodeEntry(
        edinet_code='E01694',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=977,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カワタ',
        submitter_name_en='KAWATA MFG. CO., LTD.',
        submitter_name_yomi='カブシキガイシャカワタ',
        address='大阪市西区阿波座１丁目１５番１５号（第一協業ビル）',
        industry='機械',
        sec_code='62920',
        corporate_number='6120001042354',
    ),
    'E01695': EdinetCodeEntry(
        edinet_code='E01695',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5362,
        fiscal_year_end='3月31日',
        submitter_name='日精樹脂工業株式会社',
        submitter_name_en='NISSEI PLASTIC INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='ニッセイジュシコウギョウカブシキガイシャ',
        address='埴科郡坂城町大字南条２１１０番地',
        industry='機械',
        sec_code='62930',
        corporate_number='1100001011530',
    ),
    'E01696': EdinetCodeEntry(
        edinet_code='E01696',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2221,
        fiscal_year_end='3月31日',
        submitter_name='オカダアイヨン株式会社',
        submitter_name_en='OKADA AIYON CORPORATION',
        submitter_name_yomi='オカダアイヨンカブシキガイシャ',
        address='大阪市港区海岸通４丁目１番１８号',
        industry='機械',
        sec_code='62940',
        corporate_number='3120001028645',
    ),
    'E01697': EdinetCodeEntry(
        edinet_code='E01697',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2507,
        fiscal_year_end='12月31日',
        submitter_name='富士変速機株式会社',
        submitter_name_en='FUJI HENSOKUKI CO.,LTD.',
        submitter_name_yomi='フジヘンソクキカブシキガイシャ',
        address='岐阜市中洲町１８番地',
        industry='機械',
        sec_code=None,
        corporate_number='1200001004458',
    ),
    'E01698': EdinetCodeEntry(
        edinet_code='E01698',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2220,
        fiscal_year_end='3月31日',
        submitter_name='日本金銭機械株式会社',
        submitter_name_en='Japan Cash Machine co.,ltd.',
        submitter_name_yomi='ニホンキンセンキカイカブシキガイシャ',
        address='大阪市浪速区難波中二丁目１１番１８号',
        industry='機械',
        sec_code='64180',
        corporate_number='7120001022181',
    ),
    'E01699': EdinetCodeEntry(
        edinet_code='E01699',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1165,
        fiscal_year_end='3月31日',
        submitter_name='鉱研工業株式会社',
        submitter_name_en='KOKEN BORING MACHINE CO., LTD.',
        submitter_name_yomi='コウケンコウギョウカブシキガイシャ',
        address='豊島区高田２－１７－２２目白中野ビル１階',
        industry='機械',
        sec_code=None,
        corporate_number='8013301022968',
    ),
    'E01700': EdinetCodeEntry(
        edinet_code='E01700',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6020,
        fiscal_year_end=None,
        submitter_name='株式会社神鋼環境ソリューション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンコウカンキョウソリューション',
        address='神戸市中央区脇浜町１丁目４番７８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001008256',
    ),
    'E01701': EdinetCodeEntry(
        edinet_code='E01701',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5837,
        fiscal_year_end='3月31日',
        submitter_name='アピックヤマダ株式会社',
        submitter_name_en='APIC YAMADA CORPORATION',
        submitter_name_yomi='アピックヤマダカブシキガイシャ',
        address='千曲市大字上徳間９０番地',
        industry='機械',
        sec_code=None,
        corporate_number='9100001006275',
    ),
    'E01703': EdinetCodeEntry(
        edinet_code='E01703',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2220,
        fiscal_year_end=None,
        submitter_name='株式会社ササクラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャササクラ',
        address='大阪市西淀川区御幣島６丁目７番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001049642',
    ),
    'E01704': EdinetCodeEntry(
        edinet_code='E01704',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=890,
        fiscal_year_end='3月31日',
        submitter_name='サンセイ株式会社',
        submitter_name_en='SANSEI CO.,LTD.',
        submitter_name_yomi='サンセイカブシキガイシャ',
        address='大阪市淀川区西宮原一丁目６番２号',
        industry='機械',
        sec_code='63070',
        corporate_number='3120001055482',
    ),
    'E01705': EdinetCodeEntry(
        edinet_code='E01705',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1061,
        fiscal_year_end='10月31日',
        submitter_name='巴工業株式会社',
        submitter_name_en='TOMOE ENGINEERING CO.,LTD.',
        submitter_name_yomi='トモエコウギョウカブシキガイシャ',
        address='品川区北品川五丁目５番１５号',
        industry='機械',
        sec_code='63090',
        corporate_number='2010701018429',
    ),
    'E01706': EdinetCodeEntry(
        edinet_code='E01706',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1035,
        fiscal_year_end='2月末日',
        submitter_name='フロイント産業株式会社',
        submitter_name_en='Freund Corporation',
        submitter_name_yomi='フロイントサンギョウカブシキガイシャ',
        address='新宿区西新宿六丁目２５番１３号',
        industry='機械',
        sec_code='63120',
        corporate_number='4011101018760',
    ),
    'E01707': EdinetCodeEntry(
        edinet_code='E01707',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1186,
        fiscal_year_end='12月31日',
        submitter_name='株式会社石井工作研究所',
        submitter_name_en='ISHII TOOL & ENGINEERING CORPORATION',
        submitter_name_yomi='カブシキガイシャイシイコウサクケンキュウショ',
        address='大分市東大道２丁目５番６０号',
        industry='機械',
        sec_code=None,
        corporate_number='5320001000499',
    ),
    'E01708': EdinetCodeEntry(
        edinet_code='E01708',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8932,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＷＡ株式会社',
        submitter_name_en='TOWA CORPORATION',
        submitter_name_yomi='トーワカブシキガイシャ',
        address='京都市南区上鳥羽上調子町５番地',
        industry='機械',
        sec_code='63150',
        corporate_number='7130001011258',
    ),
    'E01710': EdinetCodeEntry(
        edinet_code='E01710',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1985,
        fiscal_year_end='3月31日',
        submitter_name='ＹＵＳＨＩＮ株式会社',
        submitter_name_en='Yushin Company',
        submitter_name_yomi='ユーシンカブシキガイシャ',
        address='京都市南区久世殿城町５５５番地',
        industry='機械',
        sec_code='64820',
        corporate_number='3130001015997',
    ),
    'E01711': EdinetCodeEntry(
        edinet_code='E01711',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=893,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タクミナ',
        submitter_name_en='tacmina corporation',
        submitter_name_yomi='カブシキガイシャタクミナ',
        address='大阪市中央区淡路町二丁目２番１４号',
        industry='機械',
        sec_code='63220',
        corporate_number='1120001083948',
    ),
    'E01712': EdinetCodeEntry(
        edinet_code='E01712',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハーモニック・ドライブ・システムズ',
        submitter_name_en='Harmonic Drive Systems Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000ハーモニックドライブシステムズ',
        address='品川区南大井６丁目２５番３号',
        industry='機械',
        sec_code='63240',
        corporate_number='3010701008189',
    ),
    'E01713': EdinetCodeEntry(
        edinet_code='E01713',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1335,
        fiscal_year_end='6月30日',
        submitter_name='北川精機株式会社',
        submitter_name_en='KITAGAWA SEIKI CO.,LTD.',
        submitter_name_yomi='キタガワセイキカブシキガイシャ',
        address='府中市鵜飼町８００番地の８',
        industry='機械',
        sec_code='63270',
        corporate_number='7240001034181',
    ),
    'E01714': EdinetCodeEntry(
        edinet_code='E01714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1001,
        fiscal_year_end='12月31日',
        submitter_name='荏原実業株式会社',
        submitter_name_en='EBARA JITSUGYO CO.,LTD.',
        submitter_name_yomi='エバラジツギョウカブシキガイシャ',
        address='中央区銀座七丁目１４番１号',
        industry='機械',
        sec_code='63280',
        corporate_number='5010001039024',
    ),
    'E01715': EdinetCodeEntry(
        edinet_code='E01715',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=963,
        fiscal_year_end='9月30日',
        submitter_name='株式会社タカトリ',
        submitter_name_en='Takatori Corporation',
        submitter_name_yomi='カブシキガイシャタカトリ',
        address='橿原市新堂町３１３番地の１',
        industry='機械',
        sec_code='63380',
        corporate_number='2150001010683',
    ),
    'E01716': EdinetCodeEntry(
        edinet_code='E01716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1739,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＴＶＥ',
        submitter_name_en='TVE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャティーブイイー',
        address='尼崎市西立花町五丁目１２番１号',
        industry='機械',
        sec_code='64660',
        corporate_number='3140001052189',
    ),
    'E01717': EdinetCodeEntry(
        edinet_code='E01717',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6791,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000精工技研',
        submitter_name_en='SEIKOH GIKEN Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000セイコウギケン',
        address='松戸市松飛台２９６番地の１',
        industry='電気機器',
        sec_code='68340',
        corporate_number='6040001035845',
    ),
    'E01718': EdinetCodeEntry(
        edinet_code='E01718',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1006,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オーイズミ',
        submitter_name_en='OIZUMI Corporation',
        submitter_name_yomi='カブシキガイシャオーイズミ',
        address='厚木市中町二丁目７番１０号',
        industry='機械',
        sec_code='64280',
        corporate_number='5021001020996',
    ),
    'E01719': EdinetCodeEntry(
        edinet_code='E01719',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2177,
        fiscal_year_end='3月31日',
        submitter_name='株式会社昭和真空',
        submitter_name_en='SHOWA SHINKU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャショウワシンクウ',
        address='相模原市中央区田名３０６２番地１０',
        industry='機械',
        sec_code='63840',
        corporate_number='9021001012619',
    ),
    'E01721': EdinetCodeEntry(
        edinet_code='E01721',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=313,
        fiscal_year_end='3月31日',
        submitter_name='兼松エンジニアリング株式会社',
        submitter_name_en='KANEMATSU ENGINEERING CO.,LTD.',
        submitter_name_yomi='カネマツエンジニアリングカブシキガイシャ',
        address='高知市布師田３９８１番地７',
        industry='機械',
        sec_code='64020',
        corporate_number='5490001000318',
    ),
    'E01723': EdinetCodeEntry(
        edinet_code='E01723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3632,
        fiscal_year_end='2月末日',
        submitter_name='株式会社竹内製作所',
        submitter_name_en='TAKEUCHI MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタケウチセイサクショ',
        address='埴科郡坂城町大字上平２０５番地',
        industry='機械',
        sec_code='64320',
        corporate_number='4100001011503',
    ),
    'E01724': EdinetCodeEntry(
        edinet_code='E01724',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1154,
        fiscal_year_end='3月31日',
        submitter_name='鈴茂器工株式会社',
        submitter_name_en='Suzumo Machinery Co., Ltd.',
        submitter_name_yomi='スズモキコウカブシキガイシヤ',
        address='中野区中野四丁目１０番１号\u3000中野セントラルパークイースト',
        industry='機械',
        sec_code='64050',
        corporate_number='3011601010978',
    ),
    'E01725': EdinetCodeEntry(
        edinet_code='E01725',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18166,
        fiscal_year_end='12月31日',
        submitter_name='三井海洋開発株式会社',
        submitter_name_en='MODEC,INC.',
        submitter_name_yomi='ミツイカイヨウカイハツカブシキガイシャ',
        address='中央区日本橋二丁目３番１０号',
        industry='機械',
        sec_code='62690',
        corporate_number='8010001007886',
    ),
    'E01726': EdinetCodeEntry(
        edinet_code='E01726',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='12月31日',
        submitter_name='ナブテスコ株式会社',
        submitter_name_en='Nabtesco Corporation',
        submitter_name_yomi='ナブテスコカブシキガイシャ',
        address='千代田区平河町２丁目７番９号',
        industry='機械',
        sec_code='62680',
        corporate_number='3010001142283',
    ),
    'E01727': EdinetCodeEntry(
        edinet_code='E01727',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=732,
        fiscal_year_end='3月31日',
        submitter_name='ヒーハイスト株式会社',
        submitter_name_en='HEPHAIST CO.,LTD.',
        submitter_name_yomi='ヒーハイストカブシキガイシャ',
        address='川越市今福５８０番地１',
        industry='機械',
        sec_code='64330',
        corporate_number='6030001056900',
    ),
    'E01728': EdinetCodeEntry(
        edinet_code='E01728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=748,
        fiscal_year_end='12月31日',
        submitter_name='コンバム株式会社',
        submitter_name_en='CONVUM Ltd.',
        submitter_name_yomi='コンバムカブシキガイシャ',
        address='大田区下丸子二丁目６番１８号',
        industry='機械',
        sec_code='62650',
        corporate_number='4010801011620',
    ),
    'E01729': EdinetCodeEntry(
        edinet_code='E01729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=455,
        fiscal_year_end='3月31日',
        submitter_name='日進工具株式会社',
        submitter_name_en='NS TOOL CO.,LTD.',
        submitter_name_yomi='ニッシンコウグカブシキガイシャ',
        address='品川区南大井四丁目５番９号',
        industry='機械',
        sec_code='61570',
        corporate_number='4010701007545',
    ),
    'E01730': EdinetCodeEntry(
        edinet_code='E01730',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=557,
        fiscal_year_end='3月20日',
        submitter_name='株式会社エスティック',
        submitter_name_en='ESTIC CORPORATION',
        submitter_name_yomi='カブシキガイシャエスティック',
        address='守口市東郷通一丁目２番１６号',
        industry='機械',
        sec_code='61610',
        corporate_number='3120001155365',
    ),
    'E01731': EdinetCodeEntry(
        edinet_code='E01731',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2255,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＰＥＧＡＳＵＳ',
        submitter_name_en='PEGASUS CO., LTD.',
        submitter_name_yomi='カブシキガイシャペガサス',
        address='大阪市福島区鷺洲五丁目７番２号',
        industry='機械',
        sec_code='62620',
        corporate_number='6120001036356',
    ),
    'E01733': EdinetCodeEntry(
        edinet_code='E01733',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2633,
        fiscal_year_end='3月31日',
        submitter_name='平田機工株式会社',
        submitter_name_en='HIRATA Corporation',
        submitter_name_yomi='ヒラタキコウカブシキガイシャ',
        address='熊本市北区植木町一木１１１番地',
        industry='機械',
        sec_code='62580',
        corporate_number='4010701008411',
    ),
    'E01734': EdinetCodeEntry(
        edinet_code='E01734',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2812,
        fiscal_year_end='8月末日',
        submitter_name='株式会社エヌ・ピー・シー',
        submitter_name_en='NPC Incorporated',
        submitter_name_yomi='カブシキガイシャエヌピーシー',
        address='台東区東上野１－７－１５\u3000ヒューリック東上野一丁目ビル５階',
        industry='機械',
        sec_code='62550',
        corporate_number='9011501005718',
    ),
    'E01735': EdinetCodeEntry(
        edinet_code='E01735',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2236,
        fiscal_year_end='3月31日',
        submitter_name='野村マイクロ・サイエンス株式会社',
        submitter_name_en='Nomura Micro Science Co.,Ltd.',
        submitter_name_yomi='ノムラマイクロサイエンスカブシキガイシャ',
        address='厚木市岡田二丁目９番１０号',
        industry='機械',
        sec_code='62540',
        corporate_number='2021001020322',
    ),
    'E01737': EdinetCodeEntry(
        edinet_code='E01737',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=462817,
        fiscal_year_end='3月末日',
        submitter_name='株式会社日立製作所',
        submitter_name_en='Hitachi, Ltd.',
        submitter_name_yomi='カブシキカイシャヒタチセイサクショ',
        address='千代田区丸の内一丁目６番６号',
        industry='電気機器',
        sec_code='65010',
        corporate_number='7010001008844',
    ),
    'E01738': EdinetCodeEntry(
        edinet_code='E01738',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=201449,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000東芝',
        submitter_name_en='TOSHIBA CORPORATION',
        submitter_name_yomi='カブシキガイシャトウシバ',
        address='川崎市幸区堀川町７２番地３４',
        industry='電気機器',
        sec_code=None,
        corporate_number='2010401044997',
    ),
    'E01739': EdinetCodeEntry(
        edinet_code='E01739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=175820,
        fiscal_year_end='3月31日',
        submitter_name='三菱電機株式会社',
        submitter_name_en='Mitsubishi Electric Corporation',
        submitter_name_yomi='ミツビシデンキカブシキガイシャ',
        address='千代田区丸の内二丁目７番３号',
        industry='電気機器',
        sec_code='65030',
        corporate_number='4010001008772',
    ),
    'E01740': EdinetCodeEntry(
        edinet_code='E01740',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=47586,
        fiscal_year_end='3月31日',
        submitter_name='富士電機株式会社',
        submitter_name_en='FUJI ELECTRIC CO., LTD.',
        submitter_name_yomi='フジデンキカブシキガイシャ',
        address='川崎市川崎区田辺新田１番１号',
        industry='電気機器',
        sec_code='65040',
        corporate_number='9020001071492',
    ),
    'E01741': EdinetCodeEntry(
        edinet_code='E01741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30562,
        fiscal_year_end='2月末日',
        submitter_name='株式会社安川電機',
        submitter_name_en='YASKAWA Electric Corporation',
        submitter_name_yomi='カブシキガイシャヤスカワデンキ',
        address='北九州市八幡西区黒崎城石２番１号',
        industry='電気機器',
        sec_code='65060',
        corporate_number='5290801010767',
    ),
    'E01742': EdinetCodeEntry(
        edinet_code='E01742',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4998,
        fiscal_year_end='5月31日',
        submitter_name='東洋電機製造株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウヨウデンキセイゾウカブシキガイシャ',
        address='中央区八重洲一丁目４番１６号',
        industry='電気機器',
        sec_code='65050',
        corporate_number='7010001034857',
    ),
    'E01743': EdinetCodeEntry(
        edinet_code='E01743',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10156,
        fiscal_year_end='3月31日',
        submitter_name='シンフォニアテクノロジー株式会社',
        submitter_name_en='SINFONIA TECHNOLOGY CO., LTD.',
        submitter_name_yomi='シンフォニアテクノロジーカブシキガイシャ',
        address='港区芝大門１－１－３０芝ＮＢＦタワー',
        industry='電気機器',
        sec_code='65070',
        corporate_number='2010401054443',
    ),
    'E01744': EdinetCodeEntry(
        edinet_code='E01744',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17070,
        fiscal_year_end='3月31日',
        submitter_name='株式会社明電舎',
        submitter_name_en='MEIDENSHA CORPORATION',
        submitter_name_yomi='カブシキガイシャメイデンシャ',
        address='品川区大崎二丁目１番１号',
        industry='電気機器',
        sec_code='65080',
        corporate_number='4010701009640',
    ),
    'E01745': EdinetCodeEntry(
        edinet_code='E01745',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=17813,
        fiscal_year_end='3月31日',
        submitter_name='日立工機株式会社',
        submitter_name_en='Hitachi Koki Co., Ltd.',
        submitter_name_yomi='ヒタチコウキカブシキガイシャ',
        address='港区港南二丁目１５番１号',
        industry='機械',
        sec_code=None,
        corporate_number='7010401038697',
    ),
    'E01746': EdinetCodeEntry(
        edinet_code='E01746',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10252,
        fiscal_year_end=None,
        submitter_name='日新電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッシンデンキカブシキガイシャ',
        address='京都市右京区梅津高畝町４７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130001001588',
    ),
    'E01747': EdinetCodeEntry(
        edinet_code='E01747',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2899,
        fiscal_year_end='3月31日',
        submitter_name='株式会社戸上電機製作所',
        submitter_name_en='Togami Electric Mfg. Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトガミデンキセイサクショ',
        address='佐賀市大財北町１番１号',
        industry='電気機器',
        sec_code='66430',
        corporate_number='5300001000526',
    ),
    'E01748': EdinetCodeEntry(
        edinet_code='E01748',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4053,
        fiscal_year_end='3月31日',
        submitter_name='愛知電機株式会社',
        submitter_name_en='AICHI ELECTRIC CO.,LTD.',
        submitter_name_yomi='アイチデンキカブシキガイシャ',
        address='春日井市愛知町１番地',
        industry='電気機器',
        sec_code='66230',
        corporate_number='4180001073593',
    ),
    'E01750': EdinetCodeEntry(
        edinet_code='E01750',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10596,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイヘン',
        submitter_name_en='DAIHEN CORPORATION',
        submitter_name_yomi='カブシキガイシャダイヘン',
        address='大阪市淀川区田川二丁目１番１１号',
        industry='電気機器',
        sec_code='66220',
        corporate_number='6120001056461',
    ),
    'E01751': EdinetCodeEntry(
        edinet_code='E01751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6103,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オリジン',
        submitter_name_en='Origin Company, Limited',
        submitter_name_yomi='カブシキガイシャオリジン',
        address='さいたま市桜区栄和三丁目３番２７号',
        industry='電気機器',
        sec_code='65130',
        corporate_number='3013301003097',
    ),
    'E01752': EdinetCodeEntry(
        edinet_code='E01752',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7965,
        fiscal_year_end='3月31日',
        submitter_name='大崎電気工業株式会社',
        submitter_name_en='Osaki Electric Co.,Ltd.',
        submitter_name_yomi='オオサキデンキコウギョウカブシキガイシャ',
        address='品川区東五反田二丁目１０番２号',
        industry='電気機器',
        sec_code='66440',
        corporate_number='6010701001918',
    ),
    'E01753': EdinetCodeEntry(
        edinet_code='E01753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3481,
        fiscal_year_end='3月31日',
        submitter_name='三櫻工業株式会社',
        submitter_name_en='Sanoh Industrial Co.,Ltd.',
        submitter_name_yomi='サンオウコウギョウカブシキガイシャ',
        address='古河市鴻巣７５８番地',
        industry='輸送用機器',
        sec_code='65840',
        corporate_number='6011001045853',
    ),
    'E01754': EdinetCodeEntry(
        edinet_code='E01754',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2124,
        fiscal_year_end='3月31日',
        submitter_name='株式会社かわでん',
        submitter_name_en='KAWADEN CORPORATION',
        submitter_name_yomi='カブシキガイシャカワデン',
        address='南陽市小岩沢２２５番地',
        industry='電気機器',
        sec_code='66480',
        corporate_number='4390001010708',
    ),
    'E01755': EdinetCodeEntry(
        edinet_code='E01755',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=64100,
        fiscal_year_end='3月31日',
        submitter_name='オムロン株式会社',
        submitter_name_en='OMRON CORPORATION',
        submitter_name_yomi='オムロンカブシキガイシャ',
        address='京都市下京区塩小路通堀川東入南不動堂町８０１番地',
        industry='電気機器',
        sec_code='66450',
        corporate_number='1130001016824',
    ),
    'E01757': EdinetCodeEntry(
        edinet_code='E01757',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6761,
        fiscal_year_end='3月31日',
        submitter_name='芝浦メカトロニクス株式会社',
        submitter_name_en='SHIBAURA MECHATRONICS CORPORATION',
        submitter_name_yomi='シバウラメカトロニクスカブシキガイシャ',
        address='横浜市栄区笠間二丁目５番１号',
        industry='電気機器',
        sec_code='65900',
        corporate_number='8020001032660',
    ),
    'E01758': EdinetCodeEntry(
        edinet_code='E01758',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1954,
        fiscal_year_end='3月31日',
        submitter_name='デンヨー株式会社',
        submitter_name_en='Denyo Co.,Ltd.',
        submitter_name_yomi='デンヨーカブシキガイシャ',
        address='中央区日本橋堀留町２丁目８番５号',
        industry='電気機器',
        sec_code='65170',
        corporate_number='4010001105371',
    ),
    'E01759': EdinetCodeEntry(
        edinet_code='E01759',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6578,
        fiscal_year_end='3月31日',
        submitter_name='日東工業株式会社',
        submitter_name_en='NITTO KOGYO CORPORATION',
        submitter_name_yomi='ニットウコウギョウカブシキガイシャ',
        address='長久手市蟹原２２０１番地',
        industry='電気機器',
        sec_code='66510',
        corporate_number='9180001067905',
    ),
    'E01760': EdinetCodeEntry(
        edinet_code='E01760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2323,
        fiscal_year_end='12月31日',
        submitter_name='株式会社正興電機製作所',
        submitter_name_en='SEIKO ELECTRIC CO., LTD.',
        submitter_name_yomi='カブシキガイシャセイコウデンキセイサクショ',
        address='福岡市博多区東光二丁目７番２５号',
        industry='電気機器',
        sec_code='66530',
        corporate_number='6290001014089',
    ),
    'E01761': EdinetCodeEntry(
        edinet_code='E01761',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3143,
        fiscal_year_end='3月31日',
        submitter_name='株式会社帝国電機製作所',
        submitter_name_en='TEIKOKU ELECTRIC MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャテイコクデンキセイサクショ',
        address='たつの市新宮町平野６０番地',
        industry='機械',
        sec_code='63330',
        corporate_number='3140001039376',
    ),
    'E01762': EdinetCodeEntry(
        edinet_code='E01762',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=200,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ゼネシス',
        submitter_name_en='Xenesys Incorporated',
        submitter_name_yomi='カブシキガイシャゼネシス',
        address='伊万里市黒川町塩屋字七ッ島５番地９１',
        industry='電気機器',
        sec_code=None,
        corporate_number='1010001142153',
    ),
    'E01764': EdinetCodeEntry(
        edinet_code='E01764',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1236,
        fiscal_year_end='3月31日',
        submitter_name='寺崎電気産業株式会社',
        submitter_name_en='TERASAKI ELECTRIC CO.,LTD.',
        submitter_name_yomi='テラサキデンキサンギョウカブシキガイシャ',
        address='大阪市平野区加美東六丁目１３番４７号',
        industry='電気機器',
        sec_code='66370',
        corporate_number='6120001005889',
    ),
    'E01765': EdinetCodeEntry(
        edinet_code='E01765',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=427831,
        fiscal_year_end='3月31日',
        submitter_name='日本電気株式会社',
        submitter_name_en='NEC Corporation',
        submitter_name_yomi='ニッポンデンキカブシキカイシャ',
        address='港区芝五丁目７番１号',
        industry='電気機器',
        sec_code='67010',
        corporate_number='7010401022916',
    ),
    'E01766': EdinetCodeEntry(
        edinet_code='E01766',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=325638,
        fiscal_year_end='3月31日',
        submitter_name='富士通株式会社',
        submitter_name_en='FUJITSU LIMITED',
        submitter_name_yomi='フジツウカブシキガイシャ',
        address='川崎市中原区上小田中４丁目１番１号',
        industry='電気機器',
        sec_code='67020',
        corporate_number='1020001071491',
    ),
    'E01767': EdinetCodeEntry(
        edinet_code='E01767',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=44000,
        fiscal_year_end='3月31日',
        submitter_name='沖電気工業株式会社',
        submitter_name_en='Oki Electric Industry Company, Limited',
        submitter_name_yomi='オキデンキコウギョウカブシキガイシャ',
        address='港区虎ノ門１丁目７番１２号',
        industry='電気機器',
        sec_code='67030',
        corporate_number='7010401006126',
    ),
    'E01768': EdinetCodeEntry(
        edinet_code='E01768',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6025,
        fiscal_year_end='3月31日',
        submitter_name='岩崎通信機株式会社',
        submitter_name_en='IWATSU ELECTRIC CO., LTD.',
        submitter_name_yomi='イワサキツウシンキカブシキガイシャ',
        address='杉並区久我山１丁目７番４１号',
        industry='電気機器',
        sec_code=None,
        corporate_number='9011301000786',
    ),
    'E01769': EdinetCodeEntry(
        edinet_code='E01769',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='日本信号株式会社',
        submitter_name_en='Nippon Signal Company,Limited',
        submitter_name_yomi='ニホンシンゴウカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号\u3000新丸の内ビルディング\u3000１３階',
        industry='電気機器',
        sec_code='67410',
        corporate_number='9010001110631',
    ),
    'E01770': EdinetCodeEntry(
        edinet_code='E01770',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6270,
        fiscal_year_end='3月31日',
        submitter_name='株式会社京三製作所',
        submitter_name_en='Kyosan Electric Manufacturing Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャキョウサンセイサクショ',
        address='横浜市鶴見区平安町２丁目２９番地の１',
        industry='電気機器',
        sec_code='67420',
        corporate_number='6020001017093',
    ),
    'E01771': EdinetCodeEntry(
        edinet_code='E01771',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=14704,
        fiscal_year_end='3月31日',
        submitter_name='日本無線株式会社',
        submitter_name_en='Japan Radio Co.,Ltd.',
        submitter_name_yomi='ニホンムセンカブシキガイシャ',
        address='三鷹市牟礼六丁目２１番１１号',
        industry='電気機器',
        sec_code=None,
        corporate_number='3012401012867',
    ),
    'E01772': EdinetCodeEntry(
        edinet_code='E01772',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=259566,
        fiscal_year_end='3月31日',
        submitter_name='パナソニックホールディングス株式会社',
        submitter_name_en='Panasonic Holdings Corporation',
        submitter_name_yomi='パナソニックホールディングスカブシキガイシャ',
        address='門真市大字門真１００６番地',
        industry='電気機器',
        sec_code='67520',
        corporate_number='5120001158218',
    ),
    'E01773': EdinetCodeEntry(
        edinet_code='E01773',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='シャープ株式会社',
        submitter_name_en='Sharp Corporation',
        submitter_name_yomi='シャープカブシキガイシャ',
        address='堺市堺区匠町１番地',
        industry='電気機器',
        sec_code='67530',
        corporate_number='6120001005484',
    ),
    'E01774': EdinetCodeEntry(
        edinet_code='E01774',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19219,
        fiscal_year_end='3月31日',
        submitter_name='アンリツ株式会社',
        submitter_name_en='ANRITSU CORPORATION',
        submitter_name_yomi='アンリツカブシキガイシャ',
        address='厚木市恩名五丁目１番１号',
        industry='電気機器',
        sec_code='67540',
        corporate_number='2021001021865',
    ),
    'E01775': EdinetCodeEntry(
        edinet_code='E01775',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=18089,
        fiscal_year_end='3月31日',
        submitter_name='株式会社富士通ゼネラル',
        submitter_name_en='FUJITSU GENERAL LIMITED',
        submitter_name_yomi='カブシキガイシャフジツウゼネラル',
        address='川崎市高津区末長三丁目３番１７号',
        industry='電気機器',
        sec_code=None,
        corporate_number='6020001066941',
    ),
    'E01776': EdinetCodeEntry(
        edinet_code='E01776',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10058,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日立国際電気',
        submitter_name_en='Hitachi Kokusai Electric Inc.',
        submitter_name_yomi='カブシキガイシャヒタチコクサイデンキ',
        address='港区西新橋二丁目１５番１２号',
        industry='電気機器',
        sec_code=None,
        corporate_number='2010001098064',
    ),
    'E01777': EdinetCodeEntry(
        edinet_code='E01777',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=881357,
        fiscal_year_end='3月31日',
        submitter_name='ソニーグループ株式会社',
        submitter_name_en='SONY GROUP CORPORATION',
        submitter_name_yomi='ソニーグループカブシキガイシャ',
        address='港区港南１丁目７番１号',
        industry='電気機器',
        sec_code='67580',
        corporate_number='5010401067252',
    ),
    'E01780': EdinetCodeEntry(
        edinet_code='E01780',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32641,
        fiscal_year_end='3月31日',
        submitter_name='ＴＤＫ株式会社',
        submitter_name_en='TDK Corporation',
        submitter_name_yomi='ティーディーケイカブシキガイシャ',
        address='中央区日本橋二丁目５番１号',
        industry='電気機器',
        sec_code='67620',
        corporate_number='7010001034849',
    ),
    'E01782': EdinetCodeEntry(
        edinet_code='E01782',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3453,
        fiscal_year_end='3月31日',
        submitter_name='帝国通信工業株式会社',
        submitter_name_en='Teikoku Tsushin Kogyo Co.,Ltd',
        submitter_name_yomi='テイコクツウシンコウギョウカブシキガイシャ',
        address='川崎市中原区苅宿４５番１号',
        industry='電気機器',
        sec_code='67630',
        corporate_number='2020001069741',
    ),
    'E01785': EdinetCodeEntry(
        edinet_code='E01785',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='ミツミ電機株式会社',
        submitter_name_en='MITSUMI ELECTRIC CO.,LTD.',
        submitter_name_yomi='ミツミデンキカブシキガイシャ',
        address='多摩市鶴牧二丁目１１番地２',
        industry='電気機器',
        sec_code=None,
        corporate_number='4013401002485',
    ),
    'E01786': EdinetCodeEntry(
        edinet_code='E01786',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11829,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タムラ製作所',
        submitter_name_en='TAMURA CORPORATION',
        submitter_name_yomi='カブシキガイシャタムラセイサクショ',
        address='練馬区東大泉１－１９－４３',
        industry='電気機器',
        sec_code='67680',
        corporate_number='3011601004237',
    ),
    'E01787': EdinetCodeEntry(
        edinet_code='E01787',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='日本コロムビア株式会社',
        submitter_name_en='Nippon Columbia Co., Ltd.',
        submitter_name_yomi='ニッポンコロムビアカブシキガイシャ',
        address='港区南青山六丁目１０番１２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010401022656',
    ),
    'E01790': EdinetCodeEntry(
        edinet_code='E01790',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20896,
        fiscal_year_end='3月31日',
        submitter_name='サンケン電気株式会社',
        submitter_name_en='Sanken Electric Co.,Ltd.',
        submitter_name_yomi='サンケンデンキカブシキガイシャ',
        address='新座市北野三丁目６番３号',
        industry='電気機器',
        sec_code='67070',
        corporate_number='3030001045666',
    ),
    'E01792': EdinetCodeEntry(
        edinet_code='E01792',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=450,
        fiscal_year_end='3月31日',
        submitter_name='明星電気株式会社',
        submitter_name_en='MEISEI ELECTRIC CO.,LTD.',
        submitter_name_yomi='メイセイデンキカブシキガイシャ',
        address='伊勢崎市長沼町２２２３',
        industry='電気機器',
        sec_code=None,
        corporate_number='2010001007784',
    ),
    'E01793': EdinetCodeEntry(
        edinet_code='E01793',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38730,
        fiscal_year_end='3月31日',
        submitter_name='アルプスアルパイン株式会社',
        submitter_name_en='ALPS ALPINE CO., LTD.',
        submitter_name_yomi='アルプスアルパインカブシキガイシャ',
        address='大田区雪谷大塚町１番７号',
        industry='電気機器',
        sec_code='67700',
        corporate_number='3010801000723',
    ),
    'E01794': EdinetCodeEntry(
        edinet_code='E01794',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57381,
        fiscal_year_end=None,
        submitter_name='パイオニア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パイオニアカブシキガイシャ',
        address='文京区本駒込２－２８－８文京グリーンコート',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020001086473',
    ),
    'E01795': EdinetCodeEntry(
        edinet_code='E01795',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3649,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴＢグループ',
        submitter_name_en='TB GROUP INC.',
        submitter_name_yomi='カブシキカイシャティービーグループ',
        address='文京区本郷三丁目２６番６号',
        industry='電気機器',
        sec_code='67750',
        corporate_number='7010001005536',
    ),
    'E01797': EdinetCodeEntry(
        edinet_code='E01797',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6770,
        fiscal_year_end='3月31日',
        submitter_name='フォスター電機株式会社',
        submitter_name_en='Foster Electric Company, Limited',
        submitter_name_yomi='フォスターデンキカブシキガイシャ',
        address='昭島市つつじが丘１丁目１番１０９号',
        industry='電気機器',
        sec_code='67940',
        corporate_number='8012801002521',
    ),
    'E01798': EdinetCodeEntry(
        edinet_code='E01798',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1842,
        fiscal_year_end='3月31日',
        submitter_name='東亜ディーケーケー株式会社',
        submitter_name_en='DKK-TOA CORPORATION',
        submitter_name_yomi='トウアディーケーケーカブシキカイシャ',
        address='新宿区高田馬場一丁目２９番１０号',
        industry='電気機器',
        sec_code='68480',
        corporate_number='9011101013864',
    ),
    'E01802': EdinetCodeEntry(
        edinet_code='E01802',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3798,
        fiscal_year_end='3月31日',
        submitter_name='ホーチキ株式会社',
        submitter_name_en='HOCHIKI CORPORATION',
        submitter_name_yomi='ホーチキ\u3000カブシキガイシャ',
        address='品川区上大崎二丁目１０番４３号',
        industry='電気機器',
        sec_code='67450',
        corporate_number='3010701008973',
    ),
    'E01803': EdinetCodeEntry(
        edinet_code='E01803',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13302,
        fiscal_year_end='3月31日',
        submitter_name='能美防災株式会社',
        submitter_name_en='NOHMI BOSAI LTD.',
        submitter_name_yomi='ノウミボウサイカブシキガイシャ',
        address='千代田区九段南４－７－３',
        industry='電気機器',
        sec_code='67440',
        corporate_number='5010001008739',
    ),
    'E01804': EdinetCodeEntry(
        edinet_code='E01804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2237,
        fiscal_year_end=None,
        submitter_name='西芝電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシシバデンキカブシキガイシャ',
        address='姫路市網干区浜田１０００番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140001060460',
    ),
    'E01805': EdinetCodeEntry(
        edinet_code='E01805',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7996,
        fiscal_year_end='3月31日',
        submitter_name='ＳＭＫ株式会社',
        submitter_name_en='SMK Corporation',
        submitter_name_yomi='エスエムケイカブシキガイシャ',
        address='品川区戸越六丁目５番５号',
        industry='電気機器',
        sec_code='67980',
        corporate_number='5010701001431',
    ),
    'E01806': EdinetCodeEntry(
        edinet_code='E01806',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9926,
        fiscal_year_end='3月31日',
        submitter_name='山洋電気株式会社',
        submitter_name_en='SANYO DENKI CO.,LTD.',
        submitter_name_yomi='サンヨウデンキカブシキガイシャ',
        address='豊島区南大塚３－３３－１',
        industry='電気機器',
        sec_code='65160',
        corporate_number='1013301004808',
    ),
    'E01807': EdinetCodeEntry(
        edinet_code='E01807',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5596,
        fiscal_year_end='3月31日',
        submitter_name='日本電波工業株式会社',
        submitter_name_en='NIHON DEMPA KOGYO CO., LTD.',
        submitter_name_yomi='ニホンデンパコウギョウカブシキガイシャ',
        address='渋谷区笹塚一丁目４７番１号',
        industry='電気機器',
        sec_code='67790',
        corporate_number='1011001017865',
    ),
    'E01808': EdinetCodeEntry(
        edinet_code='E01808',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7819,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨコオ',
        submitter_name_en='YOKOWO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヨコオ',
        address='千代田区神田須田町一丁目２５\u3000ＪＲ神田万世橋ビル１４階',
        industry='電気機器',
        sec_code='68000',
        corporate_number='4011501004889',
    ),
    'E01810': EdinetCodeEntry(
        edinet_code='E01810',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社埼玉村田製作所',
        submitter_name_en='Saitama Murata Manufacturing Co., Ltd.',
        submitter_name_yomi='カブシキガイシャサイタマムラタセイサクショ',
        address='鶴ヶ島市大字五味ヶ谷１８番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='1030001070360',
    ),
    'E01811': EdinetCodeEntry(
        edinet_code='E01811',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1277,
        fiscal_year_end='3月31日',
        submitter_name='東京コスモス電機株式会社',
        submitter_name_en='Tokyo Cosmoc Electric Co., Ltd.',
        submitter_name_yomi='トウキョウコスモスデンキカブシキガイシャ',
        address='座間市相武台二丁目１２番１号',
        industry='電気機器',
        sec_code='67720',
        corporate_number='6021001028329',
    ),
    'E01813': EdinetCodeEntry(
        edinet_code='E01813',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1208,
        fiscal_year_end='3月31日',
        submitter_name='天昇電気工業株式会社',
        submitter_name_en='Tensho Electric Industries Co., Ltd.',
        submitter_name_yomi='テンショウデンキコウギョウカブシキガイシャ',
        address='世田谷区駒沢一丁目１６番７号',
        industry='化学',
        sec_code='67760',
        corporate_number='8012301007277',
    ),
    'E01814': EdinetCodeEntry(
        edinet_code='E01814',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20346,
        fiscal_year_end='3月31日',
        submitter_name='クラリオン株式会社',
        submitter_name_en='Clarion Co.,Ltd.',
        submitter_name_yomi='クラリオンカブシキガイシャ',
        address='さいたま市中央区新都心７番地２',
        industry='電気機器',
        sec_code=None,
        corporate_number='6030001017472',
    ),
    'E01815': EdinetCodeEntry(
        edinet_code='E01815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13660,
        fiscal_year_end='3月31日',
        submitter_name='ホシデン株式会社',
        submitter_name_en='Hosiden Corporation',
        submitter_name_yomi='ホシデンカブシキガイシャ',
        address='八尾市北久宝寺１丁目４番３３号',
        industry='電気機器',
        sec_code='68040',
        corporate_number='4122001020003',
    ),
    'E01816': EdinetCodeEntry(
        edinet_code='E01816',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1500,
        fiscal_year_end='3月31日',
        submitter_name='大同信号株式会社',
        submitter_name_en='Daido Signal Co.,Ltd.',
        submitter_name_yomi='ダイドウシンゴウカブシキガイシャ',
        address='港区新橋六丁目１７番１９号',
        industry='電気機器',
        sec_code='67430',
        corporate_number='3010801006704',
    ),
    'E01817': EdinetCodeEntry(
        edinet_code='E01817',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5200,
        fiscal_year_end='3月31日',
        submitter_name='北陸電気工業株式会社',
        submitter_name_en='HOKURIKU ELECTRIC INDUSTRY CO., LTD.',
        submitter_name_yomi='ホクリクデンキコウギョウカブシキガイシャ',
        address='富山市下大久保３１５８番地',
        industry='電気機器',
        sec_code='69890',
        corporate_number='6230001005201',
    ),
    'E01819': EdinetCodeEntry(
        edinet_code='E01819',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='3月31日',
        submitter_name='池上通信機株式会社',
        submitter_name_en='IKEGAMI TSUSHINKI CO., LTD.',
        submitter_name_yomi='イケガミツウシンキカブシキガイシャ',
        address='大田区池上五丁目６番１６号',
        industry='電気機器',
        sec_code='67710',
        corporate_number='6010801000811',
    ),
    'E01821': EdinetCodeEntry(
        edinet_code='E01821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2774,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三社電機製作所',
        submitter_name_en='Sansha Electric Manufacturing Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサンシャデンキセイサクショ',
        address='大阪市東淀川区西淡路三丁目１番５６号',
        industry='電気機器',
        sec_code='68820',
        corporate_number='7120001051882',
    ),
    'E01823': EdinetCodeEntry(
        edinet_code='E01823',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=333,
        fiscal_year_end=None,
        submitter_name='田淵電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タブチデンキカブシキガイシャ',
        address='大阪市淀川区塚本一丁目１５番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001102037',
    ),
    'E01824': EdinetCodeEntry(
        edinet_code='E01824',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33575,
        fiscal_year_end='3月31日',
        submitter_name='太陽誘電株式会社',
        submitter_name_en='TAIYO YUDEN CO., LTD.',
        submitter_name_yomi='タイヨウユウデンカブシキガイシャ',
        address='中央区京橋２丁目７番１９号',
        industry='電気機器',
        sec_code='69760',
        corporate_number='3010501016202',
    ),
    'E01827': EdinetCodeEntry(
        edinet_code='E01827',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4909,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナカヨ',
        submitter_name_en='NAKAYO, INC.',
        submitter_name_yomi='カブシキガイシャ\u3000ナカヨ',
        address='前橋市総社町一丁目３番２号',
        industry='電気機器',
        sec_code=None,
        corporate_number='5070001005937',
    ),
    'E01828': EdinetCodeEntry(
        edinet_code='E01828',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10690,
        fiscal_year_end='3月31日',
        submitter_name='日本航空電子工業株式会社',
        submitter_name_en='Japan Aviation Electronics Industry, Limited',
        submitter_name_yomi='ニホンコウクウデンシコウギョウカブシキガイシャ',
        address='渋谷区道玄坂１丁目２１番１号',
        industry='電気機器',
        sec_code='68070',
        corporate_number='2011001017526',
    ),
    'E01830': EdinetCodeEntry(
        edinet_code='E01830',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ユニデンホールディングス株式会社',
        submitter_name_en='UNIDEN HOLDINGS CORPORATION',
        submitter_name_yomi='ユニデンホールディングスカブシキガイシャ',
        address='中央区日本橋室町２－３－１',
        industry='電気機器',
        sec_code=None,
        corporate_number='4010001059816',
    ),
    'E01831': EdinetCodeEntry(
        edinet_code='E01831',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5279,
        fiscal_year_end='3月31日',
        submitter_name='ＴＯＡ株式会社',
        submitter_name_en='TOA CORPORATION',
        submitter_name_yomi='ティーオーエーカブシキガイシャ',
        address='神戸市中央区港島中町七丁目２番１号',
        industry='電気機器',
        sec_code='68090',
        corporate_number='3140001005675',
    ),
    'E01832': EdinetCodeEntry(
        edinet_code='E01832',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=88,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リゾート＆メディカル',
        submitter_name_en='Resort & Medical Co., Ltd.',
        submitter_name_yomi='カブシキガイシャリゾートアンドメディカル',
        address='千代田区紀尾井町４番１号',
        industry='電気機器',
        sec_code=None,
        corporate_number='4010001141276',
    ),
    'E01833': EdinetCodeEntry(
        edinet_code='E01833',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=975,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンコーシヤ',
        submitter_name_en='SANKOSHA CORPORATION',
        submitter_name_yomi='カブシキガイシャサンコーシヤ',
        address='品川区大崎二丁目十一番一号',
        industry='電気機器',
        sec_code=None,
        corporate_number='3010701003801',
    ),
    'E01834': EdinetCodeEntry(
        edinet_code='E01834',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9641,
        fiscal_year_end='12月31日',
        submitter_name='ローランド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ローランドカブシキガイシャ',
        address='浜松市浜名区新都田一丁目６番４号',
        industry='その他製品',
        sec_code='79440',
        corporate_number='6080401010213',
    ),
    'E01839': EdinetCodeEntry(
        edinet_code='E01839',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7534,
        fiscal_year_end='2月末日',
        submitter_name='古野電気株式会社',
        submitter_name_en='FURUNO ELECTRIC CO., LTD.',
        submitter_name_yomi='フルノデンキカブシキガイシャ',
        address='西宮市芦原町９番５２号',
        industry='電気機器',
        sec_code='68140',
        corporate_number='5140001070263',
    ),
    'E01840': EdinetCodeEntry(
        edinet_code='E01840',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=25920,
        fiscal_year_end='3月31日',
        submitter_name='アルパイン株式会社',
        submitter_name_en='ALPINE ELECTRONICS, INC.',
        submitter_name_yomi='アルパインカブシキガイシャ',
        address='大田区雪谷大塚町１番７号',
        industry='電気機器',
        sec_code=None,
        corporate_number='5010701000739',
    ),
    'E01841': EdinetCodeEntry(
        edinet_code='E01841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22558,
        fiscal_year_end='3月31日',
        submitter_name='双葉電子工業株式会社',
        submitter_name_en='FUTABA CORPORATION',
        submitter_name_yomi='フタバデンシコウギョウカブシキガイシャ',
        address='茂原市大芝６２９番地',
        industry='電気機器',
        sec_code='69860',
        corporate_number='9040001059420',
    ),
    'E01842': EdinetCodeEntry(
        edinet_code='E01842',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2064,
        fiscal_year_end='3月31日',
        submitter_name='リオン株式会社',
        submitter_name_en='RION CO.,LTD.',
        submitter_name_yomi='リオンカブシキガイシャ',
        address='国分寺市東元町３丁目２０番４１号',
        industry='電気機器',
        sec_code='68230',
        corporate_number='1012401002696',
    ),
    'E01843': EdinetCodeEntry(
        edinet_code='E01843',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1052,
        fiscal_year_end='3月31日',
        submitter_name='テクニカル電子株式会社',
        submitter_name_en='TECHNICAL ELECTRON Co.,Ltd.',
        submitter_name_yomi='テクニカルデンシカブシキカイシャ',
        address='大田区大森西一丁目９番１２号',
        industry='電気機器',
        sec_code=None,
        corporate_number='5010801007238',
    ),
    'E01847': EdinetCodeEntry(
        edinet_code='E01847',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3317,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エヌエフホールディングス',
        submitter_name_en='NF HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャエヌエフホールディングス',
        address='横浜市港北区綱島東六丁目３番２０号',
        industry='電気機器',
        sec_code='68640',
        corporate_number='8020001019674',
    ),
    'E01848': EdinetCodeEntry(
        edinet_code='E01848',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4673,
        fiscal_year_end='3月31日',
        submitter_name='日本アンテナ株式会社',
        submitter_name_en='NIPPON ANTENNA CO.,LTD.',
        submitter_name_yomi='ニッポンアンテナ\u3000カブシキガイシャ',
        address='荒川区西尾久七丁目４９番８号',
        industry='電気機器',
        sec_code=None,
        corporate_number='4011501008048',
    ),
    'E01849': EdinetCodeEntry(
        edinet_code='E01849',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5388,
        fiscal_year_end='3月31日',
        submitter_name='アイホン株式会社',
        submitter_name_en='AIPHONE CO.,LTD',
        submitter_name_yomi='アイホンカブシキガイシャ',
        address='名古屋市中区新栄町一丁目１番\u3000明治安田生命名古屋ビル',
        industry='電気機器',
        sec_code='67180',
        corporate_number='9180001021408',
    ),
    'E01850': EdinetCodeEntry(
        edinet_code='E01850',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7081,
        fiscal_year_end='3月31日',
        submitter_name='アイコム株式会社',
        submitter_name_en='ICOM INCORPORATED',
        submitter_name_yomi='アイコムカブシキガイシャ',
        address='大阪市平野区加美鞍作一丁目６番１９号',
        industry='電気機器',
        sec_code='68200',
        corporate_number='1120001019349',
    ),
    'E01855': EdinetCodeEntry(
        edinet_code='E01855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1730,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北海電工',
        submitter_name_en='HOKKAIDENKO CORPORATION',
        submitter_name_yomi='カブシキガイシャホッカイデンコウ',
        address='札幌市白石区菊水２条１丁目８番２１号',
        industry='建設業',
        sec_code='18320',
        corporate_number='7430001021532',
    ),
    'E01856': EdinetCodeEntry(
        edinet_code='E01856',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6042,
        fiscal_year_end='5月20日',
        submitter_name='コーセル株式会社',
        submitter_name_en='COSEL CO.,LTD.',
        submitter_name_yomi='コーセルカブシキガイシャ',
        address='富山市上赤江町一丁目６番４３号',
        industry='電気機器',
        sec_code='69050',
        corporate_number='7230001000928',
    ),
    'E01857': EdinetCodeEntry(
        edinet_code='E01857',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2019,
        fiscal_year_end='3月31日',
        submitter_name='原田工業株式会社',
        submitter_name_en='HARADA INDUSTRY CO.,LTD.',
        submitter_name_yomi='ハラダコウギョウカブシキガイシャ',
        address='品川区南大井６－２６－２',
        industry='電気機器',
        sec_code='69040',
        corporate_number='9010701008191',
    ),
    'E01859': EdinetCodeEntry(
        edinet_code='E01859',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2708,
        fiscal_year_end='3月31日',
        submitter_name='大井電気株式会社',
        submitter_name_en='Oi Electric Co.,Ltd.',
        submitter_name_yomi='オオイデンキカブシキガイシャ',
        address='横浜市港北区菊名七丁目３番１６号',
        industry='電気機器',
        sec_code='68220',
        corporate_number='2020001019746',
    ),
    'E01860': EdinetCodeEntry(
        edinet_code='E01860',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1718,
        fiscal_year_end='3月31日',
        submitter_name='イーター電機工業株式会社',
        submitter_name_en='ETA ELECTRIC INDUSTRY CO., LTD.',
        submitter_name_yomi='イーターデンキコウギョウカブシキガイシャ',
        address='大田区本羽田二丁目１６番１０号',
        industry='電気機器',
        sec_code=None,
        corporate_number='7010801000777',
    ),
    'E01862': EdinetCodeEntry(
        edinet_code='E01862',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3306,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＩＭＡＧＩＣＡ\u3000ＧＲＯＵＰ',
        submitter_name_en='IMAGICA GROUP Inc.',
        submitter_name_yomi='カブシキガイシャイマジカグループ',
        address='港区海岸１－１４－２',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010701024964',
    ),
    'E01863': EdinetCodeEntry(
        edinet_code='E01863',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=31307,
        fiscal_year_end=None,
        submitter_name='船井電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フナイデンキカブシキガイシャ',
        address='大東市中垣内７丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2122001015871',
    ),
    'E01864': EdinetCodeEntry(
        edinet_code='E01864',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1748,
        fiscal_year_end='10月31日',
        submitter_name='株式会社多摩川ホールディングス',
        submitter_name_en='TAMAGAWA HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタマガワホールディングス',
        address='港区芝２ー２８ー８\u3000芝二丁目ビル１１階',
        industry='電気機器',
        sec_code='68380',
        corporate_number='2021001027482',
    ),
    'E01865': EdinetCodeEntry(
        edinet_code='E01865',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1501,
        fiscal_year_end='3月31日',
        submitter_name='本多通信工業株式会社',
        submitter_name_en='HONDA TSUSHIN KOGYO CO.,LTD.',
        submitter_name_yomi='ホンダツウシンコウギョウカブシキガイシャ',
        address='品川区北品川五丁目９番１１号\u3000大崎ＭＴビル',
        industry='電気機器',
        sec_code=None,
        corporate_number='4013201005408',
    ),
    'E01867': EdinetCodeEntry(
        edinet_code='E01867',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10019,
        fiscal_year_end='12月31日',
        submitter_name='アライドテレシスホールディングス株式会社',
        submitter_name_en='ALLIED TELESIS HOLDINGS K.K.',
        submitter_name_yomi='アライドテレシスホールディングスカブシキガイシャ',
        address='品川区西五反田七丁目２１番１１号',
        industry='電気機器',
        sec_code='68350',
        corporate_number='4010701012116',
    ),
    'E01870': EdinetCodeEntry(
        edinet_code='E01870',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4975,
        fiscal_year_end='3月31日',
        submitter_name='ｓａｎｔｅｃ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en='santec Holdings Corporation',
        submitter_name_yomi='サンテックホールディングスカブシキガイシャ',
        address='小牧市大字大草字年上坂５８２３番地',
        industry='電気機器',
        sec_code='67770',
        corporate_number='9180001075866',
    ),
    'E01871': EdinetCodeEntry(
        edinet_code='E01871',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6764,
        fiscal_year_end='3月31日',
        submitter_name='富士通コンポーネント株式会社',
        submitter_name_en='FUJITSU COMPONENT LIMITED',
        submitter_name_yomi='フジツウコンポーネントカブシキガイシャ',
        address='品川区東品川四丁目１２番４号',
        industry='電気機器',
        sec_code=None,
        corporate_number='4010701013411',
    ),
    'E01873': EdinetCodeEntry(
        edinet_code='E01873',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=53204,
        fiscal_year_end='3月31日',
        submitter_name='セイコーエプソン株式会社',
        submitter_name_en='SEIKO EPSON CORPORATION',
        submitter_name_yomi='セイコーエプソンカブシキガイシャ',
        address='新宿区新宿四丁目１番６号',
        industry='電気機器',
        sec_code='67240',
        corporate_number='4011101010841',
    ),
    'E01874': EdinetCodeEntry(
        edinet_code='E01874',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10836,
        fiscal_year_end='3月31日',
        submitter_name='サクサ株式会社',
        submitter_name_en='SAXA, Inc.',
        submitter_name_yomi='サクサカブシキカイシャ',
        address='港区三田一丁目４番２８号\u3000三田国際ビル',
        industry='電気機器',
        sec_code='66750',
        corporate_number='2010401060020',
    ),
    'E01875': EdinetCodeEntry(
        edinet_code='E01875',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2259,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メディアリンクス',
        submitter_name_en='MEDIA LINKS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャメディアリンクス',
        address='川崎市幸区堀川町５８０－１６',
        industry='電気機器',
        sec_code='66590',
        corporate_number='4020001067149',
    ),
    'E01876': EdinetCodeEntry(
        edinet_code='E01876',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10968,
        fiscal_year_end='12月31日',
        submitter_name='Ｉ‐ＰＥＸ株式会社',
        submitter_name_en='I-PEX Inc.',
        submitter_name_yomi='アイペックスカブシキガイシャ',
        address='京都市伏見区桃山町根来１２番地４',
        industry='電気機器',
        sec_code=None,
        corporate_number='4130001014899',
    ),
    'E01878': EdinetCodeEntry(
        edinet_code='E01878',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=43401,
        fiscal_year_end='3月31日',
        submitter_name='横河電機株式会社',
        submitter_name_en='YOKOGAWA ELECTRIC CORPORATION',
        submitter_name_yomi='ヨコガワデンキカブシキガイシャ',
        address='武蔵野市中町２－９－３２',
        industry='電気機器',
        sec_code='68410',
        corporate_number='4012401012569',
    ),
    'E01879': EdinetCodeEntry(
        edinet_code='E01879',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10522,
        fiscal_year_end='3月31日',
        submitter_name='アズビル株式会社',
        submitter_name_en='Azbil Corporation',
        submitter_name_yomi='アズビルカブシキガイシャ',
        address='千代田区丸の内二丁目７番３号',
        industry='電気機器',
        sec_code='68450',
        corporate_number='9010001096367',
    ),
    'E01880': EdinetCodeEntry(
        edinet_code='E01880',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30514,
        fiscal_year_end='3月31日',
        submitter_name='スタンレー電気株式会社',
        submitter_name_en='Stanley Electric Co.,Ltd.',
        submitter_name_yomi='スタンレーデンキカブシキガイシャ',
        address='目黒区中目黒２丁目９番１３号',
        industry='電気機器',
        sec_code='69230',
        corporate_number='2013201003041',
    ),
    'E01884': EdinetCodeEntry(
        edinet_code='E01884',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=39970,
        fiscal_year_end='3月31日',
        submitter_name='東芝テック株式会社',
        submitter_name_en='TOSHIBA TEC CORPORATION',
        submitter_name_yomi='トウシバテックカブシキガイシャ',
        address='品川区大崎一丁目１１番１号',
        industry='電気機器',
        sec_code='65880',
        corporate_number='8010701016022',
    ),
    'E01885': EdinetCodeEntry(
        edinet_code='E01885',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1080,
        fiscal_year_end='3月31日',
        submitter_name='澤藤電機株式会社',
        submitter_name_en='SAWAFUJI ELECTRIC CO.,LTD.',
        submitter_name_yomi='サワフジデンキカブシキガイシャ',
        address='太田市新田早川町３番地',
        industry='電気機器',
        sec_code='69010',
        corporate_number='9070001022508',
    ),
    'E01886': EdinetCodeEntry(
        edinet_code='E01886',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8640,
        fiscal_year_end='3月31日',
        submitter_name='岩崎電気株式会社',
        submitter_name_en='IWASAKI ELECTRIC CO., LTD.',
        submitter_name_yomi='イワサキデンキカブシキガイシャ',
        address='中央区東日本橋一丁目１番７号',
        industry='電気機器',
        sec_code=None,
        corporate_number='1010001134761',
    ),
    'E01887': EdinetCodeEntry(
        edinet_code='E01887',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17823,
        fiscal_year_end='3月31日',
        submitter_name='新電元工業株式会社',
        submitter_name_en='Shindengen Electric Manufacturing Co.,Ltd.',
        submitter_name_yomi='シンデンゲンコウギョウカブシキガイシャ',
        address='千代田区大手町２－２－１',
        industry='電気機器',
        sec_code='68440',
        corporate_number='5010001008697',
    ),
    'E01888': EdinetCodeEntry(
        edinet_code='E01888',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26783,
        fiscal_year_end='3月31日',
        submitter_name='日東電工株式会社',
        submitter_name_en='NITTO DENKO CORPORATION',
        submitter_name_yomi='ニットウデンコウカブシキカイシャ',
        address='茨木市下穂積１丁目１番２号',
        industry='化学',
        sec_code='69880',
        corporate_number='2120901001628',
    ),
    'E01891': EdinetCodeEntry(
        edinet_code='E01891',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2955,
        fiscal_year_end='3月31日',
        submitter_name='大黒屋ホールディングス株式会社',
        submitter_name_en='Daikokuya Holdings Co.,LTD.',
        submitter_name_yomi='ダイコクヤホールディングスカブシキガイシャ',
        address='港区港南四丁目１番８号',
        industry='電気機器',
        sec_code='69930',
        corporate_number='1010401034636',
    ),
    'E01892': EdinetCodeEntry(
        edinet_code='E01892',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=187457,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デンソー',
        submitter_name_en='DENSO CORPORATION',
        submitter_name_yomi='カブシキガイシャデンソー',
        address='刈谷市昭和町１丁目１番地',
        industry='輸送用機器',
        sec_code='69020',
        corporate_number='9180301014251',
    ),
    'E01896': EdinetCodeEntry(
        edinet_code='E01896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='ＦＤＫ株式会社',
        submitter_name_en='FDK CORPORATION',
        submitter_name_yomi='エフディーケイカブシキガイシャ',
        address='港区港南一丁目６番４１号',
        industry='電気機器',
        sec_code='69550',
        corporate_number='3010401026846',
    ),
    'E01897': EdinetCodeEntry(
        edinet_code='E01897',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8774,
        fiscal_year_end='3月31日',
        submitter_name='電気興業株式会社',
        submitter_name_en='DKK Co.,Ltd.',
        submitter_name_yomi='デンキコウギョウカブシキカイシャ',
        address='東京都江東区豊洲五丁目５番１３号',
        industry='電気機器',
        sec_code='67060',
        corporate_number='4010001008723',
    ),
    'E01898': EdinetCodeEntry(
        edinet_code='E01898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22856,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東海理化電機製作所',
        submitter_name_en='TOKAI RIKA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウカイリカデンキセイサクショ',
        address='丹羽郡大口町豊田三丁目２６０番地',
        industry='輸送用機器',
        sec_code='69950',
        corporate_number='5180001081083',
    ),
    'E01899': EdinetCodeEntry(
        edinet_code='E01899',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5001,
        fiscal_year_end='3月31日',
        submitter_name='株式会社指月電機製作所',
        submitter_name_en='SHIZUKI ELECTRIC COMPANY INC.',
        submitter_name_yomi='カブシキガイシャシヅキデンキセイサクショ',
        address='西宮市大社町１０番４５号',
        industry='電気機器',
        sec_code='69940',
        corporate_number='9140001069021',
    ),
    'E01901': EdinetCodeEntry(
        edinet_code='E01901',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12011,
        fiscal_year_end='12月31日',
        submitter_name='株式会社堀場製作所',
        submitter_name_en='HORIBA, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ホリバセイサクショ',
        address='京都市南区吉祥院宮の東町２番地',
        industry='電気機器',
        sec_code='68560',
        corporate_number='1130001011676',
    ),
    'E01902': EdinetCodeEntry(
        edinet_code='E01902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6033,
        fiscal_year_end='3月31日',
        submitter_name='ＫＯＡ株式会社',
        submitter_name_en='KOA CORPORATION',
        submitter_name_yomi='コーアカブシキガイシャ',
        address='伊那市荒井３６７２番地（上記は登記上の本店所在地であり、実際の業務は下記の場所で行っております）長野県上伊那郡箕輪町大字中箕輪１４０１６番地',
        industry='電気機器',
        sec_code='69990',
        corporate_number='1100001020696',
    ),
    'E01903': EdinetCodeEntry(
        edinet_code='E01903',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7544,
        fiscal_year_end='3月31日',
        submitter_name='日本光電工業株式会社',
        submitter_name_en='NIHON KOHDEN CORPORATION',
        submitter_name_yomi='ニホンコウデンコウギョウカブシキガイシャ',
        address='新宿区西落合一丁目３１番４号',
        industry='電気機器',
        sec_code='68490',
        corporate_number='2011101016254',
    ),
    'E01904': EdinetCodeEntry(
        edinet_code='E01904',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14286,
        fiscal_year_end='3月31日',
        submitter_name='ニチコン株式会社',
        submitter_name_en='nichicon corporation',
        submitter_name_yomi='ニチコンカブシキガイシャ',
        address='京都市中京区烏丸通御池上る二条殿町５５１番地',
        industry='電気機器',
        sec_code='69960',
        corporate_number='2130001022029',
    ),
    'E01905': EdinetCodeEntry(
        edinet_code='E01905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21394,
        fiscal_year_end='3月31日',
        submitter_name='日本電子株式会社',
        submitter_name_en='JEOL Ltd.',
        submitter_name_yomi='ニホンデンシカブシキガイシャ',
        address='昭島市武蔵野三丁目１番２号',
        industry='電気機器',
        sec_code='69510',
        corporate_number='9012801002438',
    ),
    'E01906': EdinetCodeEntry(
        edinet_code='E01906',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=724,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本抵抗器製作所',
        submitter_name_en='JAPAN RESISTOR MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャニホンテイコウキセイサクショ',
        address='南砺市北野２３１５番地',
        industry='電気機器',
        sec_code='69770',
        corporate_number='9230001008820',
    ),
    'E01907': EdinetCodeEntry(
        edinet_code='E01907',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2509,
        fiscal_year_end='3月31日',
        submitter_name='日本タングステン株式会社',
        submitter_name_en='Nippon Tungsten Co.,Ltd.',
        submitter_name_yomi='ニッポンタングステンカブシキガイシャ',
        address='福岡市博多区美野島一丁目２番８号',
        industry='電気機器',
        sec_code='69980',
        corporate_number='7290001015268',
    ),
    'E01909': EdinetCodeEntry(
        edinet_code='E01909',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11016,
        fiscal_year_end='3月31日',
        submitter_name='ＣＫＤ株式会社',
        submitter_name_en='CKD Corporation',
        submitter_name_yomi='シーケーディカブシキガイシャ',
        address='小牧市応時二丁目２５０番地',
        industry='機械',
        sec_code='64070',
        corporate_number='6180001075968',
    ),
    'E01912': EdinetCodeEntry(
        edinet_code='E01912',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1048,
        fiscal_year_end='3月31日',
        submitter_name='森尾電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モリオデンキカブシキガイシャ',
        address='葛飾区立石４－３４－１',
        industry='電気機器',
        sec_code='66470',
        corporate_number='5011801004902',
    ),
    'E01913': EdinetCodeEntry(
        edinet_code='E01913',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21741,
        fiscal_year_end='12月31日',
        submitter_name='サンデン株式会社',
        submitter_name_en='SANDEN CORPORATION',
        submitter_name_yomi='サンデンカブシキガイシャ',
        address='伊勢崎市寿町２０番地',
        industry='機械',
        sec_code='64440',
        corporate_number='5070001013386',
    ),
    'E01914': EdinetCodeEntry(
        edinet_code='E01914',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=69444,
        fiscal_year_end='3月31日',
        submitter_name='株式会社村田製作所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャムラタセイサクショ',
        address='長岡京市東神足１丁目１０番１号',
        industry='電気機器',
        sec_code='69810',
        corporate_number='4130001030475',
    ),
    'E01916': EdinetCodeEntry(
        edinet_code='E01916',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=658,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リード',
        submitter_name_en='The Lead Co., Inc.',
        submitter_name_yomi='カブシキガイシャリード',
        address='熊谷市弥藤吾５７８番地',
        industry='輸送用機器',
        sec_code='69820',
        corporate_number='9030001085467',
    ),
    'E01917': EdinetCodeEntry(
        edinet_code='E01917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1640,
        fiscal_year_end='3月31日',
        submitter_name='古河電池株式会社',
        submitter_name_en='The Furukawa Battery Co.,Ltd.',
        submitter_name_yomi='フルカワデンチカブシキガイシャ',
        address='横浜市保土ヶ谷区星川二丁目４番１号',
        industry='電気機器',
        sec_code='69370',
        corporate_number='7020001010527',
    ),
    'E01918': EdinetCodeEntry(
        edinet_code='E01918',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=240,
        fiscal_year_end='3月31日',
        submitter_name='日電工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニチデンコウギョウカブシキガイシャ',
        address='藤沢市小塚１２６番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='9021001001704',
    ),
    'E01920': EdinetCodeEntry(
        edinet_code='E01920',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24206,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マキタ',
        submitter_name_en='Makita Corporation',
        submitter_name_yomi='カブシキガイシャマキタ',
        address='安城市住吉町３丁目１１番８号',
        industry='機械',
        sec_code='65860',
        corporate_number='2180301013342',
    ),
    'E01921': EdinetCodeEntry(
        edinet_code='E01921',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1723,
        fiscal_year_end='12月31日',
        submitter_name='株式会社共和電業',
        submitter_name_en='KYOWA ELECTRONIC INSTRUMENTS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウワデンギョウ',
        address='調布市調布ヶ丘３丁目５番地１',
        industry='電気機器',
        sec_code='68530',
        corporate_number='6012401007567',
    ),
    'E01925': EdinetCodeEntry(
        edinet_code='E01925',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='エルナー株式会社',
        submitter_name_en='ELNA CO.,LTD.',
        submitter_name_yomi='エルナーカブシキガイシャ',
        address='中央区京橋２丁目７番１９号',
        industry='電気機器',
        sec_code=None,
        corporate_number='3020001038480',
    ),
    'E01926': EdinetCodeEntry(
        edinet_code='E01926',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5452,
        fiscal_year_end='3月31日',
        submitter_name='日本ケミコン株式会社',
        submitter_name_en='NIPPON CHEMI-CON CORPORATION',
        submitter_name_yomi='ニッポンケミコンカブシキガイシャ',
        address='品川区大崎五丁目６番４号',
        industry='電気機器',
        sec_code='69970',
        corporate_number='7010701015586',
    ),
    'E01928': EdinetCodeEntry(
        edinet_code='E01928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2295,
        fiscal_year_end='3月31日',
        submitter_name='岡谷電機産業株式会社',
        submitter_name_en='OKAYA ELECTRIC INDUSTRIES CO.,LTD.',
        submitter_name_yomi='オカヤデンキサンギョウカブシキガイシャ',
        address='世田谷区等々力六丁目１６番９号',
        industry='電気機器',
        sec_code='69260',
        corporate_number='1010901002423',
    ),
    'E01929': EdinetCodeEntry(
        edinet_code='E01929',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19556,
        fiscal_year_end='3月31日',
        submitter_name='ウシオ電機株式会社',
        submitter_name_en='USHIO INC.',
        submitter_name_yomi='ウシオデンキカブシキガイシャ',
        address='千代田区丸の内一丁目６番５号',
        industry='電気機器',
        sec_code='69250',
        corporate_number='1010001008651',
    ),
    'E01930': EdinetCodeEntry(
        edinet_code='E01930',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2658,
        fiscal_year_end='3月31日',
        submitter_name='西部電機株式会社',
        submitter_name_en='Seibu Electric & Machinery Co., Ltd.',
        submitter_name_yomi='セイブデンキカブシキガイシャ',
        address='古賀市駅東三丁目３番１号',
        industry='機械',
        sec_code='61440',
        corporate_number='2290001036343',
    ),
    'E01932': EdinetCodeEntry(
        edinet_code='E01932',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3500,
        fiscal_year_end='3月31日',
        submitter_name='ティアック株式会社',
        submitter_name_en='TEAC CORPORATION',
        submitter_name_yomi='ティアックカブシキガイシャ',
        address='多摩市落合一丁目４７番地',
        industry='電気機器',
        sec_code='68030',
        corporate_number='7013401005312',
    ),
    'E01933': EdinetCodeEntry(
        edinet_code='E01933',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2469,
        fiscal_year_end='3月31日',
        submitter_name='松尾電機株式会社',
        submitter_name_en='MATSUO ELECTRIC CO.,LTD.',
        submitter_name_yomi='マツオデンキカブシキガイシャ',
        address='豊中市千成町３丁目５番３号',
        industry='電気機器',
        sec_code='69690',
        corporate_number='6120901025697',
    ),
    'E01934': EdinetCodeEntry(
        edinet_code='E01934',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2234,
        fiscal_year_end='3月31日',
        submitter_name='日本インター株式会社',
        submitter_name_en='Nihon Inter Electronics Corporation',
        submitter_name_yomi='ニホンインターカブシキガイシャ',
        address='秦野市曽屋１２０４番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='9021001022733',
    ),
    'E01935': EdinetCodeEntry(
        edinet_code='E01935',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=48592,
        fiscal_year_end='3月31日',
        submitter_name='カシオ計算機株式会社',
        submitter_name_en='CASIO COMPUTER CO.,LTD.',
        submitter_name_yomi='カシオケイサンキカブシキガイシャ',
        address='渋谷区本町１－６－２',
        industry='電気機器',
        sec_code='69520',
        corporate_number='4011001030015',
    ),
    'E01937': EdinetCodeEntry(
        edinet_code='E01937',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=499,
        fiscal_year_end=None,
        submitter_name='釜屋電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カマヤデンキカブシキガイシャ',
        address='大和市中央６ー１ー６\u3000ＰＳＡビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1021001045205',
    ),
    'E01939': EdinetCodeEntry(
        edinet_code='E01939',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9404,
        fiscal_year_end='3月31日',
        submitter_name='ヒロセ電機株式会社',
        submitter_name_en='HIROSE ELECTRIC CO.,LTD.',
        submitter_name_yomi='ヒロセデンキカブシキガイシャ',
        address='横浜市都筑区中川中央２－６－３',
        industry='電気機器',
        sec_code='68060',
        corporate_number='6010701008418',
    ),
    'E01940': EdinetCodeEntry(
        edinet_code='E01940',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=503,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中央製作所',
        submitter_name_en='Chuo Seisakusho,Ltd.',
        submitter_name_yomi='カブシキガイシャチュウオウセイサクショ',
        address='名古屋市瑞穂区内浜町２４番１号',
        industry='電気機器',
        sec_code='68460',
        corporate_number='8180001010551',
    ),
    'E01942': EdinetCodeEntry(
        edinet_code='E01942',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノ・セブン',
        submitter_name_en='TECHNOL SEVEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャテクノセブン',
        address='世田谷区池尻３－１－３',
        industry='電気機器',
        sec_code=None,
        corporate_number='4010001134189',
    ),
    'E01944': EdinetCodeEntry(
        edinet_code='E01944',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20704,
        fiscal_year_end='12月31日',
        submitter_name='マブチモーター株式会社',
        submitter_name_en='MABUCHI MOTOR CO., LTD.',
        submitter_name_yomi='マブチモーターカブシキガイシャ',
        address='松戸市松飛台４３０',
        industry='電気機器',
        sec_code='65920',
        corporate_number='2040001036954',
    ),
    'E01946': EdinetCodeEntry(
        edinet_code='E01946',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=69014,
        fiscal_year_end='3月31日',
        submitter_name='ファナック株式会社',
        submitter_name_en='FANUC CORPORATION',
        submitter_name_yomi='ファナック\u3000カブシキガイシャ',
        address='南都留郡忍野村忍草字古馬場３５８０番地',
        industry='電気機器',
        sec_code='69540',
        corporate_number='3090001010053',
    ),
    'E01947': EdinetCodeEntry(
        edinet_code='E01947',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12203,
        fiscal_year_end='3月末日',
        submitter_name='マクセル株式会社',
        submitter_name_en='Maxell, Ltd.',
        submitter_name_yomi='マクセルカブシキガイシャ',
        address='乙訓郡大山崎町大山崎小泉１番地',
        industry='電気機器',
        sec_code='68100',
        corporate_number='9120901001761',
    ),
    'E01950': EdinetCodeEntry(
        edinet_code='E01950',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32363,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アドバンテスト',
        submitter_name_en='ADVANTEST CORPORATION',
        submitter_name_yomi='カブシキガイシャアドバンテスト',
        address='千代田区丸の内一丁目６番２号',
        industry='電気機器',
        sec_code='68570',
        corporate_number='9011601000379',
    ),
    'E01951': EdinetCodeEntry(
        edinet_code='E01951',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10056,
        fiscal_year_end='3月31日',
        submitter_name='ＩＤＥＣ株式会社',
        submitter_name_en='IDEC CORPORATION',
        submitter_name_yomi='アイデックカブシキガイシャ',
        address='大阪市淀川区西宮原２丁目６番６４号',
        industry='電気機器',
        sec_code='66520',
        corporate_number='6120001053789',
    ),
    'E01952': EdinetCodeEntry(
        edinet_code='E01952',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19344,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大真空',
        submitter_name_en='DAISHINKU CORP.',
        submitter_name_yomi='カブシキガイシャダイシンクウ',
        address='加古川市野口町水足１７９番地の６',
        industry='電気機器',
        sec_code='69620',
        corporate_number='7140001043110',
    ),
    'E01953': EdinetCodeEntry(
        edinet_code='E01953',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=86969,
        fiscal_year_end='3月31日',
        submitter_name='ローム株式会社',
        submitter_name_en='ROHM COMPANY LIMITED',
        submitter_name_yomi='ロームカブシキガイシャ',
        address='京都市右京区西院溝崎町２１番地',
        industry='電気機器',
        sec_code='69630',
        corporate_number='9130001000052',
    ),
    'E01954': EdinetCodeEntry(
        edinet_code='E01954',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3779,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンコー',
        submitter_name_en='SANKO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンコー',
        address='塩尻市広丘野村９５９番地',
        industry='電気機器',
        sec_code='69640',
        corporate_number='8100001015608',
    ),
    'E01955': EdinetCodeEntry(
        edinet_code='E01955',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=34964,
        fiscal_year_end='9月30日',
        submitter_name='浜松ホトニクス株式会社',
        submitter_name_en='HAMAMATSU PHOTONICS K.K.',
        submitter_name_yomi='ハママツホトニクスカブシキガイシャ',
        address='浜松市東区市野町１１２６番地の１',
        industry='電気機器',
        sec_code='69650',
        corporate_number='2080401004193',
    ),
    'E01956': EdinetCodeEntry(
        edinet_code='E01956',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=47398,
        fiscal_year_end='3月31日',
        submitter_name='コナミグループ株式会社',
        submitter_name_en='KONAMI GROUP CORPORATION',
        submitter_name_yomi='コナミグループカブシキカイシャ',
        address='中央区銀座１丁目１１番１号',
        industry='情報・通信業',
        sec_code='97660',
        corporate_number='9010401070789',
    ),
    'E01957': EdinetCodeEntry(
        edinet_code='E01957',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='新光電気工業株式会社',
        submitter_name_en='SHINKO ELECTRIC INDUSTRIES CO., LTD.',
        submitter_name_yomi='シンコウデンキコウギョウカブシキガイシャ',
        address='長野市小島田町８０番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='3100001001364',
    ),
    'E01959': EdinetCodeEntry(
        edinet_code='E01959',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24096,
        fiscal_year_end='3月31日',
        submitter_name='日本シイエムケイ株式会社',
        submitter_name_en='CMK CORPORATION',
        submitter_name_yomi='ニッポンシイエムケイカブシキガイシャ',
        address='新宿区西新宿六丁目５番１号',
        industry='電気機器',
        sec_code='69580',
        corporate_number='6011101016382',
    ),
    'E01960': EdinetCodeEntry(
        edinet_code='E01960',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2144,
        fiscal_year_end='3月31日',
        submitter_name='株式会社芝浦電子',
        submitter_name_en='SHIBAURA ELECTRONICS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャシバウラデンシ',
        address='さいたま市中央区上落合二丁目１番２４号',
        industry='電気機器',
        sec_code=None,
        corporate_number='8030001003917',
    ),
    'E01961': EdinetCodeEntry(
        edinet_code='E01961',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=9907,
        fiscal_year_end='12月31日',
        submitter_name='大和冷機工業株式会社',
        submitter_name_en='DAIWA   INDUSTRIES   LTD.',
        submitter_name_yomi='ダイワレイキコウギョウカブシキガイシャ',
        address='大阪市天王寺区小橋町３番１３号',
        industry='機械',
        sec_code='64590',
        corporate_number='9120001083783',
    ),
    'E01964': EdinetCodeEntry(
        edinet_code='E01964',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3155,
        fiscal_year_end=None,
        submitter_name='パナソニック\u3000デバイスＳＵＮＸ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パナソニックデバイスサンクスカブシキガイシャ',
        address='春日井市牛山町２４３１番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001075227',
    ),
    'E01965': EdinetCodeEntry(
        edinet_code='E01965',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1538,
        fiscal_year_end='12月31日',
        submitter_name='ローヤル電機株式会社',
        submitter_name_en='ROYAL ELECTRIC CO., LTD.',
        submitter_name_yomi='ローヤルデンキカブシキガイシャ',
        address='港区高輪二丁目１６番３７号',
        industry='電気機器',
        sec_code=None,
        corporate_number='6210001008305',
    ),
    'E01966': EdinetCodeEntry(
        edinet_code='E01966',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10117,
        fiscal_year_end='3月31日',
        submitter_name='株式会社図研',
        submitter_name_en='ZUKEN  INC.',
        submitter_name_yomi='カブシキガイシャズケン',
        address='横浜市都筑区荏田東２－２５－１',
        industry='電気機器',
        sec_code='69470',
        corporate_number='2020001008807',
    ),
    'E01967': EdinetCodeEntry(
        edinet_code='E01967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30637,
        fiscal_year_end='3月20日',
        submitter_name='株式会社キーエンス',
        submitter_name_en='KEYENCE CORPORATION',
        submitter_name_yomi='カブシキガイシャキーエンス',
        address='大阪市東淀川区東中島１－３－１４',
        industry='電気機器',
        sec_code='68610',
        corporate_number='4120001051530',
    ),
    'E01968': EdinetCodeEntry(
        edinet_code='E01968',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5895,
        fiscal_year_end='3月31日',
        submitter_name='日本アビオニクス株式会社',
        submitter_name_en='Nippon Avionics Co., Ltd.',
        submitter_name_yomi='ニッポンアビオニクスカブシキガイシャ',
        address='横浜市瀬谷区本郷二丁目２８番２',
        industry='電気機器',
        sec_code='69460',
        corporate_number='5010701017733',
    ),
    'E01969': EdinetCodeEntry(
        edinet_code='E01969',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8457,
        fiscal_year_end='3月31日',
        submitter_name='富士通フロンテック株式会社',
        submitter_name_en='FUJITSU FRONTECH LIMITED',
        submitter_name_yomi='フジツウフロンテックカブシキガイシャ',
        address='稲城市矢野口１７７６番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='1013401002091',
    ),
    'E01970': EdinetCodeEntry(
        edinet_code='E01970',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9214,
        fiscal_year_end='9月30日',
        submitter_name='ＫＩホールディングス株式会社',
        submitter_name_en='KI HOLDINGS CO.,LTD.',
        submitter_name_yomi='ケイアイホールディングスカブシキカイシャ',
        address='横浜市戸塚区前田町１００番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='4020001007328',
    ),
    'E01971': EdinetCodeEntry(
        edinet_code='E01971',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13519,
        fiscal_year_end='12月31日',
        submitter_name='スミダコーポレーション株式会社',
        submitter_name_en='SUMIDA CORPORATION',
        submitter_name_yomi='スミダコーポレーションカブシキガイシャ',
        address='東京都中央区入船三丁目７番２号\u3000ＫＤＸ銀座イーストビル７階',
        industry='電気機器',
        sec_code='68170',
        corporate_number='8010001064093',
    ),
    'E01972': EdinetCodeEntry(
        edinet_code='E01972',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=80,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイレックス',
        submitter_name_en='AIREX INC.',
        submitter_name_yomi='カブシキガイシャアイレックス',
        address='世田谷区池尻３－１－３',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5010001126664',
    ),
    'E01973': EdinetCodeEntry(
        edinet_code='E01973',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13360,
        fiscal_year_end='12月31日',
        submitter_name='ヤマハモーターロボティクスホールディングス株式会社',
        submitter_name_en='Yamaha Motor Robotics Holdings Co., Ltd.',
        submitter_name_yomi='ヤマハモーターロボティクスホールディングスカブシキガイシャ',
        address='武蔵村山市伊奈平２丁目５１番地の１',
        industry='機械',
        sec_code=None,
        corporate_number='3012801002889',
    ),
    'E01974': EdinetCodeEntry(
        edinet_code='E01974',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=951,
        fiscal_year_end='3月31日',
        submitter_name='ＮＫＫスイッチズ株式会社',
        submitter_name_en='NKK SWITCHES.CO.,LTD.',
        submitter_name_yomi='エヌケーケースイッチズカブシキガイシャ',
        address='川崎市高津区宇奈根７１５－１',
        industry='電気機器',
        sec_code='69430',
        corporate_number='1020001066839',
    ),
    'E01975': EdinetCodeEntry(
        edinet_code='E01975',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=87784,
        fiscal_year_end='3月31日',
        submitter_name='ニデック株式会社',
        submitter_name_en='NIDEC CORPORATION',
        submitter_name_yomi='ニデックカブシキガイシャ',
        address='京都市南区久世殿城町３３８番地',
        industry='電気機器',
        sec_code='65940',
        corporate_number='9130001002387',
    ),
    'E01977': EdinetCodeEntry(
        edinet_code='E01977',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1062,
        fiscal_year_end='3月31日',
        submitter_name='ミナトホールディングス株式会社',
        submitter_name_en='MINATO HOLDINGS  INC.',
        submitter_name_yomi='ミナトホールディングスカブシキガイシャ',
        address='港区新橋４丁目２１番３号\u3000新橋東急ビル',
        industry='電気機器',
        sec_code='68620',
        corporate_number='9020001009369',
    ),
    'E01978': EdinetCodeEntry(
        edinet_code='E01978',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2065,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソフィアホールディングス',
        submitter_name_en='SOPHIA  HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャソフィアホールディングス',
        address='港区海岸一丁目１５番１号',
        industry='情報・通信業',
        sec_code='69420',
        corporate_number='9011101054751',
    ),
    'E01979': EdinetCodeEntry(
        edinet_code='E01979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10084,
        fiscal_year_end='3月31日',
        submitter_name='山一電機株式会社',
        submitter_name_en='YAMAICHI ELECTRONICS CO.,LTD.',
        submitter_name_yomi='ヤマイチデンキカブシキガイシャ',
        address='大田区南蒲田二丁目１６番２号',
        industry='電気機器',
        sec_code='69410',
        corporate_number='4010801012065',
    ),
    'E01981': EdinetCodeEntry(
        edinet_code='E01981',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6884,
        fiscal_year_end='3月31日',
        submitter_name='ＮＩＴＴＯＫＵ株式会社',
        submitter_name_en='NITTOKU CO., LTD.',
        submitter_name_yomi='ニットクカブシキガイシャ',
        address='さいたま市大宮区東町二丁目２９２番地１',
        industry='機械',
        sec_code='61450',
        corporate_number='9030001006415',
    ),
    'E01983': EdinetCodeEntry(
        edinet_code='E01983',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4256,
        fiscal_year_end='12月31日',
        submitter_name='双信電機株式会社',
        submitter_name_en='SOSHIN ELECTRIC CO., LTD.',
        submitter_name_yomi='ソウシンデンキカブシキガイシャ',
        address='佐久市長土呂８００番地３８',
        industry='電気機器',
        sec_code=None,
        corporate_number='1100001008031',
    ),
    'E01984': EdinetCodeEntry(
        edinet_code='E01984',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3648,
        fiscal_year_end='12月31日',
        submitter_name='星和電機株式会社',
        submitter_name_en='SEIWA ELECTRIC MFG. CO., LTD.',
        submitter_name_yomi='セイワデンキカブシキガイシャ',
        address='城陽市寺田新池３６番地',
        industry='電気機器',
        sec_code='67480',
        corporate_number='1130001038463',
    ),
    'E01985': EdinetCodeEntry(
        edinet_code='E01985',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9078,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本デジタル研究所',
        submitter_name_en='Japan Digital Laboratory Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニホンデジタルケンキュウジョ',
        address='江東区新砂一丁目２番３号',
        industry='電気機器',
        sec_code=None,
        corporate_number='2010601025145',
    ),
    'E01986': EdinetCodeEntry(
        edinet_code='E01986',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5155,
        fiscal_year_end='3月31日',
        submitter_name='株式会社遠藤照明',
        submitter_name_en='ENDO Lighting Corporation',
        submitter_name_yomi='カブシキガイシャエンドウショウメイ',
        address='大阪市中央区本町一丁目６番１９号',
        industry='電気機器',
        sec_code='69320',
        corporate_number='3120001041581',
    ),
    'E01987': EdinetCodeEntry(
        edinet_code='E01987',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='伊豆シャボテンリゾート株式会社',
        submitter_name_en='Izu Shaboten Resort Co.,Ltd',
        submitter_name_yomi='イズシャボテンリゾートカブシキガイシャ',
        address='港区南青山７－８－４',
        industry='サービス業',
        sec_code='68190',
        corporate_number='2010401089522',
    ),
    'E01988': EdinetCodeEntry(
        edinet_code='E01988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10994,
        fiscal_year_end='12月31日',
        submitter_name='日本セラミック株式会社',
        submitter_name_en='NIPPON CERAMIC CO.,LTD.',
        submitter_name_yomi='ニホンセラミックカブシキガイシャ',
        address='鳥取市広岡１７６番地１７',
        industry='電気機器',
        sec_code='69290',
        corporate_number='2270001000573',
    ),
    'E01989': EdinetCodeEntry(
        edinet_code='E01989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4749,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エノモト',
        submitter_name_en='ENOMOTO CO.,LTD',
        submitter_name_yomi='カブシキガイシャエノモト',
        address='上野原市上野原８１５４番地１９',
        industry='電気機器',
        sec_code='69280',
        corporate_number='5090001008079',
    ),
    'E01991': EdinetCodeEntry(
        edinet_code='E01991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=931,
        fiscal_year_end='6月30日',
        submitter_name='レーザーテック株式会社',
        submitter_name_en='Lasertec corporation',
        submitter_name_yomi='レーザーテックカブシキガイシャ',
        address='横浜市港北区新横浜２丁目１０番地１',
        industry='電気機器',
        sec_code='69200',
        corporate_number='1020001022180',
    ),
    'E01992': EdinetCodeEntry(
        edinet_code='E01992',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1617,
        fiscal_year_end='3月31日',
        submitter_name='ケル株式会社',
        submitter_name_en='KEL CORPORATION',
        submitter_name_yomi='ケルカブシキガイシャ',
        address='多摩市永山６丁目１７番地７',
        industry='電気機器',
        sec_code='69190',
        corporate_number='6013401001080',
    ),
    'E01993': EdinetCodeEntry(
        edinet_code='E01993',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2354,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アバールデータ',
        submitter_name_en='AVALDATA CORPORATION',
        submitter_name_yomi='カブシキガイシャアバールデータ',
        address='町田市旭町一丁目２５番１０号',
        industry='電気機器',
        sec_code='69180',
        corporate_number='6012301000127',
    ),
    'E01994': EdinetCodeEntry(
        edinet_code='E01994',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3588,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アイ・オー・データ機器',
        submitter_name_en='I-O DATA DEVICE, INC.',
        submitter_name_yomi='カブシキガイシャ\u3000アイオーデータキキ',
        address='金沢市桜田町三丁目１０番地',
        industry='電気機器',
        sec_code=None,
        corporate_number='5220001000575',
    ),
    'E01995': EdinetCodeEntry(
        edinet_code='E01995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2331,
        fiscal_year_end='12月31日',
        submitter_name='千代田インテグレ株式会社',
        submitter_name_en='CHIYODA INTEGRE CO.,LTD.',
        submitter_name_yomi='チヨダインテグレカブシキガイシャ',
        address='千代田区二番町１－１',
        industry='電気機器',
        sec_code='69150',
        corporate_number='5010001050385',
    ),
    'E01997': EdinetCodeEntry(
        edinet_code='E01997',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=921,
        fiscal_year_end='9月30日',
        submitter_name='助川電気工業株式会社',
        submitter_name_en='SUKEGAWA ELECTRIC CO.,LTD',
        submitter_name_yomi='スケガワデンキコウギョウカブシキガイシャ',
        address='日立市滑川本町３丁目１９番５号',
        industry='精密機器',
        sec_code='77110',
        corporate_number='6050001023279',
    ),
    'E01998': EdinetCodeEntry(
        edinet_code='E01998',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2798,
        fiscal_year_end='12月31日',
        submitter_name='オプテックスグループ株式会社',
        submitter_name_en='OPTEX GROUP Company,Limited',
        submitter_name_yomi='オプテックスグループカブシキガイシャ',
        address='大津市におの浜四丁目７番５号',
        industry='電気機器',
        sec_code='69140',
        corporate_number='1160001000321',
    ),
    'E01999': EdinetCodeEntry(
        edinet_code='E01999',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3299,
        fiscal_year_end='12月31日',
        submitter_name='日置電機株式会社',
        submitter_name_en='HIOKI E.E.CORPORATION',
        submitter_name_yomi='ヒオキデンキカブシキガイシャ',
        address='上田市小泉８１番地',
        industry='電気機器',
        sec_code='68660',
        corporate_number='6100001010247',
    ),
    'E02000': EdinetCodeEntry(
        edinet_code='E02000',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4651,
        fiscal_year_end='3月31日',
        submitter_name='桂川電機株式会社',
        submitter_name_en='KATSURAGAWA ELECTRIC CO.,LTD.',
        submitter_name_yomi='カツラガワデンキカブシキガイシャ',
        address='大田区矢口１丁目５番１号',
        industry='機械',
        sec_code='64160',
        corporate_number='1010801002630',
    ),
    'E02002': EdinetCodeEntry(
        edinet_code='E02002',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7067,
        fiscal_year_end='3月20日',
        submitter_name='未来工業株式会社',
        submitter_name_en='MIRAI INDUSTRY CO.,LTD.',
        submitter_name_yomi='ミライコウギョウカブシキガイシャ',
        address='安八郡輪之内町楡俣１６９５番地の１',
        industry='化学',
        sec_code='79310',
        corporate_number='3200001014926',
    ),
    'E02003': EdinetCodeEntry(
        edinet_code='E02003',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5220,
        fiscal_year_end='12月31日',
        submitter_name='新日本無線株式会社',
        submitter_name_en='New Japan Radio Co., Ltd.',
        submitter_name_yomi='シンニホンムセンカブシキガイシャ',
        address='中央区日本橋横山町３番１０号',
        industry='電気機器',
        sec_code=None,
        corporate_number='7010001045862',
    ),
    'E02004': EdinetCodeEntry(
        edinet_code='E02004',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2201,
        fiscal_year_end='3月31日',
        submitter_name='菊水ホールディングス株式会社',
        submitter_name_en='KIKUSUI HOLDINGS CORPORATION',
        submitter_name_yomi='キクスイホールディングスカブシキガイシャ',
        address='横浜市都筑区茅ケ崎中央６番１号\u3000サウスウッド４階',
        industry='電気機器',
        sec_code='69120',
        corporate_number='2020001019928',
    ),
    'E02005': EdinetCodeEntry(
        edinet_code='E02005',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1331,
        fiscal_year_end='3月31日',
        submitter_name='リーダー電子株式会社',
        submitter_name_en='LEADER ELECTRONICS CORPORATION',
        submitter_name_yomi='リーダーデンシカブシキガイシャ',
        address='横浜市港北区綱島東ニ丁目６番３３号',
        industry='電気機器',
        sec_code='68670',
        corporate_number='8020001022174',
    ),
    'E02006': EdinetCodeEntry(
        edinet_code='E02006',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2760,
        fiscal_year_end='3月31日',
        submitter_name='ガリレイ株式会社',
        submitter_name_en='GALILEI CO. LTD.',
        submitter_name_yomi='ガリレイカブシキガイシャ',
        address='大阪市西淀川区竹島２丁目６番１８号',
        industry='機械',
        sec_code='64200',
        corporate_number='9120001050544',
    ),
    'E02007': EdinetCodeEntry(
        edinet_code='E02007',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1087,
        fiscal_year_end='1月31日',
        submitter_name='不二電機工業株式会社',
        submitter_name_en='FUJI ELECTRIC INDUSTRY CO., LTD.',
        submitter_name_yomi='フジデンキコウギョウカブシキガイシャ',
        address='京都市中京区御池通富小路西入る東八幡町５８５番地',
        industry='電気機器',
        sec_code='66540',
        corporate_number='9130001022352',
    ),
    'E02008': EdinetCodeEntry(
        edinet_code='E02008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2801,
        fiscal_year_end='3月31日',
        submitter_name='ワイエイシイホールディングス株式会社',
        submitter_name_en='Y.A.C. HOLDINGS CO., LTD.',
        submitter_name_yomi='ワイエイシイホールディングスカブシキガイシャ',
        address='昭島市武蔵野三丁目１１番１０号',
        industry='機械',
        sec_code='62980',
        corporate_number='3012801002666',
    ),
    'E02009': EdinetCodeEntry(
        edinet_code='E02009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5640,
        fiscal_year_end='3月31日',
        submitter_name='イリソ電子工業株式会社',
        submitter_name_en='IRISO ELECTRONICS CO., LTD.',
        submitter_name_yomi='イリソデンシコウギョウカブシキガイシャ',
        address='横浜市港北区新横浜２丁目１３番地８',
        industry='電気機器',
        sec_code='69080',
        corporate_number='1020001053696',
    ),
    'E02011': EdinetCodeEntry(
        edinet_code='E02011',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1028,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ナ・デックス',
        submitter_name_en='NADEX CO., LTD.',
        submitter_name_yomi='カブシキカイシャナデックス',
        address='名古屋市中区古渡町９番２７号',
        industry='卸売業',
        sec_code='74350',
        corporate_number='5180001039239',
    ),
    'E02012': EdinetCodeEntry(
        edinet_code='E02012',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=908,
        fiscal_year_end='3月31日',
        submitter_name='三相電機株式会社',
        submitter_name_en='SANSO ELECTRIC CO.,LTD.',
        submitter_name_yomi='サンソウデンキカブシキガイシャ',
        address='姫路市青山北一丁目１番１号',
        industry='電気機器',
        sec_code='65180',
        corporate_number='5140001059091',
    ),
    'E02013': EdinetCodeEntry(
        edinet_code='E02013',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2476,
        fiscal_year_end='3月31日',
        submitter_name='ＡＳＴＩ株式会社',
        submitter_name_en='ASTI CORPORATION',
        submitter_name_yomi='アスティカブシキガイシャ',
        address='浜松市中央区米津町２８０４番地',
        industry='電気機器',
        sec_code='68990',
        corporate_number='2080401000184',
    ),
    'E02015': EdinetCodeEntry(
        edinet_code='E02015',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12723,
        fiscal_year_end='3月31日',
        submitter_name='シスメックス株式会社',
        submitter_name_en='SYSMEX CORPORATION',
        submitter_name_yomi='シスメックスカブシキガイシャ',
        address='神戸市中央区脇浜海岸通１丁目５番１号',
        industry='電気機器',
        sec_code='68690',
        corporate_number='9140001009530',
    ),
    'E02016': EdinetCodeEntry(
        edinet_code='E02016',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1966,
        fiscal_year_end='1月31日',
        submitter_name='トミタ電機株式会社',
        submitter_name_en='TOMITA ELECTRIC CO.,LTD.',
        submitter_name_yomi='トミタデンキカブシキガイシャ',
        address='鳥取市幸町１２３番地',
        industry='電気機器',
        sec_code='68980',
        corporate_number='1270001000483',
    ),
    'E02017': EdinetCodeEntry(
        edinet_code='E02017',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2517,
        fiscal_year_end='2月28日',
        submitter_name='株式会社ツインバード',
        submitter_name_en='TWIN-BIRD CORPORATION',
        submitter_name_yomi='カブシキガイシャツインバード',
        address='燕市吉田西太田字潟向２０８４番地２',
        industry='電気機器',
        sec_code='68970',
        corporate_number='7110001015665',
    ),
    'E02018': EdinetCodeEntry(
        edinet_code='E02018',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2770,
        fiscal_year_end=None,
        submitter_name='北川工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キタガワコウギョウカブシキガイシャ',
        address='稲沢市目比町東折戸６９５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001035389',
    ),
    'E02019': EdinetCodeEntry(
        edinet_code='E02019',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=333,
        fiscal_year_end=None,
        submitter_name='ダイヤモンド電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイヤモンドデンキカブシキガイシャ',
        address='大阪市淀川区塚本一丁目１５番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001056478',
    ),
    'E02020': EdinetCodeEntry(
        edinet_code='E02020',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=996,
        fiscal_year_end='12月31日',
        submitter_name='日本フェンオール株式会社',
        submitter_name_en='Fenwal  Controls  of  Japan,  Ltd.',
        submitter_name_yomi='ニホンフェンオール\u3000カブシキガイシャ',
        address='千代田区飯田橋１丁目５番１０号',
        industry='電気機器',
        sec_code='68700',
        corporate_number='5010001033646',
    ),
    'E02021': EdinetCodeEntry(
        edinet_code='E02021',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1491,
        fiscal_year_end='3月31日',
        submitter_name='パルステック工業株式会社',
        submitter_name_en='PULSTEC INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='パルステックコウギョウカブシキガイシャ',
        address='浜松市浜名区細江町中川７０００番地の３５',
        industry='電気機器',
        sec_code='68940',
        corporate_number='5080401004455',
    ),
    'E02024': EdinetCodeEntry(
        edinet_code='E02024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13201,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フェローテック',
        submitter_name_en='Ferrotec Corporation',
        submitter_name_yomi='カブシキガイシャフェローテック',
        address='中央区日本橋二丁目３番４号',
        industry='電気機器',
        sec_code='68900',
        corporate_number='1010001075980',
    ),
    'E02025': EdinetCodeEntry(
        edinet_code='E02025',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=700,
        fiscal_year_end='3月31日',
        submitter_name='株式会社高見沢サイバネティックス',
        submitter_name_en='TAKAMISAWA CYBERNETICS COMPANY,LTD.',
        submitter_name_yomi='カブシキガイシャタカミサワサイバネティックス',
        address='中野区中央２－４８－５',
        industry='機械',
        sec_code='64240',
        corporate_number='7011201003197',
    ),
    'E02026': EdinetCodeEntry(
        edinet_code='E02026',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3105,
        fiscal_year_end='3月31日',
        submitter_name='オーデリック株式会社',
        submitter_name_en='ODELIC CO.,LTD.',
        submitter_name_yomi='オーデリックカブシキガイシャ',
        address='杉並区宮前一丁目１７番５号',
        industry='電気機器',
        sec_code=None,
        corporate_number='6011301001473',
    ),
    'E02027': EdinetCodeEntry(
        edinet_code='E02027',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1460,
        fiscal_year_end='3月31日',
        submitter_name='新コスモス電機株式会社',
        submitter_name_en='NEW COSMOS ELECTRIC CO., LTD',
        submitter_name_yomi='シンコスモスデンキカブシキガイシャ',
        address='大阪市淀川区三津屋中２丁目５番４号',
        industry='電気機器',
        sec_code='68240',
        corporate_number='3120001056043',
    ),
    'E02028': EdinetCodeEntry(
        edinet_code='E02028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1037,
        fiscal_year_end='3月31日',
        submitter_name='東洋電機株式会社',
        submitter_name_en='TOYO ELECTRIC CORPORATION',
        submitter_name_yomi='トウヨウデンキカブシキガイシャ',
        address='春日井市味美町２丁目１５６番地',
        industry='電気機器',
        sec_code='66550',
        corporate_number='2180001074585',
    ),
    'E02030': EdinetCodeEntry(
        edinet_code='E02030',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5018,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本マイクロニクス',
        submitter_name_en='MICRONICS JAPAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャニホンマイクロニクス',
        address='武蔵野市吉祥寺本町二丁目６番８号',
        industry='電気機器',
        sec_code='68710',
        corporate_number='5012401011628',
    ),
    'E02035': EdinetCodeEntry(
        edinet_code='E02035',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4358,
        fiscal_year_end='3月31日',
        submitter_name='株式会社キョウデン',
        submitter_name_en='KYODEN COMPANY,LIMITED',
        submitter_name_yomi='カブシキガイシャキョウデン',
        address='上伊那郡箕輪町大字三日町４８２番地１',
        industry='電気機器',
        sec_code=None,
        corporate_number='6100001021517',
    ),
    'E02039': EdinetCodeEntry(
        edinet_code='E02039',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1441,
        fiscal_year_end='6月30日',
        submitter_name='協立電機株式会社',
        submitter_name_en='KYORITSU ELECTRIC CORPORATION',
        submitter_name_yomi='キョウリツデンキカブシキカイシャ',
        address='静岡市駿河区中田本町６１番１号',
        industry='電気機器',
        sec_code='68740',
        corporate_number='6080001001232',
    ),
    'E02040': EdinetCodeEntry(
        edinet_code='E02040',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1925,
        fiscal_year_end='9月30日',
        submitter_name='ＯＢＡＲＡ\u3000ＧＲＯＵＰ株式会社',
        submitter_name_en='Obara Group Incorporated',
        submitter_name_yomi='オバラグループカブシキガイシャ',
        address='大和市中央林間三丁目２番１０号',
        industry='電気機器',
        sec_code='68770',
        corporate_number='9021001027278',
    ),
    'E02042': EdinetCodeEntry(
        edinet_code='E02042',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4840,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メガチップス',
        submitter_name_en='MegaChips Corporation',
        submitter_name_yomi='カブシキガイシャメガチップス',
        address='大阪市淀川区宮原一丁目１番１号',
        industry='電気機器',
        sec_code='68750',
        corporate_number='9120001058777',
    ),
    'E02043': EdinetCodeEntry(
        edinet_code='E02043',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3053,
        fiscal_year_end='3月31日',
        submitter_name='日本電子材料株式会社',
        submitter_name_en='JAPAN ELECTRONIC MATERIALS CORPORATION',
        submitter_name_yomi='ニホンデンシザイリョウカブシキガイシャ',
        address='尼崎市西長洲町２丁目５番１３号',
        industry='電気機器',
        sec_code='68550',
        corporate_number='1140001050335',
    ),
    'E02045': EdinetCodeEntry(
        edinet_code='E02045',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＫＩＢＡホールディングス',
        submitter_name_en='AKIBA Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアキバホールディングス',
        address='中央区築地二丁目１番１７号',
        industry='電気機器',
        sec_code='68400',
        corporate_number='9010001101820',
    ),
    'E02046': EdinetCodeEntry(
        edinet_code='E02046',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1538,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルメディオ',
        submitter_name_en='ALMEDIO INC.',
        submitter_name_yomi='カブシキガイシャアルメディオ',
        address='国立市東一丁目４番地１２',
        industry='その他製品',
        sec_code='78590',
        corporate_number='1012701001142',
    ),
    'E02047': EdinetCodeEntry(
        edinet_code='E02047',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='1月31日',
        submitter_name='株式会社石井表記',
        submitter_name_en='ISHII HYOKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイシイヒョウキ',
        address='福山市神辺町旭丘５番地',
        industry='機械',
        sec_code='63360',
        corporate_number='4240001029432',
    ),
    'E02048': EdinetCodeEntry(
        edinet_code='E02048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1102,
        fiscal_year_end='3月31日',
        submitter_name='株式会社京写',
        submitter_name_en='KYOSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウシャ',
        address='久世郡久御山町森村東３００番地',
        industry='電気機器',
        sec_code='68370',
        corporate_number='6130001033352',
    ),
    'E02049': EdinetCodeEntry(
        edinet_code='E02049',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2521,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テセック',
        submitter_name_en='TESEC Corporation',
        submitter_name_yomi='カブシキガイシャテセック',
        address='東大和市上北台３丁目３９１番地の１',
        industry='機械',
        sec_code='63370',
        corporate_number='5012801003522',
    ),
    'E02051': EdinetCodeEntry(
        edinet_code='E02051',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4545,
        fiscal_year_end='3月31日',
        submitter_name='アオイ電子株式会社',
        submitter_name_en='AOI ELECTRONICS CO.,LTD.',
        submitter_name_yomi='アオイデンシカブシキガイシャ',
        address='高松市香西南町４５５番地の１',
        industry='電気機器',
        sec_code='68320',
        corporate_number='3470001000263',
    ),
    'E02054': EdinetCodeEntry(
        edinet_code='E02054',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3668,
        fiscal_year_end='12月31日',
        submitter_name='ローランド\u3000ディー．ジー．株式会社',
        submitter_name_en='Roland DG Corporation',
        submitter_name_yomi='ローランドディージーカブシキガイシャ',
        address='浜松市浜名区新都田一丁目１番２号',
        industry='電気機器',
        sec_code=None,
        corporate_number='2080401005893',
    ),
    'E02055': EdinetCodeEntry(
        edinet_code='E02055',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1184,
        fiscal_year_end='3月31日',
        submitter_name='名古屋電機工業株式会社',
        submitter_name_en='NAGOYA ELECTRIC WORKS CO.,LTD.',
        submitter_name_yomi='ナゴヤデンキコウギョウカブシキガイシャ',
        address='あま市篠田面徳２９－１',
        industry='電気機器',
        sec_code='67970',
        corporate_number='7180001020428',
    ),
    'E02056': EdinetCodeEntry(
        edinet_code='E02056',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12888,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メイコー',
        submitter_name_en='Meiko Electronics Co., Ltd.',
        submitter_name_yomi='カブシキガイシャメイコー',
        address='綾瀬市大上五丁目１４番１５号',
        industry='電気機器',
        sec_code='67870',
        corporate_number='3021001027639',
    ),
    'E02057': EdinetCodeEntry(
        edinet_code='E02057',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1703,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＲＶＨ',
        submitter_name_en='RVH Inc.',
        submitter_name_yomi='カブシキガイシャアールブイエイチ',
        address='港区赤坂八丁目５番２８号',
        industry='電気機器',
        sec_code='67860',
        corporate_number='5020001030519',
    ),
    'E02058': EdinetCodeEntry(
        edinet_code='E02058',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1435,
        fiscal_year_end='6月30日',
        submitter_name='株式会社鈴木',
        submitter_name_en='SUZUKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスズキ',
        address='須坂市大字小河原２１５０番地１',
        industry='電気機器',
        sec_code='67850',
        corporate_number='4100001005587',
    ),
    'E02059': EdinetCodeEntry(
        edinet_code='E02059',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4203,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワコム',
        submitter_name_en='Wacom Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャワコム',
        address='加須市豊野台二丁目５１０番地１',
        industry='電気機器',
        sec_code='67270',
        corporate_number='8030001033121',
    ),
    'E02060': EdinetCodeEntry(
        edinet_code='E02060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1213,
        fiscal_year_end='7月31日',
        submitter_name='サムコ\u3000株式会社',
        submitter_name_en='SAMCO INC.',
        submitter_name_yomi='サムコ\u3000カブシキガイシャ',
        address='京都市伏見区竹田藁屋町３６番地',
        industry='機械',
        sec_code='63870',
        corporate_number='4130001014511',
    ),
    'E02062': EdinetCodeEntry(
        edinet_code='E02062',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1175,
        fiscal_year_end='12月31日',
        submitter_name='ザインエレクトロニクス株式会社',
        submitter_name_en='THine Electronics, Inc.',
        submitter_name_yomi='ザインエレクトロニクスカブシキカイシャ',
        address='千代田区神田美土代町９番地１',
        industry='電気機器',
        sec_code='67690',
        corporate_number='1010001044837',
    ),
    'E02065': EdinetCodeEntry(
        edinet_code='E02065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=601,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＯＳＧコーポレーション',
        submitter_name_en='OSG CORPORATION CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオーエスジーコーポレーション',
        address='大阪市北区天満一丁目２６番３号',
        industry='電気機器',
        sec_code='67570',
        corporate_number='3120001061514',
    ),
    'E02066': EdinetCodeEntry(
        edinet_code='E02066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12577,
        fiscal_year_end='3月31日',
        submitter_name='エレコム株式会社',
        submitter_name_en='ELECOM CO.,LTD.',
        submitter_name_yomi='エレコムカブシキガイシャ',
        address='大阪市中央区伏見町四丁目１番１号',
        industry='電気機器',
        sec_code='67500',
        corporate_number='5120001094974',
    ),
    'E02069': EdinetCodeEntry(
        edinet_code='E02069',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4425,
        fiscal_year_end='3月31日',
        submitter_name='ＥＩＺＯ株式会社',
        submitter_name_en='EIZO Corporation',
        submitter_name_yomi='エイゾーカブシキガイシャ',
        address='白山市下柏野町１５３番地',
        industry='電気機器',
        sec_code='67370',
        corporate_number='8220001009300',
    ),
    'E02070': EdinetCodeEntry(
        edinet_code='E02070',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2086,
        fiscal_year_end='3月31日',
        submitter_name='サン電子株式会社',
        submitter_name_en='SUNCORPORATION',
        submitter_name_yomi='サンデンシカブシキガイシャ',
        address='江南市古知野町朝日２５０',
        industry='電気機器',
        sec_code='67360',
        corporate_number='5180001087444',
    ),
    'E02072': EdinetCodeEntry(
        edinet_code='E02072',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=496,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ニューテック',
        submitter_name_en='Newtech Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニューテック',
        address='港区浜松町二丁目７番１９号ＫＤＸ浜松町ビル',
        industry='電気機器',
        sec_code='67340',
        corporate_number='4010401039731',
    ),
    'E02073': EdinetCodeEntry(
        edinet_code='E02073',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=674,
        fiscal_year_end='3月31日',
        submitter_name='ダイコク電機株式会社',
        submitter_name_en='DAIKOKU DENKI CO.,LTD.',
        submitter_name_yomi='ダイコクデンキカブシキガイシャ',
        address='名古屋市中村区那古野一丁目４３番５号',
        industry='機械',
        sec_code='64300',
        corporate_number='4180001048892',
    ),
    'E02075': EdinetCodeEntry(
        edinet_code='E02075',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=273,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ピクセラ',
        submitter_name_en='PIXELA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ピクセラ',
        address='大阪市西区立売堀一丁目４番１２号\u3000立売堀スクエア５階',
        industry='電気機器',
        sec_code='67310',
        corporate_number='6120001106530',
    ),
    'E02076': EdinetCodeEntry(
        edinet_code='E02076',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2133,
        fiscal_year_end='3月31日',
        submitter_name='ヘリオス\u3000テクノ\u3000ホールディング株式会社',
        submitter_name_en='Helios Techno Holding Co.,Ltd.',
        submitter_name_yomi='ヘリオス\u3000テクノ\u3000ホールディングカブシキガイシャ',
        address='中央区日本橋馬喰町一丁目１１番１０号',
        industry='電気機器',
        sec_code='69270',
        corporate_number='5140001059001',
    ),
    'E02077': EdinetCodeEntry(
        edinet_code='E02077',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1028,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アクセル',
        submitter_name_en='AXELL CORPORATION',
        submitter_name_yomi='カブシキガイシャアクセル',
        address='千代田区外神田四丁目１４番１号',
        industry='電気機器',
        sec_code='67300',
        corporate_number='9010001072343',
    ),
    'E02081': EdinetCodeEntry(
        edinet_code='E02081',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='12月31日',
        submitter_name='ルネサスエレクトロニクス株式会社',
        submitter_name_en='Renesas Electronics Corporation',
        submitter_name_yomi='ルネサスエレクトロニクスカブシキガイシャ',
        address='江東区豊洲三丁目２番２４号',
        industry='電気機器',
        sec_code='67230',
        corporate_number='8020001075701',
    ),
    'E02082': EdinetCodeEntry(
        edinet_code='E02082',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=577,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エイアンドティー',
        submitter_name_en='A&T Corporation',
        submitter_name_yomi='カブシキガイシャエイアンドティー',
        address='藤沢市遠藤２０２３番地１',
        industry='電気機器',
        sec_code=None,
        corporate_number='1021001002692',
    ),
    'E02083': EdinetCodeEntry(
        edinet_code='E02083',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2954,
        fiscal_year_end='12月31日',
        submitter_name='ウインテスト株式会社',
        submitter_name_en='Wintest Corp.',
        submitter_name_yomi='ウインテストカブシキガイシャ',
        address='横浜市西区平沼１丁目２番２４号',
        industry='電気機器',
        sec_code='67210',
        corporate_number='3020001025396',
    ),
    'E02086': EdinetCodeEntry(
        edinet_code='E02086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バッファロー',
        submitter_name_en='BUFFALO INC.',
        submitter_name_yomi='カブシキガイシャバッファロー',
        address='千代田区丸の内一丁目１１番１号',
        industry='電気機器',
        sec_code='66760',
        corporate_number='6180001048602',
    ),
    'E02089': EdinetCodeEntry(
        edinet_code='E02089',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52841,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ジーエス・ユアサ\u3000コーポレーション',
        submitter_name_en='GS Yuasa Corporation',
        submitter_name_yomi='カブシキガイシャジーエスユアサコーポレーション',
        address='京都市南区吉祥院西ノ庄猪之馬場町１番地',
        industry='電気機器',
        sec_code='66740',
        corporate_number='6130001025374',
    ),
    'E02090': EdinetCodeEntry(
        edinet_code='E02090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3868,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＣＪ',
        submitter_name_en='MCJ Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエムシージェイ',
        address='春日部市緑町六丁目１４番５３号',
        industry='電気機器',
        sec_code='66700',
        corporate_number='9030001052005',
    ),
    'E02091': EdinetCodeEntry(
        edinet_code='E02091',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=462,
        fiscal_year_end=None,
        submitter_name='シーシーエス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーシーエスカブシキガイシャ',
        address='京都市上京区烏丸通下立売上ル桜鶴円町３７４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6130001021002',
    ),
    'E02092': EdinetCodeEntry(
        edinet_code='E02092',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=835,
        fiscal_year_end='8月31日',
        submitter_name='株式会社アドテックプラズマテクノロジー',
        submitter_name_en='ADTEC PLASMA TECHNOLOGY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアドテックプラズマテクノロジー',
        address='福山市引野町五丁目６番１０号',
        industry='電気機器',
        sec_code='66680',
        corporate_number='2240001029764',
    ),
    'E02093': EdinetCodeEntry(
        edinet_code='E02093',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1681,
        fiscal_year_end='3月31日',
        submitter_name='リバーエレテック株式会社',
        submitter_name_en='RIVER ELETEC CORPORATION',
        submitter_name_yomi='リバーエレテック\u3000カブシキガイシャ',
        address='韮崎市富士見ヶ丘２丁目１番１１号',
        industry='電気機器',
        sec_code='66660',
        corporate_number='4090001011240',
    ),
    'E02095': EdinetCodeEntry(
        edinet_code='E02095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=942,
        fiscal_year_end='11月30日',
        submitter_name='株式会社オプトエレクトロニクス',
        submitter_name_en='OPTOELECTRONICS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオプトエレクトロニクス',
        address='蕨市塚越４丁目１２番１７号',
        industry='電気機器',
        sec_code='66640',
        corporate_number='1030001020927',
    ),
    'E02096': EdinetCodeEntry(
        edinet_code='E02096',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1207,
        fiscal_year_end='3月31日',
        submitter_name='アビックス株式会社',
        submitter_name_en='AVIX,Inc.',
        submitter_name_yomi='アビックスカブシキガイシャ',
        address='横浜市中区弁天通６丁目８５番地',
        industry='その他製品',
        sec_code='78360',
        corporate_number='5020001005867',
    ),
    'E02097': EdinetCodeEntry(
        edinet_code='E02097',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=822,
        fiscal_year_end='12月20日',
        submitter_name='太洋テクノレックス株式会社',
        submitter_name_en='TAIYO TECHNOLEX CO.,LTD.',
        submitter_name_yomi='タイヨウテクノレックスカブシキガイシャ',
        address='和歌山市有本６６１番地',
        industry='電気機器',
        sec_code='66630',
        corporate_number='9170001002004',
    ),
    'E02098': EdinetCodeEntry(
        edinet_code='E02098',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=52026,
        fiscal_year_end='12月31日',
        submitter_name='日亜化学工業株式会社',
        submitter_name_en='Nichia Corporation',
        submitter_name_yomi='ニチアカガクコウギョウカブシキガイシャ',
        address='阿南市上中町岡４９１番地１００',
        industry='電気機器',
        sec_code=None,
        corporate_number='5480001006794',
    ),
    'E02100': EdinetCodeEntry(
        edinet_code='E02100',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=941,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ユビテック',
        submitter_name_en='Ubiteq,INC.',
        submitter_name_yomi='カブシキガイシャユビテック',
        address='港区南麻布三丁目２０番１号',
        industry='電気機器',
        sec_code='66620',
        corporate_number='9010701021368',
    ),
    'E02101': EdinetCodeEntry(
        edinet_code='E02101',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=546,
        fiscal_year_end=None,
        submitter_name='オプテックス・エフエー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オプテックスエフエーカブシキカイシャ',
        address='京都市下京区中堂寺粟田町９１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130001024003',
    ),
    'E02103': EdinetCodeEntry(
        edinet_code='E02103',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=199034,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＳＵＭＣＯ',
        submitter_name_en='SUMCO CORPORATION',
        submitter_name_yomi='カブシキガイシャサムコ',
        address='港区芝浦一丁目２番１号',
        industry='金属製品',
        sec_code='34360',
        corporate_number='3010401046159',
    ),
    'E02104': EdinetCodeEntry(
        edinet_code='E02104',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ディー・ディー・エス',
        submitter_name_en='DDS, Inc.',
        submitter_name_yomi='カブシキガイシャディーディーエス',
        address='新宿区西新宿六丁目１２番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7180001046613',
    ),
    'E02105': EdinetCodeEntry(
        edinet_code='E02105',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1190,
        fiscal_year_end='3月31日',
        submitter_name='レシップホールディングス株式会社',
        submitter_name_en='LECIP HOLDINGS CORPORATION',
        submitter_name_yomi='レシップホールディングスカブシキガイシャ',
        address='本巣市上保１２６０番地の２',
        industry='輸送用機器',
        sec_code='72130',
        corporate_number='7200001010392',
    ),
    'E02107': EdinetCodeEntry(
        edinet_code='E02107',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3095,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ポラテクノ',
        submitter_name_en='POLATECHNO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャポラテクノ',
        address='上越市板倉区稲増字下川原１９２番地６',
        industry='化学',
        sec_code=None,
        corporate_number='6110001019997',
    ),
    'E02109': EdinetCodeEntry(
        edinet_code='E02109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='シライ電子工業株式会社',
        submitter_name_en='Shirai Electronics Indutrial Co.,Ltd',
        submitter_name_yomi='シライデンシコウギョウカブシキガイシャ',
        address='京都市南区久世東土川町３６４－１',
        industry='電気機器',
        sec_code='66580',
        corporate_number='1130001001041',
    ),
    'E02112': EdinetCodeEntry(
        edinet_code='E02112',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=484,
        fiscal_year_end='3月31日',
        submitter_name='萩原エンジニアリング株式会社',
        submitter_name_en='HAGIWARA ENGINEERING CO.,LTD.',
        submitter_name_yomi='ハギワラエンジニアリングカブシキガイシャ',
        address='入間市大字狭山ケ原３２６番地',
        industry='機械',
        sec_code=None,
        corporate_number='1030001027880',
    ),
    'E02114': EdinetCodeEntry(
        edinet_code='E02114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4357,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミマキエンジニアリング',
        submitter_name_en='MIMAKI ENGINEERING CO.,LTD.',
        submitter_name_yomi='カブシキガイシャミマキエンジニアリング',
        address='東御市滋野乙２１８２番地３',
        industry='電気機器',
        sec_code='66380',
        corporate_number='5100001010883',
    ),
    'E02115': EdinetCodeEntry(
        edinet_code='E02115',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＦＣＭ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフシーエムカブシキガイシャ',
        address='大阪市東成区神路三丁目８番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001011859',
    ),
    'E02116': EdinetCodeEntry(
        edinet_code='E02116',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1174,
        fiscal_year_end='12月31日',
        submitter_name='株式会社大日光・エンジニアリング',
        submitter_name_en='Di-Nikko Engineering Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャダイニッコウエンジニアリング',
        address='日光市根室６９７－１',
        industry='電気機器',
        sec_code='66350',
        corporate_number='4060001008446',
    ),
    'E02117': EdinetCodeEntry(
        edinet_code='E02117',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1119,
        fiscal_year_end=None,
        submitter_name='株式会社コンテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコンテック',
        address='大阪市西淀川区姫里三丁目９－３１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001049586',
    ),
    'E02118': EdinetCodeEntry(
        edinet_code='E02118',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3882,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソルガム・ジャパン・ホールディングス',
        submitter_name_en='SORGHUM JAPAN HOLDINGS Corp.',
        submitter_name_yomi='カブシキガイシャソルガムジャパンホールディングス',
        address='品川区北品川五丁目９番１５号',
        industry='電気機器',
        sec_code=None,
        corporate_number='9020001069900',
    ),
    'E02119': EdinetCodeEntry(
        edinet_code='E02119',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6486,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニューフレアテクノロジー',
        submitter_name_en='NuFlare Technology, Inc.',
        submitter_name_yomi='カブシキガイシャニューフレアテクノロジー',
        address='横浜市磯子区新杉田町８番１',
        industry='機械',
        sec_code=None,
        corporate_number='5080101002461',
    ),
    'E02120': EdinetCodeEntry(
        edinet_code='E02120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＣＧＳホールディングス',
        submitter_name_en='CGS HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャシージーエスホールディングス',
        address='北九州市八幡西区引野１－５－１５',
        industry='電気機器',
        sec_code='66330',
        corporate_number='4010701025183',
    ),
    'E02121': EdinetCodeEntry(
        edinet_code='E02121',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=962,
        fiscal_year_end='7月31日',
        submitter_name='株式会社山王',
        submitter_name_en='SANNO Co.,Ltd',
        submitter_name_yomi='カブシキガイシャサンノー',
        address='横浜市港北区綱島東五丁目８番８号',
        industry='金属製品',
        sec_code='34410',
        corporate_number='3020001020348',
    ),
    'E02123': EdinetCodeEntry(
        edinet_code='E02123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8846,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三井Ｅ＆Ｓ',
        submitter_name_en='MITSUI E&S Co., Ltd.',
        submitter_name_yomi='カブシキガイシャミツイイーアンドエス',
        address='中央区築地五丁目６番４号',
        industry='機械',
        sec_code='70030',
        corporate_number='9010001034946',
    ),
    'E02124': EdinetCodeEntry(
        edinet_code='E02124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45442,
        fiscal_year_end='3月31日',
        submitter_name='カナデビア株式会社',
        submitter_name_en='Kanadevia Corporation',
        submitter_name_yomi='カナデビアカブシキガイシャ',
        address='大阪市住之江区南港北１丁目７番８９号',
        industry='機械',
        sec_code='70040',
        corporate_number='3120001031541',
    ),
    'E02126': EdinetCodeEntry(
        edinet_code='E02126',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=265608,
        fiscal_year_end='3月31日',
        submitter_name='三菱重工業株式会社',
        submitter_name_en='Mitsubishi Heavy Industries,Ltd.',
        submitter_name_yomi='ミツビシジュウコウギョウカブシキカイシャ',
        address='千代田区丸の内三丁目２番３号',
        industry='機械',
        sec_code='70110',
        corporate_number='8010401050387',
    ),
    'E02127': EdinetCodeEntry(
        edinet_code='E02127',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=104484,
        fiscal_year_end='3月31日',
        submitter_name='川崎重工業株式会社',
        submitter_name_en='Kawasaki Heavy Industries,Ltd.',
        submitter_name_yomi='カワサキジュウコウギョウカブシキガイシャ',
        address='神戸市中央区東川崎町３丁目１番１号',
        industry='輸送用機器',
        sec_code='70120',
        corporate_number='1140001005719',
    ),
    'E02128': EdinetCodeEntry(
        edinet_code='E02128',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=107165,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＩＨＩ',
        submitter_name_en='IHI Corporation',
        submitter_name_yomi='カブシキガイシャアイエイチアイ',
        address='江東区豊洲三丁目１番１号',
        industry='機械',
        sec_code='70130',
        corporate_number='4010601031604',
    ),
    'E02129': EdinetCodeEntry(
        edinet_code='E02129',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8135,
        fiscal_year_end='3月31日',
        submitter_name='株式会社名村造船所',
        submitter_name_en='Namura Shipbuilding Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャナムラゾウセンショ',
        address='大阪市西区立売堀二丁目１番９号',
        industry='輸送用機器',
        sec_code='70140',
        corporate_number='5120001046100',
    ),
    'E02131': EdinetCodeEntry(
        edinet_code='E02131',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1200,
        fiscal_year_end='3月31日',
        submitter_name='内海造船株式会社',
        submitter_name_en='Naikai  Zosen  Corporation',
        submitter_name_yomi='ナイカイ\u3000ゾウセン\u3000カブシキガイシャ',
        address='尾道市瀬戸田町沢２２６番地の６',
        industry='輸送用機器',
        sec_code='70180',
        corporate_number='9240001038924',
    ),
    'E02134': EdinetCodeEntry(
        edinet_code='E02134',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11810,
        fiscal_year_end='3月31日',
        submitter_name='日本車輌製造株式会社',
        submitter_name_en='NIPPON SHARYO, LTD.',
        submitter_name_yomi='ニッポンシャリョウセイゾウカブシキガイシャ',
        address='名古屋市熱田区三本松町１番１号',
        industry='輸送用機器',
        sec_code='71020',
        corporate_number='4180001022575',
    ),
    'E02136': EdinetCodeEntry(
        edinet_code='E02136',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5051,
        fiscal_year_end='3月31日',
        submitter_name='三菱ロジスネクスト株式会社',
        submitter_name_en='Mitsubishi Logisnext Co., Ltd.',
        submitter_name_yomi='ミツビシロジスネクストカブシキガイシャ',
        address='長岡京市東神足二丁目１番１号',
        industry='輸送用機器',
        sec_code='71050',
        corporate_number='3130001030352',
    ),
    'E02138': EdinetCodeEntry(
        edinet_code='E02138',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5252,
        fiscal_year_end='3月31日',
        submitter_name='近畿車輛株式会社',
        submitter_name_en='THE KINKI SHARYO CO.,LTD.',
        submitter_name_yomi='キンキシャリョウカブシキガイシャ',
        address='東大阪市稲田上町２丁目２番４６号',
        industry='輸送用機器',
        sec_code='71220',
        corporate_number='5122001001729',
    ),
    'E02140': EdinetCodeEntry(
        edinet_code='E02140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14270,
        fiscal_year_end='3月31日',
        submitter_name='株式会社小糸製作所',
        submitter_name_en='KOITO MANUFACTURING CO.,LTD.',
        submitter_name_yomi='カブシキガイシャコイトセイサクショ',
        address='品川区北品川五丁目１番１８号住友不動産大崎ツインビル東館',
        industry='電気機器',
        sec_code='72760',
        corporate_number='1010401009745',
    ),
    'E02142': EdinetCodeEntry(
        edinet_code='E02142',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=605813,
        fiscal_year_end='3月31日',
        submitter_name='日産自動車株式会社',
        submitter_name_en='NISSAN MOTOR CO., LTD.',
        submitter_name_yomi='ニッサンジドウシャカブシキガイシャ',
        address='横浜市神奈川区宝町２番地',
        industry='輸送用機器',
        sec_code='72010',
        corporate_number='9020001031109',
    ),
    'E02143': EdinetCodeEntry(
        edinet_code='E02143',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40644,
        fiscal_year_end='3月31日',
        submitter_name='いすゞ自動車株式会社',
        submitter_name_en='ISUZU MOTORS LIMITED',
        submitter_name_yomi='イスズジドウシャカブシキガイシャ',
        address='横浜市西区高島１丁目２番５号',
        industry='輸送用機器',
        sec_code='72020',
        corporate_number='5010701000904',
    ),
    'E02144': EdinetCodeEntry(
        edinet_code='E02144',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=635401,
        fiscal_year_end='3月31日',
        submitter_name='トヨタ自動車株式会社',
        submitter_name_en='TOYOTA MOTOR CORPORATION',
        submitter_name_yomi='トヨタジドウシャカブシキカイシャ',
        address='豊田市トヨタ町１番地',
        industry='輸送用機器',
        sec_code='72030',
        corporate_number='1180301018771',
    ),
    'E02146': EdinetCodeEntry(
        edinet_code='E02146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=72717,
        fiscal_year_end='3月31日',
        submitter_name='日野自動車株式会社',
        submitter_name_en='HINO MORTORS,LTD.',
        submitter_name_yomi='ヒノジドウシャカブシキガイシャ',
        address='日野市日野台３丁目１番地１',
        industry='輸送用機器',
        sec_code='72050',
        corporate_number='8013401000626',
    ),
    'E02147': EdinetCodeEntry(
        edinet_code='E02147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27647,
        fiscal_year_end='3月31日',
        submitter_name='カヤバ株式会社',
        submitter_name_en='KYB Corporation',
        submitter_name_yomi='カヤバカブシキガイシャ',
        address='港区浜松町二丁目４番１号',
        industry='輸送用機器',
        sec_code='72420',
        corporate_number='8010401007296',
    ),
    'E02150': EdinetCodeEntry(
        edinet_code='E02150',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7904,
        fiscal_year_end='3月31日',
        submitter_name='日産車体株式会社',
        submitter_name_en='NISSAN SHATAI CO.,LTD.',
        submitter_name_yomi='ニッサンシャタイカブシキカイシャ',
        address='平塚市堤町２番１号',
        industry='輸送用機器',
        sec_code='72220',
        corporate_number='3021001037076',
    ),
    'E02152': EdinetCodeEntry(
        edinet_code='E02152',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=153795,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＵＢＡＲＵ',
        submitter_name_en='SUBARU CORPORATION',
        submitter_name_yomi='カブシキガイシャスバル',
        address='渋谷区恵比寿一丁目２０番８号',
        industry='輸送用機器',
        sec_code='72700',
        corporate_number='5011101019196',
    ),
    'E02154': EdinetCodeEntry(
        edinet_code='E02154',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8070,
        fiscal_year_end='3月31日',
        submitter_name='プレス工業株式会社',
        submitter_name_en='PRESS KOGYO CO.,LTD.',
        submitter_name_yomi='プレスコウギョウカブシキガイシャ',
        address='川崎市川崎区塩浜１丁目１番１号',
        industry='輸送用機器',
        sec_code='72460',
        corporate_number='5020001074318',
    ),
    'E02155': EdinetCodeEntry(
        edinet_code='E02155',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7245,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ティラド',
        submitter_name_en='T.RAD Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャティラド',
        address='渋谷区代々木３丁目２５番３号',
        industry='輸送用機器',
        sec_code='72360',
        corporate_number='3011001015719',
    ),
    'E02157': EdinetCodeEntry(
        edinet_code='E02157',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='マレリ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マレリカブシキガイシャ',
        address='さいたま市北区日進町２－１９１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8030001014831',
    ),
    'E02158': EdinetCodeEntry(
        edinet_code='E02158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1317,
        fiscal_year_end='3月31日',
        submitter_name='東京ラヂエーター製造株式会社',
        submitter_name_en='TOKYO RADIATOR MFG. CO., LTD.',
        submitter_name_yomi='トウキョウラヂエーターセイゾウカブシキガイシャ',
        address='藤沢市遠藤２００２番地１',
        industry='輸送用機器',
        sec_code='72350',
        corporate_number='6021001002556',
    ),
    'E02161': EdinetCodeEntry(
        edinet_code='E02161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19939,
        fiscal_year_end='3月31日',
        submitter_name='曙ブレーキ工業株式会社',
        submitter_name_en='AKEBONO BRAKE INDUSTRY CO.,LTD.',
        submitter_name_yomi='アケボノブレーキコウギョウカブシキガイシャ',
        address='中央区日本橋室町１丁目１３番７号\u3000ＰＭＯ日本橋室町５Ｆ',
        industry='輸送用機器',
        sec_code='72380',
        corporate_number='8010001034724',
    ),
    'E02162': EdinetCodeEntry(
        edinet_code='E02162',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10870,
        fiscal_year_end='3月31日',
        submitter_name='愛三工業株式会社',
        submitter_name_en='AISAN INDUSTRY CO., LTD',
        submitter_name_yomi='アイサンコウギョウカブシキガイシャ',
        address='大府市共和町一丁目１番地の１',
        industry='輸送用機器',
        sec_code='72830',
        corporate_number='1180001092357',
    ),
    'E02163': EdinetCodeEntry(
        edinet_code='E02163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=283957,
        fiscal_year_end='3月31日',
        submitter_name='マツダ株式会社',
        submitter_name_en='Mazda Motor Corporation',
        submitter_name_yomi='マツダカブシキガイシャ',
        address='安芸郡府中町新地３番１号',
        industry='輸送用機器',
        sec_code='72610',
        corporate_number='3240001036223',
    ),
    'E02164': EdinetCodeEntry(
        edinet_code='E02164',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28404,
        fiscal_year_end=None,
        submitter_name='ダイハツ工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイハツコウギョウカブシキガイシャ',
        address='池田市ダイハツ町１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120901019710',
    ),
    'E02166': EdinetCodeEntry(
        edinet_code='E02166',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=86067,
        fiscal_year_end='3月31日',
        submitter_name='本田技研工業株式会社',
        submitter_name_en='HONDA MOTOR CO., LTD.',
        submitter_name_yomi='ホンダギケンコウギョウカブシキガイシャ',
        address='港区南青山二丁目１番１号',
        industry='輸送用機器',
        sec_code='72670',
        corporate_number='6010401027577',
    ),
    'E02167': EdinetCodeEntry(
        edinet_code='E02167',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=138370,
        fiscal_year_end='3月31日',
        submitter_name='スズキ株式会社',
        submitter_name_en='suzuki motor corporation',
        submitter_name_yomi='スズキカブシキガイシャ',
        address='浜松市中央区高塚町３００番地',
        industry='輸送用機器',
        sec_code='72690',
        corporate_number='8080401002431',
    ),
    'E02168': EdinetCodeEntry(
        edinet_code='E02168',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=85905,
        fiscal_year_end='12月31日',
        submitter_name='ヤマハ発動機株式会社',
        submitter_name_en='Yamaha Motor Co., Ltd.',
        submitter_name_yomi='ヤマハハツドウキカブシキガイシャ',
        address='磐田市新貝２５００番地',
        industry='輸送用機器',
        sec_code='72720',
        corporate_number='2080401016040',
    ),
    'E02169': EdinetCodeEntry(
        edinet_code='E02169',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='トーハツ株式会社',
        submitter_name_en='TOHATSU CORPORATION',
        submitter_name_yomi='トーハツカブシキガイシャ',
        address='板橋区小豆沢三丁目５番４号',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='2011401004553',
    ),
    'E02170': EdinetCodeEntry(
        edinet_code='E02170',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11899,
        fiscal_year_end='3月31日',
        submitter_name='極東開発工業株式会社',
        submitter_name_en='KYOKUTO KAIHATSU KOGYO CO.,LTD.',
        submitter_name_yomi='キョクトウカイハツコウギョウカブシキガイシャ',
        address='大阪市中央区淡路町２丁目５番１１号',
        industry='輸送用機器',
        sec_code='72260',
        corporate_number='7140001068512',
    ),
    'E02171': EdinetCodeEntry(
        edinet_code='E02171',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッキ',
        submitter_name_en='nikki co.,ltd',
        submitter_name_yomi='カブシキガイシャ\u3000ニッキ',
        address='厚木市上依知３０２９番地',
        industry='輸送用機器',
        sec_code='60420',
        corporate_number='2021001020256',
    ),
    'E02172': EdinetCodeEntry(
        edinet_code='E02172',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2215,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミクニ',
        submitter_name_en='MIKUNI CORPORATION',
        submitter_name_yomi='カブシキガイシャミクニ',
        address='千代田区外神田六丁目１３番１１号',
        industry='輸送用機器',
        sec_code='72470',
        corporate_number='1010001008791',
    ),
    'E02173': EdinetCodeEntry(
        edinet_code='E02173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1388,
        fiscal_year_end='3月31日',
        submitter_name='日本ギア工業株式会社',
        submitter_name_en='NIPPON GEAR CO.,LTD.',
        submitter_name_yomi='ニホンギアコウギョウカブシキガイシャ',
        address='港区西新橋１－７－１４',
        industry='機械',
        sec_code='63560',
        corporate_number='3021001001619',
    ),
    'E02174': EdinetCodeEntry(
        edinet_code='E02174',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5821,
        fiscal_year_end='3月31日',
        submitter_name='河西工業株式会社',
        submitter_name_en='KASAI KOGYO CO .,LTD.',
        submitter_name_yomi='カサイコウギョウカブシキガイシャ',
        address='高座郡寒川町宮山３３１６番地',
        industry='輸送用機器',
        sec_code='72560',
        corporate_number='5021001006269',
    ),
    'E02175': EdinetCodeEntry(
        edinet_code='E02175',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8413,
        fiscal_year_end='3月31日',
        submitter_name='大同メタル工業株式会社',
        submitter_name_en='DAIDO METAL CO., LTD.',
        submitter_name_yomi='ダイドウメタルコウギョウカブシキガイシャ',
        address='名古屋市中区栄二丁目３番１号名古屋広小路ビルヂング１３階',
        industry='輸送用機器',
        sec_code='72450',
        corporate_number='1180001012595',
    ),
    'E02176': EdinetCodeEntry(
        edinet_code='E02176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23335,
        fiscal_year_end='3月31日',
        submitter_name='ＮＯＫ株式会社',
        submitter_name_en='NOK CORPORATION',
        submitter_name_yomi='エヌオーケーカブシキガイシャ',
        address='港区芝大門１丁目１２番１５号',
        industry='輸送用機器',
        sec_code='72400',
        corporate_number='1010401004837',
    ),
    'E02177': EdinetCodeEntry(
        edinet_code='E02177',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8955,
        fiscal_year_end='12月31日',
        submitter_name='市光工業株式会社',
        submitter_name_en='ICHIKOH INDUSTRIES, LTD.',
        submitter_name_yomi='イチコウコウギョウカブシキガイシャ',
        address='伊勢原市板戸８０番地',
        industry='電気機器',
        sec_code='72440',
        corporate_number='9021001035727',
    ),
    'E02178': EdinetCodeEntry(
        edinet_code='E02178',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7316,
        fiscal_year_end='3月31日',
        submitter_name='太平洋工業株式会社',
        submitter_name_en='PACIFIC INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='タイヘイヨウコウギョウカブシキガイシャ',
        address='大垣市久徳町１００番地',
        industry='輸送用機器',
        sec_code='72500',
        corporate_number='7200001013874',
    ),
    'E02180': EdinetCodeEntry(
        edinet_code='E02180',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ヤマダコーポレーション',
        submitter_name_en='YAMADA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマダコーポレーション',
        address='大田区南馬込１丁目１番３号',
        industry='機械',
        sec_code='63920',
        corporate_number='9010801012135',
    ),
    'E02181': EdinetCodeEntry(
        edinet_code='E02181',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=14546,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユーシン',
        submitter_name_en='U-Shin Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ユーシン',
        address='港区芝大門１丁目１番３０号',
        industry='電気機器',
        sec_code=None,
        corporate_number='1010401030214',
    ),
    'E02183': EdinetCodeEntry(
        edinet_code='E02183',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユニバンス',
        submitter_name_en='UNIVANCE CORPORATION',
        submitter_name_yomi='カブシキガイシャユニバンス',
        address='湖西市鷲津２４１８',
        industry='輸送用機器',
        sec_code='72540',
        corporate_number='2080401006066',
    ),
    'E02184': EdinetCodeEntry(
        edinet_code='E02184',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12698,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ショーワ',
        submitter_name_en='SHOWA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ショーワ',
        address='行田市藤原町一丁目１４番地１',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='8030001086904',
    ),
    'E02185': EdinetCodeEntry(
        edinet_code='E02185',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2143,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メタルアート',
        submitter_name_en='METALART CORPORATION',
        submitter_name_yomi='カブシキガイシャメタルアート',
        address='草津市野路三丁目２番１８号',
        industry='鉄鋼',
        sec_code='56440',
        corporate_number='9160001013183',
    ),
    'E02189': EdinetCodeEntry(
        edinet_code='E02189',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4530,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＩＴＴＡＮ',
        submitter_name_en='NITTAN Corporation',
        submitter_name_yomi='カブシキガイシャニッタン',
        address='秦野市曽屋５１８番地',
        industry='輸送用機器',
        sec_code='64930',
        corporate_number='3021001022920',
    ),
    'E02190': EdinetCodeEntry(
        edinet_code='E02190',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5985,
        fiscal_year_end=None,
        submitter_name='富士機工株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジキコウカブシキガイシャ',
        address='湖西市鷲津２０２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5080401006071',
    ),
    'E02194': EdinetCodeEntry(
        edinet_code='E02194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10168,
        fiscal_year_end='3月31日',
        submitter_name='ユニプレス株式会社',
        submitter_name_en='UNIPRES CORPORATION',
        submitter_name_yomi='ユニプレス\u3000カブシキカイシャ',
        address='横浜市港北区新横浜一丁目１９番２０号',
        industry='輸送用機器',
        sec_code='59490',
        corporate_number='7020001045218',
    ),
    'E02195': EdinetCodeEntry(
        edinet_code='E02195',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16820,
        fiscal_year_end='3月31日',
        submitter_name='フタバ産業株式会社',
        submitter_name_en='FUTABA INDUSTRIAL CO., LTD.',
        submitter_name_yomi='フタバサンギョウカブシキガイシャ',
        address='岡崎市橋目町字御茶屋１番地',
        industry='輸送用機器',
        sec_code='72410',
        corporate_number='3180301001916',
    ),
    'E02196': EdinetCodeEntry(
        edinet_code='E02196',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6932,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ケーヒン',
        submitter_name_en='KEIHIN CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ケーヒン',
        address='新宿区西新宿一丁目２６番２号',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='8011101023179',
    ),
    'E02199': EdinetCodeEntry(
        edinet_code='E02199',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6712,
        fiscal_year_end='3月31日',
        submitter_name='大豊工業株式会社',
        submitter_name_en='TAIHO KOGYO CO.,LTD.',
        submitter_name_yomi='タイホウコウギョウカブシキガイシャ',
        address='豊田市緑ヶ丘３－６５',
        industry='機械',
        sec_code='64700',
        corporate_number='7180301018584',
    ),
    'E02200': EdinetCodeEntry(
        edinet_code='E02200',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7460,
        fiscal_year_end=None,
        submitter_name='アイシンシロキ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイシンシロキカブシキガイシャ',
        address='藤沢市桐原町２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021001001140',
    ),
    'E02201': EdinetCodeEntry(
        edinet_code='E02201',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4617,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴＢＫ',
        submitter_name_en='TBK Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャティービーケイ',
        address='町田市南成瀬４－２１－１',
        industry='輸送用機器',
        sec_code='72770',
        corporate_number='5012301001794',
    ),
    'E02203': EdinetCodeEntry(
        edinet_code='E02203',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8284,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エクセディ',
        submitter_name_en='EXEDY Corporation',
        submitter_name_yomi='カブシキガイシャエクセディ',
        address='寝屋川市木田元宮１丁目１番１号',
        industry='輸送用機器',
        sec_code='72780',
        corporate_number='1120001147463',
    ),
    'E02204': EdinetCodeEntry(
        edinet_code='E02204',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5657,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ハイレックスコーポレーション',
        submitter_name_en='HI-LEX CORPORATION',
        submitter_name_yomi='カブシキガイシャハイレックスコーポレーション',
        address='宝塚市栄町一丁目１２番２８号',
        industry='輸送用機器',
        sec_code='72790',
        corporate_number='1140001081875',
    ),
    'E02205': EdinetCodeEntry(
        edinet_code='E02205',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミツバ',
        submitter_name_en='MITSUBA Corporation',
        submitter_name_yomi='カブシキガイシャミツバ',
        address='桐生市広沢町一丁目２６８１番地',
        industry='電気機器',
        sec_code='72800',
        corporate_number='1070001016632',
    ),
    'E02207': EdinetCodeEntry(
        edinet_code='E02207',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=693,
        fiscal_year_end='3月31日',
        submitter_name='キーパー株式会社',
        submitter_name_en='KEEPER. CO., LTD.',
        submitter_name_yomi='キーパーカブシキガイシャ',
        address='藤沢市辻堂神台２丁目４番３６号',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='8021001004625',
    ),
    'E02210': EdinetCodeEntry(
        edinet_code='E02210',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9040,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タチエス',
        submitter_name_en='TACHI-S CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタチエス',
        address='青梅市末広町一丁目３番１号',
        industry='輸送用機器',
        sec_code='72390',
        corporate_number='6012801002309',
    ),
    'E02213': EdinetCodeEntry(
        edinet_code='E02213',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=284382,
        fiscal_year_end='3月31日',
        submitter_name='三菱自動車工業株式会社',
        submitter_name_en='MITSUBISHI MOTORS CORPORATION',
        submitter_name_yomi='ミツビシジドウシャコウギョウカブシキガイシャ',
        address='港区芝浦三丁目１番２１号',
        industry='輸送用機器',
        sec_code='72110',
        corporate_number='7010401029044',
    ),
    'E02214': EdinetCodeEntry(
        edinet_code='E02214',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14494,
        fiscal_year_end='3月31日',
        submitter_name='日本精機株式会社',
        submitter_name_en='NIPPON SEIKI CO.,LTD.',
        submitter_name_yomi='ニッポンセイキカブシキガイシャ',
        address='長岡市東蔵王２丁目２番３４号',
        industry='輸送用機器',
        sec_code='72870',
        corporate_number='3110001023135',
    ),
    'E02216': EdinetCodeEntry(
        edinet_code='E02216',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3206,
        fiscal_year_end='3月31日',
        submitter_name='日本プラスト株式会社',
        submitter_name_en='NIHON PLAST CO.,LTD.',
        submitter_name_yomi='ニホンプラストカブシキガイシャ',
        address='富士宮市山宮３５０７番地１５',
        industry='輸送用機器',
        sec_code='72910',
        corporate_number='2080101012372',
    ),
    'E02217': EdinetCodeEntry(
        edinet_code='E02217',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3165,
        fiscal_year_end='3月31日',
        submitter_name='株式会社村上開明堂',
        submitter_name_en='MURAKAMI CORPORATION',
        submitter_name_yomi='カブシキガイシャムラカミカイメイドウ',
        address='静岡市葵区伝馬町１１番地５',
        industry='輸送用機器',
        sec_code='72920',
        corporate_number='3080001005194',
    ),
    'E02219': EdinetCodeEntry(
        edinet_code='E02219',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6200,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨロズ',
        submitter_name_en='YOROZU CORPORATION',
        submitter_name_yomi='カブシキガイシャヨロズ',
        address='横浜市港北区樽町３丁目７番６０号',
        industry='輸送用機器',
        sec_code='72940',
        corporate_number='7020001030517',
    ),
    'E02221': EdinetCodeEntry(
        edinet_code='E02221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4175,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エフ・シー・シー',
        submitter_name_en='F.C.C.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエフシーシー',
        address='浜松市浜名区細江町中川７０００番地の３６',
        industry='輸送用機器',
        sec_code='72960',
        corporate_number='5080401010065',
    ),
    'E02222': EdinetCodeEntry(
        edinet_code='E02222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4366,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エイチワン',
        submitter_name_en='H-ONE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエイチワン',
        address='さいたま市大宮区桜木町１－１９５－１\u3000大宮ソラミチＫＯＺ\u3000１１階',
        industry='金属製品',
        sec_code='59890',
        corporate_number='3030001011684',
    ),
    'E02223': EdinetCodeEntry(
        edinet_code='E02223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1637,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カーメイト',
        submitter_name_en='CAR MATE MFG.CO.,LTD',
        submitter_name_yomi='カブシキガイシャカーメイト',
        address='豊島区長崎５－３３－１１',
        industry='輸送用機器',
        sec_code='72970',
        corporate_number='3013301021082',
    ),
    'E02224': EdinetCodeEntry(
        edinet_code='E02224',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3685,
        fiscal_year_end='3月31日',
        submitter_name='八千代工業株式会社',
        submitter_name_en='YACHIYO INDUSTRY CO., LTD.',
        submitter_name_yomi='ヤチヨコウギョウカブシキガイシャ',
        address='狭山市柏原３９３番地',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='2030001026675',
    ),
    'E02225': EdinetCodeEntry(
        edinet_code='E02225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3018,
        fiscal_year_end='3月31日',
        submitter_name='フジオーゼックス株式会社',
        submitter_name_en='FUJI OOZX Inc.',
        submitter_name_yomi='フジオーゼックスカブシキカイシャ',
        address='菊川市三沢１５００番地の６０',
        industry='輸送用機器',
        sec_code='72990',
        corporate_number='4080401014950',
    ),
    'E02226': EdinetCodeEntry(
        edinet_code='E02226',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2298,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イクヨ',
        submitter_name_en='IKUYO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイクヨ',
        address='厚木市上依知３０１９番地',
        industry='輸送用機器',
        sec_code='72730',
        corporate_number='9021001023731',
    ),
    'E02227': EdinetCodeEntry(
        edinet_code='E02227',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2142,
        fiscal_year_end='3月31日',
        submitter_name='株式会社安永',
        submitter_name_en='YASUNAGA CORPORATION',
        submitter_name_yomi='カブシキガイシャヤスナガ',
        address='伊賀市緑ヶ丘中町３８６０番地',
        industry='輸送用機器',
        sec_code='72710',
        corporate_number='1190001008733',
    ),
    'E02228': EdinetCodeEntry(
        edinet_code='E02228',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4656,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジーテクト',
        submitter_name_en='G-TEKT CORPORATION',
        submitter_name_yomi='カブシキガイシャジーテクト',
        address='さいたま市大宮区桜木町一丁目１１番地２０',
        industry='金属製品',
        sec_code='59700',
        corporate_number='9030001023377',
    ),
    'E02229': EdinetCodeEntry(
        edinet_code='E02229',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6790,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エフテック',
        submitter_name_en='F-TECH INC.',
        submitter_name_yomi='カブシキガイシャエフテック',
        address='久喜市菖蒲町昭和沼１９番地',
        industry='輸送用機器',
        sec_code='72120',
        corporate_number='6030001031085',
    ),
    'E02230': EdinetCodeEntry(
        edinet_code='E02230',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=715,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タツミ',
        submitter_name_en='TATSUMI Corporation',
        submitter_name_yomi='カブシキカイシャタツミ',
        address='足利市南大町４４３',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='7060001018855',
    ),
    'E02231': EdinetCodeEntry(
        edinet_code='E02231',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7289,
        fiscal_year_end='3月31日',
        submitter_name='株式会社今仙電機製作所',
        submitter_name_en='Imasen Electric Industrial Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイマセンデンキセイサクショ',
        address='犬山市字柿畑一番地',
        industry='輸送用機器',
        sec_code='72660',
        corporate_number='1180001080700',
    ),
    'E02232': EdinetCodeEntry(
        edinet_code='E02232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=601,
        fiscal_year_end='10月31日',
        submitter_name='エイケン工業株式会社',
        submitter_name_en='EIKEN INDUSTRIES CO.,LTD',
        submitter_name_yomi='エイケンコウギョウカブシキガイシャ',
        address='御前崎市門屋１３７０',
        industry='輸送用機器',
        sec_code='72650',
        corporate_number='7080401014989',
    ),
    'E02233': EdinetCodeEntry(
        edinet_code='E02233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=903,
        fiscal_year_end='11月30日',
        submitter_name='アスカ株式会社',
        submitter_name_en='ASKA CORPORATION',
        submitter_name_yomi='アスカカブシキガイシャ',
        address='刈谷市新富町二丁目４１番地２',
        industry='輸送用機器',
        sec_code='72270',
        corporate_number='1180301013673',
    ),
    'E02234': EdinetCodeEntry(
        edinet_code='E02234',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1095,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ムロコーポレーション',
        submitter_name_en='MURO CORPORATION',
        submitter_name_yomi='カブシキガイシャムロコーポレーション',
        address='宇都宮市清原工業団地７ー１',
        industry='輸送用機器',
        sec_code='72640',
        corporate_number='7010901011914',
    ),
    'E02235': EdinetCodeEntry(
        edinet_code='E02235',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3694,
        fiscal_year_end='3月31日',
        submitter_name='日信工業株式会社',
        submitter_name_en='NISSIN KOGYO CO.,LTD.',
        submitter_name_yomi='ニッシンコウギョウカブシキガイシャ',
        address='東御市加沢８０１番地',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='2100001010135',
    ),
    'E02236': EdinetCodeEntry(
        edinet_code='E02236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1754,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユタカ技研',
        submitter_name_en='YUTAKA GIKEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャユタカギケン',
        address='浜松市東区豊町５０８番地の１',
        industry='輸送用機器',
        sec_code='72290',
        corporate_number='8080401005665',
    ),
    'E02237': EdinetCodeEntry(
        edinet_code='E02237',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5427,
        fiscal_year_end='3月31日',
        submitter_name='武蔵精密工業株式会社',
        submitter_name_en='MUSASHI SEIMITSU INDUSTRY CO.,LTD.',
        submitter_name_yomi='ムサシセイミツコウギョウカブシキガイシャ',
        address='豊橋市植田町字大膳３９番地の５',
        industry='輸送用機器',
        sec_code='72200',
        corporate_number='6180301007357',
    ),
    'E02238': EdinetCodeEntry(
        edinet_code='E02238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=878,
        fiscal_year_end='8月31日',
        submitter_name='株式会社エッチ・ケー・エス',
        submitter_name_en='HKS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000エッチ\u3000ケー\u3000エス',
        address='富士宮市上井出２２６６番地',
        industry='輸送用機器',
        sec_code='72190',
        corporate_number='7080101011279',
    ),
    'E02241': EdinetCodeEntry(
        edinet_code='E02241',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='田中精密工業株式会社',
        submitter_name_en='TANAKA SEIMITSU KOGYO CO.,LTD.',
        submitter_name_yomi='タナカセイミツコウギョウカブシキガイシャ',
        address='富山市婦中町島田３２８番地',
        industry='輸送用機器',
        sec_code='72180',
        corporate_number='6230001001654',
    ),
    'E02242': EdinetCodeEntry(
        edinet_code='E02242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=217,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テイン',
        submitter_name_en='TEIN,INC.',
        submitter_name_yomi='カブシキガイシャテイン',
        address='横浜市戸塚区上矢部町３５１５－４',
        industry='輸送用機器',
        sec_code='72170',
        corporate_number='1020001033780',
    ),
    'E02244': EdinetCodeEntry(
        edinet_code='E02244',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山田製作所',
        submitter_name_en='YAMADA MANUFACTURING CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマダセイサクショ',
        address='桐生市広沢町１－２７５７',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='9070001016708',
    ),
    'E02245': EdinetCodeEntry(
        edinet_code='E02245',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2760,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルファ',
        submitter_name_en='ALPHA Corporation',
        submitter_name_yomi='カブシキガイシャアルファ',
        address='横浜市金沢区福浦一丁目６番８号',
        industry='金属製品',
        sec_code='34340',
        corporate_number='1020001005862',
    ),
    'E02246': EdinetCodeEntry(
        edinet_code='E02246',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2291,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファルテック',
        submitter_name_en='FALTEC Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャファルテック',
        address='川崎市幸区堀川町５８０番地',
        industry='輸送用機器',
        sec_code='72150',
        corporate_number='2020001077174',
    ),
    'E02247': EdinetCodeEntry(
        edinet_code='E02247',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=863,
        fiscal_year_end='3月31日',
        submitter_name='ＧＭＢ株式会社',
        submitter_name_en='GMB CORPORATION',
        submitter_name_yomi='ジーエムビーカブシキガイシャ',
        address='磯城郡川西町大字吐田１５０番地３',
        industry='輸送用機器',
        sec_code='72140',
        corporate_number='2150001011467',
    ),
    'E02248': EdinetCodeEntry(
        edinet_code='E02248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=556,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カネミツ',
        submitter_name_en='KANEMITSU CORPORATION',
        submitter_name_yomi='カブシキガイシャカネミツ',
        address='明石市大蔵本町２０番２６号',
        industry='輸送用機器',
        sec_code='72080',
        corporate_number='8140001034728',
    ),
    'E02249': EdinetCodeEntry(
        edinet_code='E02249',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=41862,
        fiscal_year_end='3月31日',
        submitter_name='タカタ株式会社',
        submitter_name_en='Takata Corporation',
        submitter_name_yomi='タカタカブシキガイシャ',
        address='港区赤坂二丁目１２番３１号',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='5010401052766',
    ),
    'E02251': EdinetCodeEntry(
        edinet_code='E02251',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='昭和飛行機工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウワヒコウキコウギョウカブシキカイシャ',
        address='昭島市代官山三丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8012801007000',
    ),
    'E02252': EdinetCodeEntry(
        edinet_code='E02252',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15981,
        fiscal_year_end='3月31日',
        submitter_name='新明和工業株式会社',
        submitter_name_en='ShinMaywa Industries, Ltd.',
        submitter_name_yomi='シンメイワコウギョウカブシキガイシャ',
        address='宝塚市新明和町１番１号',
        industry='輸送用機器',
        sec_code='72240',
        corporate_number='7140001082323',
    ),
    'E02254': EdinetCodeEntry(
        edinet_code='E02254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5359,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャムコ',
        submitter_name_en='JAMCO CORPORATION',
        submitter_name_yomi='カブシキガイシャジャムコ',
        address='三鷹市大沢六丁目１１番２５号',
        industry='輸送用機器',
        sec_code='74080',
        corporate_number='6012401012609',
    ),
    'E02255': EdinetCodeEntry(
        edinet_code='E02255',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10311,
        fiscal_year_end=None,
        submitter_name='住友精密工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイミツコウギョウカブシキガイシャ',
        address='尼崎市扶桑町１番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001049416',
    ),
    'E02257': EdinetCodeEntry(
        edinet_code='E02257',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35613,
        fiscal_year_end='12月31日',
        submitter_name='株式会社シマノ',
        submitter_name_en='SHIMANO INC.',
        submitter_name_yomi='カブシキガイシャシマノ',
        address='堺市堺区老松町３丁７７番地',
        industry='輸送用機器',
        sec_code='73090',
        corporate_number='3120101003399',
    ),
    'E02258': EdinetCodeEntry(
        edinet_code='E02258',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3940,
        fiscal_year_end='3月31日',
        submitter_name='新家工業株式会社',
        submitter_name_en='ARAYA INDUSTRIAL CO.,LTD.',
        submitter_name_yomi='アラヤコウギョウカブシキガイシャ',
        address='大阪市中央区南船場二丁目１２番１２号',
        industry='鉄鋼',
        sec_code='73050',
        corporate_number='4120001077344',
    ),
    'E02261': EdinetCodeEntry(
        edinet_code='E02261',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=400,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ツノダ',
        submitter_name_en='TSUNODA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャツノダ',
        address='小牧市大字三ツ渕字東播州１６０４番地１',
        industry='不動産業',
        sec_code=None,
        corporate_number='4180001076159',
    ),
    'E02265': EdinetCodeEntry(
        edinet_code='E02265',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26648,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000島津製作所',
        submitter_name_en='Shimadzu Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000シマヅセイサクショ',
        address='京都市中京区西ノ京桑原町１',
        industry='精密機器',
        sec_code='77010',
        corporate_number='6130001021068',
    ),
    'E02266': EdinetCodeEntry(
        edinet_code='E02266',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7218,
        fiscal_year_end='3月31日',
        submitter_name='東京計器株式会社',
        submitter_name_en='TOKYO KEIKI INC.',
        submitter_name_yomi='トウキョウケイキ\u3000カブシキガイシャ',
        address='大田区南蒲田２丁目１６番４６号',
        industry='精密機器',
        sec_code='77210',
        corporate_number='3010801008436',
    ),
    'E02267': EdinetCodeEntry(
        edinet_code='E02267',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3218,
        fiscal_year_end='3月31日',
        submitter_name='愛知時計電機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイチトケイデンキカブシキガイシャ',
        address='名古屋市熱田区千年一丁目２番７０号',
        industry='精密機器',
        sec_code='77230',
        corporate_number='3180001021396',
    ),
    'E02269': EdinetCodeEntry(
        edinet_code='E02269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1930,
        fiscal_year_end='3月31日',
        submitter_name='黒田精工株式会社',
        submitter_name_en='KURODA PRECISION INDUSTRIES LTD.',
        submitter_name_yomi='クロダセイコウカブシキガイシャ',
        address='川崎市幸区堀川町５８０番地１６',
        industry='機械',
        sec_code='77260',
        corporate_number='7020001070810',
    ),
    'E02270': EdinetCodeEntry(
        edinet_code='E02270',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2200,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オーバル',
        submitter_name_en='OVAL Corporation',
        submitter_name_yomi='カブシキガイシャオーバル',
        address='新宿区上落合三丁目１０番８号',
        industry='精密機器',
        sec_code='77270',
        corporate_number='4011101003936',
    ),
    'E02271': EdinetCodeEntry(
        edinet_code='E02271',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=65476,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニコン',
        submitter_name_en='NIKON CORPORATION',
        submitter_name_yomi='カブシキガイシャニコン',
        address='品川区西大井一丁目５番２０号',
        industry='精密機器',
        sec_code='77310',
        corporate_number='5010001008763',
    ),
    'E02272': EdinetCodeEntry(
        edinet_code='E02272',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=124643,
        fiscal_year_end='3月31日',
        submitter_name='オリンパス株式会社',
        submitter_name_en='OLYMPUS CORPORATION',
        submitter_name_yomi='オリンパスカブシキガイシャ',
        address='八王子市石川町２９５１番地',
        industry='精密機器',
        sec_code='77330',
        corporate_number='5011001005222',
    ),
    'E02274': EdinetCodeEntry(
        edinet_code='E02274',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=174762,
        fiscal_year_end='12月31日',
        submitter_name='キヤノン株式会社',
        submitter_name_en='CANON INC.',
        submitter_name_yomi='キヤノンカブシキガイシャ',
        address='大田区下丸子三丁目３０番２号',
        industry='電気機器',
        sec_code='77510',
        corporate_number='6010801003186',
    ),
    'E02275': EdinetCodeEntry(
        edinet_code='E02275',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=135364,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リコー',
        submitter_name_en='RICOH COMPANY,LTD.',
        submitter_name_yomi='カブシキガイシャリコー',
        address='大田区中馬込一丁目３番６号',
        industry='電気機器',
        sec_code='77520',
        corporate_number='2010801012579',
    ),
    'E02280': EdinetCodeEntry(
        edinet_code='E02280',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='セイコーグループ株式会社',
        submitter_name_en='SEIKO GROUP CORPORATION',
        submitter_name_yomi='セイコーグループカブシキガイシャ',
        address='中央区銀座４丁目５番１１号',
        industry='精密機器',
        sec_code='80500',
        corporate_number='9010001034797',
    ),
    'E02281': EdinetCodeEntry(
        edinet_code='E02281',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32648,
        fiscal_year_end='3月31日',
        submitter_name='シチズン時計株式会社',
        submitter_name_en='Citizen Watch Co., Ltd.',
        submitter_name_yomi='シチズントケイカブシキガイシャ',
        address='西東京市田無町六丁目１番１２号',
        industry='精密機器',
        sec_code='77620',
        corporate_number='5012701004744',
    ),
    'E02282': EdinetCodeEntry(
        edinet_code='E02282',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1563,
        fiscal_year_end='3月31日',
        submitter_name='ジェコー株式会社',
        submitter_name_en='JECO CO.,LTD.',
        submitter_name_yomi='ジェコーカブシキガイシャ',
        address='行田市富士見町１丁目４番地１',
        industry='精密機器',
        sec_code=None,
        corporate_number='6030001086906',
    ),
    'E02285': EdinetCodeEntry(
        edinet_code='E02285',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2565,
        fiscal_year_end='3月31日',
        submitter_name='理研計器株式会社',
        submitter_name_en='RIKEN KEIKI CO.,LTD',
        submitter_name_yomi='リケンケイキカブシキガイシャ',
        address='板橋区小豆沢２丁目７番６号',
        industry='精密機器',
        sec_code='77340',
        corporate_number='3011401006846',
    ),
    'E02286': EdinetCodeEntry(
        edinet_code='E02286',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4292,
        fiscal_year_end='3月31日',
        submitter_name='株式会社チノー',
        submitter_name_en='Chino Corporation',
        submitter_name_yomi='カブシキガイシャチノー',
        address='板橋区熊野町３２番８号',
        industry='電気機器',
        sec_code='68500',
        corporate_number='9011401004118',
    ),
    'E02287': EdinetCodeEntry(
        edinet_code='E02287',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1609,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セコニック',
        submitter_name_en='SEKONIC CORPORATION',
        submitter_name_yomi='カブシキガイシャセコニック',
        address='世田谷区池尻三丁目１番３号',
        industry='機械',
        sec_code=None,
        corporate_number='8011601003630',
    ),
    'E02288': EdinetCodeEntry(
        edinet_code='E02288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54044,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＣＲＥＥＮホールディングス',
        submitter_name_en='SCREEN Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャスクリーンホールディングス',
        address='京都市上京区堀川通寺之内上る４丁目天神北町１番地の１',
        industry='電気機器',
        sec_code='77350',
        corporate_number='6130001003272',
    ),
    'E02289': EdinetCodeEntry(
        edinet_code='E02289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11573,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京精密',
        submitter_name_en='TOKYO SEIMITSU CO., LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウセイミツ',
        address='八王子市石川町２９６８番地２',
        industry='精密機器',
        sec_code='77290',
        corporate_number='5010101009430',
    ),
    'E02290': EdinetCodeEntry(
        edinet_code='E02290',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=497,
        fiscal_year_end='3月31日',
        submitter_name='大和製衡株式会社',
        submitter_name_en='Yamato Scale Co.,Ltd.',
        submitter_name_yomi='ヤマトセイコウカブシキガイシャ',
        address='明石市茶園場町５番２２号',
        industry='精密機器',
        sec_code=None,
        corporate_number='7140001035636',
    ),
    'E02293': EdinetCodeEntry(
        edinet_code='E02293',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16403,
        fiscal_year_end='1月31日',
        submitter_name='株式会社三井ハイテック',
        submitter_name_en='Mitsui High-tec, Inc.',
        submitter_name_yomi='カブシキガイシャミツイハイテック',
        address='北九州市八幡西区小嶺二丁目１０番１号',
        industry='電気機器',
        sec_code='69660',
        corporate_number='6290801010667',
    ),
    'E02294': EdinetCodeEntry(
        edinet_code='E02294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12372,
        fiscal_year_end='3月31日',
        submitter_name='リズム株式会社',
        submitter_name_en='RHYTHM CO.,LTD.',
        submitter_name_yomi='リズムカブシキガイシャ',
        address='さいたま市大宮区北袋町一丁目２９９番地１２',
        industry='精密機器',
        sec_code='77690',
        corporate_number='9030001010524',
    ),
    'E02296': EdinetCodeEntry(
        edinet_code='E02296',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3522,
        fiscal_year_end='12月31日',
        submitter_name='日東精工株式会社',
        submitter_name_en='NITTO SEIKO CO.,LTD.',
        submitter_name_yomi='ニットウセイコウカブシキガイシャ',
        address='綾部市井倉町梅ヶ畑２０番地',
        industry='金属製品',
        sec_code='59570',
        corporate_number='2130001041813',
    ),
    'E02299': EdinetCodeEntry(
        edinet_code='E02299',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16984,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000トプコン',
        submitter_name_en='TOPCON CORPORATION',
        submitter_name_yomi='カブシキガイシャトプコン',
        address='板橋区蓮沼町７５番１号',
        industry='精密機器',
        sec_code='77320',
        corporate_number='4011401004725',
    ),
    'E02300': EdinetCodeEntry(
        edinet_code='E02300',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=391,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000ミツトヨ',
        submitter_name_en='Mitutoyo Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000ミツトヨ',
        address='川崎市高津区坂戸一丁目２０番１号',
        industry='精密機器',
        sec_code=None,
        corporate_number='7020001067105',
    ),
    'E02301': EdinetCodeEntry(
        edinet_code='E02301',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4969,
        fiscal_year_end='12月31日',
        submitter_name='キヤノン電子株式会社',
        submitter_name_en='CANON ELECTRONICS INC.',
        submitter_name_yomi='キヤノンデンシカブシキガイシャ',
        address='秩父市下影森１２４８番地',
        industry='電気機器',
        sec_code='77390',
        corporate_number='7030001090700',
    ),
    'E02302': EdinetCodeEntry(
        edinet_code='E02302',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12721,
        fiscal_year_end='12月31日',
        submitter_name='スター精密株式会社',
        submitter_name_en='STAR MICRONICS CO.,LTD.',
        submitter_name_yomi='スターセイミツカブシキガイシャ',
        address='静岡市駿河区中吉田２０番１０号',
        industry='機械',
        sec_code='77180',
        corporate_number='9080001002327',
    ),
    'E02303': EdinetCodeEntry(
        edinet_code='E02303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7411,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジェイ・エム・エス（称号\u3000株式会社\u3000ＪＭＳ）',
        submitter_name_en='JMS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジェイエムエス',
        address='広島市中区加古町１２番１７号',
        industry='精密機器',
        sec_code='77020',
        corporate_number='5240001004384',
    ),
    'E02304': EdinetCodeEntry(
        edinet_code='E02304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4621,
        fiscal_year_end='3月31日',
        submitter_name='フクダ電子株式会社',
        submitter_name_en='FUKUDA DENSHI CO.,LTD.',
        submitter_name_yomi='フクダデンシカブシキガイシャ',
        address='文京区本郷三丁目３９番４号',
        industry='電気機器',
        sec_code='69600',
        corporate_number='7010001006880',
    ),
    'E02305': EdinetCodeEntry(
        edinet_code='E02305',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10199,
        fiscal_year_end='3月31日',
        submitter_name='ＭＵＴＯＨホールディングス株式会社',
        submitter_name_en='MUTOH HOLDINGS CO., LTD.',
        submitter_name_yomi='ムトーホールディングスカブシキガイシャ',
        address='世田谷区池尻３丁目１番３号',
        industry='電気機器',
        sec_code='79990',
        corporate_number='7010701019406',
    ),
    'E02306': EdinetCodeEntry(
        edinet_code='E02306',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7134,
        fiscal_year_end='12月31日',
        submitter_name='株式会社小野測器',
        submitter_name_en='ONO SOKKI Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャオノソッキ',
        address='横浜市西区みなとみらい三丁目３番３号\u3000横浜コネクトスクエア\u3000１２階',
        industry='電気機器',
        sec_code='68580',
        corporate_number='1020001001886',
    ),
    'E02307': EdinetCodeEntry(
        edinet_code='E02307',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6895,
        fiscal_year_end='3月31日',
        submitter_name='エスペック株式会社',
        submitter_name_en='ESPEC CORP.',
        submitter_name_yomi='エスペックカブシキガイシャ',
        address='大阪市北区天神橋三丁目５番６号',
        industry='電気機器',
        sec_code='68590',
        corporate_number='7120001059661',
    ),
    'E02308': EdinetCodeEntry(
        edinet_code='E02308',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6923,
        fiscal_year_end='12月31日',
        submitter_name='株式会社タムロン',
        submitter_name_en='Tamron Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャタムロン',
        address='さいたま市見沼区蓮沼１３８５番地',
        industry='精密機器',
        sec_code='77400',
        corporate_number='5030001011204',
    ),
    'E02310': EdinetCodeEntry(
        edinet_code='E02310',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6642,
        fiscal_year_end='3月31日',
        submitter_name='川澄化学工業株式会社',
        submitter_name_en='Kawasumi Laboratories, Incorporated',
        submitter_name_yomi='カワスミカガクコウギョウカブシキガイシャ',
        address='佐伯市弥生大字小田１０７７',
        industry='精密機器',
        sec_code=None,
        corporate_number='5320001009417',
    ),
    'E02315': EdinetCodeEntry(
        edinet_code='E02315',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7123,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホギメディカル',
        submitter_name_en='HOGY MEDICAL CO.,LTD.',
        submitter_name_yomi='カブシキガイシャホギメディカル',
        address='港区赤坂２丁目４番６号\u3000赤坂グリーンクロス１９階',
        industry='繊維製品',
        sec_code='35930',
        corporate_number='2010401047109',
    ),
    'E02320': EdinetCodeEntry(
        edinet_code='E02320',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='ジーエルサイエンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーエルサイエンスカブシキガイシャ',
        address='新宿区西新宿六丁目２２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011101008586',
    ),
    'E02322': EdinetCodeEntry(
        edinet_code='E02322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7025,
        fiscal_year_end='12月31日',
        submitter_name='ノーリツ鋼機株式会社',
        submitter_name_en='Noritsu Koki Co.,Ltd.',
        submitter_name_yomi='ノーリツコウキカブシキガイシャ',
        address='港区麻布十番１丁目１０番１０号',
        industry='精密機器',
        sec_code='77440',
        corporate_number='9170001002607',
    ),
    'E02323': EdinetCodeEntry(
        edinet_code='E02323',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2623,
        fiscal_year_end='5月31日',
        submitter_name='シグマ光機株式会社',
        submitter_name_en='SIGMAKOKI  CO.,LTD.',
        submitter_name_yomi='シグマコウキカブシキガイシャ',
        address='日高市下高萩新田１７番地２',
        industry='精密機器',
        sec_code='77130',
        corporate_number='8030001089741',
    ),
    'E02324': EdinetCodeEntry(
        edinet_code='E02324',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=693,
        fiscal_year_end='6月30日',
        submitter_name='アクモス株式会社',
        submitter_name_en='ACMOS INC.',
        submitter_name_yomi='アクモスカブシキガイシャ',
        address='港区虎ノ門一丁目２１番１９号',
        industry='情報・通信業',
        sec_code='68880',
        corporate_number='8010001009651',
    ),
    'E02325': EdinetCodeEntry(
        edinet_code='E02325',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2018,
        fiscal_year_end='3月31日',
        submitter_name='日本精密株式会社',
        submitter_name_en='Nihon Seimitsu Co.,Ltd.',
        submitter_name_yomi='ニホンセイミツカブシキガイシャ',
        address='川口市本町四丁目１番８号',
        industry='精密機器',
        sec_code='77710',
        corporate_number='6030001076535',
    ),
    'E02328': EdinetCodeEntry(
        edinet_code='E02328',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=982,
        fiscal_year_end='2月末日',
        submitter_name='ローツェ株式会社',
        submitter_name_en='RORZE CORPORATION',
        submitter_name_yomi='ローツェカブシキガイシャ',
        address='福山市神辺町字道上１５８８番地の２',
        industry='機械',
        sec_code='63230',
        corporate_number='9240001029584',
    ),
    'E02329': EdinetCodeEntry(
        edinet_code='E02329',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4380,
        fiscal_year_end='3月31日',
        submitter_name='長野計器株式会社',
        submitter_name_en='NAGANO KEIKI  CO., LTD.',
        submitter_name_yomi='ナガノケイキカブシキガイシャ',
        address='大田区東馬込１丁目３０番４号',
        industry='精密機器',
        sec_code='77150',
        corporate_number='7010801008721',
    ),
    'E02331': EdinetCodeEntry(
        edinet_code='E02331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=867,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ナカニシ',
        submitter_name_en='NAKANISHI INC.',
        submitter_name_yomi='カブシキガイシャナカニシ',
        address='鹿沼市下日向７００番地',
        industry='精密機器',
        sec_code='77160',
        corporate_number='1060001010545',
    ),
    'E02333': EdinetCodeEntry(
        edinet_code='E02333',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=992,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本トリム',
        submitter_name_en='NIHON TRIM.,CO.LTD.',
        submitter_name_yomi='カブシキガイシャニホントリム',
        address='大阪市北区大淀中１－８－３４',
        industry='電気機器',
        sec_code='67880',
        corporate_number='8120001072952',
    ),
    'E02334': EdinetCodeEntry(
        edinet_code='E02334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2847,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ブイ・テクノロジー',
        submitter_name_en='V Technology Co., Ltd.',
        submitter_name_yomi='カブシキガイシャブイテクノロジー',
        address='横浜市保土ヶ谷区神戸町１３４番地',
        industry='精密機器',
        sec_code='77170',
        corporate_number='3020001043968',
    ),
    'E02335': EdinetCodeEntry(
        edinet_code='E02335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1023,
        fiscal_year_end='3月31日',
        submitter_name='国際計測器株式会社',
        submitter_name_en='KOKUSAI CO.,LTD',
        submitter_name_yomi='コクサイケイソクキカブシキガイシャ',
        address='多摩市永山６丁目２１番１号',
        industry='精密機器',
        sec_code='77220',
        corporate_number='3013401001100',
    ),
    'E02336': EdinetCodeEntry(
        edinet_code='E02336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1760,
        fiscal_year_end='5月31日',
        submitter_name='株式会社インターアクション',
        submitter_name_en='INTER ACTION Corporation',
        submitter_name_yomi='カブシキガイシャインターアクション',
        address='横浜市金沢区福浦一丁目１番地',
        industry='精密機器',
        sec_code='77250',
        corporate_number='8020001005906',
    ),
    'E02337': EdinetCodeEntry(
        edinet_code='E02337',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1951,
        fiscal_year_end='3月31日',
        submitter_name='クボテック株式会社',
        submitter_name_en='KUBOTEK CORPORATION',
        submitter_name_yomi='クボテックカブシキガイシャ',
        address='大阪市北区中之島四丁目３番３６号玉江橋ビル内',
        industry='精密機器',
        sec_code='77090',
        corporate_number='8120001063299',
    ),
    'E02338': EdinetCodeEntry(
        edinet_code='E02338',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='プレシジョン・システム・サイエンス株式会社',
        submitter_name_en='Precision System Science Co., Ltd.',
        submitter_name_yomi='プレシジョンシステムサイエンスカブシキガイシャ',
        address='松戸市上本郷８８番地',
        industry='精密機器',
        sec_code='77070',
        corporate_number='9040001037483',
    ),
    'E02340': EdinetCodeEntry(
        edinet_code='E02340',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1059,
        fiscal_year_end='8月31日',
        submitter_name='マニー株式会社',
        submitter_name_en='MANI, INC.',
        submitter_name_yomi='マニーカブシキガイシャ',
        address='宇都宮市清原工業団地８番３',
        industry='精密機器',
        sec_code='77300',
        corporate_number='4060001005922',
    ),
    'E02342': EdinetCodeEntry(
        edinet_code='E02342',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1359,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アルチザネットワークス',
        submitter_name_en='Artiza Networks, Inc.',
        submitter_name_yomi='カブシキガイシャアルチザネットワークス',
        address='立川市曙町二丁目３６番２号',
        industry='電気機器',
        sec_code='67780',
        corporate_number='2012801000217',
    ),
    'E02343': EdinetCodeEntry(
        edinet_code='E02343',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=292,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エーワン精密',
        submitter_name_en='A-ONE SEIMITSU INC.',
        submitter_name_yomi='カブシキガイシャエーワンセイミツ',
        address='府中市分梅町二丁目２０番５号',
        industry='機械',
        sec_code='61560',
        corporate_number='5012401000218',
    ),
    'E02344': EdinetCodeEntry(
        edinet_code='E02344',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6388,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ａ＆Ｄホロンホールディングス',
        submitter_name_en='A&D HOLON Holdings Company, Limited',
        submitter_name_yomi='カブシキガイシャエーアンドデイホロンホールディングス',
        address='豊島区東池袋三丁目２３番１４号',
        industry='精密機器',
        sec_code='77450',
        corporate_number='5013301001710',
    ),
    'E02345': EdinetCodeEntry(
        edinet_code='E02345',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1069,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノメディカ',
        submitter_name_en='Techno Medica Co., Ltd.',
        submitter_name_yomi='カブシキガイシャテクノメディカ',
        address='横浜市都筑区仲町台５丁目５番１号',
        industry='電気機器',
        sec_code='66780',
        corporate_number='4020001032202',
    ),
    'E02346': EdinetCodeEntry(
        edinet_code='E02346',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4109,
        fiscal_year_end='9月30日',
        submitter_name='株式会社エスケーエレクトロニクス',
        submitter_name_en='SK-Electronics CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエスケーエレクトロニクス',
        address='京都市上京区東堀川通リ一条上ル竪富田町４３６番地の２',
        industry='電気機器',
        sec_code='66770',
        corporate_number='4130001023818',
    ),
    'E02348': EdinetCodeEntry(
        edinet_code='E02348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='フジプレアム株式会社',
        submitter_name_en='Fujipream Corporation',
        submitter_name_yomi='フジプレアムカブシキガイシャ',
        address='姫路市飾西３８番地１',
        industry='化学',
        sec_code='42370',
        corporate_number='7140001061401',
    ),
    'E02349': EdinetCodeEntry(
        edinet_code='E02349',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18860,
        fiscal_year_end='6月30日',
        submitter_name='朝日インテック株式会社',
        submitter_name_en='ASAHI  INTECC CO.,LTD.',
        submitter_name_yomi='アサヒインテックカブシキガイシャ',
        address='瀬戸市暁町３番地１００',
        industry='精密機器',
        sec_code='77470',
        corporate_number='8180001049706',
    ),
    'E02350': EdinetCodeEntry(
        edinet_code='E02350',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3495,
        fiscal_year_end='12月31日',
        submitter_name='タツモ株式会社',
        submitter_name_en='TAZMO CO.,LTD',
        submitter_name_yomi='タツモカブシキガイシャ',
        address='岡山市北区芳賀５３１１',
        industry='機械',
        sec_code='62660',
        corporate_number='6260001018266',
    ),
    'E02352': EdinetCodeEntry(
        edinet_code='E02352',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=464,
        fiscal_year_end='9月30日',
        submitter_name='ＩＭＶ株式会社',
        submitter_name_en='IMV CORPORATION',
        submitter_name_yomi='アイエムブイカブシキガイシャ',
        address='大阪市西淀川区竹島二丁目６番１０号',
        industry='精密機器',
        sec_code='77600',
        corporate_number='3120001059756',
    ),
    'E02353': EdinetCodeEntry(
        edinet_code='E02353',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1764,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホロン',
        submitter_name_en='HOLON  CO.,LTD.',
        submitter_name_yomi='カブシキガイシャホロン',
        address='所沢市南永井１０２６－１',
        industry='精密機器',
        sec_code=None,
        corporate_number='7030001029814',
    ),
    'E02354': EdinetCodeEntry(
        edinet_code='E02354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1241,
        fiscal_year_end='3月31日',
        submitter_name='メディキット株式会社',
        submitter_name_en='MEDIKIT CO.,LTD',
        submitter_name_yomi='メディキットカブシキガイシャ',
        address='文京区湯島一丁目１３番２号',
        industry='精密機器',
        sec_code='77490',
        corporate_number='9010001007828',
    ),
    'E02356': EdinetCodeEntry(
        edinet_code='E02356',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1141,
        fiscal_year_end='4月30日',
        submitter_name='インスペック株式会社',
        submitter_name_en='inspec Inc.',
        submitter_name_yomi='インスペックカブシキガイシャ',
        address='仙北市角館町雲然荒屋敷７９番地の１',
        industry='電気機器',
        sec_code='66560',
        corporate_number='7410001008548',
    ),
    'E02357': EdinetCodeEntry(
        edinet_code='E02357',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3997,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャパン・ティッシュエンジニアリング',
        submitter_name_en='Japan Tissue Engineering Co., Ltd.',
        submitter_name_yomi='カブシキガイシャジャパンティッシュエンジニアリング',
        address='蒲郡市三谷北通６丁目２０９番地の１',
        industry='精密機器',
        sec_code='77740',
        corporate_number='4180301011063',
    ),
    'E02360': EdinetCodeEntry(
        edinet_code='E02360',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=700,
        fiscal_year_end='12月末日',
        submitter_name='株式会社太陽工機',
        submitter_name_en='TAIYO KOKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタイヨウコウキ',
        address='長岡市西陵町２２１番３５',
        industry='機械',
        sec_code=None,
        corporate_number='1110001022782',
    ),
    'E02362': EdinetCodeEntry(
        edinet_code='E02362',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28534,
        fiscal_year_end='3月31日',
        submitter_name='ヤマハ株式会社',
        submitter_name_en='YAMAHA CORPORATION',
        submitter_name_yomi='ヤマハカブシキガイシャ',
        address='浜松市中央区中沢町１０番１号',
        industry='その他製品',
        sec_code='79510',
        corporate_number='3080401005595',
    ),
    'E02363': EdinetCodeEntry(
        edinet_code='E02363',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7122,
        fiscal_year_end='3月31日',
        submitter_name='株式会社河合楽器製作所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカワイガッキセイサクショ',
        address='浜松市中央区寺島町２００番地',
        industry='その他製品',
        sec_code='79520',
        corporate_number='2080401001323',
    ),
    'E02365': EdinetCodeEntry(
        edinet_code='E02365',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4653,
        fiscal_year_end='12月31日',
        submitter_name='セーラー万年筆株式会社',
        submitter_name_en='The Sailor Pen Co.,Ltd.',
        submitter_name_yomi='セーラーマンネンヒツカブシキカイシャ',
        address='呉市天応西条二丁目１番６３号',
        industry='その他製品',
        sec_code='79920',
        corporate_number='9010601024727',
    ),
    'E02366': EdinetCodeEntry(
        edinet_code='E02366',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4497,
        fiscal_year_end='12月31日',
        submitter_name='三菱鉛筆株式会社',
        submitter_name_en='MITSUBISHI PENCIL CO.,LTD.',
        submitter_name_yomi='ミツビシエンピツカブシキガイシャ',
        address='品川区東大井五丁目２３番３７号',
        industry='その他製品',
        sec_code='79760',
        corporate_number='6010701009457',
    ),
    'E02367': EdinetCodeEntry(
        edinet_code='E02367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10065,
        fiscal_year_end='3月31日',
        submitter_name='任天堂株式会社',
        submitter_name_en='Nintendo Co., Ltd.',
        submitter_name_yomi='ニンテンドウカブシキガイシャ',
        address='京都市南区上鳥羽鉾立町１１番地１',
        industry='その他製品',
        sec_code='79740',
        corporate_number='1130001011420',
    ),
    'E02368': EdinetCodeEntry(
        edinet_code='E02368',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=11992,
        fiscal_year_end='3月31日',
        submitter_name='ＹＫＫ株式会社',
        submitter_name_en='YKK Corporation',
        submitter_name_yomi='ワイケイケイカブシキガイシャ',
        address='千代田区神田和泉町１番地',
        industry='その他製品',
        sec_code=None,
        corporate_number='6010001032696',
    ),
    'E02369': EdinetCodeEntry(
        edinet_code='E02369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18670,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オカムラ',
        submitter_name_en='OKAMURA CORPORATION',
        submitter_name_yomi='カブシキガイシャオカムラ',
        address='横浜市西区北幸二丁目７番１８号',
        industry='その他製品',
        sec_code='79940',
        corporate_number='3020001030157',
    ),
    'E02371': EdinetCodeEntry(
        edinet_code='E02371',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7351,
        fiscal_year_end='12月31日',
        submitter_name='株式会社イトーキ',
        submitter_name_en='ITOKI  CORPORATION',
        submitter_name_yomi='カブシキガイシャイトーキ',
        address='大阪市中央区淡路町一丁目６番１１号',
        industry='その他製品',
        sec_code='79720',
        corporate_number='9120001014301',
    ),
    'E02372': EdinetCodeEntry(
        edinet_code='E02372',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2998,
        fiscal_year_end='11月30日',
        submitter_name='株式会社くろがね工作所',
        submitter_name_en='Kurogane Kosakusho Ltd.',
        submitter_name_yomi='カブシキガイシャクロガネコウサクショ',
        address='大阪市西区新町一丁目４番２４号',
        industry='その他製品',
        sec_code='79970',
        corporate_number='8120001042947',
    ),
    'E02373': EdinetCodeEntry(
        edinet_code='E02373',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26356,
        fiscal_year_end='3月31日',
        submitter_name='タカラスタンダード株式会社',
        submitter_name_en='TAKARA STANDARD CO.,LTD.',
        submitter_name_yomi='タカラスタンダードカブシキガイシャ',
        address='大阪市城東区鴫野東１丁目２番１号',
        industry='その他製品',
        sec_code='79810',
        corporate_number='5120001015344',
    ),
    'E02376': EdinetCodeEntry(
        edinet_code='E02376',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=863,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ミロク',
        submitter_name_en='Miroku Corporation',
        submitter_name_yomi='カブシキガイシャミロク',
        address='南国市篠原５３７番地１',
        industry='その他製品',
        sec_code='79830',
        corporate_number='6490001006215',
    ),
    'E02377': EdinetCodeEntry(
        edinet_code='E02377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4804,
        fiscal_year_end='3月31日',
        submitter_name='マミヤ・オーピー株式会社',
        submitter_name_en='MAMIYA-OP CO.,LTD.',
        submitter_name_yomi='マミヤオーピーカブシキガイシャ',
        address='飯能市大字新光１番地１',
        industry='機械',
        sec_code='79910',
        corporate_number='7010701022392',
    ),
    'E02378': EdinetCodeEntry(
        edinet_code='E02378',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23972,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アシックス',
        submitter_name_en='ASICS Corporation',
        submitter_name_yomi='カブシキガイシャアシックス',
        address='神戸市中央区三宮町一丁目２番４号',
        industry='その他製品',
        sec_code='79360',
        corporate_number='8140001005877',
    ),
    'E02379': EdinetCodeEntry(
        edinet_code='E02379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20167,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ノーリツ',
        submitter_name_en='NORITZ CORPORATION',
        submitter_name_yomi='カブシキガイシャノーリツ',
        address='神戸市中央区江戸町９３番地',
        industry='金属製品',
        sec_code='59430',
        corporate_number='6140001010383',
    ),
    'E02380': EdinetCodeEntry(
        edinet_code='E02380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4700,
        fiscal_year_end='3月31日',
        submitter_name='テイ・エス\u3000テック株式会社',
        submitter_name_en='TS TECH CO., LTD.',
        submitter_name_yomi='テイエス\u3000テックカブシキガイシャ',
        address='朝霞市栄町三丁目７番２７号',
        industry='輸送用機器',
        sec_code='73130',
        corporate_number='8030001044928',
    ),
    'E02381': EdinetCodeEntry(
        edinet_code='E02381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12367,
        fiscal_year_end='3月31日',
        submitter_name='マックス株式会社',
        submitter_name_en='MAX CO., LTD.',
        submitter_name_yomi='マックスカブシキガイシャ',
        address='中央区日本橋箱崎町６番６号',
        industry='機械',
        sec_code='64540',
        corporate_number='2010001057739',
    ),
    'E02382': EdinetCodeEntry(
        edinet_code='E02382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4184,
        fiscal_year_end='3月31日',
        submitter_name='グローブライド株式会社',
        submitter_name_en='GLOBERIDE, Inc.',
        submitter_name_yomi='グローブライドカブシキガイシャ',
        address='東久留米市前沢３丁目１４番１６号',
        industry='その他製品',
        sec_code='79900',
        corporate_number='5012701003630',
    ),
    'E02383': EdinetCodeEntry(
        edinet_code='E02383',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=570,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000重松製作所',
        submitter_name_en='SHIGEMATSU WORKS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000シゲマツセイサクショ',
        address='北区西ケ原一丁目２６番１号',
        industry='その他製品',
        sec_code='79800',
        corporate_number='6011501017030',
    ),
    'E02385': EdinetCodeEntry(
        edinet_code='E02385',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=601,
        fiscal_year_end='3月31日',
        submitter_name='ネポン株式会社',
        submitter_name_en='NEPON Inc.',
        submitter_name_yomi='ネポンカブシキガイシャ',
        address='厚木市上古沢４１１番地',
        industry='金属製品',
        sec_code='79850',
        corporate_number='7011001018214',
    ),
    'E02386': EdinetCodeEntry(
        edinet_code='E02386',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7290,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニフコ',
        submitter_name_en='NIFCO INC.',
        submitter_name_yomi='カブシキガイシャニフコ',
        address='横須賀市光の丘５番３号',
        industry='化学',
        sec_code='79880',
        corporate_number='5020001007855',
    ),
    'E02387': EdinetCodeEntry(
        edinet_code='E02387',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2167,
        fiscal_year_end='3月31日',
        submitter_name='盟和産業株式会社',
        submitter_name_en='MEIWA Industry Co.,Ltd',
        submitter_name_yomi='メイワサンギョウカブシキガイシャ',
        address='厚木市寿町三丁目１番１号ルリエ本厚木',
        industry='輸送用機器',
        sec_code='72840',
        corporate_number='9021001020555',
    ),
    'E02388': EdinetCodeEntry(
        edinet_code='E02388',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11635,
        fiscal_year_end='3月31日',
        submitter_name='信越ポリマー株式会社',
        submitter_name_en='Shin-Etsu Polymer Co.,Ltd.',
        submitter_name_yomi='シンエツポリマーカブシキガイシャ',
        address='千代田区大手町一丁目１番３号',
        industry='化学',
        sec_code='79700',
        corporate_number='4010001034802',
    ),
    'E02389': EdinetCodeEntry(
        edinet_code='E02389',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4475,
        fiscal_year_end='12月31日',
        submitter_name='立川ブラインド工業株式会社',
        submitter_name_en='TACHIKAWA CORPORATION',
        submitter_name_yomi='タチカワブラインドコウギョウカブシキガイシャ',
        address='港区三田三丁目１番１２号',
        industry='金属製品',
        sec_code='79890',
        corporate_number='4010401017209',
    ),
    'E02390': EdinetCodeEntry(
        edinet_code='E02390',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8080,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エンプラス',
        submitter_name_en='ENPLAS CORPORATION',
        submitter_name_yomi='カブシキガイシャエンプラス',
        address='川口市並木２丁目３０番１号',
        industry='電気機器',
        sec_code='69610',
        corporate_number='5030001074060',
    ),
    'E02392': EdinetCodeEntry(
        edinet_code='E02392',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＡＳＡＫＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタサキ',
        address='神戸市中央区港島中町６丁目３番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401130224',
    ),
    'E02394': EdinetCodeEntry(
        edinet_code='E02394',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23355,
        fiscal_year_end='3月31日',
        submitter_name='リンテック株式会社',
        submitter_name_en='LINTEC Corporation',
        submitter_name_yomi='リンテックカブシキガイシャ',
        address='板橋区本町２３番２３号',
        industry='その他製品',
        sec_code='79660',
        corporate_number='7011401006867',
    ),
    'E02395': EdinetCodeEntry(
        edinet_code='E02395',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4022,
        fiscal_year_end='11月20日',
        submitter_name='象印マホービン株式会社',
        submitter_name_en='ZOJIRUSHI CORPORATION',
        submitter_name_yomi='ゾウジルシマホービンカブシキガイシャ',
        address='大阪市北区天満１丁目２０番５号',
        industry='電気機器',
        sec_code='79650',
        corporate_number='5120001059655',
    ),
    'E02396': EdinetCodeEntry(
        edinet_code='E02396',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=674,
        fiscal_year_end='12月31日',
        submitter_name='興研株式会社',
        submitter_name_en='KOKEN LTD.',
        submitter_name_yomi='コウケンカブシキガイシャ',
        address='千代田区四番町７番地',
        industry='その他製品',
        sec_code='79630',
        corporate_number='3010001016132',
    ),
    'E02397': EdinetCodeEntry(
        edinet_code='E02397',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社セガ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセガ',
        address='品川区西品川一丁目１番１号住友不動産大崎ガーデンタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010801006141',
    ),
    'E02398': EdinetCodeEntry(
        edinet_code='E02398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1978,
        fiscal_year_end='6月20日',
        submitter_name='株式会社キングジム',
        submitter_name_en='KING JIM CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキングジム',
        address='千代田区東神田二丁目１０番１８号',
        industry='その他製品',
        sec_code='79620',
        corporate_number='8010001014924',
    ),
    'E02401': EdinetCodeEntry(
        edinet_code='E02401',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6362,
        fiscal_year_end=None,
        submitter_name='株式会社オリバー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオリバー',
        address='岡崎市薮田一丁目１番地１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180301000454',
    ),
    'E02402': EdinetCodeEntry(
        edinet_code='E02402',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4791,
        fiscal_year_end='12月31日',
        submitter_name='フジコピアン株式会社',
        submitter_name_en='FUJICOPIAN CO., LTD.',
        submitter_name_yomi='フジコピアンカブシキガイシャ',
        address='大阪市西淀川区御幣島五丁目４番１４号',
        industry='その他製品',
        sec_code='79570',
        corporate_number='8120001050578',
    ),
    'E02403': EdinetCodeEntry(
        edinet_code='E02403',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16755,
        fiscal_year_end='3月31日',
        submitter_name='株式会社平和',
        submitter_name_en='Heiwa Corporation',
        submitter_name_yomi='カブシキガイシャヘイワ',
        address='台東区東上野一丁目１６番１号',
        industry='機械',
        sec_code='64120',
        corporate_number='3010501026647',
    ),
    'E02404': EdinetCodeEntry(
        edinet_code='E02404',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5199,
        fiscal_year_end='12月31日',
        submitter_name='ピジョン株式会社',
        submitter_name_en='PIGEON CORPORATION',
        submitter_name_yomi='ピジョンカブシキガイシャ',
        address='中央区日本橋久松町４番４号',
        industry='その他製品',
        sec_code='79560',
        corporate_number='8010001027298',
    ),
    'E02406': EdinetCodeEntry(
        edinet_code='E02406',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13267,
        fiscal_year_end='3月31日',
        submitter_name='クリナップ株式会社',
        submitter_name_en='Cleanup Corporation',
        submitter_name_yomi='クリナップカブシキガイシャ',
        address='荒川区西日暮里６丁目２２番２２号',
        industry='その他製品',
        sec_code='79550',
        corporate_number='6011501006231',
    ),
    'E02407': EdinetCodeEntry(
        edinet_code='E02407',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2515,
        fiscal_year_end='3月31日',
        submitter_name='日本デコラックス株式会社',
        submitter_name_en='NIHON DECOLUXE CO.,LTD.',
        submitter_name_yomi='ニホンデコラックスカブシキガイシャ',
        address='丹羽郡扶桑町大字柏森字前屋敷１０番地',
        industry='化学',
        sec_code='79500',
        corporate_number='8180001081246',
    ),
    'E02408': EdinetCodeEntry(
        edinet_code='E02408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3099,
        fiscal_year_end='3月31日',
        submitter_name='小松ウオール工業株式会社',
        submitter_name_en='KOMATSU WALL INDUSTRY CO., LTD.',
        submitter_name_yomi='コマツウオールコウギョウカブシキガイシャ',
        address='小松市工業団地１丁目７２番地',
        industry='その他製品',
        sec_code='79490',
        corporate_number='9220001011932',
    ),
    'E02409': EdinetCodeEntry(
        edinet_code='E02409',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3373,
        fiscal_year_end='3月20日',
        submitter_name='エムケー精工株式会社',
        submitter_name_en='MK SEIKO CO., LTD.',
        submitter_name_yomi='エムケーセイコウカブシキガイシャ',
        address='千曲市大字雨宮１８２５番地',
        industry='金属製品',
        sec_code='59060',
        corporate_number='2100001006100',
    ),
    'E02410': EdinetCodeEntry(
        edinet_code='E02410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14114,
        fiscal_year_end='3月31日',
        submitter_name='理想科学工業株式会社',
        submitter_name_en='RISO KAGAKU CORPORATION',
        submitter_name_yomi='リソウカガクコウギョウカブシキガイシャ',
        address='港区芝五丁目３４番７号',
        industry='機械',
        sec_code='64130',
        corporate_number='9010401031452',
    ),
    'E02411': EdinetCodeEntry(
        edinet_code='E02411',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3084,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニレコ',
        submitter_name_en='NIRECO CORPORATION',
        submitter_name_yomi='カブシキガイシャニレコ',
        address='八王子市石川町２９５１－４',
        industry='電気機器',
        sec_code='68630',
        corporate_number='5010101003020',
    ),
    'E02412': EdinetCodeEntry(
        edinet_code='E02412',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13150,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エフピコ',
        submitter_name_en='FP CORPORATION',
        submitter_name_yomi='カブシキガイシャエフピコ',
        address='福山市曙町一丁目１３番１５号',
        industry='化学',
        sec_code='79470',
        corporate_number='5240001029984',
    ),
    'E02413': EdinetCodeEntry(
        edinet_code='E02413',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='コマニー株式会社',
        submitter_name_en='COMANY INC.',
        submitter_name_yomi='コマニーカブシキガイシャ',
        address='小松市工業団地一丁目９３番地',
        industry='その他製品',
        sec_code=None,
        corporate_number='8220001011999',
    ),
    'E02414': EdinetCodeEntry(
        edinet_code='E02414',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3532,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シード',
        submitter_name_en='SEED CO.,LTD.',
        submitter_name_yomi='カブシキガイシャシード',
        address='文京区本郷二丁目４０番２号',
        industry='精密機器',
        sec_code='77430',
        corporate_number='7010001003408',
    ),
    'E02415': EdinetCodeEntry(
        edinet_code='E02415',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8136,
        fiscal_year_end='3月31日',
        submitter_name='ニチハ株式会社',
        submitter_name_en='NICHIHA CORPORATION',
        submitter_name_yomi='ニチハカブシキガイシャ',
        address='名古屋市港区汐止町１２番地',
        industry='ガラス・土石製品',
        sec_code='79430',
        corporate_number='4180001007155',
    ),
    'E02416': EdinetCodeEntry(
        edinet_code='E02416',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1461,
        fiscal_year_end='12月31日',
        submitter_name='クリエートメディック株式会社',
        submitter_name_en='CREATE MEDIC CO.,LTD.',
        submitter_name_yomi='クリエートメディックカブシキガイシャ',
        address='横浜市都筑区茅ヶ崎南二丁目５番２５号',
        industry='精密機器',
        sec_code='51870',
        corporate_number='7020001008505',
    ),
    'E02417': EdinetCodeEntry(
        edinet_code='E02417',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33239,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カプコン',
        submitter_name_en='CAPCOM CO., LTD.',
        submitter_name_yomi='カブシキガイシャカプコン',
        address='大阪市中央区内平野町三丁目１番３号',
        industry='情報・通信業',
        sec_code='96970',
        corporate_number='3120001077023',
    ),
    'E02419': EdinetCodeEntry(
        edinet_code='E02419',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14840,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三共',
        submitter_name_en='SANKYO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンキョウ',
        address='渋谷区渋谷三丁目２９番１４号',
        industry='機械',
        sec_code='64170',
        corporate_number='3011001057538',
    ),
    'E02421': EdinetCodeEntry(
        edinet_code='E02421',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2094,
        fiscal_year_end='12月31日',
        submitter_name='日本エアーテック株式会社',
        submitter_name_en='AIRTECH JAPAN,LTD.',
        submitter_name_yomi='ニホンエアーテックカブシキガイシャ',
        address='台東区入谷一丁目１４番９号',
        industry='機械',
        sec_code='62910',
        corporate_number='5010501009996',
    ),
    'E02423': EdinetCodeEntry(
        edinet_code='E02423',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6600,
        fiscal_year_end='3月31日',
        submitter_name='ＺＡＣＲＯＳ株式会社',
        submitter_name_en='ZACROS Corporation',
        submitter_name_yomi='ザクロスカブシキカイシャ',
        address='文京区小石川一丁目１番１号',
        industry='化学',
        sec_code='79170',
        corporate_number='6011101056965',
    ),
    'E02424': EdinetCodeEntry(
        edinet_code='E02424',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7934,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マースグループホールディングス',
        submitter_name_en='Mars Group Holdings Corporation',
        submitter_name_yomi='カブシキガイシャマースグループホールディングス',
        address='新宿区新宿一丁目１０番７号',
        industry='機械',
        sec_code='64190',
        corporate_number='7011101019888',
    ),
    'E02425': EdinetCodeEntry(
        edinet_code='E02425',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3274,
        fiscal_year_end='3月31日',
        submitter_name='株式会社きもと',
        submitter_name_en='KIMOTO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキモト',
        address='いなべ市北勢町京ヶ野新田４５０番地',
        industry='化学',
        sec_code='79080',
        corporate_number='9011101005242',
    ),
    'E02427': EdinetCodeEntry(
        edinet_code='E02427',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4706,
        fiscal_year_end='3月31日',
        submitter_name='ヨネックス株式会社',
        submitter_name_en='YONEX CO.,LTD.',
        submitter_name_yomi='ヨネックスカブシキガイシャ',
        address='文京区湯島三丁目２３番１３号',
        industry='その他製品',
        sec_code='79060',
        corporate_number='4010001008228',
    ),
    'E02428': EdinetCodeEntry(
        edinet_code='E02428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=925,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソノコム',
        submitter_name_en='SONOCOM CO.,LTD.',
        submitter_name_yomi='カブシキガイシャソノコム',
        address='目黒区目黒本町二丁目１５番１０号',
        industry='その他製品',
        sec_code='79020',
        corporate_number='5013201003278',
    ),
    'E02429': EdinetCodeEntry(
        edinet_code='E02429',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7212,
        fiscal_year_end='3月31日',
        submitter_name='中央化学株式会社',
        submitter_name_en='CHUO KAGAKU CO.,LTD.',
        submitter_name_yomi='チュウオウカガクカブシキカイシャ',
        address='鴻巣市宮地３丁目５番１号',
        industry='化学',
        sec_code=None,
        corporate_number='7030001061800',
    ),
    'E02430': EdinetCodeEntry(
        edinet_code='E02430',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=774,
        fiscal_year_end='4月30日',
        submitter_name='ＭＩＣＳ化学株式会社',
        submitter_name_en='MICS CHEMICAL CO.,LTD.',
        submitter_name_yomi='ミックスカガクカブシキガイシャ',
        address='愛知郡東郷町大字諸輪字北山１５８番地８９',
        industry='化学',
        sec_code=None,
        corporate_number='8180001067476',
    ),
    'E02431': EdinetCodeEntry(
        edinet_code='E02431',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4043,
        fiscal_year_end='3月31日',
        submitter_name='ジオマテック株式会社',
        submitter_name_en='GEOMATEC CO.,LTD.',
        submitter_name_yomi='ジオマテックカブシキガイシャ',
        address='横浜市西区みなとみらい二丁目２番１号',
        industry='電気機器',
        sec_code='69070',
        corporate_number='1020001015003',
    ),
    'E02433': EdinetCodeEntry(
        edinet_code='E02433',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3013,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000桑山',
        submitter_name_en='KUWAYAMA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000クワヤマ',
        address='台東区東上野２丁目２３番２１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='4010501004131',
    ),
    'E02435': EdinetCodeEntry(
        edinet_code='E02435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2015,
        fiscal_year_end='3月31日',
        submitter_name='タカノ株式会社',
        submitter_name_en='TAKANO CO.,Ltd.',
        submitter_name_yomi='タカノカブシキガイシャ',
        address='上伊那郡宮田村１３７番地',
        industry='その他製品',
        sec_code='78850',
        corporate_number='8100001021275',
    ),
    'E02438': EdinetCodeEntry(
        edinet_code='E02438',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3164,
        fiscal_year_end='2月末日',
        submitter_name='株式会社マルゼン',
        submitter_name_en='MARUZEN CO., LTD.',
        submitter_name_yomi='カブシキガイシャマルゼン',
        address='台東区根岸二丁目１９番１８号',
        industry='金属製品',
        sec_code='59820',
        corporate_number='3010501014528',
    ),
    'E02439': EdinetCodeEntry(
        edinet_code='E02439',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=602,
        fiscal_year_end='1月31日',
        submitter_name='株式会社光・彩',
        submitter_name_en='Kohsai Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコウサイ',
        address='甲斐市竜地３０４９番地',
        industry='その他製品',
        sec_code='78780',
        corporate_number='8090001004562',
    ),
    'E02441': EdinetCodeEntry(
        edinet_code='E02441',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1241,
        fiscal_year_end='3月31日',
        submitter_name='永大化工株式会社',
        submitter_name_en='EIDAI KAKO CO.,LTD.',
        submitter_name_yomi='エイダイカコウカブシキガイシャ',
        address='大阪市平野区平野北２丁目３番９号',
        industry='化学',
        sec_code='78770',
        corporate_number='1120001019704',
    ),
    'E02442': EdinetCodeEntry(
        edinet_code='E02442',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1170,
        fiscal_year_end='3月31日',
        submitter_name='トーソー株式会社',
        submitter_name_en='TOSO CO., LTD.',
        submitter_name_yomi='トーソーカブシキガイシャ',
        address='中央区新川１－４－９',
        industry='金属製品',
        sec_code='59560',
        corporate_number='6010001052315',
    ),
    'E02444': EdinetCodeEntry(
        edinet_code='E02444',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5491,
        fiscal_year_end='3月31日',
        submitter_name='レック株式会社',
        submitter_name_en='LEC,INC.',
        submitter_name_yomi='レックカブシキガイシャ',
        address='中央区京橋２丁目１番３号',
        industry='化学',
        sec_code='78740',
        corporate_number='7010001128155',
    ),
    'E02445': EdinetCodeEntry(
        edinet_code='E02445',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1471,
        fiscal_year_end='12月31日',
        submitter_name='株式会社フジマック',
        submitter_name_en='FUJIMAK CORPORATION',
        submitter_name_yomi='カブシキガイシャフジマック',
        address='港区南麻布１丁７目番２３号',
        industry='金属製品',
        sec_code='59650',
        corporate_number='3010401026945',
    ),
    'E02446': EdinetCodeEntry(
        edinet_code='E02446',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='株式会社アーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアーク',
        address='大阪市中央区南本町二丁目２番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001125197',
    ),
    'E02447': EdinetCodeEntry(
        edinet_code='E02447',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1696,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナンシン',
        submitter_name_en='NANSIN CO., LTD.',
        submitter_name_yomi='カブシキガイシャナンシン',
        address='中央区日本橋人形町一丁目１７番４号',
        industry='輸送用機器',
        sec_code='73990',
        corporate_number='1010001053053',
    ),
    'E02448': EdinetCodeEntry(
        edinet_code='E02448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=639,
        fiscal_year_end='6月30日',
        submitter_name='シンポ株式会社',
        submitter_name_en='SHINPO CO.,LTD.',
        submitter_name_yomi='シンポカブシキガイシャ',
        address='名古屋市名東区若葉台１１０番地',
        industry='金属製品',
        sec_code='59030',
        corporate_number='8180001002144',
    ),
    'E02449': EdinetCodeEntry(
        edinet_code='E02449',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=395,
        fiscal_year_end='9月30日',
        submitter_name='日本フォームサービス株式会社',
        submitter_name_en='NIHON FORM SERVICE CO.,LTD.',
        submitter_name_yomi='ニホンフォームサービスカブシキガイシャ',
        address='江東区亀戸四丁目３６－１４',
        industry='その他製品',
        sec_code=None,
        corporate_number='1011701006077',
    ),
    'E02450': EdinetCodeEntry(
        edinet_code='E02450',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3459,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タカラトミー',
        submitter_name_en='TOMY COMPANY,LTD.',
        submitter_name_yomi='カブシキガイシャタカラトミー',
        address='葛飾区立石７丁目９番１０号',
        industry='その他製品',
        sec_code='78670',
        corporate_number='8011801003488',
    ),
    'E02452': EdinetCodeEntry(
        edinet_code='E02452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=98,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ユニバーサルエンターテインメント',
        submitter_name_en='Universal Entertainment Corporation',
        submitter_name_yomi='カブシキガイシャユニバーサルエンターテインメント',
        address='江東区有明三丁目７番２６号\u3000有明フロンティアビルＡ棟',
        industry='機械',
        sec_code='64250',
        corporate_number='6010601025422',
    ),
    'E02453': EdinetCodeEntry(
        edinet_code='E02453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4755,
        fiscal_year_end='3月31日',
        submitter_name='エイベックス株式会社',
        submitter_name_en='Avex Inc.',
        submitter_name_yomi='エイベックスカブシキガイシャ',
        address='港区三田一丁目４番１号',
        industry='情報・通信業',
        sec_code='78600',
        corporate_number='7010401004245',
    ),
    'E02456': EdinetCodeEntry(
        edinet_code='E02456',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1015,
        fiscal_year_end='9月30日',
        submitter_name='株式会社テムザック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテムザック',
        address='京都市上京区浄福寺通上立売上る大黒町６８９番地１',
        industry='その他製品',
        sec_code=None,
        corporate_number='9290801002463',
    ),
    'E02458': EdinetCodeEntry(
        edinet_code='E02458',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2867,
        fiscal_year_end='3月31日',
        submitter_name='東映アニメーション株式会社',
        submitter_name_en='TOEI ANIMATION CO.,LTD.',
        submitter_name_yomi='トウエイアニメーションカブシキガイシャ',
        address='中野区中野４丁目１０番１号',
        industry='情報・通信業',
        sec_code='48160',
        corporate_number='8011601004645',
    ),
    'E02459': EdinetCodeEntry(
        edinet_code='E02459',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='カワセコンピュータサプライ株式会社',
        submitter_name_en='KAWASE COMPUTTER SUPPLIES CO., LTD.',
        submitter_name_yomi='カワセコンピュータサプライカブシキガイシャ',
        address='中央区銀座七丁目１６番１４号\u3000銀座イーストビル',
        industry='その他製品',
        sec_code='78510',
        corporate_number='2120001077131',
    ),
    'E02462': EdinetCodeEntry(
        edinet_code='E02462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='12月31日',
        submitter_name='不二精機株式会社',
        submitter_name_en='FUJI SEIKI CO.,LTD.',
        submitter_name_yomi='フジセイキカブシキガイシャ',
        address='大阪市生野区巽東四丁目４番３７号',
        industry='機械',
        sec_code='64000',
        corporate_number='3120001018670',
    ),
    'E02463': EdinetCodeEntry(
        edinet_code='E02463',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=330,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ブロッコリー',
        submitter_name_en='BROCCOLI Co., Ltd.',
        submitter_name_yomi='カブシキガイシャブロッコリー',
        address='練馬区豊玉北五丁目１４番６号５Ｆ',
        industry='小売業',
        sec_code=None,
        corporate_number='7011601006147',
    ),
    'E02464': EdinetCodeEntry(
        edinet_code='E02464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=589,
        fiscal_year_end='2月末日',
        submitter_name='株式会社グラファイトデザイン',
        submitter_name_en='GRAPHITE DESIGN INC.',
        submitter_name_yomi='カブシキガイシャグラファイトデザイン',
        address='秩父市太田２４７４番地１',
        industry='その他製品',
        sec_code='78470',
        corporate_number='1030001090714',
    ),
    'E02466': EdinetCodeEntry(
        edinet_code='E02466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2340,
        fiscal_year_end='12月31日',
        submitter_name='株式会社パイロットコーポレーション',
        submitter_name_en='PILOT CORPORATION',
        submitter_name_yomi='カブシキガイシャパイロットコーポレーション',
        address='中央区京橋２丁目６番２１号',
        industry='その他製品',
        sec_code='78460',
        corporate_number='9010001077045',
    ),
    'E02467': EdinetCodeEntry(
        edinet_code='E02467',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3611,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マーベラス',
        submitter_name_en='Marvelous Inc.',
        submitter_name_yomi='カブシキガイシャマーベラス',
        address='品川区東品川四丁目１２番８号\u3000品川シーサイドイーストタワー５階',
        industry='情報・通信業',
        sec_code='78440',
        corporate_number='3010701022537',
    ),
    'E02468': EdinetCodeEntry(
        edinet_code='E02468',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2010,
        fiscal_year_end='9月30日',
        submitter_name='株式会社フード・プラネット',
        submitter_name_en='Food Planet,Inc.',
        submitter_name_yomi='カブシキガイシャフードプラネット',
        address='札幌市中央区南３条西１丁目１番地１',
        industry='その他製品',
        sec_code=None,
        corporate_number='3120001108182',
    ),
    'E02469': EdinetCodeEntry(
        edinet_code='E02469',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=251,
        fiscal_year_end='7月31日',
        submitter_name='ゼネラルパッカー株式会社',
        submitter_name_en='GENERAL PACKER CO., LTD.',
        submitter_name_yomi='ゼネラルパッカーカブシキカイシャ',
        address='北名古屋市宇福寺神明６５番地',
        industry='機械',
        sec_code='62670',
        corporate_number='6180001045896',
    ),
    'E02470': EdinetCodeEntry(
        edinet_code='E02470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1394,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＳＨＯＥＩ',
        submitter_name_en='SHOEI CO., LTD.',
        submitter_name_yomi='カブシキガイシャショウエイ',
        address='台東区台東一丁目３１番７号',
        industry='その他製品',
        sec_code='78390',
        corporate_number='5010501005434',
    ),
    'E02472': EdinetCodeEntry(
        edinet_code='E02472',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='フランスベッドホールディングス株式会社',
        submitter_name_en='FRANCE BED HOLDINGS CO.,LTD.',
        submitter_name_yomi='フランスベッドホールディングスカブシキガイシャ',
        address='新宿区西新宿六丁目２２番１号',
        industry='その他製品',
        sec_code='78400',
        corporate_number='6011101037016',
    ),
    'E02474': EdinetCodeEntry(
        edinet_code='E02474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14965,
        fiscal_year_end='3月31日',
        submitter_name='タカラバイオ株式会社',
        submitter_name_en='TAKARA BIO INC.',
        submitter_name_yomi='タカラバイオカブシキガイシャ',
        address='草津市野路東七丁目４番３８号',
        industry='化学',
        sec_code='49740',
        corporate_number='1160001002490',
    ),
    'E02475': EdinetCodeEntry(
        edinet_code='E02475',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=29953,
        fiscal_year_end='3月31日',
        submitter_name='セガサミーホールディングス株式会社',
        submitter_name_en='SEGA SAMMY HOLDINGS INC.',
        submitter_name_yomi='セガサミーホールディングスカブシキガイシャ',
        address='品川区西品川一丁目１番１号住友不動産大崎ガーデンタワー',
        industry='機械',
        sec_code='64600',
        corporate_number='9010401055278',
    ),
    'E02476': EdinetCodeEntry(
        edinet_code='E02476',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1558,
        fiscal_year_end='9月30日',
        submitter_name='マジェスティゴルフ株式会社',
        submitter_name_en='MAJESTY GOLF Co., Ltd.',
        submitter_name_yomi='マジェスティゴルフカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号\u3000明治生命館７階',
        industry='その他製品',
        sec_code=None,
        corporate_number='4010001097221',
    ),
    'E02477': EdinetCodeEntry(
        edinet_code='E02477',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1111,
        fiscal_year_end='1月31日',
        submitter_name='ミライアル株式会社',
        submitter_name_en='Miraial Co.,Ltd',
        submitter_name_yomi='ミライアルカブシキガイシャ',
        address='豊島区東池袋一丁目２４番１号',
        industry='化学',
        sec_code='42380',
        corporate_number='4013301002222',
    ),
    'E02478': EdinetCodeEntry(
        edinet_code='E02478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=651,
        fiscal_year_end='8月31日',
        submitter_name='ミクロン精密株式会社',
        submitter_name_en='MICRON MACHINERY CO., LTD.',
        submitter_name_yomi='ミクロンセイミツカブシキガイシャ',
        address='山形市蔵王上野５７８番地の２',
        industry='機械',
        sec_code='61590',
        corporate_number='1390001001841',
    ),
    'E02480': EdinetCodeEntry(
        edinet_code='E02480',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=781,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ＩＧポート',
        submitter_name_en='IG Port,Inc.',
        submitter_name_yomi='カブシキガイシャアイジーポート',
        address='武蔵野市中町二丁目１番９号',
        industry='情報・通信業',
        sec_code='37910',
        corporate_number='5012401001942',
    ),
    'E02481': EdinetCodeEntry(
        edinet_code='E02481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バンダイナムコホールディングス',
        submitter_name_en='Bandai Namco Holdings Inc.',
        submitter_name_yomi='カブシキガイシャバンダイナムコホールディングス',
        address='港区芝五丁目３７番８号',
        industry='その他製品',
        sec_code='78320',
        corporate_number='5010701022329',
    ),
    'E02483': EdinetCodeEntry(
        edinet_code='E02483',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1240,
        fiscal_year_end='3月31日',
        submitter_name='クラスターテクノロジー株式会社',
        submitter_name_en='CLUSTER TECHNOLOGY CO.,LTD.',
        submitter_name_yomi='クラスターテクノロジーカブシキガイシャ',
        address='東大阪市渋川町４丁目５番２８号',
        industry='化学',
        sec_code='42400',
        corporate_number='4122001002199',
    ),
    'E02484': EdinetCodeEntry(
        edinet_code='E02484',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2043,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ファーマフーズ',
        submitter_name_en='Pharma Foods International Co., Ltd.',
        submitter_name_yomi='カブシキガイシャファーマフーズ',
        address='京都市西京区御陵大原１番地４９',
        industry='食料品',
        sec_code='29290',
        corporate_number='5130001011549',
    ),
    'E02485': EdinetCodeEntry(
        edinet_code='E02485',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5445,
        fiscal_year_end='6月30日',
        submitter_name='株式会社フルヤ金属',
        submitter_name_en='FURUYA METAL CO.,LTD.',
        submitter_name_yomi='カブシキガイシャフルヤキンゾク',
        address='豊島区南大塚二丁目３７番５号',
        industry='その他製品',
        sec_code='78260',
        corporate_number='8013301010956',
    ),
    'E02487': EdinetCodeEntry(
        edinet_code='E02487',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9207,
        fiscal_year_end=None,
        submitter_name='ダンロップスポーツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダンロップスポーツカブシキガイシャ',
        address='神戸市中央区脇浜町３－６－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001022902',
    ),
    'E02488': EdinetCodeEntry(
        edinet_code='E02488',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3281,
        fiscal_year_end='3月31日',
        submitter_name='株式会社藤商事',
        submitter_name_en='FUJISHOJI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャフジショウジ',
        address='大阪市中央区内本町一丁目１番４号',
        industry='機械',
        sec_code='62570',
        corporate_number='6120001099576',
    ),
    'E02489': EdinetCodeEntry(
        edinet_code='E02489',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=568,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本一ソフトウェア',
        submitter_name_en='NIPPON ICHI SOFTWARE INC.',
        submitter_name_yomi='カブシキガイシャニッポンイチソフトウェア',
        address='各務原市蘇原月丘町３丁目１７番',
        industry='情報・通信業',
        sec_code='38510',
        corporate_number='3200001007491',
    ),
    'E02490': EdinetCodeEntry(
        edinet_code='E02490',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3278,
        fiscal_year_end='1月31日',
        submitter_name='株式会社\u3000トリケミカル研究所',
        submitter_name_en='Tri Chemical Laboratories Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000トリケミカルケンキュウショ',
        address='上野原市上野原８１５４番地２１７',
        industry='化学',
        sec_code='43690',
        corporate_number='2090001008148',
    ),
    'E02491': EdinetCodeEntry(
        edinet_code='E02491',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=405,
        fiscal_year_end='6月30日',
        submitter_name='株式会社三ツ知',
        submitter_name_en='Mitsuchi Corporation',
        submitter_name_yomi='カブシキガイシャミツチ',
        address='春日井市牛山町１２０３番地',
        industry='金属製品',
        sec_code='34390',
        corporate_number='9180001001260',
    ),
    'E02492': EdinetCodeEntry(
        edinet_code='E02492',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6422,
        fiscal_year_end='6月30日',
        submitter_name='前田工繊株式会社',
        submitter_name_en='MAEDA KOSEN CO., LTD.',
        submitter_name_yomi='マエダコウセンカブシキガイシャ',
        address='坂井市春江町沖布目第３８号３番地',
        industry='その他製品',
        sec_code='78210',
        corporate_number='6210001003710',
    ),
    'E02493': EdinetCodeEntry(
        edinet_code='E02493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1190,
        fiscal_year_end='8月31日',
        submitter_name='日創グループ株式会社',
        submitter_name_en='NISSO GROUP CO.,LTD.',
        submitter_name_yomi='ニッソウグループカブシキガイシャ',
        address='福岡市南区向野二丁目１０番２５号',
        industry='金属製品',
        sec_code='34400',
        corporate_number='1290001018169',
    ),
    'E02494': EdinetCodeEntry(
        edinet_code='E02494',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=468,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ニックス',
        submitter_name_en='NIX,INC.',
        submitter_name_yomi='カブシキガイシャニックス',
        address='横浜市西区みなとみらい二丁目３番３号',
        industry='化学',
        sec_code='42430',
        corporate_number='2020001028152',
    ),
    'E02497': EdinetCodeEntry(
        edinet_code='E02497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=253448,
        fiscal_year_end='3月31日',
        submitter_name='伊藤忠商事株式会社',
        submitter_name_en='ITOCHU Corporation',
        submitter_name_yomi='イトウチュウショウジカブシキガイシャ',
        address='大阪市北区梅田三丁目１番３号',
        industry='卸売業',
        sec_code='80010',
        corporate_number='7120001077358',
    ),
    'E02498': EdinetCodeEntry(
        edinet_code='E02498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=263711,
        fiscal_year_end='3月31日',
        submitter_name='丸紅株式会社',
        submitter_name_en='Marubeni Corporation',
        submitter_name_yomi='マルベニカブシキガイシャ',
        address='千代田区大手町一丁目４番２号',
        industry='卸売業',
        sec_code='80020',
        corporate_number='9010001008776',
    ),
    'E02501': EdinetCodeEntry(
        edinet_code='E02501',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3801,
        fiscal_year_end='3月31日',
        submitter_name='高島株式会社',
        submitter_name_en='Takashima & Co.,Ltd.',
        submitter_name_yomi='タカシマカブシキガイシャ',
        address='千代田区神田駿河台２丁目２番地',
        industry='卸売業',
        sec_code='80070',
        corporate_number='3010001034860',
    ),
    'E02503': EdinetCodeEntry(
        edinet_code='E02503',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5030,
        fiscal_year_end='3月31日',
        submitter_name='極東貿易株式会社',
        submitter_name_en='Kyokuto Boeki Kaisha, Limited',
        submitter_name_yomi='キョクトウボウエキカブシキガイシャ',
        address='千代田区大手町２丁目２番１号',
        industry='卸売業',
        sec_code='80930',
        corporate_number='2010001014327',
    ),
    'E02505': EdinetCodeEntry(
        edinet_code='E02505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=64936,
        fiscal_year_end='3月31日',
        submitter_name='豊田通商株式会社',
        submitter_name_en='TOYOTA TSUSHO CORPORATION',
        submitter_name_yomi='トヨタツウショウカブシキガイシャ',
        address='名古屋市中村区名駅四丁目９番８号（センチュリー豊田ビル）',
        industry='卸売業',
        sec_code='80150',
        corporate_number='6180001031731',
    ),
    'E02506': EdinetCodeEntry(
        edinet_code='E02506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27781,
        fiscal_year_end='3月31日',
        submitter_name='兼松株式会社',
        submitter_name_en='KANEMATSU CORPORATION',
        submitter_name_yomi='カネマツカブシキガイシャ',
        address='神戸市中央区伊藤町１１９番地',
        industry='卸売業',
        sec_code='80200',
        corporate_number='7140001005647',
    ),
    'E02508': EdinetCodeEntry(
        edinet_code='E02508',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='野村トレーディング・ホールディングス株式会社',
        submitter_name_en='NOMURA TRADING HOLDINGS CO.,LTD.',
        submitter_name_yomi='ノムラトレーディングホールディングスカブシキカイシャ',
        address='大阪市中央区安土町１丁目７番３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='5120001077525',
    ),
    'E02509': EdinetCodeEntry(
        edinet_code='E02509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6800,
        fiscal_year_end='3月31日',
        submitter_name='蝶理株式会社',
        submitter_name_en='CHORI CO.,LTD.',
        submitter_name_yomi='チョウリカブシキガイシャ',
        address='大阪市中央区淡路町４丁目２番１３号',
        industry='卸売業',
        sec_code='80140',
        corporate_number='3120001077485',
    ),
    'E02510': EdinetCodeEntry(
        edinet_code='E02510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16649,
        fiscal_year_end='3月31日',
        submitter_name='日本紙パルプ商事株式会社',
        submitter_name_en='Japan Pulp & Paper Co., Ltd.',
        submitter_name_yomi='ニホンカミパルプショウジカブシキガイシャ',
        address='中央区勝どき三丁目１２番１号フォアフロントタワー',
        industry='卸売業',
        sec_code='80320',
        corporate_number='1010001034978',
    ),
    'E02512': EdinetCodeEntry(
        edinet_code='E02512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6728,
        fiscal_year_end='3月31日',
        submitter_name='西華産業株式会社',
        submitter_name_en='SEIKA CORPORATION',
        submitter_name_yomi='セイカサンギョウカブシキガイシャ',
        address='千代田区丸の内３－３－１',
        industry='卸売業',
        sec_code='80610',
        corporate_number='6010001008696',
    ),
    'E02513': EdinetCodeEntry(
        edinet_code='E02513',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=342560,
        fiscal_year_end='3月31日',
        submitter_name='三井物産株式会社',
        submitter_name_en='MITSUI & CO., LTD.',
        submitter_name_yomi='ミツイブッサンカブシキガイシャ',
        address='千代田区大手町一丁目２番１号',
        industry='卸売業',
        sec_code='80310',
        corporate_number='1010001008767',
    ),
    'E02514': EdinetCodeEntry(
        edinet_code='E02514',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2917,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＴグループ',
        submitter_name_en='AT-Group Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエィティグループ',
        address='名古屋市昭和区高辻町６番８号',
        industry='小売業',
        sec_code=None,
        corporate_number='2180001007751',
    ),
    'E02515': EdinetCodeEntry(
        edinet_code='E02515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='7月20日',
        submitter_name='株式会社内田洋行',
        submitter_name_en='UCHIDA YOKO CO., LTD.',
        submitter_name_yomi='カブシキガイシャウチダヨウコウ',
        address='中央区新川二丁目４番７号',
        industry='卸売業',
        sec_code='80570',
        corporate_number='1010001034730',
    ),
    'E02516': EdinetCodeEntry(
        edinet_code='E02516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4723,
        fiscal_year_end='3月31日',
        submitter_name='ＫＰＰグループホールディングス株式会社',
        submitter_name_en='KPP GROUP HOLDINGS CO., LTD.',
        submitter_name_yomi='ケーピーピーグループホールディングスカブシキガイシャ',
        address='中央区明石町６番２４号',
        industry='卸売業',
        sec_code='92740',
        corporate_number='9010001048806',
    ),
    'E02517': EdinetCodeEntry(
        edinet_code='E02517',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9364,
        fiscal_year_end='3月31日',
        submitter_name='稲畑産業株式会社',
        submitter_name_en='Inabata&Co.,Ltd.',
        submitter_name_yomi='イナバタサンギョウカブシキガイシャ',
        address='大阪市中央区南船場一丁目１５番１４号',
        industry='卸売業',
        sec_code='80980',
        corporate_number='4120001077360',
    ),
    'E02518': EdinetCodeEntry(
        edinet_code='E02518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10334,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＲＹＯＤＥＮ',
        submitter_name_en='RYODEN CORPORATION',
        submitter_name_yomi='カブシキガイシャリョーデン',
        address='東京都千代田区麹町五丁目１番地麹町弘済ビルディング',
        industry='卸売業',
        sec_code='80840',
        corporate_number='8013301012440',
    ),
    'E02521': EdinetCodeEntry(
        edinet_code='E02521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30079,
        fiscal_year_end='2月末日',
        submitter_name='株式会社オンワードホールディングス',
        submitter_name_en='ONWARD HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャオンワードホールディングス',
        address='中央区日本橋三丁目１０番５号',
        industry='繊維製品',
        sec_code='80160',
        corporate_number='4010001034736',
    ),
    'E02522': EdinetCodeEntry(
        edinet_code='E02522',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5650,
        fiscal_year_end='3月31日',
        submitter_name='神鋼商事株式会社',
        submitter_name_en='Shinsho Corporation',
        submitter_name_yomi='シンコウショウジカブシキガイシャ',
        address='大阪市中央区北浜二丁目６番１８号\u3000淀屋橋スクエア',
        industry='卸売業',
        sec_code='80750',
        corporate_number='5120001077442',
    ),
    'E02525': EdinetCodeEntry(
        edinet_code='E02525',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20644,
        fiscal_year_end='3月31日',
        submitter_name='ユアサ商事株式会社',
        submitter_name_en='YUASA TRADING CO.,LTD.',
        submitter_name_yomi='ユアサショウジカブシキガイシャ',
        address='千代田区神田美土代町７番地',
        industry='卸売業',
        sec_code='80740',
        corporate_number='5010001034958',
    ),
    'E02527': EdinetCodeEntry(
        edinet_code='E02527',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3443,
        fiscal_year_end='3月31日',
        submitter_name='東京産業株式会社',
        submitter_name_en='TOKYO SANGYO CO.,LTD.',
        submitter_name_yomi='トウキョウサンギョウカブシキガイシャ',
        address='千代田区大手町二丁目二番一号',
        industry='卸売業',
        sec_code='80700',
        corporate_number='6010001008820',
    ),
    'E02528': EdinetCodeEntry(
        edinet_code='E02528',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=221650,
        fiscal_year_end='3月31日',
        submitter_name='住友商事株式会社',
        submitter_name_en='SUMITOMO CORPORATION',
        submitter_name_yomi='スミトモショウジカブシキガイシャ',
        address='千代田区大手町２丁目３番２号',
        industry='卸売業',
        sec_code='80530',
        corporate_number='1010001008692',
    ),
    'E02529': EdinetCodeEntry(
        edinet_code='E02529',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=204446,
        fiscal_year_end='3月31日',
        submitter_name='三菱商事株式会社',
        submitter_name_en='Mitsubishi Corporation',
        submitter_name_yomi='ミツビシショウジカブシキガイシャ',
        address='千代田区丸の内二丁目３番１号',
        industry='卸売業',
        sec_code='80580',
        corporate_number='5010001008771',
    ),
    'E02530': EdinetCodeEntry(
        edinet_code='E02530',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6495,
        fiscal_year_end='3月31日',
        submitter_name='ＯＵＧホールディングス株式会社',
        submitter_name_en='OUG Holdings Inc.',
        submitter_name_yomi='オーユージーホールディングスカブシキガイシャ',
        address='大阪市福島区野田二丁目１３番５号',
        industry='卸売業',
        sec_code='80410',
        corporate_number='2120001036970',
    ),
    'E02534': EdinetCodeEntry(
        edinet_code='E02534',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='三共生興株式会社',
        submitter_name_en='SANKYO SEIKO CO.,LTD.',
        submitter_name_yomi='サンキョウセイコウカブシキガイシャ',
        address='大阪市中央区安土町二丁目５番６号',
        industry='卸売業',
        sec_code='80180',
        corporate_number='6140001007875',
    ),
    'E02535': EdinetCodeEntry(
        edinet_code='E02535',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1321,
        fiscal_year_end='3月31日',
        submitter_name='佐藤商事株式会社',
        submitter_name_en='SATO SHO-JI CORPORATION',
        submitter_name_yomi='サトウショウジカブシキガイシャ',
        address='千代田区丸の内一丁目８番１号',
        industry='卸売業',
        sec_code='80650',
        corporate_number='8010001034807',
    ),
    'E02536': EdinetCodeEntry(
        edinet_code='E02536',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='日販グループホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッパングループホールディングスカブシキガイシャ',
        address='千代田区神田駿河台四丁目３番地',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010001033269',
    ),
    'E02537': EdinetCodeEntry(
        edinet_code='E02537',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社日教販',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッキョウハン',
        address='文京区後楽１丁目４番２５号',
        industry='卸売業',
        sec_code=None,
        corporate_number='4010001006124',
    ),
    'E02538': EdinetCodeEntry(
        edinet_code='E02538',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーハン',
        submitter_name_en='TOHAN CORPORATION',
        submitter_name_yomi='カブシキガイシャトーハン',
        address='新宿区東五軒町６番２４号',
        industry='卸売業',
        sec_code=None,
        corporate_number='3011101014587',
    ),
    'E02541': EdinetCodeEntry(
        edinet_code='E02541',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2376,
        fiscal_year_end=None,
        submitter_name='東都水産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウトスイサンカブシキガイシャ',
        address='江東区豊洲６丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001034847',
    ),
    'E02542': EdinetCodeEntry(
        edinet_code='E02542',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2065,
        fiscal_year_end='3月31日',
        submitter_name='神栄株式会社',
        submitter_name_en='SHINYEI KAISHA',
        submitter_name_yomi='シンエイカブシキガイシャ',
        address='神戸市中央区京町７７－１',
        industry='卸売業',
        sec_code='30040',
        corporate_number='4140001008108',
    ),
    'E02543': EdinetCodeEntry(
        edinet_code='E02543',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=35123,
        fiscal_year_end='12月31日',
        submitter_name='東燃ゼネラル石油株式会社',
        submitter_name_en='TonenGeneral Sekiyu K.K.',
        submitter_name_yomi='トウネンゼネラルセキユカブシキカイシャ',
        address='港区港南一丁目８番１５号',
        industry='石油・石炭製品',
        sec_code=None,
        corporate_number='2010401015916',
    ),
    'E02544': EdinetCodeEntry(
        edinet_code='E02544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13752,
        fiscal_year_end='3月31日',
        submitter_name='日産東京販売ホールディングス株式会社',
        submitter_name_en='NISSAN TOKYO SALES HOLDINGS CO., LTD.',
        submitter_name_yomi='ニッサントウキョウハンバイホールディングスカブシキガイシャ',
        address='品川区西五反田四丁目３２番１号',
        industry='小売業',
        sec_code='82910',
        corporate_number='4010701012495',
    ),
    'E02547': EdinetCodeEntry(
        edinet_code='E02547',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2076,
        fiscal_year_end='3月31日',
        submitter_name='ラサ商事株式会社',
        submitter_name_en='Rasa Corporation',
        submitter_name_yomi='ラサショウジカブシキガイシャ',
        address='中央区日本橋蛎殻町一丁目１１番５号ＲＡＳＡ日本橋ビルディング',
        industry='卸売業',
        sec_code='30230',
        corporate_number='7010001060127',
    ),
    'E02548': EdinetCodeEntry(
        edinet_code='E02548',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1006,
        fiscal_year_end='9月30日',
        submitter_name='三洋貿易株式会社',
        submitter_name_en='Sanyo Trading Co., Ltd.',
        submitter_name_yomi='サンヨウボウエキカブシキガイシャ',
        address='千代田区神田錦町二丁目１１番地',
        industry='卸売業',
        sec_code='31760',
        corporate_number='2010001017016',
    ),
    'E02549': EdinetCodeEntry(
        edinet_code='E02549',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7186,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＧＳＩクレオス',
        submitter_name_en='GSI Creos Corporation',
        submitter_name_yomi='カブシキガイシャジーエスアイクレオス',
        address='東京都港区芝３－８－２',
        industry='卸売業',
        sec_code='81010',
        corporate_number='3010001008666',
    ),
    'E02551': EdinetCodeEntry(
        edinet_code='E02551',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='東工コーセン株式会社',
        submitter_name_en='TOKOKOSEN  CORP.',
        submitter_name_yomi='トウコウコーセンカブシキガイシャ',
        address='千代田区四番町４番２',
        industry='卸売業',
        sec_code=None,
        corporate_number='4010001071416',
    ),
    'E02552': EdinetCodeEntry(
        edinet_code='E02552',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9699,
        fiscal_year_end='3月31日',
        submitter_name='長瀬産業株式会社',
        submitter_name_en='NAGASE & CO., LTD.',
        submitter_name_yomi='ナガセサンギョウカブシキガイシャ',
        address='大阪市西区新町一丁目１番１７号',
        industry='卸売業',
        sec_code='80120',
        corporate_number='4120001049021',
    ),
    'E02553': EdinetCodeEntry(
        edinet_code='E02553',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9128,
        fiscal_year_end='2月末日',
        submitter_name='岡谷鋼機株式会社',
        submitter_name_en='OKAYA&CO.,LTD.',
        submitter_name_yomi='オカヤコウキカブシキガイシャ',
        address='名古屋市中区栄二丁目４番１８号',
        industry='卸売業',
        sec_code='74850',
        corporate_number='7180001034964',
    ),
    'E02554': EdinetCodeEntry(
        edinet_code='E02554',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45651,
        fiscal_year_end='3月31日',
        submitter_name='阪和興業株式会社',
        submitter_name_en='HANWA CO.,LTD.',
        submitter_name_yomi='ハンワコウギョウカブシキガイシャ',
        address='大阪市中央区伏見町四丁目３番９号',
        industry='卸売業',
        sec_code='80780',
        corporate_number='8120001077530',
    ),
    'E02556': EdinetCodeEntry(
        edinet_code='E02556',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=480,
        fiscal_year_end='2月末日',
        submitter_name='小泉株式会社',
        submitter_name_en='koizumi co.,ltd',
        submitter_name_yomi='コイズミカブシキカイシャ',
        address='大阪市中央区備後町３丁目１番８号',
        industry='卸売業',
        sec_code=None,
        corporate_number='3120001077411',
    ),
    'E02558': EdinetCodeEntry(
        edinet_code='E02558',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10630,
        fiscal_year_end='3月31日',
        submitter_name='三菱食品株式会社',
        submitter_name_en='Mitsubishi Shokuhin Co., Ltd.',
        submitter_name_yomi='ミツビシショクヒンカブシキガイシャ',
        address='文京区小石川一丁目１番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010801012645',
    ),
    'E02560': EdinetCodeEntry(
        edinet_code='E02560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7909,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山善',
        submitter_name_en='YAMAZEN CORPORATION',
        submitter_name_yomi='カブシキガイシャヤマゼン',
        address='大阪市西区立売堀二丁目３番１６号',
        industry='卸売業',
        sec_code='80510',
        corporate_number='1120001049040',
    ),
    'E02561': EdinetCodeEntry(
        edinet_code='E02561',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カノークス',
        submitter_name_en='CANOX CORPORATION',
        submitter_name_yomi='カブシキガイシャカノークス',
        address='名古屋市西区那古野一丁目１番１２号',
        industry='卸売業',
        sec_code='80760',
        corporate_number='7180001025105',
    ),
    'E02562': EdinetCodeEntry(
        edinet_code='E02562',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3228,
        fiscal_year_end='3月31日',
        submitter_name='新生紙パルプ商事株式会社',
        submitter_name_en='SHINSEI PULP&PAPER COMPANY LIMITED',
        submitter_name_yomi='シンセイカミパルプショウジカブシキガイシャ',
        address='千代田区神田錦町１丁目８番地',
        industry='卸売業',
        sec_code=None,
        corporate_number='7010001012862',
    ),
    'E02563': EdinetCodeEntry(
        edinet_code='E02563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4024,
        fiscal_year_end='3月31日',
        submitter_name='明和産業株式会社',
        submitter_name_en='Meiwa Corporation',
        submitter_name_yomi='メイワサンギョウカブシキガイシャ',
        address='千代田区丸の内三丁目３番１号',
        industry='卸売業',
        sec_code='81030',
        corporate_number='7010001008786',
    ),
    'E02564': EdinetCodeEntry(
        edinet_code='E02564',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8021,
        fiscal_year_end='12月31日',
        submitter_name='昭光通商株式会社',
        submitter_name_en='SHOKO CO., LTD',
        submitter_name_yomi='ショウコウツウショウカブシキガイシャ',
        address='港区芝公園',
        industry='卸売業',
        sec_code=None,
        corporate_number='4010401013769',
    ),
    'E02565': EdinetCodeEntry(
        edinet_code='E02565',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='3月31日',
        submitter_name='三国商事株式会社',
        submitter_name_en='MIKUNI SHOJI CO.,LTD.',
        submitter_name_yomi='ミクニショウジカブシキガイシャ',
        address='港区浜松町一丁目１０番７号',
        industry='卸売業',
        sec_code=None,
        corporate_number='4010401028552',
    ),
    'E02566': EdinetCodeEntry(
        edinet_code='E02566',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2995,
        fiscal_year_end='3月31日',
        submitter_name='中央魚類株式会社',
        submitter_name_en='Chuo Gyorui Co., Ltd.',
        submitter_name_yomi='チュウオウギョルイカブシキガイシャ',
        address='江東区豊洲６丁目６番２号',
        industry='卸売業',
        sec_code='80300',
        corporate_number='5010001034859',
    ),
    'E02567': EdinetCodeEntry(
        edinet_code='E02567',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35096,
        fiscal_year_end='3月31日',
        submitter_name='岩谷産業株式会社',
        submitter_name_en='IWATANI CORPORATION',
        submitter_name_yomi='イワタニサンギョウカブシキガイシャ',
        address='大阪市中央区本町三丁目６番４号',
        industry='卸売業',
        sec_code='80880',
        corporate_number='8120001077357',
    ),
    'E02569': EdinetCodeEntry(
        edinet_code='E02569',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1520,
        fiscal_year_end='3月31日',
        submitter_name='株式会社弘電社',
        submitter_name_en='The Kodensha,Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコウデンシャ',
        address='中央区銀座５丁目１１番１０号',
        industry='建設業',
        sec_code='19480',
        corporate_number='3010001034778',
    ),
    'E02570': EdinetCodeEntry(
        edinet_code='E02570',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2712,
        fiscal_year_end='10月31日',
        submitter_name='トルク株式会社',
        submitter_name_en='TORQ Inc.',
        submitter_name_yomi='トルクカブシキガイシャ',
        address='大阪市西区南堀江二丁目７番４号',
        industry='卸売業',
        sec_code='80770',
        corporate_number='7120001048994',
    ),
    'E02571': EdinetCodeEntry(
        edinet_code='E02571',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2045,
        fiscal_year_end='3月31日',
        submitter_name='築地魚市場株式会社',
        submitter_name_en='TSUKIJI UOICHIBA COMPANY,LIMITED',
        submitter_name_yomi='ツキジウオイチバカブシキガイシャ',
        address='江東区豊洲六丁目６番２号',
        industry='卸売業',
        sec_code='80390',
        corporate_number='4010001034876',
    ),
    'E02572': EdinetCodeEntry(
        edinet_code='E02572',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2945,
        fiscal_year_end='3月31日',
        submitter_name='椿本興業株式会社',
        submitter_name_en='TSUBAKIMOTO KOGYO CO.,LTD.',
        submitter_name_yomi='ツバキモトコウギョウカブシキガイシャ',
        address='大阪市北区梅田３丁目３番２０号',
        industry='卸売業',
        sec_code='80520',
        corporate_number='4120001059664',
    ),
    'E02574': EdinetCodeEntry(
        edinet_code='E02574',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11658,
        fiscal_year_end='3月31日',
        submitter_name='スターゼン株式会社',
        submitter_name_en='Starzen Company Limited',
        submitter_name_yomi='スターゼンカブシキガイシャ',
        address='港区港南二丁目５番７号',
        industry='卸売業',
        sec_code='80430',
        corporate_number='9010401015760',
    ),
    'E02575': EdinetCodeEntry(
        edinet_code='E02575',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2628,
        fiscal_year_end='3月31日',
        submitter_name='大都魚類株式会社',
        submitter_name_en='DAITO GYORUI CO.,LTD.',
        submitter_name_yomi='ダイトギョルイカブシキガイシャ',
        address='江東区豊洲六丁目６番２号',
        industry='卸売業',
        sec_code=None,
        corporate_number='4010001034851',
    ),
    'E02576': EdinetCodeEntry(
        edinet_code='E02576',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14303,
        fiscal_year_end='9月30日',
        submitter_name='横浜冷凍株式会社',
        submitter_name_en='Yokohama Reito Co.,Ltd.',
        submitter_name_yomi='ヨコハマレイトウカブシキカイシャ',
        address='横浜市鶴見区大黒町５番３５号',
        industry='卸売業',
        sec_code='28740',
        corporate_number='1020001030638',
    ),
    'E02578': EdinetCodeEntry(
        edinet_code='E02578',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5105,
        fiscal_year_end='3月31日',
        submitter_name='第一実業株式会社',
        submitter_name_en='DAIICHI JITSUGYO CO., LTD.',
        submitter_name_yomi='ダイイチジツギョウカブシキガイシャ',
        address='千代田区神田駿河台４丁目６番地（御茶ノ水ソラシティ）',
        industry='卸売業',
        sec_code='80590',
        corporate_number='5010001008714',
    ),
    'E02579': EdinetCodeEntry(
        edinet_code='E02579',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2354,
        fiscal_year_end='3月31日',
        submitter_name='ナラサキ産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナラサキサンギョウカブシキカイシャ',
        address='札幌市中央区大通西７丁目３番地１',
        industry='卸売業',
        sec_code='80850',
        corporate_number='2430001035966',
    ),
    'E02580': EdinetCodeEntry(
        edinet_code='E02580',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5576,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カナデン',
        submitter_name_en='KANADEN CORPORATION',
        submitter_name_yomi='カブシキガイシャカナデン',
        address='中央区晴海１丁目８番１２号晴海トリトンスクエアＺ棟',
        industry='卸売業',
        sec_code='80810',
        corporate_number='7010401007116',
    ),
    'E02584': EdinetCodeEntry(
        edinet_code='E02584',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22069,
        fiscal_year_end='3月31日',
        submitter_name='ナイス株式会社',
        submitter_name_en='Nice Corporation',
        submitter_name_yomi='ナイスカブシキガイシャ',
        address='横浜市鶴見区鶴見中央四丁目３３番１号',
        industry='卸売業',
        sec_code='80890',
        corporate_number='2020001037946',
    ),
    'E02585': EdinetCodeEntry(
        edinet_code='E02585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4629,
        fiscal_year_end='11月30日',
        submitter_name='アステナホールディングス株式会社',
        submitter_name_en='Astena Holdings Co., Ltd.',
        submitter_name_yomi='アステナホールディングスカブシキカイシャ',
        address='中央区日本橋本町四丁目８番２号',
        industry='卸売業',
        sec_code='80950',
        corporate_number='9010001034748',
    ),
    'E02586': EdinetCodeEntry(
        edinet_code='E02586',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6975,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤナセ',
        submitter_name_en='YANASE AND COMPANY,LIMITED',
        submitter_name_yomi='カブシキガイシャヤナセ',
        address='港区芝浦一丁目６番３８号',
        industry='小売業',
        sec_code=None,
        corporate_number='1010401029826',
    ),
    'E02587': EdinetCodeEntry(
        edinet_code='E02587',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=430,
        fiscal_year_end='3月31日',
        submitter_name='日本出版貿易株式会社',
        submitter_name_en='JAPAN PUBLICATIONS TRADING CO., LTD.',
        submitter_name_yomi='ニホンシュッパンボウエキカブシキカイシャ',
        address='千代田区神田猿楽町一丁目５番１５号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6010001033273',
    ),
    'E02588': EdinetCodeEntry(
        edinet_code='E02588',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2829,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツカモトコーポレーション',
        submitter_name_en='TSUKAMOTO CORPORATION CO., LTD.',
        submitter_name_yomi='カブシキガイシャツカモトコーポレーション',
        address='中央区日本橋本町１丁目６番５号',
        industry='卸売業',
        sec_code='80250',
        corporate_number='2010001034878',
    ),
    'E02590': EdinetCodeEntry(
        edinet_code='E02590',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=600,
        fiscal_year_end=None,
        submitter_name='ＫＩＳＣＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キスコカブシキガイシャ',
        address='大阪市中央区伏見町３丁目３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001077392',
    ),
    'E02596': EdinetCodeEntry(
        edinet_code='E02596',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1575,
        fiscal_year_end='3月31日',
        submitter_name='小泉産業株式会社',
        submitter_name_en='Koizumi Sangyo Corporation',
        submitter_name_yomi='コイズミサンギョウカブシキガイシャ',
        address='大阪市中央区備後町３丁目３番１１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='1120001077413',
    ),
    'E02597': EdinetCodeEntry(
        edinet_code='E02597',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=478,
        fiscal_year_end='3月31日',
        submitter_name='東京青果株式会社',
        submitter_name_en='TOKYO SEIKA CO.,LTD.',
        submitter_name_yomi='トウキョウセイカカブシキガイシャ',
        address='大田区東海３丁目２番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010801007777',
    ),
    'E02598': EdinetCodeEntry(
        edinet_code='E02598',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=460,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000新潟ケンベイ',
        submitter_name_en='TheNiigataKenbei-Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニイガタケンベイ',
        address='新潟市江南区亀田工業団地２丁目３番２号',
        industry='卸売業',
        sec_code=None,
        corporate_number='9110001003791',
    ),
    'E02602': EdinetCodeEntry(
        edinet_code='E02602',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5008,
        fiscal_year_end='3月31日',
        submitter_name='三谷商事株式会社',
        submitter_name_en='MITANI CORPORATIN',
        submitter_name_yomi='ミタニショウジカブシキガイシャ',
        address='福井市豊島１－３－１',
        industry='卸売業',
        sec_code='80660',
        corporate_number='7210001004022',
    ),
    'E02604': EdinetCodeEntry(
        edinet_code='E02604',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2919,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ライオン事務器',
        submitter_name_en='LION OFFICE PRODUCTS CORP.',
        submitter_name_yomi='カブシキガイシャライオンジムキ',
        address='東大阪市長田中３丁目５番４４号',
        industry='卸売業',
        sec_code='423A0',
        corporate_number='1122001014313',
    ),
    'E02608': EdinetCodeEntry(
        edinet_code='E02608',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10649,
        fiscal_year_end='3月31日',
        submitter_name='東邦ホールディングス株式会社',
        submitter_name_en='TOHO HOLDINGS CO.,LTD.',
        submitter_name_yomi='トウホウホールディングス',
        address='世田谷区代沢四丁目４３番１１号',
        industry='卸売業',
        sec_code='81290',
        corporate_number='4010901008153',
    ),
    'E02610': EdinetCodeEntry(
        edinet_code='E02610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=417,
        fiscal_year_end='3月31日',
        submitter_name='クワザワホールディングス株式会社',
        submitter_name_en='KUWAZAWA Holdings Corporation',
        submitter_name_yomi='クワザワホールディングスカブシキガイシャ',
        address='札幌市白石区中央２条７丁目１番１号',
        industry='卸売業',
        sec_code='81040',
        corporate_number='9430001005194',
    ),
    'E02611': EdinetCodeEntry(
        edinet_code='E02611',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5483,
        fiscal_year_end='3月31日',
        submitter_name='ＢＩＰＲＯＧＹ株式会社',
        submitter_name_en='BIPROGY Inc.',
        submitter_name_yomi='ビプロジー\u3000カブシキガイシャ',
        address='江東区豊洲一丁目１番１号',
        industry='情報・通信業',
        sec_code='80560',
        corporate_number='2010601029542',
    ),
    'E02612': EdinetCodeEntry(
        edinet_code='E02612',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1026,
        fiscal_year_end='3月31日',
        submitter_name='ヤマエ久野株式会社',
        submitter_name_en='YAMAE HISANO CO., LTD.',
        submitter_name_yomi='ヤマエヒサノカブシキガイシャ',
        address='福岡市博多区博多駅東２丁目１３番３４号',
        industry='卸売業',
        sec_code=None,
        corporate_number='9290001017163',
    ),
    'E02613': EdinetCodeEntry(
        edinet_code='E02613',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='千代田工販株式会社',
        submitter_name_en='CHIYODA KOHAN CO.,LTD.',
        submitter_name_yomi='チヨダコウハンカブシキカイシャ',
        address='中央区京橋一丁目１０番７号',
        industry='卸売業',
        sec_code=None,
        corporate_number='7010001050391',
    ),
    'E02615': EdinetCodeEntry(
        edinet_code='E02615',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1541,
        fiscal_year_end='3月31日',
        submitter_name='横浜丸魚株式会社',
        submitter_name_en='Yokohama Maruuo Co., Ltd',
        submitter_name_yomi='ヨコハママルウオ\u3000カブシキガイシャ',
        address='横浜市神奈川区山内町１番地中央市場内',
        industry='卸売業',
        sec_code='80450',
        corporate_number='8020001024889',
    ),
    'E02616': EdinetCodeEntry(
        edinet_code='E02616',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3626,
        fiscal_year_end='3月31日',
        submitter_name='丸藤シートパイル株式会社',
        submitter_name_en='MARUFUJI SHEET PILING CO., LTD.',
        submitter_name_yomi='マルフジシートパイルカブシキガイシャ',
        address='中央区日本橋本町３丁目７番２号',
        industry='卸売業',
        sec_code='80460',
        corporate_number='2010001034944',
    ),
    'E02617': EdinetCodeEntry(
        edinet_code='E02617',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7938,
        fiscal_year_end=None,
        submitter_name='株式会社日立ハイテク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒタチハイテク',
        address='港区虎ノ門一丁目１７番１号虎ノ門ヒルズビジネスタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401021648',
    ),
    'E02618': EdinetCodeEntry(
        edinet_code='E02618',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13821,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ワキタ',
        submitter_name_en='Wakita & Co.,LTD.',
        submitter_name_yomi='カブシキガイシャワキタ',
        address='大阪市西区江戸堀一丁目３番２０号',
        industry='卸売業',
        sec_code='81250',
        corporate_number='5120001048550',
    ),
    'E02621': EdinetCodeEntry(
        edinet_code='E02621',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2486,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ヨンドシーホールディングス',
        submitter_name_en='YONDOSHI HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャヨンドシーホールディングス',
        address='品川区上大崎二丁目１９番１０号',
        industry='卸売業',
        sec_code='80080',
        corporate_number='3010701025184',
    ),
    'E02622': EdinetCodeEntry(
        edinet_code='E02622',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=22187,
        fiscal_year_end='2月末日',
        submitter_name='ユニーグループ・ホールディングス株式会社',
        submitter_name_en='UNY Group Holdings Co., Ltd.',
        submitter_name_yomi='ユニーグループホールディングスカブシキガイシャ',
        address='稲沢市天池五反田町１番地',
        industry='小売業',
        sec_code=None,
        corporate_number='5180001086231',
    ),
    'E02623': EdinetCodeEntry(
        edinet_code='E02623',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2620,
        fiscal_year_end=None,
        submitter_name='株式会社日本アクセス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニッポンアクセス',
        address='品川区西品川一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010701025541',
    ),
    'E02624': EdinetCodeEntry(
        edinet_code='E02624',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='3月31日',
        submitter_name='山崎金属産業株式会社',
        submitter_name_en='YAMAKIN(JAPAN) Co.,Ltd.',
        submitter_name_yomi='ヤマザキキンゾクサンギョウカブシキガイシャ',
        address='千代田区岩本町１－８－１１',
        industry='卸売業',
        sec_code=None,
        corporate_number='1010001031109',
    ),
    'E02625': EdinetCodeEntry(
        edinet_code='E02625',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='東京貿易ホールディングス株式会社',
        submitter_name_en='TOKYO BOEKI HOLDINGS CORPORATION',
        submitter_name_yomi='トウキョウボウエキホールディングスカブシキガイシャ',
        address='中央区京橋二丁目２番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='7010001061629',
    ),
    'E02627': EdinetCodeEntry(
        edinet_code='E02627',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='Ｂｉｔｃｏｉｎ\u3000Ｊａｐａｎ株式会社',
        submitter_name_en='Bitcoin Japan Corporation',
        submitter_name_yomi='ビットコインジャパンカブシキガイシャ',
        address='墨田区横網１丁目１０番５号',
        industry='卸売業',
        sec_code='81050',
        corporate_number='1010001034953',
    ),
    'E02628': EdinetCodeEntry(
        edinet_code='E02628',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=86,
        fiscal_year_end='3月31日',
        submitter_name='株式会社キムラタン',
        submitter_name_en='KIMURATAN CORPORATION',
        submitter_name_yomi='カブシキガイシャキムラタン',
        address='神戸市中央区京町８３番地三宮センチュリービル',
        industry='繊維製品',
        sec_code='81070',
        corporate_number='8140001007130',
    ),
    'E02632': EdinetCodeEntry(
        edinet_code='E02632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22398,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メディパルホールディングス',
        submitter_name_en='MEDIPAL HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャメディパルホールディングス',
        address='中央区八重洲二丁目７番１５号',
        industry='卸売業',
        sec_code='74590',
        corporate_number='5010001068510',
    ),
    'E02635': EdinetCodeEntry(
        edinet_code='E02635',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3762,
        fiscal_year_end='3月31日',
        submitter_name='ソーダニッカ株式会社',
        submitter_name_en='SODA NIKKA CO., LTD.',
        submitter_name_yomi='ソーダニッカカブシキガイシャ',
        address='中央区日本橋三丁目６番２号',
        industry='卸売業',
        sec_code='81580',
        corporate_number='9010001048574',
    ),
    'E02639': EdinetCodeEntry(
        edinet_code='E02639',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='ムーンバット株式会社',
        submitter_name_en='MOONBAT Co., Ltd.',
        submitter_name_yomi='ムーンバットカブシキガイシャ',
        address='京都市下京区室町通四条南入鶏鉾町４９３番地',
        industry='卸売業',
        sec_code='81150',
        corporate_number='5130001019030',
    ),
    'E02640': EdinetCodeEntry(
        edinet_code='E02640',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16389,
        fiscal_year_end='3月31日',
        submitter_name='日鉄物産株式会社',
        submitter_name_en='NIPPON STEEL TRADING CORPORATION',
        submitter_name_yomi='ニッテツブッサンカブシキガイシャ',
        address='中央区日本橋二丁目７番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='3010001094558',
    ),
    'E02642': EdinetCodeEntry(
        edinet_code='E02642',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1001,
        fiscal_year_end='3月31日',
        submitter_name='中央自動車工業株式会社',
        submitter_name_en='CENTRAL AUTOMOTIVE PRODUCTS LTD.',
        submitter_name_yomi='チュウオウジドウシャコウギョウカブシキガイシャ',
        address='大阪市北区中之島四丁目２番３０号',
        industry='卸売業',
        sec_code='81170',
        corporate_number='3120001067115',
    ),
    'E02643': EdinetCodeEntry(
        edinet_code='E02643',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19878,
        fiscal_year_end='3月31日',
        submitter_name='伊藤忠エネクス株式会社',
        submitter_name_en='ITOCHU ENEX CO.,LTD.',
        submitter_name_yomi='イトウチュウエネクスカブシキガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='卸売業',
        sec_code='81330',
        corporate_number='9010401078551',
    ),
    'E02644': EdinetCodeEntry(
        edinet_code='E02644',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=73303,
        fiscal_year_end='12月31日',
        submitter_name='キヤノンマーケティングジャパン株式会社',
        submitter_name_en='Canon Marketing Japan Inc.',
        submitter_name_yomi='キヤノンマーケティングジャパンカブシキガイシャ',
        address='港区港南２丁目１６番６号',
        industry='卸売業',
        sec_code='80600',
        corporate_number='5010401008297',
    ),
    'E02645': EdinetCodeEntry(
        edinet_code='E02645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2346,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000キング',
        submitter_name_en='KING CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000キング',
        address='京都市下京区東塩小路高倉町２番の１',
        industry='繊維製品',
        sec_code='81180',
        corporate_number='8130001017089',
    ),
    'E02646': EdinetCodeEntry(
        edinet_code='E02646',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1450,
        fiscal_year_end='3月31日',
        submitter_name='中部水産株式会社',
        submitter_name_en='CHUBU SUISAN CO.,LTD.',
        submitter_name_yomi='チュウブスイサンカブシキガイシャ',
        address='名古屋市熱田区川並町２番２２号',
        industry='卸売業',
        sec_code='81450',
        corporate_number='3180001022262',
    ),
    'E02647': EdinetCodeEntry(
        edinet_code='E02647',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三栄コーポレーション',
        submitter_name_en='SANYEI CORPORATION',
        submitter_name_yomi='カブシキガイシャサンエイコーポレーション',
        address='台東区寿４丁目１番２号',
        industry='卸売業',
        sec_code='81190',
        corporate_number='1010501004662',
    ),
    'E02650': EdinetCodeEntry(
        edinet_code='E02650',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1720,
        fiscal_year_end='3月31日',
        submitter_name='川辺株式会社',
        submitter_name_en='T.KAWABE & CO., LTD.',
        submitter_name_yomi='カワベカブシキガイシャ',
        address='新宿区四谷４丁目１６番３号',
        industry='卸売業',
        sec_code='81230',
        corporate_number='5011101004900',
    ),
    'E02652': EdinetCodeEntry(
        edinet_code='E02652',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54961,
        fiscal_year_end='3月31日',
        submitter_name='東京エレクトロン株式会社',
        submitter_name_en='Tokyo Electron Limited',
        submitter_name_yomi='トウキョウエレクトロンカブシキガイシャ',
        address='港区赤坂五丁目３番１号',
        industry='電気機器',
        sec_code='80350',
        corporate_number='4010401020757',
    ),
    'E02653': EdinetCodeEntry(
        edinet_code='E02653',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社光製作所',
        submitter_name_en='HIKARI FURNITURE CO., LTD.',
        submitter_name_yomi='カブシキガイシャヒカリセイサクショ',
        address='荒川区東尾久四丁目７番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='5011501008377',
    ),
    'E02655': EdinetCodeEntry(
        edinet_code='E02655',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンリオ',
        submitter_name_en='Sanrio Company, Ltd.',
        submitter_name_yomi='カブシキガイシャサンリオ',
        address='品川区大崎１丁目６番１号',
        industry='卸売業',
        sec_code='81360',
        corporate_number='5010701003956',
    ),
    'E02656': EdinetCodeEntry(
        edinet_code='E02656',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3727,
        fiscal_year_end='3月31日',
        submitter_name='サンワテクノス株式会社',
        submitter_name_en='sun-wa technos corporation',
        submitter_name_yomi='サンワテクノスカブシキガイシャ',
        address='中央区京橋三丁目１番１号',
        industry='卸売業',
        sec_code='81370',
        corporate_number='5010001045369',
    ),
    'E02658': EdinetCodeEntry(
        edinet_code='E02658',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1716,
        fiscal_year_end='3月31日',
        submitter_name='三京化成株式会社',
        submitter_name_en='SANKYOKASEI CORPORATION',
        submitter_name_yomi='サンキョウカセイカブシキガイシャ',
        address='大阪市中央区北久宝寺町一丁目９番８号',
        industry='卸売業',
        sec_code='81380',
        corporate_number='8120001080385',
    ),
    'E02660': EdinetCodeEntry(
        edinet_code='E02660',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5323,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナガホリ',
        submitter_name_en='NAGAHORI CORPORATION',
        submitter_name_yomi='カブシキガイシャナガホリ',
        address='台東区上野１－１５－３',
        industry='卸売業',
        sec_code='81390',
        corporate_number='9010501010760',
    ),
    'E02663': EdinetCodeEntry(
        edinet_code='E02663',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=17690,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リョーサン',
        submitter_name_en='Ryosan Company, Limited',
        submitter_name_yomi='カブシキガイシャ\u3000リョーサン',
        address='千代田区東神田２丁目３番５号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010001008810',
    ),
    'E02664': EdinetCodeEntry(
        edinet_code='E02664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9501,
        fiscal_year_end='3月31日',
        submitter_name='新光商事株式会社',
        submitter_name_en='Shinko Shoji Co.,Ltd.',
        submitter_name_yomi='シンコウショウジカブシキガイシャ',
        address='品川区大崎一丁目２番２号',
        industry='卸売業',
        sec_code='81410',
        corporate_number='3010701019351',
    ),
    'E02665': EdinetCodeEntry(
        edinet_code='E02665',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5344,
        fiscal_year_end='1月31日',
        submitter_name='株式会社トーホー',
        submitter_name_en='TOHO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトーホー',
        address='神戸市東灘区向洋町西５丁目９番',
        industry='卸売業',
        sec_code='81420',
        corporate_number='1140001002071',
    ),
    'E02666': EdinetCodeEntry(
        edinet_code='E02666',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2644,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デンキョーグループホールディングス',
        submitter_name_en='Denkyo Group Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャデンキョーグループホールディングス',
        address='大阪市浪速区日本橋東２丁目１番３号',
        industry='卸売業',
        sec_code='81440',
        corporate_number='7120001039110',
    ),
    'E02668': EdinetCodeEntry(
        edinet_code='E02668',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=397,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トミタ',
        submitter_name_en='TOMITA CO.LTD.',
        submitter_name_yomi='カブシキガイシャトミタ',
        address='中央区銀座８丁目３番１０号',
        industry='卸売業',
        sec_code='81470',
        corporate_number='8010001052494',
    ),
    'E02669': EdinetCodeEntry(
        edinet_code='E02669',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='上原成商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウエハラセイショウジカブシキガイシャ',
        address='京都市中京区車屋町通御池上ル塗師屋町３４４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4130001019956',
    ),
    'E02671': EdinetCodeEntry(
        edinet_code='E02671',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14811,
        fiscal_year_end='3月31日',
        submitter_name='三信電気株式会社',
        submitter_name_en='SANSHIN ELECTRONICS CO., LTD.',
        submitter_name_yomi='サンシンデンキカブシキガイシャ',
        address='港区芝四丁目４番１２号',
        industry='卸売業',
        sec_code='81500',
        corporate_number='1010401012096',
    ),
    'E02672': EdinetCodeEntry(
        edinet_code='E02672',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4158,
        fiscal_year_end='9月30日',
        submitter_name='株式会社東陽テクニカ',
        submitter_name_en='TOYO Corporation',
        submitter_name_yomi='カブシキガイシャトウヨウテクニカ',
        address='中央区八重洲一丁目１番６号',
        industry='卸売業',
        sec_code='81510',
        corporate_number='8010001051991',
    ),
    'E02673': EdinetCodeEntry(
        edinet_code='E02673',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5115,
        fiscal_year_end='3月31日',
        submitter_name='ソマール株式会社',
        submitter_name_en='SOMAR CORPORATION',
        submitter_name_yomi='ソマールカブシキガイシャ',
        address='中央区銀座４－１１－２',
        industry='卸売業',
        sec_code='81520',
        corporate_number='9010001048632',
    ),
    'E02674': EdinetCodeEntry(
        edinet_code='E02674',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=525,
        fiscal_year_end='3月31日',
        submitter_name='日本アルコール販売株式会社',
        submitter_name_en='JAPAN ALCOHOL TRADING CO.,LTD.',
        submitter_name_yomi='ニホンアルコールハンバイカブシキガイシャ',
        address='中央区日本橋小舟町６－６',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010001065216',
    ),
    'E02675': EdinetCodeEntry(
        edinet_code='E02675',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11412,
        fiscal_year_end='3月31日',
        submitter_name='株式会社モスフードサービス',
        submitter_name_en='MOS FOOD SERVICES,INC.',
        submitter_name_yomi='カブシキガイシャモスフードサービス',
        address='品川区大崎二丁目１番１号',
        industry='卸売業',
        sec_code='81530',
        corporate_number='5010701019713',
    ),
    'E02676': EdinetCodeEntry(
        edinet_code='E02676',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12133,
        fiscal_year_end='3月31日',
        submitter_name='加賀電子株式会社',
        submitter_name_en='KAGA ELECTRONICS CO.,LTD.',
        submitter_name_yomi='カガデンシカブシキガイシャ',
        address='千代田区神田松永町２０番地',
        industry='卸売業',
        sec_code='81540',
        corporate_number='4010001001752',
    ),
    'E02677': EdinetCodeEntry(
        edinet_code='E02677',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=18824,
        fiscal_year_end='5月31日',
        submitter_name='三益半導体工業株式会社',
        submitter_name_en='MIMASU SEMICONDUCTOR INDUSTRY CO., LTD.',
        submitter_name_yomi='ミマスハンドウタイコウギョウカブシキガイシャ',
        address='高崎市保渡田町２１７４番地１',
        industry='金属製品',
        sec_code=None,
        corporate_number='5070001009541',
    ),
    'E02678': EdinetCodeEntry(
        edinet_code='E02678',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5874,
        fiscal_year_end='3月31日',
        submitter_name='株式会社立花エレテック',
        submitter_name_en='TACHIBANA ELETECH CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000タチバナエレテック',
        address='大阪市西区西本町１丁目１３番２５号',
        industry='卸売業',
        sec_code='81590',
        corporate_number='2120001049007',
    ),
    'E02679': EdinetCodeEntry(
        edinet_code='E02679',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4049,
        fiscal_year_end='12月31日',
        submitter_name='株式会社東京ソワール',
        submitter_name_en='TOKYO SOIR CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウソワール',
        address='中央区銀座七丁目１６番１２号',
        industry='繊維製品',
        sec_code='80400',
        corporate_number='8010401020803',
    ),
    'E02681': EdinetCodeEntry(
        edinet_code='E02681',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3379,
        fiscal_year_end='10月31日',
        submitter_name='正栄食品工業株式会社',
        submitter_name_en='SHOEI FOODS CORPORATION',
        submitter_name_yomi='ショウエイショクヒンコウギョウカブシキガイシャ',
        address='台東区秋葉原５番７号',
        industry='卸売業',
        sec_code='80790',
        corporate_number='5010001139914',
    ),
    'E02682': EdinetCodeEntry(
        edinet_code='E02682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8132,
        fiscal_year_end='3月31日',
        submitter_name='カメイ株式会社',
        submitter_name_en='KAMEI CORPORATION',
        submitter_name_yomi='カメイカブシキガイシャ',
        address='仙台市青葉区国分町３丁目１番１８号',
        industry='卸売業',
        sec_code='80370',
        corporate_number='5370001003340',
    ),
    'E02683': EdinetCodeEntry(
        edinet_code='E02683',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1969,
        fiscal_year_end='3月31日',
        submitter_name='ＤＡＩＫＯ\u3000ＸＴＥＣＨ株式会社',
        submitter_name_en='DAIKO XTECH, Ltd.',
        submitter_name_yomi='ダイコウ\u3000クロステックカブシキガイシャ',
        address='新宿区揚場町２番１号',
        industry='卸売業',
        sec_code='80230',
        corporate_number='2011101011783',
    ),
    'E02684': EdinetCodeEntry(
        edinet_code='E02684',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3075,
        fiscal_year_end='3月31日',
        submitter_name='東海エレクトロニクス株式会社',
        submitter_name_en='TOKAI ELECTRONICS CO.,LTD.',
        submitter_name_yomi='トウカイエレクトロニクスカブシキガイシャ',
        address='名古屋市中区栄三丁目３４番１４号',
        industry='卸売業',
        sec_code='80710',
        corporate_number='4180001038563',
    ),
    'E02685': EdinetCodeEntry(
        edinet_code='E02685',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13672,
        fiscal_year_end='3月31日',
        submitter_name='菱洋エレクトロ株式会社',
        submitter_name_en='RYOYO ELECTRO CORPORATION',
        submitter_name_yomi='リョーヨーエレクトロカブシキガイシャ',
        address='中央区築地一丁目１２番２２号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010001060398',
    ),
    'E02686': EdinetCodeEntry(
        edinet_code='E02686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4603,
        fiscal_year_end='3月31日',
        submitter_name='コニシ株式会社',
        submitter_name_en='KONISHI CO.,LTD.',
        submitter_name_yomi='コニシカブシキガイシャ',
        address='大阪市中央区道修町１丁目６番１０号',
        industry='化学',
        sec_code='49560',
        corporate_number='9120001077414',
    ),
    'E02687': EdinetCodeEntry(
        edinet_code='E02687',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7609,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＡＧねっとホールディングス',
        submitter_name_en='MAG NET HOLDINGS,INC.',
        submitter_name_yomi='カブシキガイシャマグネットホールディングス',
        address='港区赤坂三丁目９番２号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010401082710',
    ),
    'E02688': EdinetCodeEntry(
        edinet_code='E02688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=84397,
        fiscal_year_end='3月31日',
        submitter_name='ニプロ株式会社',
        submitter_name_en='NIPRO CORPORATION',
        submitter_name_yomi='ニプロカブシキガイシャ',
        address='摂津市千里丘新町３番２６号',
        industry='精密機器',
        sec_code='80860',
        corporate_number='8120001068678',
    ),
    'E02690': EdinetCodeEntry(
        edinet_code='E02690',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1387,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファミリー',
        submitter_name_en='FAMILY INC.',
        submitter_name_yomi='カブシキガイシャファミリー',
        address='千葉市中央区東千葉２－８－１５',
        industry='小売業',
        sec_code=None,
        corporate_number='4040001006468',
    ),
    'E02691': EdinetCodeEntry(
        edinet_code='E02691',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=15869,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＰＡＬＴＡＣ',
        submitter_name_en='PALTAC CORPORATION',
        submitter_name_yomi='カブシキガイシャパルタック',
        address='大阪市中央区本町橋２番４６号',
        industry='卸売業',
        sec_code='82830',
        corporate_number='2120001077528',
    ),
    'E02692': EdinetCodeEntry(
        edinet_code='E02692',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4808,
        fiscal_year_end='3月31日',
        submitter_name='三谷産業株式会社',
        submitter_name_en='MITANI SANGYO CO.,LTD.',
        submitter_name_yomi='ミタニサンギョウカブシキガイシャ',
        address='金沢市玉川町１番５号',
        industry='卸売業',
        sec_code='82850',
        corporate_number='5220001006845',
    ),
    'E02693': EdinetCodeEntry(
        edinet_code='E02693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4150,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォーバル',
        submitter_name_en='FORVAL CORPORATION',
        submitter_name_yomi='カブシキガイシャフォーバル',
        address='渋谷区神宮前五丁目５２番２号',
        industry='卸売業',
        sec_code='82750',
        corporate_number='4011001025865',
    ),
    'E02695': EdinetCodeEntry(
        edinet_code='E02695',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=667,
        fiscal_year_end=None,
        submitter_name='株式会社プロルート丸光',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプロルートマルミツ',
        address='大阪市中央区北久宝寺町二丁目１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001089000',
    ),
    'E02696': EdinetCodeEntry(
        edinet_code='E02696',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5001,
        fiscal_year_end=None,
        submitter_name='株式会社テクノアソシエ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテクノアソシエ',
        address='大阪市西区土佐堀３丁目３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001039195',
    ),
    'E02698': EdinetCodeEntry(
        edinet_code='E02698',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3719,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マルイチ産商',
        submitter_name_en='MARUICHI Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャマルイチサンショウ',
        address='長野市市場３番地４８',
        industry='卸売業',
        sec_code='82280',
        corporate_number='5100001003284',
    ),
    'E02699': EdinetCodeEntry(
        edinet_code='E02699',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3426,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000理経',
        submitter_name_en='RIKEI CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000リケイ',
        address='新宿区西新宿３丁目２番１１号',
        industry='卸売業',
        sec_code='82260',
        corporate_number='8011101022577',
    ),
    'E02701': EdinetCodeEntry(
        edinet_code='E02701',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5022,
        fiscal_year_end='12月31日',
        submitter_name='トラスコ中山株式会社',
        submitter_name_en='TRUSCO NAKAYAMA CORPORATION',
        submitter_name_yomi='トラスコナカヤマカブシキガイシャ',
        address='港区新橋四丁目２８番１号',
        industry='卸売業',
        sec_code='98300',
        corporate_number='5120001108073',
    ),
    'E02702': EdinetCodeEntry(
        edinet_code='E02702',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=86,
        fiscal_year_end='11月30日',
        submitter_name='リーバイ・ストラウス\u3000ジャパン株式会社',
        submitter_name_en='LEVI STRAUSS JAPAN KABUSHIKI KAISHA',
        submitter_name_yomi='リーバイストラウス\u3000ジャパン\u3000カブシキガイシャ',
        address='港区西麻布２丁目２３－７',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010401092891',
    ),
    'E02703': EdinetCodeEntry(
        edinet_code='E02703',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3532,
        fiscal_year_end='11月30日',
        submitter_name='モリト株式会社',
        submitter_name_en='MORITO CO.,LTD.',
        submitter_name_yomi='モリトカブシキガイシャ',
        address='大阪市中央区南本町４丁目２番４号',
        industry='卸売業',
        sec_code='98370',
        corporate_number='3120001077568',
    ),
    'E02706': EdinetCodeEntry(
        edinet_code='E02706',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6462,
        fiscal_year_end='2月末日',
        submitter_name='アークランズ株式会社',
        submitter_name_en='ARCLANDS CORPORATION',
        submitter_name_yomi='アークランズカブシキガイシャ',
        address='三条市上須頃４４５番地',
        industry='小売業',
        sec_code='98420',
        corporate_number='4110001013829',
    ),
    'E02708': EdinetCodeEntry(
        edinet_code='E02708',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2201,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パーカーコーポレーション',
        submitter_name_en='PARKER  CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000パーカーコーポレーション',
        address='中央区日本橋人形町二丁目２２番１号',
        industry='化学',
        sec_code='98450',
        corporate_number='5010001054386',
    ),
    'E02711': EdinetCodeEntry(
        edinet_code='E02711',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2381,
        fiscal_year_end='3月31日',
        submitter_name='株式会社共同紙販ホールディングス',
        submitter_name_en='KYODO PAPER HOLDINGS',
        submitter_name_yomi='カブシキガイシャキョウドウカミハンホールディングス',
        address='台東区北上野一丁目９番１２号住友不動産上野ビル６階',
        industry='卸売業',
        sec_code='98490',
        corporate_number='3010501032728',
    ),
    'E02712': EdinetCodeEntry(
        edinet_code='E02712',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1608,
        fiscal_year_end='3月31日',
        submitter_name='ＣＢグループマネジメント株式会社',
        submitter_name_en='CB GROUP MANAGEMENT Co., Ltd',
        submitter_name_yomi='シービーグループマネジメントカブシキガイシャ',
        address='港区南青山２丁目２番３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010401017915',
    ),
    'E02713': EdinetCodeEntry(
        edinet_code='E02713',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1533,
        fiscal_year_end='3月31日',
        submitter_name='英和株式会社',
        submitter_name_en='EIWA CORPORATION',
        submitter_name_yomi='エイワカブシキガイシャ',
        address='大阪市西区北堀江４丁目１番７号',
        industry='卸売業',
        sec_code='98570',
        corporate_number='6120001041612',
    ),
    'E02714': EdinetCodeEntry(
        edinet_code='E02714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ケーユーホールディングス',
        submitter_name_en='KU HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャケーユーホールディングス',
        address='町田市鶴間八丁目１７番１号',
        industry='小売業',
        sec_code='98560',
        corporate_number='9012301000743',
    ),
    'E02718': EdinetCodeEntry(
        edinet_code='E02718',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2293,
        fiscal_year_end='3月31日',
        submitter_name='ソレキア株式会社',
        submitter_name_en='Solekia Limited',
        submitter_name_yomi='ソレキアカブシキガイシャ',
        address='大田区西蒲田８丁目１６番６号',
        industry='卸売業',
        sec_code='98670',
        corporate_number='1010801004073',
    ),
    'E02719': EdinetCodeEntry(
        edinet_code='E02719',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5934,
        fiscal_year_end='9月30日',
        submitter_name='加藤産業株式会社',
        submitter_name_en='KATO SANGYO CO.,LTD.',
        submitter_name_yomi='カトウサンギョウカブシキガイシャ',
        address='西宮市松原町９番２０号',
        industry='卸売業',
        sec_code='98690',
        corporate_number='6140001068331',
    ),
    'E02722': EdinetCodeEntry(
        edinet_code='E02722',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2220,
        fiscal_year_end='11月20日',
        submitter_name='北恵株式会社',
        submitter_name_en='KITAKEI CO.,LTD',
        submitter_name_yomi='キタケイカブシキガイシャ',
        address='大阪市中央区南本町３丁目６番１４号\u3000\u3000イトウビル',
        industry='卸売業',
        sec_code='98720',
        corporate_number='7120001077804',
    ),
    'E02724': EdinetCodeEntry(
        edinet_code='E02724',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10517,
        fiscal_year_end='3月31日',
        submitter_name='イノテック株式会社',
        submitter_name_en='INNOTECH CORPORATION',
        submitter_name_yomi='イノテックカブシキガイシャ',
        address='横浜市港北区新横浜三丁目１７番地６号',
        industry='電気機器',
        sec_code='98800',
        corporate_number='8020001019484',
    ),
    'E02727': EdinetCodeEntry(
        edinet_code='E02727',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000シャルレ',
        submitter_name_en='CHARLE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000シャルレ',
        address='神戸市中央区港島中町七丁目７番１号',
        industry='卸売業',
        sec_code='98850',
        corporate_number='6140001008568',
    ),
    'E02728': EdinetCodeEntry(
        edinet_code='E02728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1512,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＵＥＸ',
        submitter_name_en='UEX, LTD.',
        submitter_name_yomi='カブシキガイシャウエックス',
        address='品川区東品川二丁目２番２４号',
        industry='卸売業',
        sec_code='98880',
        corporate_number='9010701001205',
    ),
    'E02729': EdinetCodeEntry(
        edinet_code='E02729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4713,
        fiscal_year_end='3月31日',
        submitter_name='ＪＢＣＣホールディングス株式会社',
        submitter_name_en='JBCC Holdings Inc.',
        submitter_name_yomi='ジェイビーシーシーホールディングスカブシキカイシャ',
        address='中央区八重洲二丁目２番１号（東京ミッドタウン八重洲\u3000八重洲セントラルタワー）',
        industry='情報・通信業',
        sec_code='98890',
        corporate_number='6010801009068',
    ),
    'E02732': EdinetCodeEntry(
        edinet_code='E02732',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2600,
        fiscal_year_end='3月31日',
        submitter_name='ＪＫホールディングス株式会社',
        submitter_name_en='JK Holdings Co.,Ltd.',
        submitter_name_yomi='ジェイケーホールディングスカブシキカイシャ',
        address='江東区新木場一丁目７番２２号',
        industry='卸売業',
        sec_code='98960',
        corporate_number='4010601027156',
    ),
    'E02734': EdinetCodeEntry(
        edinet_code='E02734',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=275,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サハダイヤモンド',
        submitter_name_en='SAKHA DIAMOND Corp.',
        submitter_name_yomi='カブシキガイシャサハダイヤモンド',
        address='台東区浅草橋３－３４－１０－２０２',
        industry='卸売業',
        sec_code=None,
        corporate_number='1010601031144',
    ),
    'E02735': EdinetCodeEntry(
        edinet_code='E02735',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15072,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イエローハット',
        submitter_name_en='YELLOW HAT LTD.',
        submitter_name_yomi='カブシキガイシャイエローハット',
        address='大田区北千束１－４－６',
        industry='卸売業',
        sec_code='98820',
        corporate_number='1010001126172',
    ),
    'E02738': EdinetCodeEntry(
        edinet_code='E02738',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1585,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ストライダーズ',
        submitter_name_en='Striders Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000ストライダーズ',
        address='中央区日本橋室町四丁目６番２号',
        industry='卸売業',
        sec_code='98160',
        corporate_number='5010401094750',
    ),
    'E02739': EdinetCodeEntry(
        edinet_code='E02739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=870,
        fiscal_year_end='3月31日',
        submitter_name='大丸エナウィン株式会社',
        submitter_name_en='DAIMARU.ENAWIN CO.,LTD.',
        submitter_name_yomi='ダイマルエナウィンカブシキガイシャ',
        address='大阪市住之江区緑木１－４－３９',
        industry='卸売業',
        sec_code='98180',
        corporate_number='6120001031150',
    ),
    'E02740': EdinetCodeEntry(
        edinet_code='E02740',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1072,
        fiscal_year_end='3月31日',
        submitter_name='エムティジェネックス株式会社',
        submitter_name_en='MT GENEX CORPORATION',
        submitter_name_yomi='エムティジェネックスカブシキガイシャ',
        address='港区虎ノ門５丁目１３番１号',
        industry='不動産業',
        sec_code='98200',
        corporate_number='4010401039616',
    ),
    'E02742': EdinetCodeEntry(
        edinet_code='E02742',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2575,
        fiscal_year_end='10月31日',
        submitter_name='泉州電業株式会社',
        submitter_name_en='SENSHU ELECTRIC CO.,LTD.',
        submitter_name_yomi='センシュウデンギョウカブシキガイシャ',
        address='吹田市南金田一丁目４番２１号',
        industry='卸売業',
        sec_code='98240',
        corporate_number='2120001066027',
    ),
    'E02743': EdinetCodeEntry(
        edinet_code='E02743',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3335,
        fiscal_year_end='12月31日',
        submitter_name='リリカラ株式会社',
        submitter_name_en='Lilycolor Co., Ltd.',
        submitter_name_yomi='リリカラカブシキガイシャ',
        address='新宿区西新宿７丁目５番２０号',
        industry='卸売業',
        sec_code='98270',
        corporate_number='2011101022797',
    ),
    'E02745': EdinetCodeEntry(
        edinet_code='E02745',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5368,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日伝',
        submitter_name_en='nichiden corporation',
        submitter_name_yomi='カブシキガイシャニチデン',
        address='大阪市中央区上本町西１丁目２番１６号',
        industry='卸売業',
        sec_code='99020',
        corporate_number='8120001077522',
    ),
    'E02747': EdinetCodeEntry(
        edinet_code='E02747',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1883,
        fiscal_year_end='3月31日',
        submitter_name='藤井産業株式会社',
        submitter_name_en='Fujii Sangyo Corporation',
        submitter_name_yomi='フジイサンギョウカブシキガイシャ',
        address='宇都宮市平出工業団地４１番地３',
        industry='卸売業',
        sec_code='99060',
        corporate_number='2060001003812',
    ),
    'E02749': EdinetCodeEntry(
        edinet_code='E02749',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1159,
        fiscal_year_end='3月31日',
        submitter_name='日本電計株式会社',
        submitter_name_en='NIHON DENKEI CO.,LTD.',
        submitter_name_yomi='ニホンデンケイカブシキガイシャ',
        address='台東区上野５丁目１４番１２号',
        industry='卸売業',
        sec_code='99080',
        corporate_number='9010501010505',
    ),
    'E02750': EdinetCodeEntry(
        edinet_code='E02750',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=611,
        fiscal_year_end='3月20日',
        submitter_name='愛光電気株式会社',
        submitter_name_en='AIKO CORPORATION',
        submitter_name_yomi='アイコウデンキカブシキカイシャ',
        address='小田原市西大友２０５番地２',
        industry='卸売業',
        sec_code=None,
        corporate_number='9021001032237',
    ),
    'E02751': EdinetCodeEntry(
        edinet_code='E02751',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11813,
        fiscal_year_end=None,
        submitter_name='ダイワボウ情報システム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイワボウジョウホウシステムカブシキガイシャ',
        address='大阪市北区中之島３ー２－４\u3000中之島フェスティバルタワーウエスト１０Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001083217',
    ),
    'E02752': EdinetCodeEntry(
        edinet_code='E02752',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3137,
        fiscal_year_end='3月31日',
        submitter_name='日邦産業株式会社',
        submitter_name_en='NIPPO LTD.',
        submitter_name_yomi='ニッポウサンギョウカブシキガイシャ',
        address='名古屋市中区錦一丁目１０番１号',
        industry='卸売業',
        sec_code='99130',
        corporate_number='1120901007832',
    ),
    'E02753': EdinetCodeEntry(
        edinet_code='E02753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1017,
        fiscal_year_end='3月20日',
        submitter_name='株式会社\u3000植松商会',
        submitter_name_en='uematsu shokai co.,ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ウエマツショウカイ',
        address='仙台市若林区卸町三丁目７番地の５',
        industry='卸売業',
        sec_code='99140',
        corporate_number='1370001002651',
    ),
    'E02754': EdinetCodeEntry(
        edinet_code='E02754',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3992,
        fiscal_year_end=None,
        submitter_name='株式会社バイタルネット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャバイタルネット',
        address='仙台市青葉区大手町１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4370001008142',
    ),
    'E02759': EdinetCodeEntry(
        edinet_code='E02759',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2107,
        fiscal_year_end='3月31日',
        submitter_name='平和紙業株式会社',
        submitter_name_en='HEIWA PAPER CO., LTD.',
        submitter_name_yomi='ヘイワシギョウカブシキガイシャ',
        address='中央区新川１－２２－１１',
        industry='卸売業',
        sec_code='99290',
        corporate_number='5120001089074',
    ),
    'E02760': EdinetCodeEntry(
        edinet_code='E02760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2597,
        fiscal_year_end='3月31日',
        submitter_name='杉本商事株式会社',
        submitter_name_en='SUGIMOTO & CO.,LTD.',
        submitter_name_yomi='スギモトショウジカブシキガイシャ',
        address='大阪市西区立売堀５丁目７番２７号',
        industry='卸売業',
        sec_code='99320',
        corporate_number='9120001044397',
    ),
    'E02761': EdinetCodeEntry(
        edinet_code='E02761',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14529,
        fiscal_year_end='3月31日',
        submitter_name='因幡電機産業株式会社',
        submitter_name_en='INABA DENKI SANGYO CO.,LTD.',
        submitter_name_yomi='イナバデンキサンギョウカブシキガイシャ',
        address='大阪市西区立売堀四丁目１１番１４号',
        industry='卸売業',
        sec_code='99340',
        corporate_number='1120001041352',
    ),
    'E02762': EdinetCodeEntry(
        edinet_code='E02762',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=257,
        fiscal_year_end='9月30日',
        submitter_name='太洋物産株式会社',
        submitter_name_en='TAIYO BUSSAN KAISHA,LTD.',
        submitter_name_yomi='タイヨウブッサンカブシキガイシャ',
        address='新宿区市谷砂土原町三丁目５番地',
        industry='卸売業',
        sec_code='99410',
        corporate_number='5010001049188',
    ),
    'E02765': EdinetCodeEntry(
        edinet_code='E02765',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2187,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨンキュウ',
        submitter_name_en='THE YONKYU CO., LTD.',
        submitter_name_yomi='カブシキガイシャヨンキュウ',
        address='宇和島市築地町２丁目３１８番地２３５',
        industry='卸売業',
        sec_code='99550',
        corporate_number='5500001015561',
    ),
    'E02766': EdinetCodeEntry(
        edinet_code='E02766',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5244,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バイテックホールディングス',
        submitter_name_en='VITEC HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャバイテックホールディングス',
        address='品川区東品川三丁目６番５号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010701008192',
    ),
    'E02767': EdinetCodeEntry(
        edinet_code='E02767',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ワールド',
        submitter_name_en='WORLD CO.,LTD.',
        submitter_name_yomi='カブシキガイシャワールド',
        address='神戸市中央区港島中町６丁目８番１',
        industry='卸売業',
        sec_code='36120',
        corporate_number='4140001024328',
    ),
    'E02769': EdinetCodeEntry(
        edinet_code='E02769',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1857,
        fiscal_year_end='3月31日',
        submitter_name='東テク株式会社',
        submitter_name_en='TOTECH CORPORATION',
        submitter_name_yomi='トウテクカブシキガイシャ',
        address='中央区日本橋本町三丁目１１番１１号',
        industry='卸売業',
        sec_code='99600',
        corporate_number='2010001051477',
    ),
    'E02770': EdinetCodeEntry(
        edinet_code='E02770',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13859,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ミスミグループ本社',
        submitter_name_en='MISUMI Group Inc.',
        submitter_name_yomi='カブシキガイシャミスミグループホンシャ',
        address='千代田区九段南一丁目６番５号',
        industry='卸売業',
        sec_code='99620',
        corporate_number='6010601006372',
    ),
    'E02772': EdinetCodeEntry(
        edinet_code='E02772',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=820,
        fiscal_year_end=None,
        submitter_name='堺商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サカイショウジカブシキガイシャ',
        address='大阪市北区中之島３丁目２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001077422',
    ),
    'E02773': EdinetCodeEntry(
        edinet_code='E02773',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2940,
        fiscal_year_end='3月31日',
        submitter_name='山喜株式会社',
        submitter_name_en='YAMAKI CO.,LTD.',
        submitter_name_yomi='ヤマキカブシキガイシャ',
        address='大阪市中央区上町１丁目３番１号',
        industry='繊維製品',
        sec_code='35980',
        corporate_number='3120001080679',
    ),
    'E02774': EdinetCodeEntry(
        edinet_code='E02774',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5527,
        fiscal_year_end='11月30日',
        submitter_name='アルテック株式会社',
        submitter_name_en='ALTECH CO., LTD.',
        submitter_name_yomi='アルテックカブシキガイシャ',
        address='中央区入船２丁目１番１号',
        industry='卸売業',
        sec_code='99720',
        corporate_number='6010001142875',
    ),
    'E02775': EdinetCodeEntry(
        edinet_code='E02775',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=417,
        fiscal_year_end='12月31日',
        submitter_name='ＫＯＺＯホールディングス株式会社',
        submitter_name_en='KOZO Holdings Co., Ltd.',
        submitter_name_yomi='コゾーホールディングスカブシキガイシャ',
        address='日本橋蛎殻町一丁目５番６号',
        industry='小売業',
        sec_code='99730',
        corporate_number='6012801009114',
    ),
    'E02776': EdinetCodeEntry(
        edinet_code='E02776',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3622,
        fiscal_year_end='2月末日',
        submitter_name='タキヒヨー株式会社',
        submitter_name_en='Takihyo Co., Ltd.',
        submitter_name_yomi='タキヒヨーカブシキガイシャ',
        address='名古屋市西区牛島町６番１号',
        industry='卸売業',
        sec_code='99820',
        corporate_number='7180001037793',
    ),
    'E02778': EdinetCodeEntry(
        edinet_code='E02778',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=238772,
        fiscal_year_end='3月31日',
        submitter_name='ソフトバンクグループ株式会社',
        submitter_name_en='SoftBank Group Corp.',
        submitter_name_yomi='ソフトバンクグループカブシキガイシャ',
        address='港区海岸一丁目７番１号',
        industry='情報・通信業',
        sec_code='99840',
        corporate_number='1010401056795',
    ),
    'E02779': EdinetCodeEntry(
        edinet_code='E02779',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2077,
        fiscal_year_end='3月31日',
        submitter_name='蔵王産業株式会社',
        submitter_name_en='ZAOH COMPANY, LTD.',
        submitter_name_yomi='ザオウサンギョウカブシキカイシャ',
        address='江東区毛利１丁目１９番５号',
        industry='卸売業',
        sec_code='99860',
        corporate_number='3010601019393',
    ),
    'E02780': EdinetCodeEntry(
        edinet_code='E02780',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13546,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スズケン',
        submitter_name_en='SUZUKEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスズケン',
        address='名古屋市東区東片端町８番地',
        industry='卸売業',
        sec_code='99870',
        corporate_number='1180001017009',
    ),
    'E02782': EdinetCodeEntry(
        edinet_code='E02782',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4398,
        fiscal_year_end='3月31日',
        submitter_name='ジェコス株式会社',
        submitter_name_en='GECOSS CORPORATION',
        submitter_name_yomi='ジェコスカブシキガイシャ',
        address='文京区後楽二丁目５番１号',
        industry='卸売業',
        sec_code='99910',
        corporate_number='2010001069981',
    ),
    'E02784': EdinetCodeEntry(
        edinet_code='E02784',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1102,
        fiscal_year_end='10月31日',
        submitter_name='株式会社理研グリーン',
        submitter_name_en='RIKENGREEN CO., LTD.',
        submitter_name_yomi='カブシキガイシャリケングリーン',
        address='台東区東上野四丁目８番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6010501014707',
    ),
    'E02785': EdinetCodeEntry(
        edinet_code='E02785',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5042,
        fiscal_year_end='3月31日',
        submitter_name='株式会社グローセル',
        submitter_name_en='Glosel Co., Ltd.',
        submitter_name_yomi='カブシキガイシャグローセル',
        address='千代田区神田司町二丁目１番地',
        industry='卸売業',
        sec_code=None,
        corporate_number='6010001036937',
    ),
    'E02786': EdinetCodeEntry(
        edinet_code='E02786',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1405,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サトー商会',
        submitter_name_en='Satoh&Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサトーショウカイ',
        address='仙台市宮城野区扇町五丁目６番２２号',
        industry='卸売業',
        sec_code='99960',
        corporate_number='7370001005153',
    ),
    'E02787': EdinetCodeEntry(
        edinet_code='E02787',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タカチホ',
        submitter_name_en='Takachiho Co.,Ltd',
        submitter_name_yomi='カブシキガイシャタカチホ',
        address='長野市大豆島５８８８番地',
        industry='卸売業',
        sec_code='82250',
        corporate_number='9100001001862',
    ),
    'E02791': EdinetCodeEntry(
        edinet_code='E02791',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=920,
        fiscal_year_end='3月31日',
        submitter_name='株式会社創健社',
        submitter_name_en='Sokensha Co., Ltd.',
        submitter_name_yomi='カブシキガイシャソウケンシャ',
        address='横浜市神奈川区片倉二丁目３７番１１号',
        industry='卸売業',
        sec_code='74130',
        corporate_number='1020001023559',
    ),
    'E02792': EdinetCodeEntry(
        edinet_code='E02792',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1181,
        fiscal_year_end='3月31日',
        submitter_name='株式会社南陽',
        submitter_name_en='NANYO CORPORATION',
        submitter_name_yomi='カブシキガイシャナンヨウ',
        address='福岡市博多区博多駅前三丁目１９番８号',
        industry='卸売業',
        sec_code='74170',
        corporate_number='5290001015146',
    ),
    'E02793': EdinetCodeEntry(
        edinet_code='E02793',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2611,
        fiscal_year_end='5月31日',
        submitter_name='佐鳥電機株式会社',
        submitter_name_en='SATORI ELECTRIC CO.,LTD.',
        submitter_name_yomi='サトリデンキカブシキガイシャ',
        address='港区芝一丁目１４番１０号',
        industry='卸売業',
        sec_code='74200',
        corporate_number='3010401011559',
    ),
    'E02794': EdinetCodeEntry(
        edinet_code='E02794',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=961,
        fiscal_year_end='12月20日',
        submitter_name='東邦レマック株式会社',
        submitter_name_en='TOHO LAMAC CO., LTD.',
        submitter_name_yomi='トウホウレマックカブシキガイシャ',
        address='文京区湯島三丁目４２番６号',
        industry='卸売業',
        sec_code='74220',
        corporate_number='2010001005342',
    ),
    'E02796': EdinetCodeEntry(
        edinet_code='E02796',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=520,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アドバンス',
        submitter_name_en='ADVANCE CO., LTD.',
        submitter_name_yomi='カブシキガイシャアドバンス',
        address='中央区東日本橋一丁目４番６号',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010001035884',
    ),
    'E02797': EdinetCodeEntry(
        edinet_code='E02797',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=885,
        fiscal_year_end='12月31日',
        submitter_name='初穂商事株式会社',
        submitter_name_en='HATSUHO SHOUJI CO.,LTD.',
        submitter_name_yomi='ハツホショウジカブシキガイシャ',
        address='名古屋市中区錦二丁目１４番２１号',
        industry='卸売業',
        sec_code='74250',
        corporate_number='2180001039869',
    ),
    'E02798': EdinetCodeEntry(
        edinet_code='E02798',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1103,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000山大',
        submitter_name_en='Yamadai Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマダイ',
        address='石巻市潮見町２番地の３',
        industry='卸売業',
        sec_code='74260',
        corporate_number='6370301001357',
    ),
    'E02799': EdinetCodeEntry(
        edinet_code='E02799',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1387,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ダルトン',
        submitter_name_en='DALTON corporation',
        submitter_name_yomi='カブシキガイシャダルトン',
        address='中央区築地五丁目６番１０号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8011101012660',
    ),
    'E02800': EdinetCodeEntry(
        edinet_code='E02800',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1491,
        fiscal_year_end='12月31日',
        submitter_name='ビーピー・カストロール株式会社',
        submitter_name_en='BP Castrol K.K.',
        submitter_name_yomi='ビーピー\u3000カストロール\u3000カブシキガイシャ',
        address='品川区大崎一丁目１１番２号',
        industry='石油・石炭製品',
        sec_code='50150',
        corporate_number='9010701017069',
    ),
    'E02801': EdinetCodeEntry(
        edinet_code='E02801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1988,
        fiscal_year_end='2月末日',
        submitter_name='エコートレーディング株式会社',
        submitter_name_en='ECHO TRADING CO.,LTD.',
        submitter_name_yomi='エコートレーディングカブシキガイシャ',
        address='大阪市淀川区宮原１丁目２番４号',
        industry='卸売業',
        sec_code='74270',
        corporate_number='4140001068093',
    ),
    'E02802': EdinetCodeEntry(
        edinet_code='E02802',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8100,
        fiscal_year_end='3月31日',
        submitter_name='伯東株式会社',
        submitter_name_en='Hakuto Co.,Ltd.',
        submitter_name_yomi='ハクトウカブシキガイシャ',
        address='新宿区新宿一丁目１番１３号',
        industry='卸売業',
        sec_code='74330',
        corporate_number='7011101017256',
    ),
    'E02803': EdinetCodeEntry(
        edinet_code='E02803',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1312,
        fiscal_year_end='5月31日',
        submitter_name='株式会社オータケ',
        submitter_name_en='OTAKE CORPORATION',
        submitter_name_yomi='カブシキガイシャオータケ',
        address='名古屋市中区丸の内２丁目１番８号',
        industry='卸売業',
        sec_code='74340',
        corporate_number='9180001029707',
    ),
    'E02804': EdinetCodeEntry(
        edinet_code='E02804',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2666,
        fiscal_year_end='3月31日',
        submitter_name='コンドーテック株式会社',
        submitter_name_en='kondotec inc.',
        submitter_name_yomi='コンドーテックカブシキガイシャ',
        address='大阪市西区境川２丁目２番１号',
        industry='卸売業',
        sec_code='74380',
        corporate_number='6120001043369',
    ),
    'E02805': EdinetCodeEntry(
        edinet_code='E02805',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1706,
        fiscal_year_end='3月31日',
        submitter_name='中山福株式会社',
        submitter_name_en='NAKAYAMAFUKU CO.,LTD.',
        submitter_name_yomi='ナカヤマフクカブシキガイシャ',
        address='大阪市中央区島之内一丁目２２番９号',
        industry='卸売業',
        sec_code='74420',
        corporate_number='9120001077505',
    ),
    'E02806': EdinetCodeEntry(
        edinet_code='E02806',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=829,
        fiscal_year_end='3月31日',
        submitter_name='横浜魚類株式会社',
        submitter_name_en='yokohama gyorui co.,ltd.',
        submitter_name_yomi='ヨコハマギョルイカブシキガイシャ',
        address='横浜市神奈川区山内町１番地',
        industry='卸売業',
        sec_code='74430',
        corporate_number='5020001030634',
    ),
    'E02807': EdinetCodeEntry(
        edinet_code='E02807',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=719,
        fiscal_year_end='3月31日',
        submitter_name='ハリマ共和物産株式会社',
        submitter_name_en='Harima-Kyowa Co.,LTD.',
        submitter_name_yomi='ハリマキョウワブッサンカブシキガイシャ',
        address='姫路市飾東町庄３１３番地',
        industry='卸売業',
        sec_code='74440',
        corporate_number='1140001060846',
    ),
    'E02809': EdinetCodeEntry(
        edinet_code='E02809',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1925,
        fiscal_year_end='8月31日',
        submitter_name='ナガイレーベン株式会社',
        submitter_name_en='NAGAILEBEN Co.,Ltd.',
        submitter_name_yomi='ナガイレーベンカブシキガイシャ',
        address='千代田区鍛冶町二丁目１番１０号',
        industry='卸売業',
        sec_code='74470',
        corporate_number='5010001025214',
    ),
    'E02810': EdinetCodeEntry(
        edinet_code='E02810',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=820,
        fiscal_year_end='9月30日',
        submitter_name='東北化学薬品株式会社',
        submitter_name_en='TOHOKU  CHEMICAL  CO.,  LTD.',
        submitter_name_yomi='トウホクカガクヤクヒンカブシキガイシャ',
        address='弘前市大字神田一丁目３番地の１',
        industry='卸売業',
        sec_code='74460',
        corporate_number='5420001009282',
    ),
    'E02812': EdinetCodeEntry(
        edinet_code='E02812',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1585,
        fiscal_year_end='3月31日',
        submitter_name='八洲電機株式会社',
        submitter_name_en='Yashima Denki Co.,Ltd.',
        submitter_name_yomi='ヤシマデンキカブシキガイシャ',
        address='港区新橋三丁目１番１号',
        industry='卸売業',
        sec_code='31530',
        corporate_number='9010401029819',
    ),
    'E02813': EdinetCodeEntry(
        edinet_code='E02813',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1690,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｍｉｓｕｍｉ',
        submitter_name_en='MISUMI CO., LTD.',
        submitter_name_yomi='カブシキガイシャミスミ',
        address='鹿児島市卸本町７番地２０',
        industry='卸売業',
        sec_code='74410',
        corporate_number='4340001004160',
    ),
    'E02814': EdinetCodeEntry(
        edinet_code='E02814',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4028,
        fiscal_year_end='3月31日',
        submitter_name='日本酒類販売株式会社',
        submitter_name_en='NIHONSHURUIHANBAI CO.,LTD.',
        submitter_name_yomi='ニホンシュルイハンバイカブシキガイシャ',
        address='中央区新川一丁目２５番４号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8010001062097',
    ),
    'E02818': EdinetCodeEntry(
        edinet_code='E02818',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大水',
        submitter_name_en='DAISUI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイスイ',
        address='大阪市福島区野田一丁目１番８６号\u3000大阪市中央卸売市場内',
        industry='卸売業',
        sec_code='75380',
        corporate_number='4120001034601',
    ),
    'E02819': EdinetCodeEntry(
        edinet_code='E02819',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3840,
        fiscal_year_end='3月31日',
        submitter_name='興和株式会社',
        submitter_name_en='KOWA COMPANY, LTD.',
        submitter_name_yomi='コウワカブシキガイシャ',
        address='名古屋市中区錦三丁目６番２９号',
        industry='卸売業',
        sec_code=None,
        corporate_number='1180001035811',
    ),
    'E02821': EdinetCodeEntry(
        edinet_code='E02821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3559,
        fiscal_year_end='3月31日',
        submitter_name='松田産業株式会社',
        submitter_name_en='MATSUDA SANGYO Co.,Ltd.',
        submitter_name_yomi='マツダサンギョウカブシキガイシャ',
        address='新宿区西新宿一丁目２６番２号',
        industry='卸売業',
        sec_code='74560',
        corporate_number='2011101020140',
    ),
    'E02823': EdinetCodeEntry(
        edinet_code='E02823',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=793,
        fiscal_year_end='3月31日',
        submitter_name='株式会社キムラ',
        submitter_name_en='KIMURA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキムラ',
        address='札幌市東区北６条東４丁目１番地７',
        industry='卸売業',
        sec_code='74610',
        corporate_number='4430001023985',
    ),
    'E02824': EdinetCodeEntry(
        edinet_code='E02824',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12350,
        fiscal_year_end='3月31日',
        submitter_name='株式会社第一興商',
        submitter_name_en='DAIICHIKOSHO CO. , LTD.',
        submitter_name_yomi='カブシキガイシャダイイチコウショウ',
        address='品川区北品川５丁目５番２６号',
        industry='卸売業',
        sec_code='74580',
        corporate_number='6010701005431',
    ),
    'E02825': EdinetCodeEntry(
        edinet_code='E02825',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1088,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤギ',
        submitter_name_en='YAGI & CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤギ',
        address='大阪市中央区久太郎町二丁目２番８号',
        industry='卸売業',
        sec_code='74600',
        corporate_number='6120001077581',
    ),
    'E02826': EdinetCodeEntry(
        edinet_code='E02826',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アドヴァン',
        submitter_name_en='ADVAN CO .,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000アドヴァン',
        address='渋谷区神宮前４丁目３２番１４号',
        industry='卸売業',
        sec_code='74630',
        corporate_number='2011001001075',
    ),
    'E02827': EdinetCodeEntry(
        edinet_code='E02827',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=898,
        fiscal_year_end='3月31日',
        submitter_name='ＳＰＫ株式会社',
        submitter_name_en='SPK CORPORATION',
        submitter_name_yomi='エスピーケイカブシキガイシャ',
        address='大阪市福島区福島五丁目５番４号',
        industry='卸売業',
        sec_code='74660',
        corporate_number='9120001034407',
    ),
    'E02828': EdinetCodeEntry(
        edinet_code='E02828',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6099,
        fiscal_year_end='3月31日',
        submitter_name='萩原電気ホールディングス株式会社',
        submitter_name_en='HAGIWARA ELECTRIC HOLDINGS CO.,LTD.',
        submitter_name_yomi='ハギワラデンキホールディングスカブシキガイシャ',
        address='名古屋市東区東桜二丁目２番１号',
        industry='卸売業',
        sec_code='74670',
        corporate_number='3180001017956',
    ),
    'E02832': EdinetCodeEntry(
        edinet_code='E02832',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4908,
        fiscal_year_end='3月31日',
        submitter_name='アルビス株式会社',
        submitter_name_en='ALBIS Co.,Ltd.',
        submitter_name_yomi='アルビス\u3000カブシキガイシャ',
        address='射水市流通センター水戸田三丁目４番地',
        industry='小売業',
        sec_code='74750',
        corporate_number='3230001012605',
    ),
    'E02833': EdinetCodeEntry(
        edinet_code='E02833',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1148,
        fiscal_year_end='3月31日',
        submitter_name='株式会社鳥羽洋行',
        submitter_name_en='TOBA,INC.',
        submitter_name_yomi='カブシキガイシャトバヨウコウ',
        address='文京区水道２－８－６',
        industry='卸売業',
        sec_code='74720',
        corporate_number='9010001005600',
    ),
    'E02835': EdinetCodeEntry(
        edinet_code='E02835',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5075,
        fiscal_year_end='3月31日',
        submitter_name='アズワン株式会社',
        submitter_name_en='AS ONE CORPORATION',
        submitter_name_yomi='アズワンカブシキガイシャ',
        address='大阪市西区江戸堀２－１－２７',
        industry='卸売業',
        sec_code='74760',
        corporate_number='8120001060544',
    ),
    'E02836': EdinetCodeEntry(
        edinet_code='E02836',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ムラキ株式会社',
        submitter_name_en='MURAKI CORPORATION',
        submitter_name_yomi='ムラキカブシキガイシャ',
        address='多摩市関戸二丁目２４番地２７',
        industry='卸売業',
        sec_code='74770',
        corporate_number='6013401005189',
    ),
    'E02837': EdinetCodeEntry(
        edinet_code='E02837',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1305,
        fiscal_year_end='3月31日',
        submitter_name='尾家産業株式会社',
        submitter_name_en='oie sangyo co.,ltd',
        submitter_name_yomi='オイエサンギョウカブシキガイシャ',
        address='大阪市北区豊崎六丁目１１番２７号',
        industry='卸売業',
        sec_code='74810',
        corporate_number='5120001061479',
    ),
    'E02838': EdinetCodeEntry(
        edinet_code='E02838',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1819,
        fiscal_year_end='3月31日',
        submitter_name='スズデン株式会社',
        submitter_name_en='SUZUDEN CORPORATION',
        submitter_name_yomi='スズデンカブシキガイシャ',
        address='千代田区外神田二丁目２番３号',
        industry='卸売業',
        sec_code='74800',
        corporate_number='1010001003966',
    ),
    'E02839': EdinetCodeEntry(
        edinet_code='E02839',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1405,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シモジマ',
        submitter_name_en='SHIMOJIMA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシモジマ',
        address='台東区浅草橋５丁目２９番８号',
        industry='卸売業',
        sec_code='74820',
        corporate_number='4010501024971',
    ),
    'E02840': EdinetCodeEntry(
        edinet_code='E02840',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4993,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ドウシシャ',
        submitter_name_en='DOSHISHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ドウシシャ',
        address='大阪市中央区東心斎橋１－５－５',
        industry='卸売業',
        sec_code='74830',
        corporate_number='8120001039126',
    ),
    'E02841': EdinetCodeEntry(
        edinet_code='E02841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1512,
        fiscal_year_end='3月31日',
        submitter_name='サンリン株式会社',
        submitter_name_en='sanrin co.,ltd.',
        submitter_name_yomi='サンリンカブシキガイシャ',
        address='東筑摩郡山形村字下本郷４０８２番地３',
        industry='卸売業',
        sec_code='74860',
        corporate_number='4100001014423',
    ),
    'E02842': EdinetCodeEntry(
        edinet_code='E02842',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1322,
        fiscal_year_end='5月31日',
        submitter_name='小津産業株式会社',
        submitter_name_en='ozu corporation',
        submitter_name_yomi='オヅサンギョウカブシキガイシャ',
        address='中央区日本橋本町三丁目６番２号',
        industry='卸売業',
        sec_code='74870',
        corporate_number='8010001039269',
    ),
    'E02843': EdinetCodeEntry(
        edinet_code='E02843',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=787,
        fiscal_year_end='4月20日',
        submitter_name='株式会社ヤガミ',
        submitter_name_en='YAGAMI INC.',
        submitter_name_yomi='カブシキガイシャヤガミ',
        address='名古屋市中区丸の内三丁目２番２９号',
        industry='卸売業',
        sec_code='74880',
        corporate_number='4180001041518',
    ),
    'E02845': EdinetCodeEntry(
        edinet_code='E02845',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3624,
        fiscal_year_end='3月31日',
        submitter_name='日新商事株式会社',
        submitter_name_en='NISSIN SHOJI CO., LTD.',
        submitter_name_yomi='ニッシンショウジカブシキカイシャ',
        address='港区芝浦一丁目１２番３号',
        industry='卸売業',
        sec_code='74900',
        corporate_number='4010401033255',
    ),
    'E02847': EdinetCodeEntry(
        edinet_code='E02847',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=569,
        fiscal_year_end='6月30日',
        submitter_name='西川計測株式会社',
        submitter_name_en='nishikawa keisoku co.,ltd.',
        submitter_name_yomi='ニシカワケイソクカブシキガイシャ',
        address='渋谷区代々木三丁目２２番７号',
        industry='卸売業',
        sec_code='75000',
        corporate_number='1010401021428',
    ),
    'E02848': EdinetCodeEntry(
        edinet_code='E02848',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1079,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ティムコ',
        submitter_name_en='TIEMCO LTD.',
        submitter_name_yomi='カブシキカイシャティムコ',
        address='墨田区菊川三丁目１番１１号',
        industry='卸売業',
        sec_code='75010',
        corporate_number='6010601021421',
    ),
    'E02850': EdinetCodeEntry(
        edinet_code='E02850',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1690,
        fiscal_year_end='3月31日',
        submitter_name='株式会社高速',
        submitter_name_en='KOHSOKU CORPORATION',
        submitter_name_yomi='カブシキガイシャコウソク',
        address='仙台市宮城野区扇町七丁目４番２０号',
        industry='卸売業',
        sec_code='75040',
        corporate_number='4370001005032',
    ),
    'E02851': EdinetCodeEntry(
        edinet_code='E02851',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3384,
        fiscal_year_end='3月31日',
        submitter_name='株式会社たけびし',
        submitter_name_en='TAKEBISHI CORPORATION',
        submitter_name_yomi='カブシキガイシャタケビシ',
        address='京都市右京区西京極豆田町２９番地',
        industry='卸売業',
        sec_code='75100',
        corporate_number='1130001001272',
    ),
    'E02853': EdinetCodeEntry(
        edinet_code='E02853',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10045,
        fiscal_year_end=None,
        submitter_name='黒田電気株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クロダデンキカブシキガイシャ',
        address='大阪市淀川区木川東４丁目１１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001055006',
    ),
    'E02854': EdinetCodeEntry(
        edinet_code='E02854',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=59,
        fiscal_year_end='3月31日',
        submitter_name='五洋インテックス株式会社',
        submitter_name_en='GOYO INTEX CO.,LTD',
        submitter_name_yomi='ゴヨウインテックスカブシキガイシャ',
        address='小牧市小木５丁目４１１番地',
        industry='卸売業',
        sec_code=None,
        corporate_number='3180001075780',
    ),
    'E02855': EdinetCodeEntry(
        edinet_code='E02855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1208,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ムサシ',
        submitter_name_en='MUSASHI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャムサシ',
        address='中央区銀座八丁目２０番３６号',
        industry='卸売業',
        sec_code='75210',
        corporate_number='6010001058667',
    ),
    'E02856': EdinetCodeEntry(
        edinet_code='E02856',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=827,
        fiscal_year_end='3月31日',
        submitter_name='リックス株式会社',
        submitter_name_en='RIX CORPORATION',
        submitter_name_yomi='リックスカブシキガイシャ',
        address='福岡市博多区東比恵１－４－１０\u3000Ｓ－ＧＡＴＥ\u3000ＦＩＴ\u3000東比恵５Ｆ',
        industry='卸売業',
        sec_code='75250',
        corporate_number='5290001017448',
    ),
    'E02858': EdinetCodeEntry(
        edinet_code='E02858',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1706,
        fiscal_year_end='9月30日',
        submitter_name='株式会社システムソフト',
        submitter_name_en='SystemSoft Corporation',
        submitter_name_yomi='カブシキガイシャシステムソフト',
        address='千代田区丸の内一丁目８番１号',
        industry='情報・通信業',
        sec_code='75270',
        corporate_number='7290001017693',
    ),
    'E02861': EdinetCodeEntry(
        edinet_code='E02861',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=735,
        fiscal_year_end='12月31日',
        submitter_name='清和中央ホールディングス株式会社',
        submitter_name_en='SEIWA CHUO HOLDINGS CORPORATION',
        submitter_name_yomi='セイワチュウオウホールディングスカブシキガイシャ',
        address='大阪市西区九条南３丁目１番２０号',
        industry='卸売業',
        sec_code='75310',
        corporate_number='2120001044593',
    ),
    'E02864': EdinetCodeEntry(
        edinet_code='E02864',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6214,
        fiscal_year_end='3月31日',
        submitter_name='丸文株式会社',
        submitter_name_en='MARUBUN CORPORATION',
        submitter_name_yomi='マルブンカブシキガイシャ',
        address='中央区日本橋大伝馬町８番１号',
        industry='卸売業',
        sec_code='75370',
        corporate_number='8010001057337',
    ),
    'E02865': EdinetCodeEntry(
        edinet_code='E02865',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=896,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アイナボホールディングス',
        submitter_name_en='AINAVO HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアイナボホールディングス',
        address='台東区元浅草二丁目６番６号\u3000東京日産台東ビル４階',
        industry='卸売業',
        sec_code='75390',
        corporate_number='9011801005756',
    ),
    'E02869': EdinetCodeEntry(
        edinet_code='E02869',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2751,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハピネット',
        submitter_name_en='HAPPINET CORPORATION',
        submitter_name_yomi='カブシキガイシャハピネット',
        address='台東区駒形二丁目４番５号',
        industry='卸売業',
        sec_code='75520',
        corporate_number='5010501011416',
    ),
    'E02870': EdinetCodeEntry(
        edinet_code='E02870',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=852,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウェッズ',
        submitter_name_en='WEDS CO., LTD.',
        submitter_name_yomi='カブシキカイシャ\u3000ウェッズ',
        address='大田区大森北１－６－８',
        industry='卸売業',
        sec_code='75510',
        corporate_number='7010801014505',
    ),
    'E02871': EdinetCodeEntry(
        edinet_code='E02871',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=551,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大田花き',
        submitter_name_en='Ota Floriculture Auction Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャオオタカキ',
        address='大田区東海二丁目２番１号',
        industry='卸売業',
        sec_code='75550',
        corporate_number='7010801002063',
    ),
    'E02873': EdinetCodeEntry(
        edinet_code='E02873',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5284,
        fiscal_year_end=None,
        submitter_name='株式会社ネクスティエレクトロニクス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャネクスティエレクトロニクス',
        address='港区港南二丁目３番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401019485',
    ),
    'E02874': EdinetCodeEntry(
        edinet_code='E02874',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ジーエフシー株式会社',
        submitter_name_en='GLOBAL FOOD CREATORS CO.,LTD.',
        submitter_name_yomi='ジーエフシーカブシキガイシャ',
        address='羽島郡笠松町田代９７８番地の１',
        industry='卸売業',
        sec_code=None,
        corporate_number='8200001011101',
    ),
    'E02875': EdinetCodeEntry(
        edinet_code='E02875',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1005,
        fiscal_year_end='3月31日',
        submitter_name='萬世電機株式会社',
        submitter_name_en='MANSEI CORPORATION',
        submitter_name_yomi='マンセイデンキカブシキガイシャ',
        address='大阪市福島区福島７丁目１５番５号',
        industry='卸売業',
        sec_code='75650',
        corporate_number='2120001036483',
    ),
    'E02876': EdinetCodeEntry(
        edinet_code='E02876',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=565,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ケー・エフ・シー',
        submitter_name_en='KFC Ltd',
        submitter_name_yomi='カブシキガイシャケーエフシー',
        address='大阪市北区西天満３－２－１７',
        industry='金属製品',
        sec_code='34200',
        corporate_number='3120001063188',
    ),
    'E02877': EdinetCodeEntry(
        edinet_code='E02877',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=412,
        fiscal_year_end='12月31日',
        submitter_name='株式会社デイトナ',
        submitter_name_en='DAYTONA CORPORATION',
        submitter_name_yomi='カブシキガイシャデイトナ',
        address='周智郡森町一宮４８０５番地',
        industry='輸送用機器',
        sec_code='72280',
        corporate_number='3080401017525',
    ),
    'E02878': EdinetCodeEntry(
        edinet_code='E02878',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社栄電子',
        submitter_name_en='SAKAE ELECTRONICS CORPORATION',
        submitter_name_yomi='カブシキガイシャサカエデンシ',
        address='千代田区外神田二丁目９番１０号',
        industry='卸売業',
        sec_code='75670',
        corporate_number='5010001017343',
    ),
    'E02879': EdinetCodeEntry(
        edinet_code='E02879',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=542,
        fiscal_year_end='3月31日',
        submitter_name='橋本総業ホールディングス株式会社',
        submitter_name_en='HASHIMOTO SOGYO HOLDINGS CO.,LTD.',
        submitter_name_yomi='ハシモト\u3000ソウギョウ\u3000ホールディングス\u3000カブシキガイシャ',
        address='中央区日本橋小伝馬町１４番７号',
        industry='卸売業',
        sec_code='75700',
        corporate_number='9010001054242',
    ),
    'E02881': EdinetCodeEntry(
        edinet_code='E02881',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2115,
        fiscal_year_end='3月31日',
        submitter_name='日本ライフライン株式会社',
        submitter_name_en='Japan Lifeline Co., Ltd.',
        submitter_name_yomi='ニホンライフラインカブシキガイシャ',
        address='品川区東品川二丁目２番２０号',
        industry='卸売業',
        sec_code='75750',
        corporate_number='2010701020987',
    ),
    'E02882': EdinetCodeEntry(
        edinet_code='E02882',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=238,
        fiscal_year_end='1月20日',
        submitter_name='ピープル株式会社',
        submitter_name_en='People Co., Ltd.',
        submitter_name_yomi='ピープルカブシキガイシャ',
        address='中央区東日本橋２丁目１５番５号',
        industry='その他製品',
        sec_code='78650',
        corporate_number='8010001055217',
    ),
    'E02887': EdinetCodeEntry(
        edinet_code='E02887',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パルテック（定款上の商号\u3000株式会社ＰＡＬＴＥＫ）',
        submitter_name_en='PALTEK CORPORATION',
        submitter_name_yomi='カブシキガイシャパルテック',
        address='横浜市港北区新横浜二丁目３番地１２',
        industry='卸売業',
        sec_code=None,
        corporate_number='6020001011897',
    ),
    'E02888': EdinetCodeEntry(
        edinet_code='E02888',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3043,
        fiscal_year_end='1月20日',
        submitter_name='株式会社タカショー',
        submitter_name_en='Takasho Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャタカショー',
        address='海南市阪井４８９番地',
        industry='卸売業',
        sec_code='75900',
        corporate_number='2170001005748',
    ),
    'E02889': EdinetCodeEntry(
        edinet_code='E02889',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5099,
        fiscal_year_end='3月31日',
        submitter_name='ＶＴホールディングス株式会社',
        submitter_name_en='VT HOLDINGS CO.,LTD.',
        submitter_name_yomi='ブイティホールディングスカブシキガイシャ',
        address='名古屋市中区錦三丁目１０番３２号',
        industry='小売業',
        sec_code='75930',
        corporate_number='5180001094556',
    ),
    'E02890': EdinetCodeEntry(
        edinet_code='E02890',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3086,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エクセル',
        submitter_name_en='EXCEL CO., LTD.',
        submitter_name_yomi='カブシキガイシャエクセル',
        address='港区西新橋三丁目１２番１０号',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010401063122',
    ),
    'E02891': EdinetCodeEntry(
        edinet_code='E02891',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1414,
        fiscal_year_end=None,
        submitter_name='株式会社マルカ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマルカ',
        address='大阪市中央区南新町二丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120901002091',
    ),
    'E02892': EdinetCodeEntry(
        edinet_code='E02892',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4157,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＩＤＯＭ',
        submitter_name_en='IDOM Inc.',
        submitter_name_yomi='カブシキガイシャイドム',
        address='千代田区丸の内二丁目７番２号ＪＰタワー',
        industry='卸売業',
        sec_code='75990',
        corporate_number='1010001069520',
    ),
    'E02893': EdinetCodeEntry(
        edinet_code='E02893',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=60,
        fiscal_year_end='3月31日',
        submitter_name='東京貴宝株式会社',
        submitter_name_en='Tokyo Kiho Co., Ltd.',
        submitter_name_yomi='トウキヨウキホウカブシキガイシャ',
        address='台東区東上野１－２６－２',
        industry='卸売業',
        sec_code=None,
        corporate_number='9010501009209',
    ),
    'E02894': EdinetCodeEntry(
        edinet_code='E02894',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3001,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000日本エム・ディ・エム',
        submitter_name_en='Japan Medical Dynamic Marketing, INC.',
        submitter_name_yomi='カブシキガイシャニホンエムディエム',
        address='新宿区市谷台町１２番２号',
        industry='精密機器',
        sec_code='76000',
        corporate_number='8011101016199',
    ),
    'E02895': EdinetCodeEntry(
        edinet_code='E02895',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2820,
        fiscal_year_end='3月31日',
        submitter_name='株式会社レダックス',
        submitter_name_en='Ledax Co., Ltd.',
        submitter_name_yomi='カブシキガイシャレダックス',
        address='千代田区紀尾井町４番１号\u3000新紀尾井町ビル２Ｆ',
        industry='卸売業',
        sec_code='76020',
        corporate_number='2010601039038',
    ),
    'E02896': EdinetCodeEntry(
        edinet_code='E02896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=951,
        fiscal_year_end='8月31日',
        submitter_name='株式会社進和',
        submitter_name_en='Shinwa Co., Ltd.',
        submitter_name_yomi='カブシキガイシャシンワ',
        address='名古屋市守山区苗代二丁目９番３号',
        industry='卸売業',
        sec_code='76070',
        corporate_number='2180001000574',
    ),
    'E02897': EdinetCodeEntry(
        edinet_code='E02897',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=461,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エスケイジャパン',
        submitter_name_en='SK JAPAN CO., LTD.',
        submitter_name_yomi='カブシキガイシャエスケイジャパン',
        address='大阪市中央区谷町三丁目１番１８号',
        industry='卸売業',
        sec_code='76080',
        corporate_number='9120001075509',
    ),
    'E02898': EdinetCodeEntry(
        edinet_code='E02898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2200,
        fiscal_year_end='12月31日',
        submitter_name='ダイトロン株式会社',
        submitter_name_en='Daitron Co.,Ltd.',
        submitter_name_yomi='ダイトロンカブシキガイシャ',
        address='大阪市淀川区宮原４丁目６番１１号',
        industry='卸売業',
        sec_code='76090',
        corporate_number='9120001083156',
    ),
    'E02899': EdinetCodeEntry(
        edinet_code='E02899',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3068,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｎｕｔｓ',
        submitter_name_en='Nuts Inc.',
        submitter_name_yomi='カブシキガイシャナッツ',
        address='港区東麻布３－３－１',
        industry='卸売業',
        sec_code=None,
        corporate_number='6010401050975',
    ),
    'E02900': EdinetCodeEntry(
        edinet_code='E02900',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2144,
        fiscal_year_end='12月31日',
        submitter_name='シークス株式会社',
        submitter_name_en='SIIX Corp.',
        submitter_name_yomi='シークスカブシキガイシャ',
        address='大阪市中央区備後町一丁目４番９号',
        industry='卸売業',
        sec_code='76130',
        corporate_number='7120001080989',
    ),
    'E02902': EdinetCodeEntry(
        edinet_code='E02902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1073,
        fiscal_year_end='3月31日',
        submitter_name='田中商事株式会社',
        submitter_name_en='TANAKA CO.,LTD',
        submitter_name_yomi='タナカショウジカブシキガイシャ',
        address='品川区南大井三丁目２番２号',
        industry='卸売業',
        sec_code='76190',
        corporate_number='8010701005900',
    ),
    'E02903': EdinetCodeEntry(
        edinet_code='E02903',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2291,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＮａＩＴＯ',
        submitter_name_en='Naito&Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャナイトウ',
        address='北区昭和町二丁目１番１１号',
        industry='卸売業',
        sec_code='76240',
        corporate_number='6011501003393',
    ),
    'E02905': EdinetCodeEntry(
        edinet_code='E02905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1825,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オーハシテクニカ',
        submitter_name_en='OHASHI TECHNICA INC.',
        submitter_name_yomi='カブシキガイシャオーハシテクニカ',
        address='港区虎ノ門四丁目３番１３号',
        industry='卸売業',
        sec_code='76280',
        corporate_number='1010401088566',
    ),
    'E02906': EdinetCodeEntry(
        edinet_code='E02906',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=11194,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マクニカ',
        submitter_name_en='MACNICA, Inc.',
        submitter_name_yomi='カブシキガイシャマクニカ',
        address='横浜市港北区新横浜一丁目６番地３',
        industry='卸売業',
        sec_code=None,
        corporate_number='2020001032286',
    ),
    'E02909': EdinetCodeEntry(
        edinet_code='E02909',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1124,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイティフォー',
        submitter_name_en='ITFOR Inc',
        submitter_name_yomi='カブシキガイシャアイティフォー',
        address='千代田区一番町２１番地',
        industry='情報・通信業',
        sec_code='47430',
        corporate_number='3010001022865',
    ),
    'E02910': EdinetCodeEntry(
        edinet_code='E02910',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=697,
        fiscal_year_end='3月31日',
        submitter_name='杉田エース株式会社',
        submitter_name_en='SUGITA ACE CO.,LTD',
        submitter_name_yomi='スギタエースカブシキガイシャ',
        address='墨田区緑二丁目１４番１５号',
        industry='卸売業',
        sec_code='76350',
        corporate_number='3010601011400',
    ),
    'E02912': EdinetCodeEntry(
        edinet_code='E02912',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1819,
        fiscal_year_end='3月31日',
        submitter_name='株式会社音通',
        submitter_name_en='ONTSU Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャオンツウ',
        address='大阪市北区本庄東一丁目１番１０号',
        industry='小売業',
        sec_code=None,
        corporate_number='9120901010556',
    ),
    'E02913': EdinetCodeEntry(
        edinet_code='E02913',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1243,
        fiscal_year_end=None,
        submitter_name='株式会社トーカン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトーカン',
        address='名古屋市熱田区川並町４番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001022373',
    ),
    'E02917': EdinetCodeEntry(
        edinet_code='E02917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2323,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アスモ',
        submitter_name_en='ASMO CORPORATION',
        submitter_name_yomi='カブシキガイシャアスモ',
        address='新宿区西新宿２－４－１\u3000新宿ＮＳビル２５階',
        industry='卸売業',
        sec_code='26540',
        corporate_number='9120001030926',
    ),
    'E02920': EdinetCodeEntry(
        edinet_code='E02920',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=300,
        fiscal_year_end='6月30日',
        submitter_name='アトムリビンテック株式会社',
        submitter_name_en='ATOM LIVIN TECH Co.,Ltd.',
        submitter_name_yomi='アトムリビンテックカブシキガイシャ',
        address='台東区入谷１丁目２７番４号',
        industry='金属製品',
        sec_code='34260',
        corporate_number='1010501007351',
    ),
    'E02922': EdinetCodeEntry(
        edinet_code='E02922',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2777,
        fiscal_year_end='9月30日',
        submitter_name='株式会社イメージワン',
        submitter_name_en='ImageONE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイメージワン',
        address='東京都品川区大崎一丁目６番３号',
        industry='卸売業',
        sec_code='26670',
        corporate_number='9011101002149',
    ),
    'E02923': EdinetCodeEntry(
        edinet_code='E02923',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=414,
        fiscal_year_end='2月末日',
        submitter_name='タビオ株式会社',
        submitter_name_en='Tabio Corporation',
        submitter_name_yomi='タビオ\u3000カブシキガイシャ',
        address='大阪市浪速区難波中二丁目１０番７０号',
        industry='卸売業',
        sec_code='26680',
        corporate_number='8120001020754',
    ),
    'E02924': EdinetCodeEntry(
        edinet_code='E02924',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='プラス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プラスカブシキガイシャ',
        address='港区虎ノ門四丁目１番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401066617',
    ),
    'E02925': EdinetCodeEntry(
        edinet_code='E02925',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19972,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エービーシー・マート',
        submitter_name_en='ABC-MART,INC.',
        submitter_name_yomi='カブシキガイシャエービーシーマート',
        address='渋谷区神南一丁目１１番５号',
        industry='小売業',
        sec_code='26700',
        corporate_number='2011001033515',
    ),
    'E02927': EdinetCodeEntry(
        edinet_code='E02927',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1209,
        fiscal_year_end='3月31日',
        submitter_name='高千穂交易株式会社',
        submitter_name_en='TAKACHIHO KOHEKI  CO.,LTD.',
        submitter_name_yomi='タカチホコウエキカブシキガイシャ',
        address='新宿区四谷１－６－１',
        industry='卸売業',
        sec_code='26760',
        corporate_number='7011101012356',
    ),
    'E02928': EdinetCodeEntry(
        edinet_code='E02928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=607,
        fiscal_year_end='6月30日',
        submitter_name='オルバヘルスケアホールディングス株式会社',
        submitter_name_en='OLBA HEALTHCARE HOLDINGS,INC.',
        submitter_name_yomi='オルバヘルスケアホールディングスカブシキガイシャ',
        address='岡山市北区下石井一丁目１番３号',
        industry='卸売業',
        sec_code='26890',
        corporate_number='7260001001915',
    ),
    'E02931': EdinetCodeEntry(
        edinet_code='E02931',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4923,
        fiscal_year_end='3月31日',
        submitter_name='伊藤忠食品株式会社',
        submitter_name_en='ITOCHU-SHOKUHIN Co., Ltd.',
        submitter_name_yomi='イトウチュウショクヒンカブシキガイシャ',
        address='大阪市中央区城見二丁目２番２２号',
        industry='卸売業',
        sec_code='26920',
        corporate_number='2120001077362',
    ),
    'E02932': EdinetCodeEntry(
        edinet_code='E02932',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1389,
        fiscal_year_end='12月31日',
        submitter_name='ＹＫＴ株式会社',
        submitter_name_en='YKT CORPORATION',
        submitter_name_yomi='ワイケイティカブシキガイシャ',
        address='渋谷区代々木五丁目７番５号',
        industry='卸売業',
        sec_code='26930',
        corporate_number='6011001023677',
    ),
    'E02934': EdinetCodeEntry(
        edinet_code='E02934',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=529,
        fiscal_year_end='12月31日',
        submitter_name='木徳神糧株式会社',
        submitter_name_en='KITOKU SHINRYO CO., LTD.',
        submitter_name_yomi='キトクシンリョウカブシキガイシャ',
        address='中央区銀座七丁目２番２２号',
        industry='卸売業',
        sec_code='27000',
        corporate_number='4010001040882',
    ),
    'E02937': EdinetCodeEntry(
        edinet_code='E02937',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1396,
        fiscal_year_end='12月31日',
        submitter_name='日本ライトン株式会社',
        submitter_name_en='LITE-ON JAPAN LTD.',
        submitter_name_yomi='ニホンライトンカブシキガイシャ',
        address='千代田区外神田２－１６－２',
        industry='卸売業',
        sec_code=None,
        corporate_number='9010001016382',
    ),
    'E02938': EdinetCodeEntry(
        edinet_code='E02938',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社久世',
        submitter_name_en='KUZE CO., LTD.',
        submitter_name_yomi='カブシキガイシャクゼ',
        address='豊島区東池袋二丁目２９番７号',
        industry='卸売業',
        sec_code='27080',
        corporate_number='7013301002723',
    ),
    'E02939': EdinetCodeEntry(
        edinet_code='E02939',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=598,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シーエスロジネット',
        submitter_name_en='CS LOGINET INC.',
        submitter_name_yomi='カブシキガイシャシーエスロジネット',
        address='名古屋市中川区舟戸町２番３７号',
        industry='卸売業',
        sec_code=None,
        corporate_number='1180001020128',
    ),
    'E02940': EdinetCodeEntry(
        edinet_code='E02940',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=793,
        fiscal_year_end='3月31日',
        submitter_name='プラマテルズ株式会社',
        submitter_name_en='Pla Matels Corporation',
        submitter_name_yomi='プラマテルズカブシキガイシャ',
        address='品川区北品川４－７－３５\u3000御殿山トラストタワー５階',
        industry='卸売業',
        sec_code=None,
        corporate_number='7010701019496',
    ),
    'E02941': EdinetCodeEntry(
        edinet_code='E02941',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2142,
        fiscal_year_end='3月31日',
        submitter_name='エレマテック株式会社',
        submitter_name_en='Elematec Corporation',
        submitter_name_yomi='エレマテックカブシキガイシャ',
        address='港区三田三丁目５番２７号\u3000住友不動産三田ツインビル西館１９階',
        industry='卸売業',
        sec_code=None,
        corporate_number='2010401017012',
    ),
    'E02946': EdinetCodeEntry(
        edinet_code='E02946',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2054,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーメンデバイス',
        submitter_name_en='TOMEN DEVICES CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000トーメンデバイス',
        address='中央区晴海一丁目８番１２号',
        industry='卸売業',
        sec_code='27370',
        corporate_number='4010001071688',
    ),
    'E02947': EdinetCodeEntry(
        edinet_code='E02947',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8568,
        fiscal_year_end='3月31日',
        submitter_name='株式会社あらた',
        submitter_name_en='ARATA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000アラタ',
        address='江東区東陽６丁目３番２号',
        industry='卸売業',
        sec_code='27330',
        corporate_number='5040001020385',
    ),
    'E02949': EdinetCodeEntry(
        edinet_code='E02949',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4339,
        fiscal_year_end='12月31日',
        submitter_name='ピクセルカンパニーズ株式会社',
        submitter_name_en='PIXEL COMPANYZ INC.',
        submitter_name_yomi='ピクセルカンパニーズカブシキガイシャ',
        address='港区虎ノ門四丁目１番４０号',
        industry='卸売業',
        sec_code='27430',
        corporate_number='4010001026485',
    ),
    'E02952': EdinetCodeEntry(
        edinet_code='E02952',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=623,
        fiscal_year_end='3月31日',
        submitter_name='石光商事株式会社',
        submitter_name_en='S.ISHIMITSU&CO.,LTD.',
        submitter_name_yomi='イシミツショウジカブシキガイシャ',
        address='神戸市灘区岩屋南町４番４０号',
        industry='卸売業',
        sec_code='27500',
        corporate_number='9140001003021',
    ),
    'E02953': EdinetCodeEntry(
        edinet_code='E02953',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=499,
        fiscal_year_end='4月30日',
        submitter_name='株式会社テンポスホールディングス',
        submitter_name_en='TENPOS HOLDINGS Co.,Ltd',
        submitter_name_yomi='カブシキガイシャテンポスホールディングス',
        address='大田区東蒲田二丁目３０番１７号',
        industry='卸売業',
        sec_code='27510',
        corporate_number='5010801007634',
    ),
    'E02955': EdinetCodeEntry(
        edinet_code='E02955',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2495,
        fiscal_year_end='3月31日',
        submitter_name='東京エレクトロンデバイス株式会社',
        submitter_name_en='TOKYO ELECTRON DEVICE LIMITED',
        submitter_name_yomi='トウキョウエレクトロンデバイスカブシキガイシャ',
        address='横浜市神奈川区金港町１番地４',
        industry='卸売業',
        sec_code='27600',
        corporate_number='4020001009043',
    ),
    'E02956': EdinetCodeEntry(
        edinet_code='E02956',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=80,
        fiscal_year_end='5月20日',
        submitter_name='トシン・グループ株式会社',
        submitter_name_en='toshin group co.,ltd.',
        submitter_name_yomi='トシングループカブシキガイシャ',
        address='新宿区新宿一丁目３番７号',
        industry='卸売業',
        sec_code=None,
        corporate_number='8011101014467',
    ),
    'E02958': EdinetCodeEntry(
        edinet_code='E02958',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=160339,
        fiscal_year_end='3月31日',
        submitter_name='双日株式会社',
        submitter_name_en='Sojitz Corporation',
        submitter_name_yomi='ソウジツカブシキガイシャ',
        address='千代田区内幸町二丁目１番１号',
        industry='卸売業',
        sec_code='27680',
        corporate_number='5010401049977',
    ),
    'E02959': EdinetCodeEntry(
        edinet_code='E02959',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=669,
        fiscal_year_end=None,
        submitter_name='株式会社ミューチュアル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミューチュアル',
        address='大阪市北区西天満一丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001071062',
    ),
    'E02960': EdinetCodeEntry(
        edinet_code='E02960',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2548,
        fiscal_year_end='1月31日',
        submitter_name='新都ホールディングス株式会社',
        submitter_name_en='SHINTO Holdings, Inc.',
        submitter_name_yomi='シントホールディングスカブシキガイシャ',
        address='豊島区北大塚３－３４－１',
        industry='卸売業',
        sec_code='27760',
        corporate_number='7010601010274',
    ),
    'E02961': EdinetCodeEntry(
        edinet_code='E02961',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社カッシーナ・イクスシー',
        submitter_name_en='CASSINA IXC. Ltd.',
        submitter_name_yomi='カブシキガイシャカッシーナイクスシー',
        address='港区南青山二丁目１３番１０号',
        industry='卸売業',
        sec_code=None,
        corporate_number='9010401088996',
    ),
    'E02962': EdinetCodeEntry(
        edinet_code='E02962',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18454,
        fiscal_year_end='3月31日',
        submitter_name='アルフレッサホールディングス株式会社',
        submitter_name_en='Alfresa Holdings Corporation',
        submitter_name_yomi='アルフレッサホールディングスカブシキガイシャ',
        address='千代田区大手町一丁目１番３号',
        industry='卸売業',
        sec_code='27840',
        corporate_number='3010001084757',
    ),
    'E02963': EdinetCodeEntry(
        edinet_code='E02963',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4325,
        fiscal_year_end='12月31日',
        submitter_name='アップルインターナショナル株式会社',
        submitter_name_en='APPLE INTERNATIONALCO.,LTD.',
        submitter_name_yomi='アップルインターナショナルカブシキガイシャ',
        address='四日市市日永二丁目３番３号',
        industry='卸売業',
        sec_code='27880',
        corporate_number='7190001014222',
    ),
    'E02964': EdinetCodeEntry(
        edinet_code='E02964',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=393,
        fiscal_year_end='3月31日',
        submitter_name='日本プリメックス株式会社',
        submitter_name_en='NIPPON PRIMEX INC.',
        submitter_name_yomi='ニホンプリメックスカブシキガイシャ',
        address='大田区鵜の木一丁目５番１２号',
        industry='卸売業',
        sec_code='27950',
        corporate_number='1010801009097',
    ),
    'E02966': EdinetCodeEntry(
        edinet_code='E02966',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=867,
        fiscal_year_end='3月31日',
        submitter_name='ＴＣＳ株式会社',
        submitter_name_en='TCS Inc.',
        submitter_name_yomi='ティーシーエスカブシキガイシャ',
        address='渋谷区恵比寿一丁目１９番１９号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6011001039962',
    ),
    'E02967': EdinetCodeEntry(
        edinet_code='E02967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1944,
        fiscal_year_end='1月31日',
        submitter_name='クロスプラス株式会社',
        submitter_name_en='CROSS PLUS INC.',
        submitter_name_yomi='クロスプラスカブシキカイシャ',
        address='名古屋市西区花の木三丁目９番１３号',
        industry='卸売業',
        sec_code='33200',
        corporate_number='1180001025507',
    ),
    'E02968': EdinetCodeEntry(
        edinet_code='E02968',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=521,
        fiscal_year_end='5月31日',
        submitter_name='ミタチ産業株式会社',
        submitter_name_en='MITACHI  CO.,LTD.',
        submitter_name_yomi='ミタチサンギョウカブシキガイシャ',
        address='名古屋市中区伊勢山二丁目１１番２８号',
        industry='卸売業',
        sec_code='33210',
        corporate_number='9180001041117',
    ),
    'E02970': EdinetCodeEntry(
        edinet_code='E02970',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テリロジー',
        submitter_name_en='Terilogy Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャテリロジー',
        address='千代田区九段北一丁目１３番５号ヒューリック九段ビル４階',
        industry='卸売業',
        sec_code=None,
        corporate_number='5010001023688',
    ),
    'E02971': EdinetCodeEntry(
        edinet_code='E02971',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2437,
        fiscal_year_end='9月30日',
        submitter_name='レカム株式会社',
        submitter_name_en='RECOMM CO.,LTD.',
        submitter_name_yomi='レカムカブシキガイシャ',
        address='渋谷区代々木三丁目２５番３号',
        industry='卸売業',
        sec_code='33230',
        corporate_number='8010401085763',
    ),
    'E02977': EdinetCodeEntry(
        edinet_code='E02977',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1349,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トラスト',
        submitter_name_en='TRUST CO., LTD.',
        submitter_name_yomi='カブシキガイシャトラスト',
        address='名古屋市中区錦三丁目１０番３２号',
        industry='小売業',
        sec_code=None,
        corporate_number='9180001038906',
    ),
    'E02978': EdinetCodeEntry(
        edinet_code='E02978',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メタプラネット',
        submitter_name_en='Metaplanet KK',
        submitter_name_yomi='カブシキガイシャメタプラネット',
        address='港区元麻布三丁目１番６号',
        industry='卸売業',
        sec_code='33500',
        corporate_number='3010401091543',
    ),
    'E02979': EdinetCodeEntry(
        edinet_code='E02979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=783,
        fiscal_year_end='12月31日',
        submitter_name='クリヤマホールディングス株式会社',
        submitter_name_en='KURIYAMA HOLDINGS CORPORATION',
        submitter_name_yomi='クリヤマホールディングス\u3000カブシキガイシャ',
        address='大阪市中央区城見１－３－７\u3000松下ＩＭＰビル２５階',
        industry='卸売業',
        sec_code='33550',
        corporate_number='3120001054971',
    ),
    'E02980': EdinetCodeEntry(
        edinet_code='E02980',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=671,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アールシーコア',
        submitter_name_en='R.C.CORE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアールシーコア',
        address='渋谷区猿楽町１０番１号',
        industry='その他製品',
        sec_code='78370',
        corporate_number='8013201007128',
    ),
    'E02982': EdinetCodeEntry(
        edinet_code='E02982',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=665,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ｃｏｔｔａ',
        submitter_name_en='cotta CO.,LTD',
        submitter_name_yomi='カブシキガイシャコッタ',
        address='津久見市上青江４４７８番地８',
        industry='卸売業',
        sec_code='33590',
        corporate_number='6320201000224',
    ),
    'E02986': EdinetCodeEntry(
        edinet_code='E02986',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1087,
        fiscal_year_end='3月31日',
        submitter_name='内外テック株式会社',
        submitter_name_en='Naigai Tec Corporation',
        submitter_name_yomi='ナイガイテックカブシキガイシャ',
        address='世田谷区三軒茶屋２丁目１１番２２号',
        industry='卸売業',
        sec_code='33740',
        corporate_number='6010901008705',
    ),
    'E02988': EdinetCodeEntry(
        edinet_code='E02988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=590,
        fiscal_year_end='11月30日',
        submitter_name='株式会社バイク王＆カンパニー',
        submitter_name_en='BIKE O & COMPANY Ltd.',
        submitter_name_yomi='カブシキガイシャバイクオーアンドカンパニー',
        address='世田谷区若林三丁目１５番４号',
        industry='卸売業',
        sec_code='33770',
        corporate_number='4011001034569',
    ),
    'E02989': EdinetCodeEntry(
        edinet_code='E02989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=232,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アークコア',
        submitter_name_en='ArkCore, Inc.',
        submitter_name_yomi='カブシキガイシャアークコア',
        address='豊島区池袋ニ丁目６番１号',
        industry='卸売業',
        sec_code='33840',
        corporate_number='8011801023775',
    ),
    'E02991': EdinetCodeEntry(
        edinet_code='E02991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=918,
        fiscal_year_end='12月31日',
        submitter_name='コスモ・バイオ株式会社',
        submitter_name_en='COSMO BIO COMPANY, LIMITED',
        submitter_name_yomi='コスモバイオカブシキガイシャ',
        address='江東区東陽二丁目２番２０号',
        industry='卸売業',
        sec_code='33860',
        corporate_number='6010601023038',
    ),
    'E02992': EdinetCodeEntry(
        edinet_code='E02992',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1658,
        fiscal_year_end='3月31日',
        submitter_name='明治電機工業株式会社',
        submitter_name_en='MEIJI ELECTRIC INDUSTRIES CO., LTD.',
        submitter_name_yomi='メイジデンキコウギョウカブシキガイシャ',
        address='名古屋市中村区亀島二丁目１３番８号',
        industry='卸売業',
        sec_code='33880',
        corporate_number='6180001033042',
    ),
    'E02993': EdinetCodeEntry(
        edinet_code='E02993',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=425,
        fiscal_year_end='2月末日',
        submitter_name='株式会社オフィス２４',
        submitter_name_en='OFFICE24 CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオフィスニジュウヨン',
        address='新宿区西新宿６－２２－１\u3000新宿スクエアタワー３階',
        industry='卸売業',
        sec_code=None,
        corporate_number='1011101010480',
    ),
    'E02994': EdinetCodeEntry(
        edinet_code='E02994',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1377,
        fiscal_year_end='3月31日',
        submitter_name='デリカフーズホールディングス株式会社',
        submitter_name_en='DELICA FOODS HOLDINGS CO.,LTD.',
        submitter_name_yomi='デリカフーズホールディングスカブシキガイシャ',
        address='足立区六町四丁目１２番１２号',
        industry='卸売業',
        sec_code='33920',
        corporate_number='8011801015921',
    ),
    'E02995': EdinetCodeEntry(
        edinet_code='E02995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=294,
        fiscal_year_end='8月20日',
        submitter_name='ケイティケイ株式会社',
        submitter_name_en='ktk INC.',
        submitter_name_yomi='ケイティケイカブシキガイシャ',
        address='名古屋市東区泉二丁目３番３号',
        industry='卸売業',
        sec_code='30350',
        corporate_number='9180001016399',
    ),
    'E02996': EdinetCodeEntry(
        edinet_code='E02996',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=494,
        fiscal_year_end='5月31日',
        submitter_name='山下医科器械株式会社',
        submitter_name_en='YAMASHITA MEDICAL INSTRUMENTS CO.,LTD.',
        submitter_name_yomi='ヤマシタイカキカイカブシキガイシャ',
        address='佐世保市湊町３番１３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='5310001006118',
    ),
    'E02997': EdinetCodeEntry(
        edinet_code='E02997',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=646,
        fiscal_year_end='3月31日',
        submitter_name='クリエイト株式会社',
        submitter_name_en='CREATE CORPORATION',
        submitter_name_yomi='クリエイトカブシキガイシャ',
        address='大阪市西区阿波座一丁目１３番１５号',
        industry='卸売業',
        sec_code='30240',
        corporate_number='7120001042923',
    ),
    'E02998': EdinetCodeEntry(
        edinet_code='E02998',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5830,
        fiscal_year_end='3月31日',
        submitter_name='アルコニックス株式会社',
        submitter_name_en='ALCONIX CORPORATION',
        submitter_name_yomi='アルコニックスカブシキカイシャ',
        address='千代田区永田町２－１１－１',
        industry='卸売業',
        sec_code='30360',
        corporate_number='1010401042424',
    ),
    'E02999': EdinetCodeEntry(
        edinet_code='E02999',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='10月31日',
        submitter_name='株式会社神戸物産',
        submitter_name_en='KOBE BUSSAN CO., LTD.',
        submitter_name_yomi='カブシキガイシャコウベブッサン',
        address='加古川市加古川町平野１２５番１',
        industry='卸売業',
        sec_code='30380',
        corporate_number='5140001044630',
    ),
    'E03000': EdinetCodeEntry(
        edinet_code='E03000',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4,
        fiscal_year_end='8月31日',
        submitter_name='株式会社カワサキ',
        submitter_name_en='Kawasaki&Co.,Ltd',
        submitter_name_yomi='カブシキガイシャカワサキ',
        address='泉北郡忠岡町新浜２丁目９番１０号',
        industry='卸売業',
        sec_code='30450',
        corporate_number='5120101042932',
    ),
    'E03003': EdinetCodeEntry(
        edinet_code='E03003',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ほくやく・竹山ホールディングス',
        submitter_name_en='HOKUYAKU TAKEYAMA Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャホクヤクタケヤマホールディングス',
        address='札幌市中央区北６条西１６丁目１番地５',
        industry='卸売業',
        sec_code='30550',
        corporate_number='2430001032501',
    ),
    'E03004': EdinetCodeEntry(
        edinet_code='E03004',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1635,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ジェリービーンズグループ',
        submitter_name_en='JELLY BEANS GROUP Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャジェリービーンズグループ',
        address='台東区上野一丁目１６番５号',
        industry='卸売業',
        sec_code='30700',
        corporate_number='9010501001644',
    ),
    'E03005': EdinetCodeEntry(
        edinet_code='E03005',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=344,
        fiscal_year_end='3月31日',
        submitter_name='ディーブイエックス株式会社',
        submitter_name_en='DVx Inc.',
        submitter_name_yomi='ディーブイエックスカブシキガイシャ',
        address='港区港南１丁目８番１５号',
        industry='卸売業',
        sec_code='30790',
        corporate_number='9011601006203',
    ),
    'E03006': EdinetCodeEntry(
        edinet_code='E03006',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='6月30日',
        submitter_name='あいホールディングス株式会社',
        submitter_name_en='Ai Holdings Corporation',
        submitter_name_yomi='アイホールディングスカブシキカイシャ',
        address='中央区日本橋久松町１２番８号',
        industry='卸売業',
        sec_code='30760',
        corporate_number='4010001108077',
    ),
    'E03007': EdinetCodeEntry(
        edinet_code='E03007',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='11月30日',
        submitter_name='テクノアルファ株式会社',
        submitter_name_en='Techno Alpha Co.,Ltd.',
        submitter_name_yomi='テクノアルファカブシキガイシャ',
        address='品川区西五反田２丁目２７－４\u3000明治安田生命五反田ビル',
        industry='卸売業',
        sec_code='30890',
        corporate_number='2010701006251',
    ),
    'E03012': EdinetCodeEntry(
        edinet_code='E03012',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000東急百貨店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000トウキュウヒャッカテン',
        address='渋谷区道玄坂２丁目２４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001016584',
    ),
    'E03013': EdinetCodeEntry(
        edinet_code='E03013',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=66025,
        fiscal_year_end='2月末日',
        submitter_name='株式会社髙島屋',
        submitter_name_en='Takashimaya Company,Limited',
        submitter_name_yomi='カブシキガイシャタカシマヤ',
        address='大阪市中央区難波５丁目１番５号',
        industry='小売業',
        sec_code='82330',
        corporate_number='5120001077467',
    ),
    'E03017': EdinetCodeEntry(
        edinet_code='E03017',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7132,
        fiscal_year_end='2月末日',
        submitter_name='株式会社松屋',
        submitter_name_en='MATSUYA CO., LTD.',
        submitter_name_yomi='カブシキガイシャマツヤ',
        address='中央区銀座三丁目６番１号',
        industry='小売業',
        sec_code='82370',
        corporate_number='1010001034945',
    ),
    'E03020': EdinetCodeEntry(
        edinet_code='E03020',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17796,
        fiscal_year_end='3月31日',
        submitter_name='エイチ・ツー・オー\u3000リテイリング株式会社',
        submitter_name_en='H2O RETAILING CORPORATION',
        submitter_name_yomi='エイチツーオーリテイリングカブシキガイシャ',
        address='大阪市北区角田町８番７号',
        industry='小売業',
        sec_code='82420',
        corporate_number='1120001059683',
    ),
    'E03021': EdinetCodeEntry(
        edinet_code='E03021',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社近鉄百貨店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキンテツヒャッカテン',
        address='大阪市阿倍野区阿倍野筋１丁目１番４３号',
        industry='小売業',
        sec_code='82440',
        corporate_number='3120001098201',
    ),
    'E03022': EdinetCodeEntry(
        edinet_code='E03022',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='興和ファシリティズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウワファシリティズカブシキガイシャ',
        address='名古屋市中区栄三丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001040644',
    ),
    'E03024': EdinetCodeEntry(
        edinet_code='E03024',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=405,
        fiscal_year_end='2月末日',
        submitter_name='株式会社\u3000山陽百貨店',
        submitter_name_en='Sanyo Department Store Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000サンヨウヒャッカテン',
        address='姫路市南町１番地',
        industry='小売業',
        sec_code=None,
        corporate_number='6140001058951',
    ),
    'E03025': EdinetCodeEntry(
        edinet_code='E03025',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3462,
        fiscal_year_end='2月末日',
        submitter_name='株式会社大和',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイワ',
        address='金沢市片町二丁目２番５号',
        industry='小売業',
        sec_code='82470',
        corporate_number='6220001003957',
    ),
    'E03026': EdinetCodeEntry(
        edinet_code='E03026',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=26867,
        fiscal_year_end='2月末日',
        submitter_name='株式会社パルコ',
        submitter_name_en='PARCO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャパルコ',
        address='豊島区南池袋一丁目２８番２号\u3000（上記は登記上の本店所在地であり、実際の業務は下記の場所で行っております。）',
        industry='小売業',
        sec_code=None,
        corporate_number='6013301010215',
    ),
    'E03031': EdinetCodeEntry(
        edinet_code='E03031',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社金沢名鉄丸越百貨店',
        submitter_name_en='Kanazawa Meitetsu Marukoshi Department Store Co., LTD.',
        submitter_name_yomi='カブシキガイシャカナザワメイテツマルコシヒャッカテン',
        address='金沢市武蔵町１５番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='6220001002182',
    ),
    'E03032': EdinetCodeEntry(
        edinet_code='E03032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社井筒屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイヅツヤ',
        address='北九州市小倉北区船場町１番１号',
        industry='小売業',
        sec_code='82600',
        corporate_number='7290801000329',
    ),
    'E03036': EdinetCodeEntry(
        edinet_code='E03036',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26137,
        fiscal_year_end='3月31日',
        submitter_name='美津濃株式会社',
        submitter_name_en='Mizuno Corporation',
        submitter_name_yomi='ミズノカブシキガイシャ',
        address='大阪市中央区北浜四丁目１番２３号',
        industry='その他製品',
        sec_code='80220',
        corporate_number='4120001077559',
    ),
    'E03040': EdinetCodeEntry(
        edinet_code='E03040',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35920,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000丸井グループ',
        submitter_name_en=None,
        submitter_name_yomi='マルイグループ',
        address='中野区中野４丁目３番２号',
        industry='小売業',
        sec_code='82520',
        corporate_number='9011201005150',
    ),
    'E03041': EdinetCodeEntry(
        edinet_code='E03041',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=75929,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クレディセゾン',
        submitter_name_en='Credit Saison Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクレディセゾン',
        address='豊島区東池袋三丁目１番１号',
        industry='その他金融業',
        sec_code='82530',
        corporate_number='2013301002884',
    ),
    'E03044': EdinetCodeEntry(
        edinet_code='E03044',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2195,
        fiscal_year_end='8月末日',
        submitter_name='株式会社さいか屋',
        submitter_name_en='Saikaya Department Store Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサイカヤ',
        address='川崎市川崎区日進町１番地',
        industry='小売業',
        sec_code='82540',
        corporate_number='3020001074170',
    ),
    'E03049': EdinetCodeEntry(
        edinet_code='E03049',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ダイエー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイエー',
        address='神戸市中央区港島中町四丁目１番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001005666',
    ),
    'E03051': EdinetCodeEntry(
        edinet_code='E03051',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7070,
        fiscal_year_end='3月31日',
        submitter_name='日本瓦斯株式会社',
        submitter_name_en='NIPPON GAS CO.,LTD.',
        submitter_name_yomi='ニホンガスカブシキガイシャ',
        address='渋谷区代々木４ー３１ー８',
        industry='小売業',
        sec_code='81740',
        corporate_number='9010001061924',
    ),
    'E03052': EdinetCodeEntry(
        edinet_code='E03052',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15121,
        fiscal_year_end='3月31日',
        submitter_name='上新電機株式会社',
        submitter_name_en='Joshin Denki Co., Ltd.',
        submitter_name_yomi='ジョウシンデンキカブシキガイシャ',
        address='大阪市浪速区日本橋西一丁目６番５号',
        industry='小売業',
        sec_code='81730',
        corporate_number='9120001038564',
    ),
    'E03054': EdinetCodeEntry(
        edinet_code='E03054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6064,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スクロール',
        submitter_name_en='Scroll Corporation',
        submitter_name_yomi='カブシキガイシャスクロール',
        address='浜松市中区佐藤二丁目２４番１号',
        industry='小売業',
        sec_code='80050',
        corporate_number='9080401005367',
    ),
    'E03057': EdinetCodeEntry(
        edinet_code='E03057',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ベスト電器',
        submitter_name_en='BEST DENKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャベストデンキ',
        address='福岡市博多区千代六丁目２番３３号',
        industry='小売業',
        sec_code=None,
        corporate_number='6290001017752',
    ),
    'E03061': EdinetCodeEntry(
        edinet_code='E03061',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=220007,
        fiscal_year_end='2月末日',
        submitter_name='イオン株式会社',
        submitter_name_en='AEON Co.,Ltd.',
        submitter_name_yomi='イオンカブシキガイシャ',
        address='千葉市美浜区中瀬１丁目５番地１',
        industry='小売業',
        sec_code='82670',
        corporate_number='6040001003380',
    ),
    'E03064': EdinetCodeEntry(
        edinet_code='E03064',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8981,
        fiscal_year_end='3月31日',
        submitter_name='株式会社いなげや',
        submitter_name_en='inageya  co.,ltd.',
        submitter_name_yomi='カブシキガイシャイナゲヤ',
        address='立川市栄町六丁目１番地の１',
        industry='小売業',
        sec_code=None,
        corporate_number='2012801000159',
    ),
    'E03067': EdinetCodeEntry(
        edinet_code='E03067',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17200,
        fiscal_year_end=None,
        submitter_name='株式会社セブン‐イレブン・ジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセブンイレブンジャパン',
        address='千代田区二番町８番地８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001088181',
    ),
    'E03068': EdinetCodeEntry(
        edinet_code='E03068',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19613,
        fiscal_year_end='2月末日',
        submitter_name='株式会社イズミ',
        submitter_name_en='izumico.,ltd',
        submitter_name_yomi='カブシキガイシャイズミ',
        address='広島市東区二葉の里三丁目３番１号',
        industry='小売業',
        sec_code='82730',
        corporate_number='8240001000777',
    ),
    'E03071': EdinetCodeEntry(
        edinet_code='E03071',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13616,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンゲツ',
        submitter_name_en='Sangetsu Corporation',
        submitter_name_yomi='カブシキガイシャサンゲツ',
        address='名古屋市西区幅下一丁目４番１号',
        industry='卸売業',
        sec_code='81300',
        corporate_number='3180001025521',
    ),
    'E03072': EdinetCodeEntry(
        edinet_code='E03072',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4220,
        fiscal_year_end='3月20日',
        submitter_name='株式会社ヤマナカ',
        submitter_name_en='YAMANAKA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤマナカ',
        address='名古屋市中村区岩塚町字西枝１番地の１',
        industry='小売業',
        sec_code='81900',
        corporate_number='8180001018537',
    ),
    'E03073': EdinetCodeEntry(
        edinet_code='E03073',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9022,
        fiscal_year_end='2月末日',
        submitter_name='株式会社東武ストア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトウブストア',
        address='板橋区上板橋３丁目１番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='4011401004551',
    ),
    'E03074': EdinetCodeEntry(
        edinet_code='E03074',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16533,
        fiscal_year_end='8月31日',
        submitter_name='株式会社島忠',
        submitter_name_en='SHIMACHU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャシマチュウ',
        address='さいたま市中央区上落合８－３－３２',
        industry='小売業',
        sec_code=None,
        corporate_number='1030001004269',
    ),
    'E03076': EdinetCodeEntry(
        edinet_code='E03076',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1005,
        fiscal_year_end='3月31日',
        submitter_name='ゼット株式会社',
        submitter_name_en='ZETT CORPORATION',
        submitter_name_yomi='ゼットカブシキガイシャ',
        address='大阪市天王寺区烏ヶ辻一丁目２番１６号',
        industry='卸売業',
        sec_code='81350',
        corporate_number='6120001023916',
    ),
    'E03077': EdinetCodeEntry(
        edinet_code='E03077',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6893,
        fiscal_year_end='2月末日',
        submitter_name='株式会社チヨダ',
        submitter_name_en='CHIYODA CO.,LTD',
        submitter_name_yomi='カブシキガイシャチヨダ',
        address='杉並区荻窪四丁目３０番１６号',
        industry='小売業',
        sec_code='81850',
        corporate_number='1011301004381',
    ),
    'E03078': EdinetCodeEntry(
        edinet_code='E03078',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4581,
        fiscal_year_end='4月30日',
        submitter_name='株式会社大塚家具',
        submitter_name_en='OTSUKA KAGU,LTD.',
        submitter_name_yomi='カブシキガイシャオオツカカグ',
        address='江東区有明三丁目６番１１号',
        industry='小売業',
        sec_code=None,
        corporate_number='5010601024012',
    ),
    'E03081': EdinetCodeEntry(
        edinet_code='E03081',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11614,
        fiscal_year_end='2月20日',
        submitter_name='株式会社\u3000平和堂',
        submitter_name_en='HEIWADO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヘイワドウ',
        address='彦根市西今町１番地',
        industry='小売業',
        sec_code='82760',
        corporate_number='3160001008726',
    ),
    'E03083': EdinetCodeEntry(
        edinet_code='E03083',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10004,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ライフコーポレーション',
        submitter_name_en='LIFE CORPORATION',
        submitter_name_yomi='カブシキガイシャライフコーポレーション',
        address='大阪市淀川区西宮原二丁目２番２２号',
        industry='小売業',
        sec_code='81940',
        corporate_number='9010001060208',
    ),
    'E03087': EdinetCodeEntry(
        edinet_code='E03087',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2267,
        fiscal_year_end='2月末日',
        submitter_name='マックスバリュ東海株式会社',
        submitter_name_en='Maxvalu Tokai Co., Ltd.',
        submitter_name_yomi='マックスバリュトウカイカブシキガイシャ',
        address='浜松市中央区篠ケ瀬町１２９５番地１',
        industry='小売業',
        sec_code='81980',
        corporate_number='1080101006499',
    ),
    'E03090': EdinetCodeEntry(
        edinet_code='E03090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11077,
        fiscal_year_end='3月31日',
        submitter_name='ＳＲＳホールディングス株式会社',
        submitter_name_en='SRS HOLDINGS CO.,LTD.',
        submitter_name_yomi='エスアールエスホールディングスカブシキガイシャ',
        address='大阪市中央区安土町二丁目３番１３号\u3000大阪国際ビルディング３０階',
        industry='小売業',
        sec_code='81630',
        corporate_number='4120101022786',
    ),
    'E03092': EdinetCodeEntry(
        edinet_code='E03092',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社千趣会',
        submitter_name_en='SENSHUKAI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000センシュカイ',
        address='大阪市北区同心１丁目６番２３号',
        industry='小売業',
        sec_code='81650',
        corporate_number='5120001066081',
    ),
    'E03093': EdinetCodeEntry(
        edinet_code='E03093',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=172,
        fiscal_year_end='2月末日',
        submitter_name='株式会社タカキュー',
        submitter_name_en='Taka-Q Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャタカキュー',
        address='板橋区板橋３丁目９番７号',
        industry='小売業',
        sec_code='81660',
        corporate_number='5011401003916',
    ),
    'E03094': EdinetCodeEntry(
        edinet_code='E03094',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7218,
        fiscal_year_end='2月末日',
        submitter_name='株式会社リテールパートナーズ',
        submitter_name_en='RETAIL PARTNERS CO., LTD.',
        submitter_name_yomi='カブシキガイシャリテイルパートナーズ',
        address='防府市大字江泊１９３６番地',
        industry='小売業',
        sec_code='81670',
        corporate_number='1250001002242',
    ),
    'E03095': EdinetCodeEntry(
        edinet_code='E03095',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2958,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジョリーパスタ',
        submitter_name_en='Jolly-Pasta CO.,LTD.',
        submitter_name_yomi='ジョリーパスタ',
        address='港区港南２－１８－１',
        industry='小売業',
        sec_code=None,
        corporate_number='6010401073811',
    ),
    'E03096': EdinetCodeEntry(
        edinet_code='E03096',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16505,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ケーヨー',
        submitter_name_en='Keiyo Co.,Ltd',
        submitter_name_yomi='カブシキガイシャケーヨー',
        address='千葉市若葉区みつわ台１丁目２８番地１号',
        industry='小売業',
        sec_code=None,
        corporate_number='4040001002054',
    ),
    'E03098': EdinetCodeEntry(
        edinet_code='E03098',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12944,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アデランス',
        submitter_name_en='Aderans Company Limited',
        submitter_name_yomi='カブシキガイシャアデランス',
        address='新宿区荒木町１３番地４',
        industry='その他製品',
        sec_code=None,
        corporate_number='4011101001064',
    ),
    'E03099': EdinetCodeEntry(
        edinet_code='E03099',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9002,
        fiscal_year_end='2月末日',
        submitter_name='株式会社リンガーハット',
        submitter_name_en='RINGER HUT CO.,LTD',
        submitter_name_yomi='カブシキガイシャリンガーハット',
        address='長崎市鍛冶屋町６番５０号',
        industry='小売業',
        sec_code='82000',
        corporate_number='5310001001011',
    ),
    'E03100': EdinetCodeEntry(
        edinet_code='E03100',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5258,
        fiscal_year_end='2月28日',
        submitter_name='さが美グループホールディングス株式会社',
        submitter_name_en='SAGAMI GROUP HOLDINGS Co.,  Ltd.',
        submitter_name_yomi='サガミグループホールディングスカブシキガイシャ',
        address='平塚市田村八丁目２１番９号',
        industry='小売業',
        sec_code=None,
        corporate_number='3020001035263',
    ),
    'E03101': EdinetCodeEntry(
        edinet_code='E03101',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='ラオックスホールディングス株式会社',
        submitter_name_en='Laox Holdings CO.,LTD.',
        submitter_name_yomi='ラオックスホールディングスカブシキガイシャ',
        address='港区虎ノ門４丁目３番１号',
        industry='小売業',
        sec_code='82020',
        corporate_number='7010401099079',
    ),
    'E03103': EdinetCodeEntry(
        edinet_code='E03103',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10229,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ミスターマックス・ホールディングス',
        submitter_name_en='Mr Max Holdings Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ミスターマックス\u3000ホールディングス',
        address='福岡市東区松田一丁目５番７号',
        industry='小売業',
        sec_code='82030',
        corporate_number='3290001004134',
    ),
    'E03105': EdinetCodeEntry(
        edinet_code='E03105',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='シャクリー・グローバル・グループ株式会社',
        submitter_name_en='SHAKLEE GLOBAL GROUP,INC.',
        submitter_name_yomi='シヤクリーグローバルグループカブシキガイシャ',
        address='新宿区西新宿二丁目６番１号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6011101061073',
    ),
    'E03107': EdinetCodeEntry(
        edinet_code='E03107',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='フルサト工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フルサトコウギョウカブシキガイシャ',
        address='大阪市中央区南新町一丁目２番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001047162',
    ),
    'E03108': EdinetCodeEntry(
        edinet_code='E03108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='テンアライド株式会社',
        submitter_name_en='TEN ALLIED CO.,LTD.',
        submitter_name_yomi='テンアライドカブシキガイシャ',
        address='目黒区鷹番二丁目１６番１８号（Ｋビル）',
        industry='小売業',
        sec_code='82070',
        corporate_number='3010001051286',
    ),
    'E03109': EdinetCodeEntry(
        edinet_code='E03109',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2902,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エンチョー',
        submitter_name_en='ENCHO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエンチョー',
        address='富士市中央町２丁目１２番１２号',
        industry='小売業',
        sec_code=None,
        corporate_number='7080101008234',
    ),
    'E03110': EdinetCodeEntry(
        edinet_code='E03110',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フレンドリー',
        submitter_name_en='FRIENDLY CORPORATION',
        submitter_name_yomi='カブシキカイシャフレンドリー',
        address='大東市寺川３丁目１２番１号',
        industry='小売業',
        sec_code='82090',
        corporate_number='9122001015873',
    ),
    'E03114': EdinetCodeEntry(
        edinet_code='E03114',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12220,
        fiscal_year_end=None,
        submitter_name='富士通Ｊａｐａｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジツウジャパンカブシキカイシャ',
        address='川崎市幸区大宮町１番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001006767',
    ),
    'E03116': EdinetCodeEntry(
        edinet_code='E03116',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23282,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＯＫＩホールディングス',
        submitter_name_en='AOKI Holdings Inc.',
        submitter_name_yomi='カブシキガイシャアオキホールディングス',
        address='横浜市都筑区葛が谷６番５６',
        industry='小売業',
        sec_code='82140',
        corporate_number='5020001091635',
    ),
    'E03117': EdinetCodeEntry(
        edinet_code='E03117',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社銀座山形屋',
        submitter_name_en='GINZA YAMAGATAYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャギンザヤマガタヤ',
        address='中央区湊二丁目４番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='5010001041228',
    ),
    'E03118': EdinetCodeEntry(
        edinet_code='E03118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19407,
        fiscal_year_end='2月末日',
        submitter_name='株式会社フジ',
        submitter_name_en='FUJI CO., LTD.',
        submitter_name_yomi='カブシキガイシャフジ',
        address='松山市宮西一丁目２番１号',
        industry='小売業',
        sec_code='82780',
        corporate_number='9500001003505',
    ),
    'E03119': EdinetCodeEntry(
        edinet_code='E03119',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14117,
        fiscal_year_end='2月20日',
        submitter_name='株式会社オークワ',
        submitter_name_en='OKUWA CO., LTD.',
        submitter_name_yomi='カブシキガイシャオークワ',
        address='和歌山市中島１８５番地の３',
        industry='小売業',
        sec_code='82170',
        corporate_number='2170001002092',
    ),
    'E03120': EdinetCodeEntry(
        edinet_code='E03120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18802,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コメリ',
        submitter_name_en='KOMERI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャコメリ',
        address='新潟市南区清水４５０１番地１',
        industry='小売業',
        sec_code='82180',
        corporate_number='9110001002050',
    ),
    'E03121': EdinetCodeEntry(
        edinet_code='E03121',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12648,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000木曽路',
        submitter_name_en='KISOJI  CO., LTD.',
        submitter_name_yomi='カブシキカイシャ\u3000キソジ',
        address='名古屋市昭和区白金三丁目１８番１３号',
        industry='小売業',
        sec_code='81600',
        corporate_number='9180001008132',
    ),
    'E03122': EdinetCodeEntry(
        edinet_code='E03122',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3950,
        fiscal_year_end='2月末日',
        submitter_name='マックスバリュ中部株式会社',
        submitter_name_en='MAXVALU CHUBU CO.,LTD',
        submitter_name_yomi='マックスバリュチュウブカブシキガイシャ',
        address='名古屋市中区錦一丁目１８番２２号',
        industry='小売業',
        sec_code=None,
        corporate_number='8190001010492',
    ),
    'E03124': EdinetCodeEntry(
        edinet_code='E03124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=62504,
        fiscal_year_end='3月31日',
        submitter_name='青山商事株式会社',
        submitter_name_en='AOYAMA TRADING Co., Ltd.',
        submitter_name_yomi='アオヤマショウジカブシキガイシャ',
        address='福山市王子町一丁目３番５号',
        industry='小売業',
        sec_code='82190',
        corporate_number='1240001029674',
    ),
    'E03125': EdinetCodeEntry(
        edinet_code='E03125',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=16659,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ファミリーマート',
        submitter_name_en='FamilyMart Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャファミリーマート',
        address='港区芝浦三丁目１番２１号',
        industry='小売業',
        sec_code=None,
        corporate_number='2013301010706',
    ),
    'E03126': EdinetCodeEntry(
        edinet_code='E03126',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9031,
        fiscal_year_end='3月31日',
        submitter_name='兼松エレクトロニクス株式会社',
        submitter_name_en='KANEMATSU ELECTRONICS LTD.',
        submitter_name_yomi='カネマツエレクトロニクスカブシキガイシャ',
        address='中央区京橋２丁目１３番１０号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3010001040339',
    ),
    'E03127': EdinetCodeEntry(
        edinet_code='E03127',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9846,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤオコー',
        submitter_name_en='YAOKO CO., LTD.',
        submitter_name_yomi='カブシキガイシャヤオコー',
        address='川越市新宿町一丁目１０番地１',
        industry='小売業',
        sec_code=None,
        corporate_number='4030001055722',
    ),
    'E03128': EdinetCodeEntry(
        edinet_code='E03128',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18125,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ケーズホールディングス',
        submitter_name_en="K'S HOLDINGS CORPORATION",
        submitter_name_yomi='カブシキガイシャケーズホールディングス',
        address='水戸市城南二丁目７番５号',
        industry='小売業',
        sec_code='82820',
        corporate_number='6050001000897',
    ),
    'E03129': EdinetCodeEntry(
        edinet_code='E03129',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15935,
        fiscal_year_end='3月31日',
        submitter_name='ゼビオホールディングス株式会社',
        submitter_name_en='XEBIO HOLDINGS CO.,LTD.',
        submitter_name_yomi='ゼビオホールディングスカブシキガイシャ',
        address='郡山市朝日３丁目７番３５号',
        industry='小売業',
        sec_code='82810',
        corporate_number='1380001005620',
    ),
    'E03130': EdinetCodeEntry(
        edinet_code='E03130',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='マックスバリュ西日本株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マックスバリュニシニホンカブシキガイシャ',
        address='広島市南区段原南一丁目３番５２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001057907',
    ),
    'E03131': EdinetCodeEntry(
        edinet_code='E03131',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11873,
        fiscal_year_end=None,
        submitter_name='株式会社ニッセンホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッセンホールディングス',
        address='京都市南区西九条院町２６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1130001011429',
    ),
    'E03132': EdinetCodeEntry(
        edinet_code='E03132',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9946,
        fiscal_year_end='2月末日',
        submitter_name='株式会社Ｏｌｙｍｐｉｃグループ',
        submitter_name_en='Olympic Group Corporation',
        submitter_name_yomi='カブシキガイシャオリンピックグループ',
        address='国分寺市本町四丁目１２番１号',
        industry='小売業',
        sec_code='82890',
        corporate_number='2012801000308',
    ),
    'E03133': EdinetCodeEntry(
        edinet_code='E03133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3159,
        fiscal_year_end='3月31日',
        submitter_name='アクシアル\u3000リテイリング株式会社',
        submitter_name_en='Axial Retailing Inc.',
        submitter_name_yomi='アクシアル\u3000リテイリングカブシキガイシャ',
        address='長岡市中之島１９９３番地１７',
        industry='小売業',
        sec_code='82550',
        corporate_number='9110001023311',
    ),
    'E03134': EdinetCodeEntry(
        edinet_code='E03134',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4037,
        fiscal_year_end='3月31日',
        submitter_name='株式会社はせがわ',
        submitter_name_en='HASEGAWA CO., LTD.',
        submitter_name_yomi='カブシキガイシャハセガワ',
        address='福岡市博多区上川端町１２番１９２号',
        industry='小売業',
        sec_code='82300',
        corporate_number='3290001015800',
    ),
    'E03137': EdinetCodeEntry(
        edinet_code='E03137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17086,
        fiscal_year_end='2月20日',
        submitter_name='株式会社しまむら',
        submitter_name_en='SHIMAMURA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシマムラ',
        address='さいたま市大宮区北袋町１丁目６０２番１号',
        industry='小売業',
        sec_code='82270',
        corporate_number='6030001004272',
    ),
    'E03138': EdinetCodeEntry(
        edinet_code='E03138',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33998,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オートバックスセブン',
        submitter_name_en='AUTOBACS SEVEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオートバックスセブン',
        address='江東区豊洲五丁目６番５２号',
        industry='卸売業',
        sec_code='98320',
        corporate_number='3010601030532',
    ),
    'E03139': EdinetCodeEntry(
        edinet_code='E03139',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=71149,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤマダホールディングス',
        submitter_name_en='YAMADA HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤマダホールディングス',
        address='高崎市栄町１－１',
        industry='小売業',
        sec_code='98310',
        corporate_number='4070001011201',
    ),
    'E03141': EdinetCodeEntry(
        edinet_code='E03141',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4224,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ジュンテンドー',
        submitter_name_en='juntendo co.,ltd.',
        submitter_name_yomi='カブシキガイシャジュンテンドー',
        address='益田市遠田町２１７９番地１',
        industry='小売業',
        sec_code='98350',
        corporate_number='5280001005032',
    ),
    'E03144': EdinetCodeEntry(
        edinet_code='E03144',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13370,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニトリホールディングス',
        submitter_name_en='Nitori Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニトリホールディングス',
        address='札幌市北区新琴似７条１丁目２番３９号',
        industry='小売業',
        sec_code='98430',
        corporate_number='5430001012905',
    ),
    'E03145': EdinetCodeEntry(
        edinet_code='E03145',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社グルメ杵屋',
        submitter_name_en='GOURMET KINEYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャグルメキネヤ',
        address='大阪市住之江区北加賀屋３丁目４番７号',
        industry='小売業',
        sec_code='98500',
        corporate_number='2120001030585',
    ),
    'E03146': EdinetCodeEntry(
        edinet_code='E03146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3697,
        fiscal_year_end='2月末日',
        submitter_name='株式会社天満屋ストア',
        submitter_name_en='TENMAYA STORE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャテンマヤストア',
        address='岡山市北区岡町１３番１６号',
        industry='小売業',
        sec_code='98460',
        corporate_number='5260001004556',
    ),
    'E03147': EdinetCodeEntry(
        edinet_code='E03147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社銀座ルノアール',
        submitter_name_en='GINZA RENOIR CO.,LTD',
        submitter_name_yomi='カブシキガイシャギンザルノアール',
        address='中野区中央４丁目６０番３号',
        industry='小売業',
        sec_code='98530',
        corporate_number='6011201015210',
    ),
    'E03148': EdinetCodeEntry(
        edinet_code='E03148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5478,
        fiscal_year_end='3月31日',
        submitter_name='愛眼株式会社',
        submitter_name_en='AIGAN CO.,LTD.',
        submitter_name_yomi='アイガンカブシキガイシャ',
        address='大阪市天王寺区大道４丁目９番１２号',
        industry='小売業',
        sec_code='98540',
        corporate_number='7120001022594',
    ),
    'E03149': EdinetCodeEntry(
        edinet_code='E03149',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2411,
        fiscal_year_end='2月末日',
        submitter_name='ＤＣＭくろがねや株式会社',
        submitter_name_en='DCM KUROGANEYA.CO.,LTD.',
        submitter_name_yomi='ディーシーエムクロガネヤカブシキガイシャ',
        address='甲府市中小河原１丁目１３号１８番',
        industry='小売業',
        sec_code=None,
        corporate_number='8090001000586',
    ),
    'E03153': EdinetCodeEntry(
        edinet_code='E03153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10265,
        fiscal_year_end='2月末日',
        submitter_name='株式会社吉野家ホールディングス',
        submitter_name_en='YOSHINOYA HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヨシノヤホールディングス',
        address='中央区日本橋箱崎町３６番２号',
        industry='小売業',
        sec_code='98610',
        corporate_number='2011501016151',
    ),
    'E03154': EdinetCodeEntry(
        edinet_code='E03154',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=14336,
        fiscal_year_end=None,
        submitter_name='双日テックイノベーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソウジツテックイノベーションカブシキガイシャ',
        address='千代田区二番町３番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001053447',
    ),
    'E03155': EdinetCodeEntry(
        edinet_code='E03155',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5996,
        fiscal_year_end='9月30日',
        submitter_name='株式会社\u3000マルキョウ',
        submitter_name_en='marukyo corporation',
        submitter_name_yomi='カブシキガイシャ\u3000マルキョウ',
        address='大野城市山田５丁目３番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='6290001041190',
    ),
    'E03157': EdinetCodeEntry(
        edinet_code='E03157',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7297,
        fiscal_year_end='3月31日',
        submitter_name='日本ＫＦＣホールディングス株式会社',
        submitter_name_en='KFC Holdings Japan, Ltd.',
        submitter_name_yomi='ニホンケイエフシイホールディングスカブシキガイシャ',
        address='横浜市西区みなとみらい４丁目４番５号',
        industry='小売業',
        sec_code=None,
        corporate_number='4011001017607',
    ),
    'E03160': EdinetCodeEntry(
        edinet_code='E03160',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=56,
        fiscal_year_end='3月20日',
        submitter_name='株式会社\u3000セキド',
        submitter_name_en='SEKIDO CO.,LTD',
        submitter_name_yomi='カブシキガイシャ\u3000セキド',
        address='新宿区西新宿三丁目７番１号',
        industry='小売業',
        sec_code='98780',
        corporate_number='6011101056882',
    ),
    'E03163': EdinetCodeEntry(
        edinet_code='E03163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4503,
        fiscal_year_end='2月末日',
        submitter_name='株式会社コックス',
        submitter_name_en='COX CO.,LTD.',
        submitter_name_yomi='カブシキガイシャコックス',
        address='中央区日本橋浜町一丁目２番１号',
        industry='小売業',
        sec_code='98760',
        corporate_number='9010001141445',
    ),
    'E03164': EdinetCodeEntry(
        edinet_code='E03164',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6655,
        fiscal_year_end='3月31日',
        submitter_name='株式会社松屋フーズホールディングス',
        submitter_name_en='MATSUYA FOODS HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000マツヤフーズホールディングス',
        address='武蔵野市中町１－１４－５',
        industry='小売業',
        sec_code='98870',
        corporate_number='6012401015768',
    ),
    'E03166': EdinetCodeEntry(
        edinet_code='E03166',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1198,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マキヤ',
        submitter_name_en='MAKIYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャマキヤ',
        address='富士市大渕２３７３番地',
        industry='小売業',
        sec_code='98900',
        corporate_number='3080101001770',
    ),
    'E03169': EdinetCodeEntry(
        edinet_code='E03169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='株式会社テーオーホールディングス',
        submitter_name_en='T.O. Holdings CO., LTD.',
        submitter_name_yomi='カブシキガイシャテーオーホールディングス',
        address='函館市港町３丁目１８番１５号',
        industry='卸売業',
        sec_code='98120',
        corporate_number='1440001001290',
    ),
    'E03173': EdinetCodeEntry(
        edinet_code='E03173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2660,
        fiscal_year_end='9月30日',
        submitter_name='株式会社マミーマートホールディングス',
        submitter_name_en='Mammy Mart Holding Corporation',
        submitter_name_yomi='カブシキガイシャマミーマートホールディングス',
        address='東松山市本町２丁目２番４７号',
        industry='小売業',
        sec_code='98230',
        corporate_number='5030001071058',
    ),
    'E03174': EdinetCodeEntry(
        edinet_code='E03174',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=957,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000ＪＥＵＧＩＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ジュージヤ',
        address='京都市中京区三条通寺町東入石橋町１１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4130001021094',
    ),
    'E03175': EdinetCodeEntry(
        edinet_code='E03175',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2368,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ながの東急百貨店',
        submitter_name_en='NAGANO TOKYU DEPARTMENT STORE CO., LTD.',
        submitter_name_yomi='カブシキガイシャナガノトウキュウヒャッカテン',
        address='長野市南千歳一丁目１番地１',
        industry='小売業',
        sec_code=None,
        corporate_number='3100001002412',
    ),
    'E03176': EdinetCodeEntry(
        edinet_code='E03176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｇｅｎｋｉ\u3000Ｇｌｏｂａｌ\u3000Ｄｉｎｉｎｇ\u3000Ｃｏｎｃｅｐｔｓ',
        submitter_name_en='Genki Global Dining Concepts Corporation',
        submitter_name_yomi='カブシキガイシャゲンキグローバツダイニングコンセプツ',
        address='台東区上野３丁目２４番６号上野フロンティアタワー１９階',
        industry='小売業',
        sec_code='98280',
        corporate_number='8060001001562',
    ),
    'E03178': EdinetCodeEntry(
        edinet_code='E03178',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9090,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サガミホールディングス',
        submitter_name_en='Sagami Holdings Corporation',
        submitter_name_yomi='カブシキガイシャサガミホールディングス',
        address='名古屋市守山区八剣二丁目１１８番地',
        industry='小売業',
        sec_code='99000',
        corporate_number='1180001000443',
    ),
    'E03179': EdinetCodeEntry(
        edinet_code='E03179',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1926,
        fiscal_year_end='2月末日',
        submitter_name='株式会社カンセキ',
        submitter_name_en='KANSEKI  CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000カンセキ',
        address='宇都宮市西川田本町３丁目１番１号',
        industry='小売業',
        sec_code='99030',
        corporate_number='8060001001208',
    ),
    'E03180': EdinetCodeEntry(
        edinet_code='E03180',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=13098,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツツミ',
        submitter_name_en='TSUTSUMI JEWELRY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャツツミ',
        address='蕨市中央４丁目２４番２６号',
        industry='その他製品',
        sec_code='79370',
        corporate_number='2030001021115',
    ),
    'E03181': EdinetCodeEntry(
        edinet_code='E03181',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベリテ',
        submitter_name_en='Verite Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャベリテ',
        address='横浜市神奈川区鶴屋町三丁目３３番８号',
        industry='小売業',
        sec_code='99040',
        corporate_number='3020001050312',
    ),
    'E03184': EdinetCodeEntry(
        edinet_code='E03184',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社関西フードマーケット',
        submitter_name_en='KANSAI FOOD MARKET LTD.',
        submitter_name_yomi='カブシキガイシャカンサイフードマーケット',
        address='伊丹市中央５丁目３番３８号',
        industry='小売業',
        sec_code=None,
        corporate_number='4140001078191',
    ),
    'E03186': EdinetCodeEntry(
        edinet_code='E03186',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワットマン',
        submitter_name_en='WATT MANN CO., LTD.',
        submitter_name_yomi='カブシキガイシャワットマン',
        address='横浜市旭区鶴ヶ峰本町１丁目２７番１３号',
        industry='小売業',
        sec_code='99270',
        corporate_number='4020001016394',
    ),
    'E03188': EdinetCodeEntry(
        edinet_code='E03188',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7491,
        fiscal_year_end='2月末日',
        submitter_name='ミニストップ株式会社',
        submitter_name_en='MINISTOP CO., LTD.',
        submitter_name_yomi='ミニストップカブシキガイシャ',
        address='千葉市美浜区中瀬１丁目５番地１',
        industry='小売業',
        sec_code='99460',
        corporate_number='4010001030181',
    ),
    'E03189': EdinetCodeEntry(
        edinet_code='E03189',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ドミー',
        submitter_name_en='DOMY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャドミー',
        address='岡崎市大平町字八ツ幡１番地１',
        industry='小売業',
        sec_code=None,
        corporate_number='5180301002689',
    ),
    'E03193': EdinetCodeEntry(
        edinet_code='E03193',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8166,
        fiscal_year_end='3月31日',
        submitter_name='株式会社王将フードサービス',
        submitter_name_en='OHSHO FOOD SERVICE CORP.',
        submitter_name_yomi='カブシキガイシャオウショウフードサービス',
        address='京都市山科区西野山射庭ノ上町２９４番地の１',
        industry='小売業',
        sec_code='99360',
        corporate_number='3130001012441',
    ),
    'E03196': EdinetCodeEntry(
        edinet_code='E03196',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ジョイフル',
        submitter_name_en='Joyfull Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャジョイフル',
        address='大分市三川新町１丁目１番４５号',
        industry='小売業',
        sec_code='99420',
        corporate_number='3320001001417',
    ),
    'E03197': EdinetCodeEntry(
        edinet_code='E03197',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3198,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ココスジャパン',
        submitter_name_en="coco's japan co.,ltd.",
        submitter_name_yomi='カブシキガイシャココスジャパン',
        address='港区港南二丁目１８番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='9010401054189',
    ),
    'E03199': EdinetCodeEntry(
        edinet_code='E03199',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アークス',
        submitter_name_en='ARCS COMPANY,LIMITED',
        submitter_name_yomi='カブシキガイシャ\u3000アークス',
        address='札幌市中央区南１３条西１１丁目２番３２号',
        industry='小売業',
        sec_code='99480',
        corporate_number='1430001018377',
    ),
    'E03200': EdinetCodeEntry(
        edinet_code='E03200',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3461,
        fiscal_year_end='2月末日',
        submitter_name='株式会社プレナス',
        submitter_name_en='PLENUS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャプレナス',
        address='福岡市博多区上牟田１丁目１９番２１号',
        industry='小売業',
        sec_code=None,
        corporate_number='2290001034974',
    ),
    'E03202': EdinetCodeEntry(
        edinet_code='E03202',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1518,
        fiscal_year_end='3月20日',
        submitter_name='株式会社ハチバン',
        submitter_name_en='HACHI-BAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハチバン',
        address='金沢市新神田一丁目１２番１８号',
        industry='小売業',
        sec_code='99500',
        corporate_number='4220001005352',
    ),
    'E03207': EdinetCodeEntry(
        edinet_code='E03207',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13609,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バローホールディングス',
        submitter_name_en='VALOR HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキカイシャバローホールディングス',
        address='恵那市大井町１８０番地の１',
        industry='小売業',
        sec_code='99560',
        corporate_number='5200001023784',
    ),
    'E03208': EdinetCodeEntry(
        edinet_code='E03208',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=798,
        fiscal_year_end='3月31日',
        submitter_name='アシードホールディングス株式会社',
        submitter_name_en='ASEED HOLDINGS CO.,LTD.',
        submitter_name_yomi='アシードホールディングスカブシキガイシャ',
        address='福山市船町７番２３号',
        industry='小売業',
        sec_code='99590',
        corporate_number='1240001029749',
    ),
    'E03211': EdinetCodeEntry(
        edinet_code='E03211',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='藤久株式会社',
        submitter_name_en='FUJIKYU CORPORATION',
        submitter_name_yomi='フジキュウカブシキガイシャ',
        address='名古屋市名東区高社一丁目２１０番地',
        industry='小売業',
        sec_code=None,
        corporate_number='5180001002849',
    ),
    'E03212': EdinetCodeEntry(
        edinet_code='E03212',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='7月31日',
        submitter_name='株式会社一や',
        submitter_name_en='ICHIYA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイチヤ',
        address='高知市帯屋町一丁目１０番１８号',
        industry='小売業',
        sec_code=None,
        corporate_number='7490001000142',
    ),
    'E03213': EdinetCodeEntry(
        edinet_code='E03213',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ショクブン',
        submitter_name_en='SHOKUBUN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャショクブン',
        address='名古屋市守山区向台三丁目１８０７番地',
        industry='小売業',
        sec_code='99690',
        corporate_number='5180001000563',
    ),
    'E03216': EdinetCodeEntry(
        edinet_code='E03216',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3912,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ベルク',
        submitter_name_en='Belc  CO., LTD.',
        submitter_name_yomi='カブシキガイシャベルク',
        address='鶴ヶ島市脚折１６４６番',
        industry='小売業',
        sec_code='99740',
        corporate_number='8030001085963',
    ),
    'E03217': EdinetCodeEntry(
        edinet_code='E03217',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10273,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ファーストリテイリング',
        submitter_name_en='FAST RETAILING CO., LTD.',
        submitter_name_yomi='カブシキガイシャファーストリテイリング',
        address='山口市佐山７１７番地１',
        industry='小売業',
        sec_code='99830',
        corporate_number='9250001000684',
    ),
    'E03219': EdinetCodeEntry(
        edinet_code='E03219',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2921,
        fiscal_year_end='2月20日',
        submitter_name='株式会社\u3000セキチュー',
        submitter_name_en='SEKICHU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000セキチュー',
        address='高崎市倉賀野町４５３１番地１号',
        industry='小売業',
        sec_code='99760',
        corporate_number='3070001008818',
    ),
    'E03220': EdinetCodeEntry(
        edinet_code='E03220',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アオキスーパー',
        submitter_name_en='Aoki Super Co., LTD.',
        submitter_name_yomi='カブシキガイシャアオキスーパー',
        address='名古屋市中村区鳥居西通一丁目１番地',
        industry='小売業',
        sec_code=None,
        corporate_number='1180001029202',
    ),
    'E03221': EdinetCodeEntry(
        edinet_code='E03221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='8月31日',
        submitter_name='株式会社文教堂グループホールディングス',
        submitter_name_en='BUNKYODO GROUP HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャブンキョウドウグループホールディングス',
        address='川崎市高津区久本３丁目１番２８号',
        industry='小売業',
        sec_code='99780',
        corporate_number='8020001066972',
    ),
    'E03223': EdinetCodeEntry(
        edinet_code='E03223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='株式会社大庄',
        submitter_name_en='DAISYO CORPORATION',
        submitter_name_yomi='カブシキガイシャダイショウ',
        address='大田区大森北一丁目２２番１号',
        industry='小売業',
        sec_code='99790',
        corporate_number='2010801006663',
    ),
    'E03225': EdinetCodeEntry(
        edinet_code='E03225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2986,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サックスバーホールディングス',
        submitter_name_en="SAC'S BAR HOLDINGS INC.",
        submitter_name_yomi='カブシキガイシャサックスバーホールディングス',
        address='葛飾区新小岩１丁目４８番１４号',
        industry='小売業',
        sec_code='99900',
        corporate_number='4011801003153',
    ),
    'E03226': EdinetCodeEntry(
        edinet_code='E03226',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3931,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンドラッグ',
        submitter_name_en='SUNDRUG CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンドラッグ',
        address='府中市若松町一丁目３８番地の１',
        industry='小売業',
        sec_code='99890',
        corporate_number='1012401000634',
    ),
    'E03227': EdinetCodeEntry(
        edinet_code='E03227',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3247,
        fiscal_year_end='3月31日',
        submitter_name='株式会社やまや',
        submitter_name_en='YAMAYA CORPORATION',
        submitter_name_yomi='カブシキガイシャヤマヤ',
        address='仙台市宮城野区榴岡三丁目４番１号',
        industry='小売業',
        sec_code='99940',
        corporate_number='5370001014536',
    ),
    'E03228': EdinetCodeEntry(
        edinet_code='E03228',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2388,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ヤマザワ',
        submitter_name_en='YAMAZAWA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヤマザワ',
        address='山形市あこや町三丁目８番９号',
        industry='小売業',
        sec_code='99930',
        corporate_number='9390001002171',
    ),
    'E03229': EdinetCodeEntry(
        edinet_code='E03229',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10612,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベルーナ',
        submitter_name_en='BELLUNA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャベルーナ',
        address='上尾市宮本町４番２号',
        industry='小売業',
        sec_code='99970',
        corporate_number='5030001041663',
    ),
    'E03231': EdinetCodeEntry(
        edinet_code='E03231',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アトム',
        submitter_name_en='ATOM CORPORATION',
        submitter_name_yomi='カブシキガイシャアトム',
        address='横浜市西区みなとみらい２－２－１\u3000ランドマークタワー１２Ｆ',
        industry='小売業',
        sec_code='74120',
        corporate_number='3180001058182',
    ),
    'E03233': EdinetCodeEntry(
        edinet_code='E03233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3991,
        fiscal_year_end='3月31日',
        submitter_name='株式会社はるやまホールディングス',
        submitter_name_en='Haruyama Holdings Inc.',
        submitter_name_yomi='カブシキガイシャハルヤマホールディングス',
        address='岡山市北区青江一丁目１７番２１号',
        industry='小売業',
        sec_code='74160',
        corporate_number='1260001005475',
    ),
    'E03235': EdinetCodeEntry(
        edinet_code='E03235',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5669,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ノジマ',
        submitter_name_en='Nojima Corporation',
        submitter_name_yomi='カブシキガイシャノジマ',
        address='相模原市中央区横山１－１－１',
        industry='小売業',
        sec_code='74190',
        corporate_number='4021001013588',
    ),
    'E03236': EdinetCodeEntry(
        edinet_code='E03236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='カッパ・クリエイト株式会社',
        submitter_name_en='KAPPA.CREATE CO.,LTD.',
        submitter_name_yomi='カッパクリエイトカブシキガイシャ',
        address='横浜市西区みなとみらい２－２－１',
        industry='小売業',
        sec_code='74210',
        corporate_number='7030001001979',
    ),
    'E03240': EdinetCodeEntry(
        edinet_code='E03240',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6195,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ライトオン',
        submitter_name_en='RIGHT ON Co.,Ltd',
        submitter_name_yomi='カブシキガイシャライトオン',
        address='つくば市小野崎２６０－１',
        industry='小売業',
        sec_code='74450',
        corporate_number='9050001016214',
    ),
    'E03244': EdinetCodeEntry(
        edinet_code='E03244',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2338,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジーンズメイト',
        submitter_name_en='JEANS MATE CORPORATION',
        submitter_name_yomi='カブシキガイシャジーンズメイト',
        address='渋谷区富ヶ谷１丁目４９番４号',
        industry='小売業',
        sec_code=None,
        corporate_number='1011001010440',
    ),
    'E03245': EdinetCodeEntry(
        edinet_code='E03245',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3243,
        fiscal_year_end='2月末日',
        submitter_name='株式会社サンデー',
        submitter_name_en='SUNDAY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンデー',
        address='八戸市根城六丁目２２番１０号',
        industry='小売業',
        sec_code='74500',
        corporate_number='3420001005928',
    ),
    'E03247': EdinetCodeEntry(
        edinet_code='E03247',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2852,
        fiscal_year_end=None,
        submitter_name='株式会社キタムラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキタムラ',
        address='高知市本町４丁目１番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3490001000435',
    ),
    'E03248': EdinetCodeEntry(
        edinet_code='E03248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6766,
        fiscal_year_end='8月末日',
        submitter_name='株式会社\u3000良品計画',
        submitter_name_en='RYOHIN KEIKAKU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000リョウヒンケイカク',
        address='文京区後楽２丁目５番１号住友不動産飯田橋ファーストビル',
        industry='小売業',
        sec_code='74530',
        corporate_number='5013301012443',
    ),
    'E03249': EdinetCodeEntry(
        edinet_code='E03249',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5901,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パリミキホールディングス',
        submitter_name_en='PARIS MIKI HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャパリミキホールディングス',
        address='中央区日本橋室町二丁目４番３号',
        industry='小売業',
        sec_code='74550',
        corporate_number='4010001044198',
    ),
    'E03250': EdinetCodeEntry(
        edinet_code='E03250',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1176,
        fiscal_year_end='2月末日',
        submitter_name='マックスバリュ北海道株式会社',
        submitter_name_en='MAXVALU HOKKAIDO Co,Ltd.',
        submitter_name_yomi='マックスバリュホッカイドウカブシキガイシャ',
        address='札幌市中央区北８条西２１丁目１番１０号',
        industry='小売業',
        sec_code=None,
        corporate_number='1430001020267',
    ),
    'E03251': EdinetCodeEntry(
        edinet_code='E03251',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=886,
        fiscal_year_end='3月31日',
        submitter_name='セフテック株式会社',
        submitter_name_en='SAFTEC CO.,LTD.',
        submitter_name_yomi='セフテックカブシキガイシャ',
        address='文京区本郷五丁目２５番１４号',
        industry='卸売業',
        sec_code='74640',
        corporate_number='7010001004224',
    ),
    'E03252': EdinetCodeEntry(
        edinet_code='E03252',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＣＡＰＩＴＡ',
        submitter_name_en='CAPITA Inc.',
        submitter_name_yomi='カブシキガイシャキャピタ',
        address='豊島区巣鴨１丁目１１番１号',
        industry='小売業',
        sec_code='74620',
        corporate_number='6010001141167',
    ),
    'E03259': EdinetCodeEntry(
        edinet_code='E03259',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5305,
        fiscal_year_end='9月30日',
        submitter_name='株式会社コナカ',
        submitter_name_en='KONAKA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャコナカ',
        address='横浜市戸塚区品濃町５１７番地２',
        industry='小売業',
        sec_code='74940',
        corporate_number='4020001007344',
    ),
    'E03264': EdinetCodeEntry(
        edinet_code='E03264',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1083,
        fiscal_year_end='9月30日',
        submitter_name='扶桑電通株式会社',
        submitter_name_en='FUSO DENTSU CO., LTD.',
        submitter_name_yomi='フソウデンツウカブシキガイシャ',
        address='中央区築地五丁目４番１８号',
        industry='卸売業',
        sec_code='75050',
        corporate_number='6010001055706',
    ),
    'E03266': EdinetCodeEntry(
        edinet_code='E03266',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=934,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ハウス\u3000オブ\u3000ローゼ',
        submitter_name_en='HOUSE OF ROSE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ハウス\u3000オブ\u3000ローゼ',
        address='港区赤坂二丁目２１番７号',
        industry='小売業',
        sec_code='75060',
        corporate_number='6010401023758',
    ),
    'E03267': EdinetCodeEntry(
        edinet_code='E03267',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1791,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｇ‐７ホールディングス',
        submitter_name_en='G-7 HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャジーセブンホールディングス',
        address='神戸市須磨区弥栄台２丁目１番地の３',
        industry='小売業',
        sec_code='75080',
        corporate_number='9140001017351',
    ),
    'E03268': EdinetCodeEntry(
        edinet_code='E03268',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6100,
        fiscal_year_end='2月末日',
        submitter_name='イオン北海道株式会社',
        submitter_name_en='Aeon Hokkaido Corporation',
        submitter_name_yomi='イオンホッカイドウカブシキガイシャ',
        address='札幌市白石区本通２１丁目南１番１０号',
        industry='小売業',
        sec_code='75120',
        corporate_number='4430001015958',
    ),
    'E03269': EdinetCodeEntry(
        edinet_code='E03269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1314,
        fiscal_year_end='3月31日',
        submitter_name='アイエーグループ株式会社',
        submitter_name_en='i.a groupcorporation',
        submitter_name_yomi='アイエーグループカブシキガイシャ',
        address='横浜市戸塚区品濃町５４５－５',
        industry='小売業',
        sec_code='75090',
        corporate_number='9020001007018',
    ),
    'E03270': EdinetCodeEntry(
        edinet_code='E03270',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25975,
        fiscal_year_end='8月31日',
        submitter_name='株式会社コジマ',
        submitter_name_en='Kojima Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコジマ',
        address='宇都宮市星が丘２丁目１番８号',
        industry='小売業',
        sec_code='75130',
        corporate_number='2060001001667',
    ),
    'E03271': EdinetCodeEntry(
        edinet_code='E03271',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2544,
        fiscal_year_end='8月31日',
        submitter_name='株式会社\u3000ヒマラヤ',
        submitter_name_en='HIMARAYA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヒマラヤ',
        address='岐阜市江添１丁目１番１号',
        industry='小売業',
        sec_code='75140',
        corporate_number='9200001004384',
    ),
    'E03272': EdinetCodeEntry(
        edinet_code='E03272',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1077,
        fiscal_year_end='2月末日',
        submitter_name='株式会社マルヨシセンター',
        submitter_name_en='Maruyoshi Center Inc.',
        submitter_name_yomi='カブシキガイシャマルヨシセンター',
        address='高松市国分寺町国分３６７番地１',
        industry='小売業',
        sec_code='75150',
        corporate_number='3470001003902',
    ),
    'E03273': EdinetCodeEntry(
        edinet_code='E03273',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17658,
        fiscal_year_end='2月末日',
        submitter_name='コーナン商事株式会社',
        submitter_name_en='KOHNAN SHOJI CO.,LTD.',
        submitter_name_yomi='コーナンショウジカブシキガイシャ',
        address='堺市西区鳳東町４丁４０１番地１',
        industry='小売業',
        sec_code='75160',
        corporate_number='3120101003135',
    ),
    'E03274': EdinetCodeEntry(
        edinet_code='E03274',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3318,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エコス',
        submitter_name_en="eco's co.,ltd",
        submitter_name_yomi='カブシキガイシャエコス',
        address='昭島市中神町１１６０番地１',
        industry='小売業',
        sec_code='75200',
        corporate_number='8012801001936',
    ),
    'E03275': EdinetCodeEntry(
        edinet_code='E03275',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4910,
        fiscal_year_end='3月31日',
        submitter_name='ワタミ株式会社',
        submitter_name_en='WATAMI  CO.,LTD.',
        submitter_name_yomi='ワタミカブシキガイシャ',
        address='大田区羽田一丁目１番３号',
        industry='小売業',
        sec_code='75220',
        corporate_number='4010801012908',
    ),
    'E03276': EdinetCodeEntry(
        edinet_code='E03276',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1770,
        fiscal_year_end='3月31日',
        submitter_name='アールビバン株式会社',
        submitter_name_en='ART VIVANT CO.,LTD.',
        submitter_name_yomi='アールビバンカブシキガイシャ',
        address='品川区東品川四丁目１３番１４号',
        industry='小売業',
        sec_code='75230',
        corporate_number='7010701024331',
    ),
    'E03278': EdinetCodeEntry(
        edinet_code='E03278',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1510,
        fiscal_year_end='3月31日',
        submitter_name='マルシェ株式会社',
        submitter_name_en='MARCHE CORPORATION',
        submitter_name_yomi='マルシェカブシキガイシャ',
        address='大阪市阿倍野区阪南町２丁目２０番１４号',
        industry='小売業',
        sec_code='75240',
        corporate_number='2120001013697',
    ),
    'E03279': EdinetCodeEntry(
        edinet_code='E03279',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=697,
        fiscal_year_end='4月30日',
        submitter_name='株式会社グリーンクロス',
        submitter_name_en='GREEN CROSS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャグリーンクロス',
        address='福岡市中央区小笹五丁目２２番３４号',
        industry='卸売業',
        sec_code=None,
        corporate_number='5290001017679',
    ),
    'E03280': EdinetCodeEntry(
        edinet_code='E03280',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23689,
        fiscal_year_end='6月30日',
        submitter_name='株式会社パン・パシフィック・インターナショナルホールディングス',
        submitter_name_en='Pan Pacific International Holdings Corporation',
        submitter_name_yomi='カブシキガイシャパンパシフィックインターナショナルホールディングス',
        address='渋谷区道玄坂二丁目２５番１２号',
        industry='小売業',
        sec_code='75320',
        corporate_number='7013201016303',
    ),
    'E03281': EdinetCodeEntry(
        edinet_code='E03281',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1571,
        fiscal_year_end='3月31日',
        submitter_name='エステールホールディングス株式会社',
        submitter_name_en='ESTELLE HOLDINGS CO.,LTD.',
        submitter_name_yomi='エステールホールディングスカブシキガイシャ',
        address='中央区銀座一丁目１９番７号',
        industry='その他製品',
        sec_code='78720',
        corporate_number='7010401094724',
    ),
    'E03283': EdinetCodeEntry(
        edinet_code='E03283',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1265,
        fiscal_year_end='4月末日',
        submitter_name='株式会社柿安本店',
        submitter_name_en='Kakiyasu Honten Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャカキヤスホンテン',
        address='桑名市吉之丸８番地',
        industry='食料品',
        sec_code='22940',
        corporate_number='7190001012102',
    ),
    'E03286': EdinetCodeEntry(
        edinet_code='E03286',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社スリーエフ',
        submitter_name_en='Three F Co., Ltd.',
        submitter_name_yomi='カブシキガイシャスリーエフ',
        address='横浜市中区日本大通１７番地',
        industry='小売業',
        sec_code='75440',
        corporate_number='5020001027135',
    ),
    'E03287': EdinetCodeEntry(
        edinet_code='E03287',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2523,
        fiscal_year_end='2月20日',
        submitter_name='株式会社西松屋チェーン',
        submitter_name_en='NISHIMATSUYA CHAIN Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニシマツヤチェーン',
        address='姫路市飾東町庄２６６番地の１',
        industry='小売業',
        sec_code='75450',
        corporate_number='6140001060486',
    ),
    'E03289': EdinetCodeEntry(
        edinet_code='E03289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=681,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中京医薬品',
        submitter_name_en='CHUKYOIYAKUHIN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャチュウキョウイヤクヒン',
        address='半田市亀崎北浦町２丁目１５番地の１',
        industry='医薬品',
        sec_code='45580',
        corporate_number='2180001091837',
    ),
    'E03291': EdinetCodeEntry(
        edinet_code='E03291',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=47497,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゼンショーホールディングス',
        submitter_name_en='ZENSHO HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャゼンショーホールディングス',
        address='港区港南二丁目１８番１号',
        industry='小売業',
        sec_code='75500',
        corporate_number='2010401045277',
    ),
    'E03293': EdinetCodeEntry(
        edinet_code='E03293',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4988,
        fiscal_year_end='3月31日',
        submitter_name='株式会社幸楽苑',
        submitter_name_en='KOURAKUEN CORPORATION',
        submitter_name_yomi='カブシキガイシャコウラクエン',
        address='郡山市田村町上行合字北川田２番地１',
        industry='小売業',
        sec_code='75540',
        corporate_number='2380001005074',
    ),
    'E03294': EdinetCodeEntry(
        edinet_code='E03294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4036,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハークスレイ',
        submitter_name_en='HURXLEY CORPORATION',
        submitter_name_yomi='カブシキガイシャハークスレイ',
        address='大阪市北区鶴野町３番１０号',
        industry='小売業',
        sec_code='75610',
        corporate_number='4120001036085',
    ),
    'E03295': EdinetCodeEntry(
        edinet_code='E03295',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3182,
        fiscal_year_end='3月31日',
        submitter_name='株式会社安楽亭',
        submitter_name_en='ANRAKUTEI Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアンラクテイ',
        address='さいたま市中央区上落合二丁目３番５号',
        industry='小売業',
        sec_code='75620',
        corporate_number='9030001000302',
    ),
    'E03296': EdinetCodeEntry(
        edinet_code='E03296',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1622,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワークマン',
        submitter_name_en='WORKMAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャワークマン',
        address='伊勢崎市柴町１７３２番地',
        industry='小売業',
        sec_code='75640',
        corporate_number='1070001013828',
    ),
    'E03299': EdinetCodeEntry(
        edinet_code='E03299',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤマノホールディングス',
        submitter_name_en='YAMANO HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキカイシャヤマノホールディングス',
        address='渋谷区代々木一丁目３０番７号',
        industry='小売業',
        sec_code='75710',
        corporate_number='4011001030931',
    ),
    'E03301': EdinetCodeEntry(
        edinet_code='E03301',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＨＡＰｉＮＳ',
        submitter_name_en='HAPiNS Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャハピンズ',
        address='品川区西五反田７丁目２２番１７号',
        industry='小売業',
        sec_code=None,
        corporate_number='2010701008058',
    ),
    'E03302': EdinetCodeEntry(
        edinet_code='E03302',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='オリジン東秀株式会社',
        submitter_name_en='ORIGIN TOSHU CO.,Ltd',
        submitter_name_yomi='オリジントウシュウカブシキガイシャ',
        address='調布市調布ヶ丘一丁目１８番地１\u3000ＫＤＸ調布ビル５階',
        industry='小売業',
        sec_code=None,
        corporate_number='3012401007462',
    ),
    'E03304': EdinetCodeEntry(
        edinet_code='E03304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1865,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニチリョク',
        submitter_name_en='NICHIRYOKU CO., LTD.',
        submitter_name_yomi='カブシキガイシャニチリョク',
        address='中央区八重洲一丁目７番２０号',
        industry='小売業',
        sec_code='75780',
        corporate_number='4011301005583',
    ),
    'E03305': EdinetCodeEntry(
        edinet_code='E03305',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8612,
        fiscal_year_end='8月31日',
        submitter_name='株式会社サイゼリヤ',
        submitter_name_en='saizeriya co.,ltd.',
        submitter_name_yomi='カブシキガイシャサイゼリヤ',
        address='吉川市旭２番地５',
        industry='小売業',
        sec_code='75810',
        corporate_number='8030001065552',
    ),
    'E03306': EdinetCodeEntry(
        edinet_code='E03306',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=275,
        fiscal_year_end='6月30日',
        submitter_name='株式会社かんなん丸',
        submitter_name_en='KAN-NANMARU CORPORATION',
        submitter_name_yomi='カブシキガイシャカンナンマル',
        address='さいたま市南区南浦和二丁目１８番５号',
        industry='小売業',
        sec_code='75850',
        corporate_number='6030001001831',
    ),
    'E03310': EdinetCodeEntry(
        edinet_code='E03310',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1563,
        fiscal_year_end='3月31日',
        submitter_name='株式会社魚力',
        submitter_name_en='UORIKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャウオリキ',
        address='立川市曙町二丁目８番３号',
        industry='小売業',
        sec_code='75960',
        corporate_number='4010101000456',
    ),
    'E03312': EdinetCodeEntry(
        edinet_code='E03312',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ポプラ',
        submitter_name_en='POPLAR Co., Ltd.',
        submitter_name_yomi='カブシキガイシャポプラ',
        address='広島市安佐北区安佐町大字久地６６５番地の１',
        industry='小売業',
        sec_code='76010',
        corporate_number='9240001010841',
    ),
    'E03313': EdinetCodeEntry(
        edinet_code='E03313',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=221,
        fiscal_year_end='2月末日',
        submitter_name='ジーイエット株式会社',
        submitter_name_en='Gyet Co., Ltd.',
        submitter_name_yomi='ジーイエットカブシキガイシャ',
        address='杉並区梅里一丁目７番７号',
        industry='小売業',
        sec_code='76030',
        corporate_number='4011301006656',
    ),
    'E03314': EdinetCodeEntry(
        edinet_code='E03314',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='4月30日',
        submitter_name='株式会社\u3000梅の花グループ',
        submitter_name_en='UMENOHANA GROUP CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ウメノハナグループ',
        address='久留米市天神町１４６番地',
        industry='小売業',
        sec_code='76040',
        corporate_number='5290001048435',
    ),
    'E03315': EdinetCodeEntry(
        edinet_code='E03315',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1236,
        fiscal_year_end='10月31日',
        submitter_name='株式会社\u3000フジ・コーポレーション',
        submitter_name_en='FUJI  CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000フジコーポレーション',
        address='富谷市成田一丁目２番２号',
        industry='小売業',
        sec_code=None,
        corporate_number='6370001017612',
    ),
    'E03316': EdinetCodeEntry(
        edinet_code='E03316',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3030,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユナイテッドアローズ',
        submitter_name_en='UNITED ARROWS LTD.',
        submitter_name_yomi='カブシキガイシャユナイテッドアローズ',
        address='渋谷区神宮前三丁目２８番１号',
        industry='小売業',
        sec_code='76060',
        corporate_number='1011001028441',
    ),
    'E03317': EdinetCodeEntry(
        edinet_code='E03317',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=466,
        fiscal_year_end='1月31日',
        submitter_name='株式会社オーエムツーネットワーク',
        submitter_name_en='OM2 Network Co.,Ltd',
        submitter_name_yomi='カブシキガイシャオーエムツーネットワーク',
        address='港区芝大門２丁目４番７号',
        industry='小売業',
        sec_code='76140',
        corporate_number='5010401041686',
    ),
    'E03318': EdinetCodeEntry(
        edinet_code='E03318',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1625,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ハイデイ日高',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハイデイヒダカ',
        address='さいたま市大宮区大門町二丁目１１８番地',
        industry='小売業',
        sec_code='76110',
        corporate_number='1030001006892',
    ),
    'E03319': EdinetCodeEntry(
        edinet_code='E03319',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社テイツー',
        submitter_name_en='TAY TWO CO.,LTD',
        submitter_name_yomi='カブシキガイシャテイツー',
        address='岡山市南区豊浜町２番２号（同所は登記上の本社所在地であり、実際の業務は下記にて行っております。）',
        industry='小売業',
        sec_code='76100',
        corporate_number='7260001004488',
    ),
    'E03320': EdinetCodeEntry(
        edinet_code='E03320',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=196,
        fiscal_year_end='3月31日',
        submitter_name='株式会社京都きもの友禅ホールディングス',
        submitter_name_en='KYOTO KIMONO YUZEN HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャキョウトキモノユウゼンホールディングス',
        address='中央区日本橋大伝馬町１４番１号',
        industry='小売業',
        sec_code='76150',
        corporate_number='7010001040938',
    ),
    'E03321': EdinetCodeEntry(
        edinet_code='E03321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27905,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000コロワイド',
        submitter_name_en='COLOWIDE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000コロワイド',
        address='横浜市西区みなとみらい二丁目２番１号\u3000ランドマークタワー１２階',
        industry='小売業',
        sec_code='76160',
        corporate_number='8020001040291',
    ),
    'E03323': EdinetCodeEntry(
        edinet_code='E03323',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4737,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ピーシーデポコーポレーション',
        submitter_name_en='PC DEPOT CORPORATION',
        submitter_name_yomi='カブシキガイシャピーシーデポコーポレーション',
        address='横浜市西区高島１丁目２番５号',
        industry='小売業',
        sec_code=None,
        corporate_number='3020001032707',
    ),
    'E03324': EdinetCodeEntry(
        edinet_code='E03324',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1291,
        fiscal_year_end='3月31日',
        submitter_name='株式会社うかい',
        submitter_name_en='UKAI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャウカイ',
        address='八王子市南浅川町３４２６番地',
        industry='小売業',
        sec_code='76210',
        corporate_number='6010101000462',
    ),
    'E03326': EdinetCodeEntry(
        edinet_code='E03326',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=411,
        fiscal_year_end='4月30日',
        submitter_name='株式会社サンオータス',
        submitter_name_en='SUNAUTAS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンオータス',
        address='横浜市港北区新横浜二丁目４番１５号',
        industry='小売業',
        sec_code=None,
        corporate_number='4020001020256',
    ),
    'E03327': EdinetCodeEntry(
        edinet_code='E03327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=43,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グローバルダイニング',
        submitter_name_en='GLOBAL-DINING,INC.',
        submitter_name_yomi='カブシキガイシャグローバルダイニング',
        address='港区南青山七丁目１番５号',
        industry='小売業',
        sec_code='76250',
        corporate_number='6010401005715',
    ),
    'E03329': EdinetCodeEntry(
        edinet_code='E03329',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1503,
        fiscal_year_end='2月28日',
        submitter_name='株式会社壱番屋',
        submitter_name_en='ICHIBANYA CO.,LTD.',
        submitter_name_yomi='カブシキカイシャイチバンヤ',
        address='一宮市三ツ井六丁目１２番２３号',
        industry='小売業',
        sec_code='76300',
        corporate_number='4180001082132',
    ),
    'E03330': EdinetCodeEntry(
        edinet_code='E03330',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=436,
        fiscal_year_end='3月31日',
        submitter_name='株式会社星医療酸器',
        submitter_name_en='HOSHIIRYO-SANKI CO., LTD.',
        submitter_name_yomi='カブシキガイシャホシイリョウサンキ',
        address='足立区入谷七丁目１１番１８号',
        industry='卸売業',
        sec_code='76340',
        corporate_number='2011801011868',
    ),
    'E03331': EdinetCodeEntry(
        edinet_code='E03331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1057,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ハンズマン',
        submitter_name_en='HANDSMAN CO., LTD.',
        submitter_name_yomi='カブシキカイシャハンズマン',
        address='都城市吉尾町２０８０番地',
        industry='小売業',
        sec_code='76360',
        corporate_number='9350001008222',
    ),
    'E03332': EdinetCodeEntry(
        edinet_code='E03332',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='白銅株式会社',
        submitter_name_en='Hakudo Co.,Ltd.',
        submitter_name_yomi='ハクドウカブシキガイシャ',
        address='千代田区丸の内二丁目５番２号',
        industry='卸売業',
        sec_code='76370',
        corporate_number='2010001054158',
    ),
    'E03333': EdinetCodeEntry(
        edinet_code='E03333',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2617,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＥＷ\u3000ＡＲＴ\u3000ＨＯＬＤＩＮＧＳ',
        submitter_name_en='NEW ART HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニューアートホールディングス',
        address='中央区銀座２丁目６番３号',
        industry='小売業',
        sec_code='76380',
        corporate_number='9010001046693',
    ),
    'E03336': EdinetCodeEntry(
        edinet_code='E03336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2007,
        fiscal_year_end='10月31日',
        submitter_name='株式会社トップカルチャー',
        submitter_name_en='TOP CULTURE Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャトップカルチャー',
        address='新潟市西区小針４丁目９番１号',
        industry='小売業',
        sec_code='76400',
        corporate_number='1110001003592',
    ),
    'E03340': EdinetCodeEntry(
        edinet_code='E03340',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1639,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ダイイチ',
        submitter_name_en='DAIICHI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイイチ',
        address='帯広市西２０条南１丁目１４番地４７',
        industry='小売業',
        sec_code='76430',
        corporate_number='6460101000896',
    ),
    'E03342': EdinetCodeEntry(
        edinet_code='E03342',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1148,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ベルパーク',
        submitter_name_en='Bell-Park Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャベルパーク',
        address='千代田区平河町１丁目４番１２号',
        industry='情報・通信業',
        sec_code='94410',
        corporate_number='7010001028883',
    ),
    'E03343': EdinetCodeEntry(
        edinet_code='E03343',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1425,
        fiscal_year_end='9月20日',
        submitter_name='株式会社ＰＬＡＮＴ',
        submitter_name_en='PLANT Co.,Ltd',
        submitter_name_yomi='カブシキガイシャプラント',
        address='坂井市坂井町下新庄１５号８番地の１',
        industry='小売業',
        sec_code='76460',
        corporate_number='5210001007068',
    ),
    'E03344': EdinetCodeEntry(
        edinet_code='E03344',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15434,
        fiscal_year_end='2月末日',
        submitter_name='スギホールディングス株式会社',
        submitter_name_en='SUGI HOLDINGS CO.,LTD.',
        submitter_name_yomi='スギホールディングスカブシキガイシャ',
        address='安城市三河安城町一丁目８番地４',
        industry='小売業',
        sec_code='76490',
        corporate_number='9180301013006',
    ),
    'E03345': EdinetCodeEntry(
        edinet_code='E03345',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=58506,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ローソン',
        submitter_name_en='Lawson,Inc.',
        submitter_name_yomi='カブシキガイシャローソン',
        address='品川区大崎１丁目１１番２号',
        industry='小売業',
        sec_code=None,
        corporate_number='2010701019195',
    ),
    'E03346': EdinetCodeEntry(
        edinet_code='E03346',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ぷらっとホーム株式会社',
        submitter_name_en="PLAT'HOME CO.,LTD.",
        submitter_name_yomi='プラットホームカブシキガイシャ',
        address='千代田区九段北四丁目１番３号',
        industry='電気機器',
        sec_code='68360',
        corporate_number='9010001028709',
    ),
    'E03347': EdinetCodeEntry(
        edinet_code='E03347',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=837,
        fiscal_year_end='9月30日',
        submitter_name='株式会社まんだらけ',
        submitter_name_en='MANDARAKE INC.',
        submitter_name_yomi='カブシキガイシャマンダラケ',
        address='中野区中野５丁目５２番１５号',
        industry='小売業',
        sec_code='26520',
        corporate_number='4011201005139',
    ),
    'E03348': EdinetCodeEntry(
        edinet_code='E03348',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3716,
        fiscal_year_end='2月末日',
        submitter_name='イオン東北株式会社',
        submitter_name_en='AEON TOHOKU CO., LTD.',
        submitter_name_yomi='イオントウホクカブシキガイシャ',
        address='秋田市土崎港北一丁目６番２５号',
        industry='小売業',
        sec_code=None,
        corporate_number='5410001001901',
    ),
    'E03349': EdinetCodeEntry(
        edinet_code='E03349',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4915,
        fiscal_year_end='2月末日',
        submitter_name='イオン九州株式会社',
        submitter_name_en='AEON KYUSHU CO., LTD.',
        submitter_name_yomi='イオンキュウシュウカブシキガイシャ',
        address='福岡市東区香椎浜二丁目８番３０号',
        industry='小売業',
        sec_code='26530',
        corporate_number='6290001017604',
    ),
    'E03350': EdinetCodeEntry(
        edinet_code='E03350',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=894,
        fiscal_year_end='2月20日',
        submitter_name='株式会社ダイユーエイト',
        submitter_name_en='DAIYU EIGHT CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイユーエイト',
        address='福島市太平寺字堰ノ上５８番地',
        industry='小売業',
        sec_code=None,
        corporate_number='9380001000795',
    ),
    'E03351': EdinetCodeEntry(
        edinet_code='E03351',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=282,
        fiscal_year_end=None,
        submitter_name='株式会社Ｋ－ＧＯＬＤインターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ケイゴールドインターナショナル',
        address='浜松市中区西丘町２７６番地の５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080401001356',
    ),
    'E03352': EdinetCodeEntry(
        edinet_code='E03352',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3723,
        fiscal_year_end='2月末日',
        submitter_name='株式会社サンエー',
        submitter_name_en='SAN-A CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンエー',
        address='宜野湾市大山七丁目２番１０号',
        industry='小売業',
        sec_code='26590',
        corporate_number='5360001008803',
    ),
    'E03355': EdinetCodeEntry(
        edinet_code='E03355',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000オートウェーブ',
        submitter_name_en='AUTOWAVE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000\u3000オートウェーブ',
        address='千葉市稲毛区宮野木町１８５０番地',
        industry='小売業',
        sec_code='26660',
        corporate_number='4040001001139',
    ),
    'E03356': EdinetCodeEntry(
        edinet_code='E03356',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13001,
        fiscal_year_end='3月15日',
        submitter_name='株式会社カワチ薬品',
        submitter_name_en='CAWACHI LIMITED',
        submitter_name_yomi='カブシキガイシャカワチヤクヒン',
        address='小山市大字卒島１２９３番地',
        industry='小売業',
        sec_code='26640',
        corporate_number='3060001014164',
    ),
    'E03358': EdinetCodeEntry(
        edinet_code='E03358',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2002,
        fiscal_year_end='2月末日',
        submitter_name='カネ美食品株式会社',
        submitter_name_en='Kanemi Co.,Ltd.',
        submitter_name_yomi='カネミショクヒンカブシキガイシャ',
        address='名古屋市緑区徳重三丁目１０７番地',
        industry='小売業',
        sec_code='26690',
        corporate_number='1180001023411',
    ),
    'E03359': EdinetCodeEntry(
        edinet_code='E03359',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1741,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ダイナックホールディングス',
        submitter_name_en='DYNAC HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャダイナックホールディングス',
        address='新宿区新宿一丁目８番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='7011101012050',
    ),
    'E03360': EdinetCodeEntry(
        edinet_code='E03360',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=534,
        fiscal_year_end='3月31日',
        submitter_name='夢みつけ隊株式会社',
        submitter_name_en='YUMEMITSUKETAI Co., Ltd.',
        submitter_name_yomi='ユメミツケタイカブシキガイシャ',
        address='千代田区神田東松下町１７番地',
        industry='小売業',
        sec_code='26730',
        corporate_number='8011101037559',
    ),
    'E03361': EdinetCodeEntry(
        edinet_code='E03361',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1676,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハードオフコーポレーション',
        submitter_name_en='HARD OFF CORPORATION Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ハードオフコーポレーション',
        address='新発田市新栄町３丁目１番１３号',
        industry='小売業',
        sec_code='26740',
        corporate_number='6110001012853',
    ),
    'E03362': EdinetCodeEntry(
        edinet_code='E03362',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2868,
        fiscal_year_end='3月20日',
        submitter_name='オーケー株式会社',
        submitter_name_en='OK Corporation',
        submitter_name_yomi='オーケーカブシキガイシャ',
        address='横浜市西区みなとみらい六丁目３番６号',
        industry='小売業',
        sec_code=None,
        corporate_number='6010801001974',
    ),
    'E03363': EdinetCodeEntry(
        edinet_code='E03363',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21223,
        fiscal_year_end='5月20日',
        submitter_name='アスクル株式会社',
        submitter_name_en='ASKUL Corporation',
        submitter_name_yomi='アスクルカブシキガイシャ',
        address='江東区豊洲三丁目２番３号',
        industry='小売業',
        sec_code='26780',
        corporate_number='5010601030357',
    ),
    'E03365': EdinetCodeEntry(
        edinet_code='E03365',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社魚喜',
        submitter_name_en='UOKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャウオキ',
        address='藤沢市湘南台２丁目１０番地５',
        industry='小売業',
        sec_code='26830',
        corporate_number='7021001002448',
    ),
    'E03366': EdinetCodeEntry(
        edinet_code='E03366',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24113,
        fiscal_year_end='12月31日',
        submitter_name='日本マクドナルドホールディングス株式会社',
        submitter_name_en="McDonald's Holdings Company(Japan),Ltd.",
        submitter_name_yomi='ニホンマクドナルドホールディングスカブシキガイシャ',
        address='新宿区西新宿六丁目５番１号',
        industry='小売業',
        sec_code='27020',
        corporate_number='8011101029028',
    ),
    'E03367': EdinetCodeEntry(
        edinet_code='E03367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9033,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゲオホールディングス',
        submitter_name_en='GEO HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャゲオホールディングス',
        address='名古屋市中区富士見町８番８号',
        industry='小売業',
        sec_code='26810',
        corporate_number='7180001074052',
    ),
    'E03368': EdinetCodeEntry(
        edinet_code='E03368',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2660,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アンドエスティＨＤ',
        submitter_name_en='and ST HD Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアンドエスティホールディングス',
        address='水戸市泉町三丁目１番２７号',
        industry='小売業',
        sec_code='26850',
        corporate_number='1050001002254',
    ),
    'E03369': EdinetCodeEntry(
        edinet_code='E03369',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2747,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジパング',
        submitter_name_en='Jipangu Inc.',
        submitter_name_yomi='カブシキガイシャジパング',
        address='渋谷区広尾一丁目１１番２号',
        industry='鉱業',
        sec_code=None,
        corporate_number='8011001070123',
    ),
    'E03370': EdinetCodeEntry(
        edinet_code='E03370',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3763,
        fiscal_year_end='2月28日',
        submitter_name='株式会社ジーフット',
        submitter_name_en='GFOOT CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジーフット',
        address='中央区新川一丁目１４番１号',
        industry='小売業',
        sec_code='26860',
        corporate_number='1180001004741',
    ),
    'E03372': EdinetCodeEntry(
        edinet_code='E03372',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1200,
        fiscal_year_end='2月末日',
        submitter_name='株式会社シー・ヴイ・エス・ベイエリア',
        submitter_name_en='CVS Bay Area Inc.',
        submitter_name_yomi='カブシキガイシャシーヴイエスベイエリア',
        address='市川市塩浜二丁目３３番１号',
        industry='小売業',
        sec_code='26870',
        corporate_number='6040001029566',
    ),
    'E03374': EdinetCodeEntry(
        edinet_code='E03374',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社焼肉坂井ホールディングス',
        submitter_name_en='Yakiniku Sakai Holdings Inc.',
        submitter_name_yomi='カブシキガイシャヤキニクサカイホールディングス',
        address='名古屋市北区黒川本通二丁目４６番地',
        industry='小売業',
        sec_code='26940',
        corporate_number='2370001010224',
    ),
    'E03375': EdinetCodeEntry(
        edinet_code='E03375',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2005,
        fiscal_year_end='10月31日',
        submitter_name='くら寿司株式会社',
        submitter_name_en='Kura Sushi,Inc.',
        submitter_name_yomi='クラズシカブシキガイシャ',
        address='堺市中区深阪１丁２番２号',
        industry='小売業',
        sec_code='26950',
        corporate_number='4120101002846',
    ),
    'E03377': EdinetCodeEntry(
        edinet_code='E03377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3028,
        fiscal_year_end='2月末日',
        submitter_name='株式会社キャンドゥ',
        submitter_name_en='CANDOCO.,LTD.',
        submitter_name_yomi='カブシキガイシャキャンドゥ',
        address='新宿区北新宿二丁目２１番１号',
        industry='小売業',
        sec_code='26980',
        corporate_number='6011101063012',
    ),
    'E03379': EdinetCodeEntry(
        edinet_code='E03379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6410,
        fiscal_year_end='3月31日',
        submitter_name='ぴあ株式会社',
        submitter_name_en='PIA CORPORATION',
        submitter_name_yomi='ピアカブシキガイシャ',
        address='渋谷区東一丁目２番２０号',
        industry='サービス業',
        sec_code='43370',
        corporate_number='1011001069980',
    ),
    'E03380': EdinetCodeEntry(
        edinet_code='E03380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2029,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大戸屋ホールディングス',
        submitter_name_en='OOTOYA Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャオオトヤホールディングス',
        address='横浜市西区北幸一丁目１番８号',
        industry='小売業',
        sec_code='27050',
        corporate_number='9012401020674',
    ),
    'E03386': EdinetCodeEntry(
        edinet_code='E03386',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=620,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ＩＫホールディングス',
        submitter_name_en='IK HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアイケイホールディングス',
        address='名古屋市中村区上米野町四丁目２０番地',
        industry='小売業',
        sec_code='27220',
        corporate_number='1180001029144',
    ),
    'E03387': EdinetCodeEntry(
        edinet_code='E03387',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3181,
        fiscal_year_end='2月末日',
        submitter_name='株式会社パルグループホールディングス',
        submitter_name_en='PAL GROUP Holdings CO.,LTD.',
        submitter_name_yomi='カブシキガイシャパルグループホールディングス',
        address='大阪市中央区道修町三丁目６番１号',
        industry='小売業',
        sec_code='27260',
        corporate_number='1120001087503',
    ),
    'E03391': EdinetCodeEntry(
        edinet_code='E03391',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=440,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ワッツ',
        submitter_name_en='WATTS CO., LTD.',
        submitter_name_yomi='カブシキガイシャワッツ',
        address='大阪市中央区城見一丁目４番７０号住友生命ＯＢＰプラザビル',
        industry='小売業',
        sec_code='27350',
        corporate_number='4120001106103',
    ),
    'E03392': EdinetCodeEntry(
        edinet_code='E03392',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=807,
        fiscal_year_end='8月31日',
        submitter_name='フェスタリアホールディングス株式会社',
        submitter_name_en='Festaria Holdings Co.,Ltd.',
        submitter_name_yomi='フェスタリアホールディングスカブシキガイシャ',
        address='品川区西五反田七丁目２０番９号',
        industry='小売業',
        sec_code='27360',
        corporate_number='6310001008798',
    ),
    'E03393': EdinetCodeEntry(
        edinet_code='E03393',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1886,
        fiscal_year_end='2月末日',
        submitter_name='株式会社スタジオアリス',
        submitter_name_en='STUDIO ALICE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャスタジオアリス',
        address='大阪市北区梅田一丁目８番１７号',
        industry='サービス業',
        sec_code='23050',
        corporate_number='5120001096533',
    ),
    'E03395': EdinetCodeEntry(
        edinet_code='E03395',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5491,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ハローズ',
        submitter_name_en='HALOWS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハローズ',
        address='福山市南蔵王町六丁目２６番７号（同所は登記上の本店所在地であり、実際の業務は「最寄りの連絡場所」で行っております。）',
        industry='小売業',
        sec_code='27420',
        corporate_number='7240001031724',
    ),
    'E03397': EdinetCodeEntry(
        edinet_code='E03397',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=641,
        fiscal_year_end='2月末日',
        submitter_name='北雄ラッキー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホクユウラッキーカブシキガイシャ',
        address='札幌市手稲区星置１条２丁目１番１号',
        industry='小売業',
        sec_code='27470',
        corporate_number='4430001015181',
    ),
    'E03398': EdinetCodeEntry(
        edinet_code='E03398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2473,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000あみやき亭',
        submitter_name_en='AMIYAKI  TEI  CO.,LDT.',
        submitter_name_yomi='カブシキガイシャ\u3000アミヤキテイ',
        address='春日井市如意申町五丁目１２番地の８',
        industry='小売業',
        sec_code='27530',
        corporate_number='7180001073665',
    ),
    'E03399': EdinetCodeEntry(
        edinet_code='E03399',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11940,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エディオン',
        submitter_name_en='EDION Corporation',
        submitter_name_yomi='カブシキガイシャエディオン',
        address='広島市中区紙屋町二丁目１番１８号',
        industry='小売業',
        sec_code='27300',
        corporate_number='3240001041231',
    ),
    'E03400': EdinetCodeEntry(
        edinet_code='E03400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5535,
        fiscal_year_end='12月31日',
        submitter_name='株式会社フジオフードグループ本社',
        submitter_name_en='FUJIO FOOD GROUP INC.',
        submitter_name_yomi='カブシキガイシャフジオフードグループホンシャ',
        address='大阪市北区菅原町２番１６号ＦＵＪＩＯ\u3000ＢＬＤＧ．',
        industry='小売業',
        sec_code='27520',
        corporate_number='2120001093715',
    ),
    'E03401': EdinetCodeEntry(
        edinet_code='E03401',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=211,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東葛ホールディングス',
        submitter_name_en='TOKATSU HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウカツホールディングス',
        address='松戸市小金きよしヶ丘三丁目２１番地の１',
        industry='小売業',
        sec_code=None,
        corporate_number='9040001036824',
    ),
    'E03404': EdinetCodeEntry(
        edinet_code='E03404',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ＳＡＮＫＯ\u3000ＭＡＲＫＥＴＩＮＧ\u3000ＦＯＯＤＳ',
        submitter_name_en='SANKO MARKETING FOODS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンコーマーケティングフーズ',
        address='中央区新川一丁目１０番１４号',
        industry='小売業',
        sec_code='27620',
        corporate_number='8013301027281',
    ),
    'E03405': EdinetCodeEntry(
        edinet_code='E03405',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1344,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エフティグループ',
        submitter_name_en='FTGroup CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエフティグループ',
        address='中央区日本橋蛎殻町二丁目１３番６号',
        industry='卸売業',
        sec_code='27630',
        corporate_number='7010001089380',
    ),
    'E03406': EdinetCodeEntry(
        edinet_code='E03406',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1213,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ひらまつ',
        submitter_name_en='Hiramatsu Inc.',
        submitter_name_yomi='カブシキガイシャヒラマツ',
        address='渋谷区恵比寿四丁目１７番３号',
        industry='小売業',
        sec_code='27640',
        corporate_number='9011001037410',
    ),
    'E03407': EdinetCodeEntry(
        edinet_code='E03407',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7948,
        fiscal_year_end='3月31日',
        submitter_name='円谷フィールズホールディングス株式会社',
        submitter_name_en='TSUBURAYA FIELDS HOLDINGS INC.',
        submitter_name_yomi='ツブラヤフィールズホールディングスカブシキガイシャ',
        address='渋谷区南平台町１６番１７号',
        industry='卸売業',
        sec_code='27670',
        corporate_number='2011001042870',
    ),
    'E03408': EdinetCodeEntry(
        edinet_code='E03408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8025,
        fiscal_year_end='11月30日',
        submitter_name='株式会社サーラコーポレーション',
        submitter_name_en='SALA CORPORATION',
        submitter_name_yomi='カブシキガイシャサーラコーポレーション',
        address='豊橋市駅前大通一丁目５５番地サーラタワー',
        industry='小売業',
        sec_code='27340',
        corporate_number='3180301008069',
    ),
    'E03409': EdinetCodeEntry(
        edinet_code='E03409',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2330,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ヴィレッジヴァンガードコーポレーション',
        submitter_name_en='Village Vanguard CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヴィレッジヴァンガードコーポレーション',
        address='名古屋市名東区上社一丁目１８０２番地',
        industry='小売業',
        sec_code='27690',
        corporate_number='7180001067799',
    ),
    'E03410': EdinetCodeEntry(
        edinet_code='E03410',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='6月20日',
        submitter_name='ゲンキー株式会社',
        submitter_name_en='Genky Stores,Inc.',
        submitter_name_yomi='ゲンキーカブシキガイシャ',
        address='坂井市丸岡町下久米田３８字３３番',
        industry='小売業',
        sec_code=None,
        corporate_number='9210001007535',
    ),
    'E03415': EdinetCodeEntry(
        edinet_code='E03415',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月20日',
        submitter_name='パレモ・ホールディングス株式会社',
        submitter_name_en='PALEMO HOLDINGS CO.,LTD.',
        submitter_name_yomi='パレモホールディングスカブシキガイシャ',
        address='名古屋市中村区名駅五丁目２７番１３号\u3000名駅錦橋ビル６Ｆ',
        industry='小売業',
        sec_code='27780',
        corporate_number='4180001086075',
    ),
    'E03416': EdinetCodeEntry(
        edinet_code='E03416',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1803,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コメ兵ホールディングス',
        submitter_name_en='Komehyo Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコメヒョウホールディングス',
        address='名古屋市中区大須三丁目２５番３１号',
        industry='小売業',
        sec_code='27800',
        corporate_number='2180001036008',
    ),
    'E03418': EdinetCodeEntry(
        edinet_code='E03418',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1278,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セリア',
        submitter_name_en='Seria Co., Ltd.',
        submitter_name_yomi='カブシキガイシャセリア',
        address='大垣市外渕２丁目３８番地',
        industry='小売業',
        sec_code='27820',
        corporate_number='4200001013662',
    ),
    'E03419': EdinetCodeEntry(
        edinet_code='E03419',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=439,
        fiscal_year_end='5月15日',
        submitter_name='株式会社サッポロドラッグストアー',
        submitter_name_en='SAPPORODRUG STORE CO.,LTD.',
        submitter_name_yomi='カブシキカイシャ\u3000サッポロドラッグストアー',
        address='札幌市東区８条東４丁目１番２０号',
        industry='小売業',
        sec_code=None,
        corporate_number='9430001020202',
    ),
    'E03421': EdinetCodeEntry(
        edinet_code='E03421',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3538,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナフコ',
        submitter_name_en='NAFCO CO., Ltd',
        submitter_name_yomi='カブシキガイシャナフコ',
        address='北九州市小倉北区魚町二丁目６番１０号',
        industry='小売業',
        sec_code='27900',
        corporate_number='7290801002705',
    ),
    'E03422': EdinetCodeEntry(
        edinet_code='E03422',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社カルラ',
        submitter_name_en='Karula Co.,LTD.',
        submitter_name_yomi='カブシキガイシャカルラ',
        address='富谷市成田九丁目２番地９',
        industry='小売業',
        sec_code='27890',
        corporate_number='9370001017691',
    ),
    'E03423': EdinetCodeEntry(
        edinet_code='E03423',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1760,
        fiscal_year_end='5月31日',
        submitter_name='大黒天物産株式会社',
        submitter_name_en='DAIKOKUTENBUSSAN CO.,LTD.',
        submitter_name_yomi='ダイコクテンブッサンカブシキガイシャ',
        address='倉敷市西中新田２９７番地１',
        industry='小売業',
        sec_code='27910',
        corporate_number='8260001013868',
    ),
    'E03424': EdinetCodeEntry(
        edinet_code='E03424',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3566,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ハニーズホールディングス',
        submitter_name_en='HONEYS HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハニーズホールディングス',
        address='いわき市鹿島町走熊字七本松２７番地の１',
        industry='小売業',
        sec_code='27920',
        corporate_number='5380001013644',
    ),
    'E03428': EdinetCodeEntry(
        edinet_code='E03428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ワイズテーブルコーポレーション',
        submitter_name_en="Y's table corporation",
        submitter_name_yomi='カブシキガイシャワイズテーブルコーポレーション',
        address='港区赤坂８－１０－２２',
        industry='小売業',
        sec_code='27980',
        corporate_number='6010401054605',
    ),
    'E03430': EdinetCodeEntry(
        edinet_code='E03430',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3652,
        fiscal_year_end='3月31日',
        submitter_name='ブックオフコーポレーション株式会社',
        submitter_name_en='BOOKOFF CORPORATION',
        submitter_name_yomi='ブックオフコーポレーションカブシキガイシャ',
        address='相模原市南区古淵二丁目１４番２０号',
        industry='小売業',
        sec_code=None,
        corporate_number='9021001013831',
    ),
    'E03432': EdinetCodeEntry(
        edinet_code='E03432',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フライングガーデン',
        submitter_name_en='FLYING GARDEN CO., LTD',
        submitter_name_yomi='カブシキガイシャフライングガーデン',
        address='小山市本郷町３－４－１８',
        industry='小売業',
        sec_code='33170',
        corporate_number='5060001014864',
    ),
    'E03433': EdinetCodeEntry(
        edinet_code='E03433',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=659,
        fiscal_year_end='4月30日',
        submitter_name='株式会社メガネスーパー',
        submitter_name_en='MEGANESUPER CO., LTD.',
        submitter_name_yomi='カブシキガイシャメガネスーパー',
        address='小田原市本町四丁目２番３９号',
        industry='小売業',
        sec_code=None,
        corporate_number='3021001032820',
    ),
    'E03434': EdinetCodeEntry(
        edinet_code='E03434',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=803,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ランシステム',
        submitter_name_en='RUNSYSTEM CO.,LTD.',
        submitter_name_yomi='カブシキガイシャランシステム',
        address='狭山市狭山台４丁目２７番地の３８',
        industry='小売業',
        sec_code='33260',
        corporate_number='3030001026708',
    ),
    'E03436': EdinetCodeEntry(
        edinet_code='E03436',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='4月30日',
        submitter_name='東和フードサービス株式会社',
        submitter_name_en='TOWA FOOD SERVICE CO.,LTD.',
        submitter_name_yomi='トウワフードサービスカブシキガイシャ',
        address='港区新橋三丁目２０番１号',
        industry='小売業',
        sec_code='33290',
        corporate_number='6010401083455',
    ),
    'E03437': EdinetCodeEntry(
        edinet_code='E03437',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3175,
        fiscal_year_end='9月30日',
        submitter_name='ＢＥＥＮＯＳ株式会社',
        submitter_name_en='BEENOS Inc.',
        submitter_name_yomi='ビーノスカブシキガイシャ',
        address='品川区西五反田８―４―１３',
        industry='小売業',
        sec_code=None,
        corporate_number='5010701020605',
    ),
    'E03439': EdinetCodeEntry(
        edinet_code='E03439',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2061,
        fiscal_year_end='2月20日',
        submitter_name='株式会社あさひ',
        submitter_name_en='Asahi Co.,LTD.',
        submitter_name_yomi='カブシキガイシャアサヒ',
        address='大阪市都島区高倉町３－１１－４',
        industry='小売業',
        sec_code='33330',
        corporate_number='7120001006861',
    ),
    'E03443': EdinetCodeEntry(
        edinet_code='E03443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=917,
        fiscal_year_end='2月末日',
        submitter_name='株式会社メディカル一光グループ',
        submitter_name_en='Medical Ikkou Group Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャメディカルイッコウグループ',
        address='津市西丸之内３６番２５号',
        industry='小売業',
        sec_code='33530',
        corporate_number='2190001001175',
    ),
    'E03444': EdinetCodeEntry(
        edinet_code='E03444',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3185,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ワンダーコーポレーション',
        submitter_name_en='WonderCorporation',
        submitter_name_yomi='カブシキガイシャワンダーコーポレーション',
        address='つくば市小野崎２９４番地１',
        industry='小売業',
        sec_code=None,
        corporate_number='1050001016270',
    ),
    'E03446': EdinetCodeEntry(
        edinet_code='E03446',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4178,
        fiscal_year_end='5月31日',
        submitter_name='株式会社コスモス薬品',
        submitter_name_en='COSMOS Pharmaceutical Corporation',
        submitter_name_yomi='カブシキガイシャコスモスヤクヒン',
        address='福岡市博多区博多駅東二丁目１０番１号\u3000第一福岡ビルＳ館４階',
        industry='小売業',
        sec_code='33490',
        corporate_number='9290001025414',
    ),
    'E03447': EdinetCodeEntry(
        edinet_code='E03447',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=653,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バッファロー',
        submitter_name_en='BUFFALO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000バッファロー',
        address='川口市本町四丁目１番８号',
        industry='小売業',
        sec_code='33520',
        corporate_number='1030001076804',
    ),
    'E03450': EdinetCodeEntry(
        edinet_code='E03450',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15553,
        fiscal_year_end='3月31日',
        submitter_name='シップヘルスケアホールディングス株式会社',
        submitter_name_en='SHIP HEALTHCARE HOLDINGS, INC.',
        submitter_name_yomi='シップヘルスケアホールディングスカブシキガイシャ',
        address='吹田市春日３丁目２０番８号',
        industry='卸売業',
        sec_code='33600',
        corporate_number='9120901006249',
    ),
    'E03451': EdinetCodeEntry(
        edinet_code='E03451',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1521,
        fiscal_year_end='3月31日',
        submitter_name='ワイエスフード株式会社',
        submitter_name_en='Y.S.FOOD  CO.,LTD.',
        submitter_name_yomi='ワイエスフードカブシキガイシャ',
        address='田川郡香春町大字鏡山字金山５５２番８',
        industry='小売業',
        sec_code='33580',
        corporate_number='9290801016604',
    ),
    'E03454': EdinetCodeEntry(
        edinet_code='E03454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=852,
        fiscal_year_end='4月30日',
        submitter_name='株式会社トーエル',
        submitter_name_en='Toell Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトーエル',
        address='横浜市港北区高田西一丁目５番２１号',
        industry='小売業',
        sec_code='33610',
        corporate_number='2020001021033',
    ),
    'E03455': EdinetCodeEntry(
        edinet_code='E03455',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1160,
        fiscal_year_end='2月末日',
        submitter_name='株式会社一六堂',
        submitter_name_en='ICHIROKUDO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイチロクドウ',
        address='中央区日本橋３丁目４－１',
        industry='小売業',
        sec_code=None,
        corporate_number='1010001065395',
    ),
    'E03456': EdinetCodeEntry(
        edinet_code='E03456',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=889,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジタコーポレーション',
        submitter_name_en='FUJITA CORPORATION Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフジタコーポレーション',
        address='苫小牧市若草町５丁目３番５号',
        industry='小売業',
        sec_code='33700',
        corporate_number='9430001054035',
    ),
    'E03457': EdinetCodeEntry(
        edinet_code='E03457',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1157,
        fiscal_year_end='3月31日',
        submitter_name='株式会社関門海',
        submitter_name_en='KANMONKAI CO., LTD.',
        submitter_name_yomi='カブシキガイシャカンモンカイ',
        address='松原市三宅東一丁目８番７号',
        industry='小売業',
        sec_code='33720',
        corporate_number='8120001130719',
    ),
    'E03459': EdinetCodeEntry(
        edinet_code='E03459',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社オンリー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオンリー',
        address='京都市下京区松原通烏丸西入ル玉津島町３０３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5130001004503',
    ),
    'E03460': EdinetCodeEntry(
        edinet_code='E03460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=331,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＺＯＡ',
        submitter_name_en='ZOA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000ゾア',
        address='沼津市大諏訪７１９番地',
        industry='小売業',
        sec_code='33750',
        corporate_number='6080101003228',
    ),
    'E03461': EdinetCodeEntry(
        edinet_code='E03461',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='2月末日',
        submitter_name='株式会社薬王堂',
        submitter_name_en='YAKUODO. Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャヤクオウドウ',
        address='紫波郡矢巾町医大通二丁目７番７号',
        industry='小売業',
        sec_code=None,
        corporate_number='9400001003829',
    ),
    'E03462': EdinetCodeEntry(
        edinet_code='E03462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社セブン＆アイ・ホールディングス',
        submitter_name_en='Seven & i Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャセブンアンドアイホールディングス',
        address='千代田区二番町８番地８',
        industry='小売業',
        sec_code='33820',
        corporate_number='1010001095203',
    ),
    'E03463': EdinetCodeEntry(
        edinet_code='E03463',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社サマンサタバサジャパンリミテッド',
        submitter_name_en='SamanthaThavasa Japan Limited',
        submitter_name_yomi='カブシキガイシャ\u3000サマンサタバサジャパンリミテッド',
        address='港区三田１－４－１',
        industry='その他製品',
        sec_code=None,
        corporate_number='9010401082371',
    ),
    'E03464': EdinetCodeEntry(
        edinet_code='E03464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11520,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ツルハホールディングス',
        submitter_name_en='TSURUHA HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャツルハホールディングス',
        address='札幌市東区北２４条東２０丁目１番２１号',
        industry='小売業',
        sec_code='33910',
        corporate_number='4430001029116',
    ),
    'E03465': EdinetCodeEntry(
        edinet_code='E03465',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=484,
        fiscal_year_end='5月31日',
        submitter_name='株式会社パシフィックネット',
        submitter_name_en='Pacific Net Co.,Ltd',
        submitter_name_yomi='カブシキガイシャパシフィックネット',
        address='港区芝五丁目３４番７号',
        industry='小売業',
        sec_code='30210',
        corporate_number='5010401054564',
    ),
    'E03467': EdinetCodeEntry(
        edinet_code='E03467',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1868,
        fiscal_year_end='2月末日',
        submitter_name='株式会社フェリシモ',
        submitter_name_en='FELISSIMO  CORPORATION',
        submitter_name_yomi='カブシキガイシャフェリシモ',
        address='神戸市中央区新港町７番１号',
        industry='小売業',
        sec_code='33960',
        corporate_number='4140001022298',
    ),
    'E03468': EdinetCodeEntry(
        edinet_code='E03468',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4181,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トリドールホールディングス',
        submitter_name_en='TORIDOLL Holdings Corporation',
        submitter_name_yomi='カブシキガイシャトリドールホールディングス',
        address='渋谷区道玄坂一丁目２１番１号',
        industry='小売業',
        sec_code='33970',
        corporate_number='8140001028201',
    ),
    'E03469': EdinetCodeEntry(
        edinet_code='E03469',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1337,
        fiscal_year_end='5月20日',
        submitter_name='株式会社クスリのアオキ',
        submitter_name_en='KUSURI NO AOKI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクスリノアオキ',
        address='白山市松本町２５１２番地',
        industry='小売業',
        sec_code=None,
        corporate_number='2220001008745',
    ),
    'E03470': EdinetCodeEntry(
        edinet_code='E03470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=325,
        fiscal_year_end='1月31日',
        submitter_name='株式会社丸千代山岡家',
        submitter_name_en='Maruchiyo Yamaokaya Corporation',
        submitter_name_yomi='カブシキガイシャマルチヨヤマオカヤ',
        address='札幌市東区東雁来７条１丁目４番３２号',
        industry='小売業',
        sec_code='33990',
        corporate_number='9430001017223',
    ),
    'E03471': EdinetCodeEntry(
        edinet_code='E03471',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3202,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ジンズホールディングス',
        submitter_name_en='JINS HOLDINGS Inc.',
        submitter_name_yomi='ジンズホールディングス',
        address='前橋市川原町二丁目２６番地４',
        industry='小売業',
        sec_code='30460',
        corporate_number='7070001001538',
    ),
    'E03472': EdinetCodeEntry(
        edinet_code='E03472',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=381,
        fiscal_year_end='3月31日',
        submitter_name='アプライド株式会社',
        submitter_name_en='Applied Co., Ltd.',
        submitter_name_yomi='アプライドカブシキガイシャ',
        address='福岡市博多区東比恵３丁目３－１',
        industry='小売業',
        sec_code='30200',
        corporate_number='4290001011410',
    ),
    'E03473': EdinetCodeEntry(
        edinet_code='E03473',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ハブ',
        submitter_name_en='HUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハブ',
        address='千代田区外神田三丁目１４番１０号',
        industry='小売業',
        sec_code='30300',
        corporate_number='8010001087103',
    ),
    'E03474': EdinetCodeEntry(
        edinet_code='E03474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=515,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゴルフ・ドゥ',
        submitter_name_en='GOLF DO CO.,LTD.',
        submitter_name_yomi='カブシキガイシヤゴルフドウ',
        address='さいたま市中央区上落合二丁目３番１号',
        industry='小売業',
        sec_code='30320',
        corporate_number='8030001002794',
    ),
    'E03475': EdinetCodeEntry(
        edinet_code='E03475',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15163,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アルペン',
        submitter_name_en='Alpen Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアルペン',
        address='名古屋市中区丸の内二丁目９番４０号',
        industry='小売業',
        sec_code='30280',
        corporate_number='7180001024676',
    ),
    'E03476': EdinetCodeEntry(
        edinet_code='E03476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5786,
        fiscal_year_end='3月31日',
        submitter_name='クオールホールディングス株式会社',
        submitter_name_en='Qol Holdings Co.,Ltd.',
        submitter_name_yomi='クオールホールディングスカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号\u3000城山トラストタワー３７階',
        industry='小売業',
        sec_code='30340',
        corporate_number='6010401088941',
    ),
    'E03478': EdinetCodeEntry(
        edinet_code='E03478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=186,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ペッパーフードサービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャペッパーフードサービス',
        address='墨田区太平四丁目１番３号オリナスタワー１７Ｆ',
        industry='小売業',
        sec_code='30530',
        corporate_number='7010601023532',
    ),
    'E03481': EdinetCodeEntry(
        edinet_code='E03481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25929,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ビックカメラ',
        submitter_name_en='BIC CAMERA INC.',
        submitter_name_yomi='カブシキガイシャビックカメラ',
        address='豊島区高田三丁目２３番２３号',
        industry='小売業',
        sec_code='30480',
        corporate_number='9013301010402',
    ),
    'E03482': EdinetCodeEntry(
        edinet_code='E03482',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=97,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＴＲＵＣＫ－ＯＮＥ',
        submitter_name_en='TRUCK-ONE CO., LTD.',
        submitter_name_yomi='カブシキガイシャトラックワン',
        address='下松市生野屋南三丁目３番４０号',
        industry='卸売業',
        sec_code='30470',
        corporate_number='5250001009424',
    ),
    'E03485': EdinetCodeEntry(
        edinet_code='E03485',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=517,
        fiscal_year_end='9月30日',
        submitter_name='株式会社東京一番フーズ',
        submitter_name_en='TOKYO ICHIBAN FOODS CO .,LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウイチバンフーズ',
        address='新宿区新宿５－６－１新宿やわらぎビル４階',
        industry='小売業',
        sec_code='30670',
        corporate_number='4011101033768',
    ),
    'E03486': EdinetCodeEntry(
        edinet_code='E03486',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=561,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ゼットン',
        submitter_name_en='zetton  inc.',
        submitter_name_yomi='カブシキカイシャゼットン',
        address='名古屋市中区栄三丁目１２番２３号',
        industry='小売業',
        sec_code=None,
        corporate_number='5180001043125',
    ),
    'E03487': EdinetCodeEntry(
        edinet_code='E03487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三洋堂ホールディングス',
        submitter_name_en='Sanyodo Holdings Inc.',
        submitter_name_yomi='カブシキガイシャサンヨウドウホールディングス',
        address='名古屋市瑞穂区新開町１８番２２号',
        industry='小売業',
        sec_code='30580',
        corporate_number='8180001008414',
    ),
    'E03489': EdinetCodeEntry(
        edinet_code='E03489',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='2月末日',
        submitter_name='ＤＣＭホールディングス株式会社',
        submitter_name_en='DCM Holdings Co.,Ltd.',
        submitter_name_yomi='ディーシーエムホールディングスカブシキガイシャ',
        address='品川区南大井六丁目２２番７号',
        industry='小売業',
        sec_code='30500',
        corporate_number='4010701019160',
    ),
    'E03490': EdinetCodeEntry(
        edinet_code='E03490',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ライフフーズ',
        submitter_name_en='Life Foods Co., Ltd.',
        submitter_name_yomi='カブシキガイシャライフフーズ',
        address='吹田市江坂町一丁目１３－４１',
        industry='小売業',
        sec_code='30650',
        corporate_number='4120901008761',
    ),
    'E03492': EdinetCodeEntry(
        edinet_code='E03492',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=220,
        fiscal_year_end='12月31日',
        submitter_name='株式会社インターメスティック',
        submitter_name_en='INTERMESTIC INC.',
        submitter_name_yomi='カブシキカイシャインターメスティック',
        address='港区北青山三丁目６番１号',
        industry='小売業',
        sec_code='262A0',
        corporate_number='6011001038675',
    ),
    'E03493': EdinetCodeEntry(
        edinet_code='E03493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3472,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アートネイチャー',
        submitter_name_en='ARTNATURE INC.',
        submitter_name_yomi='カブシキガイシャアートネイチャー',
        address='渋谷区代々木三丁目４０番７号',
        industry='その他製品',
        sec_code='78230',
        corporate_number='9011001000392',
    ),
    'E03494': EdinetCodeEntry(
        edinet_code='E03494',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='3月31日',
        submitter_name='ヒラキ株式会社',
        submitter_name_en='HIRAKI CO.,LTD.',
        submitter_name_yomi='ヒラキカブシキガイシャ',
        address='神戸市須磨区中島町三丁目２番６号',
        industry='小売業',
        sec_code='30590',
        corporate_number='9140001017855',
    ),
    'E03495': EdinetCodeEntry(
        edinet_code='E03495',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ジェイグループホールディングス',
        submitter_name_en='J-Group Holdings Corp.',
        submitter_name_yomi='カブシキガイシャジェイグループホールディングス',
        address='名古屋市中区栄三丁目４番２８号',
        industry='小売業',
        sec_code='30630',
        corporate_number='8180001050135',
    ),
    'E03496': EdinetCodeEntry(
        edinet_code='E03496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＷＤＩ',
        submitter_name_en='WDI Corporation.',
        submitter_name_yomi='カブシキガイシャダブリューディーアイ',
        address='港区六本木５丁目５番地１号\u3000ロアビル８Ｆ',
        industry='小売業',
        sec_code='30680',
        corporate_number='8010401022997',
    ),
    'E03497': EdinetCodeEntry(
        edinet_code='E03497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2042,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＭｏｎｏｔａＲＯ',
        submitter_name_en='MonotaRO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャモノタロウ',
        address='大阪市北区梅田三丁目２番２号',
        industry='小売業',
        sec_code='30640',
        corporate_number='6140001054380',
    ),
    'E03498': EdinetCodeEntry(
        edinet_code='E03498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='スターシーズ株式会社',
        submitter_name_en='Star seeds Co.,Ltd.',
        submitter_name_yomi='スターシーズカブシキガイシャ',
        address='港区新橋四丁目２１番３号',
        industry='小売業',
        sec_code='30830',
        corporate_number='6010001072528',
    ),
    'E03500': EdinetCodeEntry(
        edinet_code='E03500',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=818,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＢイレブン',
        submitter_name_en='JB ELEVEN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジェービーイレブン',
        address='名古屋市緑区桶狭間切戸２２１７番地',
        industry='小売業',
        sec_code='30660',
        corporate_number='8180001047370',
    ),
    'E03505': EdinetCodeEntry(
        edinet_code='E03505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=292,
        fiscal_year_end='3月31日',
        submitter_name='ホリイフードサービス株式会社',
        submitter_name_en='Horiifoodservice Co.,Ltd.',
        submitter_name_yomi='ホリイフードサービスカブシキガイシャ',
        address='水戸市城南３丁目１０番１７号',
        industry='小売業',
        sec_code='30770',
        corporate_number='2050001002286',
    ),
    'E03506': EdinetCodeEntry(
        edinet_code='E03506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=924,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ストリーム',
        submitter_name_en='stream co.,ltd',
        submitter_name_yomi='カブシキガイシャストリーム',
        address='港区新橋六丁目１７番２１号',
        industry='小売業',
        sec_code='30710',
        corporate_number='5010001065326',
    ),
    'E03507': EdinetCodeEntry(
        edinet_code='E03507',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社銚子丸',
        submitter_name_en='Choushimaru Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000チョウシマル',
        address='千葉市美浜区浜田二丁目３９番地',
        industry='小売業',
        sec_code='30750',
        corporate_number='1040001001199',
    ),
    'E03508': EdinetCodeEntry(
        edinet_code='E03508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2910,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ＪＦＬＡホールディングス',
        submitter_name_en='JFLA Holdings Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000ジェイエフエルエーホールディングス',
        address='中央区日本橋蛎殻町一丁目５番６号',
        industry='小売業',
        sec_code='30690',
        corporate_number='2010401066843',
    ),
    'E03509': EdinetCodeEntry(
        edinet_code='E03509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=320,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ジェーソン',
        submitter_name_en='JASON CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジェーソン',
        address='柏市大津ヶ丘二丁目８番５号',
        industry='小売業',
        sec_code='30800',
        corporate_number='7040001067160',
    ),
    'E03512': EdinetCodeEntry(
        edinet_code='E03512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=381,
        fiscal_year_end='6月30日',
        submitter_name='株式会社きちりホールディングス',
        submitter_name_en='KICHIRI HOLDINGS&Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャキチリホールディンングス',
        address='大阪市中央区安土町二丁目３番１３号',
        industry='小売業',
        sec_code='30820',
        corporate_number='6120001104237',
    ),
    'E03513': EdinetCodeEntry(
        edinet_code='E03513',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1932,
        fiscal_year_end='12月末日',
        submitter_name='アークランドサービスホールディングス株式会社',
        submitter_name_en='ARCLAND SERVICE HOLDINGS CO.,LTD.',
        submitter_name_yomi='アークランドサービスホールディングスカブシキガイシャ',
        address='千代田区神田駿河台四丁目３番地\u3000新お茶の水ビルディング１４階',
        industry='小売業',
        sec_code=None,
        corporate_number='5010001106113',
    ),
    'E03515': EdinetCodeEntry(
        edinet_code='E03515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25134,
        fiscal_year_end='12月31日',
        submitter_name='株式会社すかいらーくホールディングス',
        submitter_name_en='SKYLARK HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャスカイラークホールディングス',
        address='武蔵野市西久保１丁目２５番８号',
        industry='小売業',
        sec_code='31970',
        corporate_number='2010001138365',
    ),
    'E03516': EdinetCodeEntry(
        edinet_code='E03516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31974,
        fiscal_year_end='2月末日',
        submitter_name='Ｊ．フロント\u3000リテイリング株式会社',
        submitter_name_en='J.FRONT RETAILING Co.,Ltd.',
        submitter_name_yomi='ジェイ\u3000フロント\u3000リテイリングカブシキガイシャ',
        address='中央区銀座六丁目１０番１号',
        industry='小売業',
        sec_code='30860',
        corporate_number='5010001111996',
    ),
    'E03517': EdinetCodeEntry(
        edinet_code='E03517',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2210,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ブロンコビリー',
        submitter_name_en='BRONCO BILLY Co.,LTD.',
        submitter_name_yomi='カブシキガイシャブロンコビリー',
        address='名古屋市名東区平和が丘一丁目７５番地',
        industry='小売業',
        sec_code='30910',
        corporate_number='8180001013307',
    ),
    'E03518': EdinetCodeEntry(
        edinet_code='E03518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ドトール・日レスホールディングス',
        submitter_name_en='DOUTOR NICHIRES Holdings.,Co Ltd.',
        submitter_name_yomi='カブシキガイシャドトールニチレスホールディングス',
        address='渋谷区猿楽町１０－１１',
        industry='小売業',
        sec_code='30870',
        corporate_number='2011001053983',
    ),
    'E03519': EdinetCodeEntry(
        edinet_code='E03519',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22051,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マツキヨココカラ＆カンパニー',
        submitter_name_en='MatsukiyoCocokara & Co',
        submitter_name_yomi='カブシキガイシャマツキヨココカラアンドカンパニー',
        address='松戸市新松戸東９番地１',
        industry='小売業',
        sec_code='30880',
        corporate_number='2040001040238',
    ),
    'E03520': EdinetCodeEntry(
        edinet_code='E03520',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=906,
        fiscal_year_end='2月末日',
        submitter_name='株式会社トレジャー・ファクトリー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトレジャーファクトリー',
        address='千代田区外神田４ー１４ー１\u3000秋葉原ＵＤＸビル２０階',
        industry='小売業',
        sec_code='30930',
        corporate_number='3011801014408',
    ),
    'E03521': EdinetCodeEntry(
        edinet_code='E03521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=51340,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三越伊勢丹ホールディングス',
        submitter_name_en='Isetan Mitsukoshi Holdings Ltd.',
        submitter_name_yomi='カブシキガイシャミツコシイセタンホールディングス',
        address='新宿区新宿五丁目１６番１０号',
        industry='小売業',
        sec_code='30990',
        corporate_number='3011101060499',
    ),
    'E03522': EdinetCodeEntry(
        edinet_code='E03522',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20184,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ココカラファイングループ',
        submitter_name_en='Cocokarafine Group Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャココカラファイングループ',
        address='横浜市港北区新横浜三丁目１７番６号',
        industry='小売業',
        sec_code=None,
        corporate_number='9010801018108',
    ),
    'E03523': EdinetCodeEntry(
        edinet_code='E03523',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3513,
        fiscal_year_end='2月末日',
        submitter_name='株式会社スーパーバリュー',
        submitter_name_en='super value co., ltd.',
        submitter_name_yomi='カブシキガイシャスーパーバリュー',
        address='上尾市宮本町５番１８号',
        industry='小売業',
        sec_code='30940',
        corporate_number='2030001044306',
    ),
    'E03524': EdinetCodeEntry(
        edinet_code='E03524',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=801,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オーシャンシステム',
        submitter_name_en='OCEAN SYSTEM CORPORATION',
        submitter_name_yomi='カブシキガイシャオーシャンシステム',
        address='三条市西本成寺二丁目２６番５７号',
        industry='小売業',
        sec_code='30960',
        corporate_number='2110001013962',
    ),
    'E03528': EdinetCodeEntry(
        edinet_code='E03528',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5964,
        fiscal_year_end='6月30日',
        submitter_name='株式会社物語コーポレーション',
        submitter_name_en='The Monogatari Corporation',
        submitter_name_yomi='カブシキガイシャモノガタリコーポレーション',
        address='豊橋市西岩田五丁目７番地の１１',
        industry='小売業',
        sec_code='30970',
        corporate_number='7180301007414',
    ),
    'E03530': EdinetCodeEntry(
        edinet_code='E03530',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=178507,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＢＩ新生銀行',
        submitter_name_en='SBI Shinsei Bank, Limited',
        submitter_name_yomi='カブシキガイシャエスビーアイシンセイギンコウ',
        address='中央区日本橋室町２－４－３',
        industry='銀行業',
        sec_code='83030',
        corporate_number='7010001016855',
    ),
    'E03531': EdinetCodeEntry(
        edinet_code='E03531',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=125966,
        fiscal_year_end='3月31日',
        submitter_name='株式会社あおぞら銀行',
        submitter_name_en='Aozora Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャアオゾラギンコウ',
        address='千代田区麹町六丁目１番地１',
        industry='銀行業',
        sec_code='83040',
        corporate_number='9010001016861',
    ),
    'E03532': EdinetCodeEntry(
        edinet_code='E03532',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1404065,
        fiscal_year_end='3月31日',
        submitter_name='株式会社みずほ銀行',
        submitter_name_en='Mizuho Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャミズホギンコウ',
        address='千代田区大手町一丁目５番５号',
        industry='銀行業',
        sec_code=None,
        corporate_number='6010001008845',
    ),
    'E03533': EdinetCodeEntry(
        edinet_code='E03533',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1711958,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三菱ＵＦＪ銀行',
        submitter_name_en='MUFG Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャミツビシユーエフジェイギンコウ',
        address='千代田区丸の内二丁目７番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='5010001008846',
    ),
    'E03538': EdinetCodeEntry(
        edinet_code='E03538',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=279928,
        fiscal_year_end='3月31日',
        submitter_name='株式会社りそな銀行',
        submitter_name_en='Resona Bank, Limited',
        submitter_name_yomi='カブシキガイシャリソナギンコウ',
        address='大阪市中央区備後町二丁目２番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='6120001076393',
    ),
    'E03542': EdinetCodeEntry(
        edinet_code='E03542',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19562,
        fiscal_year_end='3月31日',
        submitter_name='株式会社青森みちのく銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアオモリミチノクギンコウ',
        address='青森市橋本１丁目９番３０号',
        industry='銀行業',
        sec_code=None,
        corporate_number='3420001000012',
    ),
    'E03543': EdinetCodeEntry(
        edinet_code='E03543',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12089,
        fiscal_year_end='3月31日',
        submitter_name='株式会社岩手銀行',
        submitter_name_en='The Bank of Iwate,Ltd.',
        submitter_name_yomi='カブシキガイシャイワテギンコウ',
        address='盛岡市中央通一丁目２番３号',
        industry='銀行業',
        sec_code='83450',
        corporate_number='7400001000423',
    ),
    'E03544': EdinetCodeEntry(
        edinet_code='E03544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13233,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000東北銀行',
        submitter_name_en='THE TOHOKU BANK,LTD.',
        submitter_name_yomi='カブシキガイシャトウホクギンコウ',
        address='盛岡市内丸３番１号',
        industry='銀行業',
        sec_code='83490',
        corporate_number='7400001001891',
    ),
    'E03545': EdinetCodeEntry(
        edinet_code='E03545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24658,
        fiscal_year_end='3月31日',
        submitter_name='株式会社七十七銀行',
        submitter_name_en='The 77Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャシチジュウシチギンコウ',
        address='仙台市青葉区中央三丁目３番２０号',
        industry='銀行業',
        sec_code='83410',
        corporate_number='1370001003352',
    ),
    'E03546': EdinetCodeEntry(
        edinet_code='E03546',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社秋田銀行',
        submitter_name_en='THE AKITA BANK,LTD.',
        submitter_name_yomi='カブシキガイシャアキタギンコウ',
        address='秋田市山王三丁目２番１号',
        industry='銀行業',
        sec_code='83430',
        corporate_number='1410001000221',
    ),
    'E03549': EdinetCodeEntry(
        edinet_code='E03549',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12008,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山形銀行',
        submitter_name_en='The Yamagata Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマガタギンコウ',
        address='山形市七日町三丁目１番２号',
        industry='銀行業',
        sec_code='83440',
        corporate_number='5390001002010',
    ),
    'E03550': EdinetCodeEntry(
        edinet_code='E03550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23519,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東邦銀行',
        submitter_name_en='The Toho Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000トウホウギンコウ',
        address='福島市大町３番２５号',
        industry='銀行業',
        sec_code='83460',
        corporate_number='9380001001018',
    ),
    'E03551': EdinetCodeEntry(
        edinet_code='E03551',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=85113,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000常陽銀行',
        submitter_name_en='The Joyo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ジョウヨウギンコウ',
        address='水戸市南町２丁目５番５号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1050001001231',
    ),
    'E03552': EdinetCodeEntry(
        edinet_code='E03552',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=48868,
        fiscal_year_end='3月31日',
        submitter_name='株式会社筑波銀行',
        submitter_name_en='Tsukuba Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャツクバギンコウ',
        address='土浦市中央二丁目１１番７号',
        industry='銀行業',
        sec_code='83380',
        corporate_number='4050001009057',
    ),
    'E03554': EdinetCodeEntry(
        edinet_code='E03554',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=48652,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000群馬銀行',
        submitter_name_en='The  Gunma  Bank,  Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000グンマギンコウ',
        address='前橋市元総社町１９４番地',
        industry='銀行業',
        sec_code='83340',
        corporate_number='3070001003513',
    ),
    'E03555': EdinetCodeEntry(
        edinet_code='E03555',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45743,
        fiscal_year_end='3月31日',
        submitter_name='株式会社武蔵野銀行',
        submitter_name_en='The Musashino Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャムサシノギンコウ',
        address='さいたま市大宮区桜木町一丁目１０番地８',
        industry='銀行業',
        sec_code='83360',
        corporate_number='6030001002490',
    ),
    'E03556': EdinetCodeEntry(
        edinet_code='E03556',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=145069,
        fiscal_year_end='3月31日',
        submitter_name='株式会社千葉銀行',
        submitter_name_en='The Chiba Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャチバギンコウ',
        address='千葉市中央区千葉港１番２号',
        industry='銀行業',
        sec_code='83310',
        corporate_number='2040001000019',
    ),
    'E03557': EdinetCodeEntry(
        edinet_code='E03557',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=62120,
        fiscal_year_end='3月31日',
        submitter_name='株式会社千葉興業銀行',
        submitter_name_en='The Chiba Kogyo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャチバコウギョウギンコウ',
        address='千葉市美浜区幸町２丁目１番２号',
        industry='銀行業',
        sec_code='83370',
        corporate_number='9040001000020',
    ),
    'E03558': EdinetCodeEntry(
        edinet_code='E03558',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=55620,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京都民銀行',
        submitter_name_en='The Tokyo Tomin Bank,Limited',
        submitter_name_yomi='カブシキガイシャトウキョウトミンギンコウ',
        address='港区南青山三丁目１０番４３号',
        industry='銀行業',
        sec_code=None,
        corporate_number='3010401020709',
    ),
    'E03559': EdinetCodeEntry(
        edinet_code='E03559',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=215628,
        fiscal_year_end=None,
        submitter_name='株式会社横浜銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヨコハマギンコウ',
        address='横浜市西区みなとみらい３丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7020001008645',
    ),
    'E03560': EdinetCodeEntry(
        edinet_code='E03560',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=32776,
        fiscal_year_end='3月31日',
        submitter_name='株式会社第四北越銀行',
        submitter_name_en='Daishi Hokuetsu Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャダイシホクエツギンコウ',
        address='新潟市中央区東堀前通七番町１０７１番地１',
        industry='銀行業',
        sec_code=None,
        corporate_number='7110001000007',
    ),
    'E03561': EdinetCodeEntry(
        edinet_code='E03561',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=24538,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000北越銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ホクエツギンコウ',
        address='長岡市大手通二丁目２番地１４',
        industry='銀行業',
        sec_code=None,
        corporate_number='9110001023146',
    ),
    'E03562': EdinetCodeEntry(
        edinet_code='E03562',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15400,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000山梨中央銀行',
        submitter_name_en='The Yamanashi Chuo Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマナシチュウオウギンコウ',
        address='甲府市丸の内一丁目２０番８号',
        industry='銀行業',
        sec_code='83600',
        corporate_number='3090001002315',
    ),
    'E03563': EdinetCodeEntry(
        edinet_code='E03563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52243,
        fiscal_year_end='3月31日',
        submitter_name='株式会社八十二長野銀行',
        submitter_name_en='Hachijuni Nagano Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャハチジュウニナガノギンコウ',
        address='長野市大字中御所字岡田１７８番地８',
        industry='銀行業',
        sec_code='83590',
        corporate_number='3100001002833',
    ),
    'E03564': EdinetCodeEntry(
        edinet_code='E03564',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=140409,
        fiscal_year_end=None,
        submitter_name='株式会社北陸銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャホクリクギンコウ',
        address='富山市堤町通り１－２－２６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1230001002946',
    ),
    'E03565': EdinetCodeEntry(
        edinet_code='E03565',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6730,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000富山銀行',
        submitter_name_en='The Bank of Toyama,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000トヤマギンコウ',
        address='高岡市下関町３番１号',
        industry='銀行業',
        sec_code='83650',
        corporate_number='9230001011196',
    ),
    'E03566': EdinetCodeEntry(
        edinet_code='E03566',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=26673,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000北國銀行',
        submitter_name_en='The Hokkoku Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャホッコクギンコウ',
        address='金沢市広岡二丁目１２番６号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8220001007709',
    ),
    'E03567': EdinetCodeEntry(
        edinet_code='E03567',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17965,
        fiscal_year_end='3月31日',
        submitter_name='株式会社福井銀行',
        submitter_name_en='The Fukui Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャフクイギンコウ',
        address='福井市順化１丁目１番１号',
        industry='銀行業',
        sec_code='83620',
        corporate_number='9210001003641',
    ),
    'E03568': EdinetCodeEntry(
        edinet_code='E03568',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=46773,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000大垣共立銀行',
        submitter_name_en='The Ogaki Kyoritsu Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000オオガキキョウリツギンコウ',
        address='大垣市郭町３丁目９８番地',
        industry='銀行業',
        sec_code='83610',
        corporate_number='7200001013379',
    ),
    'E03569': EdinetCodeEntry(
        edinet_code='E03569',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=36839,
        fiscal_year_end='3月31日',
        submitter_name='株式会社十六銀行',
        submitter_name_en='The Juroku Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャジュウロクギンコウ',
        address='岐阜市神田町八丁目２６番地',
        industry='銀行業',
        sec_code=None,
        corporate_number='5200001002598',
    ),
    'E03570': EdinetCodeEntry(
        edinet_code='E03570',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=90845,
        fiscal_year_end='3月31日',
        submitter_name='株式会社静岡銀行',
        submitter_name_en='THE SHIZUOKA BANK,LTD.',
        submitter_name_yomi='カブシキガイシャシズオカギンコウ',
        address='静岡市葵区呉服町１丁目１０番地',
        industry='銀行業',
        sec_code=None,
        corporate_number='5080001002669',
    ),
    'E03571': EdinetCodeEntry(
        edinet_code='E03571',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30043,
        fiscal_year_end='3月31日',
        submitter_name='スルガ銀行株式会社',
        submitter_name_en='Suruga Bank Ltd.',
        submitter_name_yomi='スルガギンコウカブシキガイシャ',
        address='沼津市通横町２３番地',
        industry='銀行業',
        sec_code='83580',
        corporate_number='9080101000957',
    ),
    'E03572': EdinetCodeEntry(
        edinet_code='E03572',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10816,
        fiscal_year_end='3月31日',
        submitter_name='株式会社清水銀行',
        submitter_name_en='THE SHIMIZU BANK,LTD.',
        submitter_name_yomi='カブシキガイシャシミズギンコウ',
        address='静岡市清水区富士見町２番１号',
        industry='銀行業',
        sec_code='83640',
        corporate_number='8080001001858',
    ),
    'E03573': EdinetCodeEntry(
        edinet_code='E03573',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15295,
        fiscal_year_end=None,
        submitter_name='株式会社三重銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミエギンコウ',
        address='四日市市西新地七番八号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8190001016358',
    ),
    'E03574': EdinetCodeEntry(
        edinet_code='E03574',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000百五銀行',
        submitter_name_en='The Hyakugo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヒャクゴギンコウ',
        address='津市岩田２１番２７号',
        industry='銀行業',
        sec_code='83680',
        corporate_number='5190001000892',
    ),
    'E03575': EdinetCodeEntry(
        edinet_code='E03575',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33076,
        fiscal_year_end='3月31日',
        submitter_name='株式会社滋賀銀行',
        submitter_name_en='THE SHIGA BANK,LTD.',
        submitter_name_yomi='カブシキガイシャシガギンコウ',
        address='大津市浜町１番３８号',
        industry='銀行業',
        sec_code='83660',
        corporate_number='6160001000993',
    ),
    'E03576': EdinetCodeEntry(
        edinet_code='E03576',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=42103,
        fiscal_year_end=None,
        submitter_name='株式会社京都銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキョウトギンコウ',
        address='京都市下京区烏丸通松原上る薬師前町７００番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9130001000028',
    ),
    'E03579': EdinetCodeEntry(
        edinet_code='E03579',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50710,
        fiscal_year_end=None,
        submitter_name='株式会社池田泉州銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイケダセンシュウギンコウ',
        address='大阪市北区茶屋町１８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001144082',
    ),
    'E03580': EdinetCodeEntry(
        edinet_code='E03580',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37924,
        fiscal_year_end='3月31日',
        submitter_name='株式会社南都銀行',
        submitter_name_en='The Nanto Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャナントギンコウ',
        address='奈良市大宮町四丁目２９７番地の２',
        industry='銀行業',
        sec_code='83670',
        corporate_number='5150001001622',
    ),
    'E03581': EdinetCodeEntry(
        edinet_code='E03581',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=80096,
        fiscal_year_end='3月31日',
        submitter_name='株式会社紀陽銀行',
        submitter_name_en='The Kiyo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャキヨウギンコウ',
        address='和歌山市本町１丁目３５番地',
        industry='銀行業',
        sec_code='83700',
        corporate_number='9170001000916',
    ),
    'E03582': EdinetCodeEntry(
        edinet_code='E03582',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9061,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000鳥取銀行',
        submitter_name_en='THE TOTTORIBANK,LTD.',
        submitter_name_yomi='カブシキカイシャ\u3000トットリギンコウ',
        address='鳥取市永楽温泉町１７１番地',
        industry='銀行業',
        sec_code='83830',
        corporate_number='2270001000870',
    ),
    'E03583': EdinetCodeEntry(
        edinet_code='E03583',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20705,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山陰合同銀行',
        submitter_name_en='The San-in Godo Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャサンインゴウドウギンコウ',
        address='松江市魚町１０番地',
        industry='銀行業',
        sec_code='83810',
        corporate_number='6280001000230',
    ),
    'E03584': EdinetCodeEntry(
        edinet_code='E03584',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15149,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中国銀行',
        submitter_name_en='The Chugoku Bank, Limited',
        submitter_name_yomi='カブシキガイシャチュウゴクギンコウ',
        address='岡山市北区丸の内一丁目１５番２０号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1260001006093',
    ),
    'E03585': EdinetCodeEntry(
        edinet_code='E03585',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=54573,
        fiscal_year_end='3月31日',
        submitter_name='株式会社広島銀行',
        submitter_name_en='The Hiroshima Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャヒロシマギンコウ',
        address='広島市中区紙屋町一丁目３番８号',
        industry='銀行業',
        sec_code=None,
        corporate_number='5240001012809',
    ),
    'E03587': EdinetCodeEntry(
        edinet_code='E03587',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23452,
        fiscal_year_end='3月31日',
        submitter_name='株式会社阿波銀行',
        submitter_name_en='The Awa Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャアワギンコウ',
        address='徳島市西船場町二丁目２４番地の１',
        industry='銀行業',
        sec_code='83880',
        corporate_number='5480001000070',
    ),
    'E03588': EdinetCodeEntry(
        edinet_code='E03588',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=37322,
        fiscal_year_end='3月31日',
        submitter_name='株式会社百十四銀行',
        submitter_name_en='The Hyakujushi Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャヒャクジュウシギンコウ',
        address='高松市亀井町５番地の１',
        industry='銀行業',
        sec_code='83860',
        corporate_number='6470001000203',
    ),
    'E03589': EdinetCodeEntry(
        edinet_code='E03589',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20948,
        fiscal_year_end='3月31日',
        submitter_name='株式会社伊予銀行',
        submitter_name_en='The Iyo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシヤ\u3000イヨギンコウ',
        address='松山市南堀端町１番地',
        industry='銀行業',
        sec_code=None,
        corporate_number='4500001000003',
    ),
    'E03590': EdinetCodeEntry(
        edinet_code='E03590',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社四国銀行',
        submitter_name_en='The Shikoku Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャシコクギンコウ',
        address='高知市南はりまや町一丁目１番１号',
        industry='銀行業',
        sec_code='83870',
        corporate_number='7490001000786',
    ),
    'E03591': EdinetCodeEntry(
        edinet_code='E03591',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=82329,
        fiscal_year_end='3月31日',
        submitter_name='株式会社福岡銀行',
        submitter_name_en='THE BANK OF FUKUOKA, LTD.',
        submitter_name_yomi='カブシキガイシャフクオカギンコウ',
        address='福岡市中央区天神二丁目１３番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1290001004367',
    ),
    'E03592': EdinetCodeEntry(
        edinet_code='E03592',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社筑邦銀行',
        submitter_name_en='The Chikuho Bank , Ltd.',
        submitter_name_yomi='カブシキガイシャチクホウギンコウ',
        address='久留米市諏訪野町２４５６番地の１',
        industry='銀行業',
        sec_code='83980',
        corporate_number='6290001049168',
    ),
    'E03593': EdinetCodeEntry(
        edinet_code='E03593',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=24404,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000十八銀行',
        submitter_name_en='The Eighteenth Bank,Limited',
        submitter_name_yomi='カブシキガイシャジュウハチギンコウ',
        address='長崎市銅座町１番１１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='7310001000829',
    ),
    'E03596': EdinetCodeEntry(
        edinet_code='E03596',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19598,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大分銀行',
        submitter_name_en='THE OITA BANK, LTD.',
        submitter_name_yomi='カブシキガイシャオオイタギンコウ',
        address='大分市府内町３丁目４番１号',
        industry='銀行業',
        sec_code='83920',
        corporate_number='7320001000084',
    ),
    'E03597': EdinetCodeEntry(
        edinet_code='E03597',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14697,
        fiscal_year_end='3月31日',
        submitter_name='株式会社宮崎銀行',
        submitter_name_en='The Miyazaki Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャミヤザキギンコウ',
        address='宮崎市橘通東四丁目３番５号',
        industry='銀行業',
        sec_code='83930',
        corporate_number='4350001001677',
    ),
    'E03599': EdinetCodeEntry(
        edinet_code='E03599',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16062,
        fiscal_year_end='3月31日',
        submitter_name='株式会社佐賀銀行',
        submitter_name_en='THE BANK OF SAGA LTD.',
        submitter_name_yomi='カブシキガイシャサガギンコウ',
        address='佐賀市唐人二丁目７番２０号',
        industry='銀行業',
        sec_code='83950',
        corporate_number='9300001000183',
    ),
    'E03600': EdinetCodeEntry(
        edinet_code='E03600',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5481,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000但馬銀行',
        submitter_name_en='The Tajima Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000タジマギンコウ',
        address='豊岡市千代田町１番５号',
        industry='銀行業',
        sec_code=None,
        corporate_number='3140001055984',
    ),
    'E03601': EdinetCodeEntry(
        edinet_code='E03601',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=36986,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000みちのく銀行',
        submitter_name_en='THE MICHINOKU BANK,LTD.',
        submitter_name_yomi='カブシキガイシャミチノクギンコウ',
        address='青森市勝田一丁目３番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1420001000014',
    ),
    'E03602': EdinetCodeEntry(
        edinet_code='E03602',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54127,
        fiscal_year_end='3月31日',
        submitter_name='株式会社琉球銀行',
        submitter_name_en='Bank of The Ryukyus,Limited',
        submitter_name_yomi='カブシキガイシャリュウキュウギンコウ',
        address='那覇市久茂地一丁目１１番１号',
        industry='銀行業',
        sec_code='83990',
        corporate_number='6360001000404',
    ),
    'E03603': EdinetCodeEntry(
        edinet_code='E03603',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=22725,
        fiscal_year_end='3月31日',
        submitter_name='株式会社沖縄銀行',
        submitter_name_en='The Bank of Okinawa,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000オキナワギンコウ',
        address='那覇市久茂地３丁目１０番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='4360001000406',
    ),
    'E03604': EdinetCodeEntry(
        edinet_code='E03604',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=85745,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000西日本シティ銀行',
        submitter_name_en='THE NISHI-NIPPON CITY BANK,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ニシニッポンシティギンコウ',
        address='福岡市博多区博多駅前三丁目１番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8290001004344',
    ),
    'E03606': EdinetCodeEntry(
        edinet_code='E03606',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2141513,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三菱ＵＦＪフィナンシャル・グループ',
        submitter_name_en='Mitsubishi UFJ Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシヤミツビシユーエフジエイフイナンシヤルグループ',
        address='千代田区丸の内一丁目４番５号',
        industry='銀行業',
        sec_code='83060',
        corporate_number='4010001073486',
    ),
    'E03610': EdinetCodeEntry(
        edinet_code='E03610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50552,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000りそなホールディングス',
        submitter_name_en='Resona Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャリソナホールディングス',
        address='江東区木場一丁目５番６５号',
        industry='銀行業',
        sec_code='83080',
        corporate_number='5010601039654',
    ),
    'E03611': EdinetCodeEntry(
        edinet_code='E03611',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=261608,
        fiscal_year_end='3月31日',
        submitter_name='三井住友トラストグループ株式会社',
        submitter_name_en='Sumitomo Mitsui Trust Group, Inc.',
        submitter_name_yomi='ミツイスミトモトラストグループカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号',
        industry='銀行業',
        sec_code='83090',
        corporate_number='9010001139555',
    ),
    'E03614': EdinetCodeEntry(
        edinet_code='E03614',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2346888,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三井住友フィナンシャルグループ',
        submitter_name_en='Sumitomo Mitsui Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャミツイスミトモフィナンシャルグループ',
        address='千代田区丸の内一丁目１番２号',
        industry='銀行業',
        sec_code='83160',
        corporate_number='2010001081053',
    ),
    'E03615': EdinetCodeEntry(
        edinet_code='E03615',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2256767,
        fiscal_year_end='3月31日',
        submitter_name='株式会社みずほフィナンシャルグループ',
        submitter_name_en='Mizuho Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャミズホフィナンシャルグループ',
        address='千代田区大手町一丁目５番５号',
        industry='銀行業',
        sec_code='84110',
        corporate_number='9010001081419',
    ),
    'E03617': EdinetCodeEntry(
        edinet_code='E03617',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1771093,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三井住友銀行',
        submitter_name_en='Sumitomo Mitsui Banking Corporation',
        submitter_name_yomi='カブシキガイシャミツイスミトモギンコウ',
        address='千代田区丸の内一丁目１番２号',
        industry='銀行業',
        sec_code=None,
        corporate_number='5010001008813',
    ),
    'E03618': EdinetCodeEntry(
        edinet_code='E03618',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=70895,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ほくほくフィナンシャルグループ',
        submitter_name_en='Hokuhoku Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャホクホクフィナンシャルグループ',
        address='富山市堤町通り１丁目２番２６号',
        industry='銀行業',
        sec_code='83770',
        corporate_number='1230001004554',
    ),
    'E03619': EdinetCodeEntry(
        edinet_code='E03619',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=26000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京スター銀行',
        submitter_name_en='The Tokyo Star Bank, Limited',
        submitter_name_yomi='カブシキガイシャ\u3000トウキョウスターギンコウ',
        address='港区赤坂二丁目３番５号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8010401043556',
    ),
    'E03621': EdinetCodeEntry(
        edinet_code='E03621',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32642,
        fiscal_year_end='3月31日',
        submitter_name='楽天銀行株式会社',
        submitter_name_en='Rakuten Bank, Ltd.',
        submitter_name_yomi='ラクテンギンコウカブシキガイシャ',
        address='港区港南二丁目１６番５号',
        industry='銀行業',
        sec_code='58380',
        corporate_number='5010701022527',
    ),
    'E03622': EdinetCodeEntry(
        edinet_code='E03622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山口フィナンシャルグループ',
        submitter_name_en='Yamaguchi Finacial Group,Inc.',
        submitter_name_yomi='カブシキガイシャヤマグチフィナンシャルグループ',
        address='下関市竹崎町４丁目２番３６号',
        industry='銀行業',
        sec_code='84180',
        corporate_number='5250001007270',
    ),
    'E03623': EdinetCodeEntry(
        edinet_code='E03623',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30724,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セブン銀行',
        submitter_name_en='Seven Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャセブンギンコウ',
        address='千代田区丸の内１－６－１丸の内センタービルディング',
        industry='銀行業',
        sec_code='84100',
        corporate_number='5010001073618',
    ),
    'E03624': EdinetCodeEntry(
        edinet_code='E03624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=124799,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ふくおかフィナンシャルグループ',
        submitter_name_en='Fukuoka Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャフクオカフィナンシャルグループ',
        address='福岡市中央区大手門一丁目８番３号',
        industry='銀行業',
        sec_code='83540',
        corporate_number='9290001028986',
    ),
    'E03625': EdinetCodeEntry(
        edinet_code='E03625',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=70000,
        fiscal_year_end=None,
        submitter_name='株式会社埼玉りそな銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサイタマリソナギンコウ',
        address='さいたま市浦和区常盤７－４－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8030001009848',
    ),
    'E03626': EdinetCodeEntry(
        edinet_code='E03626',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=324279,
        fiscal_year_end='3月31日',
        submitter_name='三菱ＵＦＪ信託銀行株式会社',
        submitter_name_en='Mitsubishi UFJ Trust and Banking Corporation',
        submitter_name_yomi='ミツビシユーエフジェイシンタクギンコウカブシキカイシャ',
        address='千代田区丸の内一丁目４番５号',
        industry='銀行業',
        sec_code=None,
        corporate_number='6010001008770',
    ),
    'E03627': EdinetCodeEntry(
        edinet_code='E03627',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=342037,
        fiscal_year_end='3月31日',
        submitter_name='三井住友信託銀行株式会社',
        submitter_name_en='Sumitomo Mitsui Trust Bank,Limited',
        submitter_name_yomi='ミツイスミトモシンタクギンコウカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='2010001146005',
    ),
    'E03628': EdinetCodeEntry(
        edinet_code='E03628',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=247369,
        fiscal_year_end='3月31日',
        submitter_name='みずほ信託銀行株式会社',
        submitter_name_en='Mizuho Trust & Banking Co.,Ltd.',
        submitter_name_yomi='ミズホシンタクギンコウカブシキガイシャ',
        address='千代田区丸の内一丁目３番３号',
        industry='銀行業',
        sec_code=None,
        corporate_number='9010001034962',
    ),
    'E03632': EdinetCodeEntry(
        edinet_code='E03632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=121101,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北洋銀行',
        submitter_name_en='North Pacific Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ホクヨウギンコウ',
        address='札幌市中央区大通西３丁目７番地',
        industry='銀行業',
        sec_code='85240',
        corporate_number='8430001022711',
    ),
    'E03634': EdinetCodeEntry(
        edinet_code='E03634',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7761,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000北日本銀行',
        submitter_name_en='The Kita-Nippon Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000キタニッポンギンコウ',
        address='盛岡市中央通一丁目６番７号',
        industry='銀行業',
        sec_code='85510',
        corporate_number='8400001001882',
    ),
    'E03637': EdinetCodeEntry(
        edinet_code='E03637',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19638,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000福島銀行',
        submitter_name_en='THE FUKUSHIMA BANK, LTD.',
        submitter_name_yomi='カブシキガイシャフクシマギンコウ',
        address='福島市万世町２番５号',
        industry='銀行業',
        sec_code='85620',
        corporate_number='4380001001393',
    ),
    'E03639': EdinetCodeEntry(
        edinet_code='E03639',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27408,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000栃木銀行',
        submitter_name_en='THE TOCHIGI BANK, LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000トチギギンコウ',
        address='宇都宮市西２－１－１８',
        industry='銀行業',
        sec_code='85500',
        corporate_number='5060001000014',
    ),
    'E03640': EdinetCodeEntry(
        edinet_code='E03640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38653,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東和銀行',
        submitter_name_en='THE TOWA BANK,LTD.',
        submitter_name_yomi='カブシキガイシャトウワギンコウ',
        address='前橋市本町二丁目１２番６号',
        industry='銀行業',
        sec_code='85580',
        corporate_number='2070001003514',
    ),
    'E03641': EdinetCodeEntry(
        edinet_code='E03641',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=49759,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000京葉銀行',
        submitter_name_en='The Keiyo Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャケイヨウギンコウ',
        address='千葉市中央区富士見一丁目１１番１１号',
        industry='銀行業',
        sec_code='85440',
        corporate_number='5040001000008',
    ),
    'E03642': EdinetCodeEntry(
        edinet_code='E03642',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=38300,
        fiscal_year_end=None,
        submitter_name='株式会社東日本銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒガシニッポンギンコウ',
        address='中央区日本橋三丁目十一番二号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001034913',
    ),
    'E03645': EdinetCodeEntry(
        edinet_code='E03645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大光銀行',
        submitter_name_en='THE TAIKO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャタイコウギンコウ',
        address='長岡市大手通一丁目５番地６',
        industry='銀行業',
        sec_code='85370',
        corporate_number='5110001022754',
    ),
    'E03646': EdinetCodeEntry(
        edinet_code='E03646',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10182,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000富山第一銀行',
        submitter_name_en='THE FIRST BANK OF TOYAMA, LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000トヤマダイイチギンコウ',
        address='富山市西町５番１号',
        industry='銀行業',
        sec_code='71840',
        corporate_number='8230001002106',
    ),
    'E03647': EdinetCodeEntry(
        edinet_code='E03647',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9800,
        fiscal_year_end='3月31日',
        submitter_name='株式会社福邦銀行',
        submitter_name_en='THE FUKUHO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャフクホウギンコウ',
        address='福井市順化１丁目６番９号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8210001003262',
    ),
    'E03648': EdinetCodeEntry(
        edinet_code='E03648',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社静岡中央銀行',
        submitter_name_en='THE SHIZUOKA CHUO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャシズオカチュウオウギンコウ',
        address='沼津市大手町四丁目７６番地',
        industry='銀行業',
        sec_code=None,
        corporate_number='8080101000735',
    ),
    'E03651': EdinetCodeEntry(
        edinet_code='E03651',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=18000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社愛知銀行',
        submitter_name_en='The Aichi Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャアイチギンコウ',
        address='名古屋市中区栄三丁目１４番１２号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8180001036373',
    ),
    'E03652': EdinetCodeEntry(
        edinet_code='E03652',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25090,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000名古屋銀行',
        submitter_name_en='The Bank of Nagoya, Ltd.',
        submitter_name_yomi='カブシキガイシャナゴヤギンコウ',
        address='名古屋市中区錦三丁目１９番１７号',
        industry='銀行業',
        sec_code='85220',
        corporate_number='8180001036398',
    ),
    'E03653': EdinetCodeEntry(
        edinet_code='E03653',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=31879,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中京銀行',
        submitter_name_en='The Chukyo Bank, Limited',
        submitter_name_yomi='カブシキガイシャチュウキョウギンコウ',
        address='名古屋市中区栄三丁目３３番１３号',
        industry='銀行業',
        sec_code=None,
        corporate_number='6180001036391',
    ),
    'E03654': EdinetCodeEntry(
        edinet_code='E03654',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=37461,
        fiscal_year_end=None,
        submitter_name='株式会社第三銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイサンギンコウ',
        address='松阪市京町５１０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2190001010309',
    ),
    'E03656': EdinetCodeEntry(
        edinet_code='E03656',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=47039,
        fiscal_year_end=None,
        submitter_name='株式会社関西アーバン銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカンサイアーバンギンコウ',
        address='大阪市中央区西心斎橋１丁目２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001076365',
    ),
    'E03657': EdinetCodeEntry(
        edinet_code='E03657',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27484,
        fiscal_year_end=None,
        submitter_name='株式会社みなと銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミナトギンコウ',
        address='神戸市中央区三宮町２丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140001000027',
    ),
    'E03659': EdinetCodeEntry(
        edinet_code='E03659',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='株式会社もみじ銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモミジギンコウ',
        address='広島市中区胡町１番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001012810',
    ),
    'E03660': EdinetCodeEntry(
        edinet_code='E03660',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=28497,
        fiscal_year_end='3月31日',
        submitter_name='株式会社西京銀行',
        submitter_name_en='THE SAIKYO BANK, LTD.',
        submitter_name_yomi='カブシキガイシャサイキョウギンコウ',
        address='周南市平和通一丁目１０番の２',
        industry='銀行業',
        sec_code=None,
        corporate_number='8250001008844',
    ),
    'E03663': EdinetCodeEntry(
        edinet_code='E03663',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21359,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000愛媛銀行',
        submitter_name_en='The Ehime Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000エヒメギンコウ',
        address='松山市勝山町２丁目１番地',
        industry='銀行業',
        sec_code='85410',
        corporate_number='2500001000005',
    ),
    'E03664': EdinetCodeEntry(
        edinet_code='E03664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15444,
        fiscal_year_end='3月31日',
        submitter_name='株式会社高知銀行',
        submitter_name_en='THE BANK OF KOCHI,LTD',
        submitter_name_yomi='カブシキガイシャコウチギンコウ',
        address='高知市堺町２番２４号',
        industry='銀行業',
        sec_code='84160',
        corporate_number='4490001000608',
    ),
    'E03666': EdinetCodeEntry(
        edinet_code='E03666',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社福岡中央銀行',
        submitter_name_en='THE FUKUOKA CHUO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャフクオカチュウオウギンコウ',
        address='福岡市中央区大名２丁目１２番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='9290001004368',
    ),
    'E03669': EdinetCodeEntry(
        edinet_code='E03669',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12252,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000宮崎太陽銀行',
        submitter_name_en='The Miyazaki Taiyo Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ミヤザキタイヨウギンコウ',
        address='宮崎市広島２丁目１番３１号',
        industry='銀行業',
        sec_code='85600',
        corporate_number='6350001001824',
    ),
    'E03670': EdinetCodeEntry(
        edinet_code='E03670',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13351,
        fiscal_year_end='3月31日',
        submitter_name='株式会社南日本銀行',
        submitter_name_en='The Minami-Nippon Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャミナミニッポンギンコウ',
        address='鹿児島市山下町１－１',
        industry='銀行業',
        sec_code='85540',
        corporate_number='7340001004232',
    ),
    'E03672': EdinetCodeEntry(
        edinet_code='E03672',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6191,
        fiscal_year_end='3月31日',
        submitter_name='株式会社神奈川銀行',
        submitter_name_en='THE KANAGAWA BANK, LTD.',
        submitter_name_yomi='カブシキガイシャカナガワギンコウ',
        address='横浜市\u3000中区\u3000長者町\u3000９丁目１６６番地',
        industry='銀行業',
        sec_code=None,
        corporate_number='7020001011062',
    ),
    'E03673': EdinetCodeEntry(
        edinet_code='E03673',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12495,
        fiscal_year_end='3月31日',
        submitter_name='株式会社豊和銀行',
        submitter_name_en='THE HOWA BANK,LTD.',
        submitter_name_yomi='カブシキガイシャホウワギンコウ',
        address='大分市王子中町４番１０号',
        industry='銀行業',
        sec_code='85590',
        corporate_number='3320001002530',
    ),
    'E03674': EdinetCodeEntry(
        edinet_code='E03674',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14743,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大東銀行',
        submitter_name_en='THE DAITO BANK, LTD.',
        submitter_name_yomi='カブシキガイシャダイトウギンコウ',
        address='郡山市中町１９番１号',
        industry='銀行業',
        sec_code='85630',
        corporate_number='7380001005689',
    ),
    'E03676': EdinetCodeEntry(
        edinet_code='E03676',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2679,
        fiscal_year_end='3月31日',
        submitter_name='株式会社佐賀共栄銀行',
        submitter_name_en='THE SAGA KYOEI BANK, LTD.',
        submitter_name_yomi='カブシキガイシャサガキョウエイギンコウ',
        address='佐賀市松原四丁目２番１２号',
        industry='銀行業',
        sec_code=None,
        corporate_number='8300001000201',
    ),
    'E03678': EdinetCodeEntry(
        edinet_code='E03678',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14310,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トマト銀行',
        submitter_name_en='TOMATO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャトマトギンコウ',
        address='岡山市北区番町二丁目３番４号',
        industry='銀行業',
        sec_code='85420',
        corporate_number='7260001006096',
    ),
    'E03679': EdinetCodeEntry(
        edinet_code='E03679',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7886,
        fiscal_year_end='3月31日',
        submitter_name='株式会社島根銀行',
        submitter_name_en='THE SHIMANE BANK,LTD.',
        submitter_name_yomi='カブシキガイシャシマネギンコウ',
        address='松江市朝日町４８４番地１９',
        industry='銀行業',
        sec_code='71500',
        corporate_number='8280001000328',
    ),
    'E03683': EdinetCodeEntry(
        edinet_code='E03683',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4537,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000沖縄海邦銀行',
        submitter_name_en='THE OKINAWA KAIHO BANK,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000オキナワカイホウギンコウ',
        address='那覇市久茂地２丁目９番地１２号',
        industry='銀行業',
        sec_code=None,
        corporate_number='5360001000405',
    ),
    'E03684': EdinetCodeEntry(
        edinet_code='E03684',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社長野銀行',
        submitter_name_en='THE NAGANOBANK,LTD.',
        submitter_name_yomi='カブシキガイシャナガノギンコウ',
        address='松本市渚２丁目９番３８号',
        industry='銀行業',
        sec_code=None,
        corporate_number='9100001013701',
    ),
    'E03686': EdinetCodeEntry(
        edinet_code='E03686',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=43734,
        fiscal_year_end='3月31日',
        submitter_name='株式会社きらぼし銀行',
        submitter_name_en='Kiraboshi Bank, Ltd.',
        submitter_name_yomi='カブシキガイシャキラボシギンコウ',
        address='港区南青山三丁目１０番４３号',
        industry='銀行業',
        sec_code=None,
        corporate_number='4011101011492',
    ),
    'E03688': EdinetCodeEntry(
        edinet_code='E03688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='日本証券金融株式会社',
        submitter_name_en='Japan Securities Finance Co.,Ltd.',
        submitter_name_yomi='ニホンショウケンキンユウカブシキガイシャ',
        address='中央区日本橋茅場町一丁目２番１０号',
        industry='その他金融業',
        sec_code='85110',
        corporate_number='3010001034992',
    ),
    'E03690': EdinetCodeEntry(
        edinet_code='E03690',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='中部証券金融株式会社',
        submitter_name_en='CHUBU SECURITIES FINANCING CO.,LTD.',
        submitter_name_yomi='チュウブショウケンキンユウカブシキガイシャ',
        address='名古屋市中区栄三丁目８番２０号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4180001038142',
    ),
    'E03691': EdinetCodeEntry(
        edinet_code='E03691',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=170,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日貿信',
        submitter_name_en='Nichiboshin, Ltd.',
        submitter_name_yomi='カブシキガイシャニチボウシン',
        address='中央区日本橋１丁目１２番８号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010001053582',
    ),
    'E03693': EdinetCodeEntry(
        edinet_code='E03693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=63832,
        fiscal_year_end='3月31日',
        submitter_name='アコム株式会社',
        submitter_name_en='ACOM CO.,LTD.',
        submitter_name_yomi='アコムカブシキガイシャ',
        address='港区東新橋一丁目９番１号',
        industry='その他金融業',
        sec_code='85720',
        corporate_number='6010001023778',
    ),
    'E03695': EdinetCodeEntry(
        edinet_code='E03695',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5426,
        fiscal_year_end='3月31日',
        submitter_name='日本アジア投資株式会社',
        submitter_name_en='Japan Asia Investment Company, Limited',
        submitter_name_yomi='ニホンアジアトウシカブシキガイシャ',
        address='千代田区九段北三丁目２番４号',
        industry='証券、商品先物取引業',
        sec_code='85180',
        corporate_number='6010001032820',
    ),
    'E03697': EdinetCodeEntry(
        edinet_code='E03697',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15000,
        fiscal_year_end=None,
        submitter_name='株式会社アプラスフィナンシャル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアプラスフィナンシャル',
        address='大阪市浪速区湊町一丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001073924',
    ),
    'E03711': EdinetCodeEntry(
        edinet_code='E03711',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1800,
        fiscal_year_end='3月31日',
        submitter_name='財形住宅金融株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ザイケイジュウタクキンユウカブシキガイシャ',
        address='港区港南４－１－８',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4010001017484',
    ),
    'E03716': EdinetCodeEntry(
        edinet_code='E03716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1722,
        fiscal_year_end='3月31日',
        submitter_name='豊トラスティ証券株式会社',
        submitter_name_en='YUTAKA TRUSTY SECURITIES CO., LTD.',
        submitter_name_yomi='ユタカトラスティショウケンカブシキガイシャ',
        address='中央区日本橋蛎殻町１－１６－１２',
        industry='証券、商品先物取引業',
        sec_code='87470',
        corporate_number='6010001059649',
    ),
    'E03717': EdinetCodeEntry(
        edinet_code='E03717',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ｕｎｂａｎｋｅｄ株式会社',
        submitter_name_en='unbanked inc.',
        submitter_name_yomi='アンバンクカブシキガイシャ',
        address='渋谷区恵比寿１丁目１８番１４号',
        industry='証券、商品先物取引業',
        sec_code='87460',
        corporate_number='2011001013038',
    ),
    'E03719': EdinetCodeEntry(
        edinet_code='E03719',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='ユニコムグループホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユニコムグループホールディングスカブシキカイシャ',
        address='中央区銀座四丁目１４番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001062570',
    ),
    'E03721': EdinetCodeEntry(
        edinet_code='E03721',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=94028,
        fiscal_year_end='3月31日',
        submitter_name='アイフル株式会社',
        submitter_name_en='AIFUL CORPORATION',
        submitter_name_yomi='アイフルカブシキガイシャ',
        address='京都市下京区烏丸通五条上る高砂町３８１－１',
        industry='その他金融業',
        sec_code='85150',
        corporate_number='3130001000082',
    ),
    'E03723': EdinetCodeEntry(
        edinet_code='E03723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社小林洋行',
        submitter_name_en='KOBAYASHI YOKO CO.,LTD.',
        submitter_name_yomi='カブシキカイシャコバヤシヨウコウ',
        address='中央区日本橋蛎殻町一丁目１５番７号',
        industry='証券、商品先物取引業',
        sec_code='87420',
        corporate_number='5010001043372',
    ),
    'E03724': EdinetCodeEntry(
        edinet_code='E03724',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='12月31日',
        submitter_name='Ｊトラスト株式会社',
        submitter_name_en='J Trust Co.,Ltd.',
        submitter_name_yomi='ジェイトラスト\u3000カブシキガイシャ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='その他金融業',
        sec_code='85080',
        corporate_number='2010401094729',
    ),
    'E03727': EdinetCodeEntry(
        edinet_code='E03727',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='フューチャーベンチャーキャピタル株式会社',
        submitter_name_en='Future Venture Capital  Co., Ltd.',
        submitter_name_yomi='フューチャーベンチャーキャピタルカブシキガイシャ',
        address='京都市中京区烏丸通錦小路上ル手洗水町６５９番地',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='3130001022390',
    ),
    'E03728': EdinetCodeEntry(
        edinet_code='E03728',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1200,
        fiscal_year_end='3月31日',
        submitter_name='フジトミ証券株式会社',
        submitter_name_en='FUJITOMI SECURITIES CO., LTD.',
        submitter_name_yomi='フジトミショウケンカブシキガイシャ',
        address='中央区日本橋蛎殻町一丁目１５番５号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='5010001144278',
    ),
    'E03729': EdinetCodeEntry(
        edinet_code='E03729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=890998,
        fiscal_year_end='3月31日',
        submitter_name='信金中央金庫',
        submitter_name_en='Shinkin Central Bank',
        submitter_name_yomi='シンキンチュウオウキンコ',
        address='中央区八重洲一丁目３番７号',
        industry='その他金融業',
        sec_code='84210',
        corporate_number='3010005002392',
    ),
    'E03730': EdinetCodeEntry(
        edinet_code='E03730',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=11090,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホンダファイナンス',
        submitter_name_en='HONDA FINANCE CO., LTD.',
        submitter_name_yomi='カブシキガイシャホンダファイナンス',
        address='武蔵野市中町二丁目４番１５号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='1012401020392',
    ),
    'E03732': EdinetCodeEntry(
        edinet_code='E03732',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='株式会社エム・オー・エー基金',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000エムオーエーキキン',
        address='熱海市田原本町９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080101012975',
    ),
    'E03733': EdinetCodeEntry(
        edinet_code='E03733',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5665,
        fiscal_year_end='3月31日',
        submitter_name='株式会社あかつき本社',
        submitter_name_en='Akatsuki Corp.',
        submitter_name_yomi='カブシキガイシャアカツキホンシャ',
        address='中央区日本橋小舟町８番１号',
        industry='証券、商品先物取引業',
        sec_code='87370',
        corporate_number='4010001134040',
    ),
    'E03736': EdinetCodeEntry(
        edinet_code='E03736',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=16387,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日産フィナンシャルサービス',
        submitter_name_en='NISSAN FINANCIAL SERVICES CO.,LTD.',
        submitter_name_yomi='カブシキカイシャニッサンフィナンシャルサービス',
        address='千葉市美浜区中瀬二丁目６番地１',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6040001013529',
    ),
    'E03738': EdinetCodeEntry(
        edinet_code='E03738',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1060,
        fiscal_year_end='3月31日',
        submitter_name='全宅住宅ローン株式会社',
        submitter_name_en='Zentaku Housing Loan Corporation',
        submitter_name_yomi='ゼンタクジュウタクローンカブシキガイシャ',
        address='千代田区内神田２－１６－９',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4010001090655',
    ),
    'E03739': EdinetCodeEntry(
        edinet_code='E03739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1701,
        fiscal_year_end='3月31日',
        submitter_name='日産証券グループ株式会社',
        submitter_name_en='Nissan Securities Group Co.,Ltd.',
        submitter_name_yomi='ニッサンショウケングループカブシキガイシャ',
        address='中央区銀座６丁目１０番１号',
        industry='証券、商品先物取引業',
        sec_code='87050',
        corporate_number='4120001110534',
    ),
    'E03740': EdinetCodeEntry(
        edinet_code='E03740',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=820,
        fiscal_year_end='8月31日',
        submitter_name='ａｂｃ株式会社',
        submitter_name_en='abc Co.,Ltd.',
        submitter_name_yomi='エービーシーカブシキガイシャ',
        address='港区赤坂四丁目９番１７号',
        industry='その他金融業',
        sec_code='87830',
        corporate_number='9010401047481',
    ),
    'E03745': EdinetCodeEntry(
        edinet_code='E03745',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8021,
        fiscal_year_end='3月31日',
        submitter_name='北浜キャピタルパートナーズ株式会社',
        submitter_name_en='Kitahama Capital Partners Co.,Ltd.',
        submitter_name_yomi='キタハマキャピタルパートナーズカブシキガイシャ',
        address='大阪市中央区北浜二丁目１番１７号',
        industry='サービス業',
        sec_code='21340',
        corporate_number='4120001048543',
    ),
    'E03746': EdinetCodeEntry(
        edinet_code='E03746',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2307,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アサックス',
        submitter_name_en='ASAX CO., LTD.',
        submitter_name_yomi='カブシキガイシャアサックス',
        address='渋谷区広尾一丁目３番１４号',
        industry='その他金融業',
        sec_code='87720',
        corporate_number='6011001044302',
    ),
    'E03747': EdinetCodeEntry(
        edinet_code='E03747',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2022,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マネーパートナーズグループ',
        submitter_name_en='MONEY PARTNERS GROUP CO,.LTD.',
        submitter_name_yomi='カブシキガイシャマネーパートナーズグループ',
        address='港区六本木一三丁目２番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='2010401057917',
    ),
    'E03749': EdinetCodeEntry(
        edinet_code='E03749',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1224,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マネースクウェアＨＤ',
        submitter_name_en='MONEY SQUARE HOLDINGS, INC.',
        submitter_name_yomi='カブシキガイシャマネースクウェアエイチディ',
        address='港区赤坂九丁目７番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='4010001177766',
    ),
    'E03752': EdinetCodeEntry(
        edinet_code='E03752',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=594493,
        fiscal_year_end='3月31日',
        submitter_name='野村ホールディングス株式会社',
        submitter_name_en='Nomura Holdings, Inc.',
        submitter_name_yomi='ノムラホールディングスカブシキガイシャ',
        address='中央区日本橋一丁目１３番１号',
        industry='証券、商品先物取引業',
        sec_code='86040',
        corporate_number='7010001034881',
    ),
    'E03753': EdinetCodeEntry(
        edinet_code='E03753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=247397,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大和証券グループ本社',
        submitter_name_en='Daiwa Securities Group Inc.',
        submitter_name_yomi='カブシキガイシャダイワショウケングループホンシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='証券、商品先物取引業',
        sec_code='86010',
        corporate_number='4010001008855',
    ),
    'E03756': EdinetCodeEntry(
        edinet_code='E03756',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18589,
        fiscal_year_end='3月31日',
        submitter_name='株式会社岡三証券グループ',
        submitter_name_en='OKASAN SECURITIES GROUP INC.',
        submitter_name_yomi='カブシキガイシャオカサンショウケングループ',
        address='中央区日本橋室町二丁目２番１号',
        industry='証券、商品先物取引業',
        sec_code='86090',
        corporate_number='1010001034747',
    ),
    'E03759': EdinetCodeEntry(
        edinet_code='E03759',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=125167,
        fiscal_year_end='3月31日',
        submitter_name='みずほ証券株式会社',
        submitter_name_en='Mizuho Securities Co., Ltd.',
        submitter_name_yomi='ミズホショウケンカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='7010001008687',
    ),
    'E03760': EdinetCodeEntry(
        edinet_code='E03760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='丸三証券株式会社',
        submitter_name_en='Marusan Securities Co.,Ltd.',
        submitter_name_yomi='マルサンショウケンカブシキガイシャ',
        address='千代田区麹町三丁目３番６',
        industry='証券、商品先物取引業',
        sec_code='86130',
        corporate_number='1010001057236',
    ),
    'E03761': EdinetCodeEntry(
        edinet_code='E03761',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='むさし証券株式会社',
        submitter_name_en='Musashi Securities Co.,Ltd.',
        submitter_name_yomi='ムサシシヨウケンカブシキガイシヤ',
        address='さいたま市大宮区桜木町四丁目３３３番地１３',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='7030001016837',
    ),
    'E03762': EdinetCodeEntry(
        edinet_code='E03762',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=12272,
        fiscal_year_end='3月31日',
        submitter_name='水戸証券株式会社',
        submitter_name_en='Mito Securities Co., Ltd.',
        submitter_name_yomi='ミトショウケンカブシキガイシャ',
        address='文京区小石川一丁目１番１号',
        industry='証券、商品先物取引業',
        sec_code='86220',
        corporate_number='6010001058238',
    ),
    'E03763': EdinetCodeEntry(
        edinet_code='E03763',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8000,
        fiscal_year_end='3月31日',
        submitter_name='アイザワ証券グループ株式会社',
        submitter_name_en='AIZAWA SECURITIES GROUP CO., LTD.',
        submitter_name_yomi='アイザワショウケングループカブシキガイシャ',
        address='港区東新橋一丁目９番１号',
        industry='証券、商品先物取引業',
        sec_code='87080',
        corporate_number='5010001036574',
    ),
    'E03764': EdinetCodeEntry(
        edinet_code='E03764',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36000,
        fiscal_year_end='3月31日',
        submitter_name='東海東京フィナンシャル・ホールディングス株式会社',
        submitter_name_en='Tokai Tokyo Financial Holdings, Inc.',
        submitter_name_yomi='トウカイトウキョウフィナンシャルホールディングスカブシキガイシャ',
        address='中央区日本橋二丁目５番１号',
        industry='証券、商品先物取引業',
        sec_code='86160',
        corporate_number='1010001034202',
    ),
    'E03768': EdinetCodeEntry(
        edinet_code='E03768',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13494,
        fiscal_year_end='3月31日',
        submitter_name='東洋証券株式会社',
        submitter_name_en='TOYO SECURITIES CO., LTD.',
        submitter_name_yomi='トウヨウショウケンカブシキガイシャ',
        address='中央区八丁堀４丁目７番１号',
        industry='証券、商品先物取引業',
        sec_code='86140',
        corporate_number='7010001051893',
    ),
    'E03770': EdinetCodeEntry(
        edinet_code='E03770',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12223,
        fiscal_year_end='3月31日',
        submitter_name='ＨＳホールディングス株式会社',
        submitter_name_en='HS Holdings Co.,Ltd.',
        submitter_name_yomi='エイチエスホールディングスカブシキガイシャ',
        address='港区虎ノ門五丁目１１番１号',
        industry='証券、商品先物取引業',
        sec_code='86990',
        corporate_number='4011101034411',
    ),
    'E03771': EdinetCodeEntry(
        edinet_code='E03771',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=75518,
        fiscal_year_end='3月31日',
        submitter_name='三菱ＵＦＪ証券ホールディングス株式会社',
        submitter_name_en='Mitsubishi UFJ Securities Holdings Co.,Ltd.',
        submitter_name_yomi='ミツビシユーエフジェイショウケンホールディングスカブシキガイシャ',
        address='千代田区大手町一丁目９番２号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='2010001062870',
    ),
    'E03772': EdinetCodeEntry(
        edinet_code='E03772',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14577,
        fiscal_year_end='3月31日',
        submitter_name='いちよし証券株式会社',
        submitter_name_en='Ichiyoshi Securities Co.,Ltd.',
        submitter_name_yomi='イチヨシショウケンカブシキガイシャ',
        address='中央区日本橋茅場町一丁目５番８号',
        industry='証券、商品先物取引業',
        sec_code='86240',
        corporate_number='7010001036845',
    ),
    'E03776': EdinetCodeEntry(
        edinet_code='E03776',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8932,
        fiscal_year_end='3月31日',
        submitter_name='株式会社だいこう証券ビジネス',
        submitter_name_en='DSB Co., Ltd.',
        submitter_name_yomi='カブシキガイシャダイコウショウケンビジネス',
        address='江東区潮見二丁目９番１５号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='1010001139323',
    ),
    'E03782': EdinetCodeEntry(
        edinet_code='E03782',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2619,
        fiscal_year_end='3月31日',
        submitter_name='アーク証券株式会社',
        submitter_name_en='ARK SECURITIES Co.,Ltd.',
        submitter_name_yomi='アークショウケンカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号\u3000明治安田生命ビル５階',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='5010001035460',
    ),
    'E03784': EdinetCodeEntry(
        edinet_code='E03784',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5251,
        fiscal_year_end='3月31日',
        submitter_name='極東証券株式会社',
        submitter_name_en='KYOKUTO SECURITIES CO.,LTD.',
        submitter_name_yomi='キョクトウショウケンカブシキカイシャ',
        address='中央区日本橋茅場町一丁目４番７号',
        industry='証券、商品先物取引業',
        sec_code='87060',
        corporate_number='2010001041478',
    ),
    'E03785': EdinetCodeEntry(
        edinet_code='E03785',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2540,
        fiscal_year_end=None,
        submitter_name='豊証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユタカショウケンカブシキカイシャ',
        address='名古屋市中区栄３－７－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001041714',
    ),
    'E03786': EdinetCodeEntry(
        edinet_code='E03786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8831,
        fiscal_year_end=None,
        submitter_name='エース証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エースショウケンカブシキカイシャ',
        address='大阪市中央区本町二丁目６番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001077368',
    ),
    'E03788': EdinetCodeEntry(
        edinet_code='E03788',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10004,
        fiscal_year_end='3月31日',
        submitter_name='岩井コスモホールディングス株式会社',
        submitter_name_en='IwaiCosmo Holdings, Inc.',
        submitter_name_yomi='イワイコスモホールディングスカブシキガイシャ',
        address='大阪市中央区今橋１丁目８番１２号',
        industry='証券、商品先物取引業',
        sec_code='87070',
        corporate_number='3120001074788',
    ),
    'E03789': EdinetCodeEntry(
        edinet_code='E03789',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11069,
        fiscal_year_end=None,
        submitter_name='髙木証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タカギショウケンカブシキガイシャ',
        address='大阪市北区梅田一丁目３番１－４００号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001059656',
    ),
    'E03792': EdinetCodeEntry(
        edinet_code='E03792',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3751,
        fiscal_year_end='3月31日',
        submitter_name='丸八証券株式会社',
        submitter_name_en='Maruhachi Securities Co.,Ltd.',
        submitter_name_yomi='マルハチショウケンカブシキガイシャ',
        address='名古屋市中区新栄町二丁目４番地',
        industry='証券、商品先物取引業',
        sec_code='87000',
        corporate_number='7180001040756',
    ),
    'E03793': EdinetCodeEntry(
        edinet_code='E03793',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=12000,
        fiscal_year_end='3月31日',
        submitter_name='光世証券株式会社',
        submitter_name_en='The Kosei Securities Co.,Ltd',
        submitter_name_yomi='コウセイショウケンカブシキガイシャ',
        address='大阪市中央区北浜二丁目１番１０号',
        industry='証券、商品先物取引業',
        sec_code='86170',
        corporate_number='6120001077409',
    ),
    'E03801': EdinetCodeEntry(
        edinet_code='E03801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2202,
        fiscal_year_end='3月31日',
        submitter_name='ウェルス・マネジメント株式会社',
        submitter_name_en='Wealth Management, Inc.',
        submitter_name_yomi='ウェルスマネジメントカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='不動産業',
        sec_code='37720',
        corporate_number='9010001096862',
    ),
    'E03802': EdinetCodeEntry(
        edinet_code='E03802',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='みらい證券株式会社',
        submitter_name_en='Mirai Securities Co.,Ltd',
        submitter_name_yomi='ミライショウケンカブシキガイシャ',
        address='港区西新橋三丁目４番２号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='7010001058567',
    ),
    'E03803': EdinetCodeEntry(
        edinet_code='E03803',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=13195,
        fiscal_year_end='3月31日',
        submitter_name='マネックス証券株式会社',
        submitter_name_en='Monex, Inc.',
        submitter_name_yomi='マネックスショウケンカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='1010001064546',
    ),
    'E03807': EdinetCodeEntry(
        edinet_code='E03807',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=11945,
        fiscal_year_end='3月31日',
        submitter_name='松井証券株式会社',
        submitter_name_en='MATSUI SECURITIES CO.,LTD.',
        submitter_name_yomi='マツイショウケンカブシキガイシャ',
        address='千代田区麹町一丁目４番地',
        industry='証券、商品先物取引業',
        sec_code='86280',
        corporate_number='2010001057425',
    ),
    'E03810': EdinetCodeEntry(
        edinet_code='E03810',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='野村證券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラショウケンカブシキガイシャ',
        address='中央区日本橋１ー１３ー１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001074037',
    ),
    'E03814': EdinetCodeEntry(
        edinet_code='E03814',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本取引所グループ',
        submitter_name_en='Japan Exchange Group, Inc.',
        submitter_name_yomi='カブシキガイシャニッポントリヒキジョグループ',
        address='中央区日本橋兜町２番１号',
        industry='その他金融業',
        sec_code='86970',
        corporate_number='9120001098575',
    ),
    'E03815': EdinetCodeEntry(
        edinet_code='E03815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13143,
        fiscal_year_end='3月31日',
        submitter_name='マネックスグループ株式会社',
        submitter_name_en='Monex Group, Inc.',
        submitter_name_yomi='マネックスグループカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='証券、商品先物取引業',
        sec_code='86980',
        corporate_number='8010001089066',
    ),
    'E03816': EdinetCodeEntry(
        edinet_code='E03816',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=54323,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＢＩ証券',
        submitter_name_en='SBI SECURITIES Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエスビーアイショウケン',
        address='港区六本木一丁目６番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='3010401049814',
    ),
    'E03817': EdinetCodeEntry(
        edinet_code='E03817',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=7196,
        fiscal_year_end='3月31日',
        submitter_name='三菱ＵＦＪｅスマート証券株式会社',
        submitter_name_en='Mitsubishi UFJ eSmart Securities Co., Ltd.',
        submitter_name_yomi='ミツビシユーエフジェイイースマートショウケンカブシキガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='5010001066670',
    ),
    'E03819': EdinetCodeEntry(
        edinet_code='E03819',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1564,
        fiscal_year_end='3月31日',
        submitter_name='トレイダーズホールディングス株式会社',
        submitter_name_en='Traders Holdings Co.,Ltd.',
        submitter_name_yomi='トレイダーズホールディングスカブシキガイシャ',
        address='渋谷区恵比寿四丁目２０番３号\u3000恵比寿ガーデンプレイスタワー',
        industry='証券、商品先物取引業',
        sec_code='87040',
        corporate_number='5010401039284',
    ),
    'E03821': EdinetCodeEntry(
        edinet_code='E03821',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5965,
        fiscal_year_end='3月31日',
        submitter_name='インヴァスト証券株式会社',
        submitter_name_en='INVAST SECURITIES CO.,LTD',
        submitter_name_yomi='インヴァストショウケンカブシキガイシャ',
        address='中央区東日本橋一丁目５番６号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='4010401068672',
    ),
    'E03823': EdinetCodeEntry(
        edinet_code='E03823',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=101994,
        fiscal_year_end='3月末日',
        submitter_name='東京海上日動火災保険株式会社',
        submitter_name_en='Tokio Marine & Nichido Fire Insurance Co., Ltd.',
        submitter_name_yomi='トウキョウカイジョウニチドウカサイホケンカブシキガイシャ',
        address='千代田区大手町二丁目６番４号',
        industry='保険業',
        sec_code=None,
        corporate_number='2010001008824',
    ),
    'E03824': EdinetCodeEntry(
        edinet_code='E03824',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=139595,
        fiscal_year_end='3月31日',
        submitter_name='三井住友海上火災保険株式会社',
        submitter_name_en='Mitsui Sumitomo Insurance Company, Limited',
        submitter_name_yomi='ミツイスミトモカイジョウカサイホケンカブシキガイシャ',
        address='千代田区神田駿河台三丁目９番地',
        industry='保険業',
        sec_code=None,
        corporate_number='6010001008795',
    ),
    'E03827': EdinetCodeEntry(
        edinet_code='E03827',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=167500,
        fiscal_year_end='3月31日',
        submitter_name='損害保険ジャパン株式会社',
        submitter_name_en='Sompo Japan Insurance Inc.',
        submitter_name_yomi='ソンガイホケンジャパンカブシキガイシャ',
        address='新宿区西新宿一丁目２６番１号',
        industry='保険業',
        sec_code=None,
        corporate_number='4011101023372',
    ),
    'E03833': EdinetCodeEntry(
        edinet_code='E03833',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100005,
        fiscal_year_end='3月末日',
        submitter_name='あいおいニッセイ同和損害保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイオイニッセイドウワソンガイホケンカブシキガイシャ',
        address='渋谷区恵比寿一丁目２８番１号',
        industry='保険業',
        sec_code=None,
        corporate_number='3011001027739',
    ),
    'E03835': EdinetCodeEntry(
        edinet_code='E03835',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10153,
        fiscal_year_end='3月31日',
        submitter_name='楽天損害保険株式会社',
        submitter_name_en='Rakuten General Insurance Co., Ltd.',
        submitter_name_yomi='ラクテンソンガイホケンカブシキガイシャ',
        address='新宿区新宿六丁目２７番３０号',
        industry='保険業',
        sec_code=None,
        corporate_number='7010001008860',
    ),
    'E03837': EdinetCodeEntry(
        edinet_code='E03837',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='西日本建設業保証株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシニホンケンセツギョウホショウカブシキガイシャ',
        address='大阪市西区立売堀二丁目１番２号',
        industry='保険業',
        sec_code=None,
        corporate_number='2120001046185',
    ),
    'E03838': EdinetCodeEntry(
        edinet_code='E03838',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='東日本建設業保証株式会社',
        submitter_name_en='East Japan Construction Surety Co.,Ltd.',
        submitter_name_yomi='ヒガシニホンケンセツギョウホショウカブシキガイシャ',
        address='中央区八丁堀２丁目２７番１０号',
        industry='保険業',
        sec_code=None,
        corporate_number='4010001054874',
    ),
    'E03841': EdinetCodeEntry(
        edinet_code='E03841',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=400,
        fiscal_year_end='3月31日',
        submitter_name='北海道建設業信用保証株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホッカイドウケンセツギョウシンヨウホショウカブシキガイシャ',
        address='札幌市中央区北３条西４丁目１番地４',
        industry='保険業',
        sec_code=None,
        corporate_number='6430001021830',
    ),
    'E03842': EdinetCodeEntry(
        edinet_code='E03842',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='トーア再保険株式会社',
        submitter_name_en='The Toa Reinsurance Company, Limited',
        submitter_name_yomi='トーアサイホケンカブシキガイシャ',
        address='千代田区神田駿河台三丁目６番地の５',
        industry='保険業',
        sec_code=None,
        corporate_number='6010001024000',
    ),
    'E03845': EdinetCodeEntry(
        edinet_code='E03845',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=85000,
        fiscal_year_end='3月31日',
        submitter_name='アクサ生命保険株式会社',
        submitter_name_en='AXA Life Insurance Co.,Ltd.',
        submitter_name_yomi='アクサセイメイホケンカブシキガイシャ',
        address='港区白金一丁目１７番３号',
        industry='保険業',
        sec_code=None,
        corporate_number='8010401060741',
    ),
    'E03846': EdinetCodeEntry(
        edinet_code='E03846',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=110000,
        fiscal_year_end=None,
        submitter_name='大同生命保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイドウセイメイホケンカブシキガイシャ',
        address='大阪市西区江戸堀一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001101172',
    ),
    'E03847': EdinetCodeEntry(
        edinet_code='E03847',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=150000,
        fiscal_year_end='3月末日',
        submitter_name='東京海上ホールディングス株式会社',
        submitter_name_en='Tokio Marine Holdings, Inc.',
        submitter_name_yomi='トウキョウカイジョウホールディングスカブシキガイシャ',
        address='千代田区大手町二丁目６番４号',
        industry='保険業',
        sec_code='87660',
        corporate_number='7010001078061',
    ),
    'E03848': EdinetCodeEntry(
        edinet_code='E03848',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=62500,
        fiscal_year_end=None,
        submitter_name='太陽生命保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウセイメイホケンカブシキガイシャ',
        address='中央区日本橋二丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401063692',
    ),
    'E03850': EdinetCodeEntry(
        edinet_code='E03850',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=52500,
        fiscal_year_end='3月31日',
        submitter_name='共栄火災海上保険株式会社',
        submitter_name_en='The Kyoei Fire and Marine Insurance Company,Limited',
        submitter_name_yomi='キョウエイカサイカイジョウホケンカブシキガイシャ',
        address='港区新橋一丁目１８番６号',
        industry='保険業',
        sec_code=None,
        corporate_number='3010401050012',
    ),
    'E03851': EdinetCodeEntry(
        edinet_code='E03851',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=207111,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｔ＆Ｄホールディングス',
        submitter_name_en='T&D Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャティアンドディホールディングス',
        address='中央区日本橋２丁目７番１号',
        industry='保険業',
        sec_code='87950',
        corporate_number='2010401063502',
    ),
    'E03854': EdinetCodeEntry(
        edinet_code='E03854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=101076,
        fiscal_year_end='3月31日',
        submitter_name='ＭＳ＆ＡＤインシュアランスグループホールディングス株式会社',
        submitter_name_en='MS&AD Insurance Group Holdings, Inc.',
        submitter_name_yomi='エムエスアンドエイディーインシュアランスグループホールディングスカブシキガイシャ',
        address='中央区新川二丁目２７番２号',
        industry='保険業',
        sec_code='87250',
        corporate_number='4010001116542',
    ),
    'E03855': EdinetCodeEntry(
        edinet_code='E03855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=340162,
        fiscal_year_end='3月31日',
        submitter_name='三井不動産株式会社',
        submitter_name_en='Mitsui Fudosan Co., Ltd.',
        submitter_name_yomi='ミツイフドウサンカブシキガイシャ',
        address='中央区日本橋室町二丁目１番１号',
        industry='不動産業',
        sec_code='88010',
        corporate_number='6010001034957',
    ),
    'E03856': EdinetCodeEntry(
        edinet_code='E03856',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=141898,
        fiscal_year_end='3月末日',
        submitter_name='三菱地所株式会社',
        submitter_name_en='Mitsubishi Estate Company, Limited',
        submitter_name_yomi='ミツビシジショカブシキガイシャ',
        address='千代田区大手町一丁目１番１号',
        industry='不動産業',
        sec_code='88020',
        corporate_number='2010001008774',
    ),
    'E03857': EdinetCodeEntry(
        edinet_code='E03857',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57551,
        fiscal_year_end=None,
        submitter_name='東急不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキュウフドウサンカブシキガイシャ',
        address='渋谷区道玄坂一丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001016580',
    ),
    'E03858': EdinetCodeEntry(
        edinet_code='E03858',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21492,
        fiscal_year_end='3月31日',
        submitter_name='平和不動産株式会社',
        submitter_name_en='HEIWA REAL ESTATE CO.,LTD.',
        submitter_name_yomi='ヘイワフドウサンカブシキガイシャ',
        address='中央区日本橋兜町１番１０号',
        industry='不動産業',
        sec_code='88030',
        corporate_number='1010001034920',
    ),
    'E03859': EdinetCodeEntry(
        edinet_code='E03859',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=92451,
        fiscal_year_end='12月31日',
        submitter_name='東京建物株式会社',
        submitter_name_en='Tokyo Tatemono Co., Ltd.',
        submitter_name_yomi='トウキョウタテモノカブシキガイシャ',
        address='中央区八重洲一丁目９番９号',
        industry='不動産業',
        sec_code='88040',
        corporate_number='6010001034998',
    ),
    'E03860': EdinetCodeEntry(
        edinet_code='E03860',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=28120,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンケイビル',
        submitter_name_en='THE SANKEI BUILDING CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサンケイビル',
        address='千代田区大手町一丁目７番２号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010001008688',
    ),
    'E03861': EdinetCodeEntry(
        edinet_code='E03861',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12354,
        fiscal_year_end='3月31日',
        submitter_name='ダイビル株式会社',
        submitter_name_en='DAIBIRU CORPORATION',
        submitter_name_yomi='ダイビルカブシキガイシャ',
        address='大阪市北区中之島３丁目６番３２号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3120001066364',
    ),
    'E03863': EdinetCodeEntry(
        edinet_code='E03863',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17489,
        fiscal_year_end='3月31日',
        submitter_name='日本空港ビルデング株式会社',
        submitter_name_en='Japan Airport Terminal Co.,Ltd.',
        submitter_name_yomi='ニホンクウコウビルデングカブシキガイシャ',
        address='大田区羽田空港三丁目３番２号\u3000第１旅客ターミナルビル',
        industry='不動産業',
        sec_code='97060',
        corporate_number='7010801014496',
    ),
    'E03867': EdinetCodeEntry(
        edinet_code='E03867',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9827,
        fiscal_year_end='3月31日',
        submitter_name='京阪神ビルディング株式会社',
        submitter_name_en='Keihanshin Building Co., Ltd.',
        submitter_name_yomi='ケイハンシンビルディングカブシキガイシャ',
        address='大阪市中央区瓦町４丁目２番１４号',
        industry='不動産業',
        sec_code='88180',
        corporate_number='6120001078852',
    ),
    'E03868': EdinetCodeEntry(
        edinet_code='E03868',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=135,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京建設会館',
        submitter_name_en='TOKYO KENSETSUKAIKAN LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウケンセツカイカン',
        address='中央区八丁堀二丁目８番５号',
        industry='不動産業',
        sec_code=None,
        corporate_number='9010001061271',
    ),
    'E03882': EdinetCodeEntry(
        edinet_code='E03882',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='中央地所株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウオウジショカブシキガイシャ',
        address='名古屋市中区錦三丁目１３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001038005',
    ),
    'E03886': EdinetCodeEntry(
        edinet_code='E03886',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=17000,
        fiscal_year_end='3月31日',
        submitter_name='中央日本土地建物株式会社',
        submitter_name_en='Chuo-Nittochi Co., Ltd.',
        submitter_name_yomi='チュウオウニホントチタテモノカブシキガイシャ',
        address='千代田区霞が関一丁目４番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010001033496',
    ),
    'E03889': EdinetCodeEntry(
        edinet_code='E03889',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社\u3000世界貿易センタービルディング',
        submitter_name_en='World Trade Center Building, Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000セカイボウエキセンタービルディング',
        address='港区浜松町２丁目４番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3010401015634',
    ),
    'E03896': EdinetCodeEntry(
        edinet_code='E03896',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=300,
        fiscal_year_end='12月31日',
        submitter_name='株式会社全国旅館会館',
        submitter_name_en='Zenkokuryokankaikan Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャゼンコクリョカンカイカン',
        address='千代田区平河町２－５－５',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010001020643',
    ),
    'E03907': EdinetCodeEntry(
        edinet_code='E03907',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=122805,
        fiscal_year_end='3月31日',
        submitter_name='住友不動産株式会社',
        submitter_name_en='Sumitomo Realty & Development Co.,Ltd.',
        submitter_name_yomi='スミトモフドウサンカブシキガイシャ',
        address='新宿区西新宿２－４－１',
        industry='不動産業',
        sec_code='88300',
        corporate_number='8011101010739',
    ),
    'E03908': EdinetCodeEntry(
        edinet_code='E03908',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2527,
        fiscal_year_end='3月31日',
        submitter_name='大栄不動産株式会社',
        submitter_name_en='Daiei Real Estate & Development Co.,Ltd.',
        submitter_name_yomi='ダイエイフドウサンカブシキガイシャ',
        address='中央区日本橋室町一丁目１番８号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010001049006',
    ),
    'E03913': EdinetCodeEntry(
        edinet_code='E03913',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=156,
        fiscal_year_end=None,
        submitter_name='株式会社大阪木材会館',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオサカモクザイカイカン',
        address='大阪市西区新町３丁目６番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001048955',
    ),
    'E03918': EdinetCodeEntry(
        edinet_code='E03918',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=355,
        fiscal_year_end='3月31日',
        submitter_name='株式会社群馬建設会館',
        submitter_name_en='GUNMA KENSETU KAIKAN CO.,Ltd',
        submitter_name_yomi='カブシキガイシャグンマケンセツカイカン',
        address='前橋市元総社町二丁目５番地の３',
        industry='不動産業',
        sec_code=None,
        corporate_number='2070001000890',
    ),
    'E03926': EdinetCodeEntry(
        edinet_code='E03926',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3032,
        fiscal_year_end='3月31日',
        submitter_name='鷹之台ゴルフ株式会社',
        submitter_name_en='Takanodai Golf Co.,Ltd.',
        submitter_name_yomi='タカノダイゴルフカブシキガイシャ',
        address='千葉市花見川区横戸町１５０１番地',
        industry='不動産業',
        sec_code=None,
        corporate_number='5040001004289',
    ),
    'E03928': EdinetCodeEntry(
        edinet_code='E03928',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=78,
        fiscal_year_end='9月30日',
        submitter_name='ＫＯＮＯＩＫＥ\u3000Ｃｏ．株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウノイケコーポレーションカブシキガイシャ',
        address='浜松市中央区元城町２１６番地の１１',
        industry='不動産業',
        sec_code=None,
        corporate_number='6080401001666',
    ),
    'E03929': EdinetCodeEntry(
        edinet_code='E03929',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=41171,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大京',
        submitter_name_en='DAIKYO INCORPORATED',
        submitter_name_yomi='カブシキガイシャダイキョウ',
        address='渋谷区千駄ヶ谷四丁目２４番１３号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7011001025796',
    ),
    'E03930': EdinetCodeEntry(
        edinet_code='E03930',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=290,
        fiscal_year_end='3月31日',
        submitter_name='株式会社千葉県建設業センター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチバケンケンセツギョウセンター',
        address='千葉市中央区中央港１丁目１３番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='9040001004590',
    ),
    'E03932': EdinetCodeEntry(
        edinet_code='E03932',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=200,
        fiscal_year_end='3月31日',
        submitter_name='株式会社鹿児島県プロパンガス会館',
        submitter_name_en='Kagoshima Prefecture Propane Gas Building Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャカゴシマケンプロパンガスカイカン',
        address='鹿児島市鴨池新町５番６号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7340001000867',
    ),
    'E03933': EdinetCodeEntry(
        edinet_code='E03933',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=398,
        fiscal_year_end=None,
        submitter_name='株式会社小津商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオヅショウテン',
        address='中央区日本橋本町３丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001039275',
    ),
    'E03938': EdinetCodeEntry(
        edinet_code='E03938',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コスモスイニシア',
        submitter_name_en='COSMOS INITIA Co., Ltd.',
        submitter_name_yomi='カブシキガイシャコスモスイニシア',
        address='港区芝五丁目３４番６号',
        industry='不動産業',
        sec_code='88440',
        corporate_number='2010401094621',
    ),
    'E03943': EdinetCodeEntry(
        edinet_code='E03943',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社レオパレス２１',
        submitter_name_en='LEOPALACE21CORPORATION',
        submitter_name_yomi='カブシキガイシャレオパレスニジュウイチ',
        address='中野区本町二丁目５４番１１号',
        industry='不動産業',
        sec_code='88480',
        corporate_number='3011201000900',
    ),
    'E03945': EdinetCodeEntry(
        edinet_code='E03945',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11039,
        fiscal_year_end='3月31日',
        submitter_name='スターツコーポレーション株式会社',
        submitter_name_en='starts corporation inc.',
        submitter_name_yomi='スターツコーポレーションカブシキガイシャ',
        address='中央区日本橋３丁目４番１０号',
        industry='不動産業',
        sec_code='88500',
        corporate_number='9010001095583',
    ),
    'E03946': EdinetCodeEntry(
        edinet_code='E03946',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3405,
        fiscal_year_end=None,
        submitter_name='アーバンライフ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アーバンライフカブシキガイシャ',
        address='神戸市東灘区本山南町八丁目６番２６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001000056',
    ),
    'E03948': EdinetCodeEntry(
        edinet_code='E03948',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1568,
        fiscal_year_end=None,
        submitter_name='株式会社日住サービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニチジュウサービス',
        address='神戸市中央区三宮町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001068534',
    ),
    'E03953': EdinetCodeEntry(
        edinet_code='E03953',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4872,
        fiscal_year_end='3月31日',
        submitter_name='フジ住宅株式会社',
        submitter_name_en='FUJI CORPORATION LIMITED',
        submitter_name_yomi='フジジュウタクカブシキガイシャ',
        address='岸和田市土生町１丁目４番２３号',
        industry='不動産業',
        sec_code='88600',
        corporate_number='1120101037457',
    ),
    'E03958': EdinetCodeEntry(
        edinet_code='E03958',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6826,
        fiscal_year_end='3月31日',
        submitter_name='空港施設株式会社',
        submitter_name_en='AIRPORT FACILITIES Co.,LTD.',
        submitter_name_yomi='クウコウシセツカブシキガイシャ',
        address='大田区羽田空港１丁目６番５号',
        industry='不動産業',
        sec_code='88640',
        corporate_number='8010801003218',
    ),
    'E03964': EdinetCodeEntry(
        edinet_code='E03964',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=747,
        fiscal_year_end='3月31日',
        submitter_name='株式会社宮城県建設会館',
        submitter_name_en='MiyagikenKensetsuKaiKan co.,LTD',
        submitter_name_yomi='カブシキガイシャミヤギケンケンセツカイカン',
        address='仙台市青葉区支倉町２番４８号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7370001011069',
    ),
    'E03967': EdinetCodeEntry(
        edinet_code='E03967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3537,
        fiscal_year_end='3月31日',
        submitter_name='明和地所株式会社',
        submitter_name_en='Meiwa Estate Company Limited',
        submitter_name_yomi='メイワジショカブシキガイシャ',
        address='渋谷区神泉町９番６号\u3000明和地所渋谷神泉ビル',
        industry='不動産業',
        sec_code='88690',
        corporate_number='2011001023094',
    ),
    'E03969': EdinetCodeEntry(
        edinet_code='E03969',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14258,
        fiscal_year_end='3月31日',
        submitter_name='リゾートトラスト株式会社',
        submitter_name_en='RESORTTRUST,INC.',
        submitter_name_yomi='リゾートトラストカブシキガイシャ',
        address='名古屋市中区東桜二丁目１８番３１号',
        industry='サービス業',
        sec_code='46810',
        corporate_number='5180001041871',
    ),
    'E03970': EdinetCodeEntry(
        edinet_code='E03970',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2970,
        fiscal_year_end='3月31日',
        submitter_name='住友不動産販売株式会社',
        submitter_name_en='Sumitomo Real Estate Sales Co., Ltd.',
        submitter_name_yomi='スミトモフドウサンハンバイカブシキガイシャ',
        address='新宿区西新宿二丁目４番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='4011101042249',
    ),
    'E03971': EdinetCodeEntry(
        edinet_code='E03971',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12499,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゴールドクレスト',
        submitter_name_en='GOLDCREST Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャゴールドクレスト',
        address='千代田区大手町２丁目１番１号',
        industry='不動産業',
        sec_code='88710',
        corporate_number='7010001076791',
    ),
    'E03977': EdinetCodeEntry(
        edinet_code='E03977',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1983,
        fiscal_year_end='3月31日',
        submitter_name='エスリード株式会社',
        submitter_name_en='ESLEAD CORPORATION',
        submitter_name_yomi='エスリードカブシキガイシャ',
        address='大阪市福島区福島六丁目２５番１９号',
        industry='不動産業',
        sec_code='88770',
        corporate_number='4120001072725',
    ),
    'E03984': EdinetCodeEntry(
        edinet_code='E03984',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10111,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日神グループホールディングス',
        submitter_name_en='NISSHIN GROUP HOLDINGS  Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニッシングループホールディングス',
        address='新宿区新宿五丁目８番１号',
        industry='不動産業',
        sec_code='88810',
        corporate_number='9011101015869',
    ),
    'E03986': EdinetCodeEntry(
        edinet_code='E03986',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='スターツアメニティー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スターツアメニティーカブシキカイシャ',
        address='江戸川区一之江８丁目４番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011701004271',
    ),
    'E03988': EdinetCodeEntry(
        edinet_code='E03988',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=279,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ウッドフレンズ',
        submitter_name_en='WOOD FRIENDS CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャウッドフレンズ',
        address='名古屋市中区栄四丁目５番３号',
        industry='不動産業',
        sec_code=None,
        corporate_number='4180001016164',
    ),
    'E03989': EdinetCodeEntry(
        edinet_code='E03989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2300,
        fiscal_year_end='5月31日',
        submitter_name='株式会社シーラホールディングス',
        submitter_name_en='SYLA Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャシーラホールディングス',
        address='渋谷区広尾１－１－３９',
        industry='不動産業',
        sec_code='88870',
        corporate_number='3030001038249',
    ),
    'E03991': EdinetCodeEntry(
        edinet_code='E03991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1168,
        fiscal_year_end='3月31日',
        submitter_name='ＡＭＧホールディングス株式会社',
        submitter_name_en='AMG HOLDINGS CO.,LTD.',
        submitter_name_yomi='エーエムジーホールディングスカブシキガイシャ',
        address='名古屋市中区錦３丁目１０番３２号',
        industry='不動産業',
        sec_code='88910',
        corporate_number='7180001049070',
    ),
    'E03992': EdinetCodeEntry(
        edinet_code='E03992',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16519,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エスコン',
        submitter_name_en='ES-CON JAPAN Ltd.',
        submitter_name_yomi='カブシキガイシャエスコン',
        address='港区虎ノ門二丁目１０番４号',
        industry='不動産業',
        sec_code='88920',
        corporate_number='8010001067609',
    ),
    'E03993': EdinetCodeEntry(
        edinet_code='E03993',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=299,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＲＥＶＯＬＵＴＩＯＮ',
        submitter_name_en='REVOLUTION CO.,LTD.',
        submitter_name_yomi='カブシキガイシャレボリューション',
        address='千代田区紀尾井町４番１号\u3000ニューオータニガーデンコート１２階',
        industry='不動産業',
        sec_code='88940',
        corporate_number='8250001006187',
    ),
    'E03994': EdinetCodeEntry(
        edinet_code='E03994',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=854,
        fiscal_year_end='3月31日',
        submitter_name='株式会社新日本建物',
        submitter_name_en='SHIN-NIHON TATEMONO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャシンニホンタテモノ',
        address='新宿区新宿四丁目３番１７号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6011001065843',
    ),
    'E03997': EdinetCodeEntry(
        edinet_code='E03997',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9056,
        fiscal_year_end='3月31日',
        submitter_name='ＭＩＲＡＲＴＨホールディングス株式会社',
        submitter_name_en='MIRARTH HOLDINGS, Inc.',
        submitter_name_yomi='ミラースホールディングスカブシキガイシャ',
        address='千代田区丸の内一丁目８番２号\u3000鉄鋼ビルディング１６階',
        industry='不動産業',
        sec_code='88970',
        corporate_number='6011101042313',
    ),
    'E04001': EdinetCodeEntry(
        edinet_code='E04001',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1587,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンウッド',
        submitter_name_en='Sunwood Corporation',
        submitter_name_yomi='カブシキガイシャサンウッド',
        address='港区虎ノ門三丁目２番２号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7010401032337',
    ),
    'E04002': EdinetCodeEntry(
        edinet_code='E04002',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=42383,
        fiscal_year_end='2月末日',
        submitter_name='イオンモール株式会社',
        submitter_name_en='AEON Mall Co.,Ltd.',
        submitter_name_yomi='イオンモールカブシキガイシャ',
        address='千葉市美浜区中瀬１丁目５番地１',
        industry='不動産業',
        sec_code=None,
        corporate_number='5040001000461',
    ),
    'E04005': EdinetCodeEntry(
        edinet_code='E04005',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1094,
        fiscal_year_end='12月31日',
        submitter_name='株式会社シノケングループ',
        submitter_name_en='shinoken group co.,ltd.',
        submitter_name_yomi='カブシキガイシャシノケングループ',
        address='福岡市中央区天神一丁目１番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3290001020676',
    ),
    'E04008': EdinetCodeEntry(
        edinet_code='E04008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=991,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エリアクエスト',
        submitter_name_en='Area Quest Inc.',
        submitter_name_yomi='カブシキガイシャエリアクエスト',
        address='新宿区西新宿六丁目５番１号',
        industry='不動産業',
        sec_code='89120',
        corporate_number='8013201016434',
    ),
    'E04011': EdinetCodeEntry(
        edinet_code='E04011',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6111,
        fiscal_year_end='12月31日',
        submitter_name='エリアリンク株式会社',
        submitter_name_en='Arealink Co.,Ltd.',
        submitter_name_yomi='エリアリンクカブシキガイシャ',
        address='千代田区外神田４ー１４ー１',
        industry='不動産業',
        sec_code='89140',
        corporate_number='4010001124347',
    ),
    'E04013': EdinetCodeEntry(
        edinet_code='E04013',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1584,
        fiscal_year_end='10月31日',
        submitter_name='ファースト住建株式会社',
        submitter_name_en='First Juken Co.,Ltd.',
        submitter_name_yomi='ファーストジュウケンカブシキカイシャ',
        address='尼崎市東難波町五丁目６番９号',
        industry='不動産業',
        sec_code='89170',
        corporate_number='8140001052787',
    ),
    'E04015': EdinetCodeEntry(
        edinet_code='E04015',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ランド',
        submitter_name_en='LAND Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャランド',
        address='横浜市西区北幸二丁目８番２９号',
        industry='不動産業',
        sec_code='89180',
        corporate_number='7020001031746',
    ),
    'E04018': EdinetCodeEntry(
        edinet_code='E04018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1580,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000東\u3000祥',
        submitter_name_en='TOSHO CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000トウショウ',
        address='安城市三河安城町一丁目１６番地５',
        industry='サービス業',
        sec_code='89200',
        corporate_number='2180301013169',
    ),
    'E04020': EdinetCodeEntry(
        edinet_code='E04020',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4097,
        fiscal_year_end='3月31日',
        submitter_name='日本アセットマーケティング株式会社',
        submitter_name_en='Japan Asset Marketing Co.,Ltd.',
        submitter_name_yomi='ニホンアセットマーケティングカブシキガイシャ',
        address='江戸川区北葛西四丁目１４番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6120001094362',
    ),
    'E04021': EdinetCodeEntry(
        edinet_code='E04021',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6624,
        fiscal_year_end='11月30日',
        submitter_name='トーセイ株式会社',
        submitter_name_en='TOSEI CORPORATION',
        submitter_name_yomi='トーセイカブシキガイシャ',
        address='港区芝浦四丁目５番４号',
        industry='不動産業',
        sec_code='89230',
        corporate_number='8010401064940',
    ),
    'E04022': EdinetCodeEntry(
        edinet_code='E04022',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='ニューリアルプロパティ株式会社',
        submitter_name_en='New Real Property Corporation',
        submitter_name_yomi='ニューリアルプロパティカブシキガイシャ',
        address='福井市西方一丁目３番１８号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3210001008126',
    ),
    'E04023': EdinetCodeEntry(
        edinet_code='E04023',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2428,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アルデプロ',
        submitter_name_en='ARDEPRO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアルデプロ',
        address='新宿区新宿三丁目１番２４号',
        industry='不動産業',
        sec_code=None,
        corporate_number='9011101006414',
    ),
    'E04024': EdinetCodeEntry(
        edinet_code='E04024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=614,
        fiscal_year_end='7月31日',
        submitter_name='株式会社明豊エンタープライズ',
        submitter_name_en='MEIHO ENTERPRISE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャメイホウエンタープライズ',
        address='目黒区目黒二丁目１０番１１号',
        industry='不動産業',
        sec_code='89270',
        corporate_number='1013201016399',
    ),
    'E04025': EdinetCodeEntry(
        edinet_code='E04025',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=755,
        fiscal_year_end='6月30日',
        submitter_name='穴吹興産株式会社',
        submitter_name_en='ANABUKI KOSAN INC.',
        submitter_name_yomi='アナブキコウサンカブシキカイシャ',
        address='高松市鍛冶屋町７番地１２',
        industry='不動産業',
        sec_code='89280',
        corporate_number='8470001000424',
    ),
    'E04029': EdinetCodeEntry(
        edinet_code='E04029',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1403,
        fiscal_year_end='2月末日',
        submitter_name='和田興産株式会社',
        submitter_name_en='WADAKOHSAN CORPORATION',
        submitter_name_yomi='ワダコウサンカブシキガイシャ',
        address='神戸市中央区栄町通四丁目２番１３号',
        industry='不動産業',
        sec_code='89310',
        corporate_number='9140001017079',
    ),
    'E04030': EdinetCodeEntry(
        edinet_code='E04030',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48760,
        fiscal_year_end=None,
        submitter_name='ＮＴＴ都市開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティトシカイハツカブシキカイシャ',
        address='千代田区外神田四丁目１４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001012372',
    ),
    'E04031': EdinetCodeEntry(
        edinet_code='E04031',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11965,
        fiscal_year_end='3月31日',
        submitter_name='サンフロンティア不動産株式会社',
        submitter_name_en='Sun Frontier Fudousan Co.,Ltd.',
        submitter_name_yomi='サンフロンティアフドウサンカブシキガイシャ',
        address='千代田区有楽町一丁目２番２号',
        industry='不動産業',
        sec_code='89340',
        corporate_number='9010001063953',
    ),
    'E04032': EdinetCodeEntry(
        edinet_code='E04032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2774,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＦＪネクストホールディングス',
        submitter_name_en='FJ NEXT HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャエフジェーネクストホールディングス',
        address='新宿区西新宿六丁目５番１号',
        industry='不動産業',
        sec_code='89350',
        corporate_number='1011101003369',
    ),
    'E04034': EdinetCodeEntry(
        edinet_code='E04034',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3049,
        fiscal_year_end='3月31日',
        submitter_name='グローム・ホールディングス株式会社',
        submitter_name_en='GLOME Holdings, Inc.',
        submitter_name_yomi='グロームホールディングスカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='不動産業',
        sec_code='89380',
        corporate_number='7012801003743',
    ),
    'E04036': EdinetCodeEntry(
        edinet_code='E04036',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2253,
        fiscal_year_end='5月31日',
        submitter_name='株式会社インテリックス',
        submitter_name_en='INTELLEX Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000インテリックス',
        address='渋谷区桜丘町３番２号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7011001032594',
    ),
    'E04037': EdinetCodeEntry(
        edinet_code='E04037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社エスグラントコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスグラントコーポレーション',
        address='渋谷区南平台町３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013201011245',
    ),
    'E04038': EdinetCodeEntry(
        edinet_code='E04038',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4969,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ランドビジネス',
        submitter_name_en='LAND BUSINESS',
        submitter_name_yomi='カブシキガイシャランドビジネス',
        address='千代田区霞が関三丁目２番５号霞が関ビルディング',
        industry='不動産業',
        sec_code='89440',
        corporate_number='5010001031955',
    ),
    'E04039': EdinetCodeEntry(
        edinet_code='E04039',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1705,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＡＳＩＡＮ\u3000ＳＴＡＲ',
        submitter_name_en='ASIAN STAR CO.',
        submitter_name_yomi='カブシキガイシャエイシアンスター',
        address='横浜市西区高島二丁目６番３２号',
        industry='不動産業',
        sec_code='89460',
        corporate_number='3020001016255',
    ),
    'E04042': EdinetCodeEntry(
        edinet_code='E04042',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1018,
        fiscal_year_end=None,
        submitter_name='サーラ住宅株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サーラジュウタクカブシキガイシャ',
        address='豊橋市白河町１００番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180301006265',
    ),
    'E04044': EdinetCodeEntry(
        edinet_code='E04044',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2077,
        fiscal_year_end='3月31日',
        submitter_name='グランディハウス株式会社',
        submitter_name_en='Grandy House Corporation',
        submitter_name_yomi='グランディハウスカブシキガイシャ',
        address='宇都宮市大通り四丁目３番１８号',
        industry='不動産業',
        sec_code='89990',
        corporate_number='2060001002178',
    ),
    'E04047': EdinetCodeEntry(
        edinet_code='E04047',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6890,
        fiscal_year_end='9月30日',
        submitter_name='株式会社プレサンスコーポレーション',
        submitter_name_en='PRESSANCE CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000プレサンスコーポレーション',
        address='大阪市中央区城見１丁目２番２７号\u3000クリスタルタワー２７階',
        industry='不動産業',
        sec_code=None,
        corporate_number='8120001086639',
    ),
    'E04048': EdinetCodeEntry(
        edinet_code='E04048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=328,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ハウスフリーダム',
        submitter_name_en='HousefreedomCo.,Ltd.',
        submitter_name_yomi='カブシキガイシャハウスフリーダム',
        address='松原市阿保四丁目１番３４号',
        industry='不動産業',
        sec_code='89960',
        corporate_number='6120101025572',
    ),
    'E04049': EdinetCodeEntry(
        edinet_code='E04049',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=578,
        fiscal_year_end='3月31日',
        submitter_name='株式会社誠建設工業',
        submitter_name_en='makoto construction co,ltd',
        submitter_name_yomi='カブシキガイシャマコトケンセツコウギョウ',
        address='堺市中区福田４６番地',
        industry='不動産業',
        sec_code='89950',
        corporate_number='6120101003859',
    ),
    'E04055': EdinetCodeEntry(
        edinet_code='E04055',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=454,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ラ・アトレ',
        submitter_name_en="L'attrait Co.,Ltd",
        submitter_name_yomi='カブシキガイシャラアトレ',
        address='港区海岸一丁目９番１８号',
        industry='不動産業',
        sec_code=None,
        corporate_number='1010401030809',
    ),
    'E04059': EdinetCodeEntry(
        edinet_code='E04059',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1340,
        fiscal_year_end='8月31日',
        submitter_name='株式会社メルディア',
        submitter_name_en='MELDIA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャメルディア',
        address='杉並区西荻北二丁目１番１１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='4011301002770',
    ),
    'E04060': EdinetCodeEntry(
        edinet_code='E04060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=119829,
        fiscal_year_end='3月31日',
        submitter_name='野村不動産ホールディングス株式会社',
        submitter_name_en='Nomura Real Estate Holdings, Inc.',
        submitter_name_yomi='ノムラフドウサンホールディングスカブシキガイシャ',
        address='港区芝浦一丁目１番１号',
        industry='不動産業',
        sec_code='32310',
        corporate_number='3011101037398',
    ),
    'E04064': EdinetCodeEntry(
        edinet_code='E04064',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1248,
        fiscal_year_end='5月31日',
        submitter_name='株式会社プロパスト',
        submitter_name_en='PROPERST CO.,LTD.',
        submitter_name_yomi='カブシキガイシャプロパスト',
        address='港区麻布十番一丁目１０番１０号',
        industry='不動産業',
        sec_code='32360',
        corporate_number='8010401095795',
    ),
    'E04065': EdinetCodeEntry(
        edinet_code='E04065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1008,
        fiscal_year_end='3月31日',
        submitter_name='セントラル総合開発株式会社',
        submitter_name_en='CENTRAL GENERAL DEVELOPMENT CO.,LTD.',
        submitter_name_yomi='セントラルソウゴウカイハツカブシキガイシャ',
        address='千代田区飯田橋三丁目３番７号',
        industry='不動産業',
        sec_code='32380',
        corporate_number='7010001021079',
    ),
    'E04068': EdinetCodeEntry(
        edinet_code='E04068',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=269,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ウィル',
        submitter_name_en='WILL,Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャウィル',
        address='宝塚市逆瀬川一丁目１４番６号',
        industry='不動産業',
        sec_code='32410',
        corporate_number='2140001081230',
    ),
    'E04069': EdinetCodeEntry(
        edinet_code='E04069',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2693,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アーバネットコーポレーション',
        submitter_name_en='URBANET CORPORATION CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアーバネットコーポレーション',
        address='千代田区霞が関三丁目２番５号霞が関ビルディング３５階',
        industry='不動産業',
        sec_code='32420',
        corporate_number='2010001092018',
    ),
    'E04072': EdinetCodeEntry(
        edinet_code='E04072',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3117,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ディア・ライフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディアライフ',
        address='千代田区九段北一丁目１３番５号',
        industry='不動産業',
        sec_code='32450',
        corporate_number='2010001090418',
    ),
    'E04074': EdinetCodeEntry(
        edinet_code='E04074',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20725,
        fiscal_year_end='12月31日',
        submitter_name='サムティ株式会社',
        submitter_name_en='Samty Co.,Ltd.',
        submitter_name_yomi='サムティカブシキガイシャ',
        address='大阪市淀川区西宮原一丁目８番３９号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3120001051770',
    ),
    'E04075': EdinetCodeEntry(
        edinet_code='E04075',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1562,
        fiscal_year_end='1月31日',
        submitter_name='株式会社コーセーアールイー',
        submitter_name_en='KOSE R.E. Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコーセーアールイー',
        address='福岡市中央区赤坂一丁目１５番３０号',
        industry='不動産業',
        sec_code='32460',
        corporate_number='9290001007429',
    ),
    'E04077': EdinetCodeEntry(
        edinet_code='E04077',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=167,
        fiscal_year_end='10月31日',
        submitter_name='株式会社アールエイジ',
        submitter_name_en='EARLY AGE CO., Ltd.',
        submitter_name_yomi='カブシキガイシャアールエイジ',
        address='港区赤坂２－１１－７',
        industry='不動産業',
        sec_code='32480',
        corporate_number='6010401059587',
    ),
    'E04078': EdinetCodeEntry(
        edinet_code='E04078',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5096,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エー・ディー・ワークス',
        submitter_name_en='A.D.Works Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエーディーワークス',
        address='千代田区内幸町二丁目２番３号',
        industry='不動産業',
        sec_code=None,
        corporate_number='5010001038059',
    ),
    'E04084': EdinetCodeEntry(
        edinet_code='E04084',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13522,
        fiscal_year_end='3月末日',
        submitter_name='ユニゾホールディングス株式会社',
        submitter_name_en='UNIZO Holdings Company,Limited',
        submitter_name_yomi='ユニゾホールディングスカブシキガイシャ',
        address='中央区八丁堀二丁目１０番９号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010001045269',
    ),
    'E04086': EdinetCodeEntry(
        edinet_code='E04086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=919,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エスポア',
        submitter_name_en='ESPOIR Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000エスポア',
        address='渋谷区南平台町１５－１',
        industry='不動産業',
        sec_code='32600',
        corporate_number='2180001055214',
    ),
    'E04088': EdinetCodeEntry(
        edinet_code='E04088',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=60359,
        fiscal_year_end='3月31日',
        submitter_name='小田急電鉄株式会社',
        submitter_name_en='Odakyu Electric Railway Co.,Ltd',
        submitter_name_yomi='オダキュウデンテツカブシキガイシャ',
        address='渋谷区代々木２丁目２８番１２号',
        industry='陸運業',
        sec_code='90070',
        corporate_number='1011001005060',
    ),
    'E04089': EdinetCodeEntry(
        edinet_code='E04089',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=43738,
        fiscal_year_end='3月31日',
        submitter_name='京浜急行電鉄株式会社',
        submitter_name_en='Keikyu Corporation',
        submitter_name_yomi='ケイヒンキュウコウデンテツカブシキガイシャ',
        address='横浜市西区高島１丁目２番８号',
        industry='陸運業',
        sec_code='90060',
        corporate_number='7010401009277',
    ),
    'E04090': EdinetCodeEntry(
        edinet_code='E04090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=121724,
        fiscal_year_end='3月31日',
        submitter_name='東急株式会社',
        submitter_name_en='TOKYU CORPORATION',
        submitter_name_yomi='トウキュウカブシキガイシャ',
        address='渋谷区南平台町５番６号',
        industry='陸運業',
        sec_code='90050',
        corporate_number='7011001016291',
    ),
    'E04091': EdinetCodeEntry(
        edinet_code='E04091',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36803,
        fiscal_year_end='3月31日',
        submitter_name='京成電鉄株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイセイデンテツカブシキガイシャ',
        address='市川市八幡三丁目３番１号',
        industry='陸運業',
        sec_code='90090',
        corporate_number='7010601012155',
    ),
    'E04092': EdinetCodeEntry(
        edinet_code='E04092',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=59023,
        fiscal_year_end='3月31日',
        submitter_name='京王電鉄株式会社',
        submitter_name_en='Keio Corporation',
        submitter_name_yomi='ケイオウデンテツカブシキガイシャ',
        address='新宿区新宿三丁目１番２４号',
        industry='陸運業',
        sec_code='90080',
        corporate_number='3011101005999',
    ),
    'E04093': EdinetCodeEntry(
        edinet_code='E04093',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9126,
        fiscal_year_end='3月31日',
        submitter_name='富士急行株式会社',
        submitter_name_en='FUJI KYUKO CO., LTD.',
        submitter_name_yomi='フジキュウコウカブシキガイシャ',
        address='富士吉田市上吉田二丁目５番１号',
        industry='陸運業',
        sec_code='90100',
        corporate_number='4090001009986',
    ),
    'E04094': EdinetCodeEntry(
        edinet_code='E04094',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=102135,
        fiscal_year_end='3月31日',
        submitter_name='東武鉄道株式会社',
        submitter_name_en='TOBU RAILWAY CO.,LTD.',
        submitter_name_yomi='トウブテツドウカブシキカイシャ',
        address='墨田区押上一丁目１番２号',
        industry='陸運業',
        sec_code='90010',
        corporate_number='6010601014508',
    ),
    'E04095': EdinetCodeEntry(
        edinet_code='E04095',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=640,
        fiscal_year_end='3月31日',
        submitter_name='伊豆箱根鉄道株式会社',
        submitter_name_en='IZUHAKONE RAILWAY CO.,LTD.',
        submitter_name_yomi='イズハコネテツドウカブシキガイシャ',
        address='三島市大場３００番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='9080101005353',
    ),
    'E04097': EdinetCodeEntry(
        edinet_code='E04097',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=38803,
        fiscal_year_end='3月31日',
        submitter_name='相鉄ホールディングス株式会社',
        submitter_name_en='Sotetsu Holdings,Inc.',
        submitter_name_yomi='ソウテツホールディングスカブシキガイシャ',
        address='横浜市西区北幸一丁目３番２３号',
        industry='陸運業',
        sec_code='90030',
        corporate_number='7020001014874',
    ),
    'E04098': EdinetCodeEntry(
        edinet_code='E04098',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5935,
        fiscal_year_end='3月31日',
        submitter_name='新京成電鉄株式会社',
        submitter_name_en='Shin-Keisei Electric Railway Co.,Ltd.',
        submitter_name_yomi='シンケイセイデンテツカブシキガイシャ',
        address='鎌ケ谷市くぬぎ山四丁目１番１２号',
        industry='陸運業',
        sec_code=None,
        corporate_number='7040001028138',
    ),
    'E04099': EdinetCodeEntry(
        edinet_code='E04099',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=495,
        fiscal_year_end='3月31日',
        submitter_name='長野電鉄株式会社',
        submitter_name_en='Nagano Electric Railway Co.,Ltd',
        submitter_name_yomi='ナガノデンテツカブシキガイシャ',
        address='長野市権堂町２２０１番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='7100001002441',
    ),
    'E04100': EdinetCodeEntry(
        edinet_code='E04100',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='江ノ島電鉄株式会社',
        submitter_name_en='Enoshima Electric Railway Co.,Ltd.',
        submitter_name_yomi='エノシマデンテツカブシキガイシャ',
        address='藤沢市片瀬海岸１丁目４番７号',
        industry='陸運業',
        sec_code=None,
        corporate_number='7021001000294',
    ),
    'E04101': EdinetCodeEntry(
        edinet_code='E04101',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=84185,
        fiscal_year_end='3月31日',
        submitter_name='名古屋鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナゴヤテツドウカブシキガイシャ',
        address='名古屋市中村区名駅一丁目２番４号',
        industry='陸運業',
        sec_code='90480',
        corporate_number='8180001031837',
    ),
    'E04102': EdinetCodeEntry(
        edinet_code='E04102',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=126476,
        fiscal_year_end='3月31日',
        submitter_name='近鉄グループホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キンテツグループホールディングスカブシキガイシャ',
        address='大阪市天王寺区上本町６丁目１番５５号',
        industry='陸運業',
        sec_code='90410',
        corporate_number='6120001023131',
    ),
    'E04103': EdinetCodeEntry(
        edinet_code='E04103',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99474,
        fiscal_year_end='3月31日',
        submitter_name='阪急阪神ホールディングス株式会社',
        submitter_name_en='Hankyu Hanshin Holdings,Inc.',
        submitter_name_yomi='ハンキュウハンシンホールディングスカブシキガイシャ',
        address='池田市栄町１番１号',
        industry='陸運業',
        sec_code='90420',
        corporate_number='2120901019851',
    ),
    'E04104': EdinetCodeEntry(
        edinet_code='E04104',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29384,
        fiscal_year_end=None,
        submitter_name='阪神電気鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハンシンデンキテツドウカブシキガイシャ',
        address='大阪市福島区海老江１丁目１番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001036177',
    ),
    'E04105': EdinetCodeEntry(
        edinet_code='E04105',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=51466,
        fiscal_year_end='3月31日',
        submitter_name='京阪ホールディングス株式会社',
        submitter_name_en='Keihan Holdings Co.,Ltd.',
        submitter_name_yomi='ケイハンホールディングスカブシキガイシャ',
        address='枚方市岡東町１７３番地の１',
        industry='陸運業',
        sec_code='90450',
        corporate_number='8120001149503',
    ),
    'E04106': EdinetCodeEntry(
        edinet_code='E04106',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=63739,
        fiscal_year_end='3月31日',
        submitter_name='南海電気鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナンカイデンキテツドウカブシキガイシャ',
        address='大阪市中央区難波五丁目１番６０号',
        industry='陸運業',
        sec_code='90440',
        corporate_number='6120001077499',
    ),
    'E04108': EdinetCodeEntry(
        edinet_code='E04108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='京福電気鉄道株式会社',
        submitter_name_en='Keifuku Electric Railroad Co.,Ltd.',
        submitter_name_yomi='ケイフクデンキテツドウカブシキガイシャ',
        address='京都市中京区壬生賀陽御所町３番地の２０',
        industry='陸運業',
        sec_code='90490',
        corporate_number='6130001020672',
    ),
    'E04109': EdinetCodeEntry(
        edinet_code='E04109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11710,
        fiscal_year_end='3月31日',
        submitter_name='神戸電鉄株式会社',
        submitter_name_en='Kobe Electric Railway Co.,Ltd.',
        submitter_name_yomi='コウベデンテツカブシキカイシャ',
        address='神戸市兵庫区新開地１丁目３番２４号',
        industry='陸運業',
        sec_code='90460',
        corporate_number='8140001015612',
    ),
    'E04110': EdinetCodeEntry(
        edinet_code='E04110',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26157,
        fiscal_year_end='3月31日',
        submitter_name='西日本鉄道株式会社',
        submitter_name_en='Nishi-Nippon Railroad Co.,Ltd.',
        submitter_name_yomi='ニシニッポンテツドウカブシキガイシャ',
        address='福岡市中央区天神一丁目１１番１号',
        industry='陸運業',
        sec_code='90310',
        corporate_number='4290001009413',
    ),
    'E04111': EdinetCodeEntry(
        edinet_code='E04111',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=310,
        fiscal_year_end='3月31日',
        submitter_name='Ｌマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エルマネジメントカブシキガイシャ',
        address='渋谷区神宮前一丁目５番８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='1010601022399',
    ),
    'E04112': EdinetCodeEntry(
        edinet_code='E04112',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=507,
        fiscal_year_end='3月31日',
        submitter_name='越後交通株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エチゴコウツウカブシキカイシャ',
        address='長岡市千秋２丁目２７８８番地１',
        industry='陸運業',
        sec_code=None,
        corporate_number='1110001022221',
    ),
    'E04113': EdinetCodeEntry(
        edinet_code='E04113',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1800,
        fiscal_year_end='3月31日',
        submitter_name='静岡鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シズオカテツドウカブシキガイシャ',
        address='静岡市葵区鷹匠一丁目１番１号',
        industry='陸運業',
        sec_code=None,
        corporate_number='8080001002864',
    ),
    'E04115': EdinetCodeEntry(
        edinet_code='E04115',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=449,
        fiscal_year_end='3月31日',
        submitter_name='サンデン交通株式会社',
        submitter_name_en='Sanden Kotsu Co,Ltd.',
        submitter_name_yomi='サンデンコウツウカブシキガイシャ',
        address='下関市羽山町３番３号',
        industry='陸運業',
        sec_code=None,
        corporate_number='8250001005486',
    ),
    'E04116': EdinetCodeEntry(
        edinet_code='E04116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='株式会社じょうてつ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジョウテツ',
        address='札幌市白石区東札幌１条１丁目１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1430001007925',
    ),
    'E04118': EdinetCodeEntry(
        edinet_code='E04118',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='豊橋鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨハシテツドウカブシキガイシャ',
        address='豊橋市駅前大通一丁目４６番地の１豊鉄ターミナルビル５階',
        industry='陸運業',
        sec_code=None,
        corporate_number='4180301006600',
    ),
    'E04119': EdinetCodeEntry(
        edinet_code='E04119',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=125,
        fiscal_year_end='3月31日',
        submitter_name='広島観光開発株式会社',
        submitter_name_en='Hiroshima Tourism Promoting Co., Ltd.',
        submitter_name_yomi='ヒロシマカンコウカイハツカブシキガイシャ',
        address='広島市中区東千田町二丁目９番２９号',
        industry='陸運業',
        sec_code=None,
        corporate_number='7240001009191',
    ),
    'E04122': EdinetCodeEntry(
        edinet_code='E04122',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社伊予鉄グループ',
        submitter_name_en='IYOTETSU Group Co., Ltd.',
        submitter_name_yomi='カブシキガイシャイヨテツグループ',
        address='松山市湊町４丁目４番地１',
        industry='陸運業',
        sec_code=None,
        corporate_number='1500001000476',
    ),
    'E04123': EdinetCodeEntry(
        edinet_code='E04123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2335,
        fiscal_year_end='3月31日',
        submitter_name='広島電鉄株式会社',
        submitter_name_en='Hiroshima Electric Railway Co.,Ltd.',
        submitter_name_yomi='ヒロシマデンテツカブシキガイシャ',
        address='広島市中区東千田町二丁目９番２９号',
        industry='陸運業',
        sec_code='90330',
        corporate_number='9240001009470',
    ),
    'E04124': EdinetCodeEntry(
        edinet_code='E04124',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='一畑電気鉄道株式会社',
        submitter_name_en='The Ichibata Electric Railroad Co.,Ltd.',
        submitter_name_yomi='イチバタデンキテツドウカブシキガイシャ',
        address='松江市中原町４９番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='9280001000070',
    ),
    'E04125': EdinetCodeEntry(
        edinet_code='E04125',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10090,
        fiscal_year_end='3月31日',
        submitter_name='山陽電気鉄道株式会社',
        submitter_name_en='Sanyo Electric Railway Co.,Ltd.',
        submitter_name_yomi='サンヨウデンキテツドウカブシキガイシャ',
        address='神戸市長田区御屋敷通３丁目１番１号',
        industry='陸運業',
        sec_code='90520',
        corporate_number='8140001016148',
    ),
    'E04126': EdinetCodeEntry(
        edinet_code='E04126',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=160,
        fiscal_year_end=None,
        submitter_name='岳南鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ガクナンテツドウカブシキガイシャ',
        address='富士市今泉一丁目１７番３９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3080101008312',
    ),
    'E04127': EdinetCodeEntry(
        edinet_code='E04127',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='福井鉄道株式会社',
        submitter_name_en='FUKUI RAILWAY CO.,LTD.',
        submitter_name_yomi='フクイテツドウカブシキカイシャ',
        address='越前市北府二丁目５番２０号',
        industry='陸運業',
        sec_code=None,
        corporate_number='2210001011931',
    ),
    'E04128': EdinetCodeEntry(
        edinet_code='E04128',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1557,
        fiscal_year_end='3月31日',
        submitter_name='富山地方鉄道株式会社',
        submitter_name_en='TOYAMACHIHO RAILROAD CO.,LTD.',
        submitter_name_yomi='トヤマチホウテツドウカブシキガイシャ',
        address='富山市桜町１丁目１番３６号',
        industry='陸運業',
        sec_code=None,
        corporate_number='5230001002133',
    ),
    'E04129': EdinetCodeEntry(
        edinet_code='E04129',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3800,
        fiscal_year_end='3月31日',
        submitter_name='遠州鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンシュウテツドウカブシキガイシャ',
        address='浜松市中央区旭町１２番地の１',
        industry='陸運業',
        sec_code=None,
        corporate_number='5080401000702',
    ),
    'E04130': EdinetCodeEntry(
        edinet_code='E04130',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='北陸鉄道株式会社',
        submitter_name_en='HOKURIKU RAILROAD CO.,LTD',
        submitter_name_yomi='ホクリクテツドウカブシキガイシャ',
        address='金沢市広岡３丁目１番１号\u3000金沢パークビル１階',
        industry='陸運業',
        sec_code=None,
        corporate_number='1220001006411',
    ),
    'E04135': EdinetCodeEntry(
        edinet_code='E04135',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='関東鉄道株式会社',
        submitter_name_en='Kanto Railway Co.,Ltd',
        submitter_name_yomi='カントウテツドウカブシキガイシャ',
        address='土浦市真鍋一丁目１０番８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='8050001009061',
    ),
    'E04136': EdinetCodeEntry(
        edinet_code='E04136',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=750,
        fiscal_year_end='3月31日',
        submitter_name='秩父鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チチブテツドウカブシキガイシャ',
        address='熊谷市曙町一丁目１番地',
        industry='陸運業',
        sec_code='90120',
        corporate_number='6030001085016',
    ),
    'E04137': EdinetCodeEntry(
        edinet_code='E04137',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='島原鉄道株式会社',
        submitter_name_en='Shimabara Railroad Co.,Ltd.',
        submitter_name_yomi='シマバラテツドウカブシキガイシャ',
        address='島原市下川尻町７２番地７６',
        industry='陸運業',
        sec_code=None,
        corporate_number='5310001009649',
    ),
    'E04141': EdinetCodeEntry(
        edinet_code='E04141',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1500,
        fiscal_year_end='3月31日',
        submitter_name='会津鉄道株式会社',
        submitter_name_en='Aizu Railway Co.,Ltd.',
        submitter_name_yomi='アイヅテツドウカブシキガイシャ',
        address='会津若松市材木町一丁目３番２０号',
        industry='陸運業',
        sec_code=None,
        corporate_number='3380001017143',
    ),
    'E04142': EdinetCodeEntry(
        edinet_code='E04142',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=450,
        fiscal_year_end='3月31日',
        submitter_name='のと鉄道株式会社',
        submitter_name_en='NOTO RAILWAY CO.,Ltd.',
        submitter_name_yomi='ノトテツドウカブシキガイシャ',
        address='鳳珠郡穴水町字大町チ２４番地２',
        industry='陸運業',
        sec_code=None,
        corporate_number='5220001016828',
    ),
    'E04145': EdinetCodeEntry(
        edinet_code='E04145',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=124279,
        fiscal_year_end='3月31日',
        submitter_name='東京臨海高速鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウリンカイコウソクテツドウカブシキガイシャ',
        address='江東区青海一丁目２番１号',
        industry='陸運業',
        sec_code=None,
        corporate_number='3010601023924',
    ),
    'E04146': EdinetCodeEntry(
        edinet_code='E04146',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=87350,
        fiscal_year_end=None,
        submitter_name='関西高速鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カンサイコウソクテツドウカブシキガイシャ',
        address='大阪市福島区福島三丁目１４番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001062550',
    ),
    'E04147': EdinetCodeEntry(
        edinet_code='E04147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=200000,
        fiscal_year_end='3月31日',
        submitter_name='東日本旅客鉄道株式会社',
        submitter_name_en='East Japan Railway Company',
        submitter_name_yomi='ヒガシニホンリョカクテツドウカブシキカイシャ',
        address='渋谷区代々木二丁目２番２号',
        industry='陸運業',
        sec_code='90200',
        corporate_number='9011001029597',
    ),
    'E04148': EdinetCodeEntry(
        edinet_code='E04148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100000,
        fiscal_year_end='3月31日',
        submitter_name='西日本旅客鉄道株式会社',
        submitter_name_en='West Japan Railway Company',
        submitter_name_yomi='ニシニホンリョカクテツドウカブシキガイシャ',
        address='大阪市北区芝田二丁目４番２４号',
        industry='陸運業',
        sec_code='90210',
        corporate_number='1120001059675',
    ),
    'E04149': EdinetCodeEntry(
        edinet_code='E04149',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=112000,
        fiscal_year_end='3月31日',
        submitter_name='東海旅客鉄道株式会社',
        submitter_name_en='Central Japan Railway Company',
        submitter_name_yomi='トウカイリョカクテツドウカブシキガイシャ',
        address='名古屋市中村区名駅一丁目１番４号',
        industry='陸運業',
        sec_code='90220',
        corporate_number='3180001031569',
    ),
    'E04151': EdinetCodeEntry(
        edinet_code='E04151',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=185016,
        fiscal_year_end='3月31日',
        submitter_name='首都圏新都市鉄道株式会社',
        submitter_name_en='Metropolitan Intercity Railway Company',
        submitter_name_yomi='シュトケンシントシテツドウカブシキガイシャ',
        address='台東区台東四丁目２５番７号',
        industry='陸運業',
        sec_code=None,
        corporate_number='3010501015419',
    ),
    'E04152': EdinetCodeEntry(
        edinet_code='E04152',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50719,
        fiscal_year_end='3月31日',
        submitter_name='横浜高速鉄道株式会社',
        submitter_name_en='-',
        submitter_name_yomi='ヨコハマコウソクテツドウカブシキガイシャ',
        address='横浜市中区元町一丁目１１番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='1020001029440',
    ),
    'E04153': EdinetCodeEntry(
        edinet_code='E04153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=58100,
        fiscal_year_end='3月31日',
        submitter_name='東京地下鉄株式会社',
        submitter_name_en='Tokyo Metro Co.,Ltd.',
        submitter_name_yomi='トウキョウチカテツカブシキガイシャ',
        address='台東区東上野三丁目１９番６号',
        industry='陸運業',
        sec_code='90230',
        corporate_number='4010501022810',
    ),
    'E04154': EdinetCodeEntry(
        edinet_code='E04154',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社西武ホールディングス',
        submitter_name_en='SEIBU HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャセイブホールディングス',
        address='豊島区南池袋一丁目１６番１５号',
        industry='陸運業',
        sec_code='90240',
        corporate_number='5013301022087',
    ),
    'E04155': EdinetCodeEntry(
        edinet_code='E04155',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4220,
        fiscal_year_end='3月31日',
        submitter_name='新潟交通株式会社',
        submitter_name_en='NiigataKotsu Co.,Ltd.',
        submitter_name_yomi='ニイガタコウツウカブシキガイシャ',
        address='新潟市中央区万代１丁目６番１号',
        industry='陸運業',
        sec_code='90170',
        corporate_number='7110001003728',
    ),
    'E04157': EdinetCodeEntry(
        edinet_code='E04157',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ヤマコー',
        submitter_name_en='YAMAKO Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヤマコー',
        address='山形市鉄砲町二丁目１３番１８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='2390001002260',
    ),
    'E04158': EdinetCodeEntry(
        edinet_code='E04158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3160,
        fiscal_year_end='3月31日',
        submitter_name='神奈川中央交通株式会社',
        submitter_name_en='Kanagawa Chuo Kotsu Co., Ltd.',
        submitter_name_yomi='カナガワチュウオウコウツウカブシキガイシャ',
        address='平塚市八重咲町６番１８号',
        industry='陸運業',
        sec_code='90810',
        corporate_number='6021001036307',
    ),
    'E04159': EdinetCodeEntry(
        edinet_code='E04159',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=525,
        fiscal_year_end='3月31日',
        submitter_name='大和自動車交通株式会社',
        submitter_name_en='Daiwa Motor Transportation Co.,Ltd',
        submitter_name_yomi='ダイワジドウシャコウツウカブシキカイシャ',
        address='江東区猿江二丁目１６番３１号',
        industry='陸運業',
        sec_code='90820',
        corporate_number='4010601039713',
    ),
    'E04160': EdinetCodeEntry(
        edinet_code='E04160',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3140,
        fiscal_year_end='3月31日',
        submitter_name='神姫バス株式会社',
        submitter_name_en='Shinki Bus Co.,Ltd.',
        submitter_name_yomi='シンキバスカブシキガイシャ',
        address='姫路市西駅前町１番地',
        industry='陸運業',
        sec_code='90830',
        corporate_number='6140001059289',
    ),
    'E04161': EdinetCodeEntry(
        edinet_code='E04161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2100,
        fiscal_year_end='3月31日',
        submitter_name='北海道中央バス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホッカイドウチュウオウバスカブシキガイシャ',
        address='小樽市色内１丁目８番６号',
        industry='陸運業',
        sec_code='90850',
        corporate_number='4430001050451',
    ),
    'E04162': EdinetCodeEntry(
        edinet_code='E04162',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='淡路交通株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アワジコウツウカブシキガイシャ',
        address='洲本市宇山１丁目４－３９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001084547',
    ),
    'E04163': EdinetCodeEntry(
        edinet_code='E04163',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=780,
        fiscal_year_end='12月31日',
        submitter_name='長崎自動車株式会社',
        submitter_name_en='Nagasaki Motor Bus Co.,Ltd.',
        submitter_name_yomi='ナガサキジドウシャカブシキガイシャ',
        address='長崎市新地町３番１７号',
        industry='陸運業',
        sec_code=None,
        corporate_number='2310001001369',
    ),
    'E04164': EdinetCodeEntry(
        edinet_code='E04164',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=427,
        fiscal_year_end='3月31日',
        submitter_name='大分交通株式会社',
        submitter_name_en='Oita Transportation Co.,Ltd.',
        submitter_name_yomi='オオイタコウツウカブシキガイシャ',
        address='大分市新川西一丁目３番１５号',
        industry='陸運業',
        sec_code=None,
        corporate_number='4320001000062',
    ),
    'E04165': EdinetCodeEntry(
        edinet_code='E04165',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=337,
        fiscal_year_end='9月30日',
        submitter_name='南国交通株式会社',
        submitter_name_en='Nangoku Traffic Co., Ltd.',
        submitter_name_yomi='ナンゴクコウツウカブシキガイシャ',
        address='鹿児島市中央町１８番地１',
        industry='陸運業',
        sec_code=None,
        corporate_number='7340001003192',
    ),
    'E04168': EdinetCodeEntry(
        edinet_code='E04168',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='日ノ丸自動車株式会社',
        submitter_name_en='Hinomaru Bus Co.,Ltd.',
        submitter_name_yomi='ヒノマルジドウシャカブシキガイシャ',
        address='鳥取市古海６２０番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='7270001000651',
    ),
    'E04170': EdinetCodeEntry(
        edinet_code='E04170',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1285,
        fiscal_year_end='3月31日',
        submitter_name='奈良交通株式会社',
        submitter_name_en='Nara Kotsu Bus Lines Co.,Ltd.',
        submitter_name_yomi='ナラコウツウカブシキガイシャ',
        address='奈良市大宮町１丁目１番２５号',
        industry='陸運業',
        sec_code=None,
        corporate_number='8150001001652',
    ),
    'E04172': EdinetCodeEntry(
        edinet_code='E04172',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=375,
        fiscal_year_end='3月31日',
        submitter_name='関東バス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カントウバスカブシキガイシャ',
        address='中野区東中野５丁目２３番１４号',
        industry='陸運業',
        sec_code=None,
        corporate_number='8011201001183',
    ),
    'E04177': EdinetCodeEntry(
        edinet_code='E04177',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=800,
        fiscal_year_end=None,
        submitter_name='近物レックス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キンブツレックスカブシキガイシャ',
        address='駿東郡清水町伏見字向田３５１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8080101005494',
    ),
    'E04178': EdinetCodeEntry(
        edinet_code='E04178',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10117,
        fiscal_year_end='3月31日',
        submitter_name='丸全昭和運輸株式会社',
        submitter_name_en='Maruzen Showa Unyu Co,.Ltd.',
        submitter_name_yomi='マルゼンショウワウンユカブシキガイシャ',
        address='横浜市中区南仲通二丁目１５番地',
        industry='陸運業',
        sec_code='90680',
        corporate_number='8020001028881',
    ),
    'E04179': EdinetCodeEntry(
        edinet_code='E04179',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28479,
        fiscal_year_end='3月31日',
        submitter_name='センコーグループホールディングス株式会社',
        submitter_name_en='SENKO Group Holdings Co.,Ltd.',
        submitter_name_yomi='センコーグループホールディングスカブシキガイシャ',
        address='東京都江東区潮見二丁目８番１０号',
        industry='陸運業',
        sec_code='90690',
        corporate_number='7120001059653',
    ),
    'E04180': EdinetCodeEntry(
        edinet_code='E04180',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2065,
        fiscal_year_end='3月31日',
        submitter_name='名鉄運輸株式会社',
        submitter_name_en='Meitetsu Transportation Co.,Ltd.',
        submitter_name_yomi='メイテツウンユカブシキガイシャ',
        address='名古屋市東区葵二丁目１２番８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='4180001018441',
    ),
    'E04181': EdinetCodeEntry(
        edinet_code='E04181',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=360,
        fiscal_year_end='3月31日',
        submitter_name='瀬戸内運輸株式会社',
        submitter_name_en='THE SETOUTI BUS CO., Ltd.',
        submitter_name_yomi='セトウチウンユカブシキガイシャ',
        address='今治市東門町１丁目２番地１',
        industry='陸運業',
        sec_code=None,
        corporate_number='2500001011778',
    ),
    'E04182': EdinetCodeEntry(
        edinet_code='E04182',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3559,
        fiscal_year_end='3月31日',
        submitter_name='株式会社丸運',
        submitter_name_en='MARUWN CORPORATION',
        submitter_name_yomi='カブシキガイシャマルウン',
        address='中央区日本橋小網町７番２号',
        industry='陸運業',
        sec_code='90670',
        corporate_number='5010001141787',
    ),
    'E04185': EdinetCodeEntry(
        edinet_code='E04185',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=14182,
        fiscal_year_end='3月31日',
        submitter_name='トナミホールディングス株式会社',
        submitter_name_en='Tonami Holdings Co.,Ltd.',
        submitter_name_yomi='トナミホールディングスカブシキガイシャ',
        address='高岡市昭和町３丁目２番１２号',
        industry='陸運業',
        sec_code=None,
        corporate_number='4230001010541',
    ),
    'E04186': EdinetCodeEntry(
        edinet_code='E04186',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1065,
        fiscal_year_end='9月30日',
        submitter_name='九州産業交通ホールディングス株式会社',
        submitter_name_en='KYUSHU INDUSTRIAL TRANSPORTATION HOLDINGS CO.,LTD.',
        submitter_name_yomi='キュウシュウサンギョウコウツウホールディングスカブシキガイシャ',
        address='熊本市中央区桜町３番５０号',
        industry='陸運業',
        sec_code=None,
        corporate_number='5330001001133',
    ),
    'E04187': EdinetCodeEntry(
        edinet_code='E04187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=127234,
        fiscal_year_end='3月31日',
        submitter_name='ヤマトホールディングス株式会社',
        submitter_name_en='YAMATO HOLDINGS CO.,LTD.',
        submitter_name_yomi='ヤマトホールディングスカブシキガイシャ',
        address='中央区銀座二丁目１６番１０号',
        industry='陸運業',
        sec_code='90640',
        corporate_number='7010001034964',
    ),
    'E04189': EdinetCodeEntry(
        edinet_code='E04189',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ニヤクコーポレーション',
        submitter_name_en='NIYAC CORPORATION',
        submitter_name_yomi='カブシキガイシャニヤクコーポレーション',
        address='江東区冬木１４番５号',
        industry='陸運業',
        sec_code=None,
        corporate_number='3010601042032',
    ),
    'E04190': EdinetCodeEntry(
        edinet_code='E04190',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='3月31日',
        submitter_name='東海自動車株式会社',
        submitter_name_en='TOKAIJIDOSHA',
        submitter_name_yomi='トウカイジドウシャカブシキガイシャ',
        address='伊東市渚町２番２８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='5080101013310',
    ),
    'E04191': EdinetCodeEntry(
        edinet_code='E04191',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11316,
        fiscal_year_end='3月31日',
        submitter_name='ニッコンホールディングス株式会社',
        submitter_name_en='NIKKON Holdings Co.,Ltd.',
        submitter_name_yomi='ニッコンホールディングスカブシキガイシヤ',
        address='中央区明石町６番１７号',
        industry='陸運業',
        sec_code='90720',
        corporate_number='7010001035005',
    ),
    'E04192': EdinetCodeEntry(
        edinet_code='E04192',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=81,
        fiscal_year_end='4月30日',
        submitter_name='新潟運輸株式会社',
        submitter_name_en='Niigata Unyu Co.,Ltd.',
        submitter_name_yomi='ニイガタウンユカブシキガイシャ',
        address='新潟市中央区女池北一丁目１番１号',
        industry='陸運業',
        sec_code=None,
        corporate_number='9110001003701',
    ),
    'E04194': EdinetCodeEntry(
        edinet_code='E04194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1772,
        fiscal_year_end='3月31日',
        submitter_name='カンダホールディングス株式会社',
        submitter_name_en='Kanda Holdings Co.,Ltd',
        submitter_name_yomi='カンダホールディングスカブシキガイシャ',
        address='千代田区神田三崎町三丁目２番４号',
        industry='陸運業',
        sec_code='90590',
        corporate_number='9010001014238',
    ),
    'E04195': EdinetCodeEntry(
        edinet_code='E04195',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2420,
        fiscal_year_end='3月31日',
        submitter_name='岡山県貨物運送株式会社',
        submitter_name_en='Okayamaken Freight Transportation Co.,Ltd',
        submitter_name_yomi='オカヤマケンカモツウンソウカブシキガイシャ',
        address='岡山市北区清心町４番３１号',
        industry='陸運業',
        sec_code='90630',
        corporate_number='4260001001001',
    ),
    'E04196': EdinetCodeEntry(
        edinet_code='E04196',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='立山黒部貫光株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タテヤマクロベカンコウカブシキガイシャ',
        address='富山市桜町一丁目１番３６号',
        industry='陸運業',
        sec_code=None,
        corporate_number='3230001001632',
    ),
    'E04197': EdinetCodeEntry(
        edinet_code='E04197',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='京極運輸商事株式会社',
        submitter_name_en='Kyogoku unyu shoji Co., Ltd.',
        submitter_name_yomi='キョウゴクウンユショウジカブシキガイシャ',
        address='中央区日本橋浜町一丁目２番１号',
        industry='陸運業',
        sec_code='90730',
        corporate_number='6010001040914',
    ),
    'E04198': EdinetCodeEntry(
        edinet_code='E04198',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=42481,
        fiscal_year_end='3月31日',
        submitter_name='セイノーホールディングス株式会社',
        submitter_name_en='SEINO HOLDINGS CO.,LTD.',
        submitter_name_yomi='セイノーホールディングスカブシキガイシャ',
        address='大垣市田口町１番地',
        industry='陸運業',
        sec_code='90760',
        corporate_number='3200001013795',
    ),
    'E04199': EdinetCodeEntry(
        edinet_code='E04199',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2237,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エスライングループ本社',
        submitter_name_en='S LINE GROUP CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエスライングループホンシャ',
        address='羽島郡岐南町平成四丁目６８番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='2200001010785',
    ),
    'E04206': EdinetCodeEntry(
        edinet_code='E04206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3145,
        fiscal_year_end='3月31日',
        submitter_name='日本ロジテム株式会社',
        submitter_name_en='JAPAN LOGISTIC SYSTEMS CORP.',
        submitter_name_yomi='ニホンロジテムカブシキガイシャ',
        address='品川区荏原１－１９－１７',
        industry='陸運業',
        sec_code='90600',
        corporate_number='3010701007868',
    ),
    'E04207': EdinetCodeEntry(
        edinet_code='E04207',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='両備ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リョウビホールディングスカブシキガイシャ',
        address='岡山市東区西大寺上一丁目１番５０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7260001007086',
    ),
    'E04208': EdinetCodeEntry(
        edinet_code='E04208',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1080,
        fiscal_year_end='3月31日',
        submitter_name='トランコム株式会社',
        submitter_name_en='TRANCOM CO., LTD.',
        submitter_name_yomi='トランコムカブシキガイシャ',
        address='名古屋市東区葵一丁目１９番３０号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='5180001038918',
    ),
    'E04209': EdinetCodeEntry(
        edinet_code='E04209',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1284,
        fiscal_year_end='3月31日',
        submitter_name='遠州トラック株式会社',
        submitter_name_en='ENSHU TRUCK CO.,LTD.',
        submitter_name_yomi='エンシュウトラックカブシキガイシャ',
        address='袋井市木原２２番地の１',
        industry='陸運業',
        sec_code='90570',
        corporate_number='8080401017124',
    ),
    'E04211': EdinetCodeEntry(
        edinet_code='E04211',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2349,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルプス物流',
        submitter_name_en='ALPS LOGISTICS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアルプスブツリュウ',
        address='横浜市港北区新羽町１７５６',
        industry='陸運業',
        sec_code=None,
        corporate_number='9020001019401',
    ),
    'E04213': EdinetCodeEntry(
        edinet_code='E04213',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4063,
        fiscal_year_end='11月30日',
        submitter_name='株式会社キユーソー流通システム',
        submitter_name_en='K.R.S.Corporation',
        submitter_name_yomi='カブシキガイシャキユーソーリュウツウシステム',
        address='調布市調布ケ丘三丁目５０番地１',
        industry='倉庫・運輸関連',
        sec_code='93690',
        corporate_number='7012401007541',
    ),
    'E04215': EdinetCodeEntry(
        edinet_code='E04215',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1262,
        fiscal_year_end='3月31日',
        submitter_name='センコン物流株式会社',
        submitter_name_en='SENKON LOGISTICS CO., LTD.',
        submitter_name_yomi='センコンブツリュウカブシキガイシャ',
        address='名取市下余田字中荷６７２番地の１',
        industry='陸運業',
        sec_code='90510',
        corporate_number='3370801000134',
    ),
    'E04217': EdinetCodeEntry(
        edinet_code='E04217',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1140,
        fiscal_year_end='3月20日',
        submitter_name='大宝運輸株式会社',
        submitter_name_en='Taiho Transportation Co., Ltd',
        submitter_name_yomi='タイホウウンユカブシキガイシャ',
        address='名古屋市中区金山五丁目３番１７号',
        industry='陸運業',
        sec_code='90400',
        corporate_number='2180001037542',
    ),
    'E04218': EdinetCodeEntry(
        edinet_code='E04218',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4731,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サカイ引越センター',
        submitter_name_en='Sakai Moving Service Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサカイヒッコシセンター',
        address='堺市堺区石津北町５６番地',
        industry='陸運業',
        sec_code='90390',
        corporate_number='6120101002720',
    ),
    'E04220': EdinetCodeEntry(
        edinet_code='E04220',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6547,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハマキョウレックス',
        submitter_name_en='HAMAKYOREX CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ハマキョウレックス',
        address='浜松市中央区寺脇町１７０１番地の１',
        industry='陸運業',
        sec_code='90370',
        corporate_number='1080401004368',
    ),
    'E04221': EdinetCodeEntry(
        edinet_code='E04221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=553,
        fiscal_year_end='3月31日',
        submitter_name='東部ネットワーク株式会社',
        submitter_name_en='TOHBU NETWORK CO.,LTD.',
        submitter_name_yomi='トウブネットワークカブシキガイシャ',
        address='横浜市神奈川区栄町２番地の９',
        industry='陸運業',
        sec_code='90360',
        corporate_number='9020001023915',
    ),
    'E04222': EdinetCodeEntry(
        edinet_code='E04222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2027,
        fiscal_year_end='3月31日',
        submitter_name='第一交通産業株式会社',
        submitter_name_en='DAIICHI KOUTSU SANGYO Co.,Ltd.',
        submitter_name_yomi='ダイイチコウツウサンギョウカブシキガイシャ',
        address='北九州市小倉北区馬借二丁目６番８号',
        industry='陸運業',
        sec_code='90350',
        corporate_number='6290801002202',
    ),
    'E04223': EdinetCodeEntry(
        edinet_code='E04223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=538,
        fiscal_year_end='3月31日',
        submitter_name='南総通運株式会社',
        submitter_name_en='NANSO Transport Co., Ltd.',
        submitter_name_yomi='ナンソウツウンカブシキガイシャ',
        address='東金市東金５８２番地',
        industry='陸運業',
        sec_code='90340',
        corporate_number='6040001057294',
    ),
    'E04224': EdinetCodeEntry(
        edinet_code='E04224',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3920,
        fiscal_year_end='12月31日',
        submitter_name='ＳＢＳホールディングス株式会社',
        submitter_name_en='SBS Holdings, Inc.',
        submitter_name_yomi='エスビーエスホールディングスカブシキガイシャ',
        address='新宿区西新宿八丁目１７番１号',
        industry='陸運業',
        sec_code='23840',
        corporate_number='4010601013288',
    ),
    'E04228': EdinetCodeEntry(
        edinet_code='E04228',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1001,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヒガシホールディングス',
        submitter_name_en='HIGASHI HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシヤヒガシホールディングス',
        address='大阪市中央区内久宝寺町三丁目１番９号',
        industry='陸運業',
        sec_code='90290',
        corporate_number='3120001077535',
    ),
    'E04230': EdinetCodeEntry(
        edinet_code='E04230',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3390,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ゼロ',
        submitter_name_en='ZERO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャゼロ',
        address='川崎市幸区堀川町５８０番地ソリッドスクエア西館６階',
        industry='陸運業',
        sec_code='90280',
        corporate_number='4020001079978',
    ),
    'E04232': EdinetCodeEntry(
        edinet_code='E04232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ロジネットジャパン',
        submitter_name_en='LOGINET JAPAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャロジネットジャパン',
        address='札幌市中央区大通西八丁目２番地６',
        industry='陸運業',
        sec_code='90270',
        corporate_number='5430001030460',
    ),
    'E04233': EdinetCodeEntry(
        edinet_code='E04233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='三重交通グループホールディングス株式会社',
        submitter_name_en='Mie Kotsu Group Holdings,Inc.',
        submitter_name_yomi='ミエコウツウグループホールディングスカブシキガイシャ',
        address='津市中央１番１号',
        industry='不動産業',
        sec_code='32320',
        corporate_number='3190001003559',
    ),
    'E04235': EdinetCodeEntry(
        edinet_code='E04235',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=144319,
        fiscal_year_end='3月31日',
        submitter_name='日本郵船株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンユウセンカブシキカイシャ',
        address='千代田区丸の内二丁目３番２号',
        industry='海運業',
        sec_code='91010',
        corporate_number='7010001023785',
    ),
    'E04236': EdinetCodeEntry(
        edinet_code='E04236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=66335,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000商船三井',
        submitter_name_en='Mitsui O.S.K. Lines, Ltd.',
        submitter_name_yomi='カブシキガイシャショウセンミツイ',
        address='港区虎ノ門二丁目１番１号',
        industry='海運業',
        sec_code='91040',
        corporate_number='4010401082896',
    ),
    'E04237': EdinetCodeEntry(
        edinet_code='E04237',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=75457,
        fiscal_year_end='3月31日',
        submitter_name='川崎汽船株式会社',
        submitter_name_en='Kawasaki Kisen Kaisha, Ltd.',
        submitter_name_yomi='カワサキキセンカブシキカイシャ',
        address='神戸市中央区海岸通８番',
        industry='海運業',
        sec_code='91070',
        corporate_number='8140001005720',
    ),
    'E04239': EdinetCodeEntry(
        edinet_code='E04239',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10300,
        fiscal_year_end='3月31日',
        submitter_name='ＮＳユナイテッド海運株式会社',
        submitter_name_en='NS UNITED KAIUN KAISHA, LTD.',
        submitter_name_yomi='エヌエスユナイテッドカイウンカブシキガイシャ',
        address='千代田区大手町二丁目３番２号',
        industry='海運業',
        sec_code='91100',
        corporate_number='3010001095003',
    ),
    'E04242': EdinetCodeEntry(
        edinet_code='E04242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1800,
        fiscal_year_end='3月31日',
        submitter_name='明海グループ株式会社',
        submitter_name_en='MEIJI SHIPPING GROUP CO.,LTD.',
        submitter_name_yomi='メイカイグループカブシキガイシャ',
        address='神戸市中央区明石町３２番地',
        industry='海運業',
        sec_code='91150',
        corporate_number='6140001011266',
    ),
    'E04243': EdinetCodeEntry(
        edinet_code='E04243',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13092,
        fiscal_year_end='3月31日',
        submitter_name='飯野海運株式会社',
        submitter_name_en='IINO KAIUN KAISHA, LTD.',
        submitter_name_yomi='イイノカイウンカブシキガイシャ',
        address='千代田区内幸町二丁目１番１号',
        industry='海運業',
        sec_code='91190',
        corporate_number='6010001008655',
    ),
    'E04244': EdinetCodeEntry(
        edinet_code='E04244',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='佐渡汽船株式会社',
        submitter_name_en='Sado Steam Ship Co.,Ltd.',
        submitter_name_yomi='サドキセンカブシキガイシャ',
        address='佐渡市両津湊３５３番地',
        industry='海運業',
        sec_code=None,
        corporate_number='2110001027748',
    ),
    'E04246': EdinetCodeEntry(
        edinet_code='E04246',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=702,
        fiscal_year_end='3月31日',
        submitter_name='玉井商船株式会社',
        submitter_name_en='TAMAI STEAMSHIP CO., LTD.',
        submitter_name_yomi='タマイショウセンカブシキガイシャ',
        address='港区芝浦三丁目２番１６号',
        industry='海運業',
        sec_code='91270',
        corporate_number='1010401051169',
    ),
    'E04247': EdinetCodeEntry(
        edinet_code='E04247',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2321,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大運',
        submitter_name_en='DAIUN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイウン',
        address='大阪市中央区久太郎町４丁目１番３号',
        industry='倉庫・運輸関連',
        sec_code='93630',
        corporate_number='4120001044831',
    ),
    'E04251': EdinetCodeEntry(
        edinet_code='E04251',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2850,
        fiscal_year_end='3月31日',
        submitter_name='共栄タンカー株式会社',
        submitter_name_en='KYOEI TANKER CO., LTD.',
        submitter_name_yomi='キョウエイタンカーカブシキガイシャ',
        address='港区三田三丁目２番６号',
        industry='海運業',
        sec_code='91300',
        corporate_number='2010001008667',
    ),
    'E04254': EdinetCodeEntry(
        edinet_code='E04254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1215,
        fiscal_year_end='3月31日',
        submitter_name='栗林商船株式会社',
        submitter_name_en='kuribayashi steamship co.,ltd.',
        submitter_name_yomi='クリバヤシショウセンカブシキガイシャ',
        address='千代田区大手町二丁目２番１号',
        industry='海運業',
        sec_code='91710',
        corporate_number='8010001008678',
    ),
    'E04256': EdinetCodeEntry(
        edinet_code='E04256',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1100,
        fiscal_year_end='12月31日',
        submitter_name='東海汽船株式会社',
        submitter_name_en='Tokai Kisen Co., Ltd.',
        submitter_name_yomi='トウカイキセンカブシキガイシャ',
        address='港区海岸一丁目１６番１号',
        industry='海運業',
        sec_code='91730',
        corporate_number='3010401020097',
    ),
    'E04262': EdinetCodeEntry(
        edinet_code='E04262',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1950,
        fiscal_year_end='3月31日',
        submitter_name='新日本海フェリー株式会社',
        submitter_name_en='Shinnihonkai Ferry Co.,Ltd.',
        submitter_name_yomi='シンニホンカイフェリーカブシキガイシャ',
        address='小樽市築港７番２号',
        industry='海運業',
        sec_code=None,
        corporate_number='5430001050054',
    ),
    'E04267': EdinetCodeEntry(
        edinet_code='E04267',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=890,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000東栄リーファーライン',
        submitter_name_en='TOEI REEFER LINE LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000トウエイリーファーライン',
        address='港区芝三丁目５番５号',
        industry='海運業',
        sec_code=None,
        corporate_number='5010401018998',
    ),
    'E04269': EdinetCodeEntry(
        edinet_code='E04269',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2368,
        fiscal_year_end='3月31日',
        submitter_name='川崎近海汽船株式会社',
        submitter_name_en='KAWASAKI KINKAI KISEN KAISHA,LTD.',
        submitter_name_yomi='カワサキキンカイキセンカブシキガイシャ',
        address='千代田区霞が関３―２―１',
        industry='海運業',
        sec_code=None,
        corporate_number='4010001013509',
    ),
    'E04272': EdinetCodeEntry(
        edinet_code='E04272',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=273200,
        fiscal_year_end='3月31日',
        submitter_name='日本航空株式会社',
        submitter_name_en='Japan Airlines Co., Ltd.',
        submitter_name_yomi='ニホンコウクウカブシキガイシャ',
        address='品川区東品川二丁目４番１１号',
        industry='空運業',
        sec_code='92010',
        corporate_number='7010701007666',
    ),
    'E04273': EdinetCodeEntry(
        edinet_code='E04273',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=467601,
        fiscal_year_end='3月31日',
        submitter_name='ＡＮＡホールディングス株式会社',
        submitter_name_en='ANA HOLDINGSINC.',
        submitter_name_yomi='エーエヌエーホールディングスカブシキガイシャ',
        address='港区東新橋一丁目５番２号',
        industry='空運業',
        sec_code='92020',
        corporate_number='6010401050876',
    ),
    'E04275': EdinetCodeEntry(
        edinet_code='E04275',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1673,
        fiscal_year_end='9月30日',
        submitter_name='アジア航測株式会社',
        submitter_name_en='Asia Air Survey Co.,Ltd.',
        submitter_name_yomi='アジアコウソクカブシキガイシャ',
        address='新宿区西新宿六丁目１４番１号\u3000新宿グリーンタワービル',
        industry='空運業',
        sec_code='92330',
        corporate_number='6011101000700',
    ),
    'E04278': EdinetCodeEntry(
        edinet_code='E04278',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2325,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＩＲＤＯ',
        submitter_name_en='AIRDO Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエアドゥ',
        address='札幌市中央区北一条西二丁目９番地オーク札幌ビルディング',
        industry='空運業',
        sec_code=None,
        corporate_number='6430001021797',
    ),
    'E04280': EdinetCodeEntry(
        edinet_code='E04280',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソラシドエア',
        submitter_name_en='Solaseed Air Inc.',
        submitter_name_yomi='カブシキガイシャソラシドエア',
        address='宮崎市大字赤江宮崎空港内',
        industry='空運業',
        sec_code=None,
        corporate_number='2350001002669',
    ),
    'E04283': EdinetCodeEntry(
        edinet_code='E04283',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22393,
        fiscal_year_end='3月31日',
        submitter_name='三菱倉庫株式会社',
        submitter_name_en='Mitsubishi Logistics Corporation',
        submitter_name_yomi='ミツビシソウコカブシキガイシャ',
        address='中央区日本橋一丁目１９番１号',
        industry='倉庫・運輸関連',
        sec_code='93010',
        corporate_number='8010001034947',
    ),
    'E04284': EdinetCodeEntry(
        edinet_code='E04284',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11357,
        fiscal_year_end='3月31日',
        submitter_name='三井倉庫ホールディングス株式会社',
        submitter_name_en='MITSUI-SOKO HOLDINGS Co., Ltd.',
        submitter_name_yomi='ミツイソウコホールディングスカブシキカイシャ',
        address='中央区日本橋箱崎町１９番２１号',
        industry='倉庫・運輸関連',
        sec_code='93020',
        corporate_number='2010401046416',
    ),
    'E04285': EdinetCodeEntry(
        edinet_code='E04285',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14922,
        fiscal_year_end='3月31日',
        submitter_name='株式会社住友倉庫',
        submitter_name_en='The Sumitomo Warehouse Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャスミトモソウコ',
        address='大阪市北区中之島三丁目２番１８号',
        industry='倉庫・運輸関連',
        sec_code='93030',
        corporate_number='7120001049002',
    ),
    'E04286': EdinetCodeEntry(
        edinet_code='E04286',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7847,
        fiscal_year_end='3月31日',
        submitter_name='澁澤倉庫株式会社',
        submitter_name_en='The Shibusawa Warehouse Co.,Ltd.',
        submitter_name_yomi='シブサワソウコカブシキガイシャ',
        address='江東区永代二丁目３７番２８号',
        industry='倉庫・運輸関連',
        sec_code='93040',
        corporate_number='6010601038102',
    ),
    'E04287': EdinetCodeEntry(
        edinet_code='E04287',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3412,
        fiscal_year_end='3月31日',
        submitter_name='東陽倉庫株式会社',
        submitter_name_en='Toyo Logistics Co.,Ltd.',
        submitter_name_yomi='トウヨウソウコカブシキガイシャ',
        address='名古屋市中村区名駅南二丁目６番１７号',
        industry='倉庫・運輸関連',
        sec_code='93060',
        corporate_number='5180001031666',
    ),
    'E04288': EdinetCodeEntry(
        edinet_code='E04288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2767,
        fiscal_year_end='3月31日',
        submitter_name='乾汽船株式会社',
        submitter_name_en='Inui Global Logistics Co., Ltd.',
        submitter_name_yomi='イヌイキセンカブシキガイシャ',
        address='中央区勝どき一丁目１３番６号',
        industry='海運業',
        sec_code='93080',
        corporate_number='7010001086980',
    ),
    'E04289': EdinetCodeEntry(
        edinet_code='E04289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8428,
        fiscal_year_end='3月31日',
        submitter_name='日本トランスシティ株式会社',
        submitter_name_en='Japan Transcity Corporation',
        submitter_name_yomi='ニホントランスシティカブシキガイシャ',
        address='四日市市霞二丁目１番地の１',
        industry='倉庫・運輸関連',
        sec_code='93100',
        corporate_number='9190001015895',
    ),
    'E04290': EdinetCodeEntry(
        edinet_code='E04290',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3602,
        fiscal_year_end='3月31日',
        submitter_name='安田倉庫株式会社',
        submitter_name_en='Yasuda Logistics corporation',
        submitter_name_yomi='ヤスダソウコカブシキガイシャ',
        address='港区芝浦三丁目１番１号',
        industry='倉庫・運輸関連',
        sec_code='93240',
        corporate_number='6010401029771',
    ),
    'E04291': EdinetCodeEntry(
        edinet_code='E04291',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10555,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤマタネ',
        submitter_name_en='Yamatane Corporation',
        submitter_name_yomi='カブシキガイシャヤマタネ',
        address='江東区越中島一丁目２番２１号',
        industry='卸売業',
        sec_code='93050',
        corporate_number='2010601007242',
    ),
    'E04293': EdinetCodeEntry(
        edinet_code='E04293',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5376,
        fiscal_year_end='3月31日',
        submitter_name='ケイヒン株式会社',
        submitter_name_en='THE KEIHIN CO., LTD.',
        submitter_name_yomi='ケイヒンカブシキガイシャ',
        address='港区海岸３丁目４番２０号',
        industry='倉庫・運輸関連',
        sec_code='93120',
        corporate_number='4010401009239',
    ),
    'E04294': EdinetCodeEntry(
        edinet_code='E04294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2630,
        fiscal_year_end='3月31日',
        submitter_name='株式会社杉村倉庫',
        submitter_name_en='sugimura warehouse co.,ltd.',
        submitter_name_yomi='カブシキガイシャスギムラソウコ',
        address='大阪市港区福崎１丁目１番５７号',
        industry='倉庫・運輸関連',
        sec_code='93070',
        corporate_number='4120001029155',
    ),
    'E04296': EdinetCodeEntry(
        edinet_code='E04296',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2527,
        fiscal_year_end='11月30日',
        submitter_name='丸八倉庫株式会社',
        submitter_name_en='Maruhachi Warehouse Company , Limited',
        submitter_name_yomi='マルハチソウコカブシキガイシャ',
        address='江東区富岡２丁目１番９号\u3000ＨＦ門前仲町ビルディング４階',
        industry='倉庫・運輸関連',
        sec_code='93130',
        corporate_number='2010601006194',
    ),
    'E04298': EdinetCodeEntry(
        edinet_code='E04298',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6390,
        fiscal_year_end='3月31日',
        submitter_name='アジア開発キャピタル株式会社',
        submitter_name_en='Asia Development Capital Co. Ltd.',
        submitter_name_yomi='アジアカイハツキャピタルカブシキガイシャ',
        address='江東区三好４丁目６番１７号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='9010601034809',
    ),
    'E04302': EdinetCodeEntry(
        edinet_code='E04302',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1600,
        fiscal_year_end='3月31日',
        submitter_name='鈴江コーポレーション株式会社',
        submitter_name_en='SUZUE CORPORATION',
        submitter_name_yomi='スズエコーポレーションカブシキガイシャ',
        address='横浜市中区日本大通７番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='7020001027166',
    ),
    'E04304': EdinetCodeEntry(
        edinet_code='E04304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2734,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中央倉庫',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチュウオウソウコ',
        address='京都市下京区朱雀内畑町４１番地',
        industry='倉庫・運輸関連',
        sec_code='93190',
        corporate_number='4130001018066',
    ),
    'E04317': EdinetCodeEntry(
        edinet_code='E04317',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2108,
        fiscal_year_end='3月31日',
        submitter_name='川西倉庫株式会社',
        submitter_name_en='KAWANISHI WAREHOUSE CO.,LTD.',
        submitter_name_yomi='カワニシソウコカブシキガイシャ',
        address='神戸市兵庫区七宮町一丁目４番１６号',
        industry='倉庫・運輸関連',
        sec_code='93220',
        corporate_number='9140001012831',
    ),
    'E04319': EdinetCodeEntry(
        edinet_code='E04319',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=70175,
        fiscal_year_end='12月31日',
        submitter_name='日本通運株式会社',
        submitter_name_en='NIPPON EXPRESS CO., LTD.',
        submitter_name_yomi='ニッポンツウウンカブシキガイシャ',
        address='千代田区神田和泉町２番地',
        industry='陸運業',
        sec_code=None,
        corporate_number='4010401022860',
    ),
    'E04320': EdinetCodeEntry(
        edinet_code='E04320',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6097,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日新',
        submitter_name_en='NISSIN CORPORATION',
        submitter_name_yomi='カブシキガイシャニッシン',
        address='横浜市中区尾上町六丁目８１番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2020001028235',
    ),
    'E04321': EdinetCodeEntry(
        edinet_code='E04321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8260,
        fiscal_year_end='3月31日',
        submitter_name='東洋埠頭株式会社',
        submitter_name_en='TOYO WHARF & WAREHOUSE CO.,LTD.',
        submitter_name_yomi='トウヨウフトウカブシキガイシャ',
        address='中央区晴海一丁目８番８号',
        industry='倉庫・運輸関連',
        sec_code='93510',
        corporate_number='7010001034865',
    ),
    'E04322': EdinetCodeEntry(
        edinet_code='E04322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=770,
        fiscal_year_end='3月31日',
        submitter_name='櫻島埠頭株式会社',
        submitter_name_en='SAKURAJIMA FUTO KAISHA,LTD.',
        submitter_name_yomi='サクラジマフトウカブシキガイシャ',
        address='大阪市此花区梅町１丁目１番１１号',
        industry='倉庫・運輸関連',
        sec_code='93530',
        corporate_number='8120001026363',
    ),
    'E04323': EdinetCodeEntry(
        edinet_code='E04323',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2189,
        fiscal_year_end='3月31日',
        submitter_name='アサガミ株式会社',
        submitter_name_en='ASAGAMI COPORATION',
        submitter_name_yomi='アサガミカブシキガイシヤ',
        address='千代田区丸の内三丁目１番１号',
        industry='倉庫・運輸関連',
        sec_code='93110',
        corporate_number='2010001035562',
    ),
    'E04324': EdinetCodeEntry(
        edinet_code='E04324',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28619,
        fiscal_year_end='3月31日',
        submitter_name='山九株式会社',
        submitter_name_en='SANKYU INC.',
        submitter_name_yomi='サンキュウカブシキガイシャ',
        address='北九州市門司区港町６番７号',
        industry='陸運業',
        sec_code='90650',
        corporate_number='7290801005328',
    ),
    'E04326': EdinetCodeEntry(
        edinet_code='E04326',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1950,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リンコーコーポレーション',
        submitter_name_en='RINKO CORPORATION',
        submitter_name_yomi='カブシキガイシャリンコーコーポレーション',
        address='新潟市中央区万代五丁目１１番３０号',
        industry='倉庫・運輸関連',
        sec_code='93550',
        corporate_number='3110001005876',
    ),
    'E04327': EdinetCodeEntry(
        edinet_code='E04327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1661,
        fiscal_year_end='3月31日',
        submitter_name='日本石油輸送株式会社',
        submitter_name_en='Japan Oil Transportation Co., Ltd.',
        submitter_name_yomi='ニホンセキユユソウカブシキガイシャ',
        address='品川区大崎一丁目１１番１号',
        industry='陸運業',
        sec_code='90740',
        corporate_number='3010701012439',
    ),
    'E04328': EdinetCodeEntry(
        edinet_code='E04328',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2350,
        fiscal_year_end='3月31日',
        submitter_name='名港海運株式会社',
        submitter_name_en='MEIKO TRANS CO.,LTD.',
        submitter_name_yomi='メイコウカイウンカブシキガイシャ',
        address='名古屋市港区入船二丁目４番６号',
        industry='倉庫・運輸関連',
        sec_code='93570',
        corporate_number='6180001007509',
    ),
    'E04329': EdinetCodeEntry(
        edinet_code='E04329',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2294,
        fiscal_year_end='3月31日',
        submitter_name='東海運株式会社',
        submitter_name_en='Azuma Shipping Co.,Ltd.',
        submitter_name_yomi='アヅマカイウンカブシキガイシャ',
        address='中央区晴海１－８－１２晴海アイランドトリトンスクエアオフィスタワーＺ３３階',
        industry='倉庫・運輸関連',
        sec_code='93800',
        corporate_number='4010001035123',
    ),
    'E04330': EdinetCodeEntry(
        edinet_code='E04330',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2046,
        fiscal_year_end='3月31日',
        submitter_name='伊勢湾海運株式会社',
        submitter_name_en='ISEWAN TERMINAL SERVICE CO.,LTD.',
        submitter_name_yomi='イセワンカイウンカブシキガイシャ',
        address='名古屋市港区入船一丁目７番４０号',
        industry='倉庫・運輸関連',
        sec_code='93590',
        corporate_number='3180001006050',
    ),
    'E04331': EdinetCodeEntry(
        edinet_code='E04331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10127,
        fiscal_year_end='3月31日',
        submitter_name='三愛オブリ株式会社',
        submitter_name_en='SAN-AI OBBLI CO.,LTD',
        submitter_name_yomi='サンアイオブリカブシキガイシャ',
        address='品川区東大井五丁目２２番５号',
        industry='卸売業',
        sec_code='80970',
        corporate_number='2010701003604',
    ),
    'E04334': EdinetCodeEntry(
        edinet_code='E04334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30310,
        fiscal_year_end='3月31日',
        submitter_name='福山通運株式会社',
        submitter_name_en='FUKUYAMA TRANSPORTING CO., LTD.',
        submitter_name_yomi='フクヤマツウウンカブシキガイシャ',
        address='福山市東深津町四丁目２０番１号',
        industry='陸運業',
        sec_code='90750',
        corporate_number='1240001032736',
    ),
    'E04335': EdinetCodeEntry(
        edinet_code='E04335',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2155,
        fiscal_year_end='3月31日',
        submitter_name='株式会社宇徳',
        submitter_name_en='Utoc Corporation',
        submitter_name_yomi='カブシキカイシャウトク',
        address='横浜市中区弁天通六丁目８５番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='1020001025489',
    ),
    'E04336': EdinetCodeEntry(
        edinet_code='E04336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='東京汽船株式会社',
        submitter_name_en='Tokyo Kisen Co.,Ltd.',
        submitter_name_yomi='トウキョウキセンカブシキガイシャ',
        address='横浜市中区山下町２番地',
        industry='倉庫・運輸関連',
        sec_code='91930',
        corporate_number='7020001027926',
    ),
    'E04337': EdinetCodeEntry(
        edinet_code='E04337',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=802,
        fiscal_year_end='3月31日',
        submitter_name='鈴与シンワート株式会社',
        submitter_name_en='SUZUYO SHINWART CORPORATION',
        submitter_name_yomi='スズヨシンワートカブシキガイシャ',
        address='港区芝４丁目１番２３号',
        industry='倉庫・運輸関連',
        sec_code='93600',
        corporate_number='3010401014925',
    ),
    'E04339': EdinetCodeEntry(
        edinet_code='E04339',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1850,
        fiscal_year_end='6月30日',
        submitter_name='伏木海陸運送株式会社',
        submitter_name_en='Fushiki Kairiku Unso Co.,Ltd.',
        submitter_name_yomi='フシキカイリクウンソウカブシキカイシャ',
        address='高岡市伏木湊町５番１号',
        industry='倉庫・運輸関連',
        sec_code='93610',
        corporate_number='4230001010772',
    ),
    'E04340': EdinetCodeEntry(
        edinet_code='E04340',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8758,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パスコ',
        submitter_name_en='PASCO CORPORATION',
        submitter_name_yomi='カブシキカイシャパスコ',
        address='目黒区下目黒一丁目７番１号',
        industry='空運業',
        sec_code=None,
        corporate_number='5013201004656',
    ),
    'E04341': EdinetCodeEntry(
        edinet_code='E04341',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1723,
        fiscal_year_end='3月31日',
        submitter_name='鴻池運輸株式会社',
        submitter_name_en='Konoike Transport Co.,Ltd.',
        submitter_name_yomi='コウノイケウンユカブシキガイシャ',
        address='大阪市中央区伏見町四丁目３番９号',
        industry='陸運業',
        sec_code='90250',
        corporate_number='5120001079182',
    ),
    'E04342': EdinetCodeEntry(
        edinet_code='E04342',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=612,
        fiscal_year_end='3月31日',
        submitter_name='兵機海運株式会社',
        submitter_name_en='HYOKI KAIUN KAISHA,LTD.',
        submitter_name_yomi='ヒョウキカイウンカブシキカイシャ',
        address='神戸市中央区港島３丁目６番地１',
        industry='倉庫・運輸関連',
        sec_code='93620',
        corporate_number='6140001010417',
    ),
    'E04343': EdinetCodeEntry(
        edinet_code='E04343',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12230,
        fiscal_year_end='3月31日',
        submitter_name='日本自動車ターミナル株式会社',
        submitter_name_en='Japan Motor Terminal Co.,Ltd.',
        submitter_name_yomi='ニホンジドウシャターミナルカブシキガイシャ',
        address='千代田区平河町２丁目７番９号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='8010001140943',
    ),
    'E04345': EdinetCodeEntry(
        edinet_code='E04345',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=31642,
        fiscal_year_end='3月31日',
        submitter_name='株式会社上組',
        submitter_name_en='Kamigumi  Co.,  Ltd.',
        submitter_name_yomi='カブシキガイシャカミグミ',
        address='神戸市中央区浜辺通４丁目１番１１号',
        industry='倉庫・運輸関連',
        sec_code='93640',
        corporate_number='6140001006951',
    ),
    'E04346': EdinetCodeEntry(
        edinet_code='E04346',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=735,
        fiscal_year_end='3月31日',
        submitter_name='トレーディア株式会社',
        submitter_name_en='TRADIA CORPORATION',
        submitter_name_yomi='トレーディアカブシキガイシャ',
        address='神戸市中央区海岸通一丁目２番２２号',
        industry='倉庫・運輸関連',
        sec_code='93650',
        corporate_number='3140001009726',
    ),
    'E04348': EdinetCodeEntry(
        edinet_code='E04348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＫＮＴ－ＣＴホールディングス株式会社',
        submitter_name_en='KNT-CT Holdings Co.,Ltd.',
        submitter_name_yomi='ケイエヌティーシーティーホールディングスカブシキガイシャ',
        address='新宿区西新宿二丁目６番１号',
        industry='サービス業',
        sec_code='97260',
        corporate_number='6010001008671',
    ),
    'E04349': EdinetCodeEntry(
        edinet_code='E04349',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=700,
        fiscal_year_end='3月31日',
        submitter_name='相模運輸倉庫株式会社',
        submitter_name_en='sagamitransportation & warehouse co.,ltd',
        submitter_name_yomi='サガミウンユソウコカブシキガイシャ',
        address='横須賀市田浦港町無番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='9021001040388',
    ),
    'E04351': EdinetCodeEntry(
        edinet_code='E04351',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=814990,
        fiscal_year_end='3月31日',
        submitter_name='関西国際空港土地保有株式会社',
        submitter_name_en='KANSAI INTERNATIONAL AIRPORT LAND COMPANY,LTD.',
        submitter_name_yomi='カンサイコクサイクウコウトチホユウカブシキガイシャ',
        address='泉佐野市泉州空港北一番地',
        industry='不動産業',
        sec_code=None,
        corporate_number='9120101039586',
    ),
    'E04352': EdinetCodeEntry(
        edinet_code='E04352',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90000,
        fiscal_year_end='3月31日',
        submitter_name='東京湾横断道路株式会社',
        submitter_name_en='TRANS-TOKYO BAY HIGHWAY CORPORATION',
        submitter_name_yomi='トウキョウワンオウダンドウロカブシキガイシャ',
        address='品川区大井一丁目２０番６号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2010801014658',
    ),
    'E04353': EdinetCodeEntry(
        edinet_code='E04353',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2523,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンリツ',
        submitter_name_en='SANRITSU CORPORATION',
        submitter_name_yomi='カブシキガイシャサンリツ',
        address='港区港南二丁目１２番３２号',
        industry='倉庫・運輸関連',
        sec_code='93660',
        corporate_number='5010401011846',
    ),
    'E04354': EdinetCodeEntry(
        edinet_code='E04354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2133,
        fiscal_year_end='3月31日',
        submitter_name='タカセ株式会社',
        submitter_name_en='TAKASE CORPORATION',
        submitter_name_yomi='タカセカブシキガイシャ',
        address='港区新橋一丁目１０番９号',
        industry='陸運業',
        sec_code='90870',
        corporate_number='3010401058435',
    ),
    'E04355': EdinetCodeEntry(
        edinet_code='E04355',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社農協観光',
        submitter_name_en='Nokyo Tourist Corporation',
        submitter_name_yomi='カブシキガイシャノウキョウカンコウ',
        address='千代田区大手町１丁目３番１号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='7010001026202',
    ),
    'E04356': EdinetCodeEntry(
        edinet_code='E04356',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=856,
        fiscal_year_end='3月31日',
        submitter_name='大東港運株式会社',
        submitter_name_en='DAITO KOUN CO.,LTD.',
        submitter_name_yomi='ダイトウコウウンカブシキガイシャ',
        address='港区芝浦四丁目２番８号',
        industry='倉庫・運輸関連',
        sec_code='93670',
        corporate_number='8010401016578',
    ),
    'E04357': EdinetCodeEntry(
        edinet_code='E04357',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3580,
        fiscal_year_end='3月31日',
        submitter_name='キムラユニティー株式会社',
        submitter_name_en='KIMURA UNITY CO.,LTD.',
        submitter_name_yomi='キムラユニティーカブシキガイシャ',
        address='名古屋市中区錦三丁目８番３２号',
        industry='倉庫・運輸関連',
        sec_code='93680',
        corporate_number='3180001035446',
    ),
    'E04358': EdinetCodeEntry(
        edinet_code='E04358',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='株式会社エイチ・アイ・エス',
        submitter_name_en='H.I.S. Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエイチアイエス',
        address='港区虎ノ門四丁目１番１号',
        industry='サービス業',
        sec_code='96030',
        corporate_number='6011101002696',
    ),
    'E04360': EdinetCodeEntry(
        edinet_code='E04360',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4301,
        fiscal_year_end='3月31日',
        submitter_name='郵船ロジスティクス株式会社',
        submitter_name_en='Yusen Logistics Co.,Ltd.',
        submitter_name_yomi='ユウセンロジスティクスカブシキガイシャ',
        address='港区芝公園二丁目１１番１号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='4010401090222',
    ),
    'E04361': EdinetCodeEntry(
        edinet_code='E04361',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=932,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニッコウトラベル',
        submitter_name_en='Nikko Travel Co.,Ltd',
        submitter_name_yomi='カブシキガイシャニッコウトラベル',
        address='中央区京橋一丁目１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9010001053748',
    ),
    'E04362': EdinetCodeEntry(
        edinet_code='E04362',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=83668,
        fiscal_year_end='3月31日',
        submitter_name='中部国際空港株式会社',
        submitter_name_en='CENTRAL JAPAN INTERNATIONAL AIRPORT COMPANY,LTD.',
        submitter_name_yomi='チュウブコクサイクウコウカブシキガイシャ',
        address='常滑市セントレア一丁目１番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='7180001093548',
    ),
    'E04364': EdinetCodeEntry(
        edinet_code='E04364',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7216,
        fiscal_year_end='3月31日',
        submitter_name='株式会社近鉄エクスプレス',
        submitter_name_en='Kintetsu World Express, Inc.',
        submitter_name_yomi='カブシキガイシャキンテツエクスプレス',
        address='港区港南二丁目１５番１号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='3010001014251',
    ),
    'E04365': EdinetCodeEntry(
        edinet_code='E04365',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=312,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ユーラシア旅行社',
        submitter_name_en='EURASIA TRAVEL Co.,Ltd',
        submitter_name_yomi='カブシキガイシャユーラシアリョコウシャ',
        address='千代田区平河町二丁目七番四号',
        industry='サービス業',
        sec_code='93760',
        corporate_number='1010001031554',
    ),
    'E04366': EdinetCodeEntry(
        edinet_code='E04366',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2283,
        fiscal_year_end='3月末日',
        submitter_name='株式会社\u3000エージーピー',
        submitter_name_en='AGP CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000エージーピー',
        address='大田区羽田空港一丁目７番１号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2010801001391',
    ),
    'E04367': EdinetCodeEntry(
        edinet_code='E04367',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=119736,
        fiscal_year_end='3月31日',
        submitter_name='成田国際空港株式会社',
        submitter_name_en='NARITA INTERNATIONAL AIRPORT CORPORATION',
        submitter_name_yomi='ナリタコクサイクウコウカブシキガイシャ',
        address='成田市古込字古込１番地１',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='9040001044645',
    ),
    'E04369': EdinetCodeEntry(
        edinet_code='E04369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エーアイテイー',
        submitter_name_en='AIT CORPORATION',
        submitter_name_yomi='カブシキガイシャエーアイティー',
        address='大阪市中央区本町二丁目１番６号',
        industry='倉庫・運輸関連',
        sec_code='93810',
        corporate_number='3120001075217',
    ),
    'E04370': EdinetCodeEntry(
        edinet_code='E04370',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=52500,
        fiscal_year_end='3月31日',
        submitter_name='東日本高速道路株式会社',
        submitter_name_en='East Nippon Expressway Company Limited',
        submitter_name_yomi='ヒガシニホンコウソクドウロカブシキガイシャ',
        address='千代田区霞が関三丁目３番２号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='9010001095716',
    ),
    'E04371': EdinetCodeEntry(
        edinet_code='E04371',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=65000,
        fiscal_year_end='3月31日',
        submitter_name='中日本高速道路株式会社',
        submitter_name_en='Central Nippon Expressway Company Limited',
        submitter_name_yomi='ナカニホンコウソクドウロカブシキガイシャ',
        address='名古屋市中区錦二丁目１８番１９号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='4180001056169',
    ),
    'E04372': EdinetCodeEntry(
        edinet_code='E04372',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='阪神高速道路株式会社',
        submitter_name_en='Hanshin Expressway Company Limited',
        submitter_name_yomi='ハンシンコウソクドウロカブシキガイシャ',
        address='大阪市北区中之島三丁目２番４号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2120001112350',
    ),
    'E04373': EdinetCodeEntry(
        edinet_code='E04373',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13500,
        fiscal_year_end='3月31日',
        submitter_name='首都高速道路株式会社',
        submitter_name_en='Metropolitan Expressway Company Limited',
        submitter_name_yomi='シュトコウソクドウロカブシキガイシャ',
        address='千代田区霞が関一丁目４番１号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2010001095722',
    ),
    'E04374': EdinetCodeEntry(
        edinet_code='E04374',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=47500,
        fiscal_year_end='3月31日',
        submitter_name='西日本高速道路株式会社',
        submitter_name_en='West Nippon Expressway Company Limited',
        submitter_name_yomi='ニシニホンコウソクドウロカブシキガイシャ',
        address='大阪市北区堂島一丁目６番２０号\u3000堂島アバンザ１９階',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='3120001112341',
    ),
    'E04375': EdinetCodeEntry(
        edinet_code='E04375',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54986,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴＢＳホールディングス',
        submitter_name_en='TBS HOLDINGS, INC.',
        submitter_name_yomi='カブシキガイシャテイビーエスホールディングス',
        address='港区赤坂五丁目３番６号',
        industry='情報・通信業',
        sec_code='94010',
        corporate_number='5010401020855',
    ),
    'E04376': EdinetCodeEntry(
        edinet_code='E04376',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1320,
        fiscal_year_end='3月31日',
        submitter_name='中部日本放送株式会社',
        submitter_name_en='CHUBU-NIPPON BROADCASTING Co.,LTD.',
        submitter_name_yomi='チュウブニッポンホウソウカブシキガイシャ',
        address='名古屋市中区新栄一丁目２番８号',
        industry='情報・通信業',
        sec_code='94020',
        corporate_number='7180001038107',
    ),
    'E04377': EdinetCodeEntry(
        edinet_code='E04377',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='東北放送株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウホクホウソウカブシキガイシャ',
        address='仙台市太白区八木山香澄町２６番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2370001002452',
    ),
    'E04379': EdinetCodeEntry(
        edinet_code='E04379',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4072,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＢＳメディアホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムビーエスメディアホールディングス',
        address='大阪市北区茶屋町１７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001059692',
    ),
    'E04380': EdinetCodeEntry(
        edinet_code='E04380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5299,
        fiscal_year_end='3月31日',
        submitter_name='朝日放送グループホールディングス株式会社',
        submitter_name_en='ASAHI BROADCASTING GROUP HOLDINGS CORPORATION',
        submitter_name_yomi='アサヒホウソウグループホールディングスカブシキガイシャ',
        address='大阪市福島区福島一丁目１番３０号',
        industry='情報・通信業',
        sec_code='94050',
        corporate_number='7120001060033',
    ),
    'E04381': EdinetCodeEntry(
        edinet_code='E04381',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社秋田放送',
        submitter_name_en='AKITA BROADCASTING SYSTEM, INC.',
        submitter_name_yomi='カブシキガイシャアキタホウソウ',
        address='秋田市中通七丁目１番１－２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5410001000498',
    ),
    'E04382': EdinetCodeEntry(
        edinet_code='E04382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=560,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＲＫＢ毎日ホールディングス',
        submitter_name_en='RKB MAINICHI  HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキガイシャアールケービーマイニチホールディングス',
        address='福岡市早良区百道浜二丁目３番８号',
        industry='情報・通信業',
        sec_code='94070',
        corporate_number='5290001004941',
    ),
    'E04384': EdinetCodeEntry(
        edinet_code='E04384',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='3月31日',
        submitter_name='信越放送株式会社',
        submitter_name_en='Sin-etsu Broadcasting Co.,Ltd.',
        submitter_name_yomi='シンエツホウソウカブシキガイシャ',
        address='長野市鶴賀問御所町１２００番地３',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2100001001266',
    ),
    'E04385': EdinetCodeEntry(
        edinet_code='E04385',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイビーシー岩手放送',
        submitter_name_en='Iwate Broadcasting Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアイビーシーイワテホウソウ',
        address='盛岡市志家町６番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9400001000033',
    ),
    'E04386': EdinetCodeEntry(
        edinet_code='E04386',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=180,
        fiscal_year_end='3月31日',
        submitter_name='北陸放送株式会社',
        submitter_name_en='Hokuriku Broadcasting Co.,Ltd.',
        submitter_name_yomi='ホクリクホウソウカブシキガイシャ',
        address='金沢市本多町三丁目２番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5220001006440',
    ),
    'E04387': EdinetCodeEntry(
        edinet_code='E04387',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=380,
        fiscal_year_end='3月31日',
        submitter_name='ＫＢＣグループホールディングス株式会社',
        submitter_name_en='KBC GROUP HOLDINGS CO.,LTD.',
        submitter_name_yomi='ケイビーシーグループホールディングスカブシキガイシャ',
        address='福岡市中央区長浜１丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6290001006862',
    ),
    'E04389': EdinetCodeEntry(
        edinet_code='E04389',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=360,
        fiscal_year_end='3月31日',
        submitter_name='南海放送株式会社',
        submitter_name_en='Nankai Broadcasting Company,Ltd.',
        submitter_name_yomi='ナンカイホウソウカブシキガイシャ',
        address='松山市本町１丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6500001002963',
    ),
    'E04390': EdinetCodeEntry(
        edinet_code='E04390',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='長崎放送株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナガサキホウソウカブシキガイシャ',
        address='長崎市尾上町５番６号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9310001001453',
    ),
    'E04393': EdinetCodeEntry(
        edinet_code='E04393',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=230,
        fiscal_year_end='3月31日',
        submitter_name='山口放送株式会社',
        submitter_name_en='Yamaguchi Broadcasting co.,Ltd.',
        submitter_name_yomi='ヤマグチホウソウカブシキガイシャ',
        address='周南市大字徳山５８５３番地の２',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6250001009332',
    ),
    'E04395': EdinetCodeEntry(
        edinet_code='E04395',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=230,
        fiscal_year_end='3月31日',
        submitter_name='北日本放送株式会社',
        submitter_name_en='Kitanihon Broadcasting Co.,Ltd.',
        submitter_name_yomi='キタニホンホウソウカブシキガイシャ',
        address='富山市牛島町１０番１８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3230001000758',
    ),
    'E04396': EdinetCodeEntry(
        edinet_code='E04396',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='ＲＳＫホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アールエスケイホールディングスカブシキガイシャ',
        address='岡山市北区丸の内二丁目１番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5260001002700',
    ),
    'E04397': EdinetCodeEntry(
        edinet_code='E04397',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=150,
        fiscal_year_end='3月31日',
        submitter_name='青森放送株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アオモリホウソウカブシキガイシャ',
        address='青森市松森一丁目８番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1420001000261',
    ),
    'E04398': EdinetCodeEntry(
        edinet_code='E04398',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=400,
        fiscal_year_end='3月31日',
        submitter_name='四国放送株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シコクホウソウカブシキガイシャ',
        address='徳島市中徳島町２丁目５番地の２',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9480001000851',
    ),
    'E04399': EdinetCodeEntry(
        edinet_code='E04399',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＢＳＮメディアホールディングス',
        submitter_name_en='BSN MEDIA HOLDINGS,INC.',
        submitter_name_yomi='カブシキガイシャビーエスエヌメディアホールディングス',
        address='新潟市中央区川岸町三丁目１８番地',
        industry='情報・通信業',
        sec_code='94080',
        corporate_number='5110001004521',
    ),
    'E04410': EdinetCodeEntry(
        edinet_code='E04410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18600,
        fiscal_year_end='3月31日',
        submitter_name='日本テレビホールディングス株式会社',
        submitter_name_en='Nippon Television Holdings, Inc.',
        submitter_name_yomi='ニホンテレビホールディングスカブシキガイシャ',
        address='港区東新橋一丁目６番１号',
        industry='情報・通信業',
        sec_code='94040',
        corporate_number='1010401051458',
    ),
    'E04411': EdinetCodeEntry(
        edinet_code='E04411',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=352,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000テレビ西日本',
        submitter_name_en='Television Nishinippon Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000テレビニシニッポン',
        address='福岡市早良区百道浜二丁目３番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8290001005441',
    ),
    'E04412': EdinetCodeEntry(
        edinet_code='E04412',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=750,
        fiscal_year_end='3月31日',
        submitter_name='札幌テレビ放送株式会社',
        submitter_name_en='The Sapporo Television Broadcasting Co.,Ltd.',
        submitter_name_yomi='サッポロテレビホウソウカブシキガイシャ',
        address='札幌市中央区北１条西８丁目１番地１',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5430001020206',
    ),
    'E04414': EdinetCodeEntry(
        edinet_code='E04414',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36687,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テレビ朝日ホールディングス',
        submitter_name_en='TV Asahi Holdings Corporation',
        submitter_name_yomi='カブシキガイシャテレビアサヒホールディングス',
        address='港区六本木六丁目９番１号',
        industry='情報・通信業',
        sec_code='94090',
        corporate_number='1010401015636',
    ),
    'E04425': EdinetCodeEntry(
        edinet_code='E04425',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=141852,
        fiscal_year_end='3月31日',
        submitter_name='ＫＤＤＩ株式会社',
        submitter_name_en='KDDI CORPORATION',
        submitter_name_yomi='ケイディーディーアイカブシキガイシャ',
        address='新宿区西新宿二丁目３番２号',
        industry='情報・通信業',
        sec_code='94330',
        corporate_number='9011101031552',
    ),
    'E04426': EdinetCodeEntry(
        edinet_code='E04426',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=205985,
        fiscal_year_end='3月31日',
        submitter_name='ソフトバンク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソフトバンクカブシキガイシャ',
        address='港区海岸一丁目７番１号',
        industry='情報・通信業',
        sec_code='94340',
        corporate_number='9010401052465',
    ),
    'E04427': EdinetCodeEntry(
        edinet_code='E04427',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＷＯＷＯＷ',
        submitter_name_en='WOWOW INC.',
        submitter_name_yomi='カブシキガイシャワウワウ',
        address='港区赤坂五丁目２番２０号',
        industry='情報・通信業',
        sec_code='48390',
        corporate_number='7010401022214',
    ),
    'E04430': EdinetCodeEntry(
        edinet_code='E04430',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=937950,
        fiscal_year_end='3月31日',
        submitter_name='ＮＴＴ株式会社',
        submitter_name_en='NTT, Inc.',
        submitter_name_yomi='エヌティティカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='情報・通信業',
        sec_code='94320',
        corporate_number='7010001065142',
    ),
    'E04453': EdinetCodeEntry(
        edinet_code='E04453',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4335,
        fiscal_year_end='3月31日',
        submitter_name='東京メトロポリタンテレビジョン株式会社',
        submitter_name_en='TOKYO METROPOLITAN TELEVISION BROADCASTING CORPORATION',
        submitter_name_yomi='トウキョウメトロポリタンテレビジョンカブシキガイシャ',
        address='千代田区麹町一丁目１２番',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='4010001101676',
    ),
    'E04460': EdinetCodeEntry(
        edinet_code='E04460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1414,
        fiscal_year_end='3月31日',
        submitter_name='沖縄セルラー電話株式会社',
        submitter_name_en='OKINAWA CELLULAR TELEPHONE COMPANY',
        submitter_name_yomi='オキナワセルラーデンワカブシキガイシャ',
        address='那覇市松山１丁目２番１号',
        industry='情報・通信業',
        sec_code='94360',
        corporate_number='5360001000413',
    ),
    'E04462': EdinetCodeEntry(
        edinet_code='E04462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=146200,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フジ・メディア・ホールディングス',
        submitter_name_en='FUJI MEDIA HOLDINGS, INC.',
        submitter_name_yomi='カブシキガイシャフジメディアホールディングス',
        address='港区台場二丁目４番８号',
        industry='情報・通信業',
        sec_code='46760',
        corporate_number='1010401032433',
    ),
    'E04463': EdinetCodeEntry(
        edinet_code='E04463',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=949679,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴＴドコモ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエヌティティドコモ',
        address='千代田区永田町２丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001067912',
    ),
    'E04471': EdinetCodeEntry(
        edinet_code='E04471',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=53,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジェイ・インターナショナル',
        submitter_name_en='J International Inc.',
        submitter_name_yomi='カブシキガイシャジェイインターナショナル',
        address='港区赤坂六丁目１５番１１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3010401039955',
    ),
    'E04473': EdinetCodeEntry(
        edinet_code='E04473',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=545,
        fiscal_year_end='3月31日',
        submitter_name='日本通信株式会社',
        submitter_name_en='Japan Communications Inc.',
        submitter_name_yomi='ニホンツウシンカブシキガイシャ',
        address='港区虎ノ門四丁目１番２８号',
        industry='情報・通信業',
        sec_code='94240',
        corporate_number='4010701007776',
    ),
    'E04476': EdinetCodeEntry(
        edinet_code='E04476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=553,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォーバルテレコム',
        submitter_name_en='FORVALTELECOM,INC.',
        submitter_name_yomi='カブシキガイシャフォーバルテレコム',
        address='港区港南１丁目８番２３号',
        industry='情報・通信業',
        sec_code='94450',
        corporate_number='8010001077624',
    ),
    'E04478': EdinetCodeEntry(
        edinet_code='E04478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='スペースシャワーＳＫＩＹＡＫＩホールディングス株式会社',
        submitter_name_en='SPACE SHOWER SKIYAKI HOLDINGS INC.',
        submitter_name_yomi='スペースシャワースキヤキホールディングスカブシキガイシャ',
        address='渋谷区道玄坂二丁目２５番１２号',
        industry='情報・通信業',
        sec_code='48380',
        corporate_number='1010401015149',
    ),
    'E04479': EdinetCodeEntry(
        edinet_code='E04479',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6000,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ＵＳＥＮ',
        submitter_name_en='USEN CORPORATION',
        submitter_name_yomi='カブシキガイシャユウセン',
        address='港区北青山三丁目１番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5010401068812',
    ),
    'E04491': EdinetCodeEntry(
        edinet_code='E04491',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=983,
        fiscal_year_end='12月末日',
        submitter_name='ＫＮＴＶ株式会社',
        submitter_name_en='KNTV Co., Ltd.',
        submitter_name_yomi='ケイエヌティヴィーカブシキガイシャ',
        address='港区北青山三丁目３番５号東京建物青山ビル３階',
        industry='サービス業',
        sec_code=None,
        corporate_number=None,
    ),
    'E04492': EdinetCodeEntry(
        edinet_code='E04492',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7969,
        fiscal_year_end='3月31日',
        submitter_name='ソニーネットワークコミュニケーションズ株式会社',
        submitter_name_en='Sony Network Communications Inc.',
        submitter_name_yomi='ソニーネットワークコミュニケーションズカブシキガイシャ',
        address='港区港南１丁目７番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8010701005322',
    ),
    'E04494': EdinetCodeEntry(
        edinet_code='E04494',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='富士通クラウドテクノロジーズ株式会社',
        submitter_name_en='FUJITSU CLOUD TECHNOLOGIES LIMITED',
        submitter_name_yomi='フジツウクラウドテクノロジーズカブシキガイシャ',
        address='川崎市幸区大宮町１番地５\u3000ＪＲ川崎タワ－',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7011101062005',
    ),
    'E04496': EdinetCodeEntry(
        edinet_code='E04496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=630,
        fiscal_year_end='3月31日',
        submitter_name='株式会社朝日ネット',
        submitter_name_en='ASAHI Net, Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000アサヒネット',
        address='中央区銀座四丁目１２番１５号',
        industry='情報・通信業',
        sec_code='38340',
        corporate_number='9010001035779',
    ),
    'E04497': EdinetCodeEntry(
        edinet_code='E04497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スカパーＪＳＡＴホールディングス',
        submitter_name_en='SKYPerfect JSAT Holdings Inc.',
        submitter_name_yomi='カブシキガイシャスカパージェイサットホールディングス',
        address='港区赤坂一丁目８番１号',
        industry='情報・通信業',
        sec_code='94120',
        corporate_number='5010401077210',
    ),
    'E04498': EdinetCodeEntry(
        edinet_code='E04498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1400975,
        fiscal_year_end='3月31日',
        submitter_name='東京電力ホールディングス株式会社',
        submitter_name_en='Tokyo Electric Power Company Holdings, Incorporated',
        submitter_name_yomi='トウキョウデンリョクホールディングスカブシキガイシャ',
        address='千代田区内幸町１丁目１番３号',
        industry='電気・ガス業',
        sec_code='95010',
        corporate_number='1010001008825',
    ),
    'E04499': EdinetCodeEntry(
        edinet_code='E04499',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=630040,
        fiscal_year_end='3月31日',
        submitter_name='関西電力株式会社',
        submitter_name_en='The Kansai Electric Power Company, Incorporated',
        submitter_name_yomi='カンサイデンリョクカブシキガイシャ',
        address='大阪市北区中之島３丁目６番１６号',
        industry='電気・ガス業',
        sec_code='95030',
        corporate_number='3120001059632',
    ),
    'E04500': EdinetCodeEntry(
        edinet_code='E04500',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=114291,
        fiscal_year_end='3月31日',
        submitter_name='北海道電力株式会社',
        submitter_name_en='Hokkaido Electric Power Company, Incorporated',
        submitter_name_yomi='ホッカイドウデンリョクカブシキガイシャ',
        address='札幌市中央区大通東１丁目２番地',
        industry='電気・ガス業',
        sec_code='95090',
        corporate_number='4430001022351',
    ),
    'E04501': EdinetCodeEntry(
        edinet_code='E04501',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=251441,
        fiscal_year_end='3月31日',
        submitter_name='東北電力株式会社',
        submitter_name_en='Tohoku Electric Power Company,Incorporated',
        submitter_name_yomi='トウホクデンリョクカブシキガイシャ',
        address='仙台市青葉区本町一丁目７番１号',
        industry='電気・ガス業',
        sec_code='95060',
        corporate_number='4370001011311',
    ),
    'E04502': EdinetCodeEntry(
        edinet_code='E04502',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=430777,
        fiscal_year_end='3月31日',
        submitter_name='中部電力株式会社',
        submitter_name_en='Chubu Electric Power Company,Incorporated',
        submitter_name_yomi='チュウブデンリョクカブシキガイシャ',
        address='名古屋市東区東新町１番地',
        industry='電気・ガス業',
        sec_code='95020',
        corporate_number='3180001017428',
    ),
    'E04503': EdinetCodeEntry(
        edinet_code='E04503',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=117641,
        fiscal_year_end='3月31日',
        submitter_name='北陸電力株式会社',
        submitter_name_en='Hokuriku Electric Power Company',
        submitter_name_yomi='ホクリクデンリョクカブシキガイシャ',
        address='富山市牛島町１５番１号',
        industry='電気・ガス業',
        sec_code='95050',
        corporate_number='7230001003022',
    ),
    'E04504': EdinetCodeEntry(
        edinet_code='E04504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=197024,
        fiscal_year_end='3月31日',
        submitter_name='中国電力株式会社',
        submitter_name_en='The Chugoku Electric Power Company, Incorporated',
        submitter_name_yomi='チュウゴクデンリョクカブシキガイシャ',
        address='広島市中区小町４番３３号',
        industry='電気・ガス業',
        sec_code='95040',
        corporate_number='4240001006753',
    ),
    'E04505': EdinetCodeEntry(
        edinet_code='E04505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=145551,
        fiscal_year_end='3月31日',
        submitter_name='四国電力株式会社',
        submitter_name_en='Shikoku Electric Power Company, Incorporated',
        submitter_name_yomi='シコクデンリョクカブシキカイシャ',
        address='高松市丸の内２番５号',
        industry='電気・ガス業',
        sec_code='95070',
        corporate_number='9470001001933',
    ),
    'E04506': EdinetCodeEntry(
        edinet_code='E04506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=237304,
        fiscal_year_end='3月31日',
        submitter_name='九州電力株式会社',
        submitter_name_en='Kyushu Electric Power Company, Incorporated',
        submitter_name_yomi='キュウシュウデンリョクカブシキガイシャ',
        address='福岡市中央区渡辺通二丁目１番８２号',
        industry='電気・ガス業',
        sec_code='95080',
        corporate_number='4290001007004',
    ),
    'E04507': EdinetCodeEntry(
        edinet_code='E04507',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=120000,
        fiscal_year_end='3月31日',
        submitter_name='日本原子力発電株式会社',
        submitter_name_en='The Japan Atomic Power Company',
        submitter_name_yomi='ニホンゲンシリョクハツデンカブシキガイシャ',
        address='台東区上野５丁目２番１号',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='2010001033087',
    ),
    'E04509': EdinetCodeEntry(
        edinet_code='E04509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7586,
        fiscal_year_end='3月31日',
        submitter_name='沖縄電力株式会社',
        submitter_name_en='The Okinawa Electric Power Company, Incorporated',
        submitter_name_yomi='オキナワデンリョクカブシキガイシャ',
        address='浦添市牧港五丁目２番１号',
        industry='電気・ガス業',
        sec_code='95110',
        corporate_number='3360001008565',
    ),
    'E04510': EdinetCodeEntry(
        edinet_code='E04510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=180502,
        fiscal_year_end='3月31日',
        submitter_name='電源開発株式会社',
        submitter_name_en='Electric Power Development Co., Ltd.',
        submitter_name_yomi='デンゲンカイハツカブシキガイシャ',
        address='中央区銀座六丁目１５番１号',
        industry='電気・ガス業',
        sec_code='95130',
        corporate_number='6010001050764',
    ),
    'E04511': EdinetCodeEntry(
        edinet_code='E04511',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7515,
        fiscal_year_end='3月31日',
        submitter_name='北海道瓦斯株式会社',
        submitter_name_en='HOKKAIDO GAS CO., LTD.',
        submitter_name_yomi='ホッカイドウガスカブシキガイシャ',
        address='札幌市東区北７条東２丁目１番１号',
        industry='電気・ガス業',
        sec_code='95340',
        corporate_number='5430001021815',
    ),
    'E04514': EdinetCodeEntry(
        edinet_code='E04514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=141844,
        fiscal_year_end='3月31日',
        submitter_name='東京瓦斯株式会社',
        submitter_name_en='TOKYO GAS CO.,LTD.',
        submitter_name_yomi='トウキョガスカブシキガイシャ',
        address='港区海岸一丁目５番２０号',
        industry='電気・ガス業',
        sec_code='95310',
        corporate_number='6010401020516',
    ),
    'E04515': EdinetCodeEntry(
        edinet_code='E04515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2754,
        fiscal_year_end='12月31日',
        submitter_name='京葉瓦斯株式会社',
        submitter_name_en='KEIYO GAS CO., LTD.',
        submitter_name_yomi='ケイヨウガスカブシキガイシャ',
        address='市川市市川南二丁目８番８号',
        industry='電気・ガス業',
        sec_code='95390',
        corporate_number='8040001026108',
    ),
    'E04516': EdinetCodeEntry(
        edinet_code='E04516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6279,
        fiscal_year_end='12月31日',
        submitter_name='静岡ガス株式会社',
        submitter_name_en='SHIZUOKA GAS CO., LTD.',
        submitter_name_yomi='シズオカガスカブシキガイシャ',
        address='静岡市駿河区八幡一丁目５番３８号',
        industry='電気・ガス業',
        sec_code='95430',
        corporate_number='4080001002686',
    ),
    'E04517': EdinetCodeEntry(
        edinet_code='E04517',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33072,
        fiscal_year_end='3月31日',
        submitter_name='東邦瓦斯株式会社',
        submitter_name_en='TOHO GAS CO.,LTD.',
        submitter_name_yomi='トウホウガスカブシキガイシャ',
        address='名古屋市熱田区桜田町１９番１８号',
        industry='電気・ガス業',
        sec_code='95330',
        corporate_number='2180001022387',
    ),
    'E04518': EdinetCodeEntry(
        edinet_code='E04518',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3162,
        fiscal_year_end=None,
        submitter_name='中部瓦斯株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウブガスカブシキガイシャ',
        address='豊橋市駅前大通一丁目５５番地\u3000サーラタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180301006250',
    ),
    'E04519': EdinetCodeEntry(
        edinet_code='E04519',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2400,
        fiscal_year_end='3月31日',
        submitter_name='北陸瓦斯株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホクリクガスカブシキガイシャ',
        address='新潟市中央区東大通一丁目２番２３号',
        industry='電気・ガス業',
        sec_code='95370',
        corporate_number='5110001004983',
    ),
    'E04520': EdinetCodeEntry(
        edinet_code='E04520',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=132166,
        fiscal_year_end='3月31日',
        submitter_name='大阪瓦斯株式会社',
        submitter_name_en='OSAKA GAS CO.,LTD.',
        submitter_name_yomi='オオサカガスカブシキガイシャ',
        address='大阪市中央区平野町四丁目１番２号',
        industry='電気・ガス業',
        sec_code='95320',
        corporate_number='3120001077601',
    ),
    'E04521': EdinetCodeEntry(
        edinet_code='E04521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5291,
        fiscal_year_end='3月31日',
        submitter_name='広島ガス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒロシマガスカブシキガイシャ',
        address='広島市南区皆実町二丁目７番１号',
        industry='電気・ガス業',
        sec_code='95350',
        corporate_number='2240001009205',
    ),
    'E04522': EdinetCodeEntry(
        edinet_code='E04522',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1800,
        fiscal_year_end='3月31日',
        submitter_name='四国ガス株式会社',
        submitter_name_en='SHIKOKUGAS CO., LTD.',
        submitter_name_yomi='シコクガスカブシキカイシャ',
        address='今治市南大門町二丁目２番地の４',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='4500001011652',
    ),
    'E04523': EdinetCodeEntry(
        edinet_code='E04523',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20629,
        fiscal_year_end='3月31日',
        submitter_name='西部ガスホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイブガスホールディングスカブシキガイシャ',
        address='福岡市博多区千代一丁目１７番１号',
        industry='電気・ガス業',
        sec_code='95360',
        corporate_number='6290001014048',
    ),
    'E04524': EdinetCodeEntry(
        edinet_code='E04524',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=645,
        fiscal_year_end='3月31日',
        submitter_name='日本瓦斯株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンガスカブシキガイシャ',
        address='鹿児島市中央町８番地２',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='4340001003385',
    ),
    'E04526': EdinetCodeEntry(
        edinet_code='E04526',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=180,
        fiscal_year_end='3月31日',
        submitter_name='宮崎瓦斯株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキガスカブシキガイシャ',
        address='宮崎市阿波岐原町野間３１１番地１',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='5350001001692',
    ),
    'E04535': EdinetCodeEntry(
        edinet_code='E04535',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3700,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京會舘',
        submitter_name_en='Tokyo Kaikan Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトウキョウカイカン',
        address='千代田区丸の内三丁目２番１号',
        industry='サービス業',
        sec_code='97010',
        corporate_number='5010001008821',
    ),
    'E04538': EdinetCodeEntry(
        edinet_code='E04538',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8534,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アゴーラホスピタリティーグループ',
        submitter_name_en='AGORA Hospitality Group Co., Ltd.',
        submitter_name_yomi='アゴーラホスピタリティーグループ',
        address='港区虎ノ門五丁目２番６号',
        industry='サービス業',
        sec_code='97040',
        corporate_number='5010401020095',
    ),
    'E04539': EdinetCodeEntry(
        edinet_code='E04539',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1485,
        fiscal_year_end='3月31日',
        submitter_name='株式会社帝国ホテル',
        submitter_name_en='Imperial Hotel, Ltd.',
        submitter_name_yomi='カブシキガイシャテイコクホテル',
        address='千代田区内幸町一丁目１番１号',
        industry='サービス業',
        sec_code='97080',
        corporate_number='8010001008711',
    ),
    'E04540': EdinetCodeEntry(
        edinet_code='E04540',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ロイヤルホテル',
        submitter_name_en='THE ROYAL HOTEL,LIMITED',
        submitter_name_yomi='カブシキカイシャロイヤルホテル',
        address='大阪市北区中之島５丁目３番６８号',
        industry='サービス業',
        sec_code='97130',
        corporate_number='2120001072198',
    ),
    'E04547': EdinetCodeEntry(
        edinet_code='E04547',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホテルオークラ',
        submitter_name_en='HOTEL OKURA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャホテルオークラ',
        address='港区虎ノ門二丁目１０番４号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401027614',
    ),
    'E04549': EdinetCodeEntry(
        edinet_code='E04549',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社パレスホテル',
        submitter_name_en='PALACE HOTEL CO., LTD.',
        submitter_name_yomi='カブシキガイシャパレスホテル',
        address='千代田区丸の内一丁目１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9010001026704',
    ),
    'E04550': EdinetCodeEntry(
        edinet_code='E04550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社京都ホテル',
        submitter_name_en='THE KYOTO HOTEL, LTD.',
        submitter_name_yomi='カブシキガイシャキョウトホテル',
        address='京都市中京区河原町通二条南入一之船入町５３７番地の４',
        industry='サービス業',
        sec_code='97230',
        corporate_number='6130001023386',
    ),
    'E04551': EdinetCodeEntry(
        edinet_code='E04551',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社熊本ホテルキャッスル',
        submitter_name_en='KUMAMOTO HOTEL CASTLE CO.,LTD.',
        submitter_name_yomi='カブシキカイシャクマモトホテルキャッスル',
        address='熊本市中央区城東町４番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7330001001610',
    ),
    'E04554': EdinetCodeEntry(
        edinet_code='E04554',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=600,
        fiscal_year_end='3月31日',
        submitter_name='朝日観光株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒカンコウカブシキガイシャ',
        address='鎌倉市今泉５丁目１０２６番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6021001045893',
    ),
    'E04555': EdinetCodeEntry(
        edinet_code='E04555',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=202,
        fiscal_year_end='3月31日',
        submitter_name='株式会社丸ノ内ホテル',
        submitter_name_en='MARUNOUCHI HOTEL CO., LTD.',
        submitter_name_yomi='カブシキガイシャマルノウチホテル',
        address='千代田区丸の内一丁目６番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001029578',
    ),
    'E04560': EdinetCodeEntry(
        edinet_code='E04560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='藤田観光株式会社',
        submitter_name_en='FUJITA KANKO INC.',
        submitter_name_yomi='フジタカンコウカブシキガイシャ',
        address='文京区関口二丁目１０番８号',
        industry='サービス業',
        sec_code='97220',
        corporate_number='6010001100247',
    ),
    'E04564': EdinetCodeEntry(
        edinet_code='E04564',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3462,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ニュー・オータニ',
        submitter_name_en='NEW OTANI  CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ニューオータニ',
        address='千代田区紀尾井町４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010001013240',
    ),
    'E04566': EdinetCodeEntry(
        edinet_code='E04566',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2011,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ホテル、ニューグランド',
        submitter_name_en='HOTEL NEW GRAND CO.,LTD',
        submitter_name_yomi='カブシキガイシャホテルニューグランド',
        address='横浜市中区山下町１０番地',
        industry='サービス業',
        sec_code='97200',
        corporate_number='7020001028858',
    ),
    'E04567': EdinetCodeEntry(
        edinet_code='E04567',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=55,
        fiscal_year_end='12月31日',
        submitter_name='ＡＣＡＯ\u3000ＳＰＡ＆ＲＥＳＯＲＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アカオ\u3000スパアンドリゾートカブシキガイシャ',
        address='千代田区丸の内二丁目５番１号\u3000丸の内二丁目ビル',
        industry='サービス業',
        sec_code=None,
        corporate_number='3080101012859',
    ),
    'E04576': EdinetCodeEntry(
        edinet_code='E04576',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=626,
        fiscal_year_end='3月31日',
        submitter_name='株式会社鴨川グランドホテル',
        submitter_name_en='THE KAMOGAWA GRAND HOTEL,LTD.',
        submitter_name_yomi='カブシキガイシャカモガワグランドホテル',
        address='鴨川市広場８２０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='1040001074815',
    ),
    'E04580': EdinetCodeEntry(
        edinet_code='E04580',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ホテルニューオータニ長岡',
        submitter_name_en='HOTEL NEWOTANI NAGAOKA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャホテルニューオータニナガオカ',
        address='長岡市台町２丁目８番３５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3110001022475',
    ),
    'E04582': EdinetCodeEntry(
        edinet_code='E04582',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33018,
        fiscal_year_end='2月末日',
        submitter_name='松竹株式会社',
        submitter_name_en='Shochiku Co;Ltd.',
        submitter_name_yomi='ショウチクカブシキガイシャ',
        address='中央区築地四丁目１番１号',
        industry='情報・通信業',
        sec_code='96010',
        corporate_number='6010001034809',
    ),
    'E04583': EdinetCodeEntry(
        edinet_code='E04583',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10355,
        fiscal_year_end='2月末日',
        submitter_name='東宝株式会社',
        submitter_name_en='TOHO CO., LTD.',
        submitter_name_yomi='トウホウカブシキガイシャ',
        address='千代田区有楽町一丁目２番２号',
        industry='情報・通信業',
        sec_code='96020',
        corporate_number='3010001008708',
    ),
    'E04585': EdinetCodeEntry(
        edinet_code='E04585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11707,
        fiscal_year_end='3月31日',
        submitter_name='東映株式会社',
        submitter_name_en='TOEI COMPANY,LTD.',
        submitter_name_yomi='トウエイカブシキガイシャ',
        address='中央区銀座三丁目２番１７号',
        industry='情報・通信業',
        sec_code='96050',
        corporate_number='6010001034866',
    ),
    'E04586': EdinetCodeEntry(
        edinet_code='E04586',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3323,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＯＩ\u3000Ｐｒｏ．',
        submitter_name_en='AOI Pro. Inc.',
        submitter_name_yomi='カブシキガイシャアオイプロ',
        address='品川区大崎一丁目５番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6010701000218',
    ),
    'E04588': EdinetCodeEntry(
        edinet_code='E04588',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7028,
        fiscal_year_end='12月31日',
        submitter_name='株式会社東急レクリエーション',
        submitter_name_en='TOKYU RECREATION CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウキュウレクリエーション',
        address='渋谷区桜丘町２４－４',
        industry='サービス業',
        sec_code=None,
        corporate_number='8011101014005',
    ),
    'E04589': EdinetCodeEntry(
        edinet_code='E04589',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4552,
        fiscal_year_end='3月31日',
        submitter_name='東京テアトル株式会社',
        submitter_name_en='Tokyo Theatres Company, Incorporated',
        submitter_name_yomi='トウキョウテアトルカブシキカイシャ',
        address='新宿区新宿一丁目１番８号',
        industry='サービス業',
        sec_code='96330',
        corporate_number='3010001035000',
    ),
    'E04590': EdinetCodeEntry(
        edinet_code='E04590',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3046,
        fiscal_year_end='1月31日',
        submitter_name='株式会社東京楽天地',
        submitter_name_en='TOKYO RAKUTENCHI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウラクテンチ',
        address='墨田区江東橋四丁目２７番１４号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6010601012585',
    ),
    'E04591': EdinetCodeEntry(
        edinet_code='E04591',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1004,
        fiscal_year_end='3月31日',
        submitter_name='武蔵野興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ムサシノコウギョウカブシキガイシャ',
        address='新宿区新宿三丁目３６番６号',
        industry='サービス業',
        sec_code='96350',
        corporate_number='8011101042749',
    ),
    'E04592': EdinetCodeEntry(
        edinet_code='E04592',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=564,
        fiscal_year_end='1月31日',
        submitter_name='株式会社きんえい',
        submitter_name_en='Kin-Ei Corp.',
        submitter_name_yomi='カブシキガイシャ\u3000キンエイ',
        address='大阪市阿倍野区阿倍野筋１丁目５番１号',
        industry='サービス業',
        sec_code='96360',
        corporate_number='1120001005118',
    ),
    'E04593': EdinetCodeEntry(
        edinet_code='E04593',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=800,
        fiscal_year_end=None,
        submitter_name='オーエス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーエスカブシキガイシャ',
        address='大阪市北区小松原町３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001059617',
    ),
    'E04596': EdinetCodeEntry(
        edinet_code='E04596',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=270,
        fiscal_year_end='3月31日',
        submitter_name='中日本興業株式会社',
        submitter_name_en='Nakanihon KOGYO CO.,Ltd.',
        submitter_name_yomi='ナカニホンコウギョウカブシキガイシャ',
        address='名古屋市中村区名駅四丁目５番２８号',
        industry='サービス業',
        sec_code='96430',
        corporate_number='9180001031919',
    ),
    'E04599': EdinetCodeEntry(
        edinet_code='E04599',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1331,
        fiscal_year_end='1月31日',
        submitter_name='スバル興業株式会社',
        submitter_name_en='Subaru Enterprise Co., Ltd.',
        submitter_name_yomi='スバルコウギョウカブシキガイシャ',
        address='千代田区有楽町一丁目５番２号',
        industry='サービス業',
        sec_code='96320',
        corporate_number='3010001008699',
    ),
    'E04601': EdinetCodeEntry(
        edinet_code='E04601',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=135,
        fiscal_year_end='5月31日',
        submitter_name='新橋演舞場株式会社',
        submitter_name_en='Shinbashi Enbujo Co.,Ltd.',
        submitter_name_yomi='シンバシエンブジョウカブシキガイシャ',
        address='中央区銀座六丁目１８番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001045682',
    ),
    'E04602': EdinetCodeEntry(
        edinet_code='E04602',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6053,
        fiscal_year_end='3月31日',
        submitter_name='株式会社よみうりランド',
        submitter_name_en='YOMIURI LAND. CO., LTD',
        submitter_name_yomi='カブシキガイシャヨミウリランド',
        address='稲城市矢野口４０１５番地１',
        industry='サービス業',
        sec_code=None,
        corporate_number='5013401002162',
    ),
    'E04603': EdinetCodeEntry(
        edinet_code='E04603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10586,
        fiscal_year_end='12月31日',
        submitter_name='東京都競馬株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウトケイバカブシキガイシャ',
        address='大田区大森北１－６－８',
        industry='サービス業',
        sec_code='96720',
        corporate_number='9010001034995',
    ),
    'E04604': EdinetCodeEntry(
        edinet_code='E04604',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=413,
        fiscal_year_end='3月31日',
        submitter_name='名古屋競馬株式会社',
        submitter_name_en='Nagoya Horse Racing Co.,Ltd.',
        submitter_name_yomi='ナゴヤケイバカブシキガイシャ',
        address='名古屋市緑区大将ヶ根一丁目２８１８番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5180001028605',
    ),
    'E04605': EdinetCodeEntry(
        edinet_code='E04605',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2038,
        fiscal_year_end='1月31日',
        submitter_name='株式会社東京ドーム',
        submitter_name_en='TOKYO DOME CORPORATION',
        submitter_name_yomi='カブシキガイシャトウキョウドーム',
        address='文京区後楽１－３－６１',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010001005258',
    ),
    'E04606': EdinetCodeEntry(
        edinet_code='E04606',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2365,
        fiscal_year_end='2月末日',
        submitter_name='株式会社歌舞伎座',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカブキザ',
        address='中央区銀座四丁目１２番１５号',
        industry='サービス業',
        sec_code='96610',
        corporate_number='1010001034763',
    ),
    'E04607': EdinetCodeEntry(
        edinet_code='E04607',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=883,
        fiscal_year_end='3月31日',
        submitter_name='花月園観光株式会社',
        submitter_name_en='kagetsuenkanko co.,ltd.',
        submitter_name_yomi='カゲツエンカンコウカブシキガイシャ',
        address='横浜市中区桜木町一丁目１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5020001016930',
    ),
    'E04608': EdinetCodeEntry(
        edinet_code='E04608',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='株式会社明治座',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメイジザ',
        address='中央区日本橋浜町２丁目３１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010001058757',
    ),
    'E04609': EdinetCodeEntry(
        edinet_code='E04609',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2271,
        fiscal_year_end='3月31日',
        submitter_name='株式会社御園座',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミソノザ',
        address='名古屋市中区栄一丁目６番１４号',
        industry='サービス業',
        sec_code='96640',
        corporate_number='5180001041087',
    ),
    'E04611': EdinetCodeEntry(
        edinet_code='E04611',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='奈良ゴルフ場株式会社',
        submitter_name_en='Nara Golflinks Co.,Ltd.',
        submitter_name_yomi='ナラゴルフジョウカブシキガイシャ',
        address='奈良市宝来五丁目１０番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7150001001678',
    ),
    'E04612': EdinetCodeEntry(
        edinet_code='E04612',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='福井県観光開発株式会社',
        submitter_name_en='fukuiken sight-seeing resources cultvation co.,ltd',
        submitter_name_yomi='フクイケンカンコウカイハツカブシキカイシャ',
        address='あわら市浜坂６６字塩越山１番地ノ１',
        industry='サービス業',
        sec_code=None,
        corporate_number='9210001007270',
    ),
    'E04613': EdinetCodeEntry(
        edinet_code='E04613',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000大利根カントリー倶楽部',
        submitter_name_en='Ohtone Country Club Limited',
        submitter_name_yomi='カブシキガイシャオオトネカントリークラブ',
        address='坂東市下出島１０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4050001014387',
    ),
    'E04614': EdinetCodeEntry(
        edinet_code='E04614',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='2月末日',
        submitter_name='株式会社芦の湖カントリークラブ',
        submitter_name_en='----',
        submitter_name_yomi='カブシキガイシャアシノコカントリークラブ',
        address='三島市字南原菅４７０８番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9080101005279',
    ),
    'E04615': EdinetCodeEntry(
        edinet_code='E04615',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=150,
        fiscal_year_end='12月31日',
        submitter_name='宮崎ゴルフ株式会社',
        submitter_name_en='Miyazaki Golf Co., Ltd',
        submitter_name_yomi='ミヤザキゴルフカブシキガイシャ',
        address='宮崎市大字田吉字松崎４８５５番地９０',
        industry='サービス業',
        sec_code=None,
        corporate_number='3350001001703',
    ),
    'E04616': EdinetCodeEntry(
        edinet_code='E04616',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東海カントリークラブ',
        submitter_name_en='The Tokai Country Club Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトウカイカントリークラブ',
        address='豊川市平尾町糠川１１番地の３１',
        industry='サービス業',
        sec_code=None,
        corporate_number='8180301010326',
    ),
    'E04618': EdinetCodeEntry(
        edinet_code='E04618',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=633,
        fiscal_year_end='9月30日',
        submitter_name='北陸観光開発株式会社',
        submitter_name_en='THE HOKURIKU SIGHTSEEING AND DEVELOPMENT CO.,LTD.',
        submitter_name_yomi='ホクリクカンコウカイハツカブシキガイシャ',
        address='加賀市新保町ト１番地の１',
        industry='サービス業',
        sec_code=None,
        corporate_number='2220001013398',
    ),
    'E04625': EdinetCodeEntry(
        edinet_code='E04625',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000名古屋スポーツセンター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ナゴヤスポーツセンター',
        address='名古屋市中区門前町１番６０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001039013',
    ),
    'E04626': EdinetCodeEntry(
        edinet_code='E04626',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=644,
        fiscal_year_end='12月31日',
        submitter_name='株式会社武蔵カントリー倶楽部',
        submitter_name_en='Musashi Country Club Limited',
        submitter_name_yomi='カブシキガイシャムサシカントリークラブ',
        address='入間市大字小谷田９６１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5030001027316',
    ),
    'E04627': EdinetCodeEntry(
        edinet_code='E04627',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社府中カントリークラブ',
        submitter_name_en='FUCHU COUNTRY CLUB CO.LTD.',
        submitter_name_yomi='カブシキガイシャフチュウカントリークラブ',
        address='多摩市中沢一丁目４１番地１',
        industry='サービス業',
        sec_code=None,
        corporate_number='4013401001561',
    ),
    'E04628': EdinetCodeEntry(
        edinet_code='E04628',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社伊香保カントリー倶楽部',
        submitter_name_en='Ikaho Country Club co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイカホカントリークラブ',
        address='渋川市伊香保町伊香保６５４番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9070001017499',
    ),
    'E04629': EdinetCodeEntry(
        edinet_code='E04629',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='株式会社六石ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャロッコクゴルフクラブ',
        address='いなべ市北勢町大字阿下喜字北谷３２９０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8190001012159',
    ),
    'E04630': EdinetCodeEntry(
        edinet_code='E04630',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社飯能ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハンノウゴルフクラブ',
        address='飯能市芦苅場４９５',
        industry='サービス業',
        sec_code=None,
        corporate_number='6030001089545',
    ),
    'E04631': EdinetCodeEntry(
        edinet_code='E04631',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=92,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000水戸カンツリー倶楽部',
        submitter_name_en='Mito Country Club Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ミトカンツリークラブ',
        address='東茨城郡大洗町磯浜町８２３１－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='2050001007260',
    ),
    'E04632': EdinetCodeEntry(
        edinet_code='E04632',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=40,
        fiscal_year_end='12月31日',
        submitter_name='株式会社小山カントリー倶楽部',
        submitter_name_en='OYAMA COUNTRY CLUB LIMITED',
        submitter_name_yomi='カブシキガイシャオヤマカントリークラブ',
        address='小山市大字喜沢１１４０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='3060001014809',
    ),
    'E04633': EdinetCodeEntry(
        edinet_code='E04633',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社千葉カントリー倶楽部',
        submitter_name_en='chiba country club co.,ltd.',
        submitter_name_yomi='カブシキガイシャチバカントリークラブ',
        address='野田市蕃昌４番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7040001071336',
    ),
    'E04634': EdinetCodeEntry(
        edinet_code='E04634',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社相模原ゴルフクラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサガミハラゴルフクラブ',
        address='相模原市南区大野台４－３０－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='8021001012116',
    ),
    'E04635': EdinetCodeEntry(
        edinet_code='E04635',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社花屋敷ゴルフ倶楽部',
        submitter_name_en='Hanayashiki Golf Club co.,ltd',
        submitter_name_yomi='カブシキガイシャハナヤシキゴルフクラブ',
        address='三木市吉川町上荒川字松ヶ浦７１３番地の１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7140001036816',
    ),
    'E04636': EdinetCodeEntry(
        edinet_code='E04636',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000筑波ゴルフコース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツクバゴルフコース',
        address='つくばみらい市高岡８３０番地の２',
        industry='サービス業',
        sec_code=None,
        corporate_number='1050001028241',
    ),
    'E04637': EdinetCodeEntry(
        edinet_code='E04637',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='日本観光ゴルフ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンカンコウゴルフカブシキカイシャ',
        address='城陽市寺田奥山１番地の４６',
        industry='サービス業',
        sec_code=None,
        corporate_number='9130001038522',
    ),
    'E04638': EdinetCodeEntry(
        edinet_code='E04638',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=105,
        fiscal_year_end=None,
        submitter_name='通天閣観光株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツウテンカクカンコウカブシキガイシャ',
        address='大阪市浪速区恵美須東１丁目１８番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001039026',
    ),
    'E04639': EdinetCodeEntry(
        edinet_code='E04639',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=770,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000仙台カントリークラブ',
        submitter_name_en='Sendai Country Club Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャセンダイカントリークラブ',
        address='名取市愛島笠島字南北沢１番地の８',
        industry='サービス業',
        sec_code=None,
        corporate_number='9370801000995',
    ),
    'E04640': EdinetCodeEntry(
        edinet_code='E04640',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=600,
        fiscal_year_end='12月31日',
        submitter_name='浜名湖観光開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハマナコカンコウカイハツカブシキガイシャ',
        address='湖西市白須賀５７３９',
        industry='サービス業',
        sec_code=None,
        corporate_number='4080401006048',
    ),
    'E04641': EdinetCodeEntry(
        edinet_code='E04641',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1213,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日高カントリー倶楽部',
        submitter_name_en='HIDAKA COUNTRY CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヒダカカントリークラブ',
        address='日高市高萩１２０３番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7030001090056',
    ),
    'E04642': EdinetCodeEntry(
        edinet_code='E04642',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エムケー',
        submitter_name_en='MK Co.Ltd',
        submitter_name_yomi='カブシキカイシャエムケー',
        address='瑞浪市土岐町４８５８番地の４',
        industry='サービス業',
        sec_code=None,
        corporate_number='3200001021724',
    ),
    'E04643': EdinetCodeEntry(
        edinet_code='E04643',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=135,
        fiscal_year_end='12月31日',
        submitter_name='株式会社犬山カンツリー倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイヌヤマカンツリークラブ',
        address='犬山市大字前原字橋爪山１番地の４',
        industry='サービス業',
        sec_code=None,
        corporate_number='7180001080728',
    ),
    'E04644': EdinetCodeEntry(
        edinet_code='E04644',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=169,
        fiscal_year_end='9月30日',
        submitter_name='内海観光開発株式会社',
        submitter_name_en='Nai kai kan ko kaihatsu Co.,Ltd',
        submitter_name_yomi='ナイカイカンコウカイハツカブシキガイシャ',
        address='玉野市宇野６丁目１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5260001022401',
    ),
    'E04646': EdinetCodeEntry(
        edinet_code='E04646',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='9月30日',
        submitter_name='株式会社松永カントリークラブ',
        submitter_name_en='matsunaga country club co., ltd',
        submitter_name_yomi='カブシキガイシャマツナガカントリークラブ',
        address='福山市神村町１３８８番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2240001031778',
    ),
    'E04647': EdinetCodeEntry(
        edinet_code='E04647',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='1月31日',
        submitter_name='株式会社福岡カンツリー倶楽部',
        submitter_name_en='FUKUOKA COUNTRY CLUB CO,LTD',
        submitter_name_yomi='カブシキガイシャフクオカカンツリークラブ',
        address='福岡市東区大字上和白１３１８番地の１',
        industry='サービス業',
        sec_code=None,
        corporate_number='2290001003896',
    ),
    'E04648': EdinetCodeEntry(
        edinet_code='E04648',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='呉羽観光株式会社',
        submitter_name_en='kureha sightseeing co.,ltd',
        submitter_name_yomi='クレハカンコウカブシキガイシャ',
        address='富山市三熊１９番地２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8230001000811',
    ),
    'E04649': EdinetCodeEntry(
        edinet_code='E04649',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=75,
        fiscal_year_end='12月31日',
        submitter_name='広島ゴルフ観光株式会社',
        submitter_name_en='Hiroshima Tourist and Golfing Incorporated',
        submitter_name_yomi='ヒロシマゴルフカンコウカブシキガイシャ',
        address='広島市佐伯区三宅町１０５０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4240001009277',
    ),
    'E04650': EdinetCodeEntry(
        edinet_code='E04650',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社小倉カンツリー倶楽部',
        submitter_name_en='kokura country club co, ltd',
        submitter_name_yomi='カブシキガイシャコクラカンツリークラブ',
        address='北九州市小倉南区西貫二丁目一番一号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4290801001511',
    ),
    'E04651': EdinetCodeEntry(
        edinet_code='E04651',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=45,
        fiscal_year_end='4月30日',
        submitter_name='株式会社中山カントリークラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナカヤマカントリークラブ',
        address='千代田区神田錦町３丁目１３番地７',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010001025047',
    ),
    'E04652': EdinetCodeEntry(
        edinet_code='E04652',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=353,
        fiscal_year_end='12月31日',
        submitter_name='松山観光ゴルフ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マツヤマカンコウゴルフカブシキガイシャ',
        address='東温市松瀬川乙９９７',
        industry='サービス業',
        sec_code=None,
        corporate_number='8500001007110',
    ),
    'E04654': EdinetCodeEntry(
        edinet_code='E04654',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='株式会社三好ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミヨシゴルフクラブ',
        address='みよし市黒笹町三ヶ峯１２７１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2180301019694',
    ),
    'E04655': EdinetCodeEntry(
        edinet_code='E04655',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=315,
        fiscal_year_end='3月31日',
        submitter_name='南国産業開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナンゴクサンギョウカイハツカブシキガイシャ',
        address='鹿児島市吉野町６７６９番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9340001003199',
    ),
    'E04656': EdinetCodeEntry(
        edinet_code='E04656',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=300,
        fiscal_year_end='8月31日',
        submitter_name='鳴門ゴルフ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナルトゴルフカブシキガイシャ',
        address='鳴門市瀬戸町北泊字北泊５２９－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7480001005076',
    ),
    'E04657': EdinetCodeEntry(
        edinet_code='E04657',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='遠州開発株式会社',
        submitter_name_en='Ensyukaihatsu Co., Ltd.',
        submitter_name_yomi='エンシュウカイハツカブシキガイシャ',
        address='浜松市天竜区渡ヶ島２０番地の６',
        industry='サービス業',
        sec_code=None,
        corporate_number='3080401010323',
    ),
    'E04658': EdinetCodeEntry(
        edinet_code='E04658',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=922,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000表蔵王国際ゴルフクラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000オモテザオウコクサイゴルフクラブ',
        address='柴田郡柴田町大字船迫字日光４８',
        industry='サービス業',
        sec_code=None,
        corporate_number='1370101000051',
    ),
    'E04661': EdinetCodeEntry(
        edinet_code='E04661',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=295,
        fiscal_year_end='3月31日',
        submitter_name='美々津観光開発株式会社',
        submitter_name_en='MIMITSU KANKO KAIHATSU CO.,LTD.',
        submitter_name_yomi='ミミツカンコウカイハツカブシキガイシャ',
        address='日向市東郷町山陰甲４１７番地９４',
        industry='サービス業',
        sec_code=None,
        corporate_number='6350001006212',
    ),
    'E04663': EdinetCodeEntry(
        edinet_code='E04663',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=207,
        fiscal_year_end='12月末日',
        submitter_name='株式会社旭川国際ゴルフ場',
        submitter_name_en='ASAHIGAWA KOKUSAI GOLF Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアサヒカワコクサイゴルフジョウ',
        address='旭川市５条通１０丁目２２３３番地の１３',
        industry='サービス業',
        sec_code=None,
        corporate_number='7450001000311',
    ),
    'E04664': EdinetCodeEntry(
        edinet_code='E04664',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=81,
        fiscal_year_end='6月30日',
        submitter_name='瀬戸内開発株式会社',
        submitter_name_en='Setouchi Kaihatsu Co.,Ltd.',
        submitter_name_yomi='セトウチカイハツカブシキガイシャ',
        address='三原市沼田東町釜山１０３４５番地の６',
        industry='サービス業',
        sec_code=None,
        corporate_number='5240001039653',
    ),
    'E04666': EdinetCodeEntry(
        edinet_code='E04666',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=93,
        fiscal_year_end='3月31日',
        submitter_name='福山観光開発株式会社',
        submitter_name_en='FUKUYAMA KANKOKAIHATSU CO.,LTD.',
        submitter_name_yomi='フクヤマカンコウカイハツカブシキガイシャ',
        address='福山市神辺町東中条４９８番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5240001029522',
    ),
    'E04667': EdinetCodeEntry(
        edinet_code='E04667',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=180,
        fiscal_year_end='9月30日',
        submitter_name='道後観光ゴルフ株式会社',
        submitter_name_en='DOGO KANKO GOLF CO.,LTD.',
        submitter_name_yomi='ドウゴカンコウゴルフカブシキガイシャ',
        address='松山市下伊台町乙１１５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6500001002831',
    ),
    'E04668': EdinetCodeEntry(
        edinet_code='E04668',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=905,
        fiscal_year_end='1月31日',
        submitter_name='株式会社富山ゴルフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトヤマゴルフ',
        address='富山市万願寺１の１６６番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9230001005132',
    ),
    'E04669': EdinetCodeEntry(
        edinet_code='E04669',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=474,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000秋田椿台ゴルフクラブ',
        submitter_name_en='Corporation Akita Tubakidai Golf Club',
        submitter_name_yomi='カブシキガイシャ\u3000アキタツバキダイゴルフクラブ',
        address='秋田市雄和椿川字奥椿岱２３５番',
        industry='サービス業',
        sec_code=None,
        corporate_number='6410001000448',
    ),
    'E04670': EdinetCodeEntry(
        edinet_code='E04670',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=957,
        fiscal_year_end='12月31日',
        submitter_name='魚津観光開発株式会社',
        submitter_name_en='UOZU KANKO KAIHATSU CO.,LTD.',
        submitter_name_yomi='ウオヅカンコウカイハツカブシキガイシャ',
        address='魚津市小川寺１００４番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7230001007007',
    ),
    'E04671': EdinetCodeEntry(
        edinet_code='E04671',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='1月31日',
        submitter_name='株式会社可児ゴルフ倶楽部',
        submitter_name_en='KANIGOLFCLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャカニゴルフクラブ',
        address='可児市久々利向平２２１番地の２',
        industry='サービス業',
        sec_code=None,
        corporate_number='1200001017708',
    ),
    'E04672': EdinetCodeEntry(
        edinet_code='E04672',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=80,
        fiscal_year_end='1月31日',
        submitter_name='備後観光開発株式会社',
        submitter_name_en='bingo tourist enterprise co..ltd.',
        submitter_name_yomi='ビンゴカンコウカイハツ\u3000カブシキカイシャ',
        address='世羅郡世羅町大字小世良１０６９１番地１５',
        industry='サービス業',
        sec_code=None,
        corporate_number='3240001039060',
    ),
    'E04673': EdinetCodeEntry(
        edinet_code='E04673',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='森ビルゴルフリゾート株式会社',
        submitter_name_en='Mori building Golf Resort Co., Ltd.',
        submitter_name_yomi='モリビルゴルフリゾートカブシキガイシャ',
        address='港区虎ノ門三丁目２１番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010401050432',
    ),
    'E04674': EdinetCodeEntry(
        edinet_code='E04674',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社小樽ゴルフ場',
        submitter_name_en='OTARU GOLF LINKS CO.,LTD.',
        submitter_name_yomi='カブシキカイシャオタルゴルフジョウ',
        address='小樽市銭函３丁目７３番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7430001049763',
    ),
    'E04675': EdinetCodeEntry(
        edinet_code='E04675',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=997,
        fiscal_year_end='8月31日',
        submitter_name='菊陽緑化興産株式会社',
        submitter_name_en='kikuyoryokukakosanco,ltd.',
        submitter_name_yomi='キクヨウリョクカコウサンカブシキガイシャ',
        address='菊池郡菊陽町曲手８３８番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8330001009140',
    ),
    'E04676': EdinetCodeEntry(
        edinet_code='E04676',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1434,
        fiscal_year_end='1月31日',
        submitter_name='三原京覧開発\u3000株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミハラキョウランカイハツカブシキガイシャ',
        address='三原市長谷町２９１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5240001039827',
    ),
    'E04677': EdinetCodeEntry(
        edinet_code='E04677',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=96,
        fiscal_year_end='8月31日',
        submitter_name='御調観光開発株式会社',
        submitter_name_en='MITSUKI KANKOKAIHATSU CO.,LTD.',
        submitter_name_yomi='ミツキカンコウカイハツカブシキガイシャ',
        address='三原市久井町坂井原絹掛７５５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4240001040133',
    ),
    'E04679': EdinetCodeEntry(
        edinet_code='E04679',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=193,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000出水ゴルフクラブ',
        submitter_name_en='IZUMI GOLF CLUB CO.LTD',
        submitter_name_yomi='カブシキガイシャ\u3000イズミゴルフクラブ',
        address='出水市平和町２７９番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2340001011695',
    ),
    'E04680': EdinetCodeEntry(
        edinet_code='E04680',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1175,
        fiscal_year_end='6月30日',
        submitter_name='各務原開発株式会社',
        submitter_name_en='KAKAMIGAHARAKAIHATSU CO.,LTD.',
        submitter_name_yomi='カカミガハラカイハツカブシキガイシャ',
        address='各務原市須衛字天狗谷２３６０－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7200001006952',
    ),
    'E04681': EdinetCodeEntry(
        edinet_code='E04681',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社房総カントリークラブ',
        submitter_name_en='BOSO COUNTRY CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャボウソウカントリークラブ',
        address='長生郡睦沢町妙楽寺字直沢２３００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='3040001059863',
    ),
    'E04682': EdinetCodeEntry(
        edinet_code='E04682',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3480,
        fiscal_year_end='1月31日',
        submitter_name='株式会社\u3000横浜スタジアム',
        submitter_name_en='Yokohama Stadium Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ヨコハマスタジアム',
        address='横浜市中区横浜公園',
        industry='サービス業',
        sec_code=None,
        corporate_number='2020001029497',
    ),
    'E04683': EdinetCodeEntry(
        edinet_code='E04683',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社明智ゴルフ倶楽部',
        submitter_name_en='AKECHI GOLF CLUB CO.,LTD',
        submitter_name_yomi='カブシキガイシャアケチゴルフクラブ',
        address='恵那市明智町吉良見字西山９８０番地の２',
        industry='サービス業',
        sec_code=None,
        corporate_number='3200001024041',
    ),
    'E04684': EdinetCodeEntry(
        edinet_code='E04684',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社笠間ゴルフクラブ',
        submitter_name_en='KASAMA GOLF CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャカサマゴルフクラブ',
        address='笠間市池野辺２５２３番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8050001008220',
    ),
    'E04685': EdinetCodeEntry(
        edinet_code='E04685',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='5月31日',
        submitter_name='株式会社金太郎温泉',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャキンタロウオンセン',
        address='魚津市天神野新６０００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4230001007050',
    ),
    'E04687': EdinetCodeEntry(
        edinet_code='E04687',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=45,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東松山カントリークラブ',
        submitter_name_en='HIGASHI MATSUYAMA COUNTRY CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヒガシマツヤマカントリークラブ',
        address='東松山市大字大谷１１１１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4030001071843',
    ),
    'E04691': EdinetCodeEntry(
        edinet_code='E04691',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=4340,
        fiscal_year_end='9月30日',
        submitter_name='ホウライ株式会社',
        submitter_name_en='HORAI Co.,Ltd.',
        submitter_name_yomi='ホウライカブシキガイシャ',
        address='中央区日本橋堀留町一丁目８番１２号',
        industry='サービス業',
        sec_code='96790',
        corporate_number='9010001108279',
    ),
    'E04693': EdinetCodeEntry(
        edinet_code='E04693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4180,
        fiscal_year_end='12月31日',
        submitter_name='グリーンランドリゾート株式会社',
        submitter_name_en='greenland resort company limited',
        submitter_name_yomi='グリーンランドリゾートカブシキガイシャ',
        address='荒尾市下井手１６１６番地',
        industry='サービス業',
        sec_code='96560',
        corporate_number='3330001011679',
    ),
    'E04695': EdinetCodeEntry(
        edinet_code='E04695',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=94,
        fiscal_year_end='4月30日',
        submitter_name='尾道ゴルフ観光株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オノミチゴルフカンコウカブシキガイシャ',
        address='尾道市新浜一丁目８番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9240001037892',
    ),
    'E04696': EdinetCodeEntry(
        edinet_code='E04696',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1119,
        fiscal_year_end='7月31日',
        submitter_name='株式会社\u3000藤ケ谷カントリー倶楽部',
        submitter_name_en='Fujigaya Country Culb Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフジガヤカントリークラブ',
        address='市川市八幡三丁目３番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010601015160',
    ),
    'E04698': EdinetCodeEntry(
        edinet_code='E04698',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='古賀ゴルフ株式会社',
        submitter_name_en='koga golf co. ,ltd',
        submitter_name_yomi='コガゴルフカブシキガイシャ',
        address='古賀市鹿部１３１０番地１',
        industry='サービス業',
        sec_code=None,
        corporate_number='1290001036311',
    ),
    'E04699': EdinetCodeEntry(
        edinet_code='E04699',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='12月31日',
        submitter_name='山陽開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンヨウカイハツカブシキガイシャ',
        address='加古川市上荘町井ノ口９２５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2140001042892',
    ),
    'E04700': EdinetCodeEntry(
        edinet_code='E04700',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社四日市カンツリー倶楽部',
        submitter_name_en='-',
        submitter_name_yomi='カブシキガイシャヨッカイチカンツリークラブ',
        address='四日市市山城町６４０番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9190001016704',
    ),
    'E04704': EdinetCodeEntry(
        edinet_code='E04704',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＳＤエンターテイメント株式会社',
        submitter_name_en='SD ENTERTAINMENT,Inc.',
        submitter_name_yomi='エスディーエンターテイメントカブシキガイシャ',
        address='札幌市白石区南郷通１丁目北８番１号',
        industry='サービス業',
        sec_code='46500',
        corporate_number='6430001008290',
    ),
    'E04706': EdinetCodeEntry(
        edinet_code='E04706',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='8月31日',
        submitter_name='株式会社\u3000高滝リンクス倶楽部',
        submitter_name_en='TAKATAKI  LINKS CLUB  LIMITED',
        submitter_name_yomi='カブシキカイシャ\u3000タカタキリンクスクラブ',
        address='新宿区四谷１－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7011101044374',
    ),
    'E04707': EdinetCodeEntry(
        edinet_code='E04707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=63201,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オリエンタルランド',
        submitter_name_en='ORIENTAL LAND CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオリエンタルランド',
        address='浦安市舞浜１番地１',
        industry='サービス業',
        sec_code='46610',
        corporate_number='3040001029379',
    ),
    'E04708': EdinetCodeEntry(
        edinet_code='E04708',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月20日',
        submitter_name='株式会社京ヶ野ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='キョウガノゴルフクラブカブシキガイシャ',
        address='名古屋市熱田区神宮四丁目７番２７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9180001044268',
    ),
    'E04709': EdinetCodeEntry(
        edinet_code='E04709',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='土佐観光施設株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トサカンコウシセツカブシキガイシャ',
        address='高知市重倉９４５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='3490001001532',
    ),
    'E04710': EdinetCodeEntry(
        edinet_code='E04710',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25665,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ラウンドワン',
        submitter_name_en='ROUND ONE Corporation',
        submitter_name_yomi='カブシキガイシャラウンドワン',
        address='大阪市中央区難波五丁目１番６０号',
        industry='サービス業',
        sec_code='46800',
        corporate_number='7120101008007',
    ),
    'E04714': EdinetCodeEntry(
        edinet_code='E04714',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＧＮＵ株式会社',
        submitter_name_en='GNU Inc.',
        submitter_name_yomi='ジーエヌユーカブシキガイシャ',
        address='中央区日本橋蛎殻町一丁目３９番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001094498',
    ),
    'E04715': EdinetCodeEntry(
        edinet_code='E04715',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='岡崎クラシック株式会社',
        submitter_name_en='OKAZAKI CLASSIC CO.,LTD.',
        submitter_name_yomi='オカザキクラシックカブシキガイシャ',
        address='岡崎市岩中町１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7180301003545',
    ),
    'E04719': EdinetCodeEntry(
        edinet_code='E04719',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=96,
        fiscal_year_end='3月31日',
        submitter_name='株式会社福岡サンレイクゴルフ倶楽部',
        submitter_name_en='FUKUOKASUNLAKE GOLFCLUB. CO.,LTD.',
        submitter_name_yomi='カブシキガイシャフクオカサンレイクゴルフクラブ',
        address='みやま市高田町上楠田１５１９番地２',
        industry='サービス業',
        sec_code=None,
        corporate_number='9290001053646',
    ),
    'E04720': EdinetCodeEntry(
        edinet_code='E04720',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オークモントゴルフクラブ',
        submitter_name_en='OAKMONT GOLF CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオークモントゴルフクラブ',
        address='山辺郡山添村岩屋３３１６番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7150001006413',
    ),
    'E04721': EdinetCodeEntry(
        edinet_code='E04721',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3185,
        fiscal_year_end='12月31日',
        submitter_name='株式会社紫雲ゴルフ倶楽部',
        submitter_name_en='shiun golf club co.,ltd.',
        submitter_name_yomi='カブシキガイシャシウンゴルフクラブ',
        address='新発田市元郷２１１',
        industry='サービス業',
        sec_code=None,
        corporate_number='1110001013328',
    ),
    'E04722': EdinetCodeEntry(
        edinet_code='E04722',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='多治見クラシック株式会社',
        submitter_name_en='TAJIMI CLASSIC CO.,LTD.',
        submitter_name_yomi='タジミクラシックカブシキガイシャ',
        address='多治見市小名田町１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7200001020771',
    ),
    'E04723': EdinetCodeEntry(
        edinet_code='E04723',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セントクリークゴルフクラブ',
        submitter_name_en='St.CREEK GOLF CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャセントクリークゴルフクラブ',
        address='豊田市月原町黒木１番地１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7180301020061',
    ),
    'E04724': EdinetCodeEntry(
        edinet_code='E04724',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=338,
        fiscal_year_end='12月31日',
        submitter_name='株式会社宇都宮ゴルフクラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウツノミヤゴルフクラブ',
        address='宇都宮市上戸祭町３１００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2060001000628',
    ),
    'E04725': EdinetCodeEntry(
        edinet_code='E04725',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社滋賀ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシガゴルフクラブ',
        address='甲賀市水口町嶬峨字大谷１１１５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2160001005138',
    ),
    'E04727': EdinetCodeEntry(
        edinet_code='E04727',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2553,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000極楽湯ホールディングス',
        submitter_name_en='GOKURAKUYU HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ゴクラクユホールディングス',
        address='千代田区麹町二丁目４番地',
        industry='サービス業',
        sec_code='23400',
        corporate_number='5010001063544',
    ),
    'E04728': EdinetCodeEntry(
        edinet_code='E04728',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=40,
        fiscal_year_end='12月31日',
        submitter_name='小金井ゴルフ株式会社',
        submitter_name_en='KOGANEI GOLF CO.,LTD.',
        submitter_name_yomi='コガネイゴルフカブシキカイシヤ',
        address='小平市御幸町３３１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5012701000297',
    ),
    'E04729': EdinetCodeEntry(
        edinet_code='E04729',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社小原カントリークラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオバラカントリークラブ',
        address='名古屋市中区丸の内三丁目２０番９号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6180001052538',
    ),
    'E04730': EdinetCodeEntry(
        edinet_code='E04730',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=765,
        fiscal_year_end='12月31日',
        submitter_name='株式会社サイプレスクラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサイプレスクラブ',
        address='丹波市氷上町三原２２９番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='7140001041411',
    ),
    'E04731': EdinetCodeEntry(
        edinet_code='E04731',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社山田クラブ２１',
        submitter_name_en='Yamada Club 21 Corp.',
        submitter_name_yomi='カブシキガイシャヤマダクラブニジュウイチ',
        address='渋谷区渋谷二丁目１０番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6011001030418',
    ),
    'E04732': EdinetCodeEntry(
        edinet_code='E04732',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='4月30日',
        submitter_name='株式会社涼仙',
        submitter_name_en='RYOSEN ENTERPRISE CO.,LTD',
        submitter_name_yomi='カブシキガイシャリョウセン',
        address='いなべ市員弁町西方６９５－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='3190001013203',
    ),
    'E04733': EdinetCodeEntry(
        edinet_code='E04733',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1880,
        fiscal_year_end='11月30日',
        submitter_name='大松産業株式会社',
        submitter_name_en='DAIMATSU SANGYOU CO., LTD.',
        submitter_name_yomi='ダイマツサンギョウカブシキガイシャ',
        address='三木市吉川町湯谷５６７番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6140001036809',
    ),
    'E04735': EdinetCodeEntry(
        edinet_code='E04735',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=64,
        fiscal_year_end='3月31日',
        submitter_name='株式会社グレイスヒルズカントリー倶楽部',
        submitter_name_en='GRACE HILLS COUNTRY CLUB CO.,LTD',
        submitter_name_yomi='カブシキガイシャグレイスヒルズカントリークラブ',
        address='四日市市桜町字池之谷２２３０',
        industry='サービス業',
        sec_code=None,
        corporate_number='3190001017311',
    ),
    'E04738': EdinetCodeEntry(
        edinet_code='E04738',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イーグルポイントゴルフクラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーグルポイントゴルフクラブ',
        address='稲敷郡阿見町福田１６６８番地５',
        industry='サービス業',
        sec_code=None,
        corporate_number='3050001010635',
    ),
    'E04739': EdinetCodeEntry(
        edinet_code='E04739',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=95,
        fiscal_year_end='9月30日',
        submitter_name='株式会社\u3000明世カントリークラブ',
        submitter_name_en='AKEYO COUNTRYCLUB CO.,LTD',
        submitter_name_yomi='カブシキガイシャ\u3000アケヨカントリークラブ',
        address='瑞浪市明世町月吉１１１２－８８',
        industry='サービス業',
        sec_code=None,
        corporate_number='1200001022906',
    ),
    'E04740': EdinetCodeEntry(
        edinet_code='E04740',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社リオフジワラカントリー',
        submitter_name_en='RIO FUJIWARA COUNTRY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャリオフジワラカントリー',
        address='名古屋市中区平和１丁目１５番２７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4180001055906',
    ),
    'E04741': EdinetCodeEntry(
        edinet_code='E04741',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=77,
        fiscal_year_end='3月31日',
        submitter_name='有馬冨士開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アリマフジカイハツカブシキガイシャ',
        address='三田市香下ユルシケ谷２００３番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='5140001066245',
    ),
    'E04742': EdinetCodeEntry(
        edinet_code='E04742',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='ゴールドウイン開発株式会社',
        submitter_name_en='GOLDWIN DEVELOPMENT INC.',
        submitter_name_yomi='ゴールドウインカイハツカブシキガイシャ',
        address='小矢部市興法寺１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8230001008978',
    ),
    'E04744': EdinetCodeEntry(
        edinet_code='E04744',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='南部富士株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナンブフジカブシキガイシャ',
        address='八幡平市大更第４７地割３４番地２',
        industry='サービス業',
        sec_code=None,
        corporate_number='9400001004174',
    ),
    'E04745': EdinetCodeEntry(
        edinet_code='E04745',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=250,
        fiscal_year_end='3月31日',
        submitter_name='株式会社山形ゴルフ倶楽部',
        submitter_name_en='YAMAGATA GOLF CLUB',
        submitter_name_yomi='カブシキカイシャヤマガタゴルフクラブ',
        address='東村山郡山辺町大字大蕨３１９７－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='2390001002509',
    ),
    'E04748': EdinetCodeEntry(
        edinet_code='E04748',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メイプルポイントゴルフクラブ',
        submitter_name_en='MAPLE POINT GOLF CLUB CO.,LTD.',
        submitter_name_yomi='カブシキガイシャメイプルポイントゴルフクラブ',
        address='上野原市鶴島３６００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9090001008587',
    ),
    'E04749': EdinetCodeEntry(
        edinet_code='E04749',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10940,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アコーディア・ゴルフ',
        submitter_name_en='Accordia Golf Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアコーディアゴルフ',
        address='渋谷区渋谷二丁目１５番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3011001040080',
    ),
    'E04751': EdinetCodeEntry(
        edinet_code='E04751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2570,
        fiscal_year_end='8月31日',
        submitter_name='株式会社コシダカホールディングス',
        submitter_name_en='KOSHIDAKA HOLDINGS Co.,LTD.',
        submitter_name_yomi='カブシキガイシャコシダカホールディングス',
        address='前橋市大友町一丁目５番地１',
        industry='サービス業',
        sec_code='21570',
        corporate_number='7070001003674',
    ),
    'E04752': EdinetCodeEntry(
        edinet_code='E04752',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=707,
        fiscal_year_end='3月31日',
        submitter_name='小野観光開発株式会社',
        submitter_name_en='Ono Kankokaihatsu Co., Ltd',
        submitter_name_yomi='オノカンコウカイハツカブシキガイシャ',
        address='小野市来住町１２２５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='2140001076627',
    ),
    'E04754': EdinetCodeEntry(
        edinet_code='E04754',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2410,
        fiscal_year_end='12月31日',
        submitter_name='株式会社白洋舍',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハクヨウシャ',
        address='大田区下丸子２丁目１１番８号',
        industry='サービス業',
        sec_code='97310',
        corporate_number='4011001018621',
    ),
    'E04756': EdinetCodeEntry(
        edinet_code='E04756',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=109312,
        fiscal_year_end='3月31日',
        submitter_name='三菱ＵＦＪニコス株式会社',
        submitter_name_en='Mitsubishi UFJ NICOS Co.,Ltd.',
        submitter_name_yomi='ミツビシユーエフジェイニコスカブシキガイシャ',
        address='文京区本郷３丁目３３番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010001000016',
    ),
    'E04757': EdinetCodeEntry(
        edinet_code='E04757',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6673,
        fiscal_year_end=None,
        submitter_name='東京中小企業投資育成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウチュウショウキギョウトウシイクセイカブシキガイシャ',
        address='渋谷区渋谷三丁目２９番２２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001030621',
    ),
    'E04758': EdinetCodeEntry(
        edinet_code='E04758',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6822,
        fiscal_year_end=None,
        submitter_name='大阪中小企業投資育成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオサカチュウショウキギョウトウシイクセイカブシキガイシャ',
        address='大阪市北区中之島３丁目３番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001059625',
    ),
    'E04760': EdinetCodeEntry(
        edinet_code='E04760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=74609,
        fiscal_year_end='12月31日',
        submitter_name='株式会社電通グループ',
        submitter_name_en='DENTSU GROUP INC.',
        submitter_name_yomi='カブシキガイシャデンツウグループ',
        address='港区東新橋一丁目８番１号',
        industry='サービス業',
        sec_code='43240',
        corporate_number='4010401048922',
    ),
    'E04761': EdinetCodeEntry(
        edinet_code='E04761',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2558,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＡＬＵＸ',
        submitter_name_en='JALUX Inc.',
        submitter_name_yomi='カブシキガイシャジャルックス',
        address='港区港南１丁目２番７０号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6010701007411',
    ),
    'E04762': EdinetCodeEntry(
        edinet_code='E04762',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=221111,
        fiscal_year_end='3月31日',
        submitter_name='オリックス株式会社',
        submitter_name_en='ORIX CORPORATION',
        submitter_name_yomi='オリックスカブシキガイシャ',
        address='港区浜松町２丁目４番１号世界貿易センタービル南館内',
        industry='その他金融業',
        sec_code='85910',
        corporate_number='8010401006942',
    ),
    'E04763': EdinetCodeEntry(
        edinet_code='E04763',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='1月31日',
        submitter_name='株式会社精養軒',
        submitter_name_en='Kabushiki kaisha Seiyoken.',
        submitter_name_yomi='カブシキガイシャセイヨウケン',
        address='台東区上野公園４番５８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010501016293',
    ),
    'E04764': EdinetCodeEntry(
        edinet_code='E04764',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2131,
        fiscal_year_end='5月31日',
        submitter_name='株式会社オオバ',
        submitter_name_en='OHBA CO.,LTD.',
        submitter_name_yomi='カブシキカイシャオオバ',
        address='千代田区神田錦町三丁目７番１号',
        industry='サービス業',
        sec_code='97650',
        corporate_number='9013201001170',
    ),
    'E04766': EdinetCodeEntry(
        edinet_code='E04766',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1020,
        fiscal_year_end='3月31日',
        submitter_name='全国不動産信用保証株式会社',
        submitter_name_en='National Real Estate Guarantee Co., Ltd.',
        submitter_name_yomi='ゼンコクフドウサンシンヨウホショウカブシキガイシャ',
        address='新宿区新宿１丁目２６番６号\u3000新宿加藤ビルディング',
        industry='サービス業',
        sec_code=None,
        corporate_number='5011101011062',
    ),
    'E04767': EdinetCodeEntry(
        edinet_code='E04767',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3980,
        fiscal_year_end='5月31日',
        submitter_name='互助会保証株式会社',
        submitter_name_en='MUTUAL SERVICE AID GUARANTEE CORPORATION',
        submitter_name_yomi='ゴジョカイホショウカブシキガイシャ',
        address='港区西新橋一丁目１８番１２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010401010230',
    ),
    'E04768': EdinetCodeEntry(
        edinet_code='E04768',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35680,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャックス',
        submitter_name_en='JACCS CO., LTD.',
        submitter_name_yomi='カブシキガイシャジャックス',
        address='函館市若松町２番５号（上記は登記上の本店所在地であり、実際の業務は下記の場所で行っております。）',
        industry='その他金融業',
        sec_code='85840',
        corporate_number='2440001001001',
    ),
    'E04773': EdinetCodeEntry(
        edinet_code='E04773',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=66427,
        fiscal_year_end='3月31日',
        submitter_name='セコム株式会社',
        submitter_name_en='SECOM CO., LTD.',
        submitter_name_yomi='セコムカブシキガイシャ',
        address='渋谷区神宮前一丁目５番１号',
        industry='サービス業',
        sec_code='97350',
        corporate_number='6011001035920',
    ),
    'E04775': EdinetCodeEntry(
        edinet_code='E04775',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=150079,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オリエントコーポレーション',
        submitter_name_en='Orient Corporation',
        submitter_name_yomi='カブシキガイシャオリエントコーポレーション',
        address='千代田区麹町５丁目２番地１',
        industry='その他金融業',
        sec_code='85850',
        corporate_number='9010001070784',
    ),
    'E04777': EdinetCodeEntry(
        edinet_code='E04777',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2651,
        fiscal_year_end='3月31日',
        submitter_name='丸建リース株式会社',
        submitter_name_en='Maruken Lease Co.,Ltd.',
        submitter_name_yomi='マルケンリースカブシキガイシャ',
        address='港区芝公園２丁目４番１号',
        industry='卸売業',
        sec_code='97630',
        corporate_number='1010401028415',
    ),
    'E04779': EdinetCodeEntry(
        edinet_code='E04779',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=9983,
        fiscal_year_end='3月31日',
        submitter_name='日立キャピタル株式会社',
        submitter_name_en='Hitachi Capital Corporation',
        submitter_name_yomi='ヒタチキャピタルカブシキガイシャ',
        address='港区西新橋一丁目３番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010401024970',
    ),
    'E04780': EdinetCodeEntry(
        edinet_code='E04780',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='ＴＫＣ金融保証株式会社',
        submitter_name_en='TKC FINANCE GUARANTEE CO.,LTD.',
        submitter_name_yomi='テイケイシイキンユウホショウカブシキガイシャ',
        address='新宿区揚場町１番２１号飯田橋升本ビル',
        industry='サービス業',
        sec_code=None,
        corporate_number='5011101061495',
    ),
    'E04783': EdinetCodeEntry(
        edinet_code='E04783',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17830,
        fiscal_year_end='12月31日',
        submitter_name='ロイヤルホールディングス株式会社',
        submitter_name_en='ROYAL HOLDINGS Co., Ltd.',
        submitter_name_yomi='ロイヤルホールディングスカブシキガイシャ',
        address='福岡市博多区那珂三丁目２８番５号',
        industry='小売業',
        sec_code='81790',
        corporate_number='2290001017525',
    ),
    'E04784': EdinetCodeEntry(
        edinet_code='E04784',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2572,
        fiscal_year_end='2月末日',
        submitter_name='株式会社東天紅',
        submitter_name_en='Totenko Co., Ltd.',
        submitter_name_yomi='カブシキガイシャトウテンコウ',
        address='台東区池之端１－４－１',
        industry='小売業',
        sec_code='81810',
        corporate_number='5010501016225',
    ),
    'E04788': EdinetCodeEntry(
        edinet_code='E04788',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33196,
        fiscal_year_end='3月31日',
        submitter_name='三菱ＨＣキャピタル株式会社',
        submitter_name_en='Mitsubishi HC Capital Inc.',
        submitter_name_yomi='ミツビシエイチシーキャピタルカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='その他金融業',
        sec_code='85930',
        corporate_number='4010001049866',
    ),
    'E04791': EdinetCodeEntry(
        edinet_code='E04791',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='三井住友ファイナンス＆リース株式会社',
        submitter_name_en='Sumitomo Mitsui Finance and Leasing Company, Limited',
        submitter_name_yomi='ミツイスミトモファイナンスアンドリース',
        address='千代田区丸の内一丁目３番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010401072079',
    ),
    'E04795': EdinetCodeEntry(
        edinet_code='E04795',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3173,
        fiscal_year_end='12月31日',
        submitter_name='いであ株式会社',
        submitter_name_en='IDEA Consultants.Inc.',
        submitter_name_yomi='イデアカブシキガイシャ',
        address='世田谷区駒沢三丁目１５番１号',
        industry='サービス業',
        sec_code='97680',
        corporate_number='7010901005494',
    ),
    'E04796': EdinetCodeEntry(
        edinet_code='E04796',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1216,
        fiscal_year_end='3月31日',
        submitter_name='株式会社学究社',
        submitter_name_en='GAKKYUSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャガッキュウシャ',
        address='渋谷区代々木一丁目１２番８号',
        industry='サービス業',
        sec_code='97690',
        corporate_number='6012401003599',
    ),
    'E04799': EdinetCodeEntry(
        edinet_code='E04799',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2924,
        fiscal_year_end='2月末日',
        submitter_name='セントラル警備保障株式会社',
        submitter_name_en='CENTRAL SECURITY PATROLS CO.,LTD.',
        submitter_name_yomi='セントラルケイビホショウカブシキガイシャ',
        address='新宿区西新宿二丁目４番１号\u3000新宿ＮＳビル',
        industry='サービス業',
        sec_code='97400',
        corporate_number='9011101011216',
    ),
    'E04800': EdinetCodeEntry(
        edinet_code='E04800',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8032,
        fiscal_year_end='3月31日',
        submitter_name='東海リース株式会社',
        submitter_name_en='TOKAI LEASE CO.,LTD.',
        submitter_name_yomi='トウカイリースカブシキガイシャ',
        address='大阪市北区天神橋２丁目北２番６号',
        industry='サービス業',
        sec_code='97610',
        corporate_number='7120001067607',
    ),
    'E04801': EdinetCodeEntry(
        edinet_code='E04801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2297,
        fiscal_year_end='12月31日',
        submitter_name='中道リース株式会社',
        submitter_name_en='Nakamichi Leasing Co., Ltd.',
        submitter_name_yomi='ナカミチリースカブシキガイシャ',
        address='札幌市中央区北一条東三丁目３番地',
        industry='その他金融業',
        sec_code='85940',
        corporate_number='1430001024094',
    ),
    'E04803': EdinetCodeEntry(
        edinet_code='E04803',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイネス',
        submitter_name_en='INES Corporation',
        submitter_name_yomi='カブシキガイシャアイネス',
        address='中央区日本橋蛎殻町１丁目３８番１１号',
        industry='情報・通信業',
        sec_code='97420',
        corporate_number='2020001030067',
    ),
    'E04804': EdinetCodeEntry(
        edinet_code='E04804',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メイテックグループホールディングス',
        submitter_name_en='MEITEC Group Holdings Inc.',
        submitter_name_yomi='カブシキガイシャメイテックグループホールディングス',
        address='厚木市森の里青山１５番１号',
        industry='サービス業',
        sec_code='97440',
        corporate_number='1180001027412',
    ),
    'E04806': EdinetCodeEntry(
        edinet_code='E04806',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=33251,
        fiscal_year_end='3月31日',
        submitter_name='ジャフコ\u3000グループ株式会社',
        submitter_name_en='JAFCO Group Co., Ltd.',
        submitter_name_yomi='ジャフコ\u3000グループカブシキガイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='証券、商品先物取引業',
        sec_code='85950',
        corporate_number='9010001019930',
    ),
    'E04807': EdinetCodeEntry(
        edinet_code='E04807',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5700,
        fiscal_year_end='9月30日',
        submitter_name='株式会社\u3000ＴＫＣ',
        submitter_name_en='TKC Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000テイケイシイ',
        address='宇都宮市鶴田町１７５８番地',
        industry='情報・通信業',
        sec_code='97460',
        corporate_number='5060001002844',
    ),
    'E04808': EdinetCodeEntry(
        edinet_code='E04808',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=37581,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アサツーディ・ケイ',
        submitter_name_en='ASATSU-DK INC.',
        submitter_name_yomi='カブシキガイシヤアサツーデイケイ',
        address='港区虎ノ門一丁目２３番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001035099',
    ),
    'E04809': EdinetCodeEntry(
        edinet_code='E04809',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4222,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＴＴデータＮＪＫ',
        submitter_name_en='NTT DATA NJK CORPORATION',
        submitter_name_yomi='カブシキガイシャエヌティティデータエヌジェーケー',
        address='中央区新富２丁目３番４号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3013201000954',
    ),
    'E04810': EdinetCodeEntry(
        edinet_code='E04810',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=26200,
        fiscal_year_end='12月31日',
        submitter_name='富士ソフト株式会社',
        submitter_name_en='FUJI SOFT INCORPORATED',
        submitter_name_yomi='フジソフトカブシキガシヤ',
        address='横浜市中区桜木町一丁目１番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2020001043507',
    ),
    'E04815': EdinetCodeEntry(
        edinet_code='E04815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1180,
        fiscal_year_end='3月31日',
        submitter_name='アイエックス・ナレッジ株式会社',
        submitter_name_en='IX Knowledge Incorporated',
        submitter_name_yomi='アイエックスナレッジカブシキガイシャ',
        address='港区海岸三丁目２２番２３号',
        industry='情報・通信業',
        sec_code='97530',
        corporate_number='5010401047403',
    ),
    'E04816': EdinetCodeEntry(
        edinet_code='E04816',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16174,
        fiscal_year_end='12月31日',
        submitter_name='応用地質株式会社',
        submitter_name_en='OYO Corporation',
        submitter_name_yomi='オウヨウチシツカブシキガイシャ',
        address='千代田区神田美土代町７番地',
        industry='サービス業',
        sec_code='97550',
        corporate_number='2010001034531',
    ),
    'E04817': EdinetCodeEntry(
        edinet_code='E04817',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3125,
        fiscal_year_end='12月31日',
        submitter_name='株式会社船井総研ホールディングス',
        submitter_name_en='Funai Soken Holdings Incorporated',
        submitter_name_yomi='カブシキガイシャフナイソウケンホールディングス',
        address='中央区八重洲二丁目２番１号',
        industry='サービス業',
        sec_code='97570',
        corporate_number='1120001069955',
    ),
    'E04820': EdinetCodeEntry(
        edinet_code='E04820',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1302,
        fiscal_year_end='12月31日',
        submitter_name='ジャパンシステム株式会社',
        submitter_name_en='JAPAN SYSTEMS Co.,LTD.',
        submitter_name_yomi='ジャパンシステムカブシキガイシャ',
        address='渋谷区代々木一丁目２２番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9011001053119',
    ),
    'E04821': EdinetCodeEntry(
        edinet_code='E04821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2933,
        fiscal_year_end='3月31日',
        submitter_name='株式会社九州リースサービス',
        submitter_name_en='KYUSHU LEASING SERVICE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキュウシュウリースサービス',
        address='福岡市博多区博多駅前４丁目３番１８号',
        industry='その他金融業',
        sec_code='85960',
        corporate_number='2290001012609',
    ),
    'E04822': EdinetCodeEntry(
        edinet_code='E04822',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7205,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＳＤ',
        submitter_name_en='NSD CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000エヌエスディ',
        address='千代田区神田淡路町２－１０１',
        industry='情報・通信業',
        sec_code='97590',
        corporate_number='1011101046616',
    ),
    'E04823': EdinetCodeEntry(
        edinet_code='E04823',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3984,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000進学会ホールディングス',
        submitter_name_en='SHINGAKUKAI HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000シンガクカイホールディングス',
        address='札幌市白石区本郷通一丁目北１番１５号',
        industry='サービス業',
        sec_code='97600',
        corporate_number='5430001007277',
    ),
    'E04824': EdinetCodeEntry(
        edinet_code='E04824',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2138,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナガセ',
        submitter_name_en='Nagase Brothers Inc.',
        submitter_name_yomi='カブシキガイシャナガセ',
        address='武蔵野市吉祥寺南町一丁目２９番２号',
        industry='サービス業',
        sec_code='97330',
        corporate_number='9012401011590',
    ),
    'E04826': EdinetCodeEntry(
        edinet_code='E04826',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8108,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トーカイ',
        submitter_name_en='TOKAI Corp.',
        submitter_name_yomi='カブシキガイシャトーカイ',
        address='岐阜市若宮町九丁目１６番地',
        industry='サービス業',
        sec_code='97290',
        corporate_number='8200001003544',
    ),
    'E04828': EdinetCodeEntry(
        edinet_code='E04828',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='日本管財株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンカンザイカブシキガイシャ',
        address='西宮市六湛寺町９番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140001069797',
    ),
    'E04830': EdinetCodeEntry(
        edinet_code='E04830',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22088,
        fiscal_year_end='3月31日',
        submitter_name='ＳＣＳＫ株式会社',
        submitter_name_en='SCSK Corporation',
        submitter_name_yomi='エスシーエスケイカブシキガイシャ',
        address='江東区豊洲三丁目２番２０号',
        industry='情報・通信業',
        sec_code='97190',
        corporate_number='8010001074167',
    ),
    'E04834': EdinetCodeEntry(
        edinet_code='E04834',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2238,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ジャステック',
        submitter_name_en='JASTEC Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャジャステック',
        address='港区高輪三丁目５番２３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='4010401014057',
    ),
    'E04835': EdinetCodeEntry(
        edinet_code='E04835',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6497,
        fiscal_year_end='2月末日',
        submitter_name='株式会社乃村工藝社',
        submitter_name_en='NOMURA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャノムラコウゲイシャ',
        address='港区台場２丁目３番４号',
        industry='サービス業',
        sec_code='97160',
        corporate_number='4010401023652',
    ),
    'E04837': EdinetCodeEntry(
        edinet_code='E04837',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=29065,
        fiscal_year_end='3月31日',
        submitter_name='トランス・コスモス株式会社',
        submitter_name_en='transcosmos inc.',
        submitter_name_yomi='トランスコスモスカブシキガイシャ',
        address='渋谷区東一丁目２番２０号',
        industry='サービス業',
        sec_code='97150',
        corporate_number='3011001041302',
    ),
    'E04841': EdinetCodeEntry(
        edinet_code='E04841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3775,
        fiscal_year_end='3月31日',
        submitter_name='ＮＣＳ＆Ａ株式会社',
        submitter_name_en='NCS&A CO.,LTD.',
        submitter_name_yomi='エヌシーエスアンドエーカブシキガイシャ',
        address='大阪市北区中之島３丁目３番２３号',
        industry='情報・通信業',
        sec_code='97090',
        corporate_number='8120001072787',
    ),
    'E04843': EdinetCodeEntry(
        edinet_code='E04843',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4050,
        fiscal_year_end='3月31日',
        submitter_name='東京博善株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウハクゼンカブシキガイシャ',
        address='千代田区内神田２丁目５番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001034362',
    ),
    'E04844': EdinetCodeEntry(
        edinet_code='E04844',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユニマット\u3000リタイアメント・コミュニティ',
        submitter_name_en='UNIMAT Retirement Community CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャユニマット\u3000リタイアメント\u3000コミュニティ',
        address='港区北青山二丁目７番１３号\u3000プラセオ青山ビル',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010401095635',
    ),
    'E04846': EdinetCodeEntry(
        edinet_code='E04846',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2410,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アイ・エス・ビー',
        submitter_name_en='ISB CORPORATION',
        submitter_name_yomi='カブシキガイシャアイエスビー',
        address='港区港南二丁目１６番３号',
        industry='情報・通信業',
        sec_code='97020',
        corporate_number='4010701000269',
    ),
    'E04848': EdinetCodeEntry(
        edinet_code='E04848',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8100,
        fiscal_year_end='9月30日',
        submitter_name='ニシオホールディングス株式会社',
        submitter_name_en='NISHIO HOLDINGS CO., LTD.',
        submitter_name_yomi='ニシオホールディングスカブシキガイシャ',
        address='大阪市中央区東心斎橋１丁目１１番１７号',
        industry='サービス業',
        sec_code='96990',
        corporate_number='8120001086432',
    ),
    'E04849': EdinetCodeEntry(
        edinet_code='E04849',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3149,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クレオ',
        submitter_name_en='creo co.,ltd.',
        submitter_name_yomi='カブシキガイシャクレオ',
        address='品川区東品川四丁目１０番２７号',
        industry='情報・通信業',
        sec_code='96980',
        corporate_number='7010401008436',
    ),
    'E04850': EdinetCodeEntry(
        edinet_code='E04850',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1299,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウィザス',
        submitter_name_en='With us Corporation',
        submitter_name_yomi='カブシキガイシャウィザス',
        address='大阪市中央区備後町三丁目６番２号ＫＦセンタービル',
        industry='サービス業',
        sec_code=None,
        corporate_number='9120001076820',
    ),
    'E04853': EdinetCodeEntry(
        edinet_code='E04853',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6586,
        fiscal_year_end='1月31日',
        submitter_name='株式会社シーイーシー',
        submitter_name_en='COMPUTER ENGINEERING & CONSULTING LTD.',
        submitter_name_yomi='カブシキガイシャシーイーシー',
        address='座間市東原五丁目１番１１号',
        industry='情報・通信業',
        sec_code='96920',
        corporate_number='9021001026338',
    ),
    'E04855': EdinetCodeEntry(
        edinet_code='E04855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1966,
        fiscal_year_end='3月31日',
        submitter_name='株式会社両毛システムズ',
        submitter_name_en='RYOMO SYSTEMS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャリョウモウシステムズ',
        address='桐生市広沢町三丁目４０２５番地',
        industry='情報・通信業',
        sec_code='96910',
        corporate_number='2070001016771',
    ),
    'E04856': EdinetCodeEntry(
        edinet_code='E04856',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1448,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＳＫ',
        submitter_name_en='KSK CO.,LTD.',
        submitter_name_yomi='カブシキガイシャケイエスケイ',
        address='稲城市百村１６２５番地２',
        industry='情報・通信業',
        sec_code='96870',
        corporate_number='1013401001845',
    ),
    'E04857': EdinetCodeEntry(
        edinet_code='E04857',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4618,
        fiscal_year_end='3月31日',
        submitter_name='東洋テック株式会社',
        submitter_name_en='toyo tec co ., ltd',
        submitter_name_yomi='トウヨウテックカブシキカイシャ',
        address='大阪市浪速区桜川１丁目７番１８号',
        industry='サービス業',
        sec_code='96860',
        corporate_number='8120001039200',
    ),
    'E04858': EdinetCodeEntry(
        edinet_code='E04858',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1612,
        fiscal_year_end='3月31日',
        submitter_name='ＫＹＣＯＭホールディングス株式会社',
        submitter_name_en='KYCOM  HOLDINGS CO.,LTD.',
        submitter_name_yomi='カイコム\u3000ホールディングス\u3000カブシキガイシャ',
        address='福井市月見五丁目４番４号',
        industry='情報・通信業',
        sec_code='96850',
        corporate_number='8210001001027',
    ),
    'E04859': EdinetCodeEntry(
        edinet_code='E04859',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=24039,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スクウェア・エニックス・ホールディングス',
        submitter_name_en='SQUARE ENIX HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスクウェアエニックスホールディングス',
        address='新宿区新宿六丁目２７番３０号',
        industry='情報・通信業',
        sec_code='96840',
        corporate_number='5011001027704',
    ),
    'E04860': EdinetCodeEntry(
        edinet_code='E04860',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3013,
        fiscal_year_end='3月31日',
        submitter_name='株式会社共成レンテム',
        submitter_name_en='KYOSEI RENTEMU CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャキョウセイレンテム',
        address='帯広市西１８条北１丁目１４番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6460101000459',
    ),
    'E04861': EdinetCodeEntry(
        edinet_code='E04861',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6113,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＤＴＳ',
        submitter_name_en='DTS CORPORATION',
        submitter_name_yomi='カブシキガイシャディティエス',
        address='中央区八丁堀２丁目２３番１号',
        industry='情報・通信業',
        sec_code='96820',
        corporate_number='9010401018458',
    ),
    'E04862': EdinetCodeEntry(
        edinet_code='E04862',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17829,
        fiscal_year_end='10月31日',
        submitter_name='株式会社カナモト',
        submitter_name_en='Kanamoto Co., Ltd.',
        submitter_name_yomi='カブシキガイシャカナモト',
        address='札幌市中央区大通東三丁目１番地１９',
        industry='サービス業',
        sec_code='96780',
        corporate_number='8430001003991',
    ),
    'E04867': EdinetCodeEntry(
        edinet_code='E04867',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2855,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナガワ',
        submitter_name_en='NAGAWA Co .,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ナガワ',
        address='千代田区丸の内一丁目４番１号',
        industry='サービス業',
        sec_code='96630',
        corporate_number='7430001056297',
    ),
    'E04869': EdinetCodeEntry(
        edinet_code='E04869',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2233,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビジネスブレイン太田昭和',
        submitter_name_en='BUSINESS BRAIN SHOWAOTA INC.',
        submitter_name_yomi='カブシキガイシャビジネスブレインオオタショウワ',
        address='港区西新橋一丁目１番１号',
        industry='情報・通信業',
        sec_code='96580',
        corporate_number='3010401088688',
    ),
    'E04873': EdinetCodeEntry(
        edinet_code='E04873',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1487,
        fiscal_year_end='5月31日',
        submitter_name='日本プロセス株式会社',
        submitter_name_en='Japan Process Development Co.,Ltd.',
        submitter_name_yomi='ニホンプロセスカブシキガイシャ',
        address='品川区大崎一丁目１１番１号',
        industry='情報・通信業',
        sec_code='96510',
        corporate_number='2010401055029',
    ),
    'E04874': EdinetCodeEntry(
        edinet_code='E04874',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3238,
        fiscal_year_end='2月末日',
        submitter_name='イオンディライト株式会社',
        submitter_name_en='AEON DELIGHT CO., LTD.',
        submitter_name_yomi='イオンディライトカブシキガイシャ',
        address='大阪市中央区南船場２丁目３番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1120001081381',
    ),
    'E04877': EdinetCodeEntry(
        edinet_code='E04877',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3198,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミロク情報サービス',
        submitter_name_en='MIROKU JYOHO SERVICE CO.,LTD',
        submitter_name_yomi='カブシキガイシャミロクジョウホウサービス',
        address='新宿区四谷四丁目２９番地１',
        industry='情報・通信業',
        sec_code='99280',
        corporate_number='4011101020774',
    ),
    'E04878': EdinetCodeEntry(
        edinet_code='E04878',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=686,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソラスト',
        submitter_name_en='Solasto Corporation',
        submitter_name_yomi='カブシキガイシャソラスト',
        address='港区港南二丁目１５番３号',
        industry='サービス業',
        sec_code='61970',
        corporate_number='3010001032864',
    ),
    'E04884': EdinetCodeEntry(
        edinet_code='E04884',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='11月30日',
        submitter_name='株式会社協和コンサルタンツ',
        submitter_name_en='KYOWA ENGINEERING CONSULTANTS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャキョウワコンサルタンツ',
        address='渋谷区笹塚一丁目６２番１１号',
        industry='サービス業',
        sec_code='96470',
        corporate_number='2011001006553',
    ),
    'E04887': EdinetCodeEntry(
        edinet_code='E04887',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1772,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タナベコンサルティンググループ',
        submitter_name_en='TANABE CONSULTING GROUP CO.,LTD.',
        submitter_name_yomi='カブシキカイシャタナベコンサルティンググループ',
        address='大阪市淀川区宮原３丁目３番４１号',
        industry='サービス業',
        sec_code='96440',
        corporate_number='3120001133750',
    ),
    'E04888': EdinetCodeEntry(
        edinet_code='E04888',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1167,
        fiscal_year_end='9月30日',
        submitter_name='サコス株式会社',
        submitter_name_en='SACOS CORPORATION',
        submitter_name_yomi='サコスカブシキガイシャ',
        address='品川区東五反田四丁目５番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010701012492',
    ),
    'E04889': EdinetCodeEntry(
        edinet_code='E04889',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1367,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セゾンテクノロジー',
        submitter_name_en='SAISON TECHNOLOGY CO,.LTD.',
        submitter_name_yomi='カブシキガイシャセゾンテクノロジー',
        address='港区赤坂一丁目８番１号',
        industry='情報・通信業',
        sec_code='96400',
        corporate_number='7013301005882',
    ),
    'E04890': EdinetCodeEntry(
        edinet_code='E04890',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1545,
        fiscal_year_end='3月31日',
        submitter_name='三協フロンテア株式会社',
        submitter_name_en='SANKYO FRONTIER CO.,LTD.',
        submitter_name_yomi='サンキョウフロンテアカブシキガイシャ',
        address='柏市新十余二５番地',
        industry='サービス業',
        sec_code='96390',
        corporate_number='8040001065642',
    ),
    'E04894': EdinetCodeEntry(
        edinet_code='E04894',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=890,
        fiscal_year_end='3月31日',
        submitter_name='ピー・シー・エー株式会社',
        submitter_name_en='PCA CORPORATION',
        submitter_name_yomi='ピーシーエーカブシキガイシャ',
        address='千代田区富士見１－２－２１',
        industry='情報・通信業',
        sec_code='96290',
        corporate_number='4010001027327',
    ),
    'E04895': EdinetCodeEntry(
        edinet_code='E04895',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2568,
        fiscal_year_end='8月31日',
        submitter_name='燦ホールディングス株式会社',
        submitter_name_en='SAN HOLDINGS,INC.',
        submitter_name_yomi='サンホールディングスカブシキガイシャ',
        address='大阪市中央区北浜二丁目６番１１号',
        industry='サービス業',
        sec_code='96280',
        corporate_number='6120001079074',
    ),
    'E04896': EdinetCodeEntry(
        edinet_code='E04896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21894,
        fiscal_year_end='4月30日',
        submitter_name='株式会社アインホールディングス',
        submitter_name_en='AIN HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャアインホールディングス',
        address='札幌市白石区東札幌五条二丁目４番３０号',
        industry='小売業',
        sec_code='96270',
        corporate_number='1430001020787',
    ),
    'E04899': EdinetCodeEntry(
        edinet_code='E04899',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1370,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セレスポ',
        submitter_name_en='CERESPO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャセレスポ',
        address='豊島区北大塚一丁目２１番５号',
        industry='サービス業',
        sec_code='96250',
        corporate_number='9013301006441',
    ),
    'E04900': EdinetCodeEntry(
        edinet_code='E04900',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1000,
        fiscal_year_end='9月30日',
        submitter_name='株式会社長大',
        submitter_name_en='CHODAI CO.,LTD.',
        submitter_name_yomi='カブシキガイシャチョウダイ',
        address='中央区日本橋蛎殻町一丁目２０番４号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001050435',
    ),
    'E04902': EdinetCodeEntry(
        edinet_code='E04902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3395,
        fiscal_year_end='12月31日',
        submitter_name='株式会社スペース',
        submitter_name_en='SPACE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスペース',
        address='中央区日本橋人形町三丁目９番４号',
        industry='サービス業',
        sec_code='96220',
        corporate_number='7010001047784',
    ),
    'E04903': EdinetCodeEntry(
        edinet_code='E04903',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3025,
        fiscal_year_end='12月31日',
        submitter_name='株式会社建設技術研究所',
        submitter_name_en='CTI Engineering Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャケンセツギジュツケンキュウショ',
        address='中央区日本橋浜町三丁目２１番１号',
        industry='サービス業',
        sec_code='96210',
        corporate_number='7010001042703',
    ),
    'E04904': EdinetCodeEntry(
        edinet_code='E04904',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2529,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イチネンホールディングス',
        submitter_name_en='ICHINEN HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイチネンホールディングス',
        address='大阪市淀川区西中島４丁目１０番６号',
        industry='サービス業',
        sec_code='96190',
        corporate_number='9120001053828',
    ),
    'E04908': EdinetCodeEntry(
        edinet_code='E04908',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7964,
        fiscal_year_end='3月31日',
        submitter_name='株式会社共立メンテナンス',
        submitter_name_en='KYORITSU MAINTENANCE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウリツメンテナンス',
        address='千代田区外神田２丁目１８番８号',
        industry='サービス業',
        sec_code='96160',
        corporate_number='1010001014427',
    ),
    'E04911': EdinetCodeEntry(
        edinet_code='E04911',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=142520,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮＴＴデータグループ',
        submitter_name_en='NTT DATA  GROUP CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000エヌティティデータグループ',
        address='江東区豊洲三丁目３番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010601021385',
    ),
    'E04912': EdinetCodeEntry(
        edinet_code='E04912',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45698,
        fiscal_year_end='2月末日',
        submitter_name='イオンフィナンシャルサービス株式会社',
        submitter_name_en='AEON Financial Service Co.,Ltd.',
        submitter_name_yomi='イオンフィナンシャルサービスカブシキカイシャ',
        address='千代田区神田錦町一丁目１番地',
        industry='その他金融業',
        sec_code='85700',
        corporate_number='2010001010887',
    ),
    'E04914': EdinetCodeEntry(
        edinet_code='E04914',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3992,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ラックランド',
        submitter_name_en='LUCKLAND CO., LTD.',
        submitter_name_yomi='カブシキガイシャラックランド',
        address='新宿区西新宿三丁目１８番２０号',
        industry='サービス業',
        sec_code='96120',
        corporate_number='6011101022356',
    ),
    'E04915': EdinetCodeEntry(
        edinet_code='E04915',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6757,
        fiscal_year_end='3月31日',
        submitter_name='大黒屋グローバルホールディング株式会社',
        submitter_name_en='Daikokuya Global Holding Co., Ltd.',
        submitter_name_yomi='ダイコクヤグローバルホールディングカブシキガイシャ',
        address='港区港南４丁目１番８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010401087301',
    ),
    'E04916': EdinetCodeEntry(
        edinet_code='E04916',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=722,
        fiscal_year_end='3月31日',
        submitter_name='ウィルソン・ラーニング\u3000ワールドワイド株式会社',
        submitter_name_en='WILSON LEARNING WORLDWIDE INC.',
        submitter_name_yomi='ウィルソン\u3000ラーニング\u3000ワールドワイドカブシキガイシャ',
        address='港区虎ノ門二丁目１０番１号',
        industry='サービス業',
        sec_code='96100',
        corporate_number='5010401089759',
    ),
    'E04918': EdinetCodeEntry(
        edinet_code='E04918',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=589,
        fiscal_year_end='6月30日',
        submitter_name='株式会社福山コンサルタント',
        submitter_name_en='fukuyama consultants co.,ltd',
        submitter_name_yomi='カブシキガイシャ\u3000フクヤマコンサルタント',
        address='福岡市博多区博多駅東三丁目６番１８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5290001016276',
    ),
    'E04919': EdinetCodeEntry(
        edinet_code='E04919',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3203,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイネット',
        submitter_name_en='I-NET CORP.',
        submitter_name_yomi='カブシキガイシャアイネット',
        address='横浜市西区みなとみらい五丁目１番２号',
        industry='情報・通信業',
        sec_code='96000',
        corporate_number='7020001030145',
    ),
    'E04920': EdinetCodeEntry(
        edinet_code='E04920',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=733,
        fiscal_year_end='3月31日',
        submitter_name='旭情報サービス株式会社',
        submitter_name_en='ASAHI INTELLIGENCE SERVICE CO.,LTD.',
        submitter_name_yomi='アサヒジョウホウサービスカブシキガイシャ',
        address='千代田区丸の内１丁目７番１２号',
        industry='情報・通信業',
        sec_code='97990',
        corporate_number='7010001035087',
    ),
    'E04924': EdinetCodeEntry(
        edinet_code='E04924',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1399,
        fiscal_year_end='6月30日',
        submitter_name='大日本コンサルタント株式会社',
        submitter_name_en='NIPPON ENGINEERING CONSULTANTS CO.,LTD.',
        submitter_name_yomi='ダイニッポンコンサルタントカブシキガイシャ',
        address='千代田区神田練塀町３００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8013301006938',
    ),
    'E04925': EdinetCodeEntry(
        edinet_code='E04925',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1778,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ステップ',
        submitter_name_en='STEP CO.,LTD.',
        submitter_name_yomi='カブシキガイシャステップ',
        address='藤沢市藤沢６０２番地',
        industry='サービス業',
        sec_code='97950',
        corporate_number='7021001001169',
    ),
    'E04926': EdinetCodeEntry(
        edinet_code='E04926',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11352,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダスキン',
        submitter_name_en='DUSKIN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダスキン',
        address='吹田市豊津町１番３３号',
        industry='サービス業',
        sec_code='46650',
        corporate_number='3120901007178',
    ),
    'E04930': EdinetCodeEntry(
        edinet_code='E04930',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニチイ学館',
        submitter_name_en='NICHII GAKKAN COMPANY',
        submitter_name_yomi='カブシキガイシャニチイガッカン',
        address='千代田区神田駿河台４丁目６番地御茶ノ水ソラシティ',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001025868',
    ),
    'E04931': EdinetCodeEntry(
        edinet_code='E04931',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6382,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ダイセキ',
        submitter_name_en='Daiseki Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャダイセキ',
        address='名古屋市港区船見町１－８６',
        industry='サービス業',
        sec_code='97930',
        corporate_number='6180001006700',
    ),
    'E04932': EdinetCodeEntry(
        edinet_code='E04932',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1808,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビケンテクノ',
        submitter_name_en='BIKEN TECHNO CORPORATION',
        submitter_name_yomi='カブシキガイシャビケンテクノ',
        address='吹田市南金田２丁目１２番１号',
        industry='サービス業',
        sec_code='97910',
        corporate_number='5120901008067',
    ),
    'E04933': EdinetCodeEntry(
        edinet_code='E04933',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1631,
        fiscal_year_end='3月31日',
        submitter_name='福井コンピュータホールディングス株式会社',
        submitter_name_en='Fukui Computer Holdings,Inc.',
        submitter_name_yomi='フクイコンピュータホールディングスカブシキガイシャ',
        address='福井市高木中央１丁目２５０１番地',
        industry='情報・通信業',
        sec_code='97900',
        corporate_number='8210001002891',
    ),
    'E04934': EdinetCodeEntry(
        edinet_code='E04934',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナック',
        submitter_name_en='NAC CO .,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000ナック',
        address='新宿区西新宿１丁目２５番１号',
        industry='サービス業',
        sec_code='97880',
        corporate_number='9011101015480',
    ),
    'E04939': EdinetCodeEntry(
        edinet_code='E04939',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13780,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベネッセホールディングス',
        submitter_name_en='Benesse Holdings, Inc',
        submitter_name_yomi='カブシキガイシャベネッセホールディングス',
        address='岡山市北区南方三丁目７番１７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6260001006015',
    ),
    'E04940': EdinetCodeEntry(
        edinet_code='E04940',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1092,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディーエムエス',
        submitter_name_en='DMS INC.',
        submitter_name_yomi='カブシキガイシャディーエムエス',
        address='千代田区神田小川町一丁目１１番地',
        industry='サービス業',
        sec_code='97820',
        corporate_number='5010001023358',
    ),
    'E04941': EdinetCodeEntry(
        edinet_code='E04941',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=990,
        fiscal_year_end='2月末日',
        submitter_name='株式会社昴',
        submitter_name_en='SUBARU CO., LTD.',
        submitter_name_yomi='カブシキガイシャスバル',
        address='鹿児島市加治屋町９番１号',
        industry='サービス業',
        sec_code='97780',
        corporate_number='7340001002293',
    ),
    'E04944': EdinetCodeEntry(
        edinet_code='E04944',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=654,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハリマビステム',
        submitter_name_en='HARIMA B.STEM CORPORATION',
        submitter_name_yomi='カブシキカイシャ\u3000ハリマビステム',
        address='横浜市西区みなとみらい２－２－１',
        industry='サービス業',
        sec_code='97800',
        corporate_number='6020001024214',
    ),
    'E04946': EdinetCodeEntry(
        edinet_code='E04946',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7896,
        fiscal_year_end='3月31日',
        submitter_name='リコーリース株式会社',
        submitter_name_en='RICOH LEASING COMPANY,LTD.',
        submitter_name_yomi='リコーリースカブシキガイシャ',
        address='港区東新橋一丁目５番２号',
        industry='その他金融業',
        sec_code='85660',
        corporate_number='7010601037788',
    ),
    'E04948': EdinetCodeEntry(
        edinet_code='E04948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54259,
        fiscal_year_end='3月31日',
        submitter_name='株式会社光通信',
        submitter_name_en='HIKARI TSUSHIN,INC.',
        submitter_name_yomi='カブシキガイシャヒカリツウシン',
        address='豊島区西池袋一丁目４番１０号',
        industry='情報・通信業',
        sec_code='94350',
        corporate_number='9013301019047',
    ),
    'E04950': EdinetCodeEntry(
        edinet_code='E04950',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=983,
        fiscal_year_end='3月31日',
        submitter_name='札幌臨床検査センター株式会社',
        submitter_name_en='SAPPORO CLINICAL LABORATORY INC.',
        submitter_name_yomi='サッポロリンショウケンサセンターカブシキガイシャ',
        address='札幌市中央区北３条西１８丁目２番地２',
        industry='サービス業',
        sec_code='97760',
        corporate_number='7430001020476',
    ),
    'E04952': EdinetCodeEntry(
        edinet_code='E04952',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5500,
        fiscal_year_end='3月31日',
        submitter_name='ＮＳＷ株式会社',
        submitter_name_en='NSW Inc.',
        submitter_name_yomi='エヌエスダブリュカブシキガイシャ',
        address='渋谷区桜丘町３１番１１号',
        industry='情報・通信業',
        sec_code='97390',
        corporate_number='1011001017717',
    ),
    'E04953': EdinetCodeEntry(
        edinet_code='E04953',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=501,
        fiscal_year_end='3月31日',
        submitter_name='アンドール株式会社',
        submitter_name_en='ANDOR Co.,Ltd.',
        submitter_name_yomi='アンドールカブシキガイシャ',
        address='世田谷区池尻３丁目１番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6010001088689',
    ),
    'E04954': EdinetCodeEntry(
        edinet_code='E04954',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2347,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アルプス技研',
        submitter_name_en='Altech Corporation',
        submitter_name_yomi='カブシキガイシャアルプスギケン',
        address='横浜市西区みなとみらい二丁目３番５号',
        industry='サービス業',
        sec_code='46410',
        corporate_number='5020001090389',
    ),
    'E04955': EdinetCodeEntry(
        edinet_code='E04955',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1093,
        fiscal_year_end='12月31日',
        submitter_name='オリジナル設計株式会社',
        submitter_name_en='ORIGINAL ENGINEERING CONSULTANTS CO.,LTD',
        submitter_name_yomi='オリジナルセッケイカブシキガイシャ',
        address='渋谷区元代々木町３０番１３号',
        industry='サービス業',
        sec_code='46420',
        corporate_number='8011001065098',
    ),
    'E04958': EdinetCodeEntry(
        edinet_code='E04958',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1475,
        fiscal_year_end='2月末日',
        submitter_name='株式会社市進ホールディングス',
        submitter_name_en='ICHISHIN HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャイチシンホールディングス',
        address='市川市八幡２丁目３番１１号',
        industry='サービス業',
        sec_code='46450',
        corporate_number='2040001025619',
    ),
    'E04959': EdinetCodeEntry(
        edinet_code='E04959',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2669,
        fiscal_year_end='3月31日',
        submitter_name='イマジニア株式会社',
        submitter_name_en='Imagineer Co.,Ltd.',
        submitter_name_yomi='イマジニアカブシキガイシャ',
        address='新宿区西新宿二丁目７番１号',
        industry='情報・通信業',
        sec_code='46440',
        corporate_number='4011101002161',
    ),
    'E04960': EdinetCodeEntry(
        edinet_code='E04960',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プラザホールディングス',
        submitter_name_en='PLAZA HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャプラザホールディングス',
        address='中央区晴海一丁目８番１０号',
        industry='サービス業',
        sec_code='75020',
        corporate_number='5010001028349',
    ),
    'E04962': EdinetCodeEntry(
        edinet_code='E04962',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=822,
        fiscal_year_end=None,
        submitter_name='大成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイセイカブシキガイシャ',
        address='名古屋市中区栄三丁目３１番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001030988',
    ),
    'E04963': EdinetCodeEntry(
        edinet_code='E04963',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=14374,
        fiscal_year_end='2月末日',
        submitter_name='ポケットカード株式会社',
        submitter_name_en='POCKET CARD CO., LTD.',
        submitter_name_yomi='ポケットカードカブシキガイシャ',
        address='港区芝公園一丁目１番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010401046222',
    ),
    'E04964': EdinetCodeEntry(
        edinet_code='E04964',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4205,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サニックスホールディングス',
        submitter_name_en='SANIXHOLDINGS INCORPORATED',
        submitter_name_yomi='カブシキガイシャサニックスホールディングス',
        address='福岡市博多区博多駅東２丁目１番２３号',
        industry='サービス業',
        sec_code='46510',
        corporate_number='6290001001327',
    ),
    'E04966': EdinetCodeEntry(
        edinet_code='E04966',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12279,
        fiscal_year_end='3月31日',
        submitter_name='ネットワンシステムズ株式会社',
        submitter_name_en='Net One Systems Co.,Ltd.',
        submitter_name_yomi='ネットワンシステムズカブシキガイシャ',
        address='千代田区丸の内二丁目７番２号ＪＰタワー',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010701007922',
    ),
    'E04967': EdinetCodeEntry(
        edinet_code='E04967',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1051,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイオーズ',
        submitter_name_en='DAIOHSCORPORATION',
        submitter_name_yomi='カブシキガイシャダイオーズ',
        address='港区浜松町二丁目４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010401016356',
    ),
    'E04971': EdinetCodeEntry(
        edinet_code='E04971',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000サン・ライフ',
        submitter_name_en='sunlife corporation',
        submitter_name_yomi='カブシキガイシャ\u3000サン\u3000ライフ',
        address='平塚市馬入本町１３－１１',
        industry='サービス業',
        sec_code=None,
        corporate_number='3021001036615',
    ),
    'E04972': EdinetCodeEntry(
        edinet_code='E04972',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=759,
        fiscal_year_end='6月30日',
        submitter_name='株式会社環境管理センター',
        submitter_name_en='ENVIRONMENTAL CONTROL CENTER CO.,LTD.',
        submitter_name_yomi='カブシキガイシャカンキョウカンリセンター',
        address='八王子市散田町３丁目７番２３号',
        industry='サービス業',
        sec_code='46570',
        corporate_number='7013401000164',
    ),
    'E04973': EdinetCodeEntry(
        edinet_code='E04973',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1139,
        fiscal_year_end='3月31日',
        submitter_name='日本空調サービス株式会社',
        submitter_name_en='Nippon Air Conditioning Services Co., Ltd.',
        submitter_name_yomi='ニホンクウチョウサービスカブシキガイシャ',
        address='名古屋市名東区照が丘２３９番２',
        industry='サービス業',
        sec_code='46580',
        corporate_number='6180001002699',
    ),
    'E04975': EdinetCodeEntry(
        edinet_code='E04975',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=475,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エイジス',
        submitter_name_en='AJIS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエイジス',
        address='千葉市花見川区幕張町四丁目５４４番４',
        industry='サービス業',
        sec_code='46590',
        corporate_number='3040001008325',
    ),
    'E04976': EdinetCodeEntry(
        edinet_code='E04976',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2905,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォーカスシステムズ',
        submitter_name_en='Focus Systems Corporation',
        submitter_name_yomi='カブシキガイシャフォーカスシステムズ',
        address='品川区東五反田二丁目７番８号',
        industry='情報・通信業',
        sec_code='46620',
        corporate_number='1010701008901',
    ),
    'E04978': EdinetCodeEntry(
        edinet_code='E04978',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=302,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アール・エス・シー',
        submitter_name_en='JAPAN RELIANCE SERVICE CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000アールエスシー',
        address='豊島区東池袋三丁目１番３号\u3000サンシャインシティ',
        industry='サービス業',
        sec_code='46640',
        corporate_number='8013301006491',
    ),
    'E04979': EdinetCodeEntry(
        edinet_code='E04979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32739,
        fiscal_year_end='10月31日',
        submitter_name='パーク二四株式会社（定款上の商号\u3000パーク２４株式会社）',
        submitter_name_en='PARK24 Co., Ltd.',
        submitter_name_yomi='パークニジュウヨンカブシキガイシャ',
        address='品川区西五反田２丁目２０番４号',
        industry='不動産業',
        sec_code='46660',
        corporate_number='6010001115658',
    ),
    'E04980': EdinetCodeEntry(
        edinet_code='E04980',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=520,
        fiscal_year_end='3月31日',
        submitter_name='アイサンテクノロジー株式会社',
        submitter_name_en='AISAN TECHNOLOGY CO.,LTD.',
        submitter_name_yomi='アイサンテクノロジーカブシキガイシャ',
        address='名古屋市中区錦三丁目７番１４号\u3000ＡＴビル',
        industry='情報・通信業',
        sec_code='46670',
        corporate_number='5180001049428',
    ),
    'E04981': EdinetCodeEntry(
        edinet_code='E04981',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=972,
        fiscal_year_end='8月31日',
        submitter_name='株式会社明光ネットワークジャパン',
        submitter_name_en='MEIKO NETWORK JAPAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャメイコウネットワークジャパン',
        address='新宿区西新宿７丁目２０番１号',
        industry='サービス業',
        sec_code='46680',
        corporate_number='5011101055381',
    ),
    'E04982': EdinetCodeEntry(
        edinet_code='E04982',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3371,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファルコホールディングス',
        submitter_name_en='FALCO HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャファルコホールディングス',
        address='京都市左京区聖護院蓮華蔵町４４番地３',
        industry='サービス業',
        sec_code='46710',
        corporate_number='1130001007154',
    ),
    'E04984': EdinetCodeEntry(
        edinet_code='E04984',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=720,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ニッパンレンタル',
        submitter_name_en='NIPPAN RENTAL Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニッパンレンタル',
        address='前橋市西片貝町四丁目５番地１５',
        industry='サービス業',
        sec_code=None,
        corporate_number='7070001002503',
    ),
    'E04987': EdinetCodeEntry(
        edinet_code='E04987',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=819,
        fiscal_year_end='11月30日',
        submitter_name='川崎地質株式会社',
        submitter_name_en='Kawasaki Geological Engineering Co., Ltd.',
        submitter_name_yomi='カワサキチシツカブシキガイシャ',
        address='港区三田二丁目１１番１５号',
        industry='サービス業',
        sec_code='46730',
        corporate_number='7010401037591',
    ),
    'E04988': EdinetCodeEntry(
        edinet_code='E04988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2514,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クレスコ',
        submitter_name_en='CRESCO LTD.',
        submitter_name_yomi='カブシキガイシャクレスコ',
        address='港区港南２丁目１５番１号',
        industry='情報・通信業',
        sec_code='46740',
        corporate_number='7010401008700',
    ),
    'E04990': EdinetCodeEntry(
        edinet_code='E04990',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=175,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000田\u3000谷',
        submitter_name_en='TAYA CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000タヤ',
        address='渋谷区千駄ヶ谷五丁目２３番１３号',
        industry='サービス業',
        sec_code='46790',
        corporate_number='7011001013925',
    ),
    'E04991': EdinetCodeEntry(
        edinet_code='E04991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2089,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000秀英予備校',
        submitter_name_en='SHUEI YOBIKO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000シュウエイヨビコウ',
        address='静岡市葵区鷹匠二丁目７番１号',
        industry='サービス業',
        sec_code='46780',
        corporate_number='3080001002092',
    ),
    'E04995': EdinetCodeEntry(
        edinet_code='E04995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=709,
        fiscal_year_end='3月31日',
        submitter_name='株式会社菱友システムズ',
        submitter_name_en='Ryoyu Systems Co., Ltd.',
        submitter_name_yomi='カブシキガイシャリョウユウシステムズ',
        address='港区芝浦一丁目２番３号',
        industry='情報・通信業',
        sec_code='46850',
        corporate_number='3010401031664',
    ),
    'E04996': EdinetCodeEntry(
        edinet_code='E04996',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10146,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジャストシステム',
        submitter_name_en='JUSTSYSTEMS CORPORATION',
        submitter_name_yomi='カブシキガイシャジャストシステム',
        address='徳島市川内町平石若松１０８番地４',
        industry='情報・通信業',
        sec_code='46860',
        corporate_number='7480001000861',
    ),
    'E04997': EdinetCodeEntry(
        edinet_code='E04997',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=970,
        fiscal_year_end='3月31日',
        submitter_name='ＴＤＣソフト株式会社',
        submitter_name_en='TDC SOFT Inc.',
        submitter_name_yomi='ティーディーシーソフトカブシキガイシャ',
        address='渋谷区代々木三丁目２２番７号',
        industry='情報・通信業',
        sec_code='46870',
        corporate_number='8011001014542',
    ),
    'E04999': EdinetCodeEntry(
        edinet_code='E04999',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18386,
        fiscal_year_end='12月31日',
        submitter_name='トレンドマイクロ株式会社',
        submitter_name_en='Trend Micro Incorporated',
        submitter_name_yomi='トレンドマイクロカブシキガイシャ',
        address='新宿区新宿四丁目１番６号\u3000ＪＲ新宿ミライナタワー',
        industry='情報・通信業',
        sec_code='47040',
        corporate_number='9011001030704',
    ),
    'E05000': EdinetCodeEntry(
        edinet_code='E05000',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=248144,
        fiscal_year_end='3月31日',
        submitter_name='ＬＩＮＥヤフー株式会社',
        submitter_name_en='LY Corporation',
        submitter_name_yomi='ラインヤフーカブシキカイシャ',
        address='千代田区紀尾井町１番３号',
        industry='情報・通信業',
        sec_code='46890',
        corporate_number='4010401039979',
    ),
    'E05001': EdinetCodeEntry(
        edinet_code='E05001',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=767,
        fiscal_year_end='3月31日',
        submitter_name='日本パレットプール株式会社',
        submitter_name_en='NIPPON PALLET POOL CO.,LTD.',
        submitter_name_yomi='ニッポンパレットプールカブシキカイシャ',
        address='大阪市北区芝田二丁目８番１１号',
        industry='サービス業',
        sec_code='46900',
        corporate_number='4120001072956',
    ),
    'E05003': EdinetCodeEntry(
        edinet_code='E05003',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5176,
        fiscal_year_end=None,
        submitter_name='ワタベウェディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワタベウェディングカブシキガイシャ',
        address='京都市上京区烏丸通出水上る桜鶴円町３６１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7130001019342',
    ),
    'E05004': EdinetCodeEntry(
        edinet_code='E05004',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=981,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マイスターエンジニアリング',
        submitter_name_en='MYSTAR ENGINEERING CORP.',
        submitter_name_yomi='カブシキガイシャマイスターエンジニアリング',
        address='東京都港区芝四丁目１番２３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1040001008285',
    ),
    'E05006': EdinetCodeEntry(
        edinet_code='E05006',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=334,
        fiscal_year_end='7月20日',
        submitter_name='ウチダエスコ株式会社',
        submitter_name_en='UCHIDA ESCO Co.,Ltd.',
        submitter_name_yomi='ウチダエスコカブシキガイシャ',
        address='江東区木場五丁目８番４０号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010601027461',
    ),
    'E05011': EdinetCodeEntry(
        edinet_code='E05011',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=212,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クリップコーポレーション',
        submitter_name_en='CLIP Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000クリップコーポレーション',
        address='名古屋市千種区内山三丁目１８番１０号',
        industry='サービス業',
        sec_code='47050',
        corporate_number='7180001005767',
    ),
    'E05014': EdinetCodeEntry(
        edinet_code='E05014',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=998,
        fiscal_year_end='3月31日',
        submitter_name='りらいあコミュニケーションズ株式会社',
        submitter_name_en='Relia,Inc.',
        submitter_name_yomi='リライアコミュニケーションズカブシキガイシャ',
        address='渋谷区代々木二丁目６番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9011001029944',
    ),
    'E05015': EdinetCodeEntry(
        edinet_code='E05015',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=479,
        fiscal_year_end='10月20日',
        submitter_name='株式会社キタック',
        submitter_name_en='KITAC CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000キタック',
        address='新潟市中央区新光町１０番地２',
        industry='サービス業',
        sec_code='47070',
        corporate_number='2110001001637',
    ),
    'E05017': EdinetCodeEntry(
        edinet_code='E05017',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=592,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＩＤホールディングス',
        submitter_name_en='ID Holdings Corporation',
        submitter_name_yomi='カブシキガイシャアイディーホールディングス',
        address='千代田区五番町１２番地１',
        industry='情報・通信業',
        sec_code='47090',
        corporate_number='7010001011096',
    ),
    'E05018': EdinetCodeEntry(
        edinet_code='E05018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1337,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルゴグラフィックス',
        submitter_name_en='ARGO GRAPHICS Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000アルゴグラフィックス',
        address='中央区日本橋箱崎町５番１４号',
        industry='情報・通信業',
        sec_code='75950',
        corporate_number='7010001062783',
    ),
    'E05020': EdinetCodeEntry(
        edinet_code='E05020',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=92,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＫｅｙＨｏｌｄｅｒ',
        submitter_name_en='KeyHolder,Inc.',
        submitter_name_yomi='カブシキガイシャキーホルダー',
        address='渋谷区広尾一丁目１番３９号',
        industry='サービス業',
        sec_code='47120',
        corporate_number='1010001110481',
    ),
    'E05024': EdinetCodeEntry(
        edinet_code='E05024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2890,
        fiscal_year_end='2月末日',
        submitter_name='株式会社\u3000リソー教育グループ',
        submitter_name_en='RISO KYOIKU GROUP CORPORATION.',
        submitter_name_yomi='カブシキガイシャ\u3000リソーキョウイクグループ',
        address='豊島区目白三丁目１番４０号',
        industry='サービス業',
        sec_code='47140',
        corporate_number='2013301009186',
    ),
    'E05025': EdinetCodeEntry(
        edinet_code='E05025',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19178,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オービック',
        submitter_name_en='OBIC Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャオービック',
        address='中央区京橋二丁目４番１５号',
        industry='情報・通信業',
        sec_code='46840',
        corporate_number='8010001039574',
    ),
    'E05027': EdinetCodeEntry(
        edinet_code='E05027',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=24935,
        fiscal_year_end='5月31日',
        submitter_name='日本オラクル株式会社',
        submitter_name_en='ORACLE CORPORATION JAPAN',
        submitter_name_yomi='ニホンオラクルカブシキガイシャ',
        address='港区北青山２丁目５番８号',
        industry='情報・通信業',
        sec_code='47160',
        corporate_number='4010401078085',
    ),
    'E05028': EdinetCodeEntry(
        edinet_code='E05028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2014,
        fiscal_year_end='3月31日',
        submitter_name='株式会社早稲田アカデミー',
        submitter_name_en='WASEDA ACADEMY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャワセダアカデミー',
        address='豊島区南池袋一丁目１６番１５号',
        industry='サービス業',
        sec_code='47180',
        corporate_number='7013301012607',
    ),
    'E05029': EdinetCodeEntry(
        edinet_code='E05029',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=8500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルファシステムズ',
        submitter_name_en='ALPHA SYSTEMS INC.',
        submitter_name_yomi='カブシキガイシャアルファシステムズ',
        address='川崎市中原区上小田中六丁目６番１号',
        industry='情報・通信業',
        sec_code='47190',
        corporate_number='7011001001789',
    ),
    'E05030': EdinetCodeEntry(
        edinet_code='E05030',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=655,
        fiscal_year_end='3月31日',
        submitter_name='株式会社城南進学研究社',
        submitter_name_en='JOHNAN ACADEMIC PREPARATORY INSTITUTE,INC.',
        submitter_name_yomi='カブシキガイシャジョウナンシンガクケンキュウシャ',
        address='川崎市川崎区駅前本町２２番地２',
        industry='サービス業',
        sec_code='47200',
        corporate_number='8020001073184',
    ),
    'E05031': EdinetCodeEntry(
        edinet_code='E05031',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16500,
        fiscal_year_end='3月31日',
        submitter_name='トヨタファイナンス株式会社',
        submitter_name_en='TOYOTA FINANCE CORPORATION',
        submitter_name_yomi='トヨタファイナンスカブシキガイシャ',
        address='名古屋市西区牛島町６番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010601027383',
    ),
    'E05033': EdinetCodeEntry(
        edinet_code='E05033',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4000,
        fiscal_year_end='12月31日',
        submitter_name='フューチャー株式会社',
        submitter_name_en='Future  Corporation',
        submitter_name_yomi='フューチャーカブシキガイシャ',
        address='品川区大崎一丁目２番２号',
        industry='情報・通信業',
        sec_code='47220',
        corporate_number='6010701018466',
    ),
    'E05036': EdinetCodeEntry(
        edinet_code='E05036',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3702,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＣＡＣ\u3000Ｈｏｌｄｉｎｇｓ',
        submitter_name_en='CAC Holdings Corporation',
        submitter_name_yomi='カブシキカイシャシーエーシーホールディングス',
        address='中央区日本橋箱崎町２４番１号',
        industry='情報・通信業',
        sec_code='47250',
        corporate_number='1010001019335',
    ),
    'E05037': EdinetCodeEntry(
        edinet_code='E05037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1119,
        fiscal_year_end=None,
        submitter_name='ＳＢテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーテクノロジーカブシキガイシャ',
        address='新宿区新宿６丁目２７番３０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101033773',
    ),
    'E05041': EdinetCodeEntry(
        edinet_code='E05041',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯインターネットグループ株式会社',
        submitter_name_en='GMO internet group, Inc.',
        submitter_name_yomi='ジーエムオーインターネットグループカブシキガイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='情報・通信業',
        sec_code='94490',
        corporate_number='6011001029526',
    ),
    'E05042': EdinetCodeEntry(
        edinet_code='E05042',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=967,
        fiscal_year_end='8月31日',
        submitter_name='株式会社トーセ',
        submitter_name_en='TOSE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトーセ',
        address='乙訓郡大山崎町字下植野小字二階下１３番地',
        industry='情報・通信業',
        sec_code='47280',
        corporate_number='2130001030304',
    ),
    'E05045': EdinetCodeEntry(
        edinet_code='E05045',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18881,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユー・エス・エス',
        submitter_name_en='USS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャユーエスエス',
        address='東海市新宝町５０７番地の２０',
        industry='サービス業',
        sec_code='47320',
        corporate_number='3180001094608',
    ),
    'E05047': EdinetCodeEntry(
        edinet_code='E05047',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2667,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リログループ',
        submitter_name_en='Relo Group, Inc.',
        submitter_name_yomi='カブシキガイシャリログループ',
        address='新宿区新宿４丁目３番２３号',
        industry='サービス業',
        sec_code='88760',
        corporate_number='9011101016891',
    ),
    'E05048': EdinetCodeEntry(
        edinet_code='E05048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10519,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オービックビジネスコンサルタント',
        submitter_name_en='OBIC BUSINESS CONSULTANTS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオービックビジネスコンサルタント',
        address='新宿区西新宿六丁目８番１号',
        industry='情報・通信業',
        sec_code='47330',
        corporate_number='6011101003926',
    ),
    'E05049': EdinetCodeEntry(
        edinet_code='E05049',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5511,
        fiscal_year_end='9月30日',
        submitter_name='株式会社エムティーアイ',
        submitter_name_en='MTI Ltd.',
        submitter_name_yomi='カブシキガイシャエムティーアイ',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code='94380',
        corporate_number='6011101023123',
    ),
    'E05052': EdinetCodeEntry(
        edinet_code='E05052',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1586,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビーイング',
        submitter_name_en='Being Co., Ltd.',
        submitter_name_yomi='カブシキガイシャビーイング',
        address='津市桜橋１丁目３１２番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8190001000873',
    ),
    'E05053': EdinetCodeEntry(
        edinet_code='E05053',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=327,
        fiscal_year_end='5月31日',
        submitter_name='株式会社京進',
        submitter_name_en='KYOSHIN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキョウシン',
        address='京都市下京区烏丸通五条下る大坂町３８２－１',
        industry='サービス業',
        sec_code='47350',
        corporate_number='1130001017021',
    ),
    'E05054': EdinetCodeEntry(
        edinet_code='E05054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1239,
        fiscal_year_end='3月31日',
        submitter_name='日本ラッド株式会社',
        submitter_name_en='Nippon RAD Inc.',
        submitter_name_yomi='ニッポンラッドカブシキガイシャ',
        address='港区虎ノ門二丁目２番５号',
        industry='情報・通信業',
        sec_code='47360',
        corporate_number='8010401094657',
    ),
    'E05055': EdinetCodeEntry(
        edinet_code='E05055',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エム・エイチ・グループ',
        submitter_name_en='M H GROUP LTD.',
        submitter_name_yomi='カブシキガイシャエムエイチグループ',
        address='渋谷区千駄ヶ谷１－１１－１ＭＨビル',
        industry='サービス業',
        sec_code='94390',
        corporate_number='1011001062515',
    ),
    'E05056': EdinetCodeEntry(
        edinet_code='E05056',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6045,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビー・エム・エル',
        submitter_name_en='BML, INC.',
        submitter_name_yomi='カブシキガイシャビーエムエル',
        address='渋谷区千駄ヶ谷五丁目２１番３号',
        industry='サービス業',
        sec_code='46940',
        corporate_number='7011001019237',
    ),
    'E05059': EdinetCodeEntry(
        edinet_code='E05059',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=21764,
        fiscal_year_end='3月31日',
        submitter_name='伊藤忠テクノソリューションズ株式会社',
        submitter_name_en='ITOCHU Techno-Solutions Corporation',
        submitter_name_yomi='イトウチュウテクノソリューションズカブシキガイシャ',
        address='港区虎ノ門四丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010001010788',
    ),
    'E05062': EdinetCodeEntry(
        edinet_code='E05062',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25655,
        fiscal_year_end='3月31日',
        submitter_name='株式会社野村総合研究所',
        submitter_name_en='Nomura Research Institute,Ltd.',
        submitter_name_yomi='カブシキガイシャノムラソウゴウケンキュウショ',
        address='千代田区大手町一丁目９番２号',
        industry='情報・通信業',
        sec_code='43070',
        corporate_number='4010001054032',
    ),
    'E05064': EdinetCodeEntry(
        edinet_code='E05064',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社きずな',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキズナ',
        address='中央区京橋一丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401029422',
    ),
    'E05065': EdinetCodeEntry(
        edinet_code='E05065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=186,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ニットー',
        submitter_name_en='NITTOH CORPORATION',
        submitter_name_yomi='カブシキガイシャニットー',
        address='名古屋市中川区広川町三丁目１番地８',
        industry='建設業',
        sec_code='17380',
        corporate_number='1180001013107',
    ),
    'E05066': EdinetCodeEntry(
        edinet_code='E05066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1370,
        fiscal_year_end='12月31日',
        submitter_name='株式会社東計電算',
        submitter_name_en='Toukei Computer Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトウケイデンサン',
        address='川崎市中原区市ノ坪１５０番地',
        industry='情報・通信業',
        sec_code='47460',
        corporate_number='4020001069830',
    ),
    'E05067': EdinetCodeEntry(
        edinet_code='E05067',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=642,
        fiscal_year_end='2月末日',
        submitter_name='株式会社東京個別指導学院',
        submitter_name_en='Tokyo Individualized Educational Institute,INC.',
        submitter_name_yomi='カブシキガイシャトウキョウコベツシドウガクイン',
        address='新宿区西新宿一丁目２６番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001061962',
    ),
    'E05069': EdinetCodeEntry(
        edinet_code='E05069',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1010,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000構造計画研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウゾウケイカクケンキュウジョ',
        address='中野区本町四丁目３８番１３号\u3000日本ホルスタイン会館内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011201001655',
    ),
    'E05070': EdinetCodeEntry(
        edinet_code='E05070',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='4月20日',
        submitter_name='株式会社ダイサン',
        submitter_name_en='DAISAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャダイサン',
        address='大阪市中央区南本町２丁目６番１２号',
        industry='サービス業',
        sec_code='47500',
        corporate_number='8120001083116',
    ),
    'E05072': EdinetCodeEntry(
        edinet_code='E05072',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7679,
        fiscal_year_end='9月30日',
        submitter_name='株式会社サイバーエージェント',
        submitter_name_en='CyberAgent,Inc.',
        submitter_name_yomi='カブシキガイシャサイバーエージェント',
        address='渋谷区宇田川町４０番１号',
        industry='サービス業',
        sec_code='47510',
        corporate_number='4011001034156',
    ),
    'E05073': EdinetCodeEntry(
        edinet_code='E05073',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=782,
        fiscal_year_end='9月30日',
        submitter_name='株式会社トスネット',
        submitter_name_en='TOSNETCORPORATION',
        submitter_name_yomi='カブシキガイシャトスネット',
        address='仙台市宮城野区宮城野一丁目１０番１号',
        industry='サービス業',
        sec_code='47540',
        corporate_number='3370001005710',
    ),
    'E05075': EdinetCodeEntry(
        edinet_code='E05075',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=630,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000昭和システムエンジニアリング',
        submitter_name_en='SHOWA SYSTEM ENGINEERING CORPORATION',
        submitter_name_yomi='カブシキガイシャショウワシステムエンジニアリング',
        address='中央区日本橋小伝馬町１番５号',
        industry='情報・通信業',
        sec_code='47520',
        corporate_number='3010001045552',
    ),
    'E05076': EdinetCodeEntry(
        edinet_code='E05076',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4113,
        fiscal_year_end=None,
        submitter_name='三井情報株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツイジョウホウカブシキカイシャ',
        address='港区愛宕２－５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401078785',
    ),
    'E05080': EdinetCodeEntry(
        edinet_code='E05080',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=205924,
        fiscal_year_end='12月31日',
        submitter_name='楽天グループ株式会社',
        submitter_name_en='Rakuten Group,Inc.',
        submitter_name_yomi='ラクテングループカブシキガイシャ',
        address='世田谷区玉川一丁目１４番１号',
        industry='サービス業',
        sec_code='47550',
        corporate_number='9010701020592',
    ),
    'E05081': EdinetCodeEntry(
        edinet_code='E05081',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='カルチュア・コンビニエンス・クラブ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カルチュアコンビニエンスクラブカブシキガイシャ',
        address='枚方市岡東町１２番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001077107',
    ),
    'E05083': EdinetCodeEntry(
        edinet_code='E05083',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=409,
        fiscal_year_end='8月31日',
        submitter_name='株式会社アルファ',
        submitter_name_en='ALPHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアルファ',
        address='岡山市桑野７０９番地６',
        industry='サービス業',
        sec_code='47600',
        corporate_number='6260001000380',
    ),
    'E05088': EdinetCodeEntry(
        edinet_code='E05088',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＳＭ\u3000ＥＮＴＥＲＴＡＩＮＭＥＮＴ\u3000ＪＡＰＡＮ',
        submitter_name_en='SM ENTERTAINMENT JAPAN Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエスエムエンタテインメントジャパン',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='47720',
        corporate_number='6010401036776',
    ),
    'E05090': EdinetCodeEntry(
        edinet_code='E05090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2054,
        fiscal_year_end='3月31日',
        submitter_name='株式会社さくらケーシーエス',
        submitter_name_en='SAKURA KCS Corporation',
        submitter_name_yomi='カブシキガイシャサクラケーシーエス',
        address='神戸市中央区播磨町２１番１',
        industry='情報・通信業',
        sec_code='47610',
        corporate_number='3140001007886',
    ),
    'E05091': EdinetCodeEntry(
        edinet_code='E05091',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=783,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エックスネット',
        submitter_name_en='XNET Corporation',
        submitter_name_yomi='カブシキガイシャエックスネット',
        address='新宿区荒木町１３番地４',
        industry='情報・通信業',
        sec_code='47620',
        corporate_number='1011101049890',
    ),
    'E05093': EdinetCodeEntry(
        edinet_code='E05093',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3513,
        fiscal_year_end='3月31日',
        submitter_name='総合メディカル株式会社',
        submitter_name_en='SOGO MEDICAL CO., LTD.',
        submitter_name_yomi='ソウゴウメディカルカブシキガイシャ',
        address='福岡市中央区天神二丁目１４番８号',
        industry='小売業',
        sec_code=None,
        corporate_number='7290001008379',
    ),
    'E05094': EdinetCodeEntry(
        edinet_code='E05094',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=414,
        fiscal_year_end='12月31日',
        submitter_name='Ｎｅｘｕｓ\u3000Ｂａｎｋ株式会社',
        submitter_name_en='Nexus Bank Co.,Ltd.',
        submitter_name_yomi='ネクサス\u3000バンク\u3000カブシキカイシャ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6120001031233',
    ),
    'E05096': EdinetCodeEntry(
        edinet_code='E05096',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1177,
        fiscal_year_end='2月末日',
        submitter_name='株式会社クリーク・アンド・リバー社',
        submitter_name_en='CREEK & RIVER Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクリークアンドリバーシャ',
        address='港区新橋四丁目１番１号',
        industry='サービス業',
        sec_code='47630',
        corporate_number='1010001101101',
    ),
    'E05097': EdinetCodeEntry(
        edinet_code='E05097',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3363,
        fiscal_year_end='3月31日',
        submitter_name='ＳＢＩグローバルアセットマネジメント株式会社',
        submitter_name_en='SBI Global Asset Management Co., Ltd.',
        submitter_name_yomi='エスビーアイグローバルアセットマネジメントカブシキガイシャ',
        address='港区六本木１丁目６番１号',
        industry='サービス業',
        sec_code='47650',
        corporate_number='9010401049949',
    ),
    'E05098': EdinetCodeEntry(
        edinet_code='E05098',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ピーエイ',
        submitter_name_en='PA Co., Ltd',
        submitter_name_yomi='カブシキガイシャ\u3000ピーエイ',
        address='双葉郡楢葉町大字北田字上ノ原２７－９５',
        industry='サービス業',
        sec_code='47660',
        corporate_number='4010001133026',
    ),
    'E05099': EdinetCodeEntry(
        edinet_code='E05099',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10374,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000大塚商会',
        submitter_name_en='OTSUKA CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000オオツカショウカイ',
        address='千代田区飯田橋二丁目１８番４号',
        industry='情報・通信業',
        sec_code='47680',
        corporate_number='1010001012983',
    ),
    'E05100': EdinetCodeEntry(
        edinet_code='E05100',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=948,
        fiscal_year_end='6月30日',
        submitter_name='株式会社テー・オー・ダブリュー',
        submitter_name_en='TOW CO.,LTD.',
        submitter_name_yomi='カブシキガイシャテーオーダブリュー',
        address='港区虎ノ門四丁目３番１３号\u3000ヒューリック神谷町ビル',
        industry='サービス業',
        sec_code='47670',
        corporate_number='3010401029287',
    ),
    'E05101': EdinetCodeEntry(
        edinet_code='E05101',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=407,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＩＣ',
        submitter_name_en='IC CO., LTD.',
        submitter_name_yomi='カブシキガイシャアイシー',
        address='港区港南二丁目１５番３号',
        industry='情報・通信業',
        sec_code='47690',
        corporate_number='3010701001012',
    ),
    'E05106': EdinetCodeEntry(
        edinet_code='E05106',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='図研エルミック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ズケンエルミックカブシキカイシャ',
        address='横浜市港北区新横浜三丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001025644',
    ),
    'E05107': EdinetCodeEntry(
        edinet_code='E05107',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=989,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エフアンドエム',
        submitter_name_en='F&M CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエフアンドエム',
        address='吹田市江坂町１丁目２３番３８号',
        industry='サービス業',
        sec_code='47710',
        corporate_number='9120901005589',
    ),
    'E05110': EdinetCodeEntry(
        edinet_code='E05110',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=674,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＩＥＣ',
        submitter_name_en='JIEC Co.,Ltd',
        submitter_name_yomi='カブシキカイシャジェーアイイーシー',
        address='新宿区西新宿六丁目２４番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9011101029472',
    ),
    'E05112': EdinetCodeEntry(
        edinet_code='E05112',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2149,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベクターホールディングス',
        submitter_name_en='Vector HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャベクターホールディングス',
        address='港区芝公園三丁目４番３０号',
        industry='小売業',
        sec_code='26560',
        corporate_number='7011101035588',
    ),
    'E05113': EdinetCodeEntry(
        edinet_code='E05113',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50083,
        fiscal_year_end='3月31日',
        submitter_name='スカパーＪＳＡＴ株式会社',
        submitter_name_en='SKY Perfect JSAT Corporation',
        submitter_name_yomi='スカパージェイサットカブシキガイシャ',
        address='港区赤坂一丁目８番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010401072259',
    ),
    'E05114': EdinetCodeEntry(
        edinet_code='E05114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4491,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ガーラ',
        submitter_name_en='GALA INCORPORATED',
        submitter_name_yomi='カブシキガイシャガーラ',
        address='渋谷区渋谷２－２１－１',
        industry='情報・通信業',
        sec_code='47770',
        corporate_number='8011001026934',
    ),
    'E05115': EdinetCodeEntry(
        edinet_code='E05115',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='12月31日',
        submitter_name='ソフトブレーン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソフトブレーンカブシキガイシャ',
        address='中央区日本橋一丁目１３番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010001132006',
    ),
    'E05116': EdinetCodeEntry(
        edinet_code='E05116',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=613,
        fiscal_year_end='12月31日',
        submitter_name='サイボウズ株式会社',
        submitter_name_en='Cybozu, Inc.',
        submitter_name_yomi='サイボウズカブシキカイシャ',
        address='中央区日本橋２丁目７番１号',
        industry='情報・通信業',
        sec_code='47760',
        corporate_number='5010001072207',
    ),
    'E05120': EdinetCodeEntry(
        edinet_code='E05120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=438,
        fiscal_year_end='3月31日',
        submitter_name='ＮＣＤ株式会社',
        submitter_name_en='NCD Co., Ltd.',
        submitter_name_yomi='エヌシーディーカブシキガイシャ',
        address='品川区西五反田四丁目３２番１号',
        industry='情報・通信業',
        sec_code='47830',
        corporate_number='2010701007869',
    ),
    'E05121': EdinetCodeEntry(
        edinet_code='E05121',
        submitter_type='内国法人・組合',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2492,
        fiscal_year_end=None,
        submitter_name='日本ハウズイング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンハウズイングカブシキカイシャ',
        address='新宿区新宿一丁目３１番１２号',
        industry='不動産業',
        sec_code=None,
        corporate_number='1011101016668',
    ),
    'E05123': EdinetCodeEntry(
        edinet_code='E05123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯインターネット株式会社',
        submitter_name_en='GMO  Internet Inc.',
        submitter_name_yomi='ジーエムオーインターネットカブシキガイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='サービス業',
        sec_code='47840',
        corporate_number='1011001032872',
    ),
    'E05134': EdinetCodeEntry(
        edinet_code='E05134',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1970,
        fiscal_year_end='3月31日',
        submitter_name='株式会社富士通ビー・エス・シー',
        submitter_name_en='FUJITSU BROAD SOLUTION & CONSULTING Inc.',
        submitter_name_yomi='カブシキガイシャフジツウビーエスシー',
        address='港区台場二丁目３番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010401070589',
    ),
    'E05135': EdinetCodeEntry(
        edinet_code='E05135',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1599,
        fiscal_year_end='3月31日',
        submitter_name='山田コンサルティンググループ株式会社',
        submitter_name_en='YAMADA Consulting Group  CO.,LTD.',
        submitter_name_yomi='ヤマダコンサルティンググループカブシキガイシャ',
        address='千代田区丸の内１－８－１丸の内トラストタワーＮ館',
        industry='サービス業',
        sec_code='47920',
        corporate_number='8010001136859',
    ),
    'E05137': EdinetCodeEntry(
        edinet_code='E05137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=742,
        fiscal_year_end='4月30日',
        submitter_name='株式会社トーシンホールディングス',
        submitter_name_en='TOSHIN HOLDINGS CO.,LTD',
        submitter_name_yomi='カブシキガイシャ\u3000トーシンホールディングス',
        address='名古屋市中区栄３丁目４番２１号',
        industry='情報・通信業',
        sec_code='94440',
        corporate_number='3180001020233',
    ),
    'E05141': EdinetCodeEntry(
        edinet_code='E05141',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=249,
        fiscal_year_end='5月20日',
        submitter_name='株式会社エル・シー・エーホールディングス',
        submitter_name_en='LCA Holdings Corporation',
        submitter_name_yomi='カブシキガイシャエルシーエーホールディングス',
        address='東京都港区虎ノ門一丁目１７番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010001138085',
    ),
    'E05143': EdinetCodeEntry(
        edinet_code='E05143',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1092,
        fiscal_year_end='3月31日',
        submitter_name='オリコン株式会社',
        submitter_name_en='Oricon Inc.',
        submitter_name_yomi='オリコンカブシキガイシャ',
        address='港区六本木六丁目８番１０号',
        industry='情報・通信業',
        sec_code='48000',
        corporate_number='5010401038988',
    ),
    'E05145': EdinetCodeEntry(
        edinet_code='E05145',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2261,
        fiscal_year_end='3月31日',
        submitter_name='セントラルスポーツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セントラルスポーツカブシキカイシャ',
        address='中央区新川一丁目２１番２号',
        industry='サービス業',
        sec_code='48010',
        corporate_number='5010001048124',
    ),
    'E05147': EdinetCodeEntry(
        edinet_code='E05147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8180,
        fiscal_year_end='12月31日',
        submitter_name='株式会社電通総研',
        submitter_name_en='DENTSU SOKEN INC.',
        submitter_name_yomi='カブシキガイシャデンツウソウケン',
        address='港区港南二丁目１７番１号',
        industry='情報・通信業',
        sec_code='48120',
        corporate_number='7010401053829',
    ),
    'E05148': EdinetCodeEntry(
        edinet_code='E05148',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=881,
        fiscal_year_end='3月31日',
        submitter_name='株式会社豆蔵ホールディングス',
        submitter_name_en='MAMEZOU HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャマメゾウホールディングス',
        address='新宿区西新宿二丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6011101031233',
    ),
    'E05149': EdinetCodeEntry(
        edinet_code='E05149',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1728,
        fiscal_year_end='12月31日',
        submitter_name='バリューコマース株式会社',
        submitter_name_en='ValueCommerce Co., Ltd.',
        submitter_name_yomi='バリューコマースカブシキガイシャ',
        address='千代田区紀尾井町１番３号',
        industry='サービス業',
        sec_code='24910',
        corporate_number='1010401062075',
    ),
    'E05151': EdinetCodeEntry(
        edinet_code='E05151',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1310,
        fiscal_year_end='3月31日',
        submitter_name='ネクストウェア株式会社',
        submitter_name_en='Nextware Ltd.',
        submitter_name_yomi='ネクストウェアカブシキガイシャ',
        address='大阪市中央区北久宝寺町四丁目３番１１号',
        industry='情報・通信業',
        sec_code='48140',
        corporate_number='3120001086949',
    ),
    'E05153': EdinetCodeEntry(
        edinet_code='E05153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1017,
        fiscal_year_end='3月31日',
        submitter_name='株式会社メンバーズ',
        submitter_name_en='Members Co. ,Ltd.',
        submitter_name_yomi='カブシキガイシャメンバーズ',
        address='中央区晴海１－８－１０\u3000晴海アイランドトリトンスクエア\u3000オフィスタワーＸ３７階',
        industry='サービス業',
        sec_code='21300',
        corporate_number='7010701022764',
    ),
    'E05155': EdinetCodeEntry(
        edinet_code='E05155',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2785,
        fiscal_year_end='12月31日',
        submitter_name='株式会社イーエムシステムズ（商号\u3000株式会社ＥＭシステムズ）',
        submitter_name_en='EM SYSTEMS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイーエムシステムズ',
        address='大阪市淀川区宮原一丁目６番１号',
        industry='情報・通信業',
        sec_code='48200',
        corporate_number='8120001053779',
    ),
    'E05156': EdinetCodeEntry(
        edinet_code='E05156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7437,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デジタルガレージ',
        submitter_name_en='Digital Garage, Inc.',
        submitter_name_yomi='カブシキガイシャデジタルガレージ',
        address='渋谷区恵比寿南三丁目５番７号',
        industry='情報・通信業',
        sec_code='48190',
        corporate_number='5011001014966',
    ),
    'E05159': EdinetCodeEntry(
        edinet_code='E05159',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=237409,
        fiscal_year_end='3月31日',
        submitter_name='ＳＢＩホールディングス株式会社',
        submitter_name_en='SBI Holdings, Inc.',
        submitter_name_yomi='エスビーアイホールディングスカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='証券、商品先物取引業',
        sec_code='84730',
        corporate_number='6010401045208',
    ),
    'E05161': EdinetCodeEntry(
        edinet_code='E05161',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=814,
        fiscal_year_end='6月30日',
        submitter_name='株式会社メディアシーク',
        submitter_name_en='MEDIASEEK,inc.',
        submitter_name_yomi='カブシキガイシャメディアシーク',
        address='港区白金一丁目２７番６号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010401040249',
    ),
    'E05162': EdinetCodeEntry(
        edinet_code='E05162',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1706,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ウェザーニューズ',
        submitter_name_en='WEATHERNEWS INC.',
        submitter_name_yomi='カブシキガイシャウェザーニューズ',
        address='千葉市美浜区中瀬一丁目３番地\u3000幕張テクノガーデン',
        industry='情報・通信業',
        sec_code='48250',
        corporate_number='6010401003504',
    ),
    'E05163': EdinetCodeEntry(
        edinet_code='E05163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2270,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ＣＩＪ',
        submitter_name_en='Computer Institute of Japan,Ltd.',
        submitter_name_yomi='カブシキガイシャシーアイジェイ',
        address='横浜市西区高島一丁目２番５号',
        industry='情報・通信業',
        sec_code='48260',
        corporate_number='1020001015606',
    ),
    'E05167': EdinetCodeEntry(
        edinet_code='E05167',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=697,
        fiscal_year_end='3月31日',
        submitter_name='ビジネスエンジニアリング株式会社',
        submitter_name_en='Business Engineering Corporation',
        submitter_name_yomi='ビジネスエンジニアリングカブシキガイシャ',
        address='千代田区大手町１丁目８番１号',
        industry='情報・通信業',
        sec_code='48280',
        corporate_number='9010001101119',
    ),
    'E05168': EdinetCodeEntry(
        edinet_code='E05168',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17179,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＡＣＣＥＳＳ',
        submitter_name_en='ACCESS CO., LTD.',
        submitter_name_yomi='カブシキカイシャアクセス',
        address='千代田区神田練塀町３番地',
        industry='情報・通信業',
        sec_code='48130',
        corporate_number='5010001009662',
    ),
    'E05169': EdinetCodeEntry(
        edinet_code='E05169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=595,
        fiscal_year_end='5月31日',
        submitter_name='日本エンタープライズ株式会社',
        submitter_name_en='Nihon Enterprise Co.,Ltd.',
        submitter_name_yomi='ニホンエンタープライズカブシキガイシャ',
        address='渋谷区渋谷一丁目１７番８号',
        industry='情報・通信業',
        sec_code='48290',
        corporate_number='3011001033976',
    ),
    'E05173': EdinetCodeEntry(
        edinet_code='E05173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1390,
        fiscal_year_end='3月31日',
        submitter_name='ＪＦＥシステムズ株式会社',
        submitter_name_en='JFE Systems, Inc.',
        submitter_name_yomi='ジェイエフイーシステムズカブシキガイシャ',
        address='港区芝浦一丁目２番３号',
        industry='情報・通信業',
        sec_code='48320',
        corporate_number='4010601033105',
    ),
    'E05174': EdinetCodeEntry(
        edinet_code='E05174',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='ＥＬ\u3000ＣＡＭＩＮＯ\u3000ＲＥＡＬ株式会社',
        submitter_name_en='El Camino Real Co.,Ltd.',
        submitter_name_yomi='エルカミーノレアルカブシキガイシャ',
        address='千代田区丸の内一丁目８番１号丸の内トラストタワーＮ館',
        industry='不動産業',
        sec_code=None,
        corporate_number='4010001078337',
    ),
    'E05175': EdinetCodeEntry(
        edinet_code='E05175',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｄｅｆ\u3000ｃｏｎｓｕｌｔｉｎｇ',
        submitter_name_en='Def consulting, inc.',
        submitter_name_yomi='カブシキガイシャデフコンサルティング',
        address='港区虎ノ門１ー２３ー１\u3000虎ノ門ヒルズ森タワー２１階',
        industry='サービス業',
        sec_code='48330',
        corporate_number='2020001028342',
    ),
    'E05176': EdinetCodeEntry(
        edinet_code='E05176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=256,
        fiscal_year_end='5月31日',
        submitter_name='キャリアバンク株式会社',
        submitter_name_en='CAREER BANK CO.,LTD',
        submitter_name_yomi='キャリアバンクカブシキガイシャ',
        address='札幌市中央区北五条西五丁目７番地',
        industry='サービス業',
        sec_code='48340',
        corporate_number='7430001004883',
    ),
    'E05179': EdinetCodeEntry(
        edinet_code='E05179',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4242,
        fiscal_year_end='9月30日',
        submitter_name='株式会社レーサム',
        submitter_name_en='Raysum Co., Ltd.',
        submitter_name_yomi='カブシキガイシャレーサム',
        address='千代田区霞が関三丁目２番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='5010001114702',
    ),
    'E05181': EdinetCodeEntry(
        edinet_code='E05181',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=747,
        fiscal_year_end='9月30日',
        submitter_name='株式会社サカイホールディングス',
        submitter_name_en='SAKAI Holdings CO.,LTD',
        submitter_name_yomi='カブシキガイシャサカイホールディングス',
        address='名古屋市中区千代田５－２１－２０',
        industry='情報・通信業',
        sec_code='94460',
        corporate_number='4180001034595',
    ),
    'E05182': EdinetCodeEntry(
        edinet_code='E05182',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2780,
        fiscal_year_end='12月31日',
        submitter_name='株式会社フルキャストホールディングス',
        submitter_name_en='FULLCAST HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャ\u3000フルキャストホールディングス',
        address='品川区西五反田八丁目９番５号',
        industry='サービス業',
        sec_code='48480',
        corporate_number='7010701024604',
    ),
    'E05183': EdinetCodeEntry(
        edinet_code='E05183',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社トライアイズ',
        submitter_name_en='TriIs Incorporated',
        submitter_name_yomi='カブシキガイシャトライアイズ',
        address='千代田区紀尾井町４番１号',
        industry='サービス業',
        sec_code='48400',
        corporate_number='6010001124460',
    ),
    'E05187': EdinetCodeEntry(
        edinet_code='E05187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1795,
        fiscal_year_end='6月30日',
        submitter_name='株式会社スカラ',
        submitter_name_en='Scala, Inc.',
        submitter_name_yomi='カブシキガイシャスカラ',
        address='渋谷区渋谷二丁目２１番１号',
        industry='情報・通信業',
        sec_code='48450',
        corporate_number='4011001027663',
    ),
    'E05191': EdinetCodeEntry(
        edinet_code='E05191',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=843,
        fiscal_year_end='6月30日',
        submitter_name='株式会社インテリジェント\u3000ウェイブ',
        submitter_name_en='INTELLIGENT WAVE INC.',
        submitter_name_yomi='カブシキガイシャインテリジェント\u3000ウェイブ',
        address='中央区新川１－２１－２',
        industry='情報・通信業',
        sec_code='48470',
        corporate_number='4010001091991',
    ),
    'E05192': EdinetCodeEntry(
        edinet_code='E05192',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1194,
        fiscal_year_end='3月31日',
        submitter_name='エン株式会社',
        submitter_name_en='en inc.',
        submitter_name_yomi='エンカブシキガイシャ',
        address='新宿区西新宿六丁目５番１号',
        industry='サービス業',
        sec_code='48490',
        corporate_number='1011101029018',
    ),
    'E05195': EdinetCodeEntry(
        edinet_code='E05195',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4031,
        fiscal_year_end=None,
        submitter_name='デジタル・アドバタイジング・コンソーシアム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='デジタルアドバタイジングコンソーシアムカブシキカイシャ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001028193',
    ),
    'E05196': EdinetCodeEntry(
        edinet_code='E05196',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='ＥＰＳホールディングス株式会社',
        submitter_name_en='EPS Holdings,Inc.',
        submitter_name_yomi='イーピーエスホールディングスカブシキガイシャ',
        address='新宿区津久戸町１番８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001000549',
    ),
    'E05198': EdinetCodeEntry(
        edinet_code='E05198',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1494,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000ソルクシーズ',
        submitter_name_en='SOLXYZ Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ソルクシーズ',
        address='港区芝浦三丁目１番２１号',
        industry='情報・通信業',
        sec_code='42840',
        corporate_number='2010401068617',
    ),
    'E05199': EdinetCodeEntry(
        edinet_code='E05199',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＣＬホールディングス',
        submitter_name_en='CL Holdings Inc.',
        submitter_name_yomi='カブシキガイシャシーエルホールディングス',
        address='港区赤坂５丁目２番２０号\u3000赤坂パークビル１６階',
        industry='サービス業',
        sec_code='42860',
        corporate_number='1011001025439',
    ),
    'E05201': EdinetCodeEntry(
        edinet_code='E05201',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=770,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アズジェント',
        submitter_name_en='Asgent, Inc.',
        submitter_name_yomi='カブシキガイシャアズジェント',
        address='中央区明石町６番４号',
        industry='情報・通信業',
        sec_code='42880',
        corporate_number='7010001035673',
    ),
    'E05204': EdinetCodeEntry(
        edinet_code='E05204',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=410,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ジャストプランニング',
        submitter_name_en='JUSTPLANNING INC.',
        submitter_name_yomi='カブシキガイシャ\u3000ジャストプランニング',
        address='大田区西蒲田七丁目３５番１号宝栄ビル',
        industry='情報・通信業',
        sec_code='42870',
        corporate_number='7010801005818',
    ),
    'E05205': EdinetCodeEntry(
        edinet_code='E05205',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1601,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プレステージ・インターナショナル',
        submitter_name_en='Prestige International Inc.',
        submitter_name_yomi='カブシキカイシャ\u3000プレステージ\u3000インターナショナル',
        address='千代田区麹町２－４－１',
        industry='サービス業',
        sec_code='42900',
        corporate_number='1010001089262',
    ),
    'E05206': EdinetCodeEntry(
        edinet_code='E05206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18430,
        fiscal_year_end='12月31日',
        submitter_name='株式会社セプテーニ・ホールディングス',
        submitter_name_en='SEPTENI HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャセプテーニホールディングス',
        address='新宿区西新宿八丁目１７番１号',
        industry='サービス業',
        sec_code='42930',
        corporate_number='6011101024311',
    ),
    'E05209': EdinetCodeEntry(
        edinet_code='E05209',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3218,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フェイス',
        submitter_name_en='Faith,Inc.',
        submitter_name_yomi='カブシキガイシャフェイス',
        address='京都市中京区烏丸通御池下る虎屋町５６６－１井門明治安田生命ビル',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3130001022300',
    ),
    'E05210': EdinetCodeEntry(
        edinet_code='E05210',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1849,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プロトコーポレーション',
        submitter_name_en='PROTO CORPORATION',
        submitter_name_yomi='カブシキガイシャプロトコーポレーション',
        address='名古屋市中区葵一丁目２３番１４号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2180001040422',
    ),
    'E05211': EdinetCodeEntry(
        edinet_code='E05211',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2182,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｊストリーム',
        submitter_name_en='J-Stream Inc.',
        submitter_name_yomi='カブシキガイシャジェイストリーム',
        address='港区芝二丁目５番６号',
        industry='情報・通信業',
        sec_code='43080',
        corporate_number='4010401089388',
    ),
    'E05215': EdinetCodeEntry(
        edinet_code='E05215',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=689,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハイマックス',
        submitter_name_en='HIMACS,Ltd.',
        submitter_name_yomi='カブシキガイシャハイマックス',
        address='横浜市西区みなとみらい二丁目３番５号',
        industry='情報・通信業',
        sec_code='42990',
        corporate_number='6020001028371',
    ),
    'E05218': EdinetCodeEntry(
        edinet_code='E05218',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=900,
        fiscal_year_end=None,
        submitter_name='株式会社Ｅストアー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーストアー',
        address='港区赤坂九丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401058455',
    ),
    'E05219': EdinetCodeEntry(
        edinet_code='E05219',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1587,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アミューズ',
        submitter_name_en='AMUSE INC.',
        submitter_name_yomi='カブシキガイシャアミューズ',
        address='南都留郡富士河口湖町西湖９９７番地',
        industry='サービス業',
        sec_code='43010',
        corporate_number='5011001029386',
    ),
    'E05221': EdinetCodeEntry(
        edinet_code='E05221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5019,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ドリームインキュベータ',
        submitter_name_en='Dream Incubator Inc.',
        submitter_name_yomi='カブシキガイシャドリームインキュベータ',
        address='千代田区霞が関三丁目２番６号',
        industry='サービス業',
        sec_code='43100',
        corporate_number='6010001141902',
    ),
    'E05223': EdinetCodeEntry(
        edinet_code='E05223',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=995,
        fiscal_year_end='12月31日',
        submitter_name='サイバネットシステム株式会社',
        submitter_name_en='Cybernet Systems Co.,Ltd.',
        submitter_name_yomi='サイバネットシステムカブシキガイシャ',
        address='千代田区神田練塀町３番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010001002962',
    ),
    'E05227': EdinetCodeEntry(
        edinet_code='E05227',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000ＤＡホールディングス',
        submitter_name_en='K.K. DA Holdings',
        submitter_name_yomi='カブシキカイシャ\u3000ディーエーホールディングス',
        address='港区赤坂１－１２－３２',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401093160',
    ),
    'E05228': EdinetCodeEntry(
        edinet_code='E05228',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1854,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ビーマップ',
        submitter_name_en='BeMap,Inc.',
        submitter_name_yomi='カブシキガイシャビーマップ',
        address='千代田区内神田２－１２－５',
        industry='情報・通信業',
        sec_code='43160',
        corporate_number='2010001094575',
    ),
    'E05230': EdinetCodeEntry(
        edinet_code='E05230',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=471,
        fiscal_year_end='2月末日',
        submitter_name='株式会社レイ',
        submitter_name_en='Ray Corporation',
        submitter_name_yomi='カブシキガイシャレイ',
        address='港区六本木六丁目１５番２１号',
        industry='サービス業',
        sec_code='43170',
        corporate_number='6010401031785',
    ),
    'E05231': EdinetCodeEntry(
        edinet_code='E05231',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=940,
        fiscal_year_end='3月31日',
        submitter_name='ＴＡＣ株式会社',
        submitter_name_en='TAC CO.,LTD.',
        submitter_name_yomi='タックカブシキガイシャ',
        address='千代田区神田三崎町三丁目２番１８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001022246',
    ),
    'E05232': EdinetCodeEntry(
        edinet_code='E05232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=351,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クイック',
        submitter_name_en='QUICK CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクイック',
        address='大阪市北区小松原町２番４号',
        industry='サービス業',
        sec_code='43180',
        corporate_number='9120001063067',
    ),
    'E05233': EdinetCodeEntry(
        edinet_code='E05233',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1545,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＣＥホールディングス',
        submitter_name_en='CE Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシーイーホールディングス',
        address='札幌市白石区平和通十五丁目北１番２１号',
        industry='情報・通信業',
        sec_code='43200',
        corporate_number='8430001003331',
    ),
    'E05235': EdinetCodeEntry(
        edinet_code='E05235',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10020,
        fiscal_year_end='12月31日',
        submitter_name='ケネディクス株式会社',
        submitter_name_en='Kenedix, Inc.',
        submitter_name_yomi='ケネディクスカブシキカイシャ',
        address='千代田区内幸町二丁目１番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010401036044',
    ),
    'E05236': EdinetCodeEntry(
        edinet_code='E05236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1535,
        fiscal_year_end='3月31日',
        submitter_name='日本システム技術株式会社',
        submitter_name_en='Japan System Techniques Co.,Ltd.',
        submitter_name_yomi='ニホンシステムギジュツカブシキガイシャ',
        address='大阪市北区中之島二丁目３番１８号\u3000中之島フェスティバルタワー２９階',
        industry='情報・通信業',
        sec_code='43230',
        corporate_number='3120001072817',
    ),
    'E05238': EdinetCodeEntry(
        edinet_code='E05238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=517,
        fiscal_year_end='3月31日',
        submitter_name='株式会社センチュリー２１・ジャパン',
        submitter_name_en='CENTURY 21 REAL ESTATE OF JAPAN LTD.',
        submitter_name_yomi='カブシキガイシャセンチュリートウエンテイワンジャパン',
        address='港区北青山２－１２－１６北青山吉川ビル７Ｆ',
        industry='不動産業',
        sec_code='88980',
        corporate_number='4010401015815',
    ),
    'E05239': EdinetCodeEntry(
        edinet_code='E05239',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2378,
        fiscal_year_end='6月30日',
        submitter_name='株式会社インテージホールディングス',
        submitter_name_en='INTAGE HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャインテージホールディングス',
        address='千代田区神田練塀町３番地インテージ秋葉原ビル',
        industry='情報・通信業',
        sec_code='43260',
        corporate_number='7010001101459',
    ),
    'E05241': EdinetCodeEntry(
        edinet_code='E05241',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=150,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジェイホールディングス',
        submitter_name_en='J-Holdings Corp.',
        submitter_name_yomi='カブシキガイシャ\u3000ジェイホールディングス',
        address='港区麻布十番一丁目７番１１号',
        industry='卸売業',
        sec_code='27210',
        corporate_number='2010401083302',
    ),
    'E05242': EdinetCodeEntry(
        edinet_code='E05242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8575,
        fiscal_year_end='3月31日',
        submitter_name='スパークス・グループ株式会社',
        submitter_name_en='SPARX Group Co., Ltd.',
        submitter_name_yomi='スパークスグループカブシキガイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス',
        industry='証券、商品先物取引業',
        sec_code='87390',
        corporate_number='4010701012248',
    ),
    'E05243': EdinetCodeEntry(
        edinet_code='E05243',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=656,
        fiscal_year_end='9月30日',
        submitter_name='日本エス・エイチ・エル株式会社',
        submitter_name_en='SHL-JAPAN Ltd.',
        submitter_name_yomi='ニホンエスエイチエルカブシキガイシャ',
        address='中野区中央５丁目３８番１６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5011201004057',
    ),
    'E05248': EdinetCodeEntry(
        edinet_code='E05248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テイクアンドギヴ・ニーズ',
        submitter_name_en='TAKE AND GIVE. NEEDS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000テイクアンドギヴ\u3000ニーズ',
        address='品川区東品川\u3000二丁目３番１２号',
        industry='サービス業',
        sec_code='43310',
        corporate_number='9010701022696',
    ),
    'E05250': EdinetCodeEntry(
        edinet_code='E05250',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2583,
        fiscal_year_end='6月30日',
        submitter_name='株式会社セラーテムテクノロジー',
        submitter_name_en='Celartrem Technology Inc.',
        submitter_name_yomi='カブシキガイシャセラーテムテクノロジー',
        address='中央区日本橋本石町３－１－２',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001128058',
    ),
    'E05252': EdinetCodeEntry(
        edinet_code='E05252',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=526,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東邦システムサイエンス',
        submitter_name_en='TOHO SYSTEM SCIENCE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウホウシステムサイエンス',
        address='文京区小石川一丁目１２番１４号',
        industry='情報・通信業',
        sec_code='43330',
        corporate_number='5010001005331',
    ),
    'E05254': EdinetCodeEntry(
        edinet_code='E05254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=412,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ユークス',
        submitter_name_en="YUKE'S Co.,Ltd.",
        submitter_name_yomi='カブシキガイシャユークス',
        address='堺市堺区戎島町４丁４５番地の１',
        industry='情報・通信業',
        sec_code='43340',
        corporate_number='6120101007645',
    ),
    'E05255': EdinetCodeEntry(
        edinet_code='E05255',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=255,
        fiscal_year_end='6月末日',
        submitter_name='ＩＰＳホールディングス株式会社',
        submitter_name_en='IPS Holdings Co.,Ltd.',
        submitter_name_yomi='アイピーエスホールディングスカブシキガイシャ',
        address='大阪市北区大深町３番１号グランフロント大阪タワーＢ１６階',
        industry='情報・通信業',
        sec_code='43350',
        corporate_number='3140001005782',
    ),
    'E05256': EdinetCodeEntry(
        edinet_code='E05256',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=243,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クリエアナブキ',
        submitter_name_en='CRIE ANABUKI INC.',
        submitter_name_yomi='クリエアナブキ',
        address='高松市磨屋町２番地８',
        industry='サービス業',
        sec_code=None,
        corporate_number='3470001001336',
    ),
    'E05262': EdinetCodeEntry(
        edinet_code='E05262',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=523,
        fiscal_year_end='3月31日',
        submitter_name='西菱電機株式会社',
        submitter_name_en='SEIRYO ELECTRIC CORPORATION',
        submitter_name_yomi='セイリョウデンキカブシキガイシャ',
        address='伊丹市藤ノ木三丁目５番３３号',
        industry='サービス業',
        sec_code='43410',
        corporate_number='1140001078509',
    ),
    'E05263': EdinetCodeEntry(
        edinet_code='E05263',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3530,
        fiscal_year_end='3月31日',
        submitter_name='セコム上信越株式会社',
        submitter_name_en='SECOM JOSHINETSU CO.,LTD',
        submitter_name_yomi='セコムジョウシンエツカブシキガイシャ',
        address='新潟市中央区新光町１番地１０',
        industry='サービス業',
        sec_code=None,
        corporate_number='5110001002806',
    ),
    'E05264': EdinetCodeEntry(
        edinet_code='E05264',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1747,
        fiscal_year_end='2月末日',
        submitter_name='株式会社イオンファンタジー',
        submitter_name_en='AEON Fantasy Co.,LTD.',
        submitter_name_yomi='カブシキガイシャイオンファンタジー',
        address='千葉市美浜区中瀬一丁目５番地１',
        industry='サービス業',
        sec_code='43430',
        corporate_number='6040001000485',
    ),
    'E05265': EdinetCodeEntry(
        edinet_code='E05265',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='シダックス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シダックスカブシキガイシャ',
        address='調布市調布ケ丘３丁目６番地３',
        industry='サービス業',
        sec_code=None,
        corporate_number='3012401004575',
    ),
    'E05267': EdinetCodeEntry(
        edinet_code='E05267',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=425,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シーティーエス',
        submitter_name_en='CTS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシーティーエス',
        address='上田市古里１１５番地',
        industry='サービス業',
        sec_code='43450',
        corporate_number='7100001009957',
    ),
    'E05268': EdinetCodeEntry(
        edinet_code='E05268',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＮＥＸＹＺ．Ｇｒｏｕｐ',
        submitter_name_en='NEXYZ.Group Corporation',
        submitter_name_yomi='カブシキガイシャネクシーズグループ',
        address='渋谷区桜丘町２０番４号',
        industry='サービス業',
        sec_code='43460',
        corporate_number='1011001017948',
    ),
    'E05269': EdinetCodeEntry(
        edinet_code='E05269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2969,
        fiscal_year_end='3月31日',
        submitter_name='ブロードメディア株式会社',
        submitter_name_en='Broadmedia Corporation',
        submitter_name_yomi='ブロードメディアカブシキガイシャ',
        address='港区赤坂八丁目４番１４号',
        industry='サービス業',
        sec_code='43470',
        corporate_number='2010401054419',
    ),
    'E05272': EdinetCodeEntry(
        edinet_code='E05272',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='インフォコム株式会社',
        submitter_name_en='INFOCOM CORPORATION',
        submitter_name_yomi='インフォコムカブシキカイシャ',
        address='港区赤坂九丁目７番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3011001057199',
    ),
    'E05273': EdinetCodeEntry(
        edinet_code='E05273',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=302,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テスク',
        submitter_name_en='TISC CO.,LTD.',
        submitter_name_yomi='カブシキガイシャテスク',
        address='名古屋市中区栄一丁目１８番９号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2180001022313',
    ),
    'E05274': EdinetCodeEntry(
        edinet_code='E05274',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1091,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000メディカルシステムネットワーク',
        submitter_name_en='MEDICAL SYSTEM NETWORK Co., Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000メディカルシステムネットワーク',
        address='札幌市中央区北１０条西２４丁目３番地',
        industry='小売業',
        sec_code='43500',
        corporate_number='6430001025872',
    ),
    'E05275': EdinetCodeEntry(
        edinet_code='E05275',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1084,
        fiscal_year_end='12月31日',
        submitter_name='株式会社山田再生系債権回収総合事務所',
        submitter_name_en='YAMADA SERVICER SYNTHETIC OFFICE',
        submitter_name_yomi='カブシキガイシャヤマダサイセイケイサイケンカイシュウソウゴウジムショ',
        address='横浜市西区北幸一丁目１１番１５号\u3000横浜ＳＴビル１８階',
        industry='サービス業',
        sec_code='43510',
        corporate_number='8020001016168',
    ),
    'E05277': EdinetCodeEntry(
        edinet_code='E05277',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ロングライフホールディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ロングライフホールディング\u3000カブシキガイシャ',
        address='大阪市北区中崎西二丁目４番１２号梅田センタービル２５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001073043',
    ),
    'E05278': EdinetCodeEntry(
        edinet_code='E05278',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=555,
        fiscal_year_end='2月末日',
        submitter_name='株式会社きょくとう',
        submitter_name_en='Kyokuto Co., Ltd.',
        submitter_name_yomi='カブシキガイシャキョクトウ',
        address='福岡市博多区金の隈一丁目２８番５３号',
        industry='サービス業',
        sec_code='23000',
        corporate_number='7290001012793',
    ),
    'E05279': EdinetCodeEntry(
        edinet_code='E05279',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1850,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ティー・ワイ・オー',
        submitter_name_en='TYO  Inc.',
        submitter_name_yomi='カブシキガイシャティーワイオー',
        address='品川区上大崎２丁目２１番７号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010701006244',
    ),
    'E05280': EdinetCodeEntry(
        edinet_code='E05280',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3158,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アドバンスクリエイト',
        submitter_name_en='Advance Create Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアドバンスクリエイト',
        address='大阪市中央区瓦町三丁目５番７号',
        industry='保険業',
        sec_code='87980',
        corporate_number='9120001073842',
    ),
    'E05282': EdinetCodeEntry(
        edinet_code='E05282',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=600,
        fiscal_year_end='12月31日',
        submitter_name='応用技術株式会社',
        submitter_name_en='APPLIED TECHNOLOGY CO., LTD',
        submitter_name_yomi='オウヨウギジュツカブシキガイシャ',
        address='大阪市北区中崎西二丁目４番１２号梅田センタービル',
        industry='情報・通信業',
        sec_code='43560',
        corporate_number='9120001121031',
    ),
    'E05283': EdinetCodeEntry(
        edinet_code='E05283',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1513,
        fiscal_year_end='3月31日',
        submitter_name='株式会社システナ',
        submitter_name_en='Systena Corporation',
        submitter_name_yomi='カブシキガイシャシステナ',
        address='東京都港区海岸１丁目２番２０号',
        industry='情報・通信業',
        sec_code='23170',
        corporate_number='6010401088867',
    ),
    'E05286': EdinetCodeEntry(
        edinet_code='E05286',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1500,
        fiscal_year_end='10月31日',
        submitter_name='株式会社学情',
        submitter_name_en='GAKUJO CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャガクジョウ',
        address='中央区銀座六丁目１０番１号',
        industry='サービス業',
        sec_code='23010',
        corporate_number='3120001047728',
    ),
    'E05288': EdinetCodeEntry(
        edinet_code='E05288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=393,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＣＳＳホールディングス',
        submitter_name_en='CSS HOLDINGS,LTD.',
        submitter_name_yomi='カブシキガイシャシーエスエスホールディングス',
        address='中央区日本橋小伝馬町１０番１号',
        industry='サービス業',
        sec_code='23040',
        corporate_number='2010001072812',
    ),
    'E05289': EdinetCodeEntry(
        edinet_code='E05289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=363,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ドーン',
        submitter_name_en='Dawn Corporation',
        submitter_name_yomi='カブシキガイシャ\u3000ドーン',
        address='神戸市中央区磯上通二丁目２番２１号\u3000三宮グランドビル５Ｆ',
        industry='情報・通信業',
        sec_code='23030',
        corporate_number='9140001018622',
    ),
    'E05291': EdinetCodeEntry(
        edinet_code='E05291',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クロスキャット',
        submitter_name_en='CROSS CAT CO.,LTD.',
        submitter_name_yomi='カブシキガイシャクロスキャット',
        address='港区港南一丁目２番７０号',
        industry='情報・通信業',
        sec_code='23070',
        corporate_number='5010701002818',
    ),
    'E05292': EdinetCodeEntry(
        edinet_code='E05292',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3087,
        fiscal_year_end='9月30日',
        submitter_name='シミックホールディングス株式会社',
        submitter_name_en='CMIC HOLDINGS Co.,Ltd.',
        submitter_name_yomi='シミックホールディングスカブシキガイシャ',
        address='港区芝浦一丁目１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010701011418',
    ),
    'E05293': EdinetCodeEntry(
        edinet_code='E05293',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=87,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エプコ',
        submitter_name_en='EPCO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエプコ',
        address='墨田区太平４丁目１番３号オリナスタワー１２階',
        industry='サービス業',
        sec_code='23110',
        corporate_number='4011801000662',
    ),
    'E05297': EdinetCodeEntry(
        edinet_code='E05297',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=887,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソフトフロントホールディングス',
        submitter_name_en='Softfront Holdings',
        submitter_name_yomi='カブシキガイシャソフトフロントホールディングス',
        address='千代田区九段南一丁目４番５号',
        industry='情報・通信業',
        sec_code='23210',
        corporate_number='4430001024067',
    ),
    'E05299': EdinetCodeEntry(
        edinet_code='E05299',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=520,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＮＪＳ',
        submitter_name_en='NJS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシヤエヌジエーエス',
        address='港区芝浦一丁目１番１号',
        industry='サービス業',
        sec_code='23250',
        corporate_number='6011101045308',
    ),
    'E05301': EdinetCodeEntry(
        edinet_code='E05301',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35053,
        fiscal_year_end='12月31日',
        submitter_name='アンジェス株式会社',
        submitter_name_en='AnGes, Inc.',
        submitter_name_yomi='アンジェス\u3000カブシキガイシャ',
        address='茨木市彩都あさぎ七丁目７番１５号',
        industry='医薬品',
        sec_code='45630',
        corporate_number='6120901013446',
    ),
    'E05302': EdinetCodeEntry(
        edinet_code='E05302',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ｆｏｎｆｕｎ',
        submitter_name_en='fonfun corporation',
        submitter_name_yomi='カブシキカイシャ\u3000フォンファン',
        address='渋谷区笹塚二丁目１番６号',
        industry='情報・通信業',
        sec_code='23230',
        corporate_number='6011301016389',
    ),
    'E05303': EdinetCodeEntry(
        edinet_code='E05303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=713,
        fiscal_year_end='3月31日',
        submitter_name='デジタルアーツ株式会社',
        submitter_name_en='Digital Arts Inc.',
        submitter_name_yomi='デジタルアーツカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='情報・通信業',
        sec_code='23260',
        corporate_number='3010001096117',
    ),
    'E05304': EdinetCodeEntry(
        edinet_code='E05304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12952,
        fiscal_year_end='3月31日',
        submitter_name='日鉄ソリューションズ株式会社',
        submitter_name_en='NS Solutions Corporation',
        submitter_name_yomi='ニッテツソリューションズカブシキガイシャ',
        address='港区虎ノ門１丁目１７番１号',
        industry='情報・通信業',
        sec_code='23270',
        corporate_number='9010001045803',
    ),
    'E05306': EdinetCodeEntry(
        edinet_code='E05306',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1603,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＰホールディングス',
        submitter_name_en='JP-HOLDINGS,INC.',
        submitter_name_yomi='カブシキガイシャジェイピーホールディングス',
        address='港区港南一丁目２番７０号',
        industry='サービス業',
        sec_code='27490',
        corporate_number='2180001043359',
    ),
    'E05307': EdinetCodeEntry(
        edinet_code='E05307',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2487,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東北新社',
        submitter_name_en='TOHOKUSHINSHA FILM CORPORATION',
        submitter_name_yomi='カブシキガイシャトウホクシンシャ',
        address='港区赤坂四丁目８番１０号',
        industry='情報・通信業',
        sec_code='23290',
        corporate_number='3010401015790',
    ),
    'E05308': EdinetCodeEntry(
        edinet_code='E05308',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社フォーサイド',
        submitter_name_en='Forside Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフォーサイド',
        address='中央区日本橋室町３丁目３番１号',
        industry='情報・通信業',
        sec_code='23300',
        corporate_number='9290001059247',
    ),
    'E05309': EdinetCodeEntry(
        edinet_code='E05309',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18675,
        fiscal_year_end='3月31日',
        submitter_name='ＡＬＳＯＫ株式会社',
        submitter_name_en='ALSOK CO.,LTD.',
        submitter_name_yomi='アルソックカブシキガイシャ',
        address='港区元赤坂一丁目６番６号',
        industry='サービス業',
        sec_code='23310',
        corporate_number='3010401016070',
    ),
    'E05310': EdinetCodeEntry(
        edinet_code='E05310',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=491,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クエスト',
        submitter_name_en='Quest Co., Ltd.',
        submitter_name_yomi='カブシキガイシャクエスト',
        address='港区芝浦三丁目１番１号',
        industry='情報・通信業',
        sec_code='23320',
        corporate_number='8010401008344',
    ),
    'E05312': EdinetCodeEntry(
        edinet_code='E05312',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=768,
        fiscal_year_end='3月31日',
        submitter_name='株式会社キューブシステム',
        submitter_name_en='CUBE SYSTEM INC.',
        submitter_name_yomi='カブシキガイシャ\u3000キューブシステム',
        address='品川区大崎二丁目１１番１号',
        industry='情報・通信業',
        sec_code='23350',
        corporate_number='4010701002678',
    ),
    'E05313': EdinetCodeEntry(
        edinet_code='E05313',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=775,
        fiscal_year_end='5月31日',
        submitter_name='株式会社毎日コムネット',
        submitter_name_en='MAINICHI COMNET  CO., LTD.',
        submitter_name_yomi='カブシキガイシャマイニチコムネット',
        address='千代田区大手町２－１－１',
        industry='不動産業',
        sec_code='89080',
        corporate_number='4010001002115',
    ),
    'E05314': EdinetCodeEntry(
        edinet_code='E05314',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26575,
        fiscal_year_end='2月末日',
        submitter_name='いちご株式会社',
        submitter_name_en='Ichigo Inc.',
        submitter_name_yomi='イチゴカブシキガイシャ',
        address='千代田区丸の内二丁目６番１号',
        industry='サービス業',
        sec_code='23370',
        corporate_number='1010001068118',
    ),
    'E05315': EdinetCodeEntry(
        edinet_code='E05315',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2559,
        fiscal_year_end='2月末日',
        submitter_name='クオンタムソリューションズ株式会社',
        submitter_name_en='Quantum Solutions Co.,Ltd.',
        submitter_name_yomi='クオンタムソリューションズカブシキガイシャ',
        address='千代田区丸の内１－９－２',
        industry='情報・通信業',
        sec_code='23380',
        corporate_number='2011101046458',
    ),
    'E05316': EdinetCodeEntry(
        edinet_code='E05316',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=455,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アルバイトタイムス',
        submitter_name_en='ARBEIT-TIMES CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアルバイトタイムス',
        address='中央区京橋二丁目６番地１３',
        industry='サービス業',
        sec_code='23410',
        corporate_number='8010001084372',
    ),
    'E05317': EdinetCodeEntry(
        edinet_code='E05317',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トランスジェニックグループ',
        submitter_name_en='TRANS GENIC GROUP INC.',
        submitter_name_yomi='カブシキガイシャトランスジェニックグループ',
        address='福岡市中央区天神二丁目３番３６号',
        industry='サービス業',
        sec_code='23420',
        corporate_number='9330001006698',
    ),
    'E05319': EdinetCodeEntry(
        edinet_code='E05319',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=785,
        fiscal_year_end='3月31日',
        submitter_name='平安レイサービス株式会社',
        submitter_name_en='HEIAN CEREMONY SERVICE CO.,LTD.',
        submitter_name_yomi='ヘイアンレイサービスカブシキガイシャ',
        address='平塚市桜ヶ丘１－３５',
        industry='サービス業',
        sec_code='23440',
        corporate_number='4021001037562',
    ),
    'E05320': EdinetCodeEntry(
        edinet_code='E05320',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='10月31日',
        submitter_name='株式会社クシム',
        submitter_name_en='Kushim, Inc.',
        submitter_name_yomi='カブシキガイシャクシム',
        address='港区南青山二丁目１２番１号',
        industry='情報・通信業',
        sec_code='23450',
        corporate_number='9010001041967',
    ),
    'E05322': EdinetCodeEntry(
        edinet_code='E05322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=653,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エヌアイデイ',
        submitter_name_en='Nippon Information Development Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエヌアイデイ',
        address='香取市玉造三丁目１番５号',
        industry='情報・通信業',
        sec_code='23490',
        corporate_number='8040001063472',
    ),
    'E05324': EdinetCodeEntry(
        edinet_code='E05324',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1375,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＳＪ',
        submitter_name_en='ASJ INC.',
        submitter_name_yomi='カブシキガイシャエーエスジェイ',
        address='川口市栄町三丁目２番１６号',
        industry='情報・通信業',
        sec_code='23510',
        corporate_number='2030001073593',
    ),
    'E05325': EdinetCodeEntry(
        edinet_code='E05325',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=436,
        fiscal_year_end='3月31日',
        submitter_name='ビジネス・ワンホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビジネスワンホールディングスカブシキガイシャ',
        address='福岡市中央区薬院３丁目１６番２７号',
        industry='不動産業',
        sec_code='48270',
        corporate_number='7290001032412',
    ),
    'E05326': EdinetCodeEntry(
        edinet_code='E05326',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=835,
        fiscal_year_end='12月31日',
        submitter_name='シンクレイヤ株式会社',
        submitter_name_en='SYNCLAYER INC.',
        submitter_name_yomi='シンクレイヤカブシキガイシャ',
        address='名古屋市中区千代田二丁目２１番１８号',
        industry='建設業',
        sec_code='17240',
        corporate_number='3180001033524',
    ),
    'E05327': EdinetCodeEntry(
        edinet_code='E05327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=699,
        fiscal_year_end='7月31日',
        submitter_name='日本駐車場開発株式会社',
        submitter_name_en='NIPPON PARKING DEVELOPMENT Co.,Ltd.',
        submitter_name_yomi='ニホンチュウシャジョウカイハツカブシキガイシャ',
        address='大阪市北区小松原町２番４号\u3000大阪富国生命ビル',
        industry='不動産業',
        sec_code='23530',
        corporate_number='8120001093305',
    ),
    'E05328': EdinetCodeEntry(
        edinet_code='E05328',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=673,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＹＥ\u3000ＤＩＧＩＴＡＬ',
        submitter_name_en='YE DIGITAL Corporation',
        submitter_name_yomi='カブシキガイシャワイイーデジタル',
        address='北九州市小倉北区米町二丁目１番２１号',
        industry='情報・通信業',
        sec_code='23540',
        corporate_number='7290801010765',
    ),
    'E05331': EdinetCodeEntry(
        edinet_code='E05331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＣＡＩＣＡ\u3000ＤＩＧＩＴＡＬ',
        submitter_name_en='CAICA DIGITAL Inc.',
        submitter_name_yomi='カブシキガイシャカイカデジタル',
        address='港区南青山五丁目１１番９号',
        industry='情報・通信業',
        sec_code='23150',
        corporate_number='7010701017566',
    ),
    'E05332': EdinetCodeEntry(
        edinet_code='E05332',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=440,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コア',
        submitter_name_en='CORE CORPORATION',
        submitter_name_yomi='カブシキガイシャコア',
        address='世田谷区三軒茶屋一丁目２２番３号',
        industry='情報・通信業',
        sec_code='23590',
        corporate_number='4010901003823',
    ),
    'E05335': EdinetCodeEntry(
        edinet_code='E05335',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=822,
        fiscal_year_end='9月30日',
        submitter_name='株式会社夢真ホールディングス',
        submitter_name_en='YUMESHIN HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャユメシンホールディングス',
        address='千代田区丸の内一丁目４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010001097809',
    ),
    'E05336': EdinetCodeEntry(
        edinet_code='E05336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=277,
        fiscal_year_end='9月30日',
        submitter_name='ジョルダン株式会社',
        submitter_name_en='Jorudan Co.,Ltd.',
        submitter_name_yomi='ジョルダンカブシキガイシャ',
        address='新宿区新宿２－５－１０',
        industry='情報・通信業',
        sec_code='37100',
        corporate_number='2011101009695',
    ),
    'E05338': EdinetCodeEntry(
        edinet_code='E05338',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=414,
        fiscal_year_end='3月31日',
        submitter_name='株式会社創通',
        submitter_name_en='SOTSU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャソウツウ',
        address='中央区銀座五丁目９番５号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010001048535',
    ),
    'E05340': EdinetCodeEntry(
        edinet_code='E05340',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=326,
        fiscal_year_end='9月30日',
        submitter_name='株式会社情報企画',
        submitter_name_en='Information Planning Co.,LTD.',
        submitter_name_yomi='カブシキガイシャジョウホウキカク',
        address='大阪市中央区安土町二丁目３番１３号',
        industry='情報・通信業',
        sec_code='37120',
        corporate_number='9120001043911',
    ),
    'E05346': EdinetCodeEntry(
        edinet_code='E05346',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=81129,
        fiscal_year_end='3月31日',
        submitter_name='東京センチュリー株式会社',
        submitter_name_en='Tokyo Century Corporation',
        submitter_name_yomi='トウキョウセンチュリーカブシキガイシャ',
        address='千代田区神田練塀町３番地\u3000富士ソフトビル',
        industry='その他金融業',
        sec_code='84390',
        corporate_number='6010401015821',
    ),
    'E05348': EdinetCodeEntry(
        edinet_code='E05348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=95,
        fiscal_year_end='12月31日',
        submitter_name='ＡＩストーム株式会社',
        submitter_name_en='AI storm CO.,LTD.',
        submitter_name_yomi='エイアイストームカブシキガイシャ',
        address='千代田区神田錦町３－１７－１１\u3000榮葉ビル９Ｆ',
        industry='情報・通信業',
        sec_code='37190',
        corporate_number='9013201016466',
    ),
    'E05349': EdinetCodeEntry(
        edinet_code='E05349',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2926,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メディビックグループ',
        submitter_name_en='MediBIC Group',
        submitter_name_yomi='カブシキガイシャメディビックグループ',
        address='港区芝１丁目７番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8011001064868',
    ),
    'E05350': EdinetCodeEntry(
        edinet_code='E05350',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=915,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カカクコム',
        submitter_name_en='Kakaku.com,Inc.',
        submitter_name_yomi='カブシキカイシャカカクコム',
        address='渋谷区恵比寿南三丁目５番７号',
        industry='サービス業',
        sec_code='23710',
        corporate_number='9011001065997',
    ),
    'E05351': EdinetCodeEntry(
        edinet_code='E05351',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6486,
        fiscal_year_end='9月30日',
        submitter_name='株式会社メディネット',
        submitter_name_en='MEDINET Co., Ltd.',
        submitter_name_yomi='カブシキガイシャメディネット',
        address='品川区勝島一丁目５番２１号',
        industry='サービス業',
        sec_code='23700',
        corporate_number='1020001039274',
    ),
    'E05352': EdinetCodeEntry(
        edinet_code='E05352',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3517,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイロムグループ',
        submitter_name_en="I'rom Group Co.,Ltd.",
        submitter_name_yomi='カブシキガイシャアイロムグループ',
        address='千代田区富士見二丁目１０番２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010701014711',
    ),
    'E05353': EdinetCodeEntry(
        edinet_code='E05353',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ケア２１',
        submitter_name_en='CARE TWENTYONE CORPORATION',
        submitter_name_yomi='カブシキガイシャケアニジュウイチ',
        address='大阪市北区堂島二丁目２番２号',
        industry='サービス業',
        sec_code='23730',
        corporate_number='5120001101680',
    ),
    'E05354': EdinetCodeEntry(
        edinet_code='E05354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1773,
        fiscal_year_end='3月31日',
        submitter_name='セントケア・ホールディング株式会社',
        submitter_name_en='SAINT-CARE HOLDING CORPORATION',
        submitter_name_yomi='セントケアホールディングカブシキカイシャ',
        address='中央区京橋二丁目８番７号',
        industry='サービス業',
        sec_code='23740',
        corporate_number='5010001078518',
    ),
    'E05355': EdinetCodeEntry(
        edinet_code='E05355',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16770,
        fiscal_year_end='3月31日',
        submitter_name='ＮＴＴファイナンス株式会社',
        submitter_name_en='NTT FINANCE CORPORATION',
        submitter_name_yomi='エヌティティファイナンスカブシキガイシャ',
        address='港区港南一丁目２番７０号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010401005011',
    ),
    'E05356': EdinetCodeEntry(
        edinet_code='E05356',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1067,
        fiscal_year_end='10月31日',
        submitter_name='ギグワークス株式会社',
        submitter_name_en='GIG Works Inc.',
        submitter_name_yomi='ギグワークスカブシキカイシャ',
        address='港区西新橋二丁目１１番６号\u3000ニュー西新橋ビル３階',
        industry='サービス業',
        sec_code='23750',
        corporate_number='5011101030772',
    ),
    'E05357': EdinetCodeEntry(
        edinet_code='E05357',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='7月31日',
        submitter_name='ジャパンメディアシステム株式会社',
        submitter_name_en='Japan Media Systems Corporation',
        submitter_name_yomi='ジャパンメディアシステムカブシキカ゛イシャ',
        address='千代田区外神田二丁目１４番１０号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001019249',
    ),
    'E05360': EdinetCodeEntry(
        edinet_code='E05360',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=162,
        fiscal_year_end='9月30日',
        submitter_name='日本ファルコム株式会社',
        submitter_name_en='NIHON FALCOM CORPORATION',
        submitter_name_yomi='ニホンファルコムカブシキガイシャ',
        address='立川市曙町二丁目８番１８号',
        industry='情報・通信業',
        sec_code='37230',
        corporate_number='2012801004044',
    ),
    'E05361': EdinetCodeEntry(
        edinet_code='E05361',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3210,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ルネサンス',
        submitter_name_en='RENAISSANCE,INCORPORATED',
        submitter_name_yomi='カブシキガイシャルネサンス',
        address='墨田区両国二丁目１０－１４',
        industry='サービス業',
        sec_code='23780',
        corporate_number='3010601020797',
    ),
    'E05362': EdinetCodeEntry(
        edinet_code='E05362',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=792,
        fiscal_year_end=None,
        submitter_name='株式会社ベリサーブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベリサーブ',
        address='千代田区神田三崎町３－１－１６\u3000神保町北東急ビル９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101032123',
    ),
    'E05363': EdinetCodeEntry(
        edinet_code='E05363',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='オンコセラピー・サイエンス株式会社',
        submitter_name_en='OncoTherapy Science, Inc.',
        submitter_name_yomi='オンコセラピーサイエンスカブシキガイシャ',
        address='川崎市川崎区東田町１番地２',
        industry='医薬品',
        sec_code='45640',
        corporate_number='1020001077150',
    ),
    'E05367': EdinetCodeEntry(
        edinet_code='E05367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1836,
        fiscal_year_end='6月30日',
        submitter_name='株式会社総医研ホールディングス',
        submitter_name_en='Soiken Holdings Inc.',
        submitter_name_yomi='カブシキガイシャソウイケンホールディングス',
        address='豊中市新千里東町一丁目４番２号',
        industry='サービス業',
        sec_code='23850',
        corporate_number='4120901026508',
    ),
    'E05368': EdinetCodeEntry(
        edinet_code='E05368',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1085,
        fiscal_year_end='2月末日',
        submitter_name='ディップ株式会社',
        submitter_name_en='DIP corporation',
        submitter_name_yomi='ディップカブシキガイシャ',
        address='港区六本木三丁目２番１号',
        industry='サービス業',
        sec_code='23790',
        corporate_number='6010401050785',
    ),
    'E05369': EdinetCodeEntry(
        edinet_code='E05369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1861,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アプリックス',
        submitter_name_en='Aplix Corporation',
        submitter_name_yomi='カブシキガイシャアプリックス',
        address='新宿区西早稲田二丁目２０番９号',
        industry='情報・通信業',
        sec_code='37270',
        corporate_number='6011101001194',
    ),
    'E05372': EdinetCodeEntry(
        edinet_code='E05372',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=168,
        fiscal_year_end='6月30日',
        submitter_name='株式会社マクロミル',
        submitter_name_en='MACROMILL, INC.',
        submitter_name_yomi='カブシキガイシャマクロミル',
        address='港区港南２－１６－１品川イーストワンタワー１１Ｆ',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010001157227',
    ),
    'E05374': EdinetCodeEntry(
        edinet_code='E05374',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8212,
        fiscal_year_end='12月31日',
        submitter_name='株式会社デジタルホールディングス',
        submitter_name_en='DIGITAL HOLDINGS,INC.',
        submitter_name_yomi='カブシキガイシャデジタルホールディングス',
        address='千代田区四番町６番',
        industry='サービス業',
        sec_code='23890',
        corporate_number='4010001102162',
    ),
    'E05376': EdinetCodeEntry(
        edinet_code='E05376',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=847,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ソフトウェア・サービス',
        submitter_name_en='Software Service, Inc.',
        submitter_name_yomi='カブシキガイシャソフトウェアサービス',
        address='大阪市淀川区西宮原二丁目６番１号',
        industry='情報・通信業',
        sec_code='37330',
        corporate_number='4120001103331',
    ),
    'E05377': EdinetCodeEntry(
        edinet_code='E05377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=534,
        fiscal_year_end='3月31日',
        submitter_name='明豊ファシリティワークス株式会社',
        submitter_name_en='Meiho Facility Works Ltd.',
        submitter_name_yomi='メイホウファシリティワークスカブシキガイシャ',
        address='千代田区平河町二丁目７番９号',
        industry='建設業',
        sec_code='17170',
        corporate_number='7010001072436',
    ),
    'E05378': EdinetCodeEntry(
        edinet_code='E05378',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=436,
        fiscal_year_end='7月31日',
        submitter_name='株式会社プラネット',
        submitter_name_en='PLANET,INC.',
        submitter_name_yomi='カブシキガイシャプラネット',
        address='港区浜松町一丁目３１番',
        industry='サービス業',
        sec_code='23910',
        corporate_number='5010401026654',
    ),
    'E05379': EdinetCodeEntry(
        edinet_code='E05379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1961,
        fiscal_year_end='5月31日',
        submitter_name='ファーマライズホールディングス株式会社',
        submitter_name_en='Pharmarise Holdings Corporation',
        submitter_name_yomi='ファーマライズホールディングスカブシキガイシャ',
        address='中野区中央一丁目３８番１号',
        industry='サービス業',
        sec_code='27960',
        corporate_number='5011201003645',
    ),
    'E05381': EdinetCodeEntry(
        edinet_code='E05381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2897,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本ケアサプライ',
        submitter_name_en='Nippon Care Supply Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニッポンケアサプライ',
        address='港区芝大門一丁目１番３０号',
        industry='サービス業',
        sec_code='23930',
        corporate_number='3010401035013',
    ),
    'E05383': EdinetCodeEntry(
        edinet_code='E05383',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インテア・ホールディングス',
        submitter_name_en='Intea Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャインテアホールディングス',
        address='新宿区市谷八幡町１４番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8011101033260',
    ),
    'E05385': EdinetCodeEntry(
        edinet_code='E05385',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5391,
        fiscal_year_end='3月31日',
        submitter_name='株式会社新日本科学',
        submitter_name_en='SHIN NIPPON BIOMEDICAL LABORATORIES, LTD.',
        submitter_name_yomi='カブシキガイシャシンニホンカガク',
        address='鹿児島市宮之浦町２４３８番地',
        industry='サービス業',
        sec_code='23950',
        corporate_number='9340001000031',
    ),
    'E05389': EdinetCodeEntry(
        edinet_code='E05389',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=927,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＤＮＡチップ研究所',
        submitter_name_en='DNA Chip Reserch Inc.',
        submitter_name_yomi='カブシキガイシャディエヌエイチップケンキュショ',
        address='川崎市中原区新丸子東３丁目１２００',
        industry='サービス業',
        sec_code=None,
        corporate_number='7020001035045',
    ),
    'E05390': EdinetCodeEntry(
        edinet_code='E05390',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社リサ・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシヤリサパートナーズ',
        address='港区港南二丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401061289',
    ),
    'E05391': EdinetCodeEntry(
        edinet_code='E05391',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=806,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ゴルフダイジェスト・オンライン',
        submitter_name_en='Golf Digest Online Inc.',
        submitter_name_yomi='カブシキガイシャゴルフダイジェストオンライン',
        address='品川区東五反田二丁目１０番２号\u3000東五反田スクエア８階',
        industry='小売業',
        sec_code=None,
        corporate_number='9010401040981',
    ),
    'E05392': EdinetCodeEntry(
        edinet_code='E05392',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3154,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ティーガイア',
        submitter_name_en='T-Gaia Corporation',
        submitter_name_yomi='カブシキガイシャティーガイア',
        address='渋谷区恵比寿四丁目１番１８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5011001061661',
    ),
    'E05393': EdinetCodeEntry(
        edinet_code='E05393',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3342,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツクイホールディングス',
        submitter_name_en='TSUKUI HOLDINGS CORPORATION',
        submitter_name_yomi='カブシキカイシャツクイホールディングス',
        address='横浜市港南区上大岡西一丁目６番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9020001004171',
    ),
    'E05395': EdinetCodeEntry(
        edinet_code='E05395',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1122,
        fiscal_year_end='9月30日',
        submitter_name='株式会社フォーシーズＨＤ',
        submitter_name_en='4Cs HD Co., Ltd.',
        submitter_name_yomi='カブシキガイシャフォーシーズホールディングス',
        address='福岡市中央区薬院一丁目１番１号\u3000薬院ビジネスガーデン８階',
        industry='小売業',
        sec_code='37260',
        corporate_number='7290001032701',
    ),
    'E05396': EdinetCodeEntry(
        edinet_code='E05396',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=629,
        fiscal_year_end='6月30日',
        submitter_name='株式会社フジコー',
        submitter_name_en='FUJIKOH COMPANY.,LIMITED',
        submitter_name_yomi='カブシキガイシャフジコー',
        address='台東区駒形二丁目７番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010501012084',
    ),
    'E05398': EdinetCodeEntry(
        edinet_code='E05398',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3925,
        fiscal_year_end='3月31日',
        submitter_name='ＳＯＭＰＯケアメッセージ株式会社',
        submitter_name_en='Sompo Care Message, Inc.',
        submitter_name_yomi='ソンポケアメッセージカブシキガイシャ',
        address='品川区東品川四丁目１２番８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1260001015656',
    ),
    'E05399': EdinetCodeEntry(
        edinet_code='E05399',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=528,
        fiscal_year_end='3月31日',
        submitter_name='アルファグループ株式会社',
        submitter_name_en='Alpha Group Inc.',
        submitter_name_yomi='アルファグループカブシキガイシャ',
        address='渋谷区東一丁目２６番２０号',
        industry='卸売業',
        sec_code=None,
        corporate_number='2011001029637',
    ),
    'E05400': EdinetCodeEntry(
        edinet_code='E05400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=477,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セック',
        submitter_name_en='Systems Engineering Consultants Co.,LTD.',
        submitter_name_yomi='カブシキガイシャセック',
        address='世田谷区用賀４丁目１０番１号',
        industry='情報・通信業',
        sec_code='37410',
        corporate_number='1010901026918',
    ),
    'E05401': EdinetCodeEntry(
        edinet_code='E05401',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1205,
        fiscal_year_end='3月31日',
        submitter_name='コムシード株式会社',
        submitter_name_en='CommSeed Corporation',
        submitter_name_yomi='コムシードカブシキガイシャ',
        address='千代田区神田駿河台三丁目２番地',
        industry='情報・通信業',
        sec_code='37390',
        corporate_number='5010001094481',
    ),
    'E05403': EdinetCodeEntry(
        edinet_code='E05403',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アマナ',
        submitter_name_en='amana inc.',
        submitter_name_yomi='カブシキガイシャアマナ',
        address='品川区東品川二丁目２番４３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010701000676',
    ),
    'E05405': EdinetCodeEntry(
        edinet_code='E05405',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1048,
        fiscal_year_end='3月31日',
        submitter_name='ＩＴｂｏｏｋ株式会社',
        submitter_name_en='ITbook Co.,LTD.',
        submitter_name_yomi='アイティブックカブシキガイシャ',
        address='港区虎ノ門三丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010001089484',
    ),
    'E05407': EdinetCodeEntry(
        edinet_code='E05407',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1263,
        fiscal_year_end='12月31日',
        submitter_name='株式会社青山財産ネットワークス',
        submitter_name_en='Aoyama Zaisan Networks Company,Limited',
        submitter_name_yomi='カブシキガイシャアオヤマザイサンネットワークス',
        address='港区赤坂八丁目４番１４号青山タワープレイス３階',
        industry='不動産業',
        sec_code='89290',
        corporate_number='4010401087540',
    ),
    'E05408': EdinetCodeEntry(
        edinet_code='E05408',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アルテサロンホールディングス',
        submitter_name_en='Arte Salon Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャアルテサロンホールディングス',
        address='横浜市中区翁町一丁目４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1020001033236',
    ),
    'E05409': EdinetCodeEntry(
        edinet_code='E05409',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='8月31日',
        submitter_name='株式会社鉄人化ホールディングス',
        submitter_name_en='TETSUJIN Holdings, Inc',
        submitter_name_yomi='カブシキガイシャテツジンカホールディングス',
        address='目黒区碑文谷五丁目１５番１号',
        industry='サービス業',
        sec_code='24040',
        corporate_number='5013201010877',
    ),
    'E05410': EdinetCodeEntry(
        edinet_code='E05410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10790,
        fiscal_year_end='3月31日',
        submitter_name='株式会社博報堂ＤＹホールディングス',
        submitter_name_en='HAKUHODO DY HOLDINGS INCORPORATED',
        submitter_name_yomi='カブシキガイシャハクホウドウディーワイホールディングス',
        address='港区赤坂五丁目３番１号',
        industry='サービス業',
        sec_code='24330',
        corporate_number='4010401051711',
    ),
    'E05411': EdinetCodeEntry(
        edinet_code='E05411',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=472,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ツカダ・グローバルホールディング',
        submitter_name_en='TSUKADA GLOBAL HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャツカダグローバルホールディング',
        address='渋谷区東三丁目１１番１０号',
        industry='サービス業',
        sec_code='24180',
        corporate_number='2011001035049',
    ),
    'E05413': EdinetCodeEntry(
        edinet_code='E05413',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1481,
        fiscal_year_end='12月31日',
        submitter_name='サイオス株式会社',
        submitter_name_en='SIOS Corporation',
        submitter_name_yomi='サイオスカブシキガイシャ',
        address='港区南麻布二丁目１２番３号',
        industry='情報・通信業',
        sec_code='37440',
        corporate_number='2010401067057',
    ),
    'E05414': EdinetCodeEntry(
        edinet_code='E05414',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1962,
        fiscal_year_end='9月30日',
        submitter_name='パラカ株式会社',
        submitter_name_en='Paraca Inc.',
        submitter_name_yomi='パラカカブシキガイシャ',
        address='港区愛宕二丁目５番１号',
        industry='不動産業',
        sec_code='48090',
        corporate_number='8010401043696',
    ),
    'E05416': EdinetCodeEntry(
        edinet_code='E05416',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1010,
        fiscal_year_end='12月20日',
        submitter_name='株式会社ＫＧ情報',
        submitter_name_en='KG Intelligence CO., LTD.',
        submitter_name_yomi='カブシキガイシャケージージョウホウ',
        address='高松市今里町二丁目１１番地１７',
        industry='サービス業',
        sec_code='24080',
        corporate_number='8470001001397',
    ),
    'E05417': EdinetCodeEntry(
        edinet_code='E05417',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ゲンダイエージェンシー株式会社',
        submitter_name_en='GENDAI AGENCY INC.',
        submitter_name_yomi='ゲンダイエージェンシーカブシキガイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code='24110',
        corporate_number='8010101001161',
    ),
    'E05419': EdinetCodeEntry(
        edinet_code='E05419',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=558,
        fiscal_year_end='9月30日',
        submitter_name='株式会社キャリアデザインセンター',
        submitter_name_en='CAREER DESIGN CENTER CO.,LTD.',
        submitter_name_yomi='カブシキガイシャキャリアデザインセンター',
        address='港区赤坂三丁目２１番２０号',
        industry='サービス業',
        sec_code='24100',
        corporate_number='8010401008039',
    ),
    'E05422': EdinetCodeEntry(
        edinet_code='E05422',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3953,
        fiscal_year_end='3月31日',
        submitter_name='日本調剤株式会社',
        submitter_name_en='NIHON CHOUZAI CO.,LTD.',
        submitter_name_yomi='ニホンチョウザイカブシキガイシャ',
        address='港区芝五丁目３３番１１号',
        industry='小売業',
        sec_code=None,
        corporate_number='9010001064753',
    ),
    'E05423': EdinetCodeEntry(
        edinet_code='E05423',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1527,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベネフィット・ワン',
        submitter_name_en='Benefit One Inc.',
        submitter_name_yomi='カブシキガイシャベネフィットワン',
        address='新宿区西新宿三丁目７番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8011001045281',
    ),
    'E05424': EdinetCodeEntry(
        edinet_code='E05424',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1478,
        fiscal_year_end='9月30日',
        submitter_name='株式会社インタートレード',
        submitter_name_en='INTERTRADE CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャインタートレード',
        address='中央区新川一丁目１７番２１号',
        industry='情報・通信業',
        sec_code='37470',
        corporate_number='3010001080186',
    ),
    'E05425': EdinetCodeEntry(
        edinet_code='E05425',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1280,
        fiscal_year_end='3月31日',
        submitter_name='エムスリー株式会社',
        submitter_name_en='M3, Inc.',
        submitter_name_yomi='エムスリーカブシキガイシャ',
        address='港区赤坂一丁目１１番４４号',
        industry='サービス業',
        sec_code='24130',
        corporate_number='1010401063016',
    ),
    'E05426': EdinetCodeEntry(
        edinet_code='E05426',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=46925,
        fiscal_year_end='3月31日',
        submitter_name='みずほリース株式会社',
        submitter_name_en='Mizuho Leasing Company, Limited',
        submitter_name_yomi='ミズホリースカブシキガイシャ',
        address='港区虎ノ門一丁目２番６号',
        industry='その他金融業',
        sec_code='84250',
        corporate_number='3010401094447',
    ),
    'E05428': EdinetCodeEntry(
        edinet_code='E05428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1299,
        fiscal_year_end='3月31日',
        submitter_name='ヒューマンホールディングス株式会社',
        submitter_name_en='Human Holdings Co., Ltd.',
        submitter_name_yomi='ヒューマンホールディングスカブシキガイシャ',
        address='新宿区西新宿七丁目５番２５号',
        industry='サービス業',
        sec_code='24150',
        corporate_number='2011101033968',
    ),
    'E05429': EdinetCodeEntry(
        edinet_code='E05429',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=237,
        fiscal_year_end=None,
        submitter_name='洛王セレモニー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ラクオウセレモニーカブシキガイシャ',
        address='京都市南区久世高田町３５番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130001009777',
    ),
    'E05430': EdinetCodeEntry(
        edinet_code='E05430',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4024,
        fiscal_year_end='3月31日',
        submitter_name='日本アジアグループ株式会社',
        submitter_name_en='Japan Asia Group Limited',
        submitter_name_yomi='ニホンアジアグループカブシキカイシャ',
        address='千代田区丸の内三丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5010001003351',
    ),
    'E05431': EdinetCodeEntry(
        edinet_code='E05431',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3235,
        fiscal_year_end='3月31日',
        submitter_name='エキサイト株式会社',
        submitter_name_en='Excite Japan Co., Ltd.',
        submitter_name_yomi='エキサイトカブシキガイシャ',
        address='港区南麻布３丁目２０－１',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010401089880',
    ),
    'E05432': EdinetCodeEntry(
        edinet_code='E05432',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1230,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フライトソリューションズ',
        submitter_name_en='FLIGHT SOLUTIONS Inc.',
        submitter_name_yomi='カブシキガイシャフライトソリューションズ',
        address='渋谷区恵比寿４－６－１',
        industry='情報・通信業',
        sec_code='37530',
        corporate_number='5011001032786',
    ),
    'E05433': EdinetCodeEntry(
        edinet_code='E05433',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=462,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＺＷＥＩ',
        submitter_name_en='ZWEI,Inc.',
        submitter_name_yomi='カブシキガイシャツヴァイ',
        address='中央区銀座五丁目９番８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010001050685',
    ),
    'E05434': EdinetCodeEntry(
        edinet_code='E05434',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ゴンゾ',
        submitter_name_en='GONZO K.K.',
        submitter_name_yomi='カブシキガイシャゴンゾ',
        address='杉並区成田東五丁目１７番１３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8011301017187',
    ),
    'E05437': EdinetCodeEntry(
        edinet_code='E05437',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＣＨＩＮＴＡＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチンタイ',
        address='港区元赤坂１丁目２－７',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401017689',
    ),
    'E05438': EdinetCodeEntry(
        edinet_code='E05438',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10532,
        fiscal_year_end='3月31日',
        submitter_name='芙蓉総合リース株式会社',
        submitter_name_en='Fuyo General Lease Co., Ltd.',
        submitter_name_yomi='フヨウソウゴウリースカブシキガイシャ',
        address='千代田区麹町五丁目１番地１',
        industry='その他金融業',
        sec_code='84240',
        corporate_number='3010001028689',
    ),
    'E05440': EdinetCodeEntry(
        edinet_code='E05440',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=205,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ケアサービス',
        submitter_name_en='Care Service Co., Ltd.',
        submitter_name_yomi='カブシキガイシャケアサービス',
        address='大田区大森北一丁目２番３号',
        industry='サービス業',
        sec_code='24250',
        corporate_number='8010801003671',
    ),
    'E05443': EdinetCodeEntry(
        edinet_code='E05443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡＤＲ１２０Ｓ',
        submitter_name_en='ADR120S, Inc.',
        submitter_name_yomi='カブシキガイシャエーティーアールヒャクニジュウエス',
        address='千代田区麹町２丁目３番３号',
        industry='情報・通信業',
        sec_code='37500',
        corporate_number='5011101038048',
    ),
    'E05444': EdinetCodeEntry(
        edinet_code='E05444',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2287,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ダイセキ環境ソリューション',
        submitter_name_en='Daiseki Eco. Solution Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ダイセキカンキョウソリューション',
        address='名古屋市瑞穂区明前町８番１８号',
        industry='建設業',
        sec_code=None,
        corporate_number='5180001044387',
    ),
    'E05445': EdinetCodeEntry(
        edinet_code='E05445',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2032,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノマセマティカル',
        submitter_name_en='Techno Mathematical Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャテクノマセマティカル',
        address='品川区西五反田二丁目１２番１９号',
        industry='情報・通信業',
        sec_code='37870',
        corporate_number='6010701012444',
    ),
    'E05446': EdinetCodeEntry(
        edinet_code='E05446',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1224,
        fiscal_year_end='3月31日',
        submitter_name='アクリーティブ株式会社',
        submitter_name_en='Accretive Co., Ltd.',
        submitter_name_yomi='アクリーティブカブシキガイシャ',
        address='中央区新川一丁目２８番４４号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='3040001033406',
    ),
    'E05447': EdinetCodeEntry(
        edinet_code='E05447',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=25293,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アウトソーシング',
        submitter_name_en='OUTSOURCING Inc.',
        submitter_name_yomi='カブシキガイシャアウトソーシング',
        address='千代田区丸の内１丁目８番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2080001012662',
    ),
    'E05449': EdinetCodeEntry(
        edinet_code='E05449',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=182,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ケイブ',
        submitter_name_en='CAVE CO.,LTD',
        submitter_name_yomi='カブシキガイシャケイブ',
        address='目黒区上目黒二丁目１番地１号',
        industry='情報・通信業',
        sec_code='37600',
        corporate_number='2011101006189',
    ),
    'E05450': EdinetCodeEntry(
        edinet_code='E05450',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=165,
        fiscal_year_end='5月31日',
        submitter_name='Ｓｈｉｎｗａ\u3000Ｗｉｓｅ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en='SHINWA WISE HOLDINGS CO.,LTD.',
        submitter_name_yomi='シンワワイズホールディングスカブシキガイシャ',
        address='千代田区丸の内二丁目３番２号',
        industry='サービス業',
        sec_code='24370',
        corporate_number='7010001047124',
    ),
    'E05452': EdinetCodeEntry(
        edinet_code='E05452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1484,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＤＳホールディングス',
        submitter_name_en='SDS HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャショウデンシャ',
        address='港区東新橋二丁目１１番７号',
        industry='建設業',
        sec_code='17110',
        corporate_number='2010401082989',
    ),
    'E05453': EdinetCodeEntry(
        edinet_code='E05453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=733,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アエリア',
        submitter_name_en='Aeria Inc.',
        submitter_name_yomi='カブシキガイシャアエリア',
        address='港区赤坂三丁目７－１３',
        industry='情報・通信業',
        sec_code='37580',
        corporate_number='6010401048805',
    ),
    'E05456': EdinetCodeEntry(
        edinet_code='E05456',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ぐるなび',
        submitter_name_en='Gurunavi, Inc.',
        submitter_name_yomi='カブシキガイシャグルナビ',
        address='千代田区有楽町一丁目１番２号',
        industry='サービス業',
        sec_code='24400',
        corporate_number='1010001034565',
    ),
    'E05457': EdinetCodeEntry(
        edinet_code='E05457',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14,
        fiscal_year_end='12月31日',
        submitter_name='株式会社フィスコ',
        submitter_name_en='FISCO Ltd.',
        submitter_name_yomi='カブシキガイシャフィスコ',
        address='堺市南区竹城台三丁２１番１号',
        industry='情報・通信業',
        sec_code='38070',
        corporate_number='5120101048252',
    ),
    'E05458': EdinetCodeEntry(
        edinet_code='E05458',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=667,
        fiscal_year_end='6月30日',
        submitter_name='ウェルネット株式会社',
        submitter_name_en='WELLNET CORPORATION',
        submitter_name_yomi='ウェルネットカブシキガイシャ',
        address='札幌市中央区大通東十丁目１１番地４',
        industry='サービス業',
        sec_code='24280',
        corporate_number='5010001125807',
    ),
    'E05460': EdinetCodeEntry(
        edinet_code='E05460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10397,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディー・エヌ・エー',
        submitter_name_en='DeNA Co., Ltd',
        submitter_name_yomi='カブシキガイシャディーエヌエー',
        address='渋谷区渋谷二丁目２４番１２号',
        industry='サービス業',
        sec_code='24320',
        corporate_number='4011001032721',
    ),
    'E05462': EdinetCodeEntry(
        edinet_code='E05462',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3794,
        fiscal_year_end='3月31日',
        submitter_name='ＮＥＣキャピタルソリューション株式会社',
        submitter_name_en='NEC Capital Solutions Limited',
        submitter_name_yomi='エヌイーシーキャピタルソリューションカブシキガイシャ',
        address='港区港南二丁目１５－３',
        industry='その他金融業',
        sec_code='87930',
        corporate_number='8010401021784',
    ),
    'E05463': EdinetCodeEntry(
        edinet_code='E05463',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1298,
        fiscal_year_end='3月31日',
        submitter_name='テクマトリックス株式会社',
        submitter_name_en='TECHMATRIX CORPORATION',
        submitter_name_yomi='テクマトリックスカブシキガイシャ',
        address='港区港南一丁目２番７０号',
        industry='情報・通信業',
        sec_code='37620',
        corporate_number='4010401058467',
    ),
    'E05466': EdinetCodeEntry(
        edinet_code='E05466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=770,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プロシップ',
        submitter_name_en='Pro-ship Incorporated',
        submitter_name_yomi='カブシキガイシャプロシップ',
        address='千代田区飯田橋三丁目８番５号',
        industry='情報・通信業',
        sec_code='37630',
        corporate_number='1010001073852',
    ),
    'E05467': EdinetCodeEntry(
        edinet_code='E05467',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1241,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ワールドホールディングス',
        submitter_name_en='WORLD HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキカイシャワールドホールディングス',
        address='北九州市小倉北区大手町１１番２号',
        industry='サービス業',
        sec_code='24290',
        corporate_number='4290801004051',
    ),
    'E05469': EdinetCodeEntry(
        edinet_code='E05469',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=333,
        fiscal_year_end='3月31日',
        submitter_name='システムズ・デザイン株式会社',
        submitter_name_en='SYSTEMS DESIGN Co.,Ltd.',
        submitter_name_yomi='システムズデザインカブシキガイシャ',
        address='新宿区西新宿二丁目１番１号',
        industry='情報・通信業',
        sec_code='37660',
        corporate_number='7011301012643',
    ),
    'E05470': EdinetCodeEntry(
        edinet_code='E05470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2292,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エフオン',
        submitter_name_en='EF-ON INC.',
        submitter_name_yomi='カブシキガイシャエフオン',
        address='千代田区丸の内一丁目９番２号',
        industry='電気・ガス業',
        sec_code='95140',
        corporate_number='9010001028064',
    ),
    'E05471': EdinetCodeEntry(
        edinet_code='E05471',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1188,
        fiscal_year_end='3月31日',
        submitter_name='リスクモンスター株式会社',
        submitter_name_en='RISKMONSTER.COM',
        submitter_name_yomi='リスクモンスターカブシキカイシャ',
        address='中央区日本橋二丁目１６番５号\u3000ＲＭＧビル',
        industry='情報・通信業',
        sec_code='37680',
        corporate_number='5010001075531',
    ),
    'E05474': EdinetCodeEntry(
        edinet_code='E05474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5338,
        fiscal_year_end='12月31日',
        submitter_name='ガンホー・オンライン・エンターテイメント株式会社',
        submitter_name_en='GungHo Online Entertainment, Inc.',
        submitter_name_yomi='ガンホーオンラインエンターテイメントカブシキガイシャ',
        address='千代田区丸の内一丁目１１番１号',
        industry='情報・通信業',
        sec_code='37650',
        corporate_number='8010001082839',
    ),
    'E05476': EdinetCodeEntry(
        edinet_code='E05476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13323,
        fiscal_year_end='9月30日',
        submitter_name='ＧＭＯペイメントゲートウェイ株式会社',
        submitter_name_en='GMO Payment Gateway, Inc.',
        submitter_name_yomi='ジーエムオーペイメントゲートウェイカブシキガイシャ',
        address='渋谷区道玄坂一丁目２番３号',
        industry='情報・通信業',
        sec_code='37690',
        corporate_number='6011001005411',
    ),
    'E05477': EdinetCodeEntry(
        edinet_code='E05477',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=553,
        fiscal_year_end='12月31日',
        submitter_name='共同ピーアール株式会社',
        submitter_name_en='KYODO PUBLIC RELATIONS CO.,LTD.',
        submitter_name_yomi='キョウドウピーアールカブシキカイシャ',
        address='中央区築地一丁目１３番１号',
        industry='サービス業',
        sec_code='24360',
        corporate_number='4010001041427',
    ),
    'E05478': EdinetCodeEntry(
        edinet_code='E05478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=432,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シダー',
        submitter_name_en='cedar.co.,ltd',
        submitter_name_yomi='カブシキガイシャシダー',
        address='北九州市小倉北区足立２丁目１番１号',
        industry='サービス業',
        sec_code='24350',
        corporate_number='3290801004110',
    ),
    'E05479': EdinetCodeEntry(
        edinet_code='E05479',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月31日',
        submitter_name='ルーデン・ホールディングス株式会社',
        submitter_name_en='RUDEN HOLDINGS Co.,Ltd.',
        submitter_name_yomi='ルーデンホールディングスカブシキガイシャ',
        address='渋谷区桜丘町２０番１号',
        industry='建設業',
        sec_code=None,
        corporate_number='1011101035809',
    ),
    'E05480': EdinetCodeEntry(
        edinet_code='E05480',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=23123,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インターネットイニシアティブ',
        submitter_name_en='Internet Initiative Japan Inc.',
        submitter_name_yomi='カブシキガイシャインターネットイニシアティブ',
        address='千代田区富士見二丁目１０番２号',
        industry='情報・通信業',
        sec_code='37740',
        corporate_number='6010001011147',
    ),
    'E05481': EdinetCodeEntry(
        edinet_code='E05481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=397,
        fiscal_year_end='10月31日',
        submitter_name='ＲｅＹｕｕ\u3000Ｊａｐａｎ株式会社',
        submitter_name_en='ReYuu Japan Inc.',
        submitter_name_yomi='リユージャパンカブシキガイシャ',
        address='大阪市北区天満橋一丁目８番３０号\u3000ＯＡＰタワー９階',
        industry='情報・通信業',
        sec_code='94250',
        corporate_number='2120001072917',
    ),
    'E05483': EdinetCodeEntry(
        edinet_code='E05483',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=490,
        fiscal_year_end='4月30日',
        submitter_name='株式会社アスカネット',
        submitter_name_en='Asukanet Company,Limited',
        submitter_name_yomi='カブシキガイシャアスカネット',
        address='広島市安佐南区祇園三丁目２８番１４号',
        industry='サービス業',
        sec_code='24380',
        corporate_number='7240001000407',
    ),
    'E05484': EdinetCodeEntry(
        edinet_code='E05484',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1476,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ザッパラス',
        submitter_name_en='ZAPPALLAS,INC.',
        submitter_name_yomi='カブシキガイシャザッパラス',
        address='東京都渋谷区千駄ヶ谷三丁目５１番７号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8011001048846',
    ),
    'E05485': EdinetCodeEntry(
        edinet_code='E05485',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=845,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソフトクリエイトホールディングス',
        submitter_name_en='SOFTCREATE HOLDINGS CORP.',
        submitter_name_yomi='カブシキガイシャソフトクリエイトホールディングス',
        address='渋谷区渋谷二丁目１５番地１号',
        industry='情報・通信業',
        sec_code='33710',
        corporate_number='8011001012950',
    ),
    'E05487': EdinetCodeEntry(
        edinet_code='E05487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=550,
        fiscal_year_end='3月31日',
        submitter_name='株式会社システムリサーチ',
        submitter_name_en='SYSTEM RESEARCH CO.,LTD.',
        submitter_name_yomi='カブシキガイシャシステムリサーチ',
        address='名古屋市中村区岩塚本通二丁目１２番',
        industry='情報・通信業',
        sec_code='37710',
        corporate_number='8180001030616',
    ),
    'E05491': EdinetCodeEntry(
        edinet_code='E05491',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウィズ',
        submitter_name_en='WiZ CO., LTD.',
        submitter_name_yomi='カブシキガイシャウィズ',
        address='台東区寿三丁目１４番１１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='5010001037564',
    ),
    'E05492': EdinetCodeEntry(
        edinet_code='E05492',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5372,
        fiscal_year_end='9月30日',
        submitter_name='フィンテック\u3000グローバル株式会社',
        submitter_name_en='FinTech Global Incorporated',
        submitter_name_yomi='フィンテックグローバルカブシキガイシャ',
        address='品川区上大崎三丁目１番１号\u3000目黒セントラルスクエア１５階',
        industry='その他金融業',
        sec_code='87890',
        corporate_number='7010401025761',
    ),
    'E05493': EdinetCodeEntry(
        edinet_code='E05493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1052,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タカミヤ',
        submitter_name_en='Takamiya Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャタカミヤ',
        address='大阪市北区大深町３番１号',
        industry='サービス業',
        sec_code='24450',
        corporate_number='5120001102126',
    ),
    'E05494': EdinetCodeEntry(
        edinet_code='E05494',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3345,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ブロードバンドタワー',
        submitter_name_en='BroadBand Tower, Inc.',
        submitter_name_yomi='カブシキガイシャブロードバンドタワー',
        address='千代田区内幸町二丁目１番６号\u3000日比谷パークフロント',
        industry='情報・通信業',
        sec_code='37760',
        corporate_number='6010401059802',
    ),
    'E05496': EdinetCodeEntry(
        edinet_code='E05496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6930,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アドバンスト・メディア',
        submitter_name_en='Advanced Media, Inc.',
        submitter_name_yomi='カブシキガイシャアドバンストメディア',
        address='豊島区東池袋三丁目１番１号\u3000サンシャイン６０\u3000４２階',
        industry='情報・通信業',
        sec_code='37730',
        corporate_number='5013301017946',
    ),
    'E05497': EdinetCodeEntry(
        edinet_code='E05497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ガイアックス',
        submitter_name_en='Gaiax Co.Ltd.',
        submitter_name_yomi='カブシキガイシャガイアックス',
        address='千代田区平河町２丁目５番地３号',
        industry='情報・通信業',
        sec_code='37750',
        corporate_number='1010701022159',
    ),
    'E05498': EdinetCodeEntry(
        edinet_code='E05498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=470,
        fiscal_year_end='8月31日',
        submitter_name='株式会社プラップジャパン',
        submitter_name_en='PRAP Japan,Inc.',
        submitter_name_yomi='カブシキガイシャプラップジャパン',
        address='港区赤坂９－７－２',
        industry='サービス業',
        sec_code='24490',
        corporate_number='7010401097578',
    ),
    'E05504': EdinetCodeEntry(
        edinet_code='E05504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=255,
        fiscal_year_end='3月31日',
        submitter_name='株式会社クロップス',
        submitter_name_en='CROPS CORPORATION',
        submitter_name_yomi='カブシキガイシャクロップス',
        address='名古屋市中村区名駅三丁目２６番８号',
        industry='情報・通信業',
        sec_code='94280',
        corporate_number='6180001029354',
    ),
    'E05505': EdinetCodeEntry(
        edinet_code='E05505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=828,
        fiscal_year_end='6月30日',
        submitter_name='サンネクスタグループ株式会社',
        submitter_name_en='SUNNEXTA GROUP Inc.',
        submitter_name_yomi='サンネクスタグループカブシキガイシャ',
        address='新宿区箪笥町３５番地',
        industry='不動産業',
        sec_code='89450',
        corporate_number='9011101027286',
    ),
    'E05507': EdinetCodeEntry(
        edinet_code='E05507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1610,
        fiscal_year_end=None,
        submitter_name='株式会社ＵＣＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーシーエス',
        address='稲沢市天池五反田町１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001086250',
    ),
    'E05509': EdinetCodeEntry(
        edinet_code='E05509',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=780,
        fiscal_year_end='9月30日',
        submitter_name='ジャパンベストレスキューシステム株式会社',
        submitter_name_en='Japan Best Rescue System Co.,Ltd.',
        submitter_name_yomi='ジャパンベストレスキューシステムカブシキガイシャ',
        address='名古屋市中区錦一丁目１０番２０号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9180001044664',
    ),
    'E05510': EdinetCodeEntry(
        edinet_code='E05510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=198,
        fiscal_year_end='12月31日',
        submitter_name='株式会社環境フレンドリーホールディングス',
        submitter_name_en='Environment Friendly Holdings Corp.',
        submitter_name_yomi='カブシキガイシャカンキョウフレンドリーホールディングス',
        address='港区西新橋三丁目２４番９号',
        industry='情報・通信業',
        sec_code='37770',
        corporate_number='9010501033506',
    ),
    'E05512': EdinetCodeEntry(
        edinet_code='E05512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=382,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アイフィスジャパン',
        submitter_name_en='IFIS JAPAN LTD.',
        submitter_name_yomi='カブシキガイシャアイフィスジャパン',
        address='港区六本木一丁目８番７号',
        industry='その他製品',
        sec_code='78330',
        corporate_number='9010001009543',
    ),
    'E05513': EdinetCodeEntry(
        edinet_code='E05513',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=322,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＷＯＷ\u3000ＷＯＲＬＤ',
        submitter_name_en='WOW WORLD Inc.',
        submitter_name_yomi='カブシキガイシャワオワールド',
        address='品川区西五反田七丁目２０番９号\u3000ＫＤＸ西五反田ビル４階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010701001312',
    ),
    'E05514': EdinetCodeEntry(
        edinet_code='E05514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1285,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オールアバウト',
        submitter_name_en='All About,Inc.',
        submitter_name_yomi='カブシキガイシャオールアバウト',
        address='渋谷区恵比寿南１丁目１５番１号',
        industry='サービス業',
        sec_code='24540',
        corporate_number='7011001034665',
    ),
    'E05516': EdinetCodeEntry(
        edinet_code='E05516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=484,
        fiscal_year_end='10月31日',
        submitter_name='株式会社システム\u3000ディ',
        submitter_name_en='System D Inc.',
        submitter_name_yomi='カブシキガイシャシステムディ',
        address='京都市中京区烏丸通三条上る場之町６０３番地',
        industry='情報・通信業',
        sec_code='38040',
        corporate_number='8130001021041',
    ),
    'E05517': EdinetCodeEntry(
        edinet_code='E05517',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社クリエイト・レストランツ・ホールディングス',
        submitter_name_en='create restaurants holdings inc.',
        submitter_name_yomi='カブシキガイシャクリエイトレストランツホールディングス',
        address='品川区東五反田５丁目１０番１８号',
        industry='小売業',
        sec_code='33870',
        corporate_number='9010701025939',
    ),
    'E05518': EdinetCodeEntry(
        edinet_code='E05518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11283,
        fiscal_year_end='3月31日',
        submitter_name='さくらインターネット株式会社',
        submitter_name_en='SAKURA internet Inc.',
        submitter_name_yomi='サクラインターネットカブシキガイシャ',
        address='大阪市北区大深町６番３８号',
        industry='情報・通信業',
        sec_code='37780',
        corporate_number='3120001079845',
    ),
    'E05520': EdinetCodeEntry(
        edinet_code='E05520',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=70,
        fiscal_year_end='6月30日',
        submitter_name='株式会社夢テクノロジー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ユメテクノロジー',
        address='千代田区神田練塀町３００番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010701024603',
    ),
    'E05521': EdinetCodeEntry(
        edinet_code='E05521',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=984,
        fiscal_year_end='3月31日',
        submitter_name='ＵＬＳグループ株式会社',
        submitter_name_en='ULS Group,Inc.',
        submitter_name_yomi='ユーエルエスグループカブシキガイシャ',
        address='中央区晴海一丁目８番１０号晴海アイランドトリトンスクエアオフィスタワーＸ棟１４階',
        industry='情報・通信業',
        sec_code='37980',
        corporate_number='9010001075445',
    ),
    'E05522': EdinetCodeEntry(
        edinet_code='E05522',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=12791,
        fiscal_year_end='3月31日',
        submitter_name='ＰＧＭホールディングス株式会社',
        submitter_name_en='PGM Holdings K.K.',
        submitter_name_yomi='ピージーエムホールディングスカブシキガイシャ',
        address='台東区東上野一丁目１４番７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010401055956',
    ),
    'E05523': EdinetCodeEntry(
        edinet_code='E05523',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＩＮＴ株式会社',
        submitter_name_en='INT, Inc.',
        submitter_name_yomi='アイエヌティーカブシキガイシャ',
        address='豊島区東池袋一丁目２５番８号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6011101060463',
    ),
    'E05524': EdinetCodeEntry(
        edinet_code='E05524',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1818,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＡｏｂａーＢＢＴ',
        submitter_name_en='Aoba-BBT, Inc.',
        submitter_name_yomi='カブシキガイシャアオバビービーティー',
        address='千代田区六番町１番７号',
        industry='サービス業',
        sec_code='24640',
        corporate_number='9010001027297',
    ),
    'E05527': EdinetCodeEntry(
        edinet_code='E05527',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='アウンコンサルティング株式会社',
        submitter_name_en='AUN CONSULTING,Inc.',
        submitter_name_yomi='アウンコンサルティングカブシキガイシャ',
        address='千代田区丸の内二丁目２番１号',
        industry='サービス業',
        sec_code='24590',
        corporate_number='4010001078254',
    ),
    'E05528': EdinetCodeEntry(
        edinet_code='E05528',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=53,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォーバル・リアルストレート',
        submitter_name_en='Forval RealStraight Inc.',
        submitter_name_yomi='カブシキガイシャフォーバルリアルストレート',
        address='千代田区神田神保町三丁目２３番地の２',
        industry='情報・通信業',
        sec_code='94230',
        corporate_number='6011001061470',
    ),
    'E05533': EdinetCodeEntry(
        edinet_code='E05533',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1173,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ファンコミュニケーションズ',
        submitter_name_en='FAN Communications Inc.',
        submitter_name_yomi='カブシキガイシャファンコミュニケーションズ',
        address='渋谷区渋谷一丁目１番８号',
        industry='サービス業',
        sec_code='24610',
        corporate_number='7011001035606',
    ),
    'E05535': EdinetCodeEntry(
        edinet_code='E05535',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社フュートレック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフュートレック',
        address='大阪市淀川区西中島６丁目１－１新大阪プライムタワー１８Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001095092',
    ),
    'E05536': EdinetCodeEntry(
        edinet_code='E05536',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1548,
        fiscal_year_end='5月31日',
        submitter_name='ライク株式会社',
        submitter_name_en='LIKE,Inc.',
        submitter_name_yomi='ライクカブシキガイシャ',
        address='大阪市北区角田町８番１号',
        industry='サービス業',
        sec_code='24620',
        corporate_number='5120001111993',
    ),
    'E05538': EdinetCodeEntry(
        edinet_code='E05538',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=210,
        fiscal_year_end='9月30日',
        submitter_name='株式会社エイティング',
        submitter_name_en='EIGHTING Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエイティング',
        address='品川区南大井六丁目２１番１２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010701012805',
    ),
    'E05539': EdinetCodeEntry(
        edinet_code='E05539',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=824,
        fiscal_year_end='3月31日',
        submitter_name='スターティアホールディングス株式会社',
        submitter_name_en='Startia Holdings,Inc.',
        submitter_name_yomi='スターティアホールディングスカブシキガイシャ',
        address='新宿区西新宿２－３－１新宿モノリス１９Ｆ',
        industry='卸売業',
        sec_code='33930',
        corporate_number='6011101036075',
    ),
    'E05540': EdinetCodeEntry(
        edinet_code='E05540',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=596,
        fiscal_year_end=None,
        submitter_name='株式会社ヴィンクス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヴィンクス',
        address='大阪市北区堂島浜二丁目２番８号\u3000東洋紡ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001070448',
    ),
    'E05543': EdinetCodeEntry(
        edinet_code='E05543',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='ジェイ・エスコムホールディングス株式会社',
        submitter_name_en='J ESCOM HOLDINGS,INC.',
        submitter_name_yomi='ジェイエスコムホールディングスカブシキガイシャ',
        address='港区赤坂六丁目１５番１１号',
        industry='情報・通信業',
        sec_code='37790',
        corporate_number='4010401059201',
    ),
    'E05544': EdinetCodeEntry(
        edinet_code='E05544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=26,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＶＬＣセキュリティ',
        submitter_name_en='VLC  SECURITY CO., LTD.',
        submitter_name_yomi='カブシキガイシャブイエルシーセキュリティ',
        address='港区虎ノ門四丁目１番４０号',
        industry='サービス業',
        sec_code='24670',
        corporate_number='5010001067297',
    ),
    'E05545': EdinetCodeEntry(
        edinet_code='E05545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=916,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯグローバルサイン・ホールディングス株式会社',
        submitter_name_en='GMO GlobalSign Holdings K.K.',
        submitter_name_yomi='ジーエムオーグローバルサインホールディングスカブシキガイシャ',
        address='渋谷区桜丘町２６番１号セルリアンタワー',
        industry='情報・通信業',
        sec_code='37880',
        corporate_number='7011001037734',
    ),
    'E05546': EdinetCodeEntry(
        edinet_code='E05546',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=366,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ネットワークバリューコンポネンツ',
        submitter_name_en='Network Value Components Ltd.',
        submitter_name_yomi='カブシキガイシャネットワークバリューコンポネンツ',
        address='横須賀市小川町１４番地－１',
        industry='卸売業',
        sec_code=None,
        corporate_number='3021001040906',
    ),
    'E05547': EdinetCodeEntry(
        edinet_code='E05547',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2778,
        fiscal_year_end='3月31日',
        submitter_name='コネクシオ株式会社',
        submitter_name_en='CONEXIO Corporation',
        submitter_name_yomi='コネクシオカブシキガイシャ',
        address='港区虎ノ門四丁目１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1011001044166',
    ),
    'E05548': EdinetCodeEntry(
        edinet_code='E05548',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1346,
        fiscal_year_end='3月31日',
        submitter_name='エヌ・デーソフトウェア株式会社',
        submitter_name_en='ND Software co.,Ltd.',
        submitter_name_yomi='エヌデーソフトウェアカブシキガイシャ',
        address='南陽市和田３３６９番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8390001010794',
    ),
    'E05550': EdinetCodeEntry(
        edinet_code='E05550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1701,
        fiscal_year_end='3月31日',
        submitter_name='ヒビノ株式会社',
        submitter_name_en='Hibino Corporation',
        submitter_name_yomi='ヒビノカブシキガイシャ',
        address='港区港南三丁目５番１４号',
        industry='サービス業',
        sec_code='24690',
        corporate_number='8010401025232',
    ),
    'E05551': EdinetCodeEntry(
        edinet_code='E05551',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=628,
        fiscal_year_end='3月31日',
        submitter_name='株式会社いい生活',
        submitter_name_en='e-Seikatsu Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイイセイカツ',
        address='港区南麻布５丁目２番３２号\u3000興和広尾ビル',
        industry='情報・通信業',
        sec_code='37960',
        corporate_number='9010401039891',
    ),
    'E05552': EdinetCodeEntry(
        edinet_code='E05552',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1811,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ドリコム',
        submitter_name_en='Drecom Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャドリコム',
        address='品川区大崎二丁目１番１号',
        industry='情報・通信業',
        sec_code='37930',
        corporate_number='1011101050337',
    ),
    'E05553': EdinetCodeEntry(
        edinet_code='E05553',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1737,
        fiscal_year_end='3月31日',
        submitter_name='キーウェアソリューションズ株式会社',
        submitter_name_en='Keyware Solutions Inc.',
        submitter_name_yomi='キーウェアソリューションズカブシキガイシャ',
        address='世田谷区上北沢５丁目３７番１８号',
        industry='情報・通信業',
        sec_code='37990',
        corporate_number='5011101033882',
    ),
    'E05555': EdinetCodeEntry(
        edinet_code='E05555',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=372,
        fiscal_year_end='11月30日',
        submitter_name='株式会社エスプール',
        submitter_name_en='S-Pool,Inc.',
        submitter_name_yomi='カブシキガイシャエスプール',
        address='千代田区外神田一丁目１８番１３号',
        industry='サービス業',
        sec_code='24710',
        corporate_number='8010001072939',
    ),
    'E05556': EdinetCodeEntry(
        edinet_code='E05556',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1731,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンマルクホールディングス',
        submitter_name_en='Saint Marc Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサンマルクホールディングス',
        address='岡山市北区平田１７３番地１０４',
        industry='小売業',
        sec_code='33950',
        corporate_number='4260001004499',
    ),
    'E05560': EdinetCodeEntry(
        edinet_code='E05560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='ＷＤＢホールディングス株式会社',
        submitter_name_en='WDB HOLDINGS CO.,LTD.',
        submitter_name_yomi='ダブリューディービーホールディングスカブシキガイシャ',
        address='姫路市豊沢町７９番地',
        industry='サービス業',
        sec_code='24750',
        corporate_number='5140001062244',
    ),
    'E05561': EdinetCodeEntry(
        edinet_code='E05561',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1330,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユニリタ',
        submitter_name_en='UNIRITA Inc.',
        submitter_name_yomi='カブシキガイシャユニリタ',
        address='港区港南二丁目１５番１号',
        industry='情報・通信業',
        sec_code='38000',
        corporate_number='2010401034593',
    ),
    'E05562': EdinetCodeEntry(
        edinet_code='E05562',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2923,
        fiscal_year_end='3月31日',
        submitter_name='ユナイテッド株式会社',
        submitter_name_en='UNITED, Inc.',
        submitter_name_yomi='ユナイテッドカブシキガイシャ',
        address='渋谷区渋谷一丁目２番５号',
        industry='サービス業',
        sec_code='24970',
        corporate_number='6010401094782',
    ),
    'E05563': EdinetCodeEntry(
        edinet_code='E05563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=837,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ラクーンホールディングス',
        submitter_name_en='RACCOON HOLDINGS, Inc.',
        submitter_name_yomi='カブシキガイシャラクーンホールディングス',
        address='中央区日本橋蛎殻町１－１４－１４',
        industry='卸売業',
        sec_code='30310',
        corporate_number='8010001076972',
    ),
    'E05564': EdinetCodeEntry(
        edinet_code='E05564',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=709,
        fiscal_year_end='6月30日',
        submitter_name='手間いらず株式会社',
        submitter_name_en='Temairazu, Inc.',
        submitter_name_yomi='テマイラズカブシキガイシャ',
        address='渋谷区恵比寿一丁目２１番３号',
        industry='サービス業',
        sec_code='24770',
        corporate_number='6011001044649',
    ),
    'E05569': EdinetCodeEntry(
        edinet_code='E05569',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=261,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジェイテック',
        submitter_name_en='JTEC CORPORATION',
        submitter_name_yomi='カブシキガイシャジェイテック',
        address='中央区京橋一丁目１０番７号\u3000ＫＰＰ八重洲ビル',
        industry='サービス業',
        sec_code='24790',
        corporate_number='9010001065586',
    ),
    'E05570': EdinetCodeEntry(
        edinet_code='E05570',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=592,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エヌジェイホールディングス',
        submitter_name_en='NJ Holdings Inc.',
        submitter_name_yomi='カブシキガイシャエヌジェイホールディングス',
        address='港区芝三丁目８番２号',
        industry='情報・通信業',
        sec_code='94210',
        corporate_number='3010001067118',
    ),
    'E05573': EdinetCodeEntry(
        edinet_code='E05573',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=301,
        fiscal_year_end='3月31日',
        submitter_name='イメージ情報開発株式会社',
        submitter_name_en='Image Information Inc.',
        submitter_name_yomi='イメージジョウホウカイハツカブシキガイシャ',
        address='千代田区神田猿楽町２丁目４番１１号',
        industry='情報・通信業',
        sec_code='38030',
        corporate_number='7010001141249',
    ),
    'E05575': EdinetCodeEntry(
        edinet_code='E05575',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='システム・ロケーション株式会社',
        submitter_name_en='System Location Co.,Ltd.',
        submitter_name_yomi='システムロケーションカブシキガイシャ',
        address='目黒区東山２丁目６番３号',
        industry='サービス業',
        sec_code='24800',
        corporate_number='7013201018258',
    ),
    'E05576': EdinetCodeEntry(
        edinet_code='E05576',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=501,
        fiscal_year_end='6月30日',
        submitter_name='株式会社タウンニュース社',
        submitter_name_en='TOWNNEWS-SHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャタウンニュースシャ',
        address='横浜市青葉区荏田西二丁目１番３号',
        industry='サービス業',
        sec_code='24810',
        corporate_number='4021001022663',
    ),
    'E05578': EdinetCodeEntry(
        edinet_code='E05578',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=244,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エコミック',
        submitter_name_en='ECOMIC CO.,LTD',
        submitter_name_yomi='カブシキガイシャエコミック',
        address='札幌市中央区大通西八丁目１－１\u3000朝日生命札幌大通ビル',
        industry='情報・通信業',
        sec_code='38020',
        corporate_number='1430001023947',
    ),
    'E05579': EdinetCodeEntry(
        edinet_code='E05579',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=588,
        fiscal_year_end='3月31日',
        submitter_name='株式会社翻訳センター',
        submitter_name_en='HONYAKU Center Inc.',
        submitter_name_yomi='カブシキガイシャホンヤクセンター',
        address='大阪市中央区久太郎町４丁目１番３号',
        industry='サービス業',
        sec_code='24830',
        corporate_number='1120001089458',
    ),
    'E05584': EdinetCodeEntry(
        edinet_code='E05584',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='株式会社出前館',
        submitter_name_en='DEMAE-CAN CO.,LTD',
        submitter_name_yomi='カブシキガイシャデマエカン',
        address='渋谷区千駄ヶ谷五丁目２７番５号',
        industry='情報・通信業',
        sec_code='24840',
        corporate_number='3120001089729',
    ),
    'E05585': EdinetCodeEntry(
        edinet_code='E05585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=580,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ティア',
        submitter_name_en='TEAR Corporation',
        submitter_name_yomi='カブシキガイシャティア',
        address='名古屋市北区黒川本通三丁目３５番地１',
        industry='サービス業',
        sec_code='24850',
        corporate_number='6180001045104',
    ),
    'E05587': EdinetCodeEntry(
        edinet_code='E05587',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=150,
        fiscal_year_end='6月30日',
        submitter_name='株式会社オーケーウェブ',
        submitter_name_en='OKWEB, Inc.',
        submitter_name_yomi='カブシキガイシャオーケーウェブ',
        address='港区新橋３丁目１１－８',
        industry='情報・通信業',
        sec_code='38080',
        corporate_number='2011001041781',
    ),
    'E05592': EdinetCodeEntry(
        edinet_code='E05592',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1326,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ソリトンシステムズ',
        submitter_name_en='SOLITON SYSTEMS K.K.',
        submitter_name_yomi='カブシキガイシャソリトンシステムズ',
        address='新宿区新宿二丁目４番３号',
        industry='情報・通信業',
        sec_code='30400',
        corporate_number='3011101011691',
    ),
    'E05593': EdinetCodeEntry(
        edinet_code='E05593',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=795,
        fiscal_year_end='3月31日',
        submitter_name='ＪＴＰ株式会社',
        submitter_name_en='JTP Co.,Ltd.',
        submitter_name_yomi='ジエイテイーピーカブシキカイシャ',
        address='品川区北品川四丁目７番３５号',
        industry='サービス業',
        sec_code='24880',
        corporate_number='6010701025248',
    ),
    'E05594': EdinetCodeEntry(
        edinet_code='E05594',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=484,
        fiscal_year_end='12月31日',
        submitter_name='サムシングホールディングス株式会社',
        submitter_name_en='Something Holdings Co.,Ltd.',
        submitter_name_yomi='サムシングホールディングスカブシキガイシャ',
        address='江東区木場一丁目５番２５号',
        industry='建設業',
        sec_code=None,
        corporate_number='6010001096923',
    ),
    'E05596': EdinetCodeEntry(
        edinet_code='E05596',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=304,
        fiscal_year_end='3月31日',
        submitter_name='株式会社やまねメディカル',
        submitter_name_en='Yamane Medical Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャヤマネメディカル',
        address='中央区八重洲二丁目２番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001110741',
    ),
    'E05597': EdinetCodeEntry(
        edinet_code='E05597',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=213,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ビューティカダンホールディングス',
        submitter_name_en='Beauty Kadan Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャビューティカダンホールディングス',
        address='熊本市南区流通団地１―４６',
        industry='卸売業',
        sec_code='30410',
        corporate_number='9010601040352',
    ),
    'E05598': EdinetCodeEntry(
        edinet_code='E05598',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＣＤＧ',
        submitter_name_en='CDG Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシーディージー',
        address='大阪市北区梅田二丁目５番２５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6120001054993',
    ),
    'E05599': EdinetCodeEntry(
        edinet_code='E05599',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1716,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アドウェイズ',
        submitter_name_en='Adways Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000アドウェイズ',
        address='新宿区西新宿五丁目１番１号',
        industry='サービス業',
        sec_code='24890',
        corporate_number='7011101041652',
    ),
    'E05600': EdinetCodeEntry(
        edinet_code='E05600',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=164,
        fiscal_year_end='5月31日',
        submitter_name='モジュレ株式会社',
        submitter_name_en='modulat inc.',
        submitter_name_yomi='モジュレカブシキカイシャ',
        address='港区芝５－２５－１１',
        industry='卸売業',
        sec_code=None,
        corporate_number='7010001127462',
    ),
    'E05601': EdinetCodeEntry(
        edinet_code='E05601',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=360,
        fiscal_year_end='5月31日',
        submitter_name='サイバーステップ株式会社',
        submitter_name_en='CyberStep,Inc.',
        submitter_name_yomi='サイバーステップカブシキカイシャ',
        address='杉並区和泉１－２２－１９',
        industry='情報・通信業',
        sec_code='38100',
        corporate_number='6011001049177',
    ),
    'E05606': EdinetCodeEntry(
        edinet_code='E05606',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=627,
        fiscal_year_end='3月31日',
        submitter_name='株式会社セキュアヴェイル',
        submitter_name_en='SecuAvail Inc.',
        submitter_name_yomi='カブシキガイシャセキュアヴェイル',
        address='大阪市北区東天満一丁目１番１９号',
        industry='情報・通信業',
        sec_code='30420',
        corporate_number='3120001099513',
    ),
    'E05607': EdinetCodeEntry(
        edinet_code='E05607',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='11月30日',
        submitter_name='ファーストブラザーズ株式会社',
        submitter_name_en='First Brothers Co., Ltd.',
        submitter_name_yomi='ファーストブラザーズカブシキガイシャ',
        address='千代田区丸の内二丁目４番１号',
        industry='不動産業',
        sec_code='34540',
        corporate_number='1010001086441',
    ),
    'E05609': EdinetCodeEntry(
        edinet_code='E05609',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3212,
        fiscal_year_end='12月31日',
        submitter_name='株式会社インフォマート',
        submitter_name_en='Infomart Corporation',
        submitter_name_yomi='カブシキガイシャインフォマート',
        address='港区海岸一丁目２番３号',
        industry='サービス業',
        sec_code='24920',
        corporate_number='2010401041383',
    ),
    'E05610': EdinetCodeEntry(
        edinet_code='E05610',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='アキナジスタ株式会社',
        submitter_name_en='Akinasista Corporation.',
        submitter_name_yomi='アキナジスタカブシキガイシャ',
        address='千代田区九段北３－２－５\u3000九段北３２５ビル',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010001125578',
    ),
    'E05611': EdinetCodeEntry(
        edinet_code='E05611',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2471,
        fiscal_year_end='11月30日',
        submitter_name='イーサポートリンク株式会社',
        submitter_name_en='E-SUPPORTLINK,Ltd.',
        submitter_name_yomi='イーサポートリンクカブシキガイシャ',
        address='豊島区高田二丁目１７番２２号',
        industry='サービス業',
        sec_code='24930',
        corporate_number='2013301018864',
    ),
    'E05616': EdinetCodeEntry(
        edinet_code='E05616',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=608,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ノバレーゼ',
        submitter_name_en='NOVARESE Inc.',
        submitter_name_yomi='カブシキガイシャノバレーゼ',
        address='中央区銀座１－８－１４',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010001177471',
    ),
    'E05617': EdinetCodeEntry(
        edinet_code='E05617',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9698,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＩＸＩ',
        submitter_name_en='MIXI, Inc.',
        submitter_name_yomi='カブシキガイシャミクシィ',
        address='渋谷区渋谷二丁目２４番１２号\u3000渋谷スクランブルスクエア',
        industry='サービス業',
        sec_code='21210',
        corporate_number='1011001035512',
    ),
    'E05619': EdinetCodeEntry(
        edinet_code='E05619',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=465,
        fiscal_year_end='3月31日',
        submitter_name='株式会社住宅あんしん保証',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジュウタクアンシンホショウ',
        address='中央区京橋一丁目６番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010001095908',
    ),
    'E05620': EdinetCodeEntry(
        edinet_code='E05620',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=547,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アイレップ',
        submitter_name_en='IREP Co.,Ltd',
        submitter_name_yomi='カブシキガイシャアイレップ',
        address='千代田区永田町二丁目１１番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001145333',
    ),
    'E05621': EdinetCodeEntry(
        edinet_code='E05621',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=460,
        fiscal_year_end='3月31日',
        submitter_name='クルーズ株式会社',
        submitter_name_en='CROOZ,Inc.',
        submitter_name_yomi='クルーズカブシキガイシャ',
        address='渋谷区恵比寿四丁目３番１４号',
        industry='情報・通信業',
        sec_code='21380',
        corporate_number='3010401083482',
    ),
    'E05622': EdinetCodeEntry(
        edinet_code='E05622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=451,
        fiscal_year_end='8月31日',
        submitter_name='株式会社メディア工房',
        submitter_name_en='Media Kobo,Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000メディアコウボウ',
        address='港区六本木七丁目１５番９号',
        industry='情報・通信業',
        sec_code='38150',
        corporate_number='6010401040811',
    ),
    'E05623': EdinetCodeEntry(
        edinet_code='E05623',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=984,
        fiscal_year_end='9月30日',
        submitter_name='株式会社インタースペース',
        submitter_name_en='Interspace Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャインタースペース',
        address='新宿区西新宿二丁目４番地１号',
        industry='サービス業',
        sec_code='21220',
        corporate_number='8011101028715',
    ),
    'E05624': EdinetCodeEntry(
        edinet_code='E05624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9716,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＬＩＦＵＬＬ',
        submitter_name_en='LIFULL Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャライフル',
        address='千代田区麹町１－４－４',
        industry='サービス業',
        sec_code='21200',
        corporate_number='1010401091628',
    ),
    'E05625': EdinetCodeEntry(
        edinet_code='E05625',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=619,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジェイエイシーリクルートメント',
        submitter_name_en='JAC Recruitment Co., Ltd.',
        submitter_name_yomi='カブシキガイシャジェイエイシーリクルートメント',
        address='千代田区神田神保町一丁目１０５番地神保町三井ビルディング１４階',
        industry='サービス業',
        sec_code='21240',
        corporate_number='1010001019483',
    ),
    'E05627': EdinetCodeEntry(
        edinet_code='E05627',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=567,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ハイパー',
        submitter_name_en='HYPER Inc.',
        submitter_name_yomi='カブシキガイシャハイパー',
        address='中央区日本橋堀留町二丁目９番６号',
        industry='卸売業',
        sec_code='30540',
        corporate_number='6010001026475',
    ),
    'E05628': EdinetCodeEntry(
        edinet_code='E05628',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='11月30日',
        submitter_name='スター・マイカ株式会社',
        submitter_name_en='Star Mica Co., Ltd.',
        submitter_name_yomi='スターマイカカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='2010401057974',
    ),
    'E05629': EdinetCodeEntry(
        edinet_code='E05629',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4045,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本Ｍ＆Ａセンターホールディングス',
        submitter_name_en='Nihon M&A Center Holdings Inc.',
        submitter_name_yomi='カブシキガイシャニホンエムアンドエーセンターホールディングス',
        address='千代田区丸の内一丁目８番２号',
        industry='サービス業',
        sec_code='21270',
        corporate_number='6010001033744',
    ),
    'E05630': EdinetCodeEntry(
        edinet_code='E05630',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1617,
        fiscal_year_end='8月31日',
        submitter_name='ＴＨＥ\u3000ＷＨＹ\u3000ＨＯＷ\u3000ＤＯ\u3000ＣＯＭＰＡＮＹ株式会社',
        submitter_name_en='THE WHY HOW DO COMPANY, Inc.',
        submitter_name_yomi='ザホワイハウドゥカンパニーカブシキガイシャ',
        address='新宿区愛住町２２',
        industry='情報・通信業',
        sec_code='38230',
        corporate_number='7013201013779',
    ),
    'E05631': EdinetCodeEntry(
        edinet_code='E05631',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=478,
        fiscal_year_end='12月31日',
        submitter_name='日本和装ホールディングス株式会社',
        submitter_name_en='NIHONWASOU HOLDINGS,INC.',
        submitter_name_yomi='ニホンワソウホールディングスカブシキガイシャ',
        address='港区六本木六丁目２番３１号',
        industry='サービス業',
        sec_code='24990',
        corporate_number='5010001111724',
    ),
    'E05633': EdinetCodeEntry(
        edinet_code='E05633',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=537,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アルファクス・フード・システム',
        submitter_name_en='Alphax Food System Co.,LTD',
        submitter_name_yomi='カブシキガイシャアルファクスフードシステム',
        address='宇部市西本町二丁目１４番３０号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1250001002936',
    ),
    'E05635': EdinetCodeEntry(
        edinet_code='E05635',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=382,
        fiscal_year_end='7月31日',
        submitter_name='株式会社大和コンピューター',
        submitter_name_en='DAIWA COMPUTER CO., LTD.',
        submitter_name_yomi='カブシキガイシャダイワコンピューター',
        address='高槻市若松町３６番１８号',
        industry='情報・通信業',
        sec_code='38160',
        corporate_number='1120901011371',
    ),
    'E05638': EdinetCodeEntry(
        edinet_code='E05638',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=750,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｍｉｎｏｒｉソリューションズ',
        submitter_name_en='Minori Solutions Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ\u3000ミノリソリューションズ',
        address='新宿区西新宿２丁目４番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7011101060388',
    ),
    'E05640': EdinetCodeEntry(
        edinet_code='E05640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＲＡホールディングス',
        submitter_name_en='SRA Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000エスアールエーホールディングス',
        address='豊島区南池袋二丁目３２番８号',
        industry='情報・通信業',
        sec_code='38170',
        corporate_number='2013301022429',
    ),
    'E05641': EdinetCodeEntry(
        edinet_code='E05641',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=198,
        fiscal_year_end='5月31日',
        submitter_name='メディアファイブ株式会社',
        submitter_name_en='Media Five Co.',
        submitter_name_yomi='メディアファイブカブシキガイシャ',
        address='福岡市中央区薬院一丁目１番１号',
        industry='情報・通信業',
        sec_code='38240',
        corporate_number='1290001018160',
    ),
    'E05643': EdinetCodeEntry(
        edinet_code='E05643',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=367,
        fiscal_year_end='2月末日',
        submitter_name='株式会社システムインテグレータ',
        submitter_name_en='System Integrator Corp.',
        submitter_name_yomi='カブシキガイシャシステムインテグレータ',
        address='さいたま市中央区新都心１１番地２',
        industry='情報・通信業',
        sec_code='38260',
        corporate_number='7030001003876',
    ),
    'E05645': EdinetCodeEntry(
        edinet_code='E05645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7877,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リミックスポイント',
        submitter_name_en='Remixpoint,inc.',
        submitter_name_yomi='カブシキガイシャリミックスポイント',
        address='港区虎ノ門四丁目３番９号',
        industry='情報・通信業',
        sec_code='38250',
        corporate_number='3010001110827',
    ),
    'E05646': EdinetCodeEntry(
        edinet_code='E05646',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=867,
        fiscal_year_end='9月30日',
        submitter_name='株式会社オリエンタルコンサルタンツホールディングス',
        submitter_name_en='Oriental Consultants Holdings Company Limited',
        submitter_name_yomi='カブシキカイシャオリエンタルコンサルタンツホールディングス',
        address='渋谷区本町三丁目１２番１号',
        industry='サービス業',
        sec_code='24980',
        corporate_number='5011001048948',
    ),
    'E05647': EdinetCodeEntry(
        edinet_code='E05647',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4009,
        fiscal_year_end='12月31日',
        submitter_name='ソースネクスト株式会社',
        submitter_name_en='SOURCENEXT CORPORATION',
        submitter_name_yomi='ソースネクストカブシキガイシャ',
        address='港区赤坂一丁目１４番１４号',
        industry='情報・通信業',
        sec_code='43440',
        corporate_number='3010401051654',
    ),
    'E05648': EdinetCodeEntry(
        edinet_code='E05648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=365,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アドバンテッジリスクマネジメント',
        submitter_name_en='Advantage Risk Management Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアドバンテッジリスクマネジメント',
        address='目黒区上目黒二丁目１番１号',
        industry='保険業',
        sec_code='87690',
        corporate_number='8013201007846',
    ),
    'E05650': EdinetCodeEntry(
        edinet_code='E05650',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=195,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ギガプライズ',
        submitter_name_en='GIGAPRIZE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャギガプライズ',
        address='渋谷区円山町３－６',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1011001064255',
    ),
    'E05651': EdinetCodeEntry(
        edinet_code='E05651',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1444,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イントランス',
        submitter_name_en='INTRANCE CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイントランス',
        address='渋谷区道玄坂１－１６－５大下ビル９階',
        industry='不動産業',
        sec_code='32370',
        corporate_number='5011001030534',
    ),
    'E05652': EdinetCodeEntry(
        edinet_code='E05652',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1988,
        fiscal_year_end='11月30日',
        submitter_name='株式会社Ｔ＆Ｃメディカルサイエンス',
        submitter_name_en='T&C MEDICAL SCIENCE, INC.',
        submitter_name_yomi='カブシキガイシャティーアンドシーメディカルサイエンス',
        address='港区芝浦一丁目１４番５号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010401045289',
    ),
    'E05657': EdinetCodeEntry(
        edinet_code='E05657',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=377,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヒップ',
        submitter_name_en='HIP CORPORATION',
        submitter_name_yomi='カブシキガイシャヒップ',
        address='横浜市西区楠町８番地８',
        industry='サービス業',
        sec_code='21360',
        corporate_number='9020001015813',
    ),
    'E05659': EdinetCodeEntry(
        edinet_code='E05659',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=190,
        fiscal_year_end='3月31日',
        submitter_name='ｅＢＡＳＥ株式会社',
        submitter_name_en='eBASE Co.,Ltd.',
        submitter_name_yomi='イーベースカブシキガイシャ',
        address='大阪市北区豊崎五丁目４番９号',
        industry='情報・通信業',
        sec_code='38350',
        corporate_number='9120001099805',
    ),
    'E05663': EdinetCodeEntry(
        edinet_code='E05663',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=345,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アバントグループ',
        submitter_name_en='AVANT GROUP CORPORATION',
        submitter_name_yomi='カブシキカイシャアバントグループ',
        address='港区港南二丁目１５番２号',
        industry='情報・通信業',
        sec_code='38360',
        corporate_number='4010401091204',
    ),
    'E05664': EdinetCodeEntry(
        edinet_code='E05664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=575,
        fiscal_year_end='3月31日',
        submitter_name='アドソル日進株式会社',
        submitter_name_en='Ad-Sol Nissin Corporation',
        submitter_name_yomi='アドソルニッシンカブシキカイシャ',
        address='港区港南四丁目１番８号',
        industry='情報・通信業',
        sec_code='38370',
        corporate_number='8010401052268',
    ),
    'E05665': EdinetCodeEntry(
        edinet_code='E05665',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1442,
        fiscal_year_end='3月31日',
        submitter_name='イー・ギャランティ株式会社',
        submitter_name_en='eGuarantee,Inc.',
        submitter_name_yomi='イーギャランティカブシキガイシャ',
        address='港区赤坂５－３－１',
        industry='その他金融業',
        sec_code='87710',
        corporate_number='1011001047318',
    ),
    'E05666': EdinetCodeEntry(
        edinet_code='E05666',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=77,
        fiscal_year_end='12月31日',
        submitter_name='クラウドゲート株式会社',
        submitter_name_en='Crowd Gate Co.,Ltd.',
        submitter_name_yomi='クラウドゲートカブシキガイシャ',
        address='千代田区神田佐久間町１丁目９番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001083509',
    ),
    'E05668': EdinetCodeEntry(
        edinet_code='E05668',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=404,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中広',
        submitter_name_en='CHUCO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャチュウコウ',
        address='岐阜市東興町２７番地',
        industry='サービス業',
        sec_code='21390',
        corporate_number='2200001003384',
    ),
    'E05669': EdinetCodeEntry(
        edinet_code='E05669',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=761,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジーダット',
        submitter_name_en='Jedat Inc.',
        submitter_name_yomi='カブシキガイシャジーダット',
        address='東京都中央区湊１丁目１番１２号\u3000ＨＳＢ鐵砲洲',
        industry='情報・通信業',
        sec_code='38410',
        corporate_number='7010001085545',
    ),
    'E05670': EdinetCodeEntry(
        edinet_code='E05670',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=686,
        fiscal_year_end='3月31日',
        submitter_name='株式会社光ハイツ・ヴェラス',
        submitter_name_en='HIKARI HEIGHTS-VARUS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヒカリハイツヴェラス',
        address='札幌市中央区南１９条西１１丁目１番１５号',
        industry='サービス業',
        sec_code='21370',
        corporate_number='6430001013893',
    ),
    'E05673': EdinetCodeEntry(
        edinet_code='E05673',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＤＤグループ',
        submitter_name_en='DD GROUP Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャディーディーグループ',
        address='港区芝４－１－２３\u3000三田ＮＮビル１８Ｆ',
        industry='小売業',
        sec_code=None,
        corporate_number='8010401065757',
    ),
    'E05674': EdinetCodeEntry(
        edinet_code='E05674',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=512,
        fiscal_year_end='3月31日',
        submitter_name='パス株式会社',
        submitter_name_en='PATH corporation',
        submitter_name_yomi='パスカブシキガイシャ',
        address='渋谷区神宮前六丁目１７番１１号',
        industry='情報・通信業',
        sec_code='38400',
        corporate_number='1011001070286',
    ),
    'E05676': EdinetCodeEntry(
        edinet_code='E05676',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='ｎｍｓホールディングス株式会社',
        submitter_name_en='nms Holdings Corporation',
        submitter_name_yomi='エヌエムエスホールディングスカブシキガイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='サービス業',
        sec_code='21620',
        corporate_number='7011101037766',
    ),
    'E05677': EdinetCodeEntry(
        edinet_code='E05677',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1145,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ネクストジェン',
        submitter_name_en='Nextgen,Inc.',
        submitter_name_yomi='カブシキガイシャネクストジェン',
        address='港区白金一丁目２７号６番',
        industry='情報・通信業',
        sec_code='38420',
        corporate_number='6010001097517',
    ),
    'E05678': EdinetCodeEntry(
        edinet_code='E05678',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1018,
        fiscal_year_end='3月31日',
        submitter_name='コムチュア株式会社',
        submitter_name_en='COMTURE CORPORATION',
        submitter_name_yomi='コムチュアカブシキガイシャ',
        address='品川区大崎１－１１－２',
        industry='情報・通信業',
        sec_code='38440',
        corporate_number='3010701015193',
    ),
    'E05679': EdinetCodeEntry(
        edinet_code='E05679',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=637,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＯＤＫソリューションズ',
        submitter_name_en='ODK Solutions Company,Ltd',
        submitter_name_yomi='カブシキガイシャオーディーケイソリューションズ',
        address='大阪市中央区道修町一丁目６番７号',
        industry='情報・通信業',
        sec_code='38390',
        corporate_number='8120001092926',
    ),
    'E05680': EdinetCodeEntry(
        edinet_code='E05680',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4514,
        fiscal_year_end='4月30日',
        submitter_name='フリービット株式会社',
        submitter_name_en='FreeBit Co., Ltd.',
        submitter_name_yomi='フリービットカブシキカイシャ',
        address='渋谷区円山町３番６号',
        industry='情報・通信業',
        sec_code='38430',
        corporate_number='8011001034292',
    ),
    'E05681': EdinetCodeEntry(
        edinet_code='E05681',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=309,
        fiscal_year_end='3月31日',
        submitter_name='データリンクス株式会社',
        submitter_name_en='DATALINKS CORPORATION',
        submitter_name_yomi='データリンクスカブシキガイシャ',
        address='新宿区西新宿二丁目７番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2011101005216',
    ),
    'E05682': EdinetCodeEntry(
        edinet_code='E05682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイフリークモバイル',
        submitter_name_en='I-FREEK MOBILE INC.',
        submitter_name_yomi='カブシキガイシャアイフリークモバイル',
        address='新宿区新宿二丁目１番１１号',
        industry='情報・通信業',
        sec_code='38450',
        corporate_number='2290001021923',
    ),
    'E05684': EdinetCodeEntry(
        edinet_code='E05684',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2405,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ケアネット',
        submitter_name_en='CareNet,Inc.',
        submitter_name_yomi='カブシキガイシャケアネット',
        address='千代田区富士見１丁目８番１９号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010001075490',
    ),
    'E05685': EdinetCodeEntry(
        edinet_code='E05685',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8489,
        fiscal_year_end='3月31日',
        submitter_name='株式会社タケエイ',
        submitter_name_en='TAKEEI CORPORATION',
        submitter_name_yomi='カブシキガイシャ\u3000タケエイ',
        address='港区芝公園二丁目４番１号Ａ－１０階',
        industry='サービス業',
        sec_code=None,
        corporate_number='9010401077017',
    ),
    'E05686': EdinetCodeEntry(
        edinet_code='E05686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1709,
        fiscal_year_end='3月31日',
        submitter_name='アイティメディア株式会社',
        submitter_name_en='ITmedia Inc.',
        submitter_name_yomi='アイティメディアカブシキガイシャ',
        address='千代田区紀尾井町３番１２号',
        industry='サービス業',
        sec_code='21480',
        corporate_number='1010001092299',
    ),
    'E05687': EdinetCodeEntry(
        edinet_code='E05687',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=777,
        fiscal_year_end='3月31日',
        submitter_name='パシフィックシステム株式会社',
        submitter_name_en='PACIFIC SYSTEMS CORPORATION',
        submitter_name_yomi='パシフィックシステムカブシキカイシャ',
        address='さいたま市桜区田島八丁目４番１９号',
        industry='情報・通信業',
        sec_code='38470',
        corporate_number='4030001034271',
    ),
    'E05688': EdinetCodeEntry(
        edinet_code='E05688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=430,
        fiscal_year_end='3月31日',
        submitter_name='株式会社データ・アプリケーション',
        submitter_name_en='Data Applications Company, Limited',
        submitter_name_yomi='カブシキガイシャデータアプリケーション',
        address='中央区八重洲二丁目２番１号',
        industry='情報・通信業',
        sec_code='38480',
        corporate_number='9010001051124',
    ),
    'E05690': EdinetCodeEntry(
        edinet_code='E05690',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=436,
        fiscal_year_end='3月31日',
        submitter_name='日本テクノ・ラボ株式会社',
        submitter_name_en='NIPPON TECHNO LAB INC.',
        submitter_name_yomi='ニホンテクノラボカブシキガイシャ',
        address='千代田区麹町２－１\u3000ＰＭＯ半蔵門９Ｆ',
        industry='情報・通信業',
        sec_code='38490',
        corporate_number='5010001062315',
    ),
    'E05691': EdinetCodeEntry(
        edinet_code='E05691',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=513,
        fiscal_year_end='3月31日',
        submitter_name='幼児活動研究会株式会社',
        submitter_name_en='Youji Corporation',
        submitter_name_yomi='ヨウジカツドウケンキュウカイカブシキガイシャ',
        address='品川区西五反田２－１１－１７',
        industry='サービス業',
        sec_code='21520',
        corporate_number='3010701010137',
    ),
    'E05692': EdinetCodeEntry(
        edinet_code='E05692',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6461,
        fiscal_year_end='12月31日',
        submitter_name='地主株式会社',
        submitter_name_en='JINUSHI Co.,Ltd.',
        submitter_name_yomi='ジヌシカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='不動産業',
        sec_code='32520',
        corporate_number='6120001095071',
    ),
    'E05693': EdinetCodeEntry(
        edinet_code='E05693',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社カービュー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカービュー',
        address='千代田区紀尾井町１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001047599',
    ),
    'E05694': EdinetCodeEntry(
        edinet_code='E05694',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=516,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エヌ・ティ・ティ・データ・イントラマート',
        submitter_name_en='NTT DATA INTRAMART CORPORATION',
        submitter_name_yomi='カブシキガイシャエヌティティデータイントラマート',
        address='港区赤坂四丁目１５番１号',
        industry='情報・通信業',
        sec_code='38500',
        corporate_number='7010401040174',
    ),
    'E05695': EdinetCodeEntry(
        edinet_code='E05695',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4563,
        fiscal_year_end='6月30日',
        submitter_name='株式会社オープンアップグループ',
        submitter_name_en='Open Up Group Inc.',
        submitter_name_yomi='カブシキガイシャオープンアップグループ',
        address='港区虎ノ門一丁目３番１号',
        industry='サービス業',
        sec_code='21540',
        corporate_number='5010401078571',
    ),
    'E05697': EdinetCodeEntry(
        edinet_code='E05697',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2167,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エス・エム・エス',
        submitter_name_en='SMS CO.,LTD',
        submitter_name_yomi='カブシキガイシャエスエムエス',
        address='港区芝公園二丁目１１番１号',
        industry='サービス業',
        sec_code='21750',
        corporate_number='2010001134117',
    ),
    'E05698': EdinetCodeEntry(
        edinet_code='E05698',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1465,
        fiscal_year_end='3月31日',
        submitter_name='ＵＴグループ株式会社',
        submitter_name_en='UT Group Co,.Ltd.',
        submitter_name_yomi='ユーティーグループカブシキガイシャ',
        address='品川区東五反田一丁目１１番１５号',
        industry='サービス業',
        sec_code='21460',
        corporate_number='6010701020975',
    ),
    'E05699': EdinetCodeEntry(
        edinet_code='E05699',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2275,
        fiscal_year_end='3月31日',
        submitter_name='アステリア株式会社',
        submitter_name_en='ASTERIA Corporation',
        submitter_name_yomi='アステリアカブシキガイシャ',
        address='渋谷区広尾１丁目１番３９号',
        industry='情報・通信業',
        sec_code='38530',
        corporate_number='2010701012175',
    ),
    'E05700': EdinetCodeEntry(
        edinet_code='E05700',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1761,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＦＲＯＮＴＥＯ',
        submitter_name_en='FRONTEO,Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000フロンテオ',
        address='港区港南二丁目１２番２３号',
        industry='サービス業',
        sec_code='21580',
        corporate_number='1010401051219',
    ),
    'E05701': EdinetCodeEntry(
        edinet_code='E05701',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=294,
        fiscal_year_end='3月31日',
        submitter_name='セーラー広告株式会社',
        submitter_name_en='SAYLOR ADVERTISING.INC.',
        submitter_name_yomi='セーラーコウコクカブシキガイシャ',
        address='高松市扇町二丁目７番２０号',
        industry='サービス業',
        sec_code='21560',
        corporate_number='9470001002353',
    ),
    'E05702': EdinetCodeEntry(
        edinet_code='E05702',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1819,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ネクスグループ',
        submitter_name_en='NCXX Group Inc.',
        submitter_name_yomi='カブシキガイシャネクスグループ',
        address='花巻市椚ノ目第２地割３２番地１',
        industry='電気機器',
        sec_code='66340',
        corporate_number='8400001008341',
    ),
    'E05703': EdinetCodeEntry(
        edinet_code='E05703',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=399,
        fiscal_year_end='12月31日',
        submitter_name='サイバーコム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイバーコムカブシキガイシャ',
        address='仙台市青葉区一番町２－７－１７\u3000朝日生命仙台一番町ビル',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5370001008868',
    ),
    'E05704': EdinetCodeEntry(
        edinet_code='E05704',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=898,
        fiscal_year_end='4月30日',
        submitter_name='株式会社フルスピード',
        submitter_name_en='Full Speed Inc.',
        submitter_name_yomi='カブシキガイシャフルスピード',
        address='渋谷区円山町３番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4011001041672',
    ),
    'E05705': EdinetCodeEntry(
        edinet_code='E05705',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=354,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アイル',
        submitter_name_en="I'LL INC",
        submitter_name_yomi='カブシキガイシャアイル',
        address='大阪市北区大深町３番１号',
        industry='情報・通信業',
        sec_code='38540',
        corporate_number='2120001034108',
    ),
    'E05706': EdinetCodeEntry(
        edinet_code='E05706',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='5月31日',
        submitter_name='Ｅ・Ｊホールディングス株式会社',
        submitter_name_en='EJ Holdings Inc.',
        submitter_name_yomi='イージェイホールディングスカブシキガイシャ',
        address='岡山市北区津島京町三丁目１番２１号',
        industry='サービス業',
        sec_code='21530',
        corporate_number='3260001010102',
    ),
    'E05707': EdinetCodeEntry(
        edinet_code='E05707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月末日',
        submitter_name='アクセルマーク株式会社',
        submitter_name_en='AXEL MARK INC.',
        submitter_name_yomi='アクセルマークカブシキガイシャ',
        address='中野区本町一丁目３２番２号',
        industry='情報・通信業',
        sec_code='36240',
        corporate_number='8011201015613',
    ),
    'E05712': EdinetCodeEntry(
        edinet_code='E05712',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7525,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジーエヌアイグループ',
        submitter_name_en='GNI  Group Ltd.',
        submitter_name_yomi='カブシキガイシャジーエヌアイグループ',
        address='中央区日本橋本町二丁目２番２号',
        industry='医薬品',
        sec_code='21600',
        corporate_number='4011101053527',
    ),
    'E05713': EdinetCodeEntry(
        edinet_code='E05713',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2521,
        fiscal_year_end='3月31日',
        submitter_name='Ａｂａｌａｎｃｅ株式会社',
        submitter_name_en='Abalance Corporation',
        submitter_name_yomi='エーバランスカブシキカイシャ',
        address='品川区東品川二丁目２番４号天王洲ファーストタワー',
        industry='情報・通信業',
        sec_code='38560',
        corporate_number='9010501023597',
    ),
    'E05714': EdinetCodeEntry(
        edinet_code='E05714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20029,
        fiscal_year_end='3月末日',
        submitter_name='ソニーフィナンシャルグループ株式会社',
        submitter_name_en='Sony Financial Group Inc.',
        submitter_name_yomi='ソニーフィナンシャルグループカブシキカイシャ',
        address='千代田区大手町１－９－２',
        industry='保険業',
        sec_code='87290',
        corporate_number='4010401053410',
    ),
    'E05716': EdinetCodeEntry(
        edinet_code='E05716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=287,
        fiscal_year_end='8月31日',
        submitter_name='株式会社地域新聞社',
        submitter_name_en='CHIIKISHINBUNSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャチイキシンブンシャ',
        address='八千代市勝田台北一丁目１１番１６号',
        industry='サービス業',
        sec_code='21640',
        corporate_number='6040001020962',
    ),
    'E05717': EdinetCodeEntry(
        edinet_code='E05717',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=238,
        fiscal_year_end='1月末日',
        submitter_name='株式会社アルトナー',
        submitter_name_en='ARTNER CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアルトナー',
        address='大阪市北区中之島三丁目２番１８号',
        industry='サービス業',
        sec_code='21630',
        corporate_number='6140001047590',
    ),
    'E05719': EdinetCodeEntry(
        edinet_code='E05719',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1483,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ユビキタスＡＩ',
        submitter_name_en='Ubiquitous AI Corporation',
        submitter_name_yomi='カブシキガイシャユビキタスエーアイ',
        address='新宿区西新宿一丁目２３番７号',
        industry='情報・通信業',
        sec_code='38580',
        corporate_number='7011101032305',
    ),
    'E05720': EdinetCodeEntry(
        edinet_code='E05720',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2648,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ラック',
        submitter_name_en='LAC Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャラック',
        address='千代田区平河町二丁目１６番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010001134137',
    ),
    'E05725': EdinetCodeEntry(
        edinet_code='E05725',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1359,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＺＯＺＯ',
        submitter_name_en='ZOZO, Inc.',
        submitter_name_yomi='カブシキガイシャゾゾ',
        address='千葉市美浜区中瀬二丁目６番地１',
        industry='小売業',
        sec_code='30920',
        corporate_number='4040001010503',
    ),
    'E05726': EdinetCodeEntry(
        edinet_code='E05726',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=893,
        fiscal_year_end='12月31日',
        submitter_name='ＣＤＳ株式会社',
        submitter_name_en='CDS Co.,Ltd.',
        submitter_name_yomi='シーディーエスカブシキガイシャ',
        address='岡崎市舞木町字市場４６番地',
        industry='サービス業',
        sec_code='21690',
        corporate_number='9180301001381',
    ),
    'E05727': EdinetCodeEntry(
        edinet_code='E05727',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1380,
        fiscal_year_end='12月31日',
        submitter_name='株式会社リンクアンドモチベーション',
        submitter_name_en='Link and Motivation Inc.',
        submitter_name_yomi='カブシキガイシャリンクアンドモチベーション',
        address='中央区銀座４－１２－１５\u3000歌舞伎座タワー\u3000１５階',
        industry='サービス業',
        sec_code='21700',
        corporate_number='5010001068254',
    ),
    'E05728': EdinetCodeEntry(
        edinet_code='E05728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=142,
        fiscal_year_end='3月31日',
        submitter_name='ＮＡＮＯ\u3000ＭＲＮＡ株式会社',
        submitter_name_en='NANO MRNA Co.,Ltd.',
        submitter_name_yomi='ナノエムアールエヌエイカブシキガイシャ',
        address='港区愛宕二丁目５番１号',
        industry='医薬品',
        sec_code='45710',
        corporate_number='5040001067344',
    ),
    'E05729': EdinetCodeEntry(
        edinet_code='E05729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='5月31日',
        submitter_name='株式会社パソナグループ',
        submitter_name_en='Pasona Group Inc.',
        submitter_name_yomi='カブシキガイシャパソナグループ',
        address='千代田区丸の内一丁目５番１号',
        industry='サービス業',
        sec_code='21680',
        corporate_number='6010001114024',
    ),
    'E05733': EdinetCodeEntry(
        edinet_code='E05733',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1391,
        fiscal_year_end='12月末日',
        submitter_name='ＧＣＡ株式会社',
        submitter_name_en='GCA Corporation',
        submitter_name_yomi='ジーシーエーカブシキカイシャ',
        address='千代田区丸の内一丁目１１番１号\u3000パシフィックセンチュリープレイス丸の内３０階',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001115856',
    ),
    'E05736': EdinetCodeEntry(
        edinet_code='E05736',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=570,
        fiscal_year_end='3月31日',
        submitter_name='ネットイヤーグループ株式会社',
        submitter_name_en='Netyear Group Corporation',
        submitter_name_yomi='ネットイヤーグループカブシキガイシャ',
        address='中央区銀座二丁目１５番２号',
        industry='情報・通信業',
        sec_code='36220',
        corporate_number='5010401094866',
    ),
    'E05737': EdinetCodeEntry(
        edinet_code='E05737',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=222,
        fiscal_year_end='12月31日',
        submitter_name='株式会社博展',
        submitter_name_en='Hakuten Corporation',
        submitter_name_yomi='カブシキガイシャハクテン',
        address='中央区京橋三丁目１番１号',
        industry='サービス業',
        sec_code='21730',
        corporate_number='3010001099004',
    ),
    'E05739': EdinetCodeEntry(
        edinet_code='E05739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10001,
        fiscal_year_end='3月31日',
        submitter_name='ＴＩＳ株式会社',
        submitter_name_en='TIS Inc.',
        submitter_name_yomi='ティアイエスカブシキガイシャ',
        address='新宿区西新宿８丁目１７番１号',
        industry='情報・通信業',
        sec_code='36260',
        corporate_number='2010001134133',
    ),
    'E05740': EdinetCodeEntry(
        edinet_code='E05740',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=139,
        fiscal_year_end='6月末日',
        submitter_name='株式会社インサイト',
        submitter_name_en='INSIGHT INC.',
        submitter_name_yomi='カブシキガイシャインサイト',
        address='札幌市北区北八条西一丁目３番地',
        industry='サービス業',
        sec_code='21720',
        corporate_number='9430001009798',
    ),
    'E05741': EdinetCodeEntry(
        edinet_code='E05741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1237,
        fiscal_year_end='12月31日',
        submitter_name='ビリングシステム株式会社',
        submitter_name_en='Billing System Corporation',
        submitter_name_yomi='ビリングシステムカブシキガイシャ',
        address='千代田区内幸町一丁目１番１号',
        industry='情報・通信業',
        sec_code='36230',
        corporate_number='6010001139434',
    ),
    'E05742': EdinetCodeEntry(
        edinet_code='E05742',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='6月30日',
        submitter_name='テックファームホールディングス株式会社',
        submitter_name_en='Techfirm Holdings Inc.',
        submitter_name_yomi='テックファームホールディングスカブシキガイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code='36250',
        corporate_number='3011101058080',
    ),
    'E05747': EdinetCodeEntry(
        edinet_code='E05747',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=881339,
        fiscal_year_end='12月31日',
        submitter_name='ザ・ダウ・ケミカル・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ザダウケミカルカンパニー',
        address='アメリカ合衆国４８６７４ミシガン州ミッドランド市ダウ・センター２０３０',
        industry='化学',
        sec_code=None,
        corporate_number=None,
    ),
    'E05748': EdinetCodeEntry(
        edinet_code='E05748',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3707639,
        fiscal_year_end='12月31日',
        submitter_name='インターナショナル・ビジネス・マシーンズ・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='インターナショナル\u3000ビジネス\u3000マシーンズ\u3000コーポレーション',
        address='米国ニューヨーク州\u3000１０５０４\u3000アーモンク',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05750': EdinetCodeEntry(
        edinet_code='E05750',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1364929,
        fiscal_year_end='9月30日',
        submitter_name='ナショナル・オーストラリア・バンク・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ナショナル\u3000オーストラリア\u3000バンク\u3000リミテッド',
        address='オーストラリア連邦\u3000ビクトリア州\u3000３０００\u3000メルボルン\u3000バークストリート\u3000３９５\u3000２８階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05751': EdinetCodeEntry(
        edinet_code='E05751',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=465025,
        fiscal_year_end='12月31日',
        submitter_name='テレフォニカ・エセ・アー',
        submitter_name_en=None,
        submitter_name_yomi='テレフォニカエセアー',
        address='スペイン王国２８０１３マドリッド市グラン・ビア２８番',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05753': EdinetCodeEntry(
        edinet_code='E05753',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1133894,
        fiscal_year_end='12月31日',
        submitter_name='アメリカン・エキスプレス・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='アメリカンエキスプレスカンパニー',
        address='アメリカ合衆国１０２８５ニュヨーク州ニューヨーク市ベシー・ストリート２００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05757': EdinetCodeEntry(
        edinet_code='E05757',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1329522,
        fiscal_year_end='12月31日',
        submitter_name='ビーシーイー・インク',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーイーインク',
        address='カナダ\u3000Ｈ３Ｅ３Ｂ３\u3000ケベック州ベルダン市\u3000カルフール・アレクサンダー・グラハム・ベル\u3000ビルディングＡ\u3000８階\u3000１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05759': EdinetCodeEntry(
        edinet_code='E05759',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3728842,
        fiscal_year_end='9月30日',
        submitter_name='ウエストパック・バンキング・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ウエストパックバンキングコーポレーション',
        address='オーストラリア連邦\u3000２０００\u3000ニュー・サウス・ウェールズ州シドニー市ケントストリート２７５番地ウエストパック・プレイス１８階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05760': EdinetCodeEntry(
        edinet_code='E05760',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=403319,
        fiscal_year_end='6月30日',
        submitter_name='ザ・プロクター・アンド・ギャンブル・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ザ\u3000プロクター\u3000アンド\u3000ギャンブル\u3000カンパニー',
        address='アメリカ合衆国４５２０２オハイオ州シンシナティ市ワン・プロクター・アンド・ギャンブル・プラザ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05761': EdinetCodeEntry(
        edinet_code='E05761',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=186188,
        fiscal_year_end='12月31日',
        submitter_name='コメルツバンク・アクツィエンゲゼルシャフト',
        submitter_name_en=None,
        submitter_name_yomi='コメルツバンク\u3000アクツィエンゲゼルシャフト',
        address='ドイツ連邦共和国、フランクフルト・アム・マイン\u3000６０３１１、カイザーシュトラーセ\u3000１６\u3000（カイザープラッツ）',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05762': EdinetCodeEntry(
        edinet_code='E05762',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=491792,
        fiscal_year_end='12月31日',
        submitter_name='バークレイズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='バークレイズピーエルシー',
        address='英国\u3000ロンドン市\u3000Ｅ１４\u3000５ＨＰ\u3000チャーチル・プレイス\u3000１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05763': EdinetCodeEntry(
        edinet_code='E05763',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='マクドナルド・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='マクドナルド\u3000コーポレーション',
        address='アメリカ合衆国６０６０７\u3000イリノイ州シカゴ市\u3000ノース・カーペンター・ストリート１１０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05764': EdinetCodeEntry(
        edinet_code='E05764',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2537088,
        fiscal_year_end='12月31日',
        submitter_name='ネクストエラ・エネルギー・インク',
        submitter_name_en=None,
        submitter_name_yomi='ネクストエラエネルギーインク',
        address='アメリカ合衆国フロリダ州３３４０８、ジュノ・ビーチ、ユニバース・ブールバード７００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05765': EdinetCodeEntry(
        edinet_code='E05765',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=56874,
        fiscal_year_end='12月31日',
        submitter_name='イーライ・リリー・アンド・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='イーライ\u3000リリー\u3000アンド\u3000カンパニー',
        address='アメリカ合衆国４６２８５インディアナ州インディアナポリス、リリー・コーポレート・センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05770': EdinetCodeEntry(
        edinet_code='E05770',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4667,
        fiscal_year_end='12月31日',
        submitter_name='バンク・オブ・アメリカ・コーポレーション（Ｂａｎｋ\u3000ｏｆ\u3000Ａｍｅｒｉｃａ\u3000Ｃｏｒｐｏｒａｔｉｏｎ）',
        submitter_name_en=None,
        submitter_name_yomi='バンクオブアメリカコーポレーション',
        address='アメリカ合衆国２８２５５ノース・カロライナ州シャーロット\u3000バンク・オブ・アメリカ・コーポレート・センター\u3000Ｎトライオン・ストリート１００',
        industry='銀行業',
        sec_code=None,
        corporate_number=None,
    ),
    'E05771': EdinetCodeEntry(
        edinet_code='E05771',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=655072,
        fiscal_year_end='12月31日',
        submitter_name='ビーピー・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ビーピーピーエルシー',
        address='英国\u3000ＳＷ１Ｙ\u3000４ＰＤ\u3000ロンドン\u3000セント・ジェームズ・スクウェア１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05772': EdinetCodeEntry(
        edinet_code='E05772',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=6671081,
        fiscal_year_end='12月31日',
        submitter_name='アメリカン・インターナショナル・グループ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アメリカンインターナショナルグループインク',
        address='アメリカ合衆国ニューヨーク州１００３８ニューヨーク、ウォーター・ストリート１７５',
        industry='保険業',
        sec_code=None,
        corporate_number=None,
    ),
    'E05773': EdinetCodeEntry(
        edinet_code='E05773',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=14740277,
        fiscal_year_end='12月31日',
        submitter_name='ジェー・ピー・モルガン・チェース・アンド・カンパニー（ＪＰＭｏｒｇａｎ\u3000Ｃｈａｓｅ\u3000＆\u3000Ｃｏ．）',
        submitter_name_en=None,
        submitter_name_yomi='ジェーピーモルガンチェースアンドカンパニー',
        address='アメリカ合衆国１０１７９ニューヨーク州ニューヨーク市マディソン・アベニュー３８３',
        industry='銀行業',
        sec_code=None,
        corporate_number=None,
    ),
    'E05776': EdinetCodeEntry(
        edinet_code='E05776',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=14972,
        fiscal_year_end='12月31日',
        submitter_name='ＡＦＬＡＣ\u3000Ｉｎｃｏｒｐｏｒａｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='アフラックインコーポレーテッド',
        address='アメリカ合衆国３１９９９、ジョージア州コロンバス、ウィントン・ロード１９３２',
        industry='保険業',
        sec_code=None,
        corporate_number=None,
    ),
    'E05779': EdinetCodeEntry(
        edinet_code='E05779',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=261026,
        fiscal_year_end='12月31日',
        submitter_name='バイエル・アクツィーエンゲゼルシャフト',
        submitter_name_en=None,
        submitter_name_yomi='バイエル\u3000アクツィーエンゲゼルシャフト',
        address='ドイツ、レバクーゼン５１３７３、カイザー・ヴィルヘルム・アレー１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05781': EdinetCodeEntry(
        edinet_code='E05781',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=18105,
        fiscal_year_end='12月31日',
        submitter_name='アルカテル・ルーセント',
        submitter_name_en=None,
        submitter_name_yomi='アルカテルルーセント',
        address='フランス、９２１００ブローニュ・ビヤンクール、ルート・ドゥ・ラ・レーヌ１４８／１５２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05782': EdinetCodeEntry(
        edinet_code='E05782',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4442,
        fiscal_year_end='12月31日',
        submitter_name='モトローラ・ソリューションズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='モトローラソリューションズインク',
        address='アメリカ合衆国イリノイ州６０６６１シカゴ、ウエスト・モンロー・ストリート５００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05784': EdinetCodeEntry(
        edinet_code='E05784',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=8708,
        fiscal_year_end='12月31日',
        submitter_name='クレディ・スイス・グループＡＧ',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスグループアーゲー',
        address='スイス国チューリッヒ、８００１、パラデプラッツ８番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05786': EdinetCodeEntry(
        edinet_code='E05786',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=30282,
        fiscal_year_end='3月31日',
        submitter_name='セバン・トレント・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='セバントレントピーエルシー',
        address='英国\u3000ＣＶ１\u3000２ＬＺ\u3000コベントリ、セント・ジョンズ・ストリート２、セバン・トレント・センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05791': EdinetCodeEntry(
        edinet_code='E05791',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=965401,
        fiscal_year_end='12月31日',
        submitter_name='バンコ・サンタンデール・エセ・アー',
        submitter_name_en=None,
        submitter_name_yomi='バンコサンタンデールエセアー',
        address='スペイン\u3000サンタンデール\u3000９－１２番\u3000パセオ・デ・ペレダ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05792': EdinetCodeEntry(
        edinet_code='E05792',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=735559,
        fiscal_year_end='12月31日',
        submitter_name='ドイツ銀行',
        submitter_name_en=None,
        submitter_name_yomi='ドイツギンコウ',
        address='ドイツ連邦共和国\u3000６０３２５\u3000フランクフルト・アム・マイン\u3000タウヌスアンラーゲ１２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05794': EdinetCodeEntry(
        edinet_code='E05794',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=819957,
        fiscal_year_end='12月31日',
        submitter_name='テキサス・インスツルメンツ・インコーポレイテッド',
        submitter_name_en=None,
        submitter_name_yomi='テキサスインスツルメンツインコーポレイテッド',
        address='アメリカ合衆国７５２４３テキサス州ダラス\u3000ＴＩブールバード１２５００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05803': EdinetCodeEntry(
        edinet_code='E05803',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='ザ・コリア・ファンド・インク',
        submitter_name_en=None,
        submitter_name_yomi='ザコリアファンドインク',
        address='英国\u3000ロンドン\u3000ＥＣ４Ｙ\u3000０ＪＰ\u3000ビクトリア・エンバンクメント６０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E05807': EdinetCodeEntry(
        edinet_code='E05807',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=37000,
        fiscal_year_end='12月31日',
        submitter_name='ポスコ・ホールディングス・インク',
        submitter_name_en=None,
        submitter_name_yomi='ポスコホールディングスインク',
        address='大韓民国ソウル特別市江南区テヘラン路４４０',
        industry='鉄鋼',
        sec_code=None,
        corporate_number=None,
    ),
    'E05809': EdinetCodeEntry(
        edinet_code='E05809',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=273145,
        fiscal_year_end='12月31日',
        submitter_name='サノフィ',
        submitter_name_en=None,
        submitter_name_yomi='サノフィ',
        address='フランス、パリ、７５０１７\u3000アベニュー・ドゥ・ラ・グランダルメ４６',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05816': EdinetCodeEntry(
        edinet_code='E05816',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='12月31日',
        submitter_name='ブリストル・マイヤーズ\u3000スクイブ・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ブリストルマイヤーズスクイブカンパニー',
        address='アメリカ合衆国\u3000１０１５４－００３７\u3000ニューヨーク州ニューヨーク\u3000パーク\u3000アベニュー\u3000３４５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05817': EdinetCodeEntry(
        edinet_code='E05817',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5756328,
        fiscal_year_end='6月30日',
        submitter_name='マイクロソフトコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='マイクロソフトコーポレーション',
        address='アメリカ合衆国９８０５２－６３９９ワシントン州レドモンド\u3000ワン\u3000マイクロソフト\u3000ウェイ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05821': EdinetCodeEntry(
        edinet_code='E05821',
        submitter_type='外国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22618,
        fiscal_year_end='6月30日',
        submitter_name='ワイ・ティー・エル・コーポレーション・バーハッド',
        submitter_name_en=None,
        submitter_name_yomi='ワイティーエルコーポレーションバーハッド',
        address='マレーシア\u3000５５１００\u3000クアラルンプール、ジャラン・ブキット・ビンタン\u3000Ｎｏ．２０５、メナラ・ワイ・ティー・エル３３階',
        industry='建設業',
        sec_code='17730',
        corporate_number=None,
    ),
    'E05830': EdinetCodeEntry(
        edinet_code='E05830',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1765318,
        fiscal_year_end='12月31日',
        submitter_name='ドイツテレコム・アーゲー',
        submitter_name_en=None,
        submitter_name_yomi='ドイツテレコム\u3000アーゲー',
        address='ドイツ連邦共和国\u3000５３１１３\u3000ボン\u3000フリードリヒ・エーベルト・アレー\u3000１４０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05831': EdinetCodeEntry(
        edinet_code='E05831',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='ニュースキン・エンタープライジズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='ニュースキンエンタープライジズインク',
        address='アメリカ合衆国８４６０１ユタ州プロボ、ウエスト・センター・ストリート７５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05835': EdinetCodeEntry(
        edinet_code='E05835',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=90683,
        fiscal_year_end='12月31日',
        submitter_name='ソシエテ・ジェネラル',
        submitter_name_en=None,
        submitter_name_yomi='ソシエテ\u3000ジェネラル',
        address='フランス共和国\u3000パリ９区\u3000ブルバール・オスマン\u3000２９',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05837': EdinetCodeEntry(
        edinet_code='E05837',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=54527,
        fiscal_year_end='12月31日',
        submitter_name='ヘンダーソン・ランド・ディベロプメント・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ヘンダーソン\u3000ランド\u3000ディベロプメント\u3000カンパニー\u3000リミテッド',
        address='香港、セントラル、ファイナンス・ストリート８、トゥー・インターナショナル・ファイナンス・センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05839': EdinetCodeEntry(
        edinet_code='E05839',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1197132,
        fiscal_year_end='12月31日',
        submitter_name='オレンジ',
        submitter_name_en=None,
        submitter_name_yomi='オレンジ',
        address='フランス共和国\u3000９２１３０イッシー・レ・ムリノー、ケ・デュ・プレジダン・ルーズベルト１１１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05840': EdinetCodeEntry(
        edinet_code='E05840',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2733274,
        fiscal_year_end='12月末日',
        submitter_name='インテル・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='インテルコーポレーション',
        address='米国カリフォルニア州サンタクララ、ミッション・カレッジ・ブルバード２２００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05842': EdinetCodeEntry(
        edinet_code='E05842',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4329090,
        fiscal_year_end='7月28日',
        submitter_name='シスコ・システムズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='シスコシステムズインク',
        address='アメリカ合衆国\u3000９５１３４－１７０６\u3000カリフォルニア州\u3000サンノゼ市\u3000ウエスタスマンドライブ１７０番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05845': EdinetCodeEntry(
        edinet_code='E05845',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=499067,
        fiscal_year_end='6月30日',
        submitter_name='テルストラ・コーポレーション・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='テルストラコーポレーションリミテッド',
        address='オーストラリア連邦\u3000ヴィクトリア州３０００\u3000メルボルン市\u3000エクスビション・ストリート２４２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05846': EdinetCodeEntry(
        edinet_code='E05846',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=143973,
        fiscal_year_end='12月31日',
        submitter_name='エンデサ',
        submitter_name_en=None,
        submitter_name_yomi='エンデサ',
        address='スペイン王国\u3000マドリッド市\u3000２８０４２、リベラ・デル・ロイラ\u3000６０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05851': EdinetCodeEntry(
        edinet_code='E05851',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1188,
        fiscal_year_end='10月31日',
        submitter_name='アプライド\u3000マテリアルズ\u3000インク',
        submitter_name_en=None,
        submitter_name_yomi='アプライド\u3000マテリアルズ\u3000インク',
        address='９５０５２－８０３９\u3000アメリカ合衆国カリフォルニア州サンタクララ、バウワーズ・アベニュー３０５０、私書箱５８０３９号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05852': EdinetCodeEntry(
        edinet_code='E05852',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=56013,
        fiscal_year_end='12月31日',
        submitter_name='ユービーエス・エイ・ジー',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスエイジー',
        address='スイス国\u3000チューリッヒ市\u3000ＣＨ８００１\u3000バーンホフストラッセ４５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05854': EdinetCodeEntry(
        edinet_code='E05854',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=400684,
        fiscal_year_end='12月31日',
        submitter_name='ダイムラー・アーゲー',
        submitter_name_en=None,
        submitter_name_yomi='ダイムラーアーゲー',
        address='ドイツ連邦共和国、７０３２７シュツットガルト、メルセデスシュトラーセ１３７',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05856': EdinetCodeEntry(
        edinet_code='E05856',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=53806,
        fiscal_year_end='12月31日',
        submitter_name='ファイザー・インク',
        submitter_name_en=None,
        submitter_name_yomi='ファイザーインク',
        address='アメリカ合衆国\u3000１０００１－２１９２\u3000ニューヨーク州ニューヨーク\u3000ハドソン・ブルバード・イースト６６',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05858': EdinetCodeEntry(
        edinet_code='E05858',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=5516403,
        fiscal_year_end='12月31日',
        submitter_name='ザ・ゴールドマン・サックス・グループ・インク',
        submitter_name_en=None,
        submitter_name_yomi='ザ\u3000ゴールドマン\u3000サックス\u3000グループ\u3000インク',
        address='アメリカ合衆国１０２８２ニューヨーク州ニューヨーク、ウェスト・ストリート２００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05861': EdinetCodeEntry(
        edinet_code='E05861',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ビー・エヌ・ピー・パリバ',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌピーパリバ',
        address='フランス国パリ市９区イタリア通り１６番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05866': EdinetCodeEntry(
        edinet_code='E05866',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2522562,
        fiscal_year_end='12月31日',
        submitter_name='シティグループ・インク',
        submitter_name_en=None,
        submitter_name_yomi='シティグループ\u3000インク',
        address='アメリカ合衆国ニューヨーク州ニューヨーク市グリニッジ・ストリート３８８',
        industry='銀行業',
        sec_code=None,
        corporate_number=None,
    ),
    'E05868': EdinetCodeEntry(
        edinet_code='E05868',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=272448,
        fiscal_year_end='12月31日',
        submitter_name='ザ\u3000コカ・コーラ\u3000カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ザコカコーラカンパニー',
        address='アメリカ合衆国３０３１３ジョージア州アトランタ、ワン\u3000コカ・コーラ\u3000プラザ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05871': EdinetCodeEntry(
        edinet_code='E05871',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4302299,
        fiscal_year_end='12月31日',
        submitter_name='モルガン・スタンレー',
        submitter_name_en=None,
        submitter_name_yomi='モルガンスタンレー',
        address='アメリカ合衆国\u3000１００３６\u3000ニューヨーク州ニューヨーク、ブロードウェイ１５８５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05872': EdinetCodeEntry(
        edinet_code='E05872',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1721158,
        fiscal_year_end='6月30日',
        submitter_name='オーストラリア・コモンウェルス銀行',
        submitter_name_en=None,
        submitter_name_yomi='オーストラリアコモンウェルスギンコウ',
        address='オーストラリア、２０００ニューサウス・ウェールズ州、シドニー、ハーバー・ストリート１１、コモンウェルス・バンク・プレイス・サウス、１階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05874': EdinetCodeEntry(
        edinet_code='E05874',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=331,
        fiscal_year_end='10月31日',
        submitter_name='アジレント・テクノロジーズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アジレントテクノロジーズインク',
        address='米国、９５０５１、カリフォルニア州、サンタ・クララ、スティーブンス・クリーク・ブルバード５３０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05875': EdinetCodeEntry(
        edinet_code='E05875',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=46998,
        fiscal_year_end='12月31日',
        submitter_name='ゴールドマン・サックス・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='ゴールドマンサックスインターナショナル',
        address='英国\u3000ＥＣ４Ａ\u3000４ＡＵ\u3000ロンドン\u3000シューレーン\u3000２５\u3000プラムツリー・コート',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05881': EdinetCodeEntry(
        edinet_code='E05881',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=101204,
        fiscal_year_end='12月31日',
        submitter_name='ＭＵＦＧセキュリティーズＥＭＥＡ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='エムユーエフジーセキュリティーズイーエムイーエイピーエルシー',
        address='英国ロンドン市ロープメーカー・ストリート２５\u3000ロープメーカー・プレイス\u3000ＥＣ２Ｙ\u3000９ＡＪ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05884': EdinetCodeEntry(
        edinet_code='E05884',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=900,
        fiscal_year_end='12月31日',
        submitter_name='スリーエム\u3000カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='スリーエムカンパニー',
        address='アメリカ合衆国\u3000５５１４４\u3000ミネソタ州セントポール市\u3000スリーエムセンター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05885': EdinetCodeEntry(
        edinet_code='E05885',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2446836,
        fiscal_year_end='12月31日',
        submitter_name='エイチエスビーシー・ファイナンス・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーファイナンスコーポレーション',
        address='アメリカ合衆国\u3000６０００４\u3000イリノイ州\u3000アーリントンハイツ\u3000ウェスト・シャー・ドライブ\u3000１４２１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05887': EdinetCodeEntry(
        edinet_code='E05887',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1861,
        fiscal_year_end='10月末日',
        submitter_name='ＨＰ\u3000インク',
        submitter_name_en=None,
        submitter_name_yomi='エイチピー\u3000インク',
        address='アメリカ合衆国９４３０４、カリフォルニア州、パロ・アルト、ページ・ミル・ロード\u3000１５０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05889': EdinetCodeEntry(
        edinet_code='E05889',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=157245,
        fiscal_year_end='12月31日',
        submitter_name='ドイツポスト・アーゲー',
        submitter_name_en=None,
        submitter_name_yomi='ドイツポストアーゲー',
        address='ドイツ連邦共和国、５３１１３\u3000ボン、シャルル・ド・ゴール・シュトラーセ\u3000２０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05891': EdinetCodeEntry(
        edinet_code='E05891',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=189140,
        fiscal_year_end='12月31日',
        submitter_name='グラクソスミスクライン・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='グラクソスミスクラインピーエルシー',
        address='英国、ＴＷ８\u3000９ＧＳ、ミドルセックス、ブレントフォード、グレート・ウエスト・ロード\u3000９８０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05892': EdinetCodeEntry(
        edinet_code='E05892',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=7,
        fiscal_year_end='12月1日',
        submitter_name='アドビ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アドビインク',
        address='アメリカ合衆国９５１１０－２７０４カリフォルニア州サンノゼ、パークアベニュー３４５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05895': EdinetCodeEntry(
        edinet_code='E05895',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=55453,
        fiscal_year_end='12月31日',
        submitter_name='バクスター\u3000インターナショナル\u3000インコーポレィテッド',
        submitter_name_en=None,
        submitter_name_yomi='バクスター\u3000インターナショナル\u3000インコーポレィテッド',
        address='アメリカ合衆国６００１５－４６２５イリノイ州、ディアフィールド、ワン・バクスター・パークウェイ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05898': EdinetCodeEntry(
        edinet_code='E05898',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=112877,
        fiscal_year_end='12月31日',
        submitter_name='株式會社ケーティー（ＫＴ\u3000Ｃｏｒｐｏｒａｔｉｏｎ）',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャケーティー\u3000ケーティーコーポレーション',
        address='大韓民国京畿道城南市盆唐區佛亭路９０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05903': EdinetCodeEntry(
        edinet_code='E05903',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2420,
        fiscal_year_end='12月31日',
        submitter_name='ゼネラル・エレクトリック・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ゼネラルエレクトリックカンパニー',
        address='アメリカ合衆国０２１１１、マサチューセッツ州ボストン、スイート３７００、ワン・ファイナンシャル・センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05904': EdinetCodeEntry(
        edinet_code='E05904',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=72898,
        fiscal_year_end='3月31日',
        submitter_name='トヨタ\u3000モーター\u3000クレジット\u3000コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='トヨタモータークレジットコーポレーション',
        address='アメリカ合衆国\u3000７５０２４－５９６５\u3000テキサス州\u3000プレイノ\u3000Ｗ２－５Ａ\u3000ヘッドクウォーターズ・ドライブ\u3000６５６５番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05907': EdinetCodeEntry(
        edinet_code='E05907',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=194074,
        fiscal_year_end='12月31日',
        submitter_name='ルノー',
        submitter_name_en=None,
        submitter_name_yomi='ルノー',
        address='フランス、ブローニュ・ビヤンクール９２１００\u3000ジェネラル・ルクレール・アベニュー\u3000１２２－１２２ｂｉｓ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05908': EdinetCodeEntry(
        edinet_code='E05908',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3812452,
        fiscal_year_end='12月31日',
        submitter_name='アマゾン・ドット・コム・インク',
        submitter_name_en=None,
        submitter_name_yomi='アマゾンドットコムインク',
        address='アメリカ合衆国９８１０９ワシントン州シアトル\u3000テリー・アベニュー・ノース４１０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05909': EdinetCodeEntry(
        edinet_code='E05909',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=4,
        fiscal_year_end='12月31日',
        submitter_name='大田リバーサイド・エクスプレスウェイ・ファンディング・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='オオタリバーサイドエクスプレスウェイファンディングピーエルシー',
        address='アイルランド共和国、ダブリン３、イーストポイント・ビジネス・パーク、ピナクル２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05911': EdinetCodeEntry(
        edinet_code='E05911',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=69101,
        fiscal_year_end='9月30日',
        submitter_name='キャボット・マイクロエレクトロニクス・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='キャボットマイクロエレクトロニクスコーポレーション',
        address='アメリカ合衆国６０５０４\u3000イリノイ州オーロラ市ノースコモンズ・ドライブ８７０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05913': EdinetCodeEntry(
        edinet_code='E05913',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=300,
        fiscal_year_end='12月31日',
        submitter_name='ジンマー・バイオメット・ホールディングス・インク',
        submitter_name_en=None,
        submitter_name_yomi='ジンマーバイオメットホールディングスインク',
        address='アメリカ合衆国\u3000４６５８０\u3000インディアナ州ワルソー\u3000イースト・メイン・ストリート\u3000３４５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05916': EdinetCodeEntry(
        edinet_code='E05916',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=585,
        fiscal_year_end='12月31日',
        submitter_name='プルデンシャル・ファイナンシャル・インク',
        submitter_name_en=None,
        submitter_name_yomi='プルデンシャルファイナンシャルインク',
        address='アメリカ合衆国\u3000０７１０２\u3000ニュージャージー州\u3000ニューアーク\u3000ブロード・ストリート\u3000７５１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05921': EdinetCodeEntry(
        edinet_code='E05921',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=54417,
        fiscal_year_end='12月31日',
        submitter_name='マーシュ・アンド・マクレナン・カンパニーズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='マーシュ\u3000アンド\u3000マクレナン\u3000カンパニーズ\u3000インク',
        address='アメリカ合衆国、デラウェア州、ニュー・キャッスル郡、ウィルミントン市、オレンジ・ストリート１２０９',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05923': EdinetCodeEntry(
        edinet_code='E05923',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=101168,
        fiscal_year_end='12月31日',
        submitter_name='コーペラティブ・ラボバンク・ウー・アー',
        submitter_name_en=None,
        submitter_name_yomi='コーペラティブ\u3000ラボバンク\u3000ウー\u3000アー',
        address='オランダ国\u3000３５２１\u3000ＣＢ\u3000ユトレヒト市クローセラーン１８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05924': EdinetCodeEntry(
        edinet_code='E05924',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=703091,
        fiscal_year_end='12月31日',
        submitter_name='バンク・オブ・チャイナ香港（ホールディングス）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バンク\u3000オブ\u3000チャイナ\u3000ホンコン\u3000ホールディングス\u3000リミテッド',
        address='香港ガーデンロード１、バンク・オブ・チャイナ・タワー５３階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05926': EdinetCodeEntry(
        edinet_code='E05926',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=32855,
        fiscal_year_end='12月31日',
        submitter_name='エドワーズ・ライフサイエンス・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='エドワーズライフサイエンスコーポレーション',
        address='アメリカ合衆国９２６１４カリフォルニア州アーバイン、ワン・エドワーズ・ウェイ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05927': EdinetCodeEntry(
        edinet_code='E05927',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1007600,
        fiscal_year_end='12月末日',
        submitter_name='チャイナ・テレコム・コーポレーション・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナ\u3000テレコム\u3000コーポレーション\u3000リミテッド',
        address='中国北京市西城区金融大街３１号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05928': EdinetCodeEntry(
        edinet_code='E05928',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=309207,
        fiscal_year_end='12月31日',
        submitter_name='エア・リキード・エス・エー（Ｌ’ＡＩＲ\u3000ＬＩＱＵＩＤＥ\u3000Ｓ．Ａ．）',
        submitter_name_en=None,
        submitter_name_yomi='エアリキードエスエー',
        address='フランス共和国７５３２１パリ市７区ケー・ドルセー街７５番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05929': EdinetCodeEntry(
        edinet_code='E05929',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50365,
        fiscal_year_end='3月31日',
        submitter_name='シンガポール・ポスト・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シンガポールポストリミテッド',
        address='１０\u3000ユーノス・ロード\u3000８、シンガポール・ポスト・センター、シンガポール\u3000４０８６００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05931': EdinetCodeEntry(
        edinet_code='E05931',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=218056,
        fiscal_year_end='12月31日',
        submitter_name='チョンホア・テレコム・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チョンホア\u3000テレコム\u3000カンパニー\u3000リミテッド',
        address='台湾台北市信義路１段２１－３号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05933': EdinetCodeEntry(
        edinet_code='E05933',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3151,
        fiscal_year_end='12月31日',
        submitter_name='シンセン・インベストメント・ホールディングス・ベイ・エリア・ディベロップメント・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シンセンインベストメントホールディングスベイエリアディベロップメントカンパニーリミテッド',
        address='香港ワンチャイクイーンズ・ロード・イースト１８３ホープウェル・センター６３階６３－０２室',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05937': EdinetCodeEntry(
        edinet_code='E05937',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=140610,
        fiscal_year_end='12月31日',
        submitter_name='中国人民財産保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクジンミンザイサンホケンカブシキカイシャ',
        address='中国１０００２２北京市朝陽区建国門外大街２号院２号楼',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05940': EdinetCodeEntry(
        edinet_code='E05940',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=410403,
        fiscal_year_end='12月31日',
        submitter_name='チャイナ・ライフ・インシュアランス・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナライフインシュアランスカンパニーリミテッド',
        address='中華人民共和国北京市朝陽区朝陽門外大街１６号中国人寿大厦',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05942': EdinetCodeEntry(
        edinet_code='E05942',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4995,
        fiscal_year_end='12月31日',
        submitter_name='セミコンダクター・マニュファクチュアリング・インターナショナル・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='セミコンダクター\u3000マニュファクチュアリング\u3000インターナショナル\u3000コーポレーション',
        address='ケイマン諸島、ＫＹ１－１１１１、グランドケイマン、私書箱２６８１、ハッチンスドライブ、クリケットスクエア',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05943': EdinetCodeEntry(
        edinet_code='E05943',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=276526,
        fiscal_year_end='12月28日',
        submitter_name='ジョンソン・エンド・ジョンソン',
        submitter_name_en=None,
        submitter_name_yomi='ジョンソンエンドジョンソン',
        address='アメリカ合衆国、ニュージャージー州０８９３３、ニューブランズウィック、ジョンソン・エンド・ジョンソン・プラザ１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05945': EdinetCodeEntry(
        edinet_code='E05945',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=94864,
        fiscal_year_end='12月31日',
        submitter_name='ピンアン・インシュアランス（グループ）カンパニー・オブ・チャイナ・リミテッド（中国平安保険（集団）股フン有限公司）',
        submitter_name_en=None,
        submitter_name_yomi='ピンアンインシュアランスグループカンパニーオブチャイナリミテッド',
        address='中華人民共和国広東省深セン市福田区益田路５０３３号平安金融中心４７、４８、１０９、１１０、１１１及び１１２階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05946': EdinetCodeEntry(
        edinet_code='E05946',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=272137,
        fiscal_year_end='12月31日',
        submitter_name='コスコ・シッピング・ディベロップメント・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='コスコシッピングディベロップメントカンパニーリミテッド',
        address='中華人民共和国上海市自由貿易試験区臨港新片区国貿大厦Ａ－５３８室',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05951': EdinetCodeEntry(
        edinet_code='E05951',
        submitter_type='外国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5,
        fiscal_year_end='12月31日',
        submitter_name='ビート・ホールディングス・リミテッド\u3000（貝德控股有限公司、Ｂｅａｔ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｌｉｍｉｔｅｄ）',
        submitter_name_en=None,
        submitter_name_yomi='ビートホールディングスリミテッド',
        address='ケイマン諸島、ＫＹ１‐１１１１、グランドケイマン、私書箱２６８１、ハッチンスドライブ、クリケットスクウェア',
        industry='情報・通信業',
        sec_code='93990',
        corporate_number=None,
    ),
    'E05954': EdinetCodeEntry(
        edinet_code='E05954',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=0,
        fiscal_year_end='3月31日',
        submitter_name='トヨタ\u3000ファイナンス\u3000オーストラリア\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='トヨタファイナンスオーストラリアリミテッド',
        address='オーストラリア２０００ニューサウスウェールズ州シドニー\u3000ジョージ・ストリート２２５\u3000グロブナー・プレイスレベル７',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05955': EdinetCodeEntry(
        edinet_code='E05955',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1324718,
        fiscal_year_end='12月31日',
        submitter_name='エネル・エスピーエー',
        submitter_name_en=None,
        submitter_name_yomi='エネル\u3000エスピーエー',
        address='Ｖｉａｌｅ\u3000Ｒｅｇｉｎａ\u3000Ｍａｒｇｈｅｒｉｔａ\u3000１３７，Ｒｏｍｅ，Ｉｔａｌｙ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05956': EdinetCodeEntry(
        edinet_code='E05956',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=312756,
        fiscal_year_end='12月31日',
        submitter_name='エア・チャイナ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エアチャイナリミテッド',
        address='中華人民共和国北京市順義区天柱路３０号１号ビル１～９階１０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05958': EdinetCodeEntry(
        edinet_code='E05958',
        submitter_type='外国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='12月31日',
        submitter_name='メディシノバ・インク',
        submitter_name_en=None,
        submitter_name_yomi='メディシノバインク',
        address='米国カリフォルニア州ラ・ホイヤ、スウィート３００、エグゼクティブ・スクエア４２７５',
        industry='医薬品',
        sec_code='48750',
        corporate_number=None,
    ),
    'E05959': EdinetCodeEntry(
        edinet_code='E05959',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5186,
        fiscal_year_end='3月31日',
        submitter_name='インフォシス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='インフォシスリミテッド',
        address='インド共和国、カルナタカ州５６０\u3000１００、バンガロール市、ホースール通りエレクトロニクス・シティ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05960': EdinetCodeEntry(
        edinet_code='E05960',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=39803,
        fiscal_year_end='12月31日',
        submitter_name='現代キャピタル・サービシズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='ヒュンダイ\u3000キャピタル\u3000サービシズ\u3000インク',
        address='大韓民国ソウル特別市中区世宗大路１４',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05961': EdinetCodeEntry(
        edinet_code='E05961',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4913969,
        fiscal_year_end='9月30日',
        submitter_name='オーストラリア・ニュージーランド銀行',
        submitter_name_en=None,
        submitter_name_yomi='オーストラリア\u3000ニュージーランドギンコウ',
        address='ＡＮＺ\u3000Ｃｅｎｔｒｅ\u3000Ｍｅｌｂｏｕｒｎｅ，Ｌｅｖｅｌ\u3000９，\u3000８３３\u3000Ｃｏｌｌｉｎｓ\u3000Ｓｔｒｅｅｔ，\u3000Ｄｏｃｋｌａｎｄｓ，Ｖｉｃｔｏｒｉａ，３００８\u3000Ａｕｓｔｒａｌｉａ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05962': EdinetCodeEntry(
        edinet_code='E05962',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=253126,
        fiscal_year_end='12月31日',
        submitter_name='シャンハイ・エレクトリック・グループ・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シャンハイエレクトリックグループカンパニーリミテッド',
        address='中華人民共和国上海市興義路８号万都中心\u3000３０階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05965': EdinetCodeEntry(
        edinet_code='E05965',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=311670,
        fiscal_year_end='12月31日',
        submitter_name='チャイナ・シェンフア・エナジー・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナシェンフアエナジーカンパニーリミテッド',
        address='中華人民共和国北京市東城区安定門西濱河路２２号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05966': EdinetCodeEntry(
        edinet_code='E05966',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3966,
        fiscal_year_end='11月1日',
        submitter_name='アナログ・デバイセズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アナログデバイセズインク',
        address='アメリカ合衆国\u3000０１８８７\u3000マサチューセッツ州ウィルミントン\u3000ワン・アナログ・ウェイ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05967': EdinetCodeEntry(
        edinet_code='E05967',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=689351,
        fiscal_year_end='12月31日',
        submitter_name='交通銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='コウツウギンコウカブシキユウゲンコウシ',
        address='中華人民共和国中国（上海）自由貿易試験区銀城中路１８８号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05968': EdinetCodeEntry(
        edinet_code='E05968',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=345206,
        fiscal_year_end='12月31日',
        submitter_name='コスコ・シッピング・ホールディングス・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='コスコシッピングホールディングスカンパニーリミテッド',
        address='中華人民共和国天津市天津空港経済区中心大道与東七道交口遠航商務中心１２号２階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05969': EdinetCodeEntry(
        edinet_code='E05969',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=105764,
        fiscal_year_end='12月31日',
        submitter_name='フランス電力',
        submitter_name_en=None,
        submitter_name_yomi='フランスデンリョク',
        address='２２－３０，\u3000ａｖｅｎｕｅ\u3000ｄｅ\u3000Ｗａｇｒａｍ，\u3000Ｐａｒｉｓ，\u3000Ｆｒａｎｃｅ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05970': EdinetCodeEntry(
        edinet_code='E05970',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1820,
        fiscal_year_end='12月31日',
        submitter_name='イーエムシー・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='イーエムシー\u3000コーポレーション',
        address='アメリカ合衆国０１７４８－２２０９マサチューセッツ州ホプキントン\u3000サウス・ストリート１７６',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05972': EdinetCodeEntry(
        edinet_code='E05972',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3092636,
        fiscal_year_end='12月31日',
        submitter_name='中国建設銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクケンセツギンコウグーフェンユウゲンコンス',
        address='中華人民共和国北京市西城區金融大街２５號',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05973': EdinetCodeEntry(
        edinet_code='E05973',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=700000,
        fiscal_year_end='9月30日',
        submitter_name='クアルコム・インコーポレーテッド',
        submitter_name_en=None,
        submitter_name_yomi='クアルコム\u3000インコーポレーテッド',
        address='アメリカ合衆国カリフォルニア州９２１２１サン・ディエゴ、モアハウス・ドライブ５７７５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05974': EdinetCodeEntry(
        edinet_code='E05974',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=120,
        fiscal_year_end='12月31日',
        submitter_name='東風汽車集団股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ドンフェンチィチャージートゥワングーフェンユウゲンコンス',
        address='中華人民共和国湖北省武漢市武漢経済開発区車城北路８号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05975': EdinetCodeEntry(
        edinet_code='E05975',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=23157,
        fiscal_year_end='3月31日',
        submitter_name='アイシーアイシーアイ・バンク・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アイシーアイシーアイ\u3000バンク\u3000リミテッド',
        address='インド国グジャラート州バドダラ市３９０\u3000００７、オールド・パドラ・ロード、ニア・チャクリ・サークル、ＩＣＩＣＩバンクタワー',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05977': EdinetCodeEntry(
        edinet_code='E05977',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ロッテ・ショッピング・カンパニー・リミテッド（Ｌｏｔｔｅ\u3000Ｓｈｏｐｐｉｎｇ\u3000Ｃｏ．，\u3000Ｌｔｄ．）',
        submitter_name_en=None,
        submitter_name_yomi='ロッテショッピングカンパニーリミテッド',
        address='大韓民国ソウル市中区小公洞１番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05978': EdinetCodeEntry(
        edinet_code='E05978',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=9123,
        fiscal_year_end='12月31日',
        submitter_name='ノボ\u3000ノルディスクＡ／Ｓ',
        submitter_name_en=None,
        submitter_name_yomi='ノボ\u3000ノルディスクエーエス',
        address='デンマーク王国バウスヴェア２８８０\u3000ノボ・アレ１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05981': EdinetCodeEntry(
        edinet_code='E05981',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6829761,
        fiscal_year_end='12月31日',
        submitter_name='中国銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクギンコウグーフェンユウゲンコンス',
        address='中華人民共和国１００８１８北京市西城区復興門内大街１号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05982': EdinetCodeEntry(
        edinet_code='E05982',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=358154,
        fiscal_year_end='12月31日',
        submitter_name='バークレイズ・バンク・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='バークレイズバンクピーエルシー',
        address='英国\u3000ロンドン市\u3000Ｅ１４\u3000５ＨＰ\u3000チャーチル・プレイス\u3000１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05986': EdinetCodeEntry(
        edinet_code='E05986',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=415373,
        fiscal_year_end='12月31日',
        submitter_name='招商銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ショウショウギンコウグーフェンユウゲンコンス',
        address='中華人民共和国深セン市福田区深南大道７０８８号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05987': EdinetCodeEntry(
        edinet_code='E05987',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5435207,
        fiscal_year_end='12月31日',
        submitter_name='中国工商銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクコウショウギンコウグーフェンユウゲンコンス',
        address='中華人民共和国１００１４０北京市西城区復興門内大街５５号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05990': EdinetCodeEntry(
        edinet_code='E05990',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='チャイナ・コール・エナジー・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナコールエナジーカンパニーリミテッド',
        address='中華人民共和国北京市朝陽区黄寺大街１号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E05991': EdinetCodeEntry(
        edinet_code='E05991',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=59584,
        fiscal_year_end='12月31日',
        submitter_name='ナットウエスト・マーケッツ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ナットウエストマーケッツピーエルシー',
        address='連合王国ＥＣ２Ｍ\u3000４ＡＡロンドン市ビショップスゲート２５０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05994': EdinetCodeEntry(
        edinet_code='E05994',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1121803,
        fiscal_year_end='12月31日',
        submitter_name='チャイナ・シティック・バンク・コーポレーション・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナシティックバンクコーポレーションリミテッド',
        address='中華人民共和国\u3000北京市朝陽区光華路１０号院１号楼６－３０階、３２－４２階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E05998': EdinetCodeEntry(
        edinet_code='E05998',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1887422,
        fiscal_year_end='10月31日',
        submitter_name='ロイヤル・バンク・オブ・カナダ',
        submitter_name_en=None,
        submitter_name_yomi='ロイヤル\u3000バンク\u3000オブ\u3000カナダ',
        address='Ｈ３Ｃ\u3000３Ａ９\u3000カナダ\u3000ケベック州モントリオール\u3000プレイス・ヴィル・マリー１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E06002': EdinetCodeEntry(
        edinet_code='E06002',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='メキシコ合衆国',
        submitter_name_en=None,
        submitter_name_yomi='メキシコガッシュウコク',
        address='メキシコ合衆国メキシコシティ０１０２０アルバロ・オブレゴン、コロニア・グアダルペ・イン、トーレ３ピソ７、アベニュー・インスルヘンテス・スル１９７１',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06005': EdinetCodeEntry(
        edinet_code='E06005',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2510038,
        fiscal_year_end='12月31日',
        submitter_name='欧州投資銀行',
        submitter_name_en=None,
        submitter_name_yomi='オウシュウトウシギンコウ',
        address='９８－１００，\u3000ｂｏｕｌｅｖａｒｄ\u3000Ｋｏｎｒａｄ\u3000Ａｄｅｎａｕｅｒ，\u3000Ｌ－２９５０\u3000Ｌｕｘｅｍｂｏｕｒｇ',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06009': EdinetCodeEntry(
        edinet_code='E06009',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=921890,
        fiscal_year_end='12月31日',
        submitter_name='韓国産業銀行',
        submitter_name_en=None,
        submitter_name_yomi='カンコクサンギョウギンコウ',
        address='韓国ソウル特別市永登浦区銀行路１４',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06011': EdinetCodeEntry(
        edinet_code='E06011',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='アルゼンチン共和国',
        submitter_name_en=None,
        submitter_name_yomi='アルゼンチンキョウワコク',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06016': EdinetCodeEntry(
        edinet_code='E06016',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60306,
        fiscal_year_end='12月31日',
        submitter_name='オーストリア輸出銀行',
        submitter_name_en=None,
        submitter_name_yomi='オーストリアユシュツギンコウ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06017': EdinetCodeEntry(
        edinet_code='E06017',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=44313,
        fiscal_year_end='12月31日',
        submitter_name='欧州評議会開発銀行',
        submitter_name_en=None,
        submitter_name_yomi='オウシュウヒョウギカイカイハツギンコウ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06020': EdinetCodeEntry(
        edinet_code='E06020',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50553,
        fiscal_year_end='12月末日',
        submitter_name='スウェーデン輸出信用銀行',
        submitter_name_en=None,
        submitter_name_yomi='スウェーデンユシュツシンヨウギンコウ',
        address='スウェーデン\u3000ストックホルム市\u3000１０１\u3000２３\u3000クララベルグスヴィアデュクテン\u3000６１－６３\u3000私書箱１９４',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06021': EdinetCodeEntry(
        edinet_code='E06021',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='中国中信集団有限公司（ＣＩＴＩＣ\u3000Ｇｒｏｕｐ\u3000Ｃｏｒｐｏｒａｔｉｏｎ）',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクチュウシンシュウダンユウゲンコウシ\u3000シティックグループコーポレーション',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06033': EdinetCodeEntry(
        edinet_code='E06033',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='6月30日',
        submitter_name='西オーストラリア州理財公社',
        submitter_name_en=None,
        submitter_name_yomi='ニシオーストラリアシュウリザイコウシャ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06036': EdinetCodeEntry(
        edinet_code='E06036',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='6月30日',
        submitter_name='クイーンズランド州財務公社',
        submitter_name_en=None,
        submitter_name_yomi='クイーンズランドシュウザイムコウシャ',
        address='オーストラリア連邦クイーンズランド州ブリスベン市イーグル・ストリート１１１番地３１階',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06042': EdinetCodeEntry(
        edinet_code='E06042',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=514639,
        fiscal_year_end='12月31日',
        submitter_name='北欧投資銀行',
        submitter_name_en=None,
        submitter_name_yomi='ホクオウトウシギンコウ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06045': EdinetCodeEntry(
        edinet_code='E06045',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1310521,
        fiscal_year_end='12月31日',
        submitter_name='韓国輸出入銀行',
        submitter_name_en=None,
        submitter_name_yomi='カンコクユシュツニュウギンコウ',
        address='韓国０７２４２、ソウル特別市永登浦区ウンヘン路３８',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06047': EdinetCodeEntry(
        edinet_code='E06047',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end='12月末日',
        submitter_name='ドイツ復興金融公庫',
        submitter_name_en=None,
        submitter_name_yomi='ドイツフッコウキンユウコウコ',
        address='ドイツ連邦共和国\u3000６０３２５\u3000フランクフルト・アム・マイン\u3000パルメンガルテンシュトラーセ\u3000５－９',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06052': EdinetCodeEntry(
        edinet_code='E06052',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3175,
        fiscal_year_end='12月31日',
        submitter_name='スウェーデン地方金融公社',
        submitter_name_en=None,
        submitter_name_yomi='スウェーデンチホウキンユウコウシャ',
        address='スウェーデン王国\u3000エーレブロー\u3000ドロットニンガッタン２\u3000フェニックスハウス',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06053': EdinetCodeEntry(
        edinet_code='E06053',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=208850,
        fiscal_year_end='12月31日',
        submitter_name='アンデス開発公社',
        submitter_name_en=None,
        submitter_name_yomi='アンデスカイハツコウシャ',
        address='ベネズエラ、カラカス、アルタミラ、アベニダ・ルイス・ロチェ、トーレＣＡＦ',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06057': EdinetCodeEntry(
        edinet_code='E06057',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=389,
        fiscal_year_end='12月31日',
        submitter_name='チュニジア中央銀行',
        submitter_name_en=None,
        submitter_name_yomi='チュニジアチュウオウギンコウ',
        address='チュニジア共和国、チュニス、へディ・ノウィラ通り２５番',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06061': EdinetCodeEntry(
        edinet_code='E06061',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月末日',
        submitter_name='ウルグアイ東方共和国',
        submitter_name_en=None,
        submitter_name_yomi='ウルグアイトウホウキョウワコク',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06075': EdinetCodeEntry(
        edinet_code='E06075',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=23380,
        fiscal_year_end='12月31日',
        submitter_name='ＢＮＧ銀行Ｎ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌジーギンコウエヌブイ',
        address='Ｂｏｒｄｅｗｉｊｋｌａａｎ\u3000１８，\u3000２５９１\u3000ＸＲ\u3000Ｔｈｅ\u3000Ｈａｇｕｅ，\u3000Ｔｈｅ\u3000Ｎｅｔｈｅｒｌａｎｄｓ',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06087': EdinetCodeEntry(
        edinet_code='E06087',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='フィンランド地方金融公社',
        submitter_name_en=None,
        submitter_name_yomi='フィンランドチホウキンユウコウシャ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06100': EdinetCodeEntry(
        edinet_code='E06100',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='スペイン開発金融公庫',
        submitter_name_en=None,
        submitter_name_yomi='スペインカイハツキンユウコウコ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06104': EdinetCodeEntry(
        edinet_code='E06104',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ノルウェー地方金融公社',
        submitter_name_en=None,
        submitter_name_yomi='ノルウェーチホウキンユウコウシャ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06106': EdinetCodeEntry(
        edinet_code='E06106',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ポーランド共和国',
        submitter_name_en=None,
        submitter_name_yomi='ポーランドキョウワコク',
        address='００－９１６ポーランド共和国ワルシャワ市シフィエントクシスキ通り１２',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06107': EdinetCodeEntry(
        edinet_code='E06107',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月末日',
        submitter_name='デンマーク地方金融公庫',
        submitter_name_en=None,
        submitter_name_yomi='デンマークチホウキンユウコウコ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06108': EdinetCodeEntry(
        edinet_code='E06108',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ハンガリー',
        submitter_name_en=None,
        submitter_name_yomi='ハンガリー',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06110': EdinetCodeEntry(
        edinet_code='E06110',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=36400,
        fiscal_year_end='3月末日',
        submitter_name='インド輸出入銀行',
        submitter_name_en=None,
        submitter_name_yomi='インドユシュツニュウギンコウ',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06111': EdinetCodeEntry(
        edinet_code='E06111',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='中米経済統合銀行',
        submitter_name_en=None,
        submitter_name_yomi='チュウベイケイザイトウゴウギンコウ',
        address='ホンジュラス共和国、テグシガルパ、サジャパ通り、ＢＣＩＥ・エディフィシオ・スド',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06115': EdinetCodeEntry(
        edinet_code='E06115',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='予防接種のための国際金融ファシリティ（ＩＦＦＩｍ）',
        submitter_name_en=None,
        submitter_name_yomi='ヨボウセッシュノタメノコクサイキンユウファシリティイフィム',
        address=None,
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E06121': EdinetCodeEntry(
        edinet_code='E06121',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=948,
        fiscal_year_end=None,
        submitter_name='ネスナ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='ネスナ\u3000エルエルピー',
        address='英国ＷＣ２Ｈ９ＥＡロンドン、アッパー・セントマーティンズ・レーン５、オリオン・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06125': EdinetCodeEntry(
        edinet_code='E06125',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1450000,
        fiscal_year_end=None,
        submitter_name='日本生命保険相互会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイ',
        address='大阪市中央区今橋三丁目５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120005007273',
    ),
    'E06130': EdinetCodeEntry(
        edinet_code='E06130',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=257000,
        fiscal_year_end=None,
        submitter_name='朝日生命保険相互会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒセイメイホケンソウゴカイシャ',
        address='新宿区四谷一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005008201',
    ),
    'E06133': EdinetCodeEntry(
        edinet_code='E06133',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ブランデス・インベストメント・パートナーズ・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='ブランデスインベストメントパートナーズエルピー',
        address='アメリカ合衆国、カリフォルニア州、ラホーヤ、エグゼクティブ・スクエア４２７５、５階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06134': EdinetCodeEntry(
        edinet_code='E06134',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=639000,
        fiscal_year_end=None,
        submitter_name='住友生命保険相互会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイホケンソウゴガイシャ',
        address='大阪市中央区城見１丁目４番３５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120005007271',
    ),
    'E06139': EdinetCodeEntry(
        edinet_code='E06139',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=580,
        fiscal_year_end=None,
        submitter_name='三信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンシンカブシキガイシャ',
        address='中央区八丁堀二丁目２５番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011101007720',
    ),
    'E06141': EdinetCodeEntry(
        edinet_code='E06141',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=344698,
        fiscal_year_end='3月31日',
        submitter_name='第一生命ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイイチセイメイホールディングスカブシキガイシャ',
        address='千代田区有楽町一丁目１３番１号',
        industry='保険業',
        sec_code='87500',
        corporate_number='8010001131752',
    ),
    'E06167': EdinetCodeEntry(
        edinet_code='E06167',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='城北興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジョウホクコウギョウカブシキガイシャ',
        address='渋谷区東２丁目５番３８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001010918',
    ),
    'E06176': EdinetCodeEntry(
        edinet_code='E06176',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村上\u3000三郎',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000サブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06191': EdinetCodeEntry(
        edinet_code='E06191',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田辺よし江',
        submitter_name_en=None,
        submitter_name_yomi='タナベヨシエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06223': EdinetCodeEntry(
        edinet_code='E06223',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000実',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06228': EdinetCodeEntry(
        edinet_code='E06228',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100000,
        fiscal_year_end='3月31日',
        submitter_name='大和証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイワショウケンカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='9010001063235',
    ),
    'E06234': EdinetCodeEntry(
        edinet_code='E06234',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='タワー投資顧問株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タワートウシコモンカブシキカイシャ',
        address='港区芝大門１丁目２番１８号野依ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401034513',
    ),
    'E06241': EdinetCodeEntry(
        edinet_code='E06241',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=441358,
        fiscal_year_end=None,
        submitter_name='アライアンス・バーンスタイン・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='アライアンスバーンスタインエルピー',
        address='アメリカ合衆国、テネシー州、ナッシュビル、コマース・ストリート５０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06249': EdinetCodeEntry(
        edinet_code='E06249',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30000,
        fiscal_year_end=None,
        submitter_name='伊藤忠丸紅鉄鋼株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イトウチュウマルベニテッコウカブシキガイシャ',
        address='中央区八重洲二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001075892',
    ),
    'E06264': EdinetCodeEntry(
        edinet_code='E06264',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2218,
        fiscal_year_end=None,
        submitter_name='ＪＰモルガン・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェーピーモルガンアセットマネジメントカブシキガイシャ',
        address='千代田区丸の内二丁目７番３号\u3000東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001098507',
    ),
    'E06267': EdinetCodeEntry(
        edinet_code='E06267',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1235,
        fiscal_year_end=None,
        submitter_name='キャピタル・リサーチ・アンド・マネージメント・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='キャピタルリサーチアンドマネージメントカンパニー',
        address='アメリカ合衆国カリフォルニア州、ロスアンジェルス、サウスホープ・ストリート３３３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06278': EdinetCodeEntry(
        edinet_code='E06278',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙松多聞',
        submitter_name_en=None,
        submitter_name_yomi='タカマツタモン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06283': EdinetCodeEntry(
        edinet_code='E06283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='峯栄興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホウエイコウギョウカブシキガイシャ',
        address='千代田区神田神保町３丁目２番地７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001029235',
    ),
    'E06291': EdinetCodeEntry(
        edinet_code='E06291',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石垣\u3000裕義',
        submitter_name_en=None,
        submitter_name_yomi='イシガキ\u3000ヒロヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06295': EdinetCodeEntry(
        edinet_code='E06295',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和山\u3000明弘',
        submitter_name_en=None,
        submitter_name_yomi='カズヤマ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06297': EdinetCodeEntry(
        edinet_code='E06297',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福井\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06318': EdinetCodeEntry(
        edinet_code='E06318',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000宗徳',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ムネノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06321': EdinetCodeEntry(
        edinet_code='E06321',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西川\u3000啓子',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06327': EdinetCodeEntry(
        edinet_code='E06327',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=136000,
        fiscal_year_end=None,
        submitter_name='富国生命保険相互会社',
        submitter_name_en=None,
        submitter_name_yomi='フコクセイメイホケンソウゴガイシャ',
        address='千代田区内幸町２丁目２－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005003959',
    ),
    'E06332': EdinetCodeEntry(
        edinet_code='E06332',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ファースト・イーグル・インベストメント・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ファースト\u3000イーグル\u3000インベストメント\u3000マネジメント\u3000エルエルシー',
        address='アメリカ合衆国ニューヨーク州ニューヨーク市アベニュー・オブ・ジ・アメリカズ１３４５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06335': EdinetCodeEntry(
        edinet_code='E06335',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ユニマットライフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャユニマットライフ',
        address='港区南青山二丁目１２番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401030487',
    ),
    'E06339': EdinetCodeEntry(
        edinet_code='E06339',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='株式会社エルガみらい研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエルガミライケンキュウショ',
        address='渋谷区恵比寿２－３１－５－９０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401025420',
    ),
    'E06369': EdinetCodeEntry(
        edinet_code='E06369',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=880000,
        fiscal_year_end=None,
        submitter_name='明治安田生命保険相互会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイホケンソウゴガイシャ',
        address='千代田区丸の内２丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005007932',
    ),
    'E06375': EdinetCodeEntry(
        edinet_code='E06375',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井村守宏',
        submitter_name_en=None,
        submitter_name_yomi='イムラモリヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06381': EdinetCodeEntry(
        edinet_code='E06381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横川\u3000紀夫',
        submitter_name_en=None,
        submitter_name_yomi='ヨコカワ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06393': EdinetCodeEntry(
        edinet_code='E06393',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='朝日重剛',
        submitter_name_en=None,
        submitter_name_yomi='アサヒジュウゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06394': EdinetCodeEntry(
        edinet_code='E06394',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本政敬',
        submitter_name_en=None,
        submitter_name_yomi='マツモトマサヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06400': EdinetCodeEntry(
        edinet_code='E06400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000茂夫',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000シゲオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06413': EdinetCodeEntry(
        edinet_code='E06413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='速水\u3000浩二',
        submitter_name_en=None,
        submitter_name_yomi='ハヤミ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06433': EdinetCodeEntry(
        edinet_code='E06433',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='東京海上アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウカイジョウアセットマネジメントカブシキガイシャ',
        address='千代田区丸の内１丁目８番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001034076',
    ),
    'E06449': EdinetCodeEntry(
        edinet_code='E06449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26,
        fiscal_year_end=None,
        submitter_name='株式会社光和',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウワ',
        address='練馬区中村北３丁目４番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011601002218',
    ),
    'E06450': EdinetCodeEntry(
        edinet_code='E06450',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000實',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06452': EdinetCodeEntry(
        edinet_code='E06452',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='毒島\u3000秀行',
        submitter_name_en=None,
        submitter_name_yomi='ブスジマ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06458': EdinetCodeEntry(
        edinet_code='E06458',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3078,
        fiscal_year_end=None,
        submitter_name='ドイチェ・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ドイチェ\u3000アセット\u3000マネジメント\u3000カブシキガイシャ',
        address='港区麻布台一丁目３番１号\u3000麻布台ヒルズ森ＪＰタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001024529',
    ),
    'E06459': EdinetCodeEntry(
        edinet_code='E06459',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=47458,
        fiscal_year_end=None,
        submitter_name='ユービーエス・エイ・ジー（銀行）',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエス\u3000エイ\u3000ジー\u3000ギンコウ',
        address='千代田区大手町１丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2700150002748',
    ),
    'E06461': EdinetCodeEntry(
        edinet_code='E06461',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='テンプルトン・インベストメント・カウンセル・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='テンプルトンインベストメントカウンセルエルエルシー',
        address='アメリカ合衆国\u3000３３３０１、フロリダ州、フォート・ローダデイル、セカンドストリート、サウスイースト３００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06470': EdinetCodeEntry(
        edinet_code='E06470',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ジヤパンソフアルシム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンソファルシムカブシキガイシャ',
        address='千代田区岩本町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001019192',
    ),
    'E06477': EdinetCodeEntry(
        edinet_code='E06477',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98768,
        fiscal_year_end=None,
        submitter_name='ＢｏｆＡ証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーオブエーショウケンカブシキガイシャ',
        address='中央区日本橋一丁目４番１号日本橋一丁目三井ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001030858',
    ),
    'E06479': EdinetCodeEntry(
        edinet_code='E06479',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4000,
        fiscal_year_end=None,
        submitter_name='インベスコ・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インベスコアセットマネジメントカブシキガイシャ',
        address='港区六本木六丁目１０番１号\u3000六本木ヒルズ森タワー１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401061146',
    ),
    'E06480': EdinetCodeEntry(
        edinet_code='E06480',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='新業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンギョウカブシキガイシャ',
        address='千代田区四番町２番地１クレール東郷坂４０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401084616',
    ),
    'E06481': EdinetCodeEntry(
        edinet_code='E06481',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='荻原\u3000年',
        submitter_name_en=None,
        submitter_name_yomi='オギハラ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06485': EdinetCodeEntry(
        edinet_code='E06485',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17180,
        fiscal_year_end=None,
        submitter_name='野村アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラアセットマネジメントカブシキガイシャ',
        address='江東区豊洲二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001054021',
    ),
    'E06498': EdinetCodeEntry(
        edinet_code='E06498',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉浦\u3000求',
        submitter_name_en=None,
        submitter_name_yomi='スギウラ\u3000モトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06502': EdinetCodeEntry(
        edinet_code='E06502',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='沖津\u3000弘之',
        submitter_name_en=None,
        submitter_name_yomi='オキツ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06528': EdinetCodeEntry(
        edinet_code='E06528',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000正輝',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000マサテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06532': EdinetCodeEntry(
        edinet_code='E06532',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前田耕作',
        submitter_name_en=None,
        submitter_name_yomi='マエダコウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06533': EdinetCodeEntry(
        edinet_code='E06533',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='赤澤\u3000庄三',
        submitter_name_en=None,
        submitter_name_yomi='アカザワ\u3000ショウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06556': EdinetCodeEntry(
        edinet_code='E06556',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河本太郎',
        submitter_name_en=None,
        submitter_name_yomi='カワモトタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06560': EdinetCodeEntry(
        edinet_code='E06560',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='シグマ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シグマカブシキガイシャ',
        address='港区南麻布４丁目１０番２号\u3000ホーマットアンバサダー４２０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401013003',
    ),
    'E06567': EdinetCodeEntry(
        edinet_code='E06567',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平田\u3000晴久',
        submitter_name_en=None,
        submitter_name_yomi='ヒラタ\u3000ハルヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06581': EdinetCodeEntry(
        edinet_code='E06581',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100000,
        fiscal_year_end=None,
        submitter_name='株式会社メタルワン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメタルワン',
        address='千代田区丸の内二丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401049321',
    ),
    'E06584': EdinetCodeEntry(
        edinet_code='E06584',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='財務大臣',
        submitter_name_en=None,
        submitter_name_yomi='ザイムダイジン',
        address='千代田区霞が関３‐１‐１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8000012050001',
    ),
    'E06591': EdinetCodeEntry(
        edinet_code='E06591',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大畑\u3000榮一',
        submitter_name_en=None,
        submitter_name_yomi='オオハタ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06625': EdinetCodeEntry(
        edinet_code='E06625',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奈迫昭子',
        submitter_name_en=None,
        submitter_name_yomi='ナセコアキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06629': EdinetCodeEntry(
        edinet_code='E06629',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舩木\u3000元旦',
        submitter_name_en=None,
        submitter_name_yomi='フナキ\u3000モトカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06630': EdinetCodeEntry(
        edinet_code='E06630',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06637': EdinetCodeEntry(
        edinet_code='E06637',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000昭夫',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06648': EdinetCodeEntry(
        edinet_code='E06648',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二村\u3000昭二',
        submitter_name_en=None,
        submitter_name_yomi='フタムラ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06668': EdinetCodeEntry(
        edinet_code='E06668',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='片山貴雄',
        submitter_name_en=None,
        submitter_name_yomi='カタヤマタカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06676': EdinetCodeEntry(
        edinet_code='E06676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＴＣＳホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーシーエスホールディングスカブシキガイシャ',
        address='中央区日本橋本町四丁目８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001034154',
    ),
    'E06683': EdinetCodeEntry(
        edinet_code='E06683',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永守重信',
        submitter_name_en=None,
        submitter_name_yomi='ナガモリシゲノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06699': EdinetCodeEntry(
        edinet_code='E06699',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇野澤\u3000虎雄',
        submitter_name_en=None,
        submitter_name_yomi='ウノザワ\u3000トラオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06718': EdinetCodeEntry(
        edinet_code='E06718',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='日本鉱泉株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンコウセンカブシキガイシャ',
        address='広島市安佐南区緑井六丁目２４―２２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7240001008045',
    ),
    'E06719': EdinetCodeEntry(
        edinet_code='E06719',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='北村\u3000精男',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06731': EdinetCodeEntry(
        edinet_code='E06731',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2950,
        fiscal_year_end=None,
        submitter_name='三菱ＵＦＪキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシユーエフジェーキャピタルカブシキカイシャ',
        address='中央区日本橋２丁目３番４号\u3000日本橋プラザビル７Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001022150',
    ),
    'E06732': EdinetCodeEntry(
        edinet_code='E06732',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伏島\u3000靖豊',
        submitter_name_en=None,
        submitter_name_yomi='フセジマ\u3000ヤストヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06736': EdinetCodeEntry(
        edinet_code='E06736',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＯＤＥＮホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウデンホールディングス',
        address='大田区多摩川二丁目１３番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010801003799',
    ),
    'E06748': EdinetCodeEntry(
        edinet_code='E06748',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41424,
        fiscal_year_end=None,
        submitter_name='大和アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイワアセットマネジメントカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001049257',
    ),
    'E06754': EdinetCodeEntry(
        edinet_code='E06754',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹内敏也',
        submitter_name_en=None,
        submitter_name_yomi='タケウチトシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06757': EdinetCodeEntry(
        edinet_code='E06757',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1800,
        fiscal_year_end=None,
        submitter_name='ＴＳＵＣＨＩＹＡ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤカブシキガイシャ',
        address='大垣市神田町２丁目５５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2200001013986',
    ),
    'E06761': EdinetCodeEntry(
        edinet_code='E06761',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12000,
        fiscal_year_end=None,
        submitter_name='大和ＰＩパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイワピーアイパートナーズカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001075595',
    ),
    'E06779': EdinetCodeEntry(
        edinet_code='E06779',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市川周作',
        submitter_name_en=None,
        submitter_name_yomi='イチカワシュウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06783': EdinetCodeEntry(
        edinet_code='E06783',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若土\u3000征男',
        submitter_name_en=None,
        submitter_name_yomi='ワカツチ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06786': EdinetCodeEntry(
        edinet_code='E06786',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原田修一',
        submitter_name_en=None,
        submitter_name_yomi='ハラダシュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06788': EdinetCodeEntry(
        edinet_code='E06788',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='船井\u3000哲雄',
        submitter_name_en=None,
        submitter_name_yomi='フナイ\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06825': EdinetCodeEntry(
        edinet_code='E06825',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000ローム\u3000ミュージック\u3000ファンデーション',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000ローム\u3000ミュージック\u3000ファンデーション',
        address='京都市右京区西院西溝崎町４４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130005012219',
    ),
    'E06832': EdinetCodeEntry(
        edinet_code='E06832',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='金子真人ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カネコマコトホールディングスカブシキガイシャ',
        address='大田区田園調布三丁目２３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010801001796',
    ),
    'E06834': EdinetCodeEntry(
        edinet_code='E06834',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='滝崎\u3000武光',
        submitter_name_en=None,
        submitter_name_yomi='タキザキ\u3000タケミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06854': EdinetCodeEntry(
        edinet_code='E06854',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福島\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06902': EdinetCodeEntry(
        edinet_code='E06902',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='進藤\u3000晶弘',
        submitter_name_en=None,
        submitter_name_yomi='シンドウ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06907': EdinetCodeEntry(
        edinet_code='E06907',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='児嶋\u3000雄二',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06913': EdinetCodeEntry(
        edinet_code='E06913',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯塚\u3000哲哉',
        submitter_name_en=None,
        submitter_name_yomi='イイヅカ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06928': EdinetCodeEntry(
        edinet_code='E06928',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笠原\u3000康人',
        submitter_name_en=None,
        submitter_name_yomi='カサハラ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06931': EdinetCodeEntry(
        edinet_code='E06931',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栢森\u3000秀行',
        submitter_name_en=None,
        submitter_name_yomi='カヤモリ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06935': EdinetCodeEntry(
        edinet_code='E06935',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村口\u3000和孝',
        submitter_name_en=None,
        submitter_name_yomi='ムラグチ\u3000カズタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06942': EdinetCodeEntry(
        edinet_code='E06942',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=321,
        fiscal_year_end=None,
        submitter_name='緑屋電気株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミドリヤデンキカブシキガイシャ',
        address='中央区日本橋室町１－２－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001058548',
    ),
    'E06979': EdinetCodeEntry(
        edinet_code='E06979',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池俊嗣',
        submitter_name_en=None,
        submitter_name_yomi='キクチトシツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E06989': EdinetCodeEntry(
        edinet_code='E06989',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='市野\u3000諮',
        submitter_name_en=None,
        submitter_name_yomi='イチノ\u3000ハカル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07002': EdinetCodeEntry(
        edinet_code='E07002',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49,
        fiscal_year_end=None,
        submitter_name='株式会社三井クリエイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミツイクリエイト',
        address='北九州市八幡西区千代１丁目２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290801010662',
    ),
    'E07009': EdinetCodeEntry(
        edinet_code='E07009',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福田\u3000孝太郎',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07015': EdinetCodeEntry(
        edinet_code='E07015',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保木\u3000將夫',
        submitter_name_en=None,
        submitter_name_yomi='ホキマサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07031': EdinetCodeEntry(
        edinet_code='E07031',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久保\u3000哲夫',
        submitter_name_en=None,
        submitter_name_yomi='クボ\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07033': EdinetCodeEntry(
        edinet_code='E07033',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田島\u3000秀二',
        submitter_name_en=None,
        submitter_name_yomi='タジマ\u3000ヒデジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07036': EdinetCodeEntry(
        edinet_code='E07036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松谷\u3000貫司',
        submitter_name_en=None,
        submitter_name_yomi='マツタニ\u3000カンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07037': EdinetCodeEntry(
        edinet_code='E07037',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松谷\u3000正光',
        submitter_name_en=None,
        submitter_name_yomi='マツタニ\u3000マサミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07039': EdinetCodeEntry(
        edinet_code='E07039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='床次\u3000隆志',
        submitter_name_en=None,
        submitter_name_yomi='トコナミ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07051': EdinetCodeEntry(
        edinet_code='E07051',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横田\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ヨコタ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07056': EdinetCodeEntry(
        edinet_code='E07056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市川\u3000典男',
        submitter_name_en=None,
        submitter_name_yomi='イチカワ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07059': EdinetCodeEntry(
        edinet_code='E07059',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='酒井\u3000眞一',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07064': EdinetCodeEntry(
        edinet_code='E07064',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000恭介',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000キョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07065': EdinetCodeEntry(
        edinet_code='E07065',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000憲司',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07076': EdinetCodeEntry(
        edinet_code='E07076',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000重夫',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000シゲオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07078': EdinetCodeEntry(
        edinet_code='E07078',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社加納アネシス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカノウアネシス',
        address='小松市白江町ヨ２７８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4220001012943',
    ),
    'E07098': EdinetCodeEntry(
        edinet_code='E07098',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社マサトヨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマサトヨ',
        address='千代田区四番町４ー６ー４０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011301006633',
    ),
    'E07120': EdinetCodeEntry(
        edinet_code='E07120',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='里見\u3000治',
        submitter_name_en=None,
        submitter_name_yomi='サトミ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07141': EdinetCodeEntry(
        edinet_code='E07141',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='一広株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イチヒロカブシキガイシャ',
        address='今治市八町西４丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1500001011127',
    ),
    'E07159': EdinetCodeEntry(
        edinet_code='E07159',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西條徳三',
        submitter_name_en=None,
        submitter_name_yomi='サイジョウトクゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07160': EdinetCodeEntry(
        edinet_code='E07160',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三谷\u3000充',
        submitter_name_en=None,
        submitter_name_yomi='ミタニ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07161': EdinetCodeEntry(
        edinet_code='E07161',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三谷\u3000美智子',
        submitter_name_en=None,
        submitter_name_yomi='ミタニ\u3000ミチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07194': EdinetCodeEntry(
        edinet_code='E07194',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='吉野石膏株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノセッコウカブシキガイシャ',
        address='千代田区丸の内三丁目３番１号\u3000新東京ビル内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001031687',
    ),
    'E07204': EdinetCodeEntry(
        edinet_code='E07204',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='有限会社高田興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャタカダコウサン',
        address='足立区千住緑町２－８－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011802015297',
    ),
    'E07207': EdinetCodeEntry(
        edinet_code='E07207',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田口\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='タグチ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07214': EdinetCodeEntry(
        edinet_code='E07214',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='孫\u3000正義',
        submitter_name_en=None,
        submitter_name_yomi='ソン\u3000マサヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07223': EdinetCodeEntry(
        edinet_code='E07223',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000正之',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07229': EdinetCodeEntry(
        edinet_code='E07229',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武内\u3000徳夫',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07236': EdinetCodeEntry(
        edinet_code='E07236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤登\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='サワノボリ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07237': EdinetCodeEntry(
        edinet_code='E07237',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤登\u3000辰郎',
        submitter_name_en=None,
        submitter_name_yomi='サワノボリ\u3000タツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07242': EdinetCodeEntry(
        edinet_code='E07242',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松田芳明',
        submitter_name_en=None,
        submitter_name_yomi='マツダヨシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07251': EdinetCodeEntry(
        edinet_code='E07251',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井内\u3000英夫',
        submitter_name_en=None,
        submitter_name_yomi='イウチ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07255': EdinetCodeEntry(
        edinet_code='E07255',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下島\u3000謙司',
        submitter_name_en=None,
        submitter_name_yomi='シモジマ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07266': EdinetCodeEntry(
        edinet_code='E07266',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ワイエムピー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイエムピー',
        address='大阪市中央区北久宝寺町２－４－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001092530',
    ),
    'E07284': EdinetCodeEntry(
        edinet_code='E07284',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社ハット企画',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャハットキカク',
        address='江戸川区南小岩３丁目７番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010902024209',
    ),
    'E07286': EdinetCodeEntry(
        edinet_code='E07286',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000啓介',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07288': EdinetCodeEntry(
        edinet_code='E07288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋忠仁',
        submitter_name_en=None,
        submitter_name_yomi='タカハシタダヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07291': EdinetCodeEntry(
        edinet_code='E07291',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='羽鳥\u3000貴夫',
        submitter_name_en=None,
        submitter_name_yomi='ハトリ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07295': EdinetCodeEntry(
        edinet_code='E07295',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉崇史',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベタカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07304': EdinetCodeEntry(
        edinet_code='E07304',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村井史郎',
        submitter_name_en=None,
        submitter_name_yomi='ムライシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07305': EdinetCodeEntry(
        edinet_code='E07305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000秀吉',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ヒデヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07312': EdinetCodeEntry(
        edinet_code='E07312',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡村\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='オカムラ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07313': EdinetCodeEntry(
        edinet_code='E07313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永津邦彦',
        submitter_name_en=None,
        submitter_name_yomi='ナガツクニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07316': EdinetCodeEntry(
        edinet_code='E07316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000良一',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07321': EdinetCodeEntry(
        edinet_code='E07321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=76,
        fiscal_year_end=None,
        submitter_name='株式会社マスプ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマスプ',
        address='岡山市北区伊福町三丁目２３番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6260001007657',
    ),
    'E07324': EdinetCodeEntry(
        edinet_code='E07324',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=59,
        fiscal_year_end=None,
        submitter_name='株式会社ベニア商会',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャベニアショウカイ',
        address='大田区下丸子４丁目２７番２－５０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401089473',
    ),
    'E07327': EdinetCodeEntry(
        edinet_code='E07327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅崎\u3000興生',
        submitter_name_en=None,
        submitter_name_yomi='ウメザキ\u3000コウセイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07351': EdinetCodeEntry(
        edinet_code='E07351',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森下\u3000篤史',
        submitter_name_en=None,
        submitter_name_yomi='モリシタ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07361': EdinetCodeEntry(
        edinet_code='E07361',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30000,
        fiscal_year_end=None,
        submitter_name='森トラスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モリトラストカブシキカイシャ',
        address='港区虎ノ門４－１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401029670',
    ),
    'E07374': EdinetCodeEntry(
        edinet_code='E07374',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=31475,
        fiscal_year_end=None,
        submitter_name='預金保険機構',
        submitter_name_en=None,
        submitter_name_yomi='ヨキンホケンキコウ',
        address='千代田区大手町一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005002591',
    ),
    'E07419': EdinetCodeEntry(
        edinet_code='E07419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青木擴憲',
        submitter_name_en=None,
        submitter_name_yomi='アオキヒロノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07422': EdinetCodeEntry(
        edinet_code='E07422',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大桑いく嗣',
        submitter_name_en=None,
        submitter_name_yomi='オオクワイクジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07423': EdinetCodeEntry(
        edinet_code='E07423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大桑啓嗣',
        submitter_name_en=None,
        submitter_name_yomi='オオクワケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07433': EdinetCodeEntry(
        edinet_code='E07433',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='株式会社川野商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカワノショウジ',
        address='川越市新宿町一丁目１０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7030002080270',
    ),
    'E07445': EdinetCodeEntry(
        edinet_code='E07445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000裕一',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07450': EdinetCodeEntry(
        edinet_code='E07450',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5300,
        fiscal_year_end=None,
        submitter_name='株式会社テックプランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテックプランニング',
        address='高崎市栄町１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2070001003811',
    ),
    'E07465': EdinetCodeEntry(
        edinet_code='E07465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関戸\u3000正実',
        submitter_name_en=None,
        submitter_name_yomi='セキド\u3000マサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07480': EdinetCodeEntry(
        edinet_code='E07480',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩崎\u3000裕文',
        submitter_name_en=None,
        submitter_name_yomi='イワサキ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07515': EdinetCodeEntry(
        edinet_code='E07515',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤\u3000薫徳',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000シゲノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07538': EdinetCodeEntry(
        edinet_code='E07538',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安野\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='ヤスノ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07543': EdinetCodeEntry(
        edinet_code='E07543',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='治山\u3000正史',
        submitter_name_en=None,
        submitter_name_yomi='ハルヤマ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07544': EdinetCodeEntry(
        edinet_code='E07544',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='治山\u3000正次',
        submitter_name_en=None,
        submitter_name_yomi='ハルヤマ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07549': EdinetCodeEntry(
        edinet_code='E07549',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野島隆久',
        submitter_name_en=None,
        submitter_name_yomi='ノジマタカヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07553': EdinetCodeEntry(
        edinet_code='E07553',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤原政博',
        submitter_name_en=None,
        submitter_name_yomi='フジワラマサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07566': EdinetCodeEntry(
        edinet_code='E07566',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000ローズエージェンシー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャ\u3000ローズエージェンシー',
        address='市川市八幡３－２３－１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401031949',
    ),
    'E07572': EdinetCodeEntry(
        edinet_code='E07572',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='疋田耕造',
        submitter_name_en=None,
        submitter_name_yomi='ヒキタコウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07573': EdinetCodeEntry(
        edinet_code='E07573',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='疋田直太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヒキダナオタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07580': EdinetCodeEntry(
        edinet_code='E07580',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社安隆商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアンリュウショウジ',
        address='千代田区麹町一丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2013201016233',
    ),
    'E07581': EdinetCodeEntry(
        edinet_code='E07581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000朝',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ハヤシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07601': EdinetCodeEntry(
        edinet_code='E07601',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='新井田\u3000傳',
        submitter_name_en=None,
        submitter_name_yomi='ニイダ\u3000ツタエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07618': EdinetCodeEntry(
        edinet_code='E07618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅野\u3000重俊',
        submitter_name_en=None,
        submitter_name_yomi='ウメノ\u3000シゲトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07624': EdinetCodeEntry(
        edinet_code='E07624',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋均',
        submitter_name_en=None,
        submitter_name_yomi='タカハシヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07625': EdinetCodeEntry(
        edinet_code='E07625',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神田\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='カンダ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07631': EdinetCodeEntry(
        edinet_code='E07631',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蔵人金男',
        submitter_name_en=None,
        submitter_name_yomi='クロウドカネオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07645': EdinetCodeEntry(
        edinet_code='E07645',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田悦弘',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07647': EdinetCodeEntry(
        edinet_code='E07647',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田祐次',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダスケツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07649': EdinetCodeEntry(
        edinet_code='E07649',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水秀雄',
        submitter_name_en=None,
        submitter_name_yomi='シミズヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07653': EdinetCodeEntry(
        edinet_code='E07653',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西川\u3000猛',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000タケル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07655': EdinetCodeEntry(
        edinet_code='E07655',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三ッ田\u3000勝規',
        submitter_name_en=None,
        submitter_name_yomi='ミッタ\u3000マサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07660': EdinetCodeEntry(
        edinet_code='E07660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000友康',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000トモヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07675': EdinetCodeEntry(
        edinet_code='E07675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本善政',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモトヨシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07713': EdinetCodeEntry(
        edinet_code='E07713',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯田\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='イイダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07718': EdinetCodeEntry(
        edinet_code='E07718',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平岡史生',
        submitter_name_en=None,
        submitter_name_yomi='ヒラオカフミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07720': EdinetCodeEntry(
        edinet_code='E07720',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社トーランス・ジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトーランスジャパン',
        address='大阪市西区北堀江２丁目１１番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001120604',
    ),
    'E07721': EdinetCodeEntry(
        edinet_code='E07721',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本村昌次',
        submitter_name_en=None,
        submitter_name_yomi='モトムラマサツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07725': EdinetCodeEntry(
        edinet_code='E07725',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000利行',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07733': EdinetCodeEntry(
        edinet_code='E07733',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000國春',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000クニハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07744': EdinetCodeEntry(
        edinet_code='E07744',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平林\u3000実',
        submitter_name_en=None,
        submitter_name_yomi='ヒラバヤシ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07754': EdinetCodeEntry(
        edinet_code='E07754',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12000,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000整理回収機構',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000セイリカイシュウキコウ',
        address='千代田区丸の内３丁目４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011201002545',
    ),
    'E07786': EdinetCodeEntry(
        edinet_code='E07786',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=603,
        fiscal_year_end=None,
        submitter_name='ハリス・アソシエイツ・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='ハリスアソシエイツエルピー',
        address='６０６０６、アメリカ合衆国イリノイ州シカゴ市スィート４６００、サウスワッカードライブ１１１番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07789': EdinetCodeEntry(
        edinet_code='E07789',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1015,
        fiscal_year_end=None,
        submitter_name='野村土地建物株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラトチタテモノカブシキガイシャ',
        address='中央区日本橋本町１－７－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001054024',
    ),
    'E07790': EdinetCodeEntry(
        edinet_code='E07790',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社巽也蔵',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタツミヤグラ',
        address='港区南青山６－８－１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401044480',
    ),
    'E07791': EdinetCodeEntry(
        edinet_code='E07791',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本\u3000大',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000オオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07795': EdinetCodeEntry(
        edinet_code='E07795',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松井\u3000道夫',
        submitter_name_en=None,
        submitter_name_yomi='マツイ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07801': EdinetCodeEntry(
        edinet_code='E07801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リクルートホールディングス',
        submitter_name_en='Recruit Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャリクルートホールディングス',
        address='千代田区丸の内１－９－２',
        industry='サービス業',
        sec_code='60980',
        corporate_number='5010001060426',
    ),
    'E07812': EdinetCodeEntry(
        edinet_code='E07812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙杉\u3000仁',
        submitter_name_en=None,
        submitter_name_yomi='タカスギ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07825': EdinetCodeEntry(
        edinet_code='E07825',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神山\u3000和郎',
        submitter_name_en=None,
        submitter_name_yomi='カミヤマ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07827': EdinetCodeEntry(
        edinet_code='E07827',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前田\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07836': EdinetCodeEntry(
        edinet_code='E07836',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西河\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07839': EdinetCodeEntry(
        edinet_code='E07839',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村山\u3000義男',
        submitter_name_en=None,
        submitter_name_yomi='ムラヤマ\u3000ヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07840': EdinetCodeEntry(
        edinet_code='E07840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西岡\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='ニシオカ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07846': EdinetCodeEntry(
        edinet_code='E07846',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=102000,
        fiscal_year_end='3月31日',
        submitter_name='森ビル株式会社',
        submitter_name_en='MORI BUILDING Co.,Ltd.',
        submitter_name_yomi='モリビルカブシキガイシャ',
        address='港区六本木六丁目１０番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='1010401029669',
    ),
    'E07849': EdinetCodeEntry(
        edinet_code='E07849',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='廣岡\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='ヒロオカ\u3000テツヤ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07850': EdinetCodeEntry(
        edinet_code='E07850',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='篠原\u3000英明',
        submitter_name_en=None,
        submitter_name_yomi='シノハラ\u3000ヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07857': EdinetCodeEntry(
        edinet_code='E07857',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清原\u3000雅人',
        submitter_name_en=None,
        submitter_name_yomi='キヨハラ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07859': EdinetCodeEntry(
        edinet_code='E07859',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=38,
        fiscal_year_end=None,
        submitter_name='株式会社原島不動産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハラシマフドウサン',
        address='千代田区神田三崎町三丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010002013377',
    ),
    'E07862': EdinetCodeEntry(
        edinet_code='E07862',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=42,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＩＣＯＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイコー',
        address='名古屋市東区葵１－１９－３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001041826',
    ),
    'E07867': EdinetCodeEntry(
        edinet_code='E07867',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大須賀\u3000正孝',
        submitter_name_en=None,
        submitter_name_yomi='オオスカ\u3000マサタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07879': EdinetCodeEntry(
        edinet_code='E07879',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ワールド・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワールドキャピタルカブシキガイシャ',
        address='神奈川県横浜市旭区中希望が丘１６９－３２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013401002275',
    ),
    'E07896': EdinetCodeEntry(
        edinet_code='E07896',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=230900,
        fiscal_year_end=None,
        submitter_name='ＮＴＴドコモビジネス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティドコモビジネスカブシキカイシャ',
        address='千代田区大手町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001064648',
    ),
    'E07923': EdinetCodeEntry(
        edinet_code='E07923',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉野\u3000公彦',
        submitter_name_en=None,
        submitter_name_yomi='スギノ\u3000マサヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07928': EdinetCodeEntry(
        edinet_code='E07928',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='島田\u3000亨',
        submitter_name_en=None,
        submitter_name_yomi='シマダ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07929': EdinetCodeEntry(
        edinet_code='E07929',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='株式会社時事通信社',
        submitter_name_en=None,
        submitter_name_yomi='ジジツウシンシャ',
        address='中央区銀座五丁目十五番八号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001018703',
    ),
    'E07947': EdinetCodeEntry(
        edinet_code='E07947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平井睦雄',
        submitter_name_en=None,
        submitter_name_yomi='ヒライムツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07948': EdinetCodeEntry(
        edinet_code='E07948',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福田武',
        submitter_name_en=None,
        submitter_name_yomi='フクダタケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07951': EdinetCodeEntry(
        edinet_code='E07951',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神山\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='カミヤマ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07952': EdinetCodeEntry(
        edinet_code='E07952',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥田\u3000耕己',
        submitter_name_en=None,
        submitter_name_yomi='オクダ\u3000コウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07953': EdinetCodeEntry(
        edinet_code='E07953',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥田\u3000昌孝',
        submitter_name_en=None,
        submitter_name_yomi='オクダ\u3000マサタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07974': EdinetCodeEntry(
        edinet_code='E07974',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='襟川\u3000陽一',
        submitter_name_en=None,
        submitter_name_yomi='エリカワ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E07982': EdinetCodeEntry(
        edinet_code='E07982',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大部\u3000力',
        submitter_name_en=None,
        submitter_name_yomi='オオブ\u3000チカラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08003': EdinetCodeEntry(
        edinet_code='E08003',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大谷喜一',
        submitter_name_en=None,
        submitter_name_yomi='オオタニキイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08036': EdinetCodeEntry(
        edinet_code='E08036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='梶山\u3000高志',
        submitter_name_en=None,
        submitter_name_yomi='カジヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08043': EdinetCodeEntry(
        edinet_code='E08043',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福武\u3000總一郎',
        submitter_name_en=None,
        submitter_name_yomi='フクタケ\u3000ソウイチロウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08051': EdinetCodeEntry(
        edinet_code='E08051',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社光パワー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャヒカリパワー',
        address='港区虎ノ門３－１８－６朝日虎ノ門マンション３１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010402032814',
    ),
    'E08052': EdinetCodeEntry(
        edinet_code='E08052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='重田康光',
        submitter_name_en=None,
        submitter_name_yomi='シゲタヤスミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08056': EdinetCodeEntry(
        edinet_code='E08056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅田\u3000威男',
        submitter_name_en=None,
        submitter_name_yomi='ウメダ\u3000タケオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08059': EdinetCodeEntry(
        edinet_code='E08059',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000憲司',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08072': EdinetCodeEntry(
        edinet_code='E08072',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000弘穀',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヒロタケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08073': EdinetCodeEntry(
        edinet_code='E08073',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石塚\u3000幸司',
        submitter_name_en=None,
        submitter_name_yomi='イシヅカ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08077': EdinetCodeEntry(
        edinet_code='E08077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木幸藏',
        submitter_name_en=None,
        submitter_name_yomi='ミキコウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08079': EdinetCodeEntry(
        edinet_code='E08079',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩﨑俊雄',
        submitter_name_en=None,
        submitter_name_yomi='イワサキトシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08090': EdinetCodeEntry(
        edinet_code='E08090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='浮川\u3000和宣',
        submitter_name_en=None,
        submitter_name_yomi='ウキカワ\u3000カズノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08112': EdinetCodeEntry(
        edinet_code='E08112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩佐\u3000実次',
        submitter_name_en=None,
        submitter_name_yomi='イワサ\u3000ミツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08117': EdinetCodeEntry(
        edinet_code='E08117',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下村\u3000勝己',
        submitter_name_en=None,
        submitter_name_yomi='シモムラ\u3000カツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08120': EdinetCodeEntry(
        edinet_code='E08120',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南部靖之',
        submitter_name_en=None,
        submitter_name_yomi='ナンブヤスユキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08131': EdinetCodeEntry(
        edinet_code='E08131',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000正寿',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000マサトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08140': EdinetCodeEntry(
        edinet_code='E08140',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津田\u3000能成',
        submitter_name_en=None,
        submitter_name_yomi='ツダ\u3000ヨシシゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08142': EdinetCodeEntry(
        edinet_code='E08142',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青山洋一',
        submitter_name_en=None,
        submitter_name_yomi='アオヤマヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08155': EdinetCodeEntry(
        edinet_code='E08155',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='東京濾器株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウロキカブシキカイシャ',
        address='横浜市都筑区仲町台３丁目１２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5020001009050',
    ),
    'E08159': EdinetCodeEntry(
        edinet_code='E08159',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='服部\u3000正太',
        submitter_name_en=None,
        submitter_name_yomi='ハットリ\u3000ショウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08161': EdinetCodeEntry(
        edinet_code='E08161',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000晋',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08163': EdinetCodeEntry(
        edinet_code='E08163',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=940,
        fiscal_year_end=None,
        submitter_name='アバディーン・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アバディーン\u3000ジャパン\u3000カブシキガイシャ',
        address='千代田区大手町一丁目９番２号大手町フィナンシャルシティグランキューブ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401008780',
    ),
    'E08164': EdinetCodeEntry(
        edinet_code='E08164',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀江\u3000貴文',
        submitter_name_en=None,
        submitter_name_yomi='ホリエ\u3000タカフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08167': EdinetCodeEntry(
        edinet_code='E08167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三木谷\u3000浩史',
        submitter_name_en=None,
        submitter_name_yomi='ミキタニ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08168': EdinetCodeEntry(
        edinet_code='E08168',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社八雲',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤクモ',
        address='岡山市北区津島京町３丁目１－２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5260001006692',
    ),
    'E08182': EdinetCodeEntry(
        edinet_code='E08182',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井川\u3000幸広',
        submitter_name_en=None,
        submitter_name_yomi='イカワ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08192': EdinetCodeEntry(
        edinet_code='E08192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊川\u3000曉',
        submitter_name_en=None,
        submitter_name_yomi='キクガワ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08222': EdinetCodeEntry(
        edinet_code='E08222',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='豊田\u3000崇克',
        submitter_name_en=None,
        submitter_name_yomi='トヨダ\u3000タカヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08223': EdinetCodeEntry(
        edinet_code='E08223',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='國光\u3000浩三',
        submitter_name_en=None,
        submitter_name_yomi='クニミツ\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08224': EdinetCodeEntry(
        edinet_code='E08224',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000郁',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08227': EdinetCodeEntry(
        edinet_code='E08227',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩井\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='イワイ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08230': EdinetCodeEntry(
        edinet_code='E08230',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西尾\u3000直紀',
        submitter_name_en=None,
        submitter_name_yomi='ニシオ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08232': EdinetCodeEntry(
        edinet_code='E08232',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ダブリュー・エヌ・アイ・インスティテュート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダブリューエヌアイインスティテュート',
        address='千葉市緑区あすみが丘六丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2040001008697',
    ),
    'E08246': EdinetCodeEntry(
        edinet_code='E08246',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大村\u3000浩次',
        submitter_name_en=None,
        submitter_name_yomi='オオムラ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08260': EdinetCodeEntry(
        edinet_code='E08260',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35848,
        fiscal_year_end=None,
        submitter_name='株式会社博報堂',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャハクホウドウ',
        address='港区赤坂５丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401024011',
    ),
    'E08277': EdinetCodeEntry(
        edinet_code='E08277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='玉上\u3000進一',
        submitter_name_en=None,
        submitter_name_yomi='タマガミ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08278': EdinetCodeEntry(
        edinet_code='E08278',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='七村\u3000守',
        submitter_name_en=None,
        submitter_name_yomi='ナナムラ\u3000マモル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08282': EdinetCodeEntry(
        edinet_code='E08282',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉村\u3000一男',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000カズオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08288': EdinetCodeEntry(
        edinet_code='E08288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横山\u3000博一',
        submitter_name_en=None,
        submitter_name_yomi='ヨコヤマ\u3000ヒロイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08292': EdinetCodeEntry(
        edinet_code='E08292',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='前田眞也',
        submitter_name_en=None,
        submitter_name_yomi='マエダシンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08296': EdinetCodeEntry(
        edinet_code='E08296',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石村賢一',
        submitter_name_en=None,
        submitter_name_yomi='イシムラケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08305': EdinetCodeEntry(
        edinet_code='E08305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀\u3000紘一',
        submitter_name_en=None,
        submitter_name_yomi='ホリ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08316': EdinetCodeEntry(
        edinet_code='E08316',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金子\u3000修',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000オサム',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08335': EdinetCodeEntry(
        edinet_code='E08335',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000修平',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000シュウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08352': EdinetCodeEntry(
        edinet_code='E08352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙塚\u3000優',
        submitter_name_en=None,
        submitter_name_yomi='タカツカ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08356': EdinetCodeEntry(
        edinet_code='E08356',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000行規',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000ユキノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08360': EdinetCodeEntry(
        edinet_code='E08360',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藏田\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='クラタ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08361': EdinetCodeEntry(
        edinet_code='E08361',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000英樹',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08365': EdinetCodeEntry(
        edinet_code='E08365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08369': EdinetCodeEntry(
        edinet_code='E08369',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ノザワコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャノザワコーポレーション',
        address='新潟市中央区有明台１番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8110001000708',
    ),
    'E08372': EdinetCodeEntry(
        edinet_code='E08372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志太勤一',
        submitter_name_en=None,
        submitter_name_yomi='シダキンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08374': EdinetCodeEntry(
        edinet_code='E08374',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横島\u3000泰蔵',
        submitter_name_en=None,
        submitter_name_yomi='ヨコシマ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08378': EdinetCodeEntry(
        edinet_code='E08378',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近藤\u3000太香巳',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000タカミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08383': EdinetCodeEntry(
        edinet_code='E08383',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田晃久',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダアキヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08384': EdinetCodeEntry(
        edinet_code='E08384',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08387': EdinetCodeEntry(
        edinet_code='E08387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='牧平\u3000年廣',
        submitter_name_en=None,
        submitter_name_yomi='マキヒラ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08394': EdinetCodeEntry(
        edinet_code='E08394',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='濱田佳治',
        submitter_name_en=None,
        submitter_name_yomi='ハマダヨシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08402': EdinetCodeEntry(
        edinet_code='E08402',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中井\u3000清和',
        submitter_name_en=None,
        submitter_name_yomi='ナカイ\u3000キヨカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08406': EdinetCodeEntry(
        edinet_code='E08406',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野口\u3000緑',
        submitter_name_en=None,
        submitter_name_yomi='ノグチ\u3000ミドリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08413': EdinetCodeEntry(
        edinet_code='E08413',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20000,
        fiscal_year_end=None,
        submitter_name='エヌ・ティ・ティ・コムウェア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティコムウェアカブシキカイシャ',
        address='港区港南１－９－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401032249',
    ),
    'E08428': EdinetCodeEntry(
        edinet_code='E08428',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森下\u3000竜一',
        submitter_name_en=None,
        submitter_name_yomi='モリシタ\u3000リュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08430': EdinetCodeEntry(
        edinet_code='E08430',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='冨田\u3000憲介',
        submitter_name_en=None,
        submitter_name_yomi='トミタ\u3000ケンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08431': EdinetCodeEntry(
        edinet_code='E08431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='アント・キャピタル・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アントキャピタルパートナーズカブシキガイシャ',
        address='千代田区丸の内二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001073654',
    ),
    'E08433': EdinetCodeEntry(
        edinet_code='E08433',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='道具\u3000登志夫',
        submitter_name_en=None,
        submitter_name_yomi='ドウグ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08438': EdinetCodeEntry(
        edinet_code='E08438',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=902,
        fiscal_year_end=None,
        submitter_name='みずほキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミズホキャピタルカブシキガイシャ',
        address='千代田区内幸町１－２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001077605',
    ),
    'E08445': EdinetCodeEntry(
        edinet_code='E08445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内田廣',
        submitter_name_en=None,
        submitter_name_yomi='ウチダヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08448': EdinetCodeEntry(
        edinet_code='E08448',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='﨑山\u3000收',
        submitter_name_en=None,
        submitter_name_yomi='サキヤマ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08454': EdinetCodeEntry(
        edinet_code='E08454',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='満井\u3000義政',
        submitter_name_en=None,
        submitter_name_yomi='ミツイ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08459': EdinetCodeEntry(
        edinet_code='E08459',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='相馬\u3000秀行',
        submitter_name_en=None,
        submitter_name_yomi='ソウマ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08461': EdinetCodeEntry(
        edinet_code='E08461',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='ＮＴＴテクノクロス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティテクノクロスカブシキガイシャ',
        address='東京都港区芝浦３－４－１\u3000グランパークタワー１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401056882',
    ),
    'E08464': EdinetCodeEntry(
        edinet_code='E08464',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000治昭',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ハルアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08469': EdinetCodeEntry(
        edinet_code='E08469',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='巽一久',
        submitter_name_en=None,
        submitter_name_yomi='タツミカズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08480': EdinetCodeEntry(
        edinet_code='E08480',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4792427,
        fiscal_year_end=None,
        submitter_name='農林中央金庫',
        submitter_name_en=None,
        submitter_name_yomi='ノウリンチュウオウキンコ',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005004002',
    ),
    'E08481': EdinetCodeEntry(
        edinet_code='E08481',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=115255,
        fiscal_year_end=None,
        submitter_name='全国農業協同組合連合会',
        submitter_name_en=None,
        submitter_name_yomi='ゼンコクノウギョウキョウドウクミアイレンゴウカイ',
        address='千代田区大手町１－３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005002090',
    ),
    'E08491': EdinetCodeEntry(
        edinet_code='E08491',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=87768,
        fiscal_year_end=None,
        submitter_name='バークレイズ・キャピタル・セキュリティーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バークレイズキャピタルセキュリティーズリミテッド',
        address='Ｅ１４\u3000４ＢＢ\u3000英国\u3000ロンドン市\u3000カナリーワーフ\u3000ノース・コロネード５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08502': EdinetCodeEntry(
        edinet_code='E08502',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高見澤秀茂',
        submitter_name_en=None,
        submitter_name_yomi='タカミサワヒデシゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08556': EdinetCodeEntry(
        edinet_code='E08556',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畔柳\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='クロヤナギマコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08561': EdinetCodeEntry(
        edinet_code='E08561',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平松\u3000博利',
        submitter_name_en=None,
        submitter_name_yomi='ヒラマツ\u3000ヒロトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08564': EdinetCodeEntry(
        edinet_code='E08564',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000英俊',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ヒデトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08569': EdinetCodeEntry(
        edinet_code='E08569',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='安川\u3000秀俊',
        submitter_name_en=None,
        submitter_name_yomi='ヤスカワ\u3000ヒデトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08576': EdinetCodeEntry(
        edinet_code='E08576',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河野\u3000義勝',
        submitter_name_en=None,
        submitter_name_yomi='コウノ\u3000ヨシカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08587': EdinetCodeEntry(
        edinet_code='E08587',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19000,
        fiscal_year_end='3月31日',
        submitter_name='日本貨物鉄道株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンカモツテツドウカブシキカイシャ',
        address='渋谷区千駄ヶ谷５－３３－８',
        industry='陸運業',
        sec_code=None,
        corporate_number='7011001068366',
    ),
    'E08615': EdinetCodeEntry(
        edinet_code='E08615',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='辻\u3000理',
        submitter_name_en=None,
        submitter_name_yomi='ツジ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08618': EdinetCodeEntry(
        edinet_code='E08618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大塚\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08643': EdinetCodeEntry(
        edinet_code='E08643',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='福岡地所株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フクオカジショカブシキガイシャ',
        address='福岡市博多区住吉１丁目２番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1290001016156',
    ),
    'E08650': EdinetCodeEntry(
        edinet_code='E08650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松岡仁史',
        submitter_name_en=None,
        submitter_name_yomi='マツオカヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08664': EdinetCodeEntry(
        edinet_code='E08664',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000洋助',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08672': EdinetCodeEntry(
        edinet_code='E08672',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5800,
        fiscal_year_end=None,
        submitter_name='ＣＢＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シービーシーカブシキガイシャ',
        address='中央区月島二丁目１５番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001050333',
    ),
    'E08675': EdinetCodeEntry(
        edinet_code='E08675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳井\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='ヤナイ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08688': EdinetCodeEntry(
        edinet_code='E08688',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平野\u3000能章',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000ヨシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08699': EdinetCodeEntry(
        edinet_code='E08699',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=51,
        fiscal_year_end=None,
        submitter_name='株式会社シャルダン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシャルダン',
        address='新宿区下落合１－４－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701022161',
    ),
    'E08707': EdinetCodeEntry(
        edinet_code='E08707',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=990,
        fiscal_year_end=None,
        submitter_name='モルガン・スタンレー・インベストメント・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モルガンスタンレーインベストメントマネジメントカブシキガイシャ',
        address='千代田区大手町１－９－７\u3000大手町フィナンシャルシティ\u3000サウスタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001026405',
    ),
    'E08716': EdinetCodeEntry(
        edinet_code='E08716',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野田\u3000順弘',
        submitter_name_en=None,
        submitter_name_yomi='ノダ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08729': EdinetCodeEntry(
        edinet_code='E08729',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川上\u3000量生',
        submitter_name_en=None,
        submitter_name_yomi='カワカミ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08749': EdinetCodeEntry(
        edinet_code='E08749',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='協同興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウドウコウギョウカブシキガイシャ',
        address='豊島区南池袋二丁目２９番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011301001950',
    ),
    'E08758': EdinetCodeEntry(
        edinet_code='E08758',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＩＰＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイピーシーカブシキガイシャ',
        address='渋谷区道玄坂一丁目１０番８号渋谷道玄坂東急ビル２ＦーＣ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001073219',
    ),
    'E08765': EdinetCodeEntry(
        edinet_code='E08765',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='政木\u3000喜三郎',
        submitter_name_en=None,
        submitter_name_yomi='マサキ\u3000キサブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08770': EdinetCodeEntry(
        edinet_code='E08770',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=96307,
        fiscal_year_end=None,
        submitter_name='シティグループ証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シティグループショウケンカブシキガイシャ',
        address='千代田区大手町一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001113388',
    ),
    'E08775': EdinetCodeEntry(
        edinet_code='E08775',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='有限会社和幸興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャワコウコウサン',
        address='柏市北柏１丁目１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9040002092180',
    ),
    'E08778': EdinetCodeEntry(
        edinet_code='E08778',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000尚道',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ナオミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08787': EdinetCodeEntry(
        edinet_code='E08787',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＥＮＥＯＳウイング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエネオスウイング',
        address='名古屋市中区栄三丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001016088',
    ),
    'E08801': EdinetCodeEntry(
        edinet_code='E08801',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ウェルホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウェルホールディングス',
        address='福岡市中央区天神二丁目１４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290001024702',
    ),
    'E08802': EdinetCodeEntry(
        edinet_code='E08802',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=687,
        fiscal_year_end=None,
        submitter_name='株式会社ワイエムシィ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワイエムシィ',
        address='京都市下京区五条通烏丸西入醍醐町２８４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1130001019307',
    ),
    'E08823': EdinetCodeEntry(
        edinet_code='E08823',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井\u3000康彦',
        submitter_name_en=None,
        submitter_name_yomi='イ\u3000ヤスヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08827': EdinetCodeEntry(
        edinet_code='E08827',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=160,
        fiscal_year_end=None,
        submitter_name='ダルトン・インベストメンツ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ダルトンインベストメンツエルエルシー',
        address='米国カリフォルニア州９０４０４、サンタモニカ市、クロバーフィールド・ブルヴァード１６０１、スイート５０５０Ｎ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08833': EdinetCodeEntry(
        edinet_code='E08833',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福島\u3000愼介',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000シンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08836': EdinetCodeEntry(
        edinet_code='E08836',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森明信',
        submitter_name_en=None,
        submitter_name_yomi='モリアキノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08844': EdinetCodeEntry(
        edinet_code='E08844',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石原\u3000卓児',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000タクジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08857': EdinetCodeEntry(
        edinet_code='E08857',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000満寿世',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000マスヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08861': EdinetCodeEntry(
        edinet_code='E08861',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久保田\u3000純子',
        submitter_name_en=None,
        submitter_name_yomi='クボタ\u3000ジュンコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08889': EdinetCodeEntry(
        edinet_code='E08889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='旭化成ファーマ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒカセイフアーマカブシキガイシヤ',
        address='千代田区有楽町１丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001017825',
    ),
    'E08901': EdinetCodeEntry(
        edinet_code='E08901',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=205,
        fiscal_year_end=None,
        submitter_name='南海興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナンカイコウサンカブシキガイシャ',
        address='高松市常磐町二丁目１３番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6470001003049',
    ),
    'E08903': EdinetCodeEntry(
        edinet_code='E08903',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5000,
        fiscal_year_end=None,
        submitter_name='日鉄ステンレス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッテツステンレスカブシキガイシャ',
        address='千代田区丸の内一丁目８番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001084826',
    ),
    'E08914': EdinetCodeEntry(
        edinet_code='E08914',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='重里\u3000欣孝',
        submitter_name_en=None,
        submitter_name_yomi='シゲサト\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08920': EdinetCodeEntry(
        edinet_code='E08920',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森\u3000豊隆',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000トヨタカ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08930': EdinetCodeEntry(
        edinet_code='E08930',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='諸橋\u3000輝子',
        submitter_name_en=None,
        submitter_name_yomi='モロハシ\u3000テルコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08932': EdinetCodeEntry(
        edinet_code='E08932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='富山\u3000睦浩',
        submitter_name_en=None,
        submitter_name_yomi='トミヤマ\u3000ムツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08938': EdinetCodeEntry(
        edinet_code='E08938',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='有限会社ビー・ケー・ファイナンス',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャビーケーファイナンス',
        address='北区赤羽１－４０－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011502004835',
    ),
    'E08939': EdinetCodeEntry(
        edinet_code='E08939',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=748,
        fiscal_year_end=None,
        submitter_name='スプラウスグローブインベストメントマネジメントリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スプラウスグローブインベストメントマネジメントリミテッド',
        address='１８１\u3000Ｕｎｉｖｅｒｓｉｔｙ\u3000Ａｖｅｎｕｅ\u3000Ｓｕｉｔｅ\u3000１３００\u3000Ｔｏｒｏｎｔｏ，\u3000Ｏｎｔａｒｉｏ\u3000Ｃａｎａｄａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08957': EdinetCodeEntry(
        edinet_code='E08957',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='三井住友ＤＳアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツイスミトモディーエスアセットマネジメントカブシキガイシャ',
        address='港区虎ノ門一丁目１７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401049128',
    ),
    'E08962': EdinetCodeEntry(
        edinet_code='E08962',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人西村奨学財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンニシムラショウガクザイダン',
        address='大阪市中央区十二軒町５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120005012182',
    ),
    'E08971': EdinetCodeEntry(
        edinet_code='E08971',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村田\u3000吉優',
        submitter_name_en=None,
        submitter_name_yomi='ムラタ\u3000ヨシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08978': EdinetCodeEntry(
        edinet_code='E08978',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒土\u3000始',
        submitter_name_en=None,
        submitter_name_yomi='クロツチ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08993': EdinetCodeEntry(
        edinet_code='E08993',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江守\u3000康昌',
        submitter_name_en=None,
        submitter_name_yomi='エモリ\u3000ヤスマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E08996': EdinetCodeEntry(
        edinet_code='E08996',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='合同会社イーエム・プランニング',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャイーエムプランニング',
        address='渋谷区神南一丁目２０番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011003002920',
    ),
    'E08997': EdinetCodeEntry(
        edinet_code='E08997',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5000,
        fiscal_year_end=None,
        submitter_name='セントラル短資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セントラルタンシカブシキカイシャ',
        address='中央区日本橋本石町三丁目３番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001059266',
    ),
    'E09004': EdinetCodeEntry(
        edinet_code='E09004',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社博報堂ＤＹメディアパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハクホウドウディワイメディアパートナーズ',
        address='東京都港区赤坂五丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401052280',
    ),
    'E09016': EdinetCodeEntry(
        edinet_code='E09016',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='コンセーユ・ティ・アイ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コンセーユティアイカブシキガイシャ',
        address='中央区勝どき六丁目３番２－４８０９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001067806',
    ),
    'E09029': EdinetCodeEntry(
        edinet_code='E09029',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='橋田\u3000麗子',
        submitter_name_en=None,
        submitter_name_yomi='ハシダ\u3000レイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09035': EdinetCodeEntry(
        edinet_code='E09035',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河合\u3000日出雄',
        submitter_name_en=None,
        submitter_name_yomi='カワイヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09037': EdinetCodeEntry(
        edinet_code='E09037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ウィズ・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウィズパートナーズ',
        address='港区愛宕２丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401050707',
    ),
    'E09048': EdinetCodeEntry(
        edinet_code='E09048',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='若山\u3000陽一',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09050': EdinetCodeEntry(
        edinet_code='E09050',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='マサチューセッツ・ファイナンシャル・サービセズ・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='マサチューセッツ\u3000ファイナンシャル\u3000サービセズ\u3000カンパニー',
        address='アメリカ合衆国、マサチューセッツ州、ボストン、ハンティントンアベニュー１１１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09056': EdinetCodeEntry(
        edinet_code='E09056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鎌田正彦',
        submitter_name_en=None,
        submitter_name_yomi='カマタマサヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09065': EdinetCodeEntry(
        edinet_code='E09065',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙野時丸',
        submitter_name_en=None,
        submitter_name_yomi='タカノトキマル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09070': EdinetCodeEntry(
        edinet_code='E09070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江尻義久',
        submitter_name_en=None,
        submitter_name_yomi='エジリヨシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09082': EdinetCodeEntry(
        edinet_code='E09082',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡本\u3000\u3000毅',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09083': EdinetCodeEntry(
        edinet_code='E09083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土屋\u3000公三',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤ\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09094': EdinetCodeEntry(
        edinet_code='E09094',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='越山\u3000勇',
        submitter_name_en=None,
        submitter_name_yomi='コシヤマ\u3000イサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09096': EdinetCodeEntry(
        edinet_code='E09096',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3120,
        fiscal_year_end=None,
        submitter_name='ブラックロック・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブラックロックジャパンカブシキガイシャ',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001125976',
    ),
    'E09105': EdinetCodeEntry(
        edinet_code='E09105',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社南悠商社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナンユウショウシャ',
        address='港区虎ノ門四丁目１‐３５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401049682',
    ),
    'E09106': EdinetCodeEntry(
        edinet_code='E09106',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=855939,
        fiscal_year_end=None,
        submitter_name='ドイツ銀行ロンドン支店',
        submitter_name_en=None,
        submitter_name_yomi='ドイツギンコウロンドンシテン',
        address='英国ロンドン市ＥＣ２Ｙ９ＤＢムーアフィールズ２１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09109': EdinetCodeEntry(
        edinet_code='E09109',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='銀行等保有株式取得機構',
        submitter_name_en=None,
        submitter_name_yomi='ギンコウトウホユウカブシキシュトクキコウ',
        address='中央区新川二丁目２８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005005829',
    ),
    'E09111': EdinetCodeEntry(
        edinet_code='E09111',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ベイリー・ギフォード・アンド・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ベイリーギフォードアンドカンパニー',
        address='カルトン・スクエア、１グリーンサイド・ロウ、エジンバラＥＨ１\u3000３ＡＮ\u3000スコットランド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09147': EdinetCodeEntry(
        edinet_code='E09147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='沓名\u3000俊裕',
        submitter_name_en=None,
        submitter_name_yomi='クツナ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09150': EdinetCodeEntry(
        edinet_code='E09150',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='幸\u3000寿',
        submitter_name_en=None,
        submitter_name_yomi='ユキ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09154': EdinetCodeEntry(
        edinet_code='E09154',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山澤\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザワ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09164': EdinetCodeEntry(
        edinet_code='E09164',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='須田\u3000忠雄',
        submitter_name_en=None,
        submitter_name_yomi='スダ\u3000タダオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09175': EdinetCodeEntry(
        edinet_code='E09175',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野内\u3000敦',
        submitter_name_en=None,
        submitter_name_yomi='ノウチ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09183': EdinetCodeEntry(
        edinet_code='E09183',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='タイヨウ・ファンド・マネッジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウファンドマネッジメントエルエルシー',
        address='アメリカ合衆国、ワシントン州９８０３３、カークランド、キャリロンポイント５３００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09185': EdinetCodeEntry(
        edinet_code='E09185',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社サカタホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='サカタホールディングス',
        address='目黒区東が丘二丁目１番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013201010934',
    ),
    'E09203': EdinetCodeEntry(
        edinet_code='E09203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松田\u3000邦子',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000クニコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09205': EdinetCodeEntry(
        edinet_code='E09205',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口誠一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチセイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09223': EdinetCodeEntry(
        edinet_code='E09223',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金山\u3000精三郎',
        submitter_name_en=None,
        submitter_name_yomi='カナヤマ\u3000セイザブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09234': EdinetCodeEntry(
        edinet_code='E09234',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永田\u3000良一',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09245': EdinetCodeEntry(
        edinet_code='E09245',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='有限会社カツコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャカツコーポレーション',
        address='品川区東品川４－１３－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010702015387',
    ),
    'E09272': EdinetCodeEntry(
        edinet_code='E09272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋元\u3000竜弥',
        submitter_name_en=None,
        submitter_name_yomi='アキモト\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09278': EdinetCodeEntry(
        edinet_code='E09278',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2730,
        fiscal_year_end=None,
        submitter_name='中央不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウオウフドウサンカブシキガイシャ',
        address='千代田区霞ヶ関１－４－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001068385',
    ),
    'E09280': EdinetCodeEntry(
        edinet_code='E09280',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='酒井\u3000俊光',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000トシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09287': EdinetCodeEntry(
        edinet_code='E09287',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ヤマノネットワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマノネットワーク',
        address='渋谷区代々木一丁目３０番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001030264',
    ),
    'E09299': EdinetCodeEntry(
        edinet_code='E09299',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石坂\u3000信也',
        submitter_name_en=None,
        submitter_name_yomi='イシザカ\u3000ノブヤ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09302': EdinetCodeEntry(
        edinet_code='E09302',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='株式会社ゴルフダイジェスト社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャゴルフダイジェストシャ',
        address='港区新橋６丁目１８番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401010604',
    ),
    'E09319': EdinetCodeEntry(
        edinet_code='E09319',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社直木商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナオキショウジ',
        address='沼津市原８１５番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4080101001175',
    ),
    'E09373': EdinetCodeEntry(
        edinet_code='E09373',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉岡伸一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシオカシンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09389': EdinetCodeEntry(
        edinet_code='E09389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09426': EdinetCodeEntry(
        edinet_code='E09426',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='倉正治',
        submitter_name_en=None,
        submitter_name_yomi='クラマサハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09439': EdinetCodeEntry(
        edinet_code='E09439',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙島\u3000勇二',
        submitter_name_en=None,
        submitter_name_yomi='タカシマ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09452': EdinetCodeEntry(
        edinet_code='E09452',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾崎浩太',
        submitter_name_en=None,
        submitter_name_yomi='オザキヒロタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09453': EdinetCodeEntry(
        edinet_code='E09453',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾崎文彦',
        submitter_name_en=None,
        submitter_name_yomi='オザキフミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09456': EdinetCodeEntry(
        edinet_code='E09456',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=427980,
        fiscal_year_end=None,
        submitter_name='ヴァレオ・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ヴァレオ\u3000マネジメント',
        address='フランス、パリ、７５０１７、ル・ドゥ・クールセル１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09458': EdinetCodeEntry(
        edinet_code='E09458',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='近石\u3000幸博',
        submitter_name_en=None,
        submitter_name_yomi='チカイシ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09459': EdinetCodeEntry(
        edinet_code='E09459',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢野\u3000恭一',
        submitter_name_en=None,
        submitter_name_yomi='ヤノ\u3000キョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09481': EdinetCodeEntry(
        edinet_code='E09481',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉川\u3000隆',
        submitter_name_en=None,
        submitter_name_yomi='キッカワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09482': EdinetCodeEntry(
        edinet_code='E09482',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社エスジェーエス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスジェーエス',
        address='世田谷区成城２－２２－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010901001813',
    ),
    'E09483': EdinetCodeEntry(
        edinet_code='E09483',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='ハウス興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハウスコウサンカブシキガイシャ',
        address='東大阪市御厨栄町１丁目５番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4122001005870',
    ),
    'E09485': EdinetCodeEntry(
        edinet_code='E09485',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='馬場邦明',
        submitter_name_en=None,
        submitter_name_yomi='ババクニアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09489': EdinetCodeEntry(
        edinet_code='E09489',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='進藤博信',
        submitter_name_en=None,
        submitter_name_yomi='シンドウヒロノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09491': EdinetCodeEntry(
        edinet_code='E09491',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000喜代子',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000キヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09496': EdinetCodeEntry(
        edinet_code='E09496',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮田\u3000憲次',
        submitter_name_en=None,
        submitter_name_yomi='ミヤタ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09507': EdinetCodeEntry(
        edinet_code='E09507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='株式会社ベストライフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベストライフ',
        address='新宿区西新宿二丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101038876',
    ),
    'E09520': EdinetCodeEntry(
        edinet_code='E09520',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社誠香',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセイカ',
        address='世田谷区尾山台１ー１６－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010901014302',
    ),
    'E09528': EdinetCodeEntry(
        edinet_code='E09528',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小佐野\u3000文雄',
        submitter_name_en=None,
        submitter_name_yomi='オサノ\u3000フミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09537': EdinetCodeEntry(
        edinet_code='E09537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000修逸',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000シュウイツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09544': EdinetCodeEntry(
        edinet_code='E09544',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000和田商会',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ワダショウカイ',
        address='新潟市中央区礎町通三ノ町２１２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7110001005848',
    ),
    'E09562': EdinetCodeEntry(
        edinet_code='E09562',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000惠美子',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000エミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09566': EdinetCodeEntry(
        edinet_code='E09566',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉原直樹',
        submitter_name_en=None,
        submitter_name_yomi='ヨシハラ\u3000\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09580': EdinetCodeEntry(
        edinet_code='E09580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日置恒明',
        submitter_name_en=None,
        submitter_name_yomi='ヒオキツネアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09593': EdinetCodeEntry(
        edinet_code='E09593',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野島\u3000廣司',
        submitter_name_en=None,
        submitter_name_yomi='ノジマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09600': EdinetCodeEntry(
        edinet_code='E09600',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='第一燃料株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイイチネンリョウカブシキカイシャ',
        address='大阪市淀川区西中島四丁目３番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001056441',
    ),
    'E09601': EdinetCodeEntry(
        edinet_code='E09601',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社笹興',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャササコウ',
        address='大阪市福島区海老江五丁目２番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001049641',
    ),
    'E09607': EdinetCodeEntry(
        edinet_code='E09607',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西川正洋',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワマサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09616': EdinetCodeEntry(
        edinet_code='E09616',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000正卓',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000マサタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09631': EdinetCodeEntry(
        edinet_code='E09631',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三津原\u3000庸介',
        submitter_name_en=None,
        submitter_name_yomi='ミツハラ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09632': EdinetCodeEntry(
        edinet_code='E09632',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社マックスプランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマックスプランニング',
        address='港区西麻布四丁目１９番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9013202005971',
    ),
    'E09633': EdinetCodeEntry(
        edinet_code='E09633',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=370,
        fiscal_year_end=None,
        submitter_name='銀泉株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ギンセンカブシキガイシャ',
        address='大阪市中央区高麗橋４丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001078309',
    ),
    'E09636': EdinetCodeEntry(
        edinet_code='E09636',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社ツカサ・エンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツカサエンタープライズ',
        address='中野区東中野一丁目１３番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011202011247',
    ),
    'E09643': EdinetCodeEntry(
        edinet_code='E09643',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森\u3000猛',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09652': EdinetCodeEntry(
        edinet_code='E09652',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='栄紙業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サカエシギョウカブシキガイシャ',
        address='中央区京橋１丁目１－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001044765',
    ),
    'E09660': EdinetCodeEntry(
        edinet_code='E09660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000朋也',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トモナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09662': EdinetCodeEntry(
        edinet_code='E09662',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=73,
        fiscal_year_end=None,
        submitter_name='オービス・インベストメント・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='オービス\u3000インベストメント\u3000マネジメント\u3000リミテッド',
        address='バミューダＨＭ１１ハミルトン、フロント・ストリート２５、オービス・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09666': EdinetCodeEntry(
        edinet_code='E09666',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1200,
        fiscal_year_end=None,
        submitter_name='アムンディ・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アムンディジャパンカブシキガイシャ',
        address='東京都港区東新橋一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001062807',
    ),
    'E09669': EdinetCodeEntry(
        edinet_code='E09669',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6568,
        fiscal_year_end=None,
        submitter_name='ドッチ・アンド・コックス',
        submitter_name_en=None,
        submitter_name_yomi='ドッチアンドコックス',
        address='アメリカ合州国カリフォルニア州９４１０４、サンフランシスコ、カリフォルニア・ストリート５５５、４０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09675': EdinetCodeEntry(
        edinet_code='E09675',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=200,
        fiscal_year_end='2月末日',
        submitter_name='ジョイ開発有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ジョイカイハツユウゲンガイシャ',
        address='大分市萩原４丁目１１番２４号（ジョイ８５）',
        industry='サービス業',
        sec_code=None,
        corporate_number='7320002003490',
    ),
    'E09681': EdinetCodeEntry(
        edinet_code='E09681',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤田\u3000秀雄',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09691': EdinetCodeEntry(
        edinet_code='E09691',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＳＢＩキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイキャピタルカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401045051',
    ),
    'E09695': EdinetCodeEntry(
        edinet_code='E09695',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社土屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツチヤ',
        address='福山市一文字町１４－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001035729',
    ),
    'E09698': EdinetCodeEntry(
        edinet_code='E09698',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹内\u3000惠司',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09704': EdinetCodeEntry(
        edinet_code='E09704',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000敏雄',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09713': EdinetCodeEntry(
        edinet_code='E09713',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塚田\u3000正之',
        submitter_name_en=None,
        submitter_name_yomi='ツカダ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09715': EdinetCodeEntry(
        edinet_code='E09715',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='ウエルズ通商株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウエルズツウショウカブシキカイシャ',
        address='大田区北馬込２丁目２８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010801001267',
    ),
    'E09728': EdinetCodeEntry(
        edinet_code='E09728',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木崇英',
        submitter_name_en=None,
        submitter_name_yomi='スズキタカヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09740': EdinetCodeEntry(
        edinet_code='E09740',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000吉孝',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09741': EdinetCodeEntry(
        edinet_code='E09741',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09748': EdinetCodeEntry(
        edinet_code='E09748',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀口\u3000智顕',
        submitter_name_en=None,
        submitter_name_yomi='ホリグチ\u3000トモアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09753': EdinetCodeEntry(
        edinet_code='E09753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10703,
        fiscal_year_end='3月31日',
        submitter_name='全国保証株式会社',
        submitter_name_en='ZENKOKU HOSHO Co.,Ltd',
        submitter_name_yomi='ゼンコクホショウカブシキカイシャ',
        address='千代田区大手町二丁目１番１号',
        industry='その他金融業',
        sec_code='71640',
        corporate_number='8010001008694',
    ),
    'E09779': EdinetCodeEntry(
        edinet_code='E09779',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='細江\u3000美則',
        submitter_name_en=None,
        submitter_name_yomi='ホソエ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09800': EdinetCodeEntry(
        edinet_code='E09800',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='太陽鉱工株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウコウコウカブシキカイシャ',
        address='神戸市中央区磯辺通１丁目１番３９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5140001009113',
    ),
    'E09802': EdinetCodeEntry(
        edinet_code='E09802',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='兼平\u3000宏',
        submitter_name_en=None,
        submitter_name_yomi='カネヒラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09804': EdinetCodeEntry(
        edinet_code='E09804',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土井\u3000春彦',
        submitter_name_en=None,
        submitter_name_yomi='ドイ\u3000ハルヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09806': EdinetCodeEntry(
        edinet_code='E09806',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田村友一',
        submitter_name_en=None,
        submitter_name_yomi='タムラユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09809': EdinetCodeEntry(
        edinet_code='E09809',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='肥田\u3000幸春',
        submitter_name_en=None,
        submitter_name_yomi='ヒダ\u3000ユキハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09810': EdinetCodeEntry(
        edinet_code='E09810',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='オービス・インベストメント・マネジメント・（ガーンジー）・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='オービス\u3000インベストメント\u3000マネジメント\u3000ガーンジー\u3000リミテッド',
        address='ガーンジー\u3000ＧＹ１\u3000１ＤＢ\u3000セント・ピーター・ポート、ル・ボーデージ、チューダー・ハウス１階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09814': EdinetCodeEntry(
        edinet_code='E09814',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松岡信夫',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09825': EdinetCodeEntry(
        edinet_code='E09825',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津吹\u3000憲男',
        submitter_name_en=None,
        submitter_name_yomi='ツブキ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09827': EdinetCodeEntry(
        edinet_code='E09827',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='新井\u3000隆二',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09828': EdinetCodeEntry(
        edinet_code='E09828',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='住吉食品有限会社',
        submitter_name_en=None,
        submitter_name_yomi='スミヨシショクヒンユウゲンガイシャ',
        address='新潟市東区宝町１３番５号２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1110002003484',
    ),
    'E09852': EdinetCodeEntry(
        edinet_code='E09852',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000結蔵',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000ユウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09860': EdinetCodeEntry(
        edinet_code='E09860',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=94,
        fiscal_year_end=None,
        submitter_name='株式会社サンセイテクノス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサンセイテクノス',
        address='大阪市淀川区西三国１－１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001055489',
    ),
    'E09862': EdinetCodeEntry(
        edinet_code='E09862',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1226194,
        fiscal_year_end=None,
        submitter_name='ジェー・ピー・モルガン・セキュリティーズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ジェーピーモルガンセキュリティーズピーエルシー',
        address='英国、ロンドン\u3000Ｅ１４\u3000５ＪＰ\u3000カナリー・ウォーフ、バンク・ストリート２５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09881': EdinetCodeEntry(
        edinet_code='E09881',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1174,
        fiscal_year_end=None,
        submitter_name='プラチナム・インベストメント・マネージメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='プラチナム\u3000インベストメント\u3000マネージメント\u3000リミテッド',
        address='オーストラリア、ニューサウスウェールズ州２０００、シドニー・マッコーリー・プレイス７、８階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09895': EdinetCodeEntry(
        edinet_code='E09895',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ユアーズ',
        submitter_name_en='YOURS Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャユアーズ',
        address='広島市東区二葉の里三丁目３番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='5240001036659',
    ),
    'E09919': EdinetCodeEntry(
        edinet_code='E09919',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩城\u3000裕一',
        submitter_name_en=None,
        submitter_name_yomi='イワキ\u3000ユウイチ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09925': EdinetCodeEntry(
        edinet_code='E09925',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福村善光',
        submitter_name_en=None,
        submitter_name_yomi='フクムラヨシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09948': EdinetCodeEntry(
        edinet_code='E09948',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野田勝憲',
        submitter_name_en=None,
        submitter_name_yomi='ノダカツノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09956': EdinetCodeEntry(
        edinet_code='E09956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷\u3000秋子',
        submitter_name_en=None,
        submitter_name_yomi='タニ\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09957': EdinetCodeEntry(
        edinet_code='E09957',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二木\u3000浩三',
        submitter_name_en=None,
        submitter_name_yomi='フタギ\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09958': EdinetCodeEntry(
        edinet_code='E09958',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古川國久',
        submitter_name_en=None,
        submitter_name_yomi='フルカワクニヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09977': EdinetCodeEntry(
        edinet_code='E09977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='敷田\u3000憲治',
        submitter_name_en=None,
        submitter_name_yomi='シキタ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09984': EdinetCodeEntry(
        edinet_code='E09984',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鶴見\u3000哲',
        submitter_name_en=None,
        submitter_name_yomi='ツルミ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09985': EdinetCodeEntry(
        edinet_code='E09985',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000武治',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000タケハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E09994': EdinetCodeEntry(
        edinet_code='E09994',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5000,
        fiscal_year_end=None,
        submitter_name='上田八木短資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウエダヤギタンシカブシキガイシャ',
        address='大阪市中央区高麗橋二丁目４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001077364',
    ),
    'E10004': EdinetCodeEntry(
        edinet_code='E10004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山崎\u3000嘉忠',
        submitter_name_en=None,
        submitter_name_yomi='ヤマサキ\u3000ヨシタダ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10007': EdinetCodeEntry(
        edinet_code='E10007',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川本公夫',
        submitter_name_en=None,
        submitter_name_yomi='カワモトキミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10011': EdinetCodeEntry(
        edinet_code='E10011',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='生悦住\u3000望',
        submitter_name_en=None,
        submitter_name_yomi='イケズミ\u3000ノゾム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10028': EdinetCodeEntry(
        edinet_code='E10028',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='大東通商株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイトウツウショウカブシキカイシャ',
        address='新宿区市谷台町６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101062340',
    ),
    'E10037': EdinetCodeEntry(
        edinet_code='E10037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='有限会社佐々興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャササコウサン',
        address='大阪市生野区勝山北１丁目１８番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120002009539',
    ),
    'E10052': EdinetCodeEntry(
        edinet_code='E10052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小森\u3000裕作',
        submitter_name_en=None,
        submitter_name_yomi='コモリ\u3000ユウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10081': EdinetCodeEntry(
        edinet_code='E10081',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='カネエム工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カネエムコウギョウカブシキガイシャ',
        address='八尾市泉町１丁目９３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9122001018109',
    ),
    'E10085': EdinetCodeEntry(
        edinet_code='E10085',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='パインブリッジ・インベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パインブリッジインベストメンツカブシキガイシャ',
        address='千代田区大手町一丁目３番１号ＪＡビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001011855',
    ),
    'E10089': EdinetCodeEntry(
        edinet_code='E10089',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大塚\u3000隆一',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000リュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10093': EdinetCodeEntry(
        edinet_code='E10093',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社巴ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャトモエホールディングス',
        address='名古屋市天白区表山三丁目２４２６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180002058107',
    ),
    'E10099': EdinetCodeEntry(
        edinet_code='E10099',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000卓也',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10104': EdinetCodeEntry(
        edinet_code='E10104',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000博章',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10112': EdinetCodeEntry(
        edinet_code='E10112',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='インダス・キャピタル・パートナーズ・エル・エル・シー',
        submitter_name_en=None,
        submitter_name_yomi='インダスキャピタルパートナーズエルエルシー',
        address='米国、郵便番号１００１９、ニューヨーク州、ニューヨーク、ブロードウェイ１７００、３９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10121': EdinetCodeEntry(
        edinet_code='E10121',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000宗治',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ムネハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10123': EdinetCodeEntry(
        edinet_code='E10123',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='エルティサンダビー・ヴィー・ビー・エー（ＬＴＳａｎｄａ\u3000Ｂ．Ｖ．Ｂ．Ａ．）',
        submitter_name_en=None,
        submitter_name_yomi='エルティサンダビーヴィービーエー',
        address='ヴアン\u3000オーヴアーベケラアン\u3000１８２\u3000３４、１０８３\u3000ガンシヨーレン、ベルギー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10126': EdinetCodeEntry(
        edinet_code='E10126',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石垣\u3000靖子',
        submitter_name_en=None,
        submitter_name_yomi='イシガキ\u3000セイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10152': EdinetCodeEntry(
        edinet_code='E10152',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社キャピタルギャラリー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキャピタルギャラリー',
        address='渋谷区南平台町９番１８号－３１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001044975',
    ),
    'E10164': EdinetCodeEntry(
        edinet_code='E10164',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川嶋\u3000真理',
        submitter_name_en=None,
        submitter_name_yomi='カワシマ\u3000マリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10173': EdinetCodeEntry(
        edinet_code='E10173',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木下\u3000守',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000マモル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10174': EdinetCodeEntry(
        edinet_code='E10174',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木下\u3000陽子',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10177': EdinetCodeEntry(
        edinet_code='E10177',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='和井田\u3000俶生',
        submitter_name_en=None,
        submitter_name_yomi='ワイダ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10180': EdinetCodeEntry(
        edinet_code='E10180',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＩＭＰＬＥＸ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンプレクス',
        address='千代田区丸の内１－５－１\u3000新丸の内ビルディング２７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001109934',
    ),
    'E10181': EdinetCodeEntry(
        edinet_code='E10181',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='和井田\u3000光生',
        submitter_name_en=None,
        submitter_name_yomi='ワイダ\u3000ミツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10189': EdinetCodeEntry(
        edinet_code='E10189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉澤\u3000信男',
        submitter_name_en=None,
        submitter_name_yomi='ヨシザワ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10197': EdinetCodeEntry(
        edinet_code='E10197',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙宮\u3000東実',
        submitter_name_en=None,
        submitter_name_yomi='タカミヤ\u3000トウジツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10198': EdinetCodeEntry(
        edinet_code='E10198',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙宮\u3000一雅',
        submitter_name_en=None,
        submitter_name_yomi='タカミヤ\u3000カズマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10201': EdinetCodeEntry(
        edinet_code='E10201',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000敏行',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10202': EdinetCodeEntry(
        edinet_code='E10202',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤範久',
        submitter_name_en=None,
        submitter_name_yomi='イトウノリヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10203': EdinetCodeEntry(
        edinet_code='E10203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='権田\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='ゴンダ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10206': EdinetCodeEntry(
        edinet_code='E10206',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑\u3000慎也',
        submitter_name_en=None,
        submitter_name_yomi='ハタ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10207': EdinetCodeEntry(
        edinet_code='E10207',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西端\u3000慶久',
        submitter_name_en=None,
        submitter_name_yomi='ニシバタ\u3000ヨシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10215': EdinetCodeEntry(
        edinet_code='E10215',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='丸田産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルタサンギョウカブシキガイシャ',
        address='岡山市北区本町６番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7260001006328',
    ),
    'E10227': EdinetCodeEntry(
        edinet_code='E10227',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＳＢＩインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイインベストメントカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401045023',
    ),
    'E10232': EdinetCodeEntry(
        edinet_code='E10232',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000秋彦',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10233': EdinetCodeEntry(
        edinet_code='E10233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000義博',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10235': EdinetCodeEntry(
        edinet_code='E10235',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中島\u3000崇',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10236': EdinetCodeEntry(
        edinet_code='E10236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000弘明',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10264': EdinetCodeEntry(
        edinet_code='E10264',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上田\u3000祐司',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10275': EdinetCodeEntry(
        edinet_code='E10275',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小嶋\u3000成夫',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000シゲオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10292': EdinetCodeEntry(
        edinet_code='E10292',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=638,
        fiscal_year_end=None,
        submitter_name='バーガンディ・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バーガンディアセットマネジメントリミテッド',
        address='カナダ\u3000Ｍ５Ｊ\u3000２Ｔ３\u3000オンタリオ、トロント、ベイ・ストリート１８１、ブルックフィールド・プレイス、スウィート４５１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10296': EdinetCodeEntry(
        edinet_code='E10296',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='小澤物産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オザワブッサンカブシキガイシャ',
        address='品川区西五反田７丁目２４番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010701002055',
    ),
    'E10298': EdinetCodeEntry(
        edinet_code='E10298',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='カレッジ・リタイアメント・エクイティーズ・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='カレッジリタイアメントエクイティーズファンド',
        address='米国ニューヨーク州１００１７、ニューヨーク市サード・アヴェニュー７３０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10300': EdinetCodeEntry(
        edinet_code='E10300',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000將人',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10301': EdinetCodeEntry(
        edinet_code='E10301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='太田\u3000正志',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10313': EdinetCodeEntry(
        edinet_code='E10313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000明男',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10318': EdinetCodeEntry(
        edinet_code='E10318',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=750,
        fiscal_year_end=None,
        submitter_name='株式会社辰巳商会',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタツミショウカイ',
        address='大阪市港区築港四丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001029347',
    ),
    'E10347': EdinetCodeEntry(
        edinet_code='E10347',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='株式会社ジュンプランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャ\u3000ジュンプランニング',
        address='越谷市南町２丁目２３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001038250',
    ),
    'E10352': EdinetCodeEntry(
        edinet_code='E10352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鳴本\u3000聡一郎',
        submitter_name_en=None,
        submitter_name_yomi='ナルモト\u3000ソウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10360': EdinetCodeEntry(
        edinet_code='E10360',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榊原\u3000暢宏',
        submitter_name_en=None,
        submitter_name_yomi='サカキバラ\u3000ノブヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10369': EdinetCodeEntry(
        edinet_code='E10369',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='辻本\u3000治',
        submitter_name_en=None,
        submitter_name_yomi='ツジモト\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10376': EdinetCodeEntry(
        edinet_code='E10376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社トーテム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトーテム',
        address='港区南青山７－８－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401057879',
    ),
    'E10383': EdinetCodeEntry(
        edinet_code='E10383',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='正渡\u3000康弘',
        submitter_name_en=None,
        submitter_name_yomi='ショウド\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10385': EdinetCodeEntry(
        edinet_code='E10385',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ビッグモーター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビッグモーター',
        address='港区六本木６丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9250001011590',
    ),
    'E10387': EdinetCodeEntry(
        edinet_code='E10387',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社神戸アート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカンベアート',
        address='尾張旭市南本地ヶ原町３丁目８３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001079782',
    ),
    'E10389': EdinetCodeEntry(
        edinet_code='E10389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西郷\u3000辰弘',
        submitter_name_en=None,
        submitter_name_yomi='サイゴウ\u3000タツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10390': EdinetCodeEntry(
        edinet_code='E10390',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='グローバル・ブレイン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グローバルブレインカブシキガイシャ',
        address='渋谷区渋谷二丁目１７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401077766',
    ),
    'E10411': EdinetCodeEntry(
        edinet_code='E10411',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000一和雄',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000イワオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10423': EdinetCodeEntry(
        edinet_code='E10423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前島\u3000達也',
        submitter_name_en=None,
        submitter_name_yomi='マエシマ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10439': EdinetCodeEntry(
        edinet_code='E10439',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='ピクテ・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピクテジャパンカブシキカイシヤ',
        address='千代田区丸の内二丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001027269',
    ),
    'E10443': EdinetCodeEntry(
        edinet_code='E10443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='若林\u3000和芳',
        submitter_name_en=None,
        submitter_name_yomi='ワカバヤシ\u3000カズヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10449': EdinetCodeEntry(
        edinet_code='E10449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26,
        fiscal_year_end=None,
        submitter_name='株式会社大谷製作所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオタニセイサクショ',
        address='燕市吉田下中野１４６２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2110001015736',
    ),
    'E10476': EdinetCodeEntry(
        edinet_code='E10476',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000広共',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ヒロキョウ',
        address='広島市中区本通９－３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001025408',
    ),
    'E10479': EdinetCodeEntry(
        edinet_code='E10479',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='信太\u3000明',
        submitter_name_en=None,
        submitter_name_yomi='シダ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10500': EdinetCodeEntry(
        edinet_code='E10500',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='伊藤忠テクノロジーベンチャーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イトウチュウテクノロジーベンチャーズカブシキカイシャ',
        address='港区北青山２丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401041838',
    ),
    'E10501': EdinetCodeEntry(
        edinet_code='E10501',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='大一殖産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイイチショクサンカブシキガイシャ',
        address='中央区八丁堀３丁目２８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001048803',
    ),
    'E10510': EdinetCodeEntry(
        edinet_code='E10510',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三吉野\u3000健滋',
        submitter_name_en=None,
        submitter_name_yomi='ミヨシノ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10530': EdinetCodeEntry(
        edinet_code='E10530',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000幸一',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10535': EdinetCodeEntry(
        edinet_code='E10535',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=450,
        fiscal_year_end=None,
        submitter_name='アクサ・インベストメント・マネージャーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アクサインベストメントマネージャーズカブシキカイシャ',
        address='港区白金一丁目１７番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401061149',
    ),
    'E10536': EdinetCodeEntry(
        edinet_code='E10536',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000岩谷直治記念財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000イワタニナオジキネンザイダン',
        address='千代田区内幸町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005018098',
    ),
    'E10538': EdinetCodeEntry(
        edinet_code='E10538',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舘本\u3000勲武',
        submitter_name_en=None,
        submitter_name_yomi='タチモト\u3000イサタケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10541': EdinetCodeEntry(
        edinet_code='E10541',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡本\u3000泰彦',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000ヤスヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10542': EdinetCodeEntry(
        edinet_code='E10542',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=335000,
        fiscal_year_end=None,
        submitter_name='ＮＴＴ東日本株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティヒガシニホンカブシキガイシャ',
        address='新宿区西新宿三丁目１９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101028104',
    ),
    'E10543': EdinetCodeEntry(
        edinet_code='E10543',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菊地\u3000俊雄',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10544': EdinetCodeEntry(
        edinet_code='E10544',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000美奈子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ミナコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10545': EdinetCodeEntry(
        edinet_code='E10545',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000映子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10546': EdinetCodeEntry(
        edinet_code='E10546',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000節子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000セツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10550': EdinetCodeEntry(
        edinet_code='E10550',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='協友商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウユウショウジカブシキカイシャ',
        address='船橋市本町７丁目５番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9040001017147',
    ),
    'E10578': EdinetCodeEntry(
        edinet_code='E10578',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青山\u3000満',
        submitter_name_en=None,
        submitter_name_yomi='アオヤマ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10586': EdinetCodeEntry(
        edinet_code='E10586',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=87,
        fiscal_year_end=None,
        submitter_name='有限会社\u3000伊部',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャ\u3000イベ',
        address='港区東新橋一丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010402022381',
    ),
    'E10589': EdinetCodeEntry(
        edinet_code='E10589',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石川\u3000光久',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000ミツヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10593': EdinetCodeEntry(
        edinet_code='E10593',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長嶋\u3000貴之',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10601': EdinetCodeEntry(
        edinet_code='E10601',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10616,
        fiscal_year_end=None,
        submitter_name='株式会社ジェーシービー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェーシービー',
        address='港区南青山５－１－２２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401050511',
    ),
    'E10602': EdinetCodeEntry(
        edinet_code='E10602',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本郷秀之',
        submitter_name_en=None,
        submitter_name_yomi='ホンゴウヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10603': EdinetCodeEntry(
        edinet_code='E10603',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉本\u3000宏之',
        submitter_name_en=None,
        submitter_name_yomi='スギモト\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10614': EdinetCodeEntry(
        edinet_code='E10614',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金光\u3000俊明',
        submitter_name_en=None,
        submitter_name_yomi='カネミツ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10646': EdinetCodeEntry(
        edinet_code='E10646',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='盛田エンタプライズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モリタエンタプライズカブシキガイシャ',
        address='名古屋市中区栄１－７－３４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001034144',
    ),
    'E10647': EdinetCodeEntry(
        edinet_code='E10647',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='萩原\u3000義昭',
        submitter_name_en=None,
        submitter_name_yomi='ハギワラ\u3000ヨシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10657': EdinetCodeEntry(
        edinet_code='E10657',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1612,
        fiscal_year_end='2月末日',
        submitter_name='マックスバリュ九州株式会社',
        submitter_name_en='MAXVALU KYUSHU CO., LTD.',
        submitter_name_yomi='マックスバリュキュウシュウカブシキガイシャ',
        address='福岡市博多区大井２丁目３－１',
        industry='小売業',
        sec_code=None,
        corporate_number='4290001022069',
    ),
    'E10670': EdinetCodeEntry(
        edinet_code='E10670',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=370,
        fiscal_year_end=None,
        submitter_name='シンプレクス・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンプレクスアセットマネジメントカブシキカイシャ',
        address='千代田区丸の内１―５―１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001066608',
    ),
    'E10671': EdinetCodeEntry(
        edinet_code='E10671',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='寺浦興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テラウラコウサンカブシキカイシャ',
        address='宝塚市栄町１丁目１２番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001081798',
    ),
    'E10675': EdinetCodeEntry(
        edinet_code='E10675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='折田\u3000譲治',
        submitter_name_en=None,
        submitter_name_yomi='オリタ\u3000ジョウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10677': EdinetCodeEntry(
        edinet_code='E10677',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='アセットマネジメントＯｎｅ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アセットマネジメントワンカブシキカイシャ',
        address='千代田区丸の内一丁目８番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001021473',
    ),
    'E10678': EdinetCodeEntry(
        edinet_code='E10678',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日比野\u3000晃久',
        submitter_name_en=None,
        submitter_name_yomi='ヒビノ\u3000テルヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10687': EdinetCodeEntry(
        edinet_code='E10687',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山西\u3000みき子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマニシ\u3000ミキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10694': EdinetCodeEntry(
        edinet_code='E10694',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内藤\u3000裕紀',
        submitter_name_en=None,
        submitter_name_yomi='ナイトウ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10709': EdinetCodeEntry(
        edinet_code='E10709',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='粟田\u3000貴也',
        submitter_name_en=None,
        submitter_name_yomi='アワタ\u3000タカヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10717': EdinetCodeEntry(
        edinet_code='E10717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=53,
        fiscal_year_end=None,
        submitter_name='株式会社小松安弘興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコマツヤスヒロコウサン',
        address='港区麻布台二丁目１番２号－１０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401067618',
    ),
    'E10725': EdinetCodeEntry(
        edinet_code='E10725',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上田\u3000満弘',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000ミツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10734': EdinetCodeEntry(
        edinet_code='E10734',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青木\u3000保外志',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ヤストシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10737': EdinetCodeEntry(
        edinet_code='E10737',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=16749,
        fiscal_year_end='5月20日',
        submitter_name='株式会社クスリのアオキホールディングス',
        submitter_name_en='KUSURI NO AOKI HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャクスリノアオキホールディングス',
        address='白山市松本町２５１２番地',
        industry='小売業',
        sec_code='35490',
        corporate_number='9220002009323',
    ),
    'E10741': EdinetCodeEntry(
        edinet_code='E10741',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山岡\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='ヤマオカ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10744': EdinetCodeEntry(
        edinet_code='E10744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=360,
        fiscal_year_end=None,
        submitter_name='株式会社泉興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイズミコウサン',
        address='中央区月島４－１６－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5080101012584',
    ),
    'E10747': EdinetCodeEntry(
        edinet_code='E10747',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋敬一',
        submitter_name_en=None,
        submitter_name_yomi='タカハシケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10750': EdinetCodeEntry(
        edinet_code='E10750',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山下\u3000尚登',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000ナオト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10767': EdinetCodeEntry(
        edinet_code='E10767',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大阪市',
        submitter_name_en=None,
        submitter_name_yomi='オオサカシ',
        address='大阪市北区中之島１丁目３番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6000020271004',
    ),
    'E10782': EdinetCodeEntry(
        edinet_code='E10782',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川路\u3000耕一',
        submitter_name_en=None,
        submitter_name_yomi='カワジ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10795': EdinetCodeEntry(
        edinet_code='E10795',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社キャピタル・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャキャピタルマネジメント',
        address='港区南麻布１－２７－２２－２０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010402035726',
    ),
    'E10799': EdinetCodeEntry(
        edinet_code='E10799',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000英一',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10802': EdinetCodeEntry(
        edinet_code='E10802',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=62149,
        fiscal_year_end='3月末日',
        submitter_name='モルガン・スタンレーＭＵＦＧ証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モルガンスタンレーエムユーエフジーショウケンカブシキガイシャ',
        address='千代田区大手町一丁目９番７号大手町フィナンシャルシティサウスタワー',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='2011001046046',
    ),
    'E10807': EdinetCodeEntry(
        edinet_code='E10807',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000博敏',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヒロトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10813': EdinetCodeEntry(
        edinet_code='E10813',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中野\u3000敏光',
        submitter_name_en=None,
        submitter_name_yomi='ナカノ\u3000トシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10840': EdinetCodeEntry(
        edinet_code='E10840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩井\u3000辰男',
        submitter_name_en=None,
        submitter_name_yomi='シオイ\u3000タツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10850': EdinetCodeEntry(
        edinet_code='E10850',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=180,
        fiscal_year_end=None,
        submitter_name='コロンビア・ワンガー・アセット・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='コロンビアワンガーアセットマネジメントエルエルシー',
        address='アメリカ合衆国６０６０６－４６３７イリノイ州シカゴ市サウス・ワッカー・ドライブ７１スイート２５００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10862': EdinetCodeEntry(
        edinet_code='E10862',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤本\u3000彰',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10867': EdinetCodeEntry(
        edinet_code='E10867',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松田\u3000芳久',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000ヨシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10868': EdinetCodeEntry(
        edinet_code='E10868',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙松\u3000喜与志',
        submitter_name_en=None,
        submitter_name_yomi='タカマツ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10870': EdinetCodeEntry(
        edinet_code='E10870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小方\u3000功',
        submitter_name_en=None,
        submitter_name_yomi='オガタ\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10873': EdinetCodeEntry(
        edinet_code='E10873',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤良雄',
        submitter_name_en=None,
        submitter_name_yomi='サトウヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10874': EdinetCodeEntry(
        edinet_code='E10874',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1371153,
        fiscal_year_end=None,
        submitter_name='クレディ・スイス・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスインターナショナル',
        address='英国\u3000ロンドン\u3000Ｅ１４\u3000４ＱＪ、ワン・カボット・スクウェア',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10875': EdinetCodeEntry(
        edinet_code='E10875',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社データ・アート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデータアート',
        address='渋谷区東１－３２－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001039711',
    ),
    'E10884': EdinetCodeEntry(
        edinet_code='E10884',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本産業パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンサンギョウパートナーズカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001094082',
    ),
    'E10888': EdinetCodeEntry(
        edinet_code='E10888',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='代永衛',
        submitter_name_en=None,
        submitter_name_yomi='ヨナガマモリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10895': EdinetCodeEntry(
        edinet_code='E10895',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇山\u3000忠男',
        submitter_name_en=None,
        submitter_name_yomi='ウヤマ\u3000タダオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10896': EdinetCodeEntry(
        edinet_code='E10896',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇山\u3000知成',
        submitter_name_en=None,
        submitter_name_yomi='ウヤマ\u3000トモナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10900': EdinetCodeEntry(
        edinet_code='E10900',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000敬',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10906': EdinetCodeEntry(
        edinet_code='E10906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堂山道生',
        submitter_name_en=None,
        submitter_name_yomi='ドウヤマミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10922': EdinetCodeEntry(
        edinet_code='E10922',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='隅田\u3000和夫',
        submitter_name_en=None,
        submitter_name_yomi='スミタ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10933': EdinetCodeEntry(
        edinet_code='E10933',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='目黒\u3000俊治',
        submitter_name_en=None,
        submitter_name_yomi='メグロ\u3000シュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10935': EdinetCodeEntry(
        edinet_code='E10935',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社サンクプランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンクプランニング',
        address='和歌山市西高松一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7170001002501',
    ),
    'E10936': EdinetCodeEntry(
        edinet_code='E10936',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社マーキュリアインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマーキュリアインベストメント',
        address='千代田区内幸町一丁目３番３号内幸町ダイビル',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='2010001126667',
    ),
    'E10960': EdinetCodeEntry(
        edinet_code='E10960',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='沼田\u3000昭二',
        submitter_name_en=None,
        submitter_name_yomi='ヌマタ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10985': EdinetCodeEntry(
        edinet_code='E10985',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三島\u3000美佐夫',
        submitter_name_en=None,
        submitter_name_yomi='ミシマ\u3000ミサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10987': EdinetCodeEntry(
        edinet_code='E10987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='牛嶋\u3000英揚',
        submitter_name_en=None,
        submitter_name_yomi='ウシジマ\u3000ヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10988': EdinetCodeEntry(
        edinet_code='E10988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菅原\u3000雅史',
        submitter_name_en=None,
        submitter_name_yomi='スガワラ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10994': EdinetCodeEntry(
        edinet_code='E10994',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊野\u3000英介',
        submitter_name_en=None,
        submitter_name_yomi='クマノ\u3000エイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E10996': EdinetCodeEntry(
        edinet_code='E10996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西川\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11001': EdinetCodeEntry(
        edinet_code='E11001',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米今\u3000政臣',
        submitter_name_en=None,
        submitter_name_yomi='ヨネイマ\u3000マサオミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11014': EdinetCodeEntry(
        edinet_code='E11014',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前\u3000俊守',
        submitter_name_en=None,
        submitter_name_yomi='マエ\u3000トシモリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11023': EdinetCodeEntry(
        edinet_code='E11023',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000類',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ルイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11027': EdinetCodeEntry(
        edinet_code='E11027',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=78100,
        fiscal_year_end=None,
        submitter_name='クレディ・スイス証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスショウケンカブシキカイシャ',
        address='港区六本木一丁目６番１号泉ガーデンタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401059260',
    ),
    'E11029': EdinetCodeEntry(
        edinet_code='E11029',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=463288,
        fiscal_year_end='12月末日',
        submitter_name='クレディ・スイス・エイ・ジー',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスエイジー',
        address='スイス国チューリッヒ、８００１、パラデプラッツ８番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E11042': EdinetCodeEntry(
        edinet_code='E11042',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='寺田倉庫株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テラダソウコカブシキガイシャ',
        address='品川区東品川２丁目６番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010701006378',
    ),
    'E11043': EdinetCodeEntry(
        edinet_code='E11043',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平\u3000邦雄',
        submitter_name_en=None,
        submitter_name_yomi='タイラ\u3000クニオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11045': EdinetCodeEntry(
        edinet_code='E11045',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田義彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダヨシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11048': EdinetCodeEntry(
        edinet_code='E11048',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='鈴与商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スズヨショウジカブシキカイシャ',
        address='静岡市清水区入船町１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1080001002318',
    ),
    'E11060': EdinetCodeEntry(
        edinet_code='E11060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小髙\u3000得央',
        submitter_name_en=None,
        submitter_name_yomi='コタカ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11077': EdinetCodeEntry(
        edinet_code='E11077',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='2月末日',
        submitter_name='清川商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キヨカワショウジカブシキガイシャ',
        address='港区芝大門二丁目５番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='7010401063786',
    ),
    'E11088': EdinetCodeEntry(
        edinet_code='E11088',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ルコンテ小川\u3000珠里',
        submitter_name_en=None,
        submitter_name_yomi='ルコンテオガワ\u3000ジュリ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11090': EdinetCodeEntry(
        edinet_code='E11090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙谷\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='タカタニ\u3000ショウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11094': EdinetCodeEntry(
        edinet_code='E11094',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社あさしお',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャアサシオ',
        address='大田区田園調布３丁目１２－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010802017641',
    ),
    'E11099': EdinetCodeEntry(
        edinet_code='E11099',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米多比\u3000昌治',
        submitter_name_en=None,
        submitter_name_yomi='メタビ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11118': EdinetCodeEntry(
        edinet_code='E11118',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中邦裕',
        submitter_name_en=None,
        submitter_name_yomi='タナカクニヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11137': EdinetCodeEntry(
        edinet_code='E11137',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中浜\u3000勇',
        submitter_name_en=None,
        submitter_name_yomi='ナカハマ\u3000イサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11138': EdinetCodeEntry(
        edinet_code='E11138',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中浜\u3000勇治',
        submitter_name_en=None,
        submitter_name_yomi='ナカハマ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11143': EdinetCodeEntry(
        edinet_code='E11143',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000重久',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000シゲヒサ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11145': EdinetCodeEntry(
        edinet_code='E11145',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小池\u3000信三',
        submitter_name_en=None,
        submitter_name_yomi='コイケ\u3000シンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11147': EdinetCodeEntry(
        edinet_code='E11147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='池谷保彦',
        submitter_name_en=None,
        submitter_name_yomi='イケヤヤスヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11151': EdinetCodeEntry(
        edinet_code='E11151',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月末日',
        submitter_name='光南商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウナンショウジカブシキガイシャ',
        address='港区芝大門二丁目５番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010401009781',
    ),
    'E11152': EdinetCodeEntry(
        edinet_code='E11152',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='笠原\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='カサハラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11161': EdinetCodeEntry(
        edinet_code='E11161',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2500,
        fiscal_year_end=None,
        submitter_name='スパークス・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スパークスアセットマネジメントカブシキガイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010701017007',
    ),
    'E11171': EdinetCodeEntry(
        edinet_code='E11171',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金親晋午',
        submitter_name_en=None,
        submitter_name_yomi='カナオヤシンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11174': EdinetCodeEntry(
        edinet_code='E11174',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一瀬\u3000邦夫',
        submitter_name_en=None,
        submitter_name_yomi='イチノセ\u3000クニオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11184': EdinetCodeEntry(
        edinet_code='E11184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柿原\u3000健晴',
        submitter_name_en=None,
        submitter_name_yomi='カキハラ\u3000ケンセイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11189': EdinetCodeEntry(
        edinet_code='E11189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水永\u3000政志',
        submitter_name_en=None,
        submitter_name_yomi='ミズナガ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11190': EdinetCodeEntry(
        edinet_code='E11190',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古屋\u3000堯民',
        submitter_name_en=None,
        submitter_name_yomi='フルヤ\u3000タカヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11197': EdinetCodeEntry(
        edinet_code='E11197',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='玉田\u3000宏一',
        submitter_name_en=None,
        submitter_name_yomi='タマダ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11198': EdinetCodeEntry(
        edinet_code='E11198',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=83616,
        fiscal_year_end=None,
        submitter_name='ゴールドマン・サックス証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゴールドマンサックスショウケンカブシキガイシャ',
        address='港区虎ノ門二丁目６番１号虎ノ門ヒルズステーションタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401059056',
    ),
    'E11203': EdinetCodeEntry(
        edinet_code='E11203',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ケプラム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケプラム',
        address='千代田区一番町２０番地６－２０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011101036868',
    ),
    'E11204': EdinetCodeEntry(
        edinet_code='E11204',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村井\u3000昭',
        submitter_name_en=None,
        submitter_name_yomi='ムライ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11210': EdinetCodeEntry(
        edinet_code='E11210',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40000,
        fiscal_year_end=None,
        submitter_name='富士フイルム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジフイルムカブシキガイシャ',
        address='港区西麻布２丁目２６番３０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401064789',
    ),
    'E11213': EdinetCodeEntry(
        edinet_code='E11213',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000章博',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11214': EdinetCodeEntry(
        edinet_code='E11214',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐山\u3000展生',
        submitter_name_en=None,
        submitter_name_yomi='サヤマ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11216': EdinetCodeEntry(
        edinet_code='E11216',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000礼二郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000レイジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11249': EdinetCodeEntry(
        edinet_code='E11249',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堤\u3000純也',
        submitter_name_en=None,
        submitter_name_yomi='ツツミ\u3000ジュンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11255': EdinetCodeEntry(
        edinet_code='E11255',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='足立\u3000建一郎',
        submitter_name_en=None,
        submitter_name_yomi='アダチ\u3000ケンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11260': EdinetCodeEntry(
        edinet_code='E11260',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日章興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッショウコウサンカブシキガイシャ',
        address='中央区銀座４－１２－１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401021744',
    ),
    'E11266': EdinetCodeEntry(
        edinet_code='E11266',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田島\u3000克洋',
        submitter_name_en=None,
        submitter_name_yomi='タシマ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11272': EdinetCodeEntry(
        edinet_code='E11272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000高志',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11274': EdinetCodeEntry(
        edinet_code='E11274',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000悟',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11277': EdinetCodeEntry(
        edinet_code='E11277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000敏男',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11286': EdinetCodeEntry(
        edinet_code='E11286',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='剣持\u3000忠',
        submitter_name_en=None,
        submitter_name_yomi='ケンモチ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11293': EdinetCodeEntry(
        edinet_code='E11293',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='葉田\u3000順治',
        submitter_name_en=None,
        submitter_name_yomi='ハダ\u3000ジュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11294': EdinetCodeEntry(
        edinet_code='E11294',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社エスティオ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスティオ',
        address='甲斐市竜地３０４９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5090001000275',
    ),
    'E11316': EdinetCodeEntry(
        edinet_code='E11316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='新田\u3000二郎',
        submitter_name_en=None,
        submitter_name_yomi='ニッタ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11326': EdinetCodeEntry(
        edinet_code='E11326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000隆一',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000リュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11338': EdinetCodeEntry(
        edinet_code='E11338',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='ベイリー・ギフォード・オーバーシーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ベイリーギフォードオーバーシーズリミテッド',
        address='カルトン・スクエア、１グリーンサイド・ロウ、エジンバラＥＨ１\u3000３ＡＮ\u3000スコットランド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11341': EdinetCodeEntry(
        edinet_code='E11341',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='梅田弘之',
        submitter_name_en=None,
        submitter_name_yomi='ウメダヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11348': EdinetCodeEntry(
        edinet_code='E11348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=250,
        fiscal_year_end=None,
        submitter_name='ベアリングス・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ベアリングスジャパンカブシキガイシャ',
        address='中央区京橋二丁目２番１号\u3000京橋エドグラン',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001028755',
    ),
    'E11352': EdinetCodeEntry(
        edinet_code='E11352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村直樹',
        submitter_name_en=None,
        submitter_name_yomi='キムラナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11358': EdinetCodeEntry(
        edinet_code='E11358',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000宣夫',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11362': EdinetCodeEntry(
        edinet_code='E11362',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日置勇二',
        submitter_name_en=None,
        submitter_name_yomi='ヒオキユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11365': EdinetCodeEntry(
        edinet_code='E11365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000大一',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ダイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11387': EdinetCodeEntry(
        edinet_code='E11387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000靖司',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11398': EdinetCodeEntry(
        edinet_code='E11398',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ブレット\u3000ダンドイ',
        submitter_name_en=None,
        submitter_name_yomi='ブレット\u3000ダンドイ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11399': EdinetCodeEntry(
        edinet_code='E11399',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鳥越\u3000慎二',
        submitter_name_en=None,
        submitter_name_yomi='トリゴエ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11400': EdinetCodeEntry(
        edinet_code='E11400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹原\u3000大',
        submitter_name_en=None,
        submitter_name_yomi='タケハラ\u3000ダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11408': EdinetCodeEntry(
        edinet_code='E11408',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='モバイル・インターネットキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モバイルインターネットキャピタルカブシキガイシャ',
        address='千代田区霞が関３－２－５\u3000霞が関ビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401039322',
    ),
    'E11419': EdinetCodeEntry(
        edinet_code='E11419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松田\u3000憲幸',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11422': EdinetCodeEntry(
        edinet_code='E11422',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='新美\u3000司',
        submitter_name_en=None,
        submitter_name_yomi='ニイミ\u3000ツカサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11423': EdinetCodeEntry(
        edinet_code='E11423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000吉武',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヨシタケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11429': EdinetCodeEntry(
        edinet_code='E11429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐谷\u3000宣昭',
        submitter_name_en=None,
        submitter_name_yomi='サタニ\u3000ノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11431': EdinetCodeEntry(
        edinet_code='E11431',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='常包浩司',
        submitter_name_en=None,
        submitter_name_yomi='ツネカネ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11432': EdinetCodeEntry(
        edinet_code='E11432',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000洋二',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ヨウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11437': EdinetCodeEntry(
        edinet_code='E11437',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉山\u3000裕一',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11444': EdinetCodeEntry(
        edinet_code='E11444',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='東山明弘',
        submitter_name_en=None,
        submitter_name_yomi='トウヤマアキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11445': EdinetCodeEntry(
        edinet_code='E11445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前田\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000トシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11447': EdinetCodeEntry(
        edinet_code='E11447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ケイエヌジェイ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャ\u3000ケイエヌジェイ',
        address='新宿区矢来町３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011102015956',
    ),
    'E11467': EdinetCodeEntry(
        edinet_code='E11467',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19824,
        fiscal_year_end='3月末日',
        submitter_name='日鉄興和不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッテツコウワフドウサンカブシキガイシャ',
        address='港区赤坂１丁目８番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='8010401055238',
    ),
    'E11469': EdinetCodeEntry(
        edinet_code='E11469',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16,
        fiscal_year_end=None,
        submitter_name='いちごアセットマネジメント・インタ－ナショナル・ピ－ティ－イ－・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='イチゴアセットマネジメントインターナショナルピーティーイーリミテッド',
        address='シンガポ－ル、ハイ\u3000ストリート\u3000センター\u3000＃０６－０８\u3000ノース\u3000ブリッジ\u3000ロード\u3000１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11470': EdinetCodeEntry(
        edinet_code='E11470',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='野村不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラフドウサンカブシキガイシャ',
        address='港区芝浦一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101017056',
    ),
    'E11473': EdinetCodeEntry(
        edinet_code='E11473',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='シービーアールイー・インベストメント・マネジメント・リステッド・リアル・アセッツ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='シービーアールイーインベストメントマネジメントリステッドリアルアセッツエルエルシー',
        address='アメリカ合衆国ペンシルベニア州ラドナー市、キング・オブ・プルシア・ロード２０１番、スイート６００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11493': EdinetCodeEntry(
        edinet_code='E11493',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='折田\u3000節子',
        submitter_name_en=None,
        submitter_name_yomi='オリタ\u3000セツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11505': EdinetCodeEntry(
        edinet_code='E11505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡本和子',
        submitter_name_en=None,
        submitter_name_yomi='オカモトカズコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11510': EdinetCodeEntry(
        edinet_code='E11510',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ティーアイエーエー・シーアールイーエフ・インベストメント・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ティーアイエーエーシーアールイーエフインベストメントマネジメントエルエルシー',
        address='米国ニューヨーク州１００１７、ニューヨーク市サード・アヴェニュー７３０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11513': EdinetCodeEntry(
        edinet_code='E11513',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社無量寿',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャムリョウジュ',
        address='富士市錦町一丁目７番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7080102015205',
    ),
    'E11518': EdinetCodeEntry(
        edinet_code='E11518',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='三菱ＵＦＪアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシユーエフジェイアセットマネジメントカブシキカイシャ',
        address='港区東新橋一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001034450',
    ),
    'E11535': EdinetCodeEntry(
        edinet_code='E11535',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='高速興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウソクコウサンカブシキガイシヤ',
        address='仙台市青葉区立町２３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7370001007975',
    ),
    'E11538': EdinetCodeEntry(
        edinet_code='E11538',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社植村組',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウエムラグミ',
        address='鹿児島市伊敷五丁目９番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7340001000529',
    ),
    'E11540': EdinetCodeEntry(
        edinet_code='E11540',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='近藤\u3000健介',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000ケンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11541': EdinetCodeEntry(
        edinet_code='E11541',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22286,
        fiscal_year_end=None,
        submitter_name='シュローダー・インベストメント・マネージメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シュローダー\u3000インベストメント\u3000マネージメント\u3000リミテッド',
        address='英国\u3000ＥＣ２Ｙ５ＡＵ\u3000ロンドン\u3000ロンドン・ウォール・プレイス１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11543': EdinetCodeEntry(
        edinet_code='E11543',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='グリーンコア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グリーンコアカブシキガイシャ',
        address='渋谷区富ヶ谷１－１４－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001025721',
    ),
    'E11550': EdinetCodeEntry(
        edinet_code='E11550',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='有限会社\u3000学友社',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャ\u3000ガクユウシャ',
        address='鹿児島市城西２丁目２２－１５－１１０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2340002002462',
    ),
    'E11555': EdinetCodeEntry(
        edinet_code='E11555',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='望月圭一郎',
        submitter_name_en=None,
        submitter_name_yomi='モチヅキ\u3000ケイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11564': EdinetCodeEntry(
        edinet_code='E11564',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松元\u3000邦夫',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000クニオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11565': EdinetCodeEntry(
        edinet_code='E11565',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松元\u3000正夫',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11567': EdinetCodeEntry(
        edinet_code='E11567',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='冨田\u3000薫',
        submitter_name_en=None,
        submitter_name_yomi='トミタ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11573': EdinetCodeEntry(
        edinet_code='E11573',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='草間\u3000庸文',
        submitter_name_en=None,
        submitter_name_yomi='クサマ\u3000ツネフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11575': EdinetCodeEntry(
        edinet_code='E11575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田澤\u3000知志',
        submitter_name_en=None,
        submitter_name_yomi='タザワ\u3000トモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11577': EdinetCodeEntry(
        edinet_code='E11577',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000惠子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11584': EdinetCodeEntry(
        edinet_code='E11584',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='児玉\u3000佳子',
        submitter_name_en=None,
        submitter_name_yomi='コダマ\u3000ヨシコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11585': EdinetCodeEntry(
        edinet_code='E11585',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000成一',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11588': EdinetCodeEntry(
        edinet_code='E11588',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='五十嵐\u3000祥剛',
        submitter_name_en=None,
        submitter_name_yomi='イガラシ\u3000ヨシカタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11592': EdinetCodeEntry(
        edinet_code='E11592',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1062,
        fiscal_year_end=None,
        submitter_name='スレッドニードル・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スレッドニードルアセットマネジメントリミテッド',
        address='Ｃａｎｎｏｎ\u3000Ｐｌａｃｅ，７８\u3000Ｃａｎｎｏｎ\u3000Ｓｔｒｅｅｔ，Ｌｏｎｄｏｎ\u3000ＥＣ４Ｎ\u3000６ＡＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11595': EdinetCodeEntry(
        edinet_code='E11595',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='ＭＦＳインベストメント・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエフエスインベストメント\u3000マネジメントカブシキガイシャ',
        address='千代田区霞が関一丁目４番２号大同生命霞が関ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001096996',
    ),
    'E11598': EdinetCodeEntry(
        edinet_code='E11598',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='アローストリート・キャピタル・リミテッド・パートナーシップ',
        submitter_name_en=None,
        submitter_name_yomi='アローストリートキャピタルリミテッドパートナーシップ',
        address='アメリカ合衆国、マサチューセッツ州０２１１６、ボストン、クラレンドン・ストリート２００、３０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11599': EdinetCodeEntry(
        edinet_code='E11599',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中伸明',
        submitter_name_en=None,
        submitter_name_yomi='タナカノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11618': EdinetCodeEntry(
        edinet_code='E11618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大野\u3000利美知',
        submitter_name_en=None,
        submitter_name_yomi='オオノ\u3000トシミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11622': EdinetCodeEntry(
        edinet_code='E11622',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木敏雄',
        submitter_name_en=None,
        submitter_name_yomi='スズキトシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11634': EdinetCodeEntry(
        edinet_code='E11634',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1414227,
        fiscal_year_end=None,
        submitter_name='シティグループ・グローバル・マーケッツ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シティグループグローバルマーケッツリミテッド',
        address='英国ロンドン、カナリーワーフ、カナダスクエア、シティグループセンター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11642': EdinetCodeEntry(
        edinet_code='E11642',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＵＣＣ\u3000Ｃａｐｉｔａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユーシーシーキャピタルカブシキガイシャ',
        address='神戸市中央区多聞通５丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140001012362',
    ),
    'E11648': EdinetCodeEntry(
        edinet_code='E11648',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ラザード・アセット・マネージメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ラザード\u3000アセット\u3000マネージメント\u3000エルエルシー',
        address='ニューヨーク州ニューヨーク市ロックフェラー・プラザ３０番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11651': EdinetCodeEntry(
        edinet_code='E11651',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アミューズキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアミューズキャピタル',
        address='中央区銀座３－１５－８\u3000銀座プラザビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001138742',
    ),
    'E11652': EdinetCodeEntry(
        edinet_code='E11652',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松村\u3000厚久',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000アツヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11654': EdinetCodeEntry(
        edinet_code='E11654',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='關\u3000啓三',
        submitter_name_en=None,
        submitter_name_yomi='セキ\u3000ケイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11661': EdinetCodeEntry(
        edinet_code='E11661',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1639,
        fiscal_year_end='3月31日',
        submitter_name='フリュー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フリューカブシキガイシャ',
        address='渋谷区鶯谷町２番３号',
        industry='機械',
        sec_code='62380',
        corporate_number='3011001049510',
    ),
    'E11676': EdinetCodeEntry(
        edinet_code='E11676',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鎌田\u3000信夫',
        submitter_name_en=None,
        submitter_name_yomi='カマタ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11677': EdinetCodeEntry(
        edinet_code='E11677',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野﨑\u3000隆男',
        submitter_name_en=None,
        submitter_name_yomi='ノザキ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11679': EdinetCodeEntry(
        edinet_code='E11679',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='有限会社欅',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャケヤキ',
        address='宇都宮市山本１丁目３８番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5060002016793',
    ),
    'E11686': EdinetCodeEntry(
        edinet_code='E11686',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤公信',
        submitter_name_en=None,
        submitter_name_yomi='サトウキミノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11687': EdinetCodeEntry(
        edinet_code='E11687',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社池田ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイケダホールディングス',
        address='上田市国分１－４－１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5100001011171',
    ),
    'E11688': EdinetCodeEntry(
        edinet_code='E11688',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社田中企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタナカキカク',
        address='東御市県５３２－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11689': EdinetCodeEntry(
        edinet_code='E11689',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000規幸',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11701': EdinetCodeEntry(
        edinet_code='E11701',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000424,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本政策投資銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッポンセイサクトウシギンコウ',
        address='千代田区大手町一丁目９番６号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='2010001120389',
    ),
    'E11711': EdinetCodeEntry(
        edinet_code='E11711',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=51,
        fiscal_year_end=None,
        submitter_name='株式会社森トラスト・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモリトラスト\u3000ホールディングス',
        address='港区虎ノ門四丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401016481',
    ),
    'E11712': EdinetCodeEntry(
        edinet_code='E11712',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢倉\u3000英一',
        submitter_name_en=None,
        submitter_name_yomi='ヤグラ\u3000ヒデカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11733': EdinetCodeEntry(
        edinet_code='E11733',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3500,
        fiscal_year_end=None,
        submitter_name='国分グループ本社株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コクブグループホンシャカブシキガイシャ',
        address='中央区日本橋１丁目１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001043063',
    ),
    'E11737': EdinetCodeEntry(
        edinet_code='E11737',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='太田万三彦',
        submitter_name_en=None,
        submitter_name_yomi='オオタマサヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11744': EdinetCodeEntry(
        edinet_code='E11744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社石原ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイシハラホールディングス',
        address='台東区東上野一丁目１４番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6360001012960',
    ),
    'E11748': EdinetCodeEntry(
        edinet_code='E11748',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=357,
        fiscal_year_end=None,
        submitter_name='キャピタル・インターナショナル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='キャピタルインターナショナルリミテッド',
        address='英国Ｗ２\u3000１ＧＬ、ロンドン、パディントン・スクエア１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11749': EdinetCodeEntry(
        edinet_code='E11749',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=69,
        fiscal_year_end=None,
        submitter_name='キャピタル・インターナショナル・インク',
        submitter_name_en=None,
        submitter_name_yomi='キャピタルインターナショナルインク',
        address='アメリカ合衆国カリフォルニア州９００７１、ロスアンジェルス、サウスホープ・ストリート３３３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11751': EdinetCodeEntry(
        edinet_code='E11751',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橋本\u3000慶太',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000ケイタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11757': EdinetCodeEntry(
        edinet_code='E11757',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下島\u3000和光',
        submitter_name_en=None,
        submitter_name_yomi='シモジマ\u3000ワコウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11762': EdinetCodeEntry(
        edinet_code='E11762',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢメディアホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーメディアホールディングスカブシキカイシャ',
        address='港区虎ノ門二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401058566',
    ),
    'E11764': EdinetCodeEntry(
        edinet_code='E11764',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1100,
        fiscal_year_end=None,
        submitter_name='Ｔ＆Ｄアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティアンドディアセットマネジメントカブシキガイシャ',
        address='港区芝五丁目３６番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401064261',
    ),
    'E11776': EdinetCodeEntry(
        edinet_code='E11776',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=475,
        fiscal_year_end=None,
        submitter_name='あいグローバル・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイグローバルアセットマネジメントカブシキガイシャ',
        address='港区六本木一丁目６番１号\u3000泉ガーデンタワー７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001065933',
    ),
    'E11793': EdinetCodeEntry(
        edinet_code='E11793',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ビッグサンズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビッグサンズ',
        address='大阪市北区西天満４－８－１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001069421',
    ),
    'E11818': EdinetCodeEntry(
        edinet_code='E11818',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='エアーテックアシスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エアーテックアシストカブシキガイシャ',
        address='草加市吉町五丁目６番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6030001034716',
    ),
    'E11833': EdinetCodeEntry(
        edinet_code='E11833',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岨野公一',
        submitter_name_en=None,
        submitter_name_yomi='ソノコウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11843': EdinetCodeEntry(
        edinet_code='E11843',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=620,
        fiscal_year_end=None,
        submitter_name='モンドリアン・インベストメント・パートナーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='モンドリアンインベストメントパートナーズリミテッド',
        address='英国、ＥＣ２Ｍ\u3000５ＴＱ\u3000ロンドン市、シックスティ・ロンドン・ウォール、１０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11847': EdinetCodeEntry(
        edinet_code='E11847',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北角\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='キタズミ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11852': EdinetCodeEntry(
        edinet_code='E11852',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1330,
        fiscal_year_end=None,
        submitter_name='エフィッシモ\u3000キャピタル\u3000マネージメント\u3000ピーティーイー\u3000エルティーディー（Ｅｆｆｉｓｓｉｍｏ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｐｔｅ\u3000Ｌｔｄ）',
        submitter_name_en=None,
        submitter_name_yomi='エフィッシモキャピタルマネージメントピーティーイーエルティーディー',
        address='２６０\u3000オーチャードロード\u3000＃１２－０６\u3000ザヒーレン\u3000シンガポール\u3000２３８８５５（２６０\u3000Ｏｒｃｈａｒｄ\u3000Ｒｏａｄ\u3000＃１２－０６\u3000Ｔｈｅ\u3000Ｈｅｅｒｅｎ\u3000Ｓｉｎｇａｐｏｒｅ\u3000２３８８５５）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11873': EdinetCodeEntry(
        edinet_code='E11873',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=104873,
        fiscal_year_end='3月31日',
        submitter_name='日本製紙株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンセイシカブシキガイシャ',
        address='北区王子１丁目４番１号',
        industry='パルプ・紙',
        sec_code='38630',
        corporate_number='8011501009422',
    ),
    'E11879': EdinetCodeEntry(
        edinet_code='E11879',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社明晃',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメイコウ',
        address='渋谷区松濤二丁目１番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001051421',
    ),
    'E11891': EdinetCodeEntry(
        edinet_code='E11891',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2102,
        fiscal_year_end=None,
        submitter_name='株式会社マイナビ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマイナビ',
        address='千代田区一ツ橋一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001029968',
    ),
    'E11907': EdinetCodeEntry(
        edinet_code='E11907',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='腰髙\u3000修',
        submitter_name_en=None,
        submitter_name_yomi='コシダカ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11908': EdinetCodeEntry(
        edinet_code='E11908',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='腰髙\u3000博',
        submitter_name_en=None,
        submitter_name_yomi='コシダカ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11914': EdinetCodeEntry(
        edinet_code='E11914',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西通義',
        submitter_name_en=None,
        submitter_name_yomi='オオニシミチヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11920': EdinetCodeEntry(
        edinet_code='E11920',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大谷\u3000卓男',
        submitter_name_en=None,
        submitter_name_yomi='オオタニ\u3000タクオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11923': EdinetCodeEntry(
        edinet_code='E11923',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='ＩＴＪ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイティジェイカブシキガイシャ',
        address='港区芝浦四丁目１６番２３号\u3000アクアシティ芝浦９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401098230',
    ),
    'E11927': EdinetCodeEntry(
        edinet_code='E11927',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クラウンユナイテッド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクラウンユナイテッド',
        address='大田区大森北１－２３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010801003352',
    ),
    'E11935': EdinetCodeEntry(
        edinet_code='E11935',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27482,
        fiscal_year_end=None,
        submitter_name='ウォルター・スコット・アンド・パートナーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウォルター\u3000スコット\u3000アンド\u3000パートナーズ\u3000リミテッド',
        address='英国、スコットランドＥＨ２\u3000４ＤＲ、エジンバラ、ワン・シャルロット・スクエア',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11939': EdinetCodeEntry(
        edinet_code='E11939',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＧＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジーディー',
        address='港区虎ノ門五丁目３番２０号仙石山アネックス３０６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401061174',
    ),
    'E11943': EdinetCodeEntry(
        edinet_code='E11943',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｅｖｏ\u3000Ｆｕｎｄ',
        submitter_name_en=None,
        submitter_name_yomi='エボ\u3000ファンド',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシズ（ケイマン）リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11946': EdinetCodeEntry(
        edinet_code='E11946',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='守本\u3000正宏',
        submitter_name_en=None,
        submitter_name_yomi='モリモト\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11947': EdinetCodeEntry(
        edinet_code='E11947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池上\u3000成朝',
        submitter_name_en=None,
        submitter_name_yomi='イケウエ\u3000ナリトモ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11961': EdinetCodeEntry(
        edinet_code='E11961',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社キタイアンドカンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャキタイアンドカンパニー',
        address='目黒区中央町二丁目２２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7013202001997',
    ),
    'E11962': EdinetCodeEntry(
        edinet_code='E11962',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='アムス・インターナショナル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アムスインターナショナルカブシキガイシャ',
        address='豊島区東池袋１－１５－１２\u3000アムスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2013301016083',
    ),
    'E11977': EdinetCodeEntry(
        edinet_code='E11977',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢＩインキュベーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイインキュベーションカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401046936',
    ),
    'E11982': EdinetCodeEntry(
        edinet_code='E11982',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='隣良郎',
        submitter_name_en=None,
        submitter_name_yomi='チカキヨシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11998': EdinetCodeEntry(
        edinet_code='E11998',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000幸広',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E11999': EdinetCodeEntry(
        edinet_code='E11999',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹中\u3000潤平',
        submitter_name_en=None,
        submitter_name_yomi='タケナカ\u3000ジュンペイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12014': EdinetCodeEntry(
        edinet_code='E12014',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原田\u3000英明',
        submitter_name_en=None,
        submitter_name_yomi='ハラダ\u3000ヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12027': EdinetCodeEntry(
        edinet_code='E12027',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石田\u3000利幸',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12028': EdinetCodeEntry(
        edinet_code='E12028',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石田\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12043': EdinetCodeEntry(
        edinet_code='E12043',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯塚\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='イイズカ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12046': EdinetCodeEntry(
        edinet_code='E12046',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='三田証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミタショウケンカブシキガイシャ',
        address='中央区日本橋兜町３－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001058171',
    ),
    'E12056': EdinetCodeEntry(
        edinet_code='E12056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='馬場\u3000利明',
        submitter_name_en=None,
        submitter_name_yomi='ババ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12081': EdinetCodeEntry(
        edinet_code='E12081',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=640,
        fiscal_year_end=None,
        submitter_name='丸紅シーフーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルベニシーフーズカブシキガイシャ',
        address='港区芝浦４丁目９番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401027125',
    ),
    'E12097': EdinetCodeEntry(
        edinet_code='E12097',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1028859,
        fiscal_year_end=None,
        submitter_name='ノルウェー銀行',
        submitter_name_en=None,
        submitter_name_yomi='ノルウェーギンコウ',
        address='ノルウェー\u3000オスロ\u3000Ｎ‐０１０７\u3000セントラム\u3000私書箱１１７９\u3000バンクプラッセン２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12103': EdinetCodeEntry(
        edinet_code='E12103',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ルネット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャルネット',
        address='港区港南二丁目１６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001062337',
    ),
    'E12114': EdinetCodeEntry(
        edinet_code='E12114',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ジー・コミュニケーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジーコミュニケーション',
        address='名古屋市北区黒川本通二丁目４６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001045018',
    ),
    'E12116': EdinetCodeEntry(
        edinet_code='E12116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社オーエーコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーエーコーポレーション',
        address='江東区塩浜２ー４－２０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010601023705',
    ),
    'E12127': EdinetCodeEntry(
        edinet_code='E12127',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=108,
        fiscal_year_end=None,
        submitter_name='ハイクレア・インターナショナル・インベスターズ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='ハイクレア\u3000インターナショナル\u3000インベスターズ\u3000エルエルピー',
        address='英国ロンドン、ダブリュー１ユー\u3000３ピーピー、マンチェスター・スクウェア\u3000１２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12141': EdinetCodeEntry(
        edinet_code='E12141',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中秀夫',
        submitter_name_en=None,
        submitter_name_yomi='タナカヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12147': EdinetCodeEntry(
        edinet_code='E12147',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8641,
        fiscal_year_end=None,
        submitter_name='クナウフ・インタナショナル・ゲーエムベーハー',
        submitter_name_en=None,
        submitter_name_yomi='クナウフインタナショナルゲーエムベーハー',
        address='ドイツ連邦共和国９７３４６イプホーフェン、アム・バンホフ７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12148': EdinetCodeEntry(
        edinet_code='E12148',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=346,
        fiscal_year_end=None,
        submitter_name='マフューズ・インターナショナル・キャピタル・マネージメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='マフューズインターナショナルキャピタルマネージメントエルエルシー',
        address='アメリカ合衆国カリフォルニア州サンフランシスコ、エンバーカデロ・センター４、スイート５５０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12160': EdinetCodeEntry(
        edinet_code='E12160',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='インフィニティ・アライアンス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='インフィニティアライアンスリミテッド',
        address='英国ヴァージン諸島トルトラ島ロードタウン私書箱３４６９ウォーターフロントドライブジュネーブプレイス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12170': EdinetCodeEntry(
        edinet_code='E12170',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1270869,
        fiscal_year_end=None,
        submitter_name='マフューズ・インターナショナル・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='マフューズインターナショナルファンズ',
        address='アメリカ合衆国カリフォルニア州サンフランシスコ、エンバーカデロ・センター４、スイート５５０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12197': EdinetCodeEntry(
        edinet_code='E12197',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社井門コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイモンコーポレーション',
        address='品川区東大井五丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701001066',
    ),
    'E12208': EdinetCodeEntry(
        edinet_code='E12208',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=591858,
        fiscal_year_end=None,
        submitter_name='ＦＭＲ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='エフエムアール\u3000エルエルシー',
        address='米国マサチューセッツ州ボストン、サマー・ストリート２４５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12211': EdinetCodeEntry(
        edinet_code='E12211',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近間\u3000之文',
        submitter_name_en=None,
        submitter_name_yomi='チカマ\u3000ユキフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12214': EdinetCodeEntry(
        edinet_code='E12214',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松岡\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12233': EdinetCodeEntry(
        edinet_code='E12233',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社フェニックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフェニックス',
        address='中央区佃１丁目１１番９－３００４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001143246',
    ),
    'E12234': EdinetCodeEntry(
        edinet_code='E12234',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ＯＫＵＲＡ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオクラカブシキガイシャ',
        address='名古屋市千種区今池南１７番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001062073',
    ),
    'E12238': EdinetCodeEntry(
        edinet_code='E12238',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='サッポロビール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サッポロビールカブシキガイシャ',
        address='渋谷区恵比寿４－２０－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001040690',
    ),
    'E12246': EdinetCodeEntry(
        edinet_code='E12246',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='芝崎\u3000晶紀',
        submitter_name_en=None,
        submitter_name_yomi='シバザキ\u3000アキノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12267': EdinetCodeEntry(
        edinet_code='E12267',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野坂\u3000英吾',
        submitter_name_en=None,
        submitter_name_yomi='ノサカ\u3000エイゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12272': EdinetCodeEntry(
        edinet_code='E12272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='前澤\u3000友作',
        submitter_name_en=None,
        submitter_name_yomi='マエザワ\u3000ユウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12302': EdinetCodeEntry(
        edinet_code='E12302',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='オラクル・ジャパン・ホールディング・インク',
        submitter_name_en=None,
        submitter_name_yomi='オラクル\u3000ジャパン\u3000ホールディング\u3000インク',
        address='アメリカ合衆国\u3000カリフォルニア州\u3000レッドウッド・ショアズ\u3000オラクル・パークウェイ５００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12321': EdinetCodeEntry(
        edinet_code='E12321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='フジファンド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジファンドカブシキカイシャ',
        address='伊東市富戸８９０番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001113963',
    ),
    'E12324': EdinetCodeEntry(
        edinet_code='E12324',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='テレーザ\u3000サンダ\u3000ヴォンダーシュミット',
        submitter_name_en=None,
        submitter_name_yomi='テレーザ\u3000サンダ\u3000ヴォンダーシュミット',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12328': EdinetCodeEntry(
        edinet_code='E12328',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ユカリア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユカリア',
        address='千代田区霞が関３丁目２番５号\u3000霞が関ビルディング１９階',
        industry='サービス業',
        sec_code='286A0',
        corporate_number='8010401056616',
    ),
    'E12335': EdinetCodeEntry(
        edinet_code='E12335',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白石\u3000幸生',
        submitter_name_en=None,
        submitter_name_yomi='シライシ\u3000ユキオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12348': EdinetCodeEntry(
        edinet_code='E12348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=122,
        fiscal_year_end=None,
        submitter_name='寿不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コトブキフドウサンカブシキガイシャ',
        address='大阪市北区堂島浜二丁目１番４０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001059642',
    ),
    'E12351': EdinetCodeEntry(
        edinet_code='E12351',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮澤\u3000栄一',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザワ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12363': EdinetCodeEntry(
        edinet_code='E12363',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社アニメイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアニメイト',
        address='豊島区東池袋三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7013301000644',
    ),
    'E12366': EdinetCodeEntry(
        edinet_code='E12366',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯野光彦',
        submitter_name_en=None,
        submitter_name_yomi='イイノミツヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12373': EdinetCodeEntry(
        edinet_code='E12373',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='安井\u3000玄一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤスイ\u3000ゲンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12380': EdinetCodeEntry(
        edinet_code='E12380',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='千葉\u3000ゆきえ',
        submitter_name_en=None,
        submitter_name_yomi='チバ\u3000ユキエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12381': EdinetCodeEntry(
        edinet_code='E12381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='服部\u3000京子',
        submitter_name_en=None,
        submitter_name_yomi='ハットリ\u3000キョウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12389': EdinetCodeEntry(
        edinet_code='E12389',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=164,
        fiscal_year_end=None,
        submitter_name='ＧＩＣプライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジーアイシープライベートリミテッド',
        address='シンガポール共和国０６８９１２、キャピタル・タワー＃３７－０１、ロビンソン・ロード１６８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12390': EdinetCodeEntry(
        edinet_code='E12390',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤澤\u3000信義',
        submitter_name_en=None,
        submitter_name_yomi='フジサワ\u3000ノブヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12391': EdinetCodeEntry(
        edinet_code='E12391',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='浅井\u3000一',
        submitter_name_en=None,
        submitter_name_yomi='アサイ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12402': EdinetCodeEntry(
        edinet_code='E12402',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2334,
        fiscal_year_end=None,
        submitter_name='アリアンツ・グローバル・インベスターズ・アジア・パシフィック・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アリアンツグローバルインベスターズアジアパシフィックリミテッド',
        address='香港、セントラル、ガーデンロード３、ＩＣＢＣタワー２７階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12413': EdinetCodeEntry(
        edinet_code='E12413',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='オラクル・グローバル・ホールディングス・インク',
        submitter_name_en=None,
        submitter_name_yomi='オラクル\u3000グローバル\u3000ホールディングス\u3000インク',
        address='アメリカ合衆国\u3000カリフォルニア州\u3000レッドウッド・ショアズ\u3000オラクル・パークウェイ５００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12415': EdinetCodeEntry(
        edinet_code='E12415',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='オラクル・システムズ・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='オラクル\u3000システムズ\u3000コーポレーション',
        address='アメリカ合衆国\u3000カリフォルニア州\u3000レッドウッド・ショアズ\u3000オラクル・パークウェイ５００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E12422': EdinetCodeEntry(
        edinet_code='E12422',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='しんきんアセットマネジメント投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンキンアセットマネジメントトウシンカブシキガイシャ',
        address='中央区京橋三丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001046310',
    ),
    'E12425': EdinetCodeEntry(
        edinet_code='E12425',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='フランクリン・テンプルトン・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フランクリン\u3000テンプルトン\u3000ジャパン\u3000カブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001048652',
    ),
    'E12429': EdinetCodeEntry(
        edinet_code='E12429',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=219,
        fiscal_year_end=None,
        submitter_name='ＰＧＩＭジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピージムジャパンカブシキガイシャ',
        address='千代田区永田町二丁目１３番１０号プルデンシャルタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001098893',
    ),
    'E12430': EdinetCodeEntry(
        edinet_code='E12430',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17363,
        fiscal_year_end=None,
        submitter_name='アモーヴァ・アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アモーヴァアセットマネジメントカブシキガイシャ',
        address='港区赤坂九丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401072159',
    ),
    'E12431': EdinetCodeEntry(
        edinet_code='E12431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＢＮＰパリバ・アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌピーパリバアセットマネジメントカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号グラントウキョウノースタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001068479',
    ),
    'E12434': EdinetCodeEntry(
        edinet_code='E12434',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1550,
        fiscal_year_end=None,
        submitter_name='ＳＯＭＰＯアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソンポアセットマネジメントカブシキガイシャ',
        address='中央区日本橋二丁目２番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001031160',
    ),
    'E12437': EdinetCodeEntry(
        edinet_code='E12437',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='パインブリッジ・インベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パインブリッジインベストメンツカブシキガイシャ',
        address='千代田区大手町一丁目３番１号\u3000ＪＡビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001011855',
    ),
    'E12441': EdinetCodeEntry(
        edinet_code='E12441',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢＩ岡三アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイオカサンアセットマネジメントカブシキガイシャ',
        address='中央区京橋二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001062358',
    ),
    'E12444': EdinetCodeEntry(
        edinet_code='E12444',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='三井住友トラスト・アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツイスミトモトラストアセットマネジメントカブシキガイシャ',
        address='港区芝公園１丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001114914',
    ),
    'E12447': EdinetCodeEntry(
        edinet_code='E12447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='朝日ライフ\u3000アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒライフ\u3000アセットマネジメントカブシキガイシャ',
        address='杉並区和泉一丁目２２番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011301011486',
    ),
    'E12448': EdinetCodeEntry(
        edinet_code='E12448',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='明治安田アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダアセットマネジメントカブシキガイシャ',
        address='千代田区大手町二丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401040306',
    ),
    'E12450': EdinetCodeEntry(
        edinet_code='E12450',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=490,
        fiscal_year_end=None,
        submitter_name='ラッセル・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ラッセルインベストメントカブシキガイシャ',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401037394',
    ),
    'E12453': EdinetCodeEntry(
        edinet_code='E12453',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='ニッセイアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッセイアセットマネジメントカブシキガイシャ',
        address='千代田区丸の内一丁目６番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001025953',
    ),
    'E12457': EdinetCodeEntry(
        edinet_code='E12457',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=490,
        fiscal_year_end=None,
        submitter_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゴールドマンサックスアセットマネジメントカブシキガイシャ',
        address='港区虎ノ門二丁目６番１号\u3000虎ノ門ヒルズステーションタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401009945',
    ),
    'E12460': EdinetCodeEntry(
        edinet_code='E12460',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17180,
        fiscal_year_end=None,
        submitter_name='野村アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラアセットマネジメントカブシキガイシャ',
        address='江東区豊洲二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001054021',
    ),
    'E12468': EdinetCodeEntry(
        edinet_code='E12468',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=320,
        fiscal_year_end=None,
        submitter_name='さわかみ投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サワカミトウシン\u3000カブシキガイシャ',
        address='千代田区一番町２９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001018139',
    ),
    'E12473': EdinetCodeEntry(
        edinet_code='E12473',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2200,
        fiscal_year_end=None,
        submitter_name='ＵＢＳアセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスアセットマネジメントカブシキガイシャ',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001031576',
    ),
    'E12480': EdinetCodeEntry(
        edinet_code='E12480',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1630,
        fiscal_year_end=None,
        submitter_name='アライアンス・バーンスタイン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アライアンスバーンスタインカブシキカイシャ',
        address='千代田区内幸町二丁目１番６号\u3000日比谷パークフロント',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001010313',
    ),
    'E12481': EdinetCodeEntry(
        edinet_code='E12481',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='フィデリティ投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フィデリティトウシンカブシキカイシャ',
        address='港区六本木七丁目７番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401025734',
    ),
    'E12492': EdinetCodeEntry(
        edinet_code='E12492',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='ＨＳＢＣアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーアセットマネジメントカブシキガイシャ',
        address='中央区日本橋三丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001124868',
    ),
    'E12566': EdinetCodeEntry(
        edinet_code='E12566',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=649,
        fiscal_year_end=None,
        submitter_name='イーストスプリング・インベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イーストスプリングインベストメンツカブシキガイシャ',
        address='千代田区丸の内二丁目６番１号\u3000丸の内パークビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001066780',
    ),
    'E12586': EdinetCodeEntry(
        edinet_code='E12586',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=490,
        fiscal_year_end=None,
        submitter_name='シュローダー・インベストメント・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シュローダーインベストメントマネジメントカブシキガイシャ',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001077097',
    ),
    'E12882': EdinetCodeEntry(
        edinet_code='E12882',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1466,
        fiscal_year_end=None,
        submitter_name='農林中金全共連アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノウリンチュウキンゼンキョウレンアセットマネジメントカブシキガイシャ',
        address='千代田区九段南一丁目６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001054095',
    ),
    'E12963': EdinetCodeEntry(
        edinet_code='E12963',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=310,
        fiscal_year_end=None,
        submitter_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ステートストリートグローバルアドバイザーズカブシキガイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401034817',
    ),
    'E13205': EdinetCodeEntry(
        edinet_code='E13205',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=497241,
        fiscal_year_end=None,
        submitter_name='ジャパンリアルエステイト投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンリアルエステイトトウシホウジン',
        address='千代田区大手町一丁目１番１号大手町パークビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005005479',
    ),
    'E13206': EdinetCodeEntry(
        edinet_code='E13206',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=691097,
        fiscal_year_end=None,
        submitter_name='日本ビルファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニホンビルファンドトウシホウジン',
        address='中央区日本橋室町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005005404',
    ),
    'E13343': EdinetCodeEntry(
        edinet_code='E13343',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=795,
        fiscal_year_end=None,
        submitter_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌワイメロン\u3000インベストメント\u3000マネジメント\u3000ジャパン\u3000カブシキガイシャ',
        address='千代田区丸の内一丁目８番３号丸の内トラストタワー本館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001040648',
    ),
    'E13347': EdinetCodeEntry(
        edinet_code='E13347',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日立投資顧問株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒタチトウシコモンカブシキカイシャ',
        address='台東区東上野二丁目１６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001065462',
    ),
    'E13410': EdinetCodeEntry(
        edinet_code='E13410',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=411878,
        fiscal_year_end=None,
        submitter_name='日本都市ファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニホントシファンドトウシホウジン',
        address='千代田区丸の内二丁目７番３号\u3000東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005005643',
    ),
    'E13445': EdinetCodeEntry(
        edinet_code='E13445',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=335757,
        fiscal_year_end=None,
        submitter_name='オリックス不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='オリックスフドウサントウシホウジン',
        address='港区浜松町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010405002909',
    ),
    'E13447': EdinetCodeEntry(
        edinet_code='E13447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='ＳＢＩアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイアセットマネジメントカブシキカイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401045054',
    ),
    'E13448': EdinetCodeEntry(
        edinet_code='E13448',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=257751,
        fiscal_year_end=None,
        submitter_name='日本プライムリアルティ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニホンプライムリアルティトウシホウジン',
        address='中央区八重洲一丁目４番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005005640',
    ),
    'E13484': EdinetCodeEntry(
        edinet_code='E13484',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=140497,
        fiscal_year_end=None,
        submitter_name='ＮＴＴ都市開発リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティトシカイハツリートトウシホウジン',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010405003106',
    ),
    'E13661': EdinetCodeEntry(
        edinet_code='E13661',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=110479,
        fiscal_year_end=None,
        submitter_name='東急リアル・エステート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='トウキュウリアルエステートトウシホウジン',
        address='渋谷区道玄坂一丁目１２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011005001457',
    ),
    'E13678': EdinetCodeEntry(
        edinet_code='E13678',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=93901,
        fiscal_year_end=None,
        submitter_name='グローバル・ワン不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='グローバルワンフドウサントウシホウジン',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005006554',
    ),
    'E13756': EdinetCodeEntry(
        edinet_code='E13756',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=319973,
        fiscal_year_end=None,
        submitter_name='ユナイテッド・アーバン投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ユナイテッドアーバントウシホウジン',
        address='港区虎ノ門四丁目３番１号\u3000城山トラストタワー１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010405003750',
    ),
    'E13771': EdinetCodeEntry(
        edinet_code='E13771',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=153990,
        fiscal_year_end=None,
        submitter_name='森トラストリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='モリトラストリートトウシホウジン',
        address='港区虎ノ門４丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010405002922',
    ),
    'E13833': EdinetCodeEntry(
        edinet_code='E13833',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=326079,
        fiscal_year_end=None,
        submitter_name='インヴィンシブル投資法人',
        submitter_name_en=None,
        submitter_name_yomi='インヴィンシブルトウシホウジン',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010005010238',
    ),
    'E13869': EdinetCodeEntry(
        edinet_code='E13869',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=168510,
        fiscal_year_end=None,
        submitter_name='フロンティア不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='フロンティアフドウサントウシホウジン',
        address='中央区銀座六丁目８番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005015394',
    ),
    'E13909': EdinetCodeEntry(
        edinet_code='E13909',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26500,
        fiscal_year_end=None,
        submitter_name='ありがとう投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アリガトウトウシンカブシキガイシャ',
        address='千代田区内神田二丁目１５番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010501022769',
    ),
    'E14005': EdinetCodeEntry(
        edinet_code='E14005',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=81370,
        fiscal_year_end=None,
        submitter_name='平和不動産リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ヘイワフドウサンリートトウシホウジン',
        address='中央区日本橋兜町５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405003021',
    ),
    'E14042': EdinetCodeEntry(
        edinet_code='E14042',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=130579,
        fiscal_year_end=None,
        submitter_name='日本ロジスティクスファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニホンロジスティクスファンドトウシホウジン',
        address='千代田区西神田三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005008361',
    ),
    'E14079': EdinetCodeEntry(
        edinet_code='E14079',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=109264,
        fiscal_year_end=None,
        submitter_name='福岡リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='フクオカリートトウシホウジン',
        address='福岡市博多区住吉一丁目２番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290005003793',
    ),
    'E14109': EdinetCodeEntry(
        edinet_code='E14109',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=217970,
        fiscal_year_end=None,
        submitter_name='ＫＤＸ不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ケイディーエックスフドウサントウシホウジン',
        address='千代田区内幸町二丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010405006092',
    ),
    'E14140': EdinetCodeEntry(
        edinet_code='E14140',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=268042,
        fiscal_year_end=None,
        submitter_name='大和ハウスリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ダイワハウスリートトウシホウジン',
        address='千代田区永田町二丁目４番８号\u3000ニッセイ永田町ビル７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005015144',
    ),
    'E14150': EdinetCodeEntry(
        edinet_code='E14150',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=67675,
        fiscal_year_end=None,
        submitter_name='いちごオフィスリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='イチゴオフィスリートトウシホウジン',
        address='千代田区丸の内二丁目６番１号２０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005017808',
    ),
    'E14197': EdinetCodeEntry(
        edinet_code='E14197',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=234094,
        fiscal_year_end=None,
        submitter_name='大和証券オフィス投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ダイワショウケンオフィストウシホウジン',
        address='中央区銀座六丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005008854',
    ),
    'E14207': EdinetCodeEntry(
        edinet_code='E14207',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=84270,
        fiscal_year_end=None,
        submitter_name='阪急阪神リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ハンキュウハンシンリートトウシホウジン',
        address='大阪市北区茶屋町１９番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120005009386',
    ),
    'E14223': EdinetCodeEntry(
        edinet_code='E14223',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41684,
        fiscal_year_end=None,
        submitter_name='スターツプロシード投資法人',
        submitter_name_en=None,
        submitter_name_yomi='スターツプロシードトウシホウジン',
        address='中央区日本橋三丁目１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005008634',
    ),
    'E14235': EdinetCodeEntry(
        edinet_code='E14235',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＴＯＲＡＮＯＴＥＣ投信投資顧問株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トラノテックトウシントウシコモンカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号\u3000城山トラストタワー３６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001132378',
    ),
    'E14273': EdinetCodeEntry(
        edinet_code='E14273',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=199051,
        fiscal_year_end=None,
        submitter_name='ジャパン・ホテル・リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンホテルリートトウシホウジン',
        address='渋谷区恵比寿４丁目１番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011005003801',
    ),
    'E14380': EdinetCodeEntry(
        edinet_code='E14380',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=152719,
        fiscal_year_end=None,
        submitter_name='大和証券リビング投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ダイワショウケンリビングトウシホウジン',
        address='中央区銀座六丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010405005732',
    ),
    'E14394': EdinetCodeEntry(
        edinet_code='E14394',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=139907,
        fiscal_year_end=None,
        submitter_name='ジャパンエクセレント投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンエクセレントトウシホウジン',
        address='港区南青山一丁目１５番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010405005210',
    ),
    'E14404': EdinetCodeEntry(
        edinet_code='E14404',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=145449,
        fiscal_year_end=None,
        submitter_name='三井不動産アコモデーションファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ミツイフドウサンアコモデーションファンドトウシホウジン',
        address='中央区日本橋一丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005009225',
    ),
    'E14415': EdinetCodeEntry(
        edinet_code='E14415',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=370,
        fiscal_year_end=None,
        submitter_name='シンプレクス・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンプレクスアセットマネジメントカブシキカイシャ',
        address='千代田区丸の内１－５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001066608',
    ),
    'E14490': EdinetCodeEntry(
        edinet_code='E14490',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=195718,
        fiscal_year_end=None,
        submitter_name='森ヒルズリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='モリヒルズリートトウシホウジン',
        address='港区赤坂一丁目１２番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405005158',
    ),
    'E14561': EdinetCodeEntry(
        edinet_code='E14561',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='セゾン投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セゾントウシンカブシキガイシャ',
        address='豊島区東池袋３－１－１サンシャイン６０・４８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1013301022479',
    ),
    'E14601': EdinetCodeEntry(
        edinet_code='E14601',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='ＰａｙＰａｙアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ペイペイアセットマネジメントカブシキガイシャ',
        address='千代田区神田錦町一丁目１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401079382',
    ),
    'E14703': EdinetCodeEntry(
        edinet_code='E14703',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=450,
        fiscal_year_end=None,
        submitter_name='キャピタル・インターナショナル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キャピタルインターナショナルカブシキガイシャ',
        address='千代田区丸の内三丁目２番３号\u3000丸の内二重橋ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001014858',
    ),
    'E14705': EdinetCodeEntry(
        edinet_code='E14705',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=237815,
        fiscal_year_end=None,
        submitter_name='産業ファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='サンギョウファンドトウシホウジン',
        address='千代田区丸の内二丁目７番３号東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005011484',
    ),
    'E14714': EdinetCodeEntry(
        edinet_code='E14714',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=280,
        fiscal_year_end=None,
        submitter_name='キャピタル\u3000アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キャピタル\u3000アセットマネジメントカブシキガイシャ',
        address='千代田区内神田一丁目１３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001090483',
    ),
    'E14732': EdinetCodeEntry(
        edinet_code='E14732',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=498,
        fiscal_year_end=None,
        submitter_name='ソシエテ・ジェネラル・オスマン・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソシエテジェネラルオスマンマネジメントカブシキカイシャ',
        address='千代田区丸の内一丁目１番１号\u3000パレスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401068539',
    ),
    'E14830': EdinetCodeEntry(
        edinet_code='E14830',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90257,
        fiscal_year_end=None,
        submitter_name='ＢＮＹメロン・ラージ・キャップ・セキュリティーズ・ファンド・インク',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌワイ\u3000メロン\u3000ラージ\u3000キャップ\u3000セキュリティーズ\u3000ファンド\u3000インク',
        address='アメリカ合衆国ニューヨーク州１０２８６、ニューヨーク市グリニッジ・ストリート２４０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14832': EdinetCodeEntry(
        edinet_code='E14832',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4545,
        fiscal_year_end=None,
        submitter_name='インベスコ・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='インベスコ\u3000ファンズ',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－２４５３、ユージーン・ルパート通り２－４\u3000ベルティゴ・ビルディング－ポラリス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14834': EdinetCodeEntry(
        edinet_code='E14834',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16036,
        fiscal_year_end=None,
        submitter_name='ＤＷＳ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000ＧｍｂＨ',
        submitter_name_en=None,
        submitter_name_yomi='デーヴェーエス\u3000インベストメント\u3000ゲーエムベーハー',
        address='ドイツ連邦共和国フランクフルト・アム・マイン\u3000マインツェル・ラントシュトラーセ１１－１７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14837': EdinetCodeEntry(
        edinet_code='E14837',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=86113,
        fiscal_year_end=None,
        submitter_name='アライアンス・バーンスタインＳＩＣＡＶ',
        submitter_name_en=None,
        submitter_name_yomi='アライアンスバーンスタインシカブ',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－２４５３、ユージェーヌ・リュペール通り２－４番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14840': EdinetCodeEntry(
        edinet_code='E14840',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6606,
        fiscal_year_end=None,
        submitter_name='アリアンツ・グローバル・インベスターズ・ゲーエムベーハー',
        submitter_name_en=None,
        submitter_name_yomi='アリアンツ\u3000グローバル\u3000インベスターズ\u3000ゲーエムベーハー',
        address='ドイツ連邦共和国６０３２３フランクフルト市\u3000ボッケンハイマーラントシュトラッセ４２－４４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14843': EdinetCodeEntry(
        edinet_code='E14843',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=42,
        fiscal_year_end=None,
        submitter_name='グローバル・ファンズ・マネジメント・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='グローバルファンズマネジメントエスエー',
        address='ルクセンブルグ大公国、エスペランジュ\u3000Ｌ－５８２６、ガスペリッシュ通り３３番Ａ棟',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14853': EdinetCodeEntry(
        edinet_code='E14853',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='エスエムビーシー\u3000ニッコウ\u3000インベストメント\u3000ファンド\u3000マネジメント\u3000カンパニー\u3000エス\u3000エイ',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－１２８２\u3000ヒルデガルト・フォン・ビンゲン通り２番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14857': EdinetCodeEntry(
        edinet_code='E14857',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=62,
        fiscal_year_end=None,
        submitter_name='エスエムティー・ファンド・サービシーズ（アイルランド）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エスエムティーファンドサービシーズアイルランドリミテッド',
        address='アイルランド共和国、ダブリン２、ハーコート・ロード、ハーコート・センター、ブロック５、レベル３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14863': EdinetCodeEntry(
        edinet_code='E14863',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15454,
        fiscal_year_end=None,
        submitter_name='パトナム・ハイ・イールド・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='パトナム\u3000ハイ\u3000イールド\u3000ファンド',
        address='米国０２１１０マサチューセッツ州ボストン市フェデラル・ストリート１００番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14866': EdinetCodeEntry(
        edinet_code='E14866',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=428,
        fiscal_year_end=None,
        submitter_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
        submitter_name_en=None,
        submitter_name_yomi='アライアンスバーンスタインルクセンブルグエスエイアールエル',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－２４５３、ユージェーヌ・リュペール通り２－４番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14867': EdinetCodeEntry(
        edinet_code='E14867',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=397574,
        fiscal_year_end=None,
        submitter_name='パトナム・ディバーシファイド・インカム・トラスト',
        submitter_name_en=None,
        submitter_name_yomi='パトナムディバーシファイドインカムトラスト',
        address='アメリカ合衆国\u3000０２１１０\u3000マサチューセッツ州\u3000ボストン市\u3000フェデラル・ストリート１００番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14869': EdinetCodeEntry(
        edinet_code='E14869',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=78129,
        fiscal_year_end=None,
        submitter_name='パトナム・インカム・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='パトナム\u3000インカム\u3000ファンド',
        address='アメリカ合衆国\u3000０２１１０\u3000マサチューセッツ州\u3000ボストン市\u3000フェデラル・ストリート１００番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14900': EdinetCodeEntry(
        edinet_code='E14900',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2291,
        fiscal_year_end=None,
        submitter_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスアセットマネジメントヨーロッパエスエイ',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14903': EdinetCodeEntry(
        edinet_code='E14903',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=425,
        fiscal_year_end=None,
        submitter_name='ＢＮＰパリバ・アセットマネジメント・ルクセンブルグ',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌピーパリバアセットマネジメントルクセンブルグ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－２５４０、エドワード・スタイケン通り１０番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14915': EdinetCodeEntry(
        edinet_code='E14915',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=126,
        fiscal_year_end=None,
        submitter_name='スパークス・オーバーシーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スパークスオーバーシーズリミテッド',
        address='バミューダ、ハミルトンＨＭ１１，フロント・ストリート３７番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14924': EdinetCodeEntry(
        edinet_code='E14924',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=912,
        fiscal_year_end=None,
        submitter_name='ＭＵＦＧルクスマネジメントカンパニーＳ．Ａ．',
        submitter_name_en=None,
        submitter_name_yomi='エムユーエフジールクスマネジメントカンパニーエスエイ',
        address='２８７－２８９、ｒｏｕｔｅ\u3000ｄ’Ａｒｌｏｎ\u3000Ｌ－１１５０\u3000Ｌｕｘｅｍｂｏｕｒｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14940': EdinetCodeEntry(
        edinet_code='E14940',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=155,
        fiscal_year_end=None,
        submitter_name='アクサ・インベストメント・マネージャーズ・パリ',
        submitter_name_en=None,
        submitter_name_yomi='アクサインベストメントマネージャーズパリ',
        address='フランス共和国ピュトー市９２８００、プラス・デ・ラ・ピラミッド６、ラ・デファン９、トゥール・マジュンガ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14945': EdinetCodeEntry(
        edinet_code='E14945',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=585562,
        fiscal_year_end=None,
        submitter_name='バンガード・インデックス・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='バンガードインデックスファンズ',
        address='アメリカ合衆国１９３５５\u3000ペンシルバニア州\u3000マルバーン市\u3000バンガード・ブルーヴァード１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14951': EdinetCodeEntry(
        edinet_code='E14951',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳオコーナー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエス\u3000オコーナー\u3000エルエルシー',
        address='アメリカ合衆国\u3000デラウェア州１９８０７、ウィルミントン、ケネット・パイク４００１番、スイート３０２、メイプルズ信託業務（デラウェア）インク気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14961': EdinetCodeEntry(
        edinet_code='E14961',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3896,
        fiscal_year_end=None,
        submitter_name='ＤＷＳインベストメント・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='ディーダブリューエスインベストメントエスエー',
        address='ルクセンブルク大公国、ルクセンブルク１１１５、ブールバール・コンラ・アデヌール２番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14979': EdinetCodeEntry(
        edinet_code='E14979',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=141,
        fiscal_year_end=None,
        submitter_name='タワー・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='タワーアセットマネジメントリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、郵便私書箱３０９号、メープルズ・コーポレート・サービセズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14980': EdinetCodeEntry(
        edinet_code='E14980',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=146,
        fiscal_year_end=None,
        submitter_name='バリュー・パートナーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バリューパートナーズリミテッド',
        address='英領バージン諸島、ＶＧ１１１０、トートラ、ロード・タウン、私書箱３１４０、ウィックハムズ・ケイ１、コマース・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E14984': EdinetCodeEntry(
        edinet_code='E14984',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='インターナショナル・マネジメント・サービシズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='インターナショナル\u3000マネジメント\u3000サービシズ\u3000リミテッド',
        address='ケイマン諸島、グランド・ケイマン、ハーバー・センター４階、私書箱６１ＧＴ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15033': EdinetCodeEntry(
        edinet_code='E15033',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=83,
        fiscal_year_end=None,
        submitter_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アイキュー\u3000イーキュー\u3000マネジメント\u3000バミューダ\u3000リミテッド',
        address='バーミューダ、ハミルトン\u3000ＨＭ１１、レイド・ストリート２０番、ウィリアムズ・ハウス４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15034': EdinetCodeEntry(
        edinet_code='E15034',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20528,
        fiscal_year_end=None,
        submitter_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='パシフィックインベストメントマネジメントカンパニーエルエルシー',
        address='アメリカ合衆国、９２６６０、カリフォルニア、ニューポート・ビーチ、ニューポート・センター・ドライブ６５０番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15044': EdinetCodeEntry(
        edinet_code='E15044',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1679,
        fiscal_year_end=None,
        submitter_name='シュローダー・インベストメント・マネージメント（ヨーロッパ）エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='シュローダーインベストメントマネージメントヨーロッパエスエイ',
        address='ルクセンブルグ大公国、セニンガーベルグ\u3000Ｌ－１７３６、ハーヘンホフ通り５番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15099': EdinetCodeEntry(
        edinet_code='E15099',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＦＣインベストメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エフシーインベストメントリミテッド',
        address='英領西インド諸島、ケイマン諸島、ＫＹ１－１１１１、グランド・ケイマン、私書箱２６８１、ハッチンス・ドライブ、クリケット・スクエア、コンヤーズ・トラスト・カンパニー（ケイマン）リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15153': EdinetCodeEntry(
        edinet_code='E15153',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28924,
        fiscal_year_end=None,
        submitter_name='ビー・エヌ・ピー・パリバ\u3000アセットマネジメント・ヨーロッパ',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌピーパリバアセットマネジメントヨーロッパ',
        address='フランス共和国パリ市７５００９、オスマン大通り１番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15174': EdinetCodeEntry(
        edinet_code='E15174',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3600,
        fiscal_year_end=None,
        submitter_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
        submitter_name_en=None,
        submitter_name_yomi='ルクセンブルクミツビシユーエフジェイインベスターサービスギンコウエスエイ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１１５０、アーロン通り２８７－２８９番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15194': EdinetCodeEntry(
        edinet_code='E15194',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=170,
        fiscal_year_end=None,
        submitter_name='リンク・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='リンクアセットマネジメントリミテッド',
        address='香港、カオルーン、クアン・トン、ホイ・ブン・ロード７７、ザ・キーサイド、タワー１\u3000２０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15214': EdinetCodeEntry(
        edinet_code='E15214',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌワイメロンインターナショナルマネジメントリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、ウグランド・ハウス、私書箱３０９号、メイプルズ・コーポレート・サービシイズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15244': EdinetCodeEntry(
        edinet_code='E15244',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=585523,
        fiscal_year_end='12月31日',
        submitter_name='ナティクシス',
        submitter_name_en=None,
        submitter_name_yomi='ナティクシス',
        address='フランス、７５０１３\u3000パリ市プロムナード・ジェルメーヌ・サブロン７番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E15255': EdinetCodeEntry(
        edinet_code='E15255',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='アイガー・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アイガー\u3000マネジメント\u3000リミテッド',
        address='ケイマン諸島、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、ウグランド・ハウス、私書箱３０９ＧＴ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15262': EdinetCodeEntry(
        edinet_code='E15262',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8227,
        fiscal_year_end=None,
        submitter_name='ザ・パトナム・アドバイザリー・カンパニー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ザパトナムアドバイザリーカンパニーエルエルシー',
        address='アメリカ合衆国\u3000０２１１０\u3000マサチューセッツ州\u3000ボストン市\u3000フェデラル・ストリート１００番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15291': EdinetCodeEntry(
        edinet_code='E15291',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49,
        fiscal_year_end=None,
        submitter_name='グローバル・ファンズ・マネジメント・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='グローバル\u3000ファンズ\u3000マネジメント\u3000エス\u3000エー',
        address='ルクセンブルグ大公国\u3000エスペランジュ\u3000ガスペリッシュ通り\u3000３３番\u3000Ａ棟',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15296': EdinetCodeEntry(
        edinet_code='E15296',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスルクスキーセレクションシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15336': EdinetCodeEntry(
        edinet_code='E15336',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=896429,
        fiscal_year_end=None,
        submitter_name='メリルリンチ・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='メリルリンチインターナショナル',
        address='２，Ｋｉｎｇ\u3000Ｅｄｗａｒｄ\u3000Ｓｔｒｅｅｔ，Ｌｏｎｄｏｎ，ＥＣ１Ａ\u3000１ＨＱ，Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15389': EdinetCodeEntry(
        edinet_code='E15389',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='ＵＢＳマネジメント（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスマネジメントケイマンリミテッド',
        address='ケイマン諸島、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、ウグランド・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15404': EdinetCodeEntry(
        edinet_code='E15404',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7082,
        fiscal_year_end=None,
        submitter_name='サムスン資産運用株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サムスンシサンウンヨウカブシキガイシャ',
        address='大韓民国ソウル特別市瑞草区瑞草大路７４キル１１（瑞草洞）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15447': EdinetCodeEntry(
        edinet_code='E15447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日亜持株組合',
        submitter_name_en=None,
        submitter_name_yomi='ニチアモチカブクミアイ',
        address='阿南市上中町岡４９１番地１００',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15690': EdinetCodeEntry(
        edinet_code='E15690',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1304,
        fiscal_year_end='3月31日',
        submitter_name='アルピコホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アルピコホールディングスカブシキガイシャ',
        address='松本市井川城二丁目１番１号',
        industry='陸運業',
        sec_code='297A0',
        corporate_number='2100001016611',
    ),
    'E15692': EdinetCodeEntry(
        edinet_code='E15692',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='9月末日',
        submitter_name='ビザ・インク（Ｖｉｓａ\u3000Ｉｎｃ．）',
        submitter_name_en=None,
        submitter_name_yomi='ビザインク',
        address='米国カリフォルニア州サンフランシスコ、ピー・オー・ボックス８９９９',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E15702': EdinetCodeEntry(
        edinet_code='E15702',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=13,
        fiscal_year_end=None,
        submitter_name='有限会社ドクターホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャドクターホールディングス',
        address='さいたま市大宮区寿能町１丁目３８番地９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3030002015222',
    ),
    'E15703': EdinetCodeEntry(
        edinet_code='E15703',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川畑博士',
        submitter_name_en=None,
        submitter_name_yomi='カワハタヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15704': EdinetCodeEntry(
        edinet_code='E15704',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='有限会社ライト経営',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャライトケイエイ',
        address='上尾市大字上２１０番地の３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5030002055308',
    ),
    'E15706': EdinetCodeEntry(
        edinet_code='E15706',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤輝英',
        submitter_name_en=None,
        submitter_name_yomi='サトウテルヒデ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15710': EdinetCodeEntry(
        edinet_code='E15710',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='濱中ナット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハマナカナットカブシキカイシャ',
        address='姫路市白浜町甲７７０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001060783',
    ),
    'E15711': EdinetCodeEntry(
        edinet_code='E15711',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ツカモト',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャツカモト',
        address='大阪市中央区南船場３丁目１２番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140002058552',
    ),
    'E15717': EdinetCodeEntry(
        edinet_code='E15717',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='樋口\u3000勤',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15743': EdinetCodeEntry(
        edinet_code='E15743',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='持山\u3000銀次郎',
        submitter_name_en=None,
        submitter_name_yomi='モチヤマ\u3000ギンジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15748': EdinetCodeEntry(
        edinet_code='E15748',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大島\u3000康広',
        submitter_name_en=None,
        submitter_name_yomi='オオシマ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15759': EdinetCodeEntry(
        edinet_code='E15759',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社デジタル・メディア総合研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデジタルメディアソウゴウケンキュウジョ',
        address='横浜市中区山手町２４２－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001045043',
    ),
    'E15761': EdinetCodeEntry(
        edinet_code='E15761',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='王子エフテックス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オウジエフテックスカブシキガイシャ',
        address='中央区銀座５－１２－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001089546',
    ),
    'E15770': EdinetCodeEntry(
        edinet_code='E15770',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=230,
        fiscal_year_end=None,
        submitter_name='Ｃｙｋａｎ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｃｏ．，Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='サイカンホールディングス',
        address='ソウル市江南区アックジョン路３６道１８、３階（新沙洞、シングビル）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15773': EdinetCodeEntry(
        edinet_code='E15773',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本バリュー・インベスターズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンバリューインベスターズカブシキガイシャ',
        address='千代田区丸の内一丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001096796',
    ),
    'E15776': EdinetCodeEntry(
        edinet_code='E15776',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永嶋\u3000秀和',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000ヒデカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15779': EdinetCodeEntry(
        edinet_code='E15779',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小林\u3000佳雄',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E15786': EdinetCodeEntry(
        edinet_code='E15786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社パリミキアセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャパリミキアセットマネジメント',
        address='中央区銀座二丁目８番４号\u3000泰明ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001113885',
    ),
    'E15787': EdinetCodeEntry(
        edinet_code='E15787',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='楽天投信投資顧問株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ラクテントウシントウシコモンカブシキカイシャ',
        address='港区南青山二丁目６番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010701021680',
    ),
    'E15791': EdinetCodeEntry(
        edinet_code='E15791',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ダイワ・アセット・マネジメント・サービシイズ・リミテッド（ケイマン）',
        submitter_name_en=None,
        submitter_name_yomi='ダイワ\u3000アセット\u3000マネジメント\u3000サービシイズ\u3000リミテッド\u3000ケイマン',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、ウグランド・ハウス、私書箱３０９号、メイプルズ・コーポレート・サービシイズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20003': EdinetCodeEntry(
        edinet_code='E20003',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=621772,
        fiscal_year_end=None,
        submitter_name='ＮＯＭＵＲＡ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＰＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ノムラインターナショナルピーエルシー',
        address='１\u3000ＡＮＧＥＬ\u3000ＬＡＮＥ\u3000ＬＯＮＤＯＮ\u3000ＥＣ４Ｒ\u3000３ＡＢ\u3000ＵＮＩＴＥＤ\u3000ＫＩＮＧＤＯＭ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20011': EdinetCodeEntry(
        edinet_code='E20011',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石田\u3000洋子',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20016': EdinetCodeEntry(
        edinet_code='E20016',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1151422,
        fiscal_year_end=None,
        submitter_name='モルガン・スタンレー・アンド・カンパニー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='モルガン\u3000スタンレー\u3000アンド\u3000カンパニー\u3000エルエルシー',
        address='ｃ／ｏ\u3000Ｔｈｅ\u3000Ｃｏｒｐｏｒａｔｉｏｎ\u3000Ｔｒｕｓｔ\u3000Ｃｏｍｐａｎｙ\u3000（ＤＥ）\u3000Ｃｏｒｐｏｒａｔｉｏｎ\u3000Ｔｒｕｓｔ\u3000Ｃｅｎｔｅｒ，１２０９\u3000Ｏｒａｎｇｅ\u3000Ｓｔｒｅｅｔ\u3000Ｗｉｌｍｉｎｇｔｏｎ\u3000ＤＥ\u3000１９８０１\u3000Ｕｎｉｔｅｄ\u3000Ｓｔａｔｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20021': EdinetCodeEntry(
        edinet_code='E20021',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=73272,
        fiscal_year_end=None,
        submitter_name='ＪＰモルガン証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェーピーモルガンショウケンカブシキガイシャ',
        address='千代田区丸の内２丁目７番３号\u3000東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001095702',
    ),
    'E20029': EdinetCodeEntry(
        edinet_code='E20029',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000敬三郎',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000ケイザブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20037': EdinetCodeEntry(
        edinet_code='E20037',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=923648,
        fiscal_year_end=None,
        submitter_name='モルガン・スタンレー・アンド・カンパニー・インターナショナル・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='モルガン\u3000スタンレー\u3000アンド\u3000カンパニー\u3000インターナショナル\u3000ピーエルシー',
        address='英国\u3000ロンドン\u3000カナリーワーフ\u3000２５\u3000カボットスクエア\u3000Ｅ１４\u3000４ＱＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20065': EdinetCodeEntry(
        edinet_code='E20065',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='武内\u3000英一郎',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000エイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20098': EdinetCodeEntry(
        edinet_code='E20098',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='ＤＭＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディーエムシーカブシキガイシャ',
        address='京都市下京区南不動堂町８０５－１１０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130001015101',
    ),
    'E20165': EdinetCodeEntry(
        edinet_code='E20165',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=327,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ\u3000ＡＳＳＥＴ\u3000ＭＡＮＡＧＥＭＥＮＴ\u3000（ＳＩＮＧＡＰＯＲＥ）\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエス\u3000アセット\u3000マネジメント\u3000シンガポール\u3000リミテッド',
        address='９\u3000ＰＥＮＡＮＧ\u3000ＲＯＡＤ\u3000ＰＡＲＫ\u3000ＭＡＬＬ\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20167': EdinetCodeEntry(
        edinet_code='E20167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20224': EdinetCodeEntry(
        edinet_code='E20224',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塚本\u3000粹子',
        submitter_name_en=None,
        submitter_name_yomi='ツカモト\u3000スイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20227': EdinetCodeEntry(
        edinet_code='E20227',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='スリースター有限会社',
        submitter_name_en=None,
        submitter_name_yomi='スリースターユウゲンガイシャ',
        address='西宮市美作町８－２０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120002013127',
    ),
    'E20257': EdinetCodeEntry(
        edinet_code='E20257',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=480,
        fiscal_year_end=None,
        submitter_name='野村プロパティーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラプロパティーズカブシキカイシャ',
        address='中央区日本橋本町一丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001069787',
    ),
    'E20289': EdinetCodeEntry(
        edinet_code='E20289',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社コム',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャコム',
        address='港区六本木１－７－１０－１６０９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7012402008118',
    ),
    'E20307': EdinetCodeEntry(
        edinet_code='E20307',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ＳＭＳホールディングス有限会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエムエスホールディングスユウゲンガイシャ',
        address='港区白金六丁目１６番２５グランドメゾン白金の杜ザ・タワー１４１０号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010802020330',
    ),
    'E20385': EdinetCodeEntry(
        edinet_code='E20385',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2403,
        fiscal_year_end='2月末日',
        submitter_name='テクミラホールディングス株式会社',
        submitter_name_en='TECMIRA HOLDINGS INC.',
        submitter_name_yomi='テクミラホールディングスカブシキガイシャ',
        address='千代田区神田須田町１丁目２３番地１',
        industry='情報・通信業',
        sec_code='36270',
        corporate_number='6010001087526',
    ),
    'E20393': EdinetCodeEntry(
        edinet_code='E20393',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='株式会社読売新聞東京本社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヨミウリシンブントウキョウホンシャ',
        address='千代田区大手町一丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001079224',
    ),
    'E20482': EdinetCodeEntry(
        edinet_code='E20482',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=77,
        fiscal_year_end=None,
        submitter_name='株式会社イーアライアンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーアライアンス',
        address='港区北青山２－１１－１０－４０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401079602',
    ),
    'E20484': EdinetCodeEntry(
        edinet_code='E20484',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='三光起業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンコウキギョウカブシキガイシャ',
        address='中央区銀座五丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001044390',
    ),
    'E20501': EdinetCodeEntry(
        edinet_code='E20501',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='有限会社萬緑',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャバンリョク',
        address='福岡市博多区博多駅東２－８－３５－２０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290002031607',
    ),
    'E20534': EdinetCodeEntry(
        edinet_code='E20534',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=23500,
        fiscal_year_end=None,
        submitter_name='東芝デジタルソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウシバデジタルソリューションズカブシキカイシャ',
        address='川崎市幸区堀川町７２番地３４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401052137',
    ),
    'E20567': EdinetCodeEntry(
        edinet_code='E20567',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＡＣＡ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーシーエーカブシキガイシャ',
        address='千代田区永田町一丁目１１番３０号サウスヒル永田町５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001092715',
    ),
    'E20591': EdinetCodeEntry(
        edinet_code='E20591',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='有限会社イワサキコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャイワサキコーポレーション',
        address='横浜市中区山手町２５番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020002018943',
    ),
    'E20603': EdinetCodeEntry(
        edinet_code='E20603',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笠原啓子',
        submitter_name_en=None,
        submitter_name_yomi='カサハラ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20608': EdinetCodeEntry(
        edinet_code='E20608',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社神明ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンメイホールディングス',
        address='神戸市中央区栄町通６－１－２１神明ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001008398',
    ),
    'E20616': EdinetCodeEntry(
        edinet_code='E20616',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=287,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ティーケーピー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーケーピー',
        address='新宿区市谷八幡町８番地',
        industry='不動産業',
        sec_code='34790',
        corporate_number='7010001105955',
    ),
    'E20633': EdinetCodeEntry(
        edinet_code='E20633',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社熊谷正寿事務所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクマガイマサトシジムショ',
        address='渋谷区桜丘町２６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401091620',
    ),
    'E20647': EdinetCodeEntry(
        edinet_code='E20647',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社やがみビル',
        submitter_name_en=None,
        submitter_name_yomi='カブキカイシャヤガミビル',
        address='名古屋市中区丸の内三丁目２番２９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001041512',
    ),
    'E20652': EdinetCodeEntry(
        edinet_code='E20652',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=34,
        fiscal_year_end=None,
        submitter_name='名古屋友豊株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナゴヤユウホウカブシキカイシャ',
        address='名古屋市中川区尾頭橋一丁目１番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180001020454',
    ),
    'E20669': EdinetCodeEntry(
        edinet_code='E20669',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=39,
        fiscal_year_end=None,
        submitter_name='株式会社ケイビー恒産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイビーコウサン',
        address='京都市伏見区山崎町３４３番地１－５０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130002013737',
    ),
    'E20677': EdinetCodeEntry(
        edinet_code='E20677',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='池永\u3000重彦',
        submitter_name_en=None,
        submitter_name_yomi='イケナガ\u3000シゲヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20682': EdinetCodeEntry(
        edinet_code='E20682',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社環境エネルギー投資',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカンキョウエネルギートウシ',
        address='品川区東五反田５丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010701016932',
    ),
    'E20685': EdinetCodeEntry(
        edinet_code='E20685',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000和男',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20698': EdinetCodeEntry(
        edinet_code='E20698',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アイアンドアイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイアンドアイ',
        address='港区虎ノ門四丁目１番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401066548',
    ),
    'E20706': EdinetCodeEntry(
        edinet_code='E20706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岨野\u3000俊雄',
        submitter_name_en=None,
        submitter_name_yomi='ソノ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20709': EdinetCodeEntry(
        edinet_code='E20709',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＯＮ\u3000Ｆｉｎａｎｃｉａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソンフィナンシャルカブシキガイシャ',
        address='品川区西五反田二丁目７番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010701021333',
    ),
    'E20724': EdinetCodeEntry(
        edinet_code='E20724',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='太田興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオタコウサンカブシキガイシャ',
        address='横浜市港北区新横浜二丁目４番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001019729',
    ),
    'E20731': EdinetCodeEntry(
        edinet_code='E20731',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社志',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャココロ',
        address='世田谷区新町３丁目２２番１０の４０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010002044911',
    ),
    'E20748': EdinetCodeEntry(
        edinet_code='E20748',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社相模鋼材商会',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサガミコウザイショウカイ',
        address='静岡市清水区三保３８７番地７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001007379',
    ),
    'E20760': EdinetCodeEntry(
        edinet_code='E20760',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='清信興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セイシンコウサンカブシキガイシャ',
        address='中央区日本橋本町３－６－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001062966',
    ),
    'E20762': EdinetCodeEntry(
        edinet_code='E20762',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='千村\u3000岳彦',
        submitter_name_en=None,
        submitter_name_yomi='チムラ\u3000タケヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20810': EdinetCodeEntry(
        edinet_code='E20810',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='9月30日',
        submitter_name='株式会社秋津原',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアキツバラ',
        address='御所市朝町１０７５番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='4150001015136',
    ),
    'E20816': EdinetCodeEntry(
        edinet_code='E20816',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3661,
        fiscal_year_end=None,
        submitter_name='Ｔ．Ｒｏｗｅ\u3000Ｐｒｉｃｅ\u3000Ａｓｓｏｃｉａｔｅｓ，Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ティロウプライスアソシエイツインク',
        address='米国メリーランド州、２１２３１、ボルティモア、ポイント・ストリート１３０７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20817': EdinetCodeEntry(
        edinet_code='E20817',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26038,
        fiscal_year_end=None,
        submitter_name='ティー・ロウ・プライス・インターナショナル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ティーロウプライスインターナショナルリミテッド',
        address='英国ロンドン市イーシー４エム７ディーエックス、パターノスター・スクエア５、ウォーリック・コート',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20822': EdinetCodeEntry(
        edinet_code='E20822',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久世\u3000健吉',
        submitter_name_en=None,
        submitter_name_yomi='クゼ\u3000ケンキチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20848': EdinetCodeEntry(
        edinet_code='E20848',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池谷\u3000正成',
        submitter_name_en=None,
        submitter_name_yomi='イケタニ\u3000マサナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20855': EdinetCodeEntry(
        edinet_code='E20855',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='児島\u3000誠一郎',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000セイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20870': EdinetCodeEntry(
        edinet_code='E20870',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＭＳ＆Ｃｏｎｓｕｌｔｉｎｇ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムエスアンドコンサルティング',
        address='中央区日本橋小伝馬町４番９号',
        industry='サービス業',
        sec_code='65550',
        corporate_number='3010001152084',
    ),
    'E20919': EdinetCodeEntry(
        edinet_code='E20919',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='有限会社青山物産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャアオヤマブッサン',
        address='福山市王子町一丁目３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6240002039049',
    ),
    'E20922': EdinetCodeEntry(
        edinet_code='E20922',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=684,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イナリサーチ',
        submitter_name_en='Ina Research Inc.',
        submitter_name_yomi='カブシキガイシャイナリサーチ',
        address='伊那市西箕輪２１４８番地１８８',
        industry='サービス業',
        sec_code=None,
        corporate_number='5100001020627',
    ),
    'E20953': EdinetCodeEntry(
        edinet_code='E20953',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人大島育英会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンオオシマイクエイカイ',
        address='千代田区九段北四丁目２番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005015578',
    ),
    'E20955': EdinetCodeEntry(
        edinet_code='E20955',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大島\u3000義和',
        submitter_name_en=None,
        submitter_name_yomi='オオシマ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E20969': EdinetCodeEntry(
        edinet_code='E20969',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｔ．Ｇ．アセット有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ティジーアセットユウゲンガイシャ',
        address='市川市鬼高二丁目１０番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3040002038858',
    ),
    'E20989': EdinetCodeEntry(
        edinet_code='E20989',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=147,
        fiscal_year_end='3月31日',
        submitter_name='トヨタ\u3000モーター\u3000ファイナンス\u3000（ネザーランズ）\u3000ビーブイ',
        submitter_name_en=None,
        submitter_name_yomi='トヨタモーターファイナンスネザーランズビーブイ',
        address='オランダ王国\u3000１０７７\u3000ＸＶ\u3000アムステルダム市\u3000ザイドプライン\u3000２１８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E20994': EdinetCodeEntry(
        edinet_code='E20994',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社増進会ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゾウシンカイホールディングス',
        address='三島市文教町一丁目９番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8080101005817',
    ),
    'E20996': EdinetCodeEntry(
        edinet_code='E20996',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クレアート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャクレアート',
        address='品川区東五反田２－７－１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010701020389',
    ),
    'E21005': EdinetCodeEntry(
        edinet_code='E21005',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3208,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＧＰＩグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイエイキョウソウキバン',
        address='千代田区丸の内１丁目９番２号\u3000グラントウキョウサウスタワー８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001108192',
    ),
    'E21035': EdinetCodeEntry(
        edinet_code='E21035',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7792,
        fiscal_year_end='2月末日',
        submitter_name='ウエルシアホールディングス株式会社',
        submitter_name_en='WELCIA HOLDINGS CO., LTD.',
        submitter_name_yomi='ウエルシアホールディングスカブシキガイシャ',
        address='千代田区外神田二丁目２番１５号',
        industry='小売業',
        sec_code=None,
        corporate_number='7010001119831',
    ),
    'E21092': EdinetCodeEntry(
        edinet_code='E21092',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社東京ウエルズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトウキョウウエルズ',
        address='大田区北馬込二丁目２８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010801007689',
    ),
    'E21108': EdinetCodeEntry(
        edinet_code='E21108',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000昌史',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21120': EdinetCodeEntry(
        edinet_code='E21120',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=147,
        fiscal_year_end=None,
        submitter_name='株式会社小学館',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャショウガクカン',
        address='千代田区一ツ橋二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001018919',
    ),
    'E21122': EdinetCodeEntry(
        edinet_code='E21122',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1807,
        fiscal_year_end='12月31日',
        submitter_name='株式会社オークネット',
        submitter_name_en='AUCNET INC.',
        submitter_name_yomi='カブシキガイシャオークネット',
        address='港区北青山二丁目５番８号',
        industry='情報・通信業',
        sec_code='39640',
        corporate_number='4010001116006',
    ),
    'E21142': EdinetCodeEntry(
        edinet_code='E21142',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='有限会社神田コンサルティング',
        submitter_name_en=None,
        submitter_name_yomi='ユゲンガイシャカンダコンサルティング',
        address='中央区銀座６丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010902019147',
    ),
    'E21145': EdinetCodeEntry(
        edinet_code='E21145',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1989,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東京商品取引所',
        submitter_name_en='Tokyo Commodity Exchange, Inc.',
        submitter_name_yomi='カブシキガイシャ\u3000トウキョウショウヒントリヒキジョ',
        address='中央区日本橋堀留町１－１０－７',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4010001121906',
    ),
    'E21152': EdinetCodeEntry(
        edinet_code='E21152',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='フレックスコーポレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フレックスコーポレーションカブシキガイシャ',
        address='港区南麻布五丁目２番５‐７０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401026500',
    ),
    'E21176': EdinetCodeEntry(
        edinet_code='E21176',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=389,
        fiscal_year_end=None,
        submitter_name='ＢＮＰパリバ・アセットマネジメント・ルクセンブルク',
        submitter_name_en=None,
        submitter_name_yomi='ビーエヌピーパリバアセットマネジメントルクセンブルク',
        address='ルクセンブルク大公国、ルクセンブルクＬ－２５４０、エドワード・スタイケン通り１０番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21183': EdinetCodeEntry(
        edinet_code='E21183',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=81690,
        fiscal_year_end='12月31日',
        submitter_name='大塚ホールディングス株式会社',
        submitter_name_en='Otsuka Holdings Co., Ltd.',
        submitter_name_yomi='オオツカホールディングスカブシキカイシャ',
        address='千代田区神田司町２－９',
        industry='医薬品',
        sec_code='45780',
        corporate_number='4010001118786',
    ),
    'E21187': EdinetCodeEntry(
        edinet_code='E21187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7790,
        fiscal_year_end='3月31日',
        submitter_name='ＡＲＥホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイアールイーホールディングスカブシキガイシャ',
        address='神戸市中央区加納町四丁目４番１７号',
        industry='非鉄金属',
        sec_code='58570',
        corporate_number='4140001030937',
    ),
    'E21191': EdinetCodeEntry(
        edinet_code='E21191',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙野\u3000裕子',
        submitter_name_en=None,
        submitter_name_yomi='タカノ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21200': EdinetCodeEntry(
        edinet_code='E21200',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社川金ホールディングス',
        submitter_name_en='Kawakin Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャカワキンホールディングス',
        address='川口市川口２丁目２番７号',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='8030001081624',
    ),
    'E21204': EdinetCodeEntry(
        edinet_code='E21204',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中川\u3000博司',
        submitter_name_en=None,
        submitter_name_yomi='ナカガワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21213': EdinetCodeEntry(
        edinet_code='E21213',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=180000,
        fiscal_year_end='12月31日',
        submitter_name='ヴイエムウェア・インク',
        submitter_name_en=None,
        submitter_name_yomi='ヴイエムウェアインク',
        address='米国９４３０４カリフォルニア州パロアルト、ヒルビュー・アベニュー３４０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E21218': EdinetCodeEntry(
        edinet_code='E21218',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000快一郎',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000カイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21219': EdinetCodeEntry(
        edinet_code='E21219',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォレストホールディングス',
        submitter_name_en='Forest Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャフォレストホールディングス',
        address='大分市西大道二丁目３番８号',
        industry='卸売業',
        sec_code=None,
        corporate_number='6320001005316',
    ),
    'E21239': EdinetCodeEntry(
        edinet_code='E21239',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=318,
        fiscal_year_end=None,
        submitter_name='チカラ・インベストメンツ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='チカラインベストメンツエルエルピー',
        address='ロンドン\u3000セント・ジェームスズ・ストリート\u3000３１―３２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21258': EdinetCodeEntry(
        edinet_code='E21258',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社やまびこ',
        submitter_name_en='YAMABIKO CORPORATION',
        submitter_name_yomi='カブシキガイシャヤマビコ',
        address='青梅市末広町一丁目７番地２',
        industry='機械',
        sec_code='62500',
        corporate_number='1013101005329',
    ),
    'E21259': EdinetCodeEntry(
        edinet_code='E21259',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1509,
        fiscal_year_end='6月30日',
        submitter_name='ＢＲＵＮＯ株式会社',
        submitter_name_en='BRUNO, Inc.',
        submitter_name_yomi='ブルーノカブシキガイシャ',
        address='新宿区西新宿八丁目１７番１号\u3000住友不動産新宿グランドタワー３６階',
        industry='卸売業',
        sec_code='31400',
        corporate_number='7010401037344',
    ),
    'E21261': EdinetCodeEntry(
        edinet_code='E21261',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17479,
        fiscal_year_end='3月31日',
        submitter_name='パーソルホールディングス株式会社',
        submitter_name_en='PERSOL HOLDINGS CO.,LTD.',
        submitter_name_yomi='パーソルホールディングスカブシキカイシャ',
        address='渋谷区代々木二丁目１番１号',
        industry='サービス業',
        sec_code='21810',
        corporate_number='8011001058176',
    ),
    'E21264': EdinetCodeEntry(
        edinet_code='E21264',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='セノーテキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セノーテキャピタルカブシキガイシャ',
        address='中央区築地２－１５－１５\u3000セントラル東銀座７０９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001144682',
    ),
    'E21269': EdinetCodeEntry(
        edinet_code='E21269',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='塚本\u3000勲',
        submitter_name_en=None,
        submitter_name_yomi='ツカモト\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21272': EdinetCodeEntry(
        edinet_code='E21272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下田\u3000佳史',
        submitter_name_en=None,
        submitter_name_yomi='シモダ\u3000ヨシフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21278': EdinetCodeEntry(
        edinet_code='E21278',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='株式会社幸栄企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウエイキカク',
        address='目黒区自由が丘三丁目１８番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4013202007799',
    ),
    'E21290': EdinetCodeEntry(
        edinet_code='E21290',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='関家\u3000圭三',
        submitter_name_en=None,
        submitter_name_yomi='セキヤ\u3000ケイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21316': EdinetCodeEntry(
        edinet_code='E21316',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ワイ・アンド・ジー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャワイアンドジー',
        address='新宿区津久戸町１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011102023182',
    ),
    'E21317': EdinetCodeEntry(
        edinet_code='E21317',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='梅田\u3000和江',
        submitter_name_en=None,
        submitter_name_yomi='ウメダ\u3000カズエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21320': EdinetCodeEntry(
        edinet_code='E21320',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13645,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＶＣケンウッド',
        submitter_name_en='JVCKENWOOD Corporation',
        submitter_name_yomi='カブシキカイシャジェイブイシーケンウッド',
        address='横浜市神奈川区守屋町三丁目１２番地',
        industry='電気機器',
        sec_code='66320',
        corporate_number='8020001059159',
    ),
    'E21322': EdinetCodeEntry(
        edinet_code='E21322',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社トライステージ',
        submitter_name_en='Tri-Stage Inc.',
        submitter_name_yomi='カブシキガイシャトライステージ',
        address='港区海岸一丁目２番２０号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010401060899',
    ),
    'E21331': EdinetCodeEntry(
        edinet_code='E21331',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口\u3000裕久',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000ヒロヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21342': EdinetCodeEntry(
        edinet_code='E21342',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2500,
        fiscal_year_end='3月31日',
        submitter_name='住石ホールディングス株式会社',
        submitter_name_en='Sumiseki Holdings, Inc.',
        submitter_name_yomi='スミセキホールディングスカブシキガイシャ',
        address='港区新橋６－１６－１２',
        industry='鉱業',
        sec_code='15140',
        corporate_number='2010401078384',
    ),
    'E21354': EdinetCodeEntry(
        edinet_code='E21354',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社苅谷',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカリヤ',
        address='船橋市新高根六丁目１４番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001023447',
    ),
    'E21381': EdinetCodeEntry(
        edinet_code='E21381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=547,
        fiscal_year_end='6月末日',
        submitter_name='株式会社サニーサイドアップグループ',
        submitter_name_en='SUNNY SIDE UP GROUP Inc.',
        submitter_name_yomi='カブシキガイシャサニーサイドアップグループ',
        address='渋谷区千駄ヶ谷四丁目２３番５号',
        industry='サービス業',
        sec_code='21800',
        corporate_number='1011001044042',
    ),
    'E21389': EdinetCodeEntry(
        edinet_code='E21389',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社キャトル・セゾン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキャトルセゾン',
        address='港区三田五丁目３番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401007990',
    ),
    'E21391': EdinetCodeEntry(
        edinet_code='E21391',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5367,
        fiscal_year_end='9月末日',
        submitter_name='株式会社アスコット',
        submitter_name_en='Ascot Corp.',
        submitter_name_yomi='カブシキガイシャアスコット',
        address='渋谷区神宮前三丁目１番３０号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7011101028617',
    ),
    'E21398': EdinetCodeEntry(
        edinet_code='E21398',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000広太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21414': EdinetCodeEntry(
        edinet_code='E21414',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ワールド・ゴールド・トラスト・サービシズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ワールドゴールドトラストサービシズエルエルシー',
        address='ニューヨーク州\u3000１００１７\u3000ニューヨーク郡\u3000サード\u3000アヴェニュー\u3000６８５\u3000２７０２号室（２７階）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21457': EdinetCodeEntry(
        edinet_code='E21457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='實吉\u3000繁幸',
        submitter_name_en=None,
        submitter_name_yomi='サネヨシ\u3000シゲユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21465': EdinetCodeEntry(
        edinet_code='E21465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鳥羽\u3000聰子',
        submitter_name_en=None,
        submitter_name_yomi='トバ\u3000トシコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21467': EdinetCodeEntry(
        edinet_code='E21467',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梶並\u3000伸博',
        submitter_name_en=None,
        submitter_name_yomi='カジナミ\u3000ノブヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21476': EdinetCodeEntry(
        edinet_code='E21476',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社カネヨシ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカネヨシ',
        address='渋谷区千駄ヶ谷三丁目６０番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001044076',
    ),
    'E21486': EdinetCodeEntry(
        edinet_code='E21486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='松栄産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウエイサンギョウカブシキガイシャ',
        address='八尾市植松町６丁目３番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8122001018737',
    ),
    'E21497': EdinetCodeEntry(
        edinet_code='E21497',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000哲男',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21501': EdinetCodeEntry(
        edinet_code='E21501',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=27136898,
        fiscal_year_end='1月31日',
        submitter_name='ウォルマート・インク',
        submitter_name_en=None,
        submitter_name_yomi='ウォルマート\u3000インク',
        address='アメリカ合衆国、デラウェア州、ニューカッスル郡、ウイルミントン市、オレンジ・ストリート１２０９番地、コーポレーション・トラスト・センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E21510': EdinetCodeEntry(
        edinet_code='E21510',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='イーストスプリング・インベストメンツ（シンガポール）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='イーストスプリング\u3000インベストメンツ\u3000シンガポール\u3000リミテッド',
        address='シンガポール共和国ストレイツ・ビュー７、＃０９－０１、マリーナ・ワン・イーストタワー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21511': EdinetCodeEntry(
        edinet_code='E21511',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大松正明',
        submitter_name_en=None,
        submitter_name_yomi='オオマツマサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21513': EdinetCodeEntry(
        edinet_code='E21513',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤明子',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウアキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21514': EdinetCodeEntry(
        edinet_code='E21514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=235,
        fiscal_year_end='3月31日',
        submitter_name='株式会社成学社',
        submitter_name_en='SEIGAKUSHA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャセイガクシャ',
        address='大阪市北区中崎西三丁目１番２号',
        industry='サービス業',
        sec_code='21790',
        corporate_number='6120001140744',
    ),
    'E21515': EdinetCodeEntry(
        edinet_code='E21515',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='太田\u3000明弘',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21553': EdinetCodeEntry(
        edinet_code='E21553',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2156,
        fiscal_year_end='3月31日',
        submitter_name='株式会社データホライゾン',
        submitter_name_en='DATA HORIZON CO.,LTD',
        submitter_name_yomi='カブシキガイシャデータホライゾン',
        address='広島市西区草津新町一丁目２１番３５号\u3000広島ミクシス・ビル',
        industry='情報・通信業',
        sec_code='36280',
        corporate_number='9240001012318',
    ),
    'E21562': EdinetCodeEntry(
        edinet_code='E21562',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='鈴与ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スズヨホールディングスカブシキカイシャ',
        address='静岡市清水区入船町１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6080001009481',
    ),
    'E21573': EdinetCodeEntry(
        edinet_code='E21573',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='有限会社井内盛英堂',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャイウチセイエイドウ',
        address='大阪市北区天満四丁目１０番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120002031201',
    ),
    'E21587': EdinetCodeEntry(
        edinet_code='E21587',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000義巳',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヨシミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21592': EdinetCodeEntry(
        edinet_code='E21592',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000弘子',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21606': EdinetCodeEntry(
        edinet_code='E21606',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='5月31日',
        submitter_name='株式会社クリエイトＳＤホールディングス',
        submitter_name_en='CREATE SD HOLDINGS CO.,LTD',
        submitter_name_yomi='カブシキガイシャクリエイトエスディーホールディングス',
        address='横浜市青葉区荏田西二丁目３番地２',
        industry='小売業',
        sec_code='31480',
        corporate_number='9020001052360',
    ),
    'E21612': EdinetCodeEntry(
        edinet_code='E21612',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西村\u3000陽子',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21618': EdinetCodeEntry(
        edinet_code='E21618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋沢\u3000英海',
        submitter_name_en=None,
        submitter_name_yomi='アキザワ\u3000ヒデウミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21619': EdinetCodeEntry(
        edinet_code='E21619',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丸田\u3000昭雄',
        submitter_name_en=None,
        submitter_name_yomi='マルタ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21620': EdinetCodeEntry(
        edinet_code='E21620',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='妹尾\u3000勲',
        submitter_name_en=None,
        submitter_name_yomi='セノオ\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21627': EdinetCodeEntry(
        edinet_code='E21627',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000準',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21649': EdinetCodeEntry(
        edinet_code='E21649',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=504,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アサカ理研',
        submitter_name_en='Asaka Riken Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアサカリケン',
        address='郡山市田村町金屋字マセ口４７番地',
        industry='非鉄金属',
        sec_code='57240',
        corporate_number='7380001004435',
    ),
    'E21665': EdinetCodeEntry(
        edinet_code='E21665',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65,
        fiscal_year_end=None,
        submitter_name='有限会社ケー・プランニング',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャケープランニング',
        address='茅ヶ崎市浜竹３ー４－５５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5021002011004',
    ),
    'E21671': EdinetCodeEntry(
        edinet_code='E21671',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='レオス・キャピタルワークス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='レオスキャピタルワークスカブシキガイシャ',
        address='千代田区丸の内一丁目１１番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='1010001082655',
    ),
    'E21704': EdinetCodeEntry(
        edinet_code='E21704',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社赤塚興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアカツカコウサン',
        address='桑名市吉之丸８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1190001011992',
    ),
    'E21706': EdinetCodeEntry(
        edinet_code='E21706',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=214,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リニカル',
        submitter_name_en='Linical Co., Ltd.',
        submitter_name_yomi='カブシキガイシャリニカル',
        address='大阪市淀川区宮原１丁目６番１号',
        industry='サービス業',
        sec_code='21830',
        corporate_number='9120001111255',
    ),
    'E21708': EdinetCodeEntry(
        edinet_code='E21708',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='ユニオン投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユニオントウシンカブシキカイシャ',
        address='松本市深志一丁目１番２１号\u3000中田歯科ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4100001016601',
    ),
    'E21717': EdinetCodeEntry(
        edinet_code='E21717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2300,
        fiscal_year_end=None,
        submitter_name='株式会社川野パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカワノパートナーズ',
        address='川越市新宿町一丁目１０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6030002080271',
    ),
    'E21733': EdinetCodeEntry(
        edinet_code='E21733',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000佳司',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ヨシジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21736': EdinetCodeEntry(
        edinet_code='E21736',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='次原\u3000悦子',
        submitter_name_en=None,
        submitter_name_yomi='ツギハラ\u3000エツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21739': EdinetCodeEntry(
        edinet_code='E21739',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='イートンコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='イートンコーポレーション',
        address='アメリカ合衆国オハイオ州４４１２２\u3000クリーブランド\u3000イートンブールバード１０００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21740': EdinetCodeEntry(
        edinet_code='E21740',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2469,
        fiscal_year_end='12月31日',
        submitter_name='株式会社電算システム',
        submitter_name_en='Densan System Co., Ltd,',
        submitter_name_yomi='カブシキガイシャデンサンシステム',
        address='岐阜市日置江一丁目５８番地',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5200001003514',
    ),
    'E21764': EdinetCodeEntry(
        edinet_code='E21764',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アニヴェルセルＨＯＬＤＩＮＧＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアニヴェルセルホールディングス',
        address='港区北青山三丁目５番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401039499',
    ),
    'E21778': EdinetCodeEntry(
        edinet_code='E21778',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=115030,
        fiscal_year_end=None,
        submitter_name='ＬＩＴＥ－ＯＮ\u3000ＴＥＣＨＮＯＬＯＧＹ\u3000ＣＯＲＰＯＲＡＴＩＯＮ',
        submitter_name_en=None,
        submitter_name_yomi='ライトンテクノロジーコーポレーション',
        address='台湾台北市内湖区瑞光路３９２号２２階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21779': EdinetCodeEntry(
        edinet_code='E21779',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3278,
        fiscal_year_end=None,
        submitter_name='ＳＩＬＩＴＥＣＨ\u3000ＴＥＣＨＮＯＬＯＧＹ\u3000ＣＯＲＰＯＲＡＴＩＯＮ',
        submitter_name_en=None,
        submitter_name_yomi='シリテックテクノロジーコーポレーション',
        address='新北市淡水区奎柔山路７３号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21799': EdinetCodeEntry(
        edinet_code='E21799',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=243,
        fiscal_year_end='12月31日',
        submitter_name='内外トランスライン株式会社',
        submitter_name_en='NAIGAI TRANS LINE LTD.',
        submitter_name_yomi='ナイガイトランスラインカブシキガイシャ',
        address='大阪市中央区備後町二丁目６番８号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='2120001085992',
    ),
    'E21814': EdinetCodeEntry(
        edinet_code='E21814',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='出原ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イデハラホールディングスカブシキカイシャ',
        address='品川区小山７－７－１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010701020952',
    ),
    'E21815': EdinetCodeEntry(
        edinet_code='E21815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=229,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ショーエイコーポレーション',
        submitter_name_en='shoei corporation',
        submitter_name_yomi='カブシキカイシャショーエイコーポレーション',
        address='大阪市中央区備後町２丁目１番１号',
        industry='化学',
        sec_code='93850',
        corporate_number='5120001043857',
    ),
    'E21830': EdinetCodeEntry(
        edinet_code='E21830',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=72,
        fiscal_year_end=None,
        submitter_name='有限会社\u3000大久保興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャオオクボコウサン',
        address='大阪市北区天満１丁目５番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120002070873',
    ),
    'E21832': EdinetCodeEntry(
        edinet_code='E21832',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=363,
        fiscal_year_end='3月31日',
        submitter_name='オーウイル株式会社',
        submitter_name_en="O'will Corporation",
        submitter_name_yomi='オーウイルカブシキガイシャ',
        address='港区北青山一丁目２番３号',
        industry='卸売業',
        sec_code='31430',
        corporate_number='5010401083638',
    ),
    'E21833': EdinetCodeEntry(
        edinet_code='E21833',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアセットマネジメント',
        address='名古屋市東区主税町四丁目８５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001057833',
    ),
    'E21839': EdinetCodeEntry(
        edinet_code='E21839',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=31,
        fiscal_year_end=None,
        submitter_name='有限会社Ｌａｍ’ｓ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャラムズ',
        address='西宮市高座町１３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140002056005',
    ),
    'E21840': EdinetCodeEntry(
        edinet_code='E21840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000千代',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000チヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21850': EdinetCodeEntry(
        edinet_code='E21850',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='株式会社成和',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセイワ',
        address='港区西新橋１丁目１４番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401015569',
    ),
    'E21867': EdinetCodeEntry(
        edinet_code='E21867',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='カバウター・マネージメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='カバウターマネージメントエルエルシー',
        address='アメリカ合衆国イリノイ州６０６１１、シカゴ、ノース・ミシガン・アベニュー４０１、６４０号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21870': EdinetCodeEntry(
        edinet_code='E21870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川村\u3000治',
        submitter_name_en=None,
        submitter_name_yomi='カワムラ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21876': EdinetCodeEntry(
        edinet_code='E21876',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='内海\u3000良夫',
        submitter_name_en=None,
        submitter_name_yomi='ウツミ\u3000ヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21897': EdinetCodeEntry(
        edinet_code='E21897',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｇ＆Ｃｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジーアンドカンパニー',
        address='港区六本木四丁目６番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401077467',
    ),
    'E21902': EdinetCodeEntry(
        edinet_code='E21902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30000,
        fiscal_year_end='3月31日',
        submitter_name='明治ホールディングス株式会社',
        submitter_name_en='Meiji Holdings Co., Ltd.',
        submitter_name_yomi='メイジホールディングスカブシキカイシャ',
        address='中央区京橋二丁目４番１６号',
        industry='食料品',
        sec_code='22690',
        corporate_number='9010001123947',
    ),
    'E21911': EdinetCodeEntry(
        edinet_code='E21911',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野田\u3000正英',
        submitter_name_en=None,
        submitter_name_yomi='ノダ\u3000マサエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21951': EdinetCodeEntry(
        edinet_code='E21951',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=218653,
        fiscal_year_end='3月末日',
        submitter_name='株式会社商工組合中央金庫',
        submitter_name_en='The Shoko Chukin Bank,Ltd.',
        submitter_name_yomi='カブシキガイシャショウコウクミアイチュウオウキンコ',
        address='中央区八重洲二丁目十番十七号',
        industry='銀行業',
        sec_code=None,
        corporate_number='9010001120408',
    ),
    'E21953': EdinetCodeEntry(
        edinet_code='E21953',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社フォワードＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフォワードティ',
        address='港区白金台４丁目１６番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401050506',
    ),
    'E21955': EdinetCodeEntry(
        edinet_code='E21955',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5374,
        fiscal_year_end='3月31日',
        submitter_name='川田テクノロジーズ株式会社',
        submitter_name_en='KAWADA TECHNOLOGIES,INC.',
        submitter_name_yomi='カワダテクノロジーズカブシキガイシャ',
        address='南砺市苗島４６１０番地',
        industry='金属製品',
        sec_code='34430',
        corporate_number='6230001009490',
    ),
    'E21958': EdinetCodeEntry(
        edinet_code='E21958',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='廣沢\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='ヒロサワ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21969': EdinetCodeEntry(
        edinet_code='E21969',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=810,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エス・ディー・エス\u3000バイオテック',
        submitter_name_en='SDS Biotech K.K.',
        submitter_name_yomi='カブシキガイシャエスディーエスバイオテック',
        address='中央区東日本橋一丁目１番５号',
        industry='化学',
        sec_code=None,
        corporate_number='7010001092764',
    ),
    'E21970': EdinetCodeEntry(
        edinet_code='E21970',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=397,
        fiscal_year_end=None,
        submitter_name='ＵＴＩインターナショナル（シンガポール）・プライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ユーティーアイインターナショナルシンガポールプライベートリミテッド',
        address='シンガポール、チャーチ・ストリート３、２２－０１、サムスン・ハブ・ビルディング',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E21976': EdinetCodeEntry(
        edinet_code='E21976',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＧＡＵＤＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ガウディカブシキガイシャ',
        address='平塚市宝町５－２７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9021001036956',
    ),
    'E21995': EdinetCodeEntry(
        edinet_code='E21995',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＫＯ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ティケイオー',
        address='港区赤坂八丁目４番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401084696',
    ),
    'E22007': EdinetCodeEntry(
        edinet_code='E22007',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1517,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＣＡＲＴＡ\u3000ＨＯＬＤＩＮＧＳ',
        submitter_name_en='CARTA HOLDINGS, INC.',
        submitter_name_yomi='カブシキカイシャカルタホールディングス',
        address='港区虎ノ門二丁目６番１号虎ノ門ヒルズステーションタワー３６階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6011001033049',
    ),
    'E22012': EdinetCodeEntry(
        edinet_code='E22012',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='グリーホールディングス株式会社',
        submitter_name_en='GREE Holdings, Inc.',
        submitter_name_yomi='グリーホールディングスカブシキガイシャ',
        address='港区六本木六丁目１１番１号六本木ヒルズゲートタワー',
        industry='情報・通信業',
        sec_code='36320',
        corporate_number='8010401055923',
    ),
    'E22016': EdinetCodeEntry(
        edinet_code='E22016',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=358,
        fiscal_year_end='4月30日',
        submitter_name='株式会社菊池製作所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキクチセイサクショ',
        address='八王子市美山町２１６１番地２１',
        industry='金属製品',
        sec_code='34440',
        corporate_number='6010101000917',
    ),
    'E22024': EdinetCodeEntry(
        edinet_code='E22024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=697,
        fiscal_year_end='12月31日',
        submitter_name='株式会社デ・ウエスタン・セラピテクス研究所',
        submitter_name_en='D.Western Therapeutics Institute, Inc.',
        submitter_name_yomi='カブシキガイシャデウエスタンセラピテクスケンキュウジョ',
        address='名古屋市中区錦一丁目１８番１１号',
        industry='医薬品',
        sec_code='45760',
        corporate_number='5180001055013',
    ),
    'E22029': EdinetCodeEntry(
        edinet_code='E22029',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='合同会社エーエスティ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエーエスティ',
        address='神戸市北区鈴蘭台西町２―４―１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140002026756',
    ),
    'E22035': EdinetCodeEntry(
        edinet_code='E22035',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='五十嵐\u3000幹',
        submitter_name_en=None,
        submitter_name_yomi='イガラシ\u3000ミキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22038': EdinetCodeEntry(
        edinet_code='E22038',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中田\u3000みち',
        submitter_name_en=None,
        submitter_name_yomi='ナカタ\u3000ミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22042': EdinetCodeEntry(
        edinet_code='E22042',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=657,
        fiscal_year_end='9月30日',
        submitter_name='株式会社シイエム・シイ',
        submitter_name_en='CMC CORPORATION',
        submitter_name_yomi='カブシキカイシャシイエムシイ',
        address='名古屋市中区平和一丁目１番１９号',
        industry='サービス業',
        sec_code='21850',
        corporate_number='4180001036617',
    ),
    'E22045': EdinetCodeEntry(
        edinet_code='E22045',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000守',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000マモル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22046': EdinetCodeEntry(
        edinet_code='E22046',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000利典',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000トシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22049': EdinetCodeEntry(
        edinet_code='E22049',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=214,
        fiscal_year_end='2月末日',
        submitter_name='ソーバル株式会社',
        submitter_name_en='Sobal Corporation',
        submitter_name_yomi='ソーバルカブシキカイシャ',
        address='品川区北品川５－９－１１',
        industry='サービス業',
        sec_code='21860',
        corporate_number='9010801008257',
    ),
    'E22055': EdinetCodeEntry(
        edinet_code='E22055',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000直哉',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ナオヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22060': EdinetCodeEntry(
        edinet_code='E22060',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社アップワード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアップワード',
        address='川崎市中原区市ノ坪１５０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001068748',
    ),
    'E22069': EdinetCodeEntry(
        edinet_code='E22069',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小口\u3000八穗子',
        submitter_name_en=None,
        submitter_name_yomi='オグチ\u3000ヤホコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22070': EdinetCodeEntry(
        edinet_code='E22070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小口\u3000英噐',
        submitter_name_en=None,
        submitter_name_yomi='オグチ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22083': EdinetCodeEntry(
        edinet_code='E22083',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1500,
        fiscal_year_end=None,
        submitter_name='三井物産企業投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツイブッサンキギョウトウシカブシキカイシャ',
        address='千代田区大手町一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001083062',
    ),
    'E22087': EdinetCodeEntry(
        edinet_code='E22087',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='坂本\u3000勲勇',
        submitter_name_en=None,
        submitter_name_yomi='サカモト\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22089': EdinetCodeEntry(
        edinet_code='E22089',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ヒロタ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒロタカブシキガイシャ',
        address='岐阜市玉姓町３丁目２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4200001004414',
    ),
    'E22096': EdinetCodeEntry(
        edinet_code='E22096',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='コモンズ投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コモンズトウシンカブシキカイシャ',
        address='港区南青山二丁目５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001113497',
    ),
    'E22101': EdinetCodeEntry(
        edinet_code='E22101',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=149,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯペパボ株式会社',
        submitter_name_en='GMO Pepabo, Inc.',
        submitter_name_yomi='ジーエムオーペパボカブシキガイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='情報・通信業',
        sec_code='36330',
        corporate_number='5011001042496',
    ),
    'E22103': EdinetCodeEntry(
        edinet_code='E22103',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社Ｐｅｒｓｏｎｓ\u3000Ｂｒｉｄｇｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャパーソンズブリッジ',
        address='新宿区西新宿二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101037005',
    ),
    'E22107': EdinetCodeEntry(
        edinet_code='E22107',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1287,
        fiscal_year_end=None,
        submitter_name='ＪＡＰＡＮ\u3000ＡＳＩＡ\u3000ＨＯＬＤＩＮＧＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ジャパン\u3000アジア\u3000ホールディングズ\u3000リミテッド',
        address='Ｐ．Ｏ．ＢＯＸ\u3000３１１１９\u3000Ｇｒａｎｄ\u3000Ｐａｖｉｌｉｏｎ，Ｈｉｂｉｓｃｕｓ\u3000Ｗａｙ，８０２\u3000Ｗｅｓｔ\u3000Ｂａｙ\u3000Ｒｏａｄ，Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，ＫＹ１‐１２０５，Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22113': EdinetCodeEntry(
        edinet_code='E22113',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹田\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='タケダ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22125': EdinetCodeEntry(
        edinet_code='E22125',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=54,
        fiscal_year_end=None,
        submitter_name='有限会社エムエフ長堀',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエムエフナガホリ',
        address='台東区上野１－１２－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010502009802',
    ),
    'E22130': EdinetCodeEntry(
        edinet_code='E22130',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=326,
        fiscal_year_end='2月末日',
        submitter_name='株式会社リックコーポレーション',
        submitter_name_en='LIC CO.,LTD.',
        submitter_name_yomi='カブシキガイシャリックコーポレーション',
        address='岡山市北区下中野４６５番地の４',
        industry='小売業',
        sec_code=None,
        corporate_number='2260001003593',
    ),
    'E22146': EdinetCodeEntry(
        edinet_code='E22146',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社フレキシブル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフレキシブル',
        address='渋谷区渋谷二丁目９番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001117173',
    ),
    'E22184': EdinetCodeEntry(
        edinet_code='E22184',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社エムエヌ企画',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエムエヌキカク',
        address='八王子市横山町４番５－１６０８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2090002009590',
    ),
    'E22186': EdinetCodeEntry(
        edinet_code='E22186',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社エノモト興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャエノモトコウサン',
        address='上野原市上野原７４７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4090002009589',
    ),
    'E22189': EdinetCodeEntry(
        edinet_code='E22189',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ジェイユー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイユー',
        address='港区南青山二丁目２番１５号ウィン青山１４０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010901021425',
    ),
    'E22198': EdinetCodeEntry(
        edinet_code='E22198',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=6000,
        fiscal_year_end='3月31日',
        submitter_name='東海東京証券株式会社',
        submitter_name_en='Tokai Tokyo Securities  Co., Ltd.',
        submitter_name_yomi='トウカイトウキョウショウケンカブシキガイシャ',
        address='名古屋市中村区名駅四丁目７番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='5180001088789',
    ),
    'E22200': EdinetCodeEntry(
        edinet_code='E22200',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シティグループファーストインベストメントマネジメントリミテッド',
        address='香港、セントラル、ガーデン・ロード３、チャンピオン・タワー５０Ｆ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22203': EdinetCodeEntry(
        edinet_code='E22203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山下\u3000宗吾',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000シュウゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22213': EdinetCodeEntry(
        edinet_code='E22213',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='大口興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオグチコウサンカブシキカイシャ',
        address='名古屋市昭和区高峯町１４３番地の３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001022098',
    ),
    'E22222': EdinetCodeEntry(
        edinet_code='E22222',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福井\u3000康人',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22233': EdinetCodeEntry(
        edinet_code='E22233',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='大同商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイドウショウジカブシキガイシャ',
        address='生駒市白庭台６丁目８番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001024208',
    ),
    'E22239': EdinetCodeEntry(
        edinet_code='E22239',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエス\u3000ルクス\u3000ボンド\u3000シキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22245': EdinetCodeEntry(
        edinet_code='E22245',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000理香',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000リカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22256': EdinetCodeEntry(
        edinet_code='E22256',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村石\u3000久二',
        submitter_name_en=None,
        submitter_name_yomi='ムライシ\u3000ヒサジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22263': EdinetCodeEntry(
        edinet_code='E22263',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長沢\u3000一男',
        submitter_name_en=None,
        submitter_name_yomi='ナガサワ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22277': EdinetCodeEntry(
        edinet_code='E22277',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社タイパック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタイパック',
        address='春日部市新宿新田３３３番地４２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7030001052568',
    ),
    'E22314': EdinetCodeEntry(
        edinet_code='E22314',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000良和',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22316': EdinetCodeEntry(
        edinet_code='E22316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々\u3000幸恭',
        submitter_name_en=None,
        submitter_name_yomi='ササ\u3000ユキヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22334': EdinetCodeEntry(
        edinet_code='E22334',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22335': EdinetCodeEntry(
        edinet_code='E22335',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000龍郎',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000タツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22342': EdinetCodeEntry(
        edinet_code='E22342',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社テル・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテルコーポレーション',
        address='渋谷区代々木４－４２－１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001015129',
    ),
    'E22357': EdinetCodeEntry(
        edinet_code='E22357',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横田\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ヨコタ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22366': EdinetCodeEntry(
        edinet_code='E22366',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ワイエム管財',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイエムカンザイ',
        address='中央区日本橋兜町５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011601014589',
    ),
    'E22400': EdinetCodeEntry(
        edinet_code='E22400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='芝原\u3000英司',
        submitter_name_en=None,
        submitter_name_yomi='シバハラ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22416': EdinetCodeEntry(
        edinet_code='E22416',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='有限会社丸六',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャマルロク',
        address='文京区西片二丁目４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010002030577',
    ),
    'E22429': EdinetCodeEntry(
        edinet_code='E22429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西山\u3000由之',
        submitter_name_en=None,
        submitter_name_yomi='ニシヤマ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22440': EdinetCodeEntry(
        edinet_code='E22440',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社バイタルケーエスケー・ホールディングス',
        submitter_name_en='VITAL KSK HOLDINGS,INC.',
        submitter_name_yomi='カブシキカイシャバイタルケーエスケーホールディングス',
        address='世田谷区弦巻一丁目１番１２号',
        industry='卸売業',
        sec_code='31510',
        corporate_number='4010901024332',
    ),
    'E22444': EdinetCodeEntry(
        edinet_code='E22444',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='五十嵐\u3000充',
        submitter_name_en=None,
        submitter_name_yomi='イガラシ\u3000ミツル',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22451': EdinetCodeEntry(
        edinet_code='E22451',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山﨑\u3000好和',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22460': EdinetCodeEntry(
        edinet_code='E22460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コーエーテクモホールディングス',
        submitter_name_en='KOEI TECMO HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャコーエーテクモホールディングス',
        address='横浜市港北区箕輪町一丁目１８番１２号',
        industry='情報・通信業',
        sec_code='36350',
        corporate_number='4020001061110',
    ),
    'E22461': EdinetCodeEntry(
        edinet_code='E22461',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=505,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ソケッツ',
        submitter_name_en='Sockets Inc.',
        submitter_name_yomi='カブシキガイシャソケッツ',
        address='渋谷区恵比寿４丁目２０番３号\u3000恵比寿ガーデンプレイスタワー３６階',
        industry='情報・通信業',
        sec_code='36340',
        corporate_number='8011001061907',
    ),
    'E22464': EdinetCodeEntry(
        edinet_code='E22464',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='3月31日',
        submitter_name='株式会社岐阜中濃土地建物',
        submitter_name_en='GIFU CHUNO TOCHITATEMONO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャギフチュウノウトチタテモノ',
        address='関市小迫間東別所８５２番地',
        industry='不動産業',
        sec_code=None,
        corporate_number='9200001019820',
    ),
    'E22465': EdinetCodeEntry(
        edinet_code='E22465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000吉弘',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22470': EdinetCodeEntry(
        edinet_code='E22470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1556,
        fiscal_year_end='12月末日',
        submitter_name='株式会社バリューＨＲ',
        submitter_name_en='Value HR Co., Ltd.',
        submitter_name_yomi='カブシキガイシャバリューエイチアール',
        address='渋谷区千駄ヶ谷五丁目２１番１４号',
        industry='サービス業',
        sec_code='60780',
        corporate_number='7011001036950',
    ),
    'E22474': EdinetCodeEntry(
        edinet_code='E22474',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小熊\u3000千惠子',
        submitter_name_en=None,
        submitter_name_yomi='オグマ\u3000チエコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22509': EdinetCodeEntry(
        edinet_code='E22509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=495,
        fiscal_year_end='3月31日',
        submitter_name='大研医器株式会社',
        submitter_name_en='DAIKEN MEDICAL CO.,LTD',
        submitter_name_yomi='ダイケンイキカブシキガイシャ',
        address='和泉市あゆみ野２丁目６番２号',
        industry='精密機器',
        sec_code='77750',
        corporate_number='7120001083307',
    ),
    'E22524': EdinetCodeEntry(
        edinet_code='E22524',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本多\u3000基記',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000モトノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22528': EdinetCodeEntry(
        edinet_code='E22528',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=131755,
        fiscal_year_end='12月31日',
        submitter_name='コーニングインコーポレイティッド',
        submitter_name_en=None,
        submitter_name_yomi='コーニングインコーポレイティッド',
        address='アメリカ合衆国ニューヨーク州コーニング\u3000ワン・リバーフロント・プラザ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E22544': EdinetCodeEntry(
        edinet_code='E22544',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西村\u3000元秀',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000モトヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22547': EdinetCodeEntry(
        edinet_code='E22547',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=708,
        fiscal_year_end='3月31日',
        submitter_name='株式会社グリムス',
        submitter_name_en='grems,Inc.',
        submitter_name_yomi='カブシキガイシャグリムス',
        address='品川区東品川二丁目２番４号',
        industry='卸売業',
        sec_code='31500',
        corporate_number='8010701018101',
    ),
    'E22554': EdinetCodeEntry(
        edinet_code='E22554',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=324,
        fiscal_year_end='12月31日',
        submitter_name='株式会社小田原機器',
        submitter_name_en='ODAWARA AUTO-MACHINE MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオダワラキキ',
        address='小田原市中町一丁目１１番３号',
        industry='輸送用機器',
        sec_code='73140',
        corporate_number='6021001032396',
    ),
    'E22555': EdinetCodeEntry(
        edinet_code='E22555',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トータルネットワークホールディングスリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='トータルネットワークホールディングスリミテッド',
        address='英国領ヴァージン諸島、ＶＧ１１１０、トルトラ、ロードタウン、１３９メイン・ストリート、ナジコ・ビルディング２階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22559': EdinetCodeEntry(
        edinet_code='E22559',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=70000,
        fiscal_year_end='12月末日',
        submitter_name='サントリーホールディングス株式会社',
        submitter_name_en='Suntory Holdings Limited',
        submitter_name_yomi='サントリーホールディングスカブシキカイシャ',
        address='大阪市北区堂島浜二丁目１番４０号',
        industry='食料品',
        sec_code=None,
        corporate_number='3120001136159',
    ),
    'E22560': EdinetCodeEntry(
        edinet_code='E22560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='大幸薬品株式会社',
        submitter_name_en='TAIKO PHARMACEUTICAL CO., LTD.',
        submitter_name_yomi='タイコウヤクヒンカブシキガイシャ',
        address='吹田市内本町三丁目３４番１４号',
        industry='医薬品',
        sec_code='45740',
        corporate_number='2120901007344',
    ),
    'E22575': EdinetCodeEntry(
        edinet_code='E22575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津川\u3000善夫',
        submitter_name_en=None,
        submitter_name_yomi='ツガワ\u3000ヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22605': EdinetCodeEntry(
        edinet_code='E22605',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋元\u3000利規',
        submitter_name_en=None,
        submitter_name_yomi='アキモト\u3000トシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22606': EdinetCodeEntry(
        edinet_code='E22606',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='有限会社ローゼンクイーン商会',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャローゼンクイーンショウカイ',
        address='各務原市新鵜沼台三丁目２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5200002007142',
    ),
    'E22612': EdinetCodeEntry(
        edinet_code='E22612',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1180,
        fiscal_year_end='11月末日',
        submitter_name='株式会社ファンドクリエーショングループ',
        submitter_name_en='Fund Creation Group Co.,Ltd',
        submitter_name_yomi='カブシキカイシャファンドクリエーショングループ',
        address='千代田区麹町一丁目４番地',
        industry='不動産業',
        sec_code='32660',
        corporate_number='8010001145769',
    ),
    'E22621': EdinetCodeEntry(
        edinet_code='E22621',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3315,
        fiscal_year_end='12月末日',
        submitter_name='テラ株式会社',
        submitter_name_en='tella,Inc.',
        submitter_name_yomi='テラカブシキガイシャ',
        address='新宿区西新宿七丁目２２番３６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010001132341',
    ),
    'E22630': EdinetCodeEntry(
        edinet_code='E22630',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2985515,
        fiscal_year_end='12月31日',
        submitter_name='エイチエスビーシー・バンク・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーバンクピーエルシー',
        address='連合王国Ｅ１４\u3000５ＨＱロンドン市カナダ・スクエア８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E22658': EdinetCodeEntry(
        edinet_code='E22658',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='グローバルリンクアドバイザーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グローバルリンクアドバイザーズカブシキガイシャ',
        address='大阪市北区神山町８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001102627',
    ),
    'E22663': EdinetCodeEntry(
        edinet_code='E22663',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月末日',
        submitter_name='クックパッド株式会社',
        submitter_name_en='Cookpad Inc.',
        submitter_name_yomi='クックパッドカブシキカイシャ',
        address='目黒区大橋二丁目２２番４４号',
        industry='サービス業',
        sec_code='21930',
        corporate_number='6010401071872',
    ),
    'E22667': EdinetCodeEntry(
        edinet_code='E22667',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤\u3000安邦',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000ヤスクニ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22684': EdinetCodeEntry(
        edinet_code='E22684',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='敷地\u3000みか',
        submitter_name_en=None,
        submitter_name_yomi='シキジ\u3000ミカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22697': EdinetCodeEntry(
        edinet_code='E22697',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000文子',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000フミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22749': EdinetCodeEntry(
        edinet_code='E22749',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='志太ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シダホールディングスカブシキカイシャ',
        address='千代田区紀尾井町４－１\u3000ニューオータニ・ビジネスコート１０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001045050',
    ),
    'E22760': EdinetCodeEntry(
        edinet_code='E22760',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4321796,
        fiscal_year_end=None,
        submitter_name='ＨＳＢＣグローバル・インベストメント・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーグローバルインベストメントファンド',
        address='ルクセンブルグ大公国、ホヴァルト\u3000Ｌ－２３７０、ペテルネルシェン通り４番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22762': EdinetCodeEntry(
        edinet_code='E22762',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='有限会社ユーホー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャユーホー',
        address='綾瀬市大上５丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021002047091',
    ),
    'E22764': EdinetCodeEntry(
        edinet_code='E22764',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='酒井\u3000貞彦',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000サダヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22768': EdinetCodeEntry(
        edinet_code='E22768',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='アクセスアジア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アクセスアジアカブシキガイシャ',
        address='品川区上大崎１丁目３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401091820',
    ),
    'E22769': EdinetCodeEntry(
        edinet_code='E22769',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＣネットワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエヌシーネットワーク',
        address='台東区東上野一丁目１４番５号ユーエムビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001067938',
    ),
    'E22774': EdinetCodeEntry(
        edinet_code='E22774',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ホスピタルネット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャホスピタルネット',
        address='大阪市北区西天満４－８－１７宇治電ビルデイング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001094405',
    ),
    'E22777': EdinetCodeEntry(
        edinet_code='E22777',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000政臣',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000マサオミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22787': EdinetCodeEntry(
        edinet_code='E22787',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木\u3000征一郎',
        submitter_name_en=None,
        submitter_name_yomi='ミキ\u3000セイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22801': EdinetCodeEntry(
        edinet_code='E22801',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堤\u3000征二',
        submitter_name_en=None,
        submitter_name_yomi='ツツミ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22806': EdinetCodeEntry(
        edinet_code='E22806',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000俊之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22818': EdinetCodeEntry(
        edinet_code='E22818',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=85,
        fiscal_year_end=None,
        submitter_name='株式会社ゼロシステム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャゼロシステム',
        address='四日市市住吉町５番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7190001015559',
    ),
    'E22835': EdinetCodeEntry(
        edinet_code='E22835',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000満',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22849': EdinetCodeEntry(
        edinet_code='E22849',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22867': EdinetCodeEntry(
        edinet_code='E22867',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=70,
        fiscal_year_end=None,
        submitter_name='有限会社松籟',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャショウライ',
        address='神戸市東灘区御影山手五丁目９番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120002036276',
    ),
    'E22879': EdinetCodeEntry(
        edinet_code='E22879',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＳＩグローバル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスアイグローバルカブシキガイシャ',
        address='中央区日本橋蛎殻町一丁目５番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401091210',
    ),
    'E22883': EdinetCodeEntry(
        edinet_code='E22883',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='西武ハウス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セイブハウスカブシキガイシャ',
        address='福岡市中央区長浜３丁目１６番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4290001008266',
    ),
    'E22889': EdinetCodeEntry(
        edinet_code='E22889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ゴー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャゴー',
        address='福岡市中央区薬院３丁目１６番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290002025477',
    ),
    'E22896': EdinetCodeEntry(
        edinet_code='E22896',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='浦部\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='ウラベ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22921': EdinetCodeEntry(
        edinet_code='E22921',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ヒラノ・アソシエイツ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒラノアソシエイツ',
        address='渋谷区道玄坂１－１５－３－１１０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011002026721',
    ),
    'E22942': EdinetCodeEntry(
        edinet_code='E22942',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大田\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22987': EdinetCodeEntry(
        edinet_code='E22987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='関\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='セキ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E22991': EdinetCodeEntry(
        edinet_code='E22991',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='サントリー酒類株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サントリーシュルイカブシキカイシャ',
        address='港区台場二丁目３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401081172',
    ),
    'E22995': EdinetCodeEntry(
        edinet_code='E22995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1344,
        fiscal_year_end='6月30日',
        submitter_name='メディアスホールディングス株式会社',
        submitter_name_en='MEDIUS HOLDINGS Co.,Ltd.',
        submitter_name_yomi='メディアスホールディングスカブシキガイシャ',
        address='千代田区有楽町一丁目２番２号',
        industry='卸売業',
        sec_code='31540',
        corporate_number='3010001135832',
    ),
    'E23032': EdinetCodeEntry(
        edinet_code='E23032',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1090,
        fiscal_year_end=None,
        submitter_name='アーカス・インベストメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アーカスインベストメントリミテッド',
        address='連合王国ロンドン\u3000セカンドフロア、７ストラットフォードプレイス\u3000２ｎｄ\u3000ｆｌｏｏｒ、７Ｓｔｒａｔｆｏｒｄ\u3000Ｐｌａｃｅ，Ｌｏｎｄｏｎ，Ｗ１Ｃ\u3000１ＡＹ，ＵＫ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23045': EdinetCodeEntry(
        edinet_code='E23045',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='モダンパス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='モダンパスゴウドウカイシャ',
        address='千代田区一番町２２－３アデックス一番町ビル４０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010003014588',
    ),
    'E23050': EdinetCodeEntry(
        edinet_code='E23050',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉田\u3000直良',
        submitter_name_en=None,
        submitter_name_yomi='スギタ\u3000ナオヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23058': EdinetCodeEntry(
        edinet_code='E23058',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北村\u3000良一',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23060': EdinetCodeEntry(
        edinet_code='E23060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新保\u3000光栄',
        submitter_name_en=None,
        submitter_name_yomi='シンボ\u3000コウエイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23064': EdinetCodeEntry(
        edinet_code='E23064',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='有限会社フクジュコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャフクジュコーポレーション',
        address='中央区日本橋小網町１８番２０－９０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010002024510',
    ),
    'E23074': EdinetCodeEntry(
        edinet_code='E23074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二宮\u3000五月',
        submitter_name_en=None,
        submitter_name_yomi='ニノミヤ\u3000サツキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23075': EdinetCodeEntry(
        edinet_code='E23075',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植村\u3000綾',
        submitter_name_en=None,
        submitter_name_yomi='ウエムラ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23082': EdinetCodeEntry(
        edinet_code='E23082',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000久尚',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ヒサナオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23122': EdinetCodeEntry(
        edinet_code='E23122',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='是枝\u3000伸彦',
        submitter_name_en=None,
        submitter_name_yomi='コレエダ\u3000ノブヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23130': EdinetCodeEntry(
        edinet_code='E23130',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='椋本\u3000充士',
        submitter_name_en=None,
        submitter_name_yomi='ムクモト\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23136': EdinetCodeEntry(
        edinet_code='E23136',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='株式会社日立産機システム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒタチサンキシステム',
        address='千代田区外神田一丁目５番１号\u3000住友不動産秋葉原ファーストビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001090826',
    ),
    'E23147': EdinetCodeEntry(
        edinet_code='E23147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='早川\u3000与規',
        submitter_name_en=None,
        submitter_name_yomi='ハヤカワ\u3000トモノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23156': EdinetCodeEntry(
        edinet_code='E23156',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社アミューズキャピタルインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアミューズキャピタルインベストメント',
        address='中央区銀座３－１５－８\u3000銀座プラザビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001138765',
    ),
    'E23167': EdinetCodeEntry(
        edinet_code='E23167',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＳＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムエスエス',
        address='豊島区西池袋三丁目６－１８\u3000アビタシオン３０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5013301024777',
    ),
    'E23179': EdinetCodeEntry(
        edinet_code='E23179',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=266,
        fiscal_year_end=None,
        submitter_name='株式会社図書館流通センター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトショカンリュウツウセンター',
        address='文京区大塚三丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001005556',
    ),
    'E23187': EdinetCodeEntry(
        edinet_code='E23187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18000,
        fiscal_year_end='3月31日',
        submitter_name='フィデアホールディングス株式会社',
        submitter_name_en='FIDEA Holdings Co. Ltd.',
        submitter_name_yomi='フィデアホールディングスカブシキカイシャ',
        address='仙台市青葉区中央三丁目１番２４号',
        industry='銀行業',
        sec_code='87130',
        corporate_number='4370001018694',
    ),
    'E23192': EdinetCodeEntry(
        edinet_code='E23192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000典義\u3000相続人代表\u3000玉野\u3000玲子',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ノリヨシ\u3000ソウゾクニンダイヒョウ\u3000タマノ\u3000レイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23193': EdinetCodeEntry(
        edinet_code='E23193',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='有限会社エヌ・アンド・アイ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエヌアンドアイ',
        address='中郡大磯町東小磯６９７－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7021002060346',
    ),
    'E23201': EdinetCodeEntry(
        edinet_code='E23201',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='ステート・ストリート・グローバル・アドバイザーズ・シンガポール・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ステートストリートグローバルアドバイザーズシンガポールリミテッド',
        address='シンガポール\u3000０６８９１２\u3000キャピタルタワー\u3000＃３３－０１\u3000ロビンソンロード\u3000１６８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23202': EdinetCodeEntry(
        edinet_code='E23202',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='雪印メグミルク株式会社',
        submitter_name_en='MEGMILK SNOW BRAND Co.,Ltd.',
        submitter_name_yomi='ユキジルシメグミルクカブシキカイシャ',
        address='札幌市東区苗穂町６丁目１番１号',
        industry='食料品',
        sec_code='22700',
        corporate_number='8430001041570',
    ),
    'E23224': EdinetCodeEntry(
        edinet_code='E23224',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アプラス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアプラス',
        address='大阪市浪速区湊町一丁目２番３号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='2120001137521',
    ),
    'E23226': EdinetCodeEntry(
        edinet_code='E23226',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='細江\u3000由紀子',
        submitter_name_en=None,
        submitter_name_yomi='ホソエ\u3000ユキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23227': EdinetCodeEntry(
        edinet_code='E23227',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='都丸\u3000由美子',
        submitter_name_en=None,
        submitter_name_yomi='トマル\u3000ユミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23231': EdinetCodeEntry(
        edinet_code='E23231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉本\u3000隆洋',
        submitter_name_en=None,
        submitter_name_yomi='スギモト\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23244': EdinetCodeEntry(
        edinet_code='E23244',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社トゥルース',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャトゥルース',
        address='津市半田１１１３番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7190002001087',
    ),
    'E23245': EdinetCodeEntry(
        edinet_code='E23245',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4383,
        fiscal_year_end='3月31日',
        submitter_name='株式会社レスター',
        submitter_name_en='Restar Corporation',
        submitter_name_yomi='カブシキガイシャレスター',
        address='港区港南二丁目１０番９号',
        industry='卸売業',
        sec_code='31560',
        corporate_number='7010701022780',
    ),
    'E23250': EdinetCodeEntry(
        edinet_code='E23250',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=102999,
        fiscal_year_end='3月31日',
        submitter_name='株式会社池田泉州ホールディングス',
        submitter_name_en='Senshu Ikeda Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャイケダセンシュウホールディングス',
        address='大阪市北区茶屋町１８番１４号',
        industry='銀行業',
        sec_code='87140',
        corporate_number='1120001140303',
    ),
    'E23255': EdinetCodeEntry(
        edinet_code='E23255',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小森\u3000孝一',
        submitter_name_en=None,
        submitter_name_yomi='コモリ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23256': EdinetCodeEntry(
        edinet_code='E23256',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小森\u3000俊太郎',
        submitter_name_en=None,
        submitter_name_yomi='コモリ\u3000シュンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23262': EdinetCodeEntry(
        edinet_code='E23262',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='カタリスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カタリストカブシキカイシャ',
        address='豊島区長崎６－２２－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010901022038',
    ),
    'E23274': EdinetCodeEntry(
        edinet_code='E23274',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ケープ・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ケープアセットマネジメントリミテッド',
        address='香港、クイーンズウエイ\u3000８９番地、リッポ・センター、タワー１、３３階、３３０３号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23282': EdinetCodeEntry(
        edinet_code='E23282',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀬戸\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='セト\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23288': EdinetCodeEntry(
        edinet_code='E23288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=850,
        fiscal_year_end='3月31日',
        submitter_name='ジオリーブグループ株式会社',
        submitter_name_en='GEOLIVE Group Corporation',
        submitter_name_yomi='ジオリーブグループカブシキガイシャ',
        address='港区新橋六丁目３番４号',
        industry='卸売業',
        sec_code='31570',
        corporate_number='8010401084328',
    ),
    'E23302': EdinetCodeEntry(
        edinet_code='E23302',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=190,
        fiscal_year_end=None,
        submitter_name='阪神酒販株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハンシンシュハンカブシキガイシャ',
        address='神戸市兵庫区吉田町二丁目１３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001013902',
    ),
    'E23303': EdinetCodeEntry(
        edinet_code='E23303',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='スーパーファンド・ジャパン・トレーディング（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スーパーファンドジャパントレーディングケイマンリミテッド',
        address='ケイマン諸島、ＫＹ１－９０１０、グランド・ケイマン、クリケット・スクエア、ウィロー・ハウス４階、キャンベルズ・コーポレート・サービシーズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23305': EdinetCodeEntry(
        edinet_code='E23305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内田\u3000雅敏',
        submitter_name_en=None,
        submitter_name_yomi='ウチダ\u3000マサトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23311': EdinetCodeEntry(
        edinet_code='E23311',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='穐田\u3000誉輝',
        submitter_name_en=None,
        submitter_name_yomi='アキタ\u3000ヨシテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23312': EdinetCodeEntry(
        edinet_code='E23312',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='分部\u3000日出男',
        submitter_name_en=None,
        submitter_name_yomi='ワケベ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23338': EdinetCodeEntry(
        edinet_code='E23338',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小渕\u3000宏二',
        submitter_name_en=None,
        submitter_name_yomi='オブチ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23350': EdinetCodeEntry(
        edinet_code='E23350',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田崎\u3000忠良',
        submitter_name_en=None,
        submitter_name_yomi='タザキ\u3000タダヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23378': EdinetCodeEntry(
        edinet_code='E23378',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000賢',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23404': EdinetCodeEntry(
        edinet_code='E23404',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＧＭＯアドホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーエムオーアドホールディングスカブシキガイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001050046',
    ),
    'E23437': EdinetCodeEntry(
        edinet_code='E23437',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡﨑\u3000成子',
        submitter_name_en=None,
        submitter_name_yomi='オカザキ\u3000シゲコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23448': EdinetCodeEntry(
        edinet_code='E23448',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ウィズダムツリー・メタル・セキュリティーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウィズダムツリーメタルセキュリティーズリミテッド',
        address='英国チャンネル諸島、ジャージー\u3000ジェーイー４\u3000８ピーダブリュー、セント・ハリアー、ピア・ロード\u3000３１、オーデナンス・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23465': EdinetCodeEntry(
        edinet_code='E23465',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=545,
        fiscal_year_end='9月30日',
        submitter_name='粧美堂株式会社',
        submitter_name_en='SHOBIDO Corporation',
        submitter_name_yomi='ショウビドウカブシキガイシャ',
        address='港区港南二丁目１５番１号',
        industry='その他製品',
        sec_code='78190',
        corporate_number='4010401097556',
    ),
    'E23479': EdinetCodeEntry(
        edinet_code='E23479',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=480,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シーボン',
        submitter_name_en="C'BON COSMETICS Co.,Ltd",
        submitter_name_yomi='カブシキガイシャシーボン',
        address='港区六本木七丁目１８番１２号',
        industry='化学',
        sec_code='49260',
        corporate_number='4010401012787',
    ),
    'E23483': EdinetCodeEntry(
        edinet_code='E23483',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森田\u3000純子',
        submitter_name_en=None,
        submitter_name_yomi='モリタ\u3000ジュンコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23487': EdinetCodeEntry(
        edinet_code='E23487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6777,
        fiscal_year_end='6月末日',
        submitter_name='株式会社キャンバス',
        submitter_name_en='CanBas Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャキャンバス',
        address='沼津市大手町二丁目２番１号',
        industry='医薬品',
        sec_code='45750',
        corporate_number='1080101002382',
    ),
    'E23492': EdinetCodeEntry(
        edinet_code='E23492',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6336,
        fiscal_year_end='9月末日',
        submitter_name='株式会社三菱総合研究所',
        submitter_name_en='Mitsubishi Research Institute, Inc.',
        submitter_name_yomi='カブシキガイシャミツビシソウゴウケンキュウショ',
        address='千代田区永田町二丁目１０番３号',
        industry='情報・通信業',
        sec_code='36360',
        corporate_number='6010001030403',
    ),
    'E23509': EdinetCodeEntry(
        edinet_code='E23509',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=480,
        fiscal_year_end=None,
        submitter_name='大谷製鉄株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオタニセイテツカブシキカイシャ',
        address='射水市奈呉の江８番地の４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6230001012379',
    ),
    'E23516': EdinetCodeEntry(
        edinet_code='E23516',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本観光免税株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンカンコウメンゼイカブシキカイシャ',
        address='飯山市大字飯山１１４９２番地４２９モンエール斑尾',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4013201011983',
    ),
    'E23518': EdinetCodeEntry(
        edinet_code='E23518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢吹\u3000満',
        submitter_name_en=None,
        submitter_name_yomi='ヤブキ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23582': EdinetCodeEntry(
        edinet_code='E23582',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=11768699,
        fiscal_year_end='3月31日',
        submitter_name='株式会社日本政策金融公庫',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッポンセイサクキンユウコウコ',
        address='千代田区大手町１丁目９番４号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='8010001120391',
    ),
    'E23594': EdinetCodeEntry(
        edinet_code='E23594',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=44551,
        fiscal_year_end=None,
        submitter_name='マッコーリー\u3000バンク\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='マッコーリー\u3000バンク\u3000リミテッド',
        address='オーストラリア連邦\u3000ニューサウスウェールズ州２０００\u3000シドニー\u3000１エリザベス\u3000ストリート\u3000レベル１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23615': EdinetCodeEntry(
        edinet_code='E23615',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='ＳＭＢＣ日興証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエムビーシーニッコウショウケンカブシキガイシャ',
        address='千代田区丸の内三丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001125714',
    ),
    'E23631': EdinetCodeEntry(
        edinet_code='E23631',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=19495,
        fiscal_year_end=None,
        submitter_name='楽天証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ラクテンショウケンカブシキガイシャ',
        address='港区南青山二丁目六番二十一号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010701021660',
    ),
    'E23634': EdinetCodeEntry(
        edinet_code='E23634',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=474,
        fiscal_year_end='12月31日',
        submitter_name='アミタホールディングス株式会社',
        submitter_name_en='AMITA HOLDINGS CO.,LTD.',
        submitter_name_yomi='アミタホールディングスカブシキガイシャ',
        address='京都市中京区烏丸通押小路上ル秋野々町５３５番地',
        industry='サービス業',
        sec_code='21950',
        corporate_number='3010001129669',
    ),
    'E23662': EdinetCodeEntry(
        edinet_code='E23662',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野澤\u3000宏',
        submitter_name_en=None,
        submitter_name_yomi='ノザワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23671': EdinetCodeEntry(
        edinet_code='E23671',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=48,
        fiscal_year_end='8月末日',
        submitter_name='アクセンチュア・パブリック・リミテッド・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='アクセンチュア\u3000パブリック\u3000リミテッド\u3000カンパニー',
        address='アイルランド、ダブリン２、グランドキャナルハーバー、グランドキャナルスクエア１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E23677': EdinetCodeEntry(
        edinet_code='E23677',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='細野\u3000昭雄',
        submitter_name_en=None,
        submitter_name_yomi='ホソノ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23696': EdinetCodeEntry(
        edinet_code='E23696',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久保\u3000泰子',
        submitter_name_en=None,
        submitter_name_yomi='クボ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23700': EdinetCodeEntry(
        edinet_code='E23700',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=78525,
        fiscal_year_end=None,
        submitter_name='トヨタファイナンシャルサービス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨタファイナンシャルサービスカブシキカイシャ',
        address='名古屋市西区牛島町６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001049410',
    ),
    'E23720': EdinetCodeEntry(
        edinet_code='E23720',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤本\u3000順子',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000ジュンコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23721': EdinetCodeEntry(
        edinet_code='E23721',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000利男',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23740': EdinetCodeEntry(
        edinet_code='E23740',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='株式会社メルコグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメルコグループ',
        address='千代田区丸の内一丁目１１番１号パシフィックセンチュリープレイス丸の内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401092709',
    ),
    'E23741': EdinetCodeEntry(
        edinet_code='E23741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1438,
        fiscal_year_end='3月末日',
        submitter_name='シンデン・ハイテックス株式会社',
        submitter_name_en='Shinden Hightex Corporation',
        submitter_name_yomi='シンデンハイテックスカブシキカイシャ',
        address='中央区入船三丁目７番２号',
        industry='卸売業',
        sec_code='31310',
        corporate_number='2010001094897',
    ),
    'E23756': EdinetCodeEntry(
        edinet_code='E23756',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000暁子',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23770': EdinetCodeEntry(
        edinet_code='E23770',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ウィズダムツリー・コモディティ・セキュリティーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウィズダムツリーコモディティセキュリティーズリミテッド',
        address='英国領チャンネル諸島、ジャージー\u3000ＪＥ４\u3000８ＰＷ、セント・ハリアー、ピア・ロード\u3000３１、オーデナンス・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23774': EdinetCodeEntry(
        edinet_code='E23774',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='王\u3000厚龍',
        submitter_name_en=None,
        submitter_name_yomi='オウ\u3000コウリュウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23777': EdinetCodeEntry(
        edinet_code='E23777',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＣＮ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエーシーエヌ',
        address='大阪市中央区城見二丁目１番６１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001096090',
    ),
    'E23784': EdinetCodeEntry(
        edinet_code='E23784',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='Ｌｉｎｄｓｅｌｌ\u3000Ｔｒａｉｎ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='リンゼル\u3000トレイン\u3000リミテッド',
        address='英国ロンドン、バッキンガム・ゲート６６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23785': EdinetCodeEntry(
        edinet_code='E23785',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社スギ商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスギショウジ',
        address='安城市三河安城町一丁目８番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180301013004',
    ),
    'E23793': EdinetCodeEntry(
        edinet_code='E23793',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000節子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000セツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23798': EdinetCodeEntry(
        edinet_code='E23798',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社扇港鋼業所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセンコウコウギョウショ',
        address='神戸市東灘区住吉南町３丁目１番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1140001001817',
    ),
    'E23800': EdinetCodeEntry(
        edinet_code='E23800',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7572,
        fiscal_year_end='3月31日',
        submitter_name='日本海洋掘削株式会社',
        submitter_name_en='Japan Drilling Co., Ltd.',
        submitter_name_yomi='ニホンカイヨウクッサクカブシキ',
        address='中央区日本橋堀留町二丁目４番３号',
        industry='鉱業',
        sec_code=None,
        corporate_number='3010001095234',
    ),
    'E23808': EdinetCodeEntry(
        edinet_code='E23808',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アーチザン・インベストメンツ・ジーピー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='アーチザン\u3000インベストメンツ\u3000ジーピー\u3000エルエルシー',
        address='アメリカ合衆国５３２０２ウィスコンシン州ミルウォーキー、スウィート８００、ウィスコンシン・アヴェニュー８７５Ｅ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23810': EdinetCodeEntry(
        edinet_code='E23810',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日髙\u3000有一',
        submitter_name_en=None,
        submitter_name_yomi='ヒダカ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23811': EdinetCodeEntry(
        edinet_code='E23811',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='日髙\u3000弘義',
        submitter_name_en=None,
        submitter_name_yomi='ヒダカ\u3000ヒロヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23814': EdinetCodeEntry(
        edinet_code='E23814',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='12月31日',
        submitter_name='株式会社タカマツ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタカマツ',
        address='白山市宮永市町８３番地７',
        industry='サービス業',
        sec_code=None,
        corporate_number='6220001014327',
    ),
    'E23818': EdinetCodeEntry(
        edinet_code='E23818',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='チムニー株式会社',
        submitter_name_en='CHIMNEY CO., LTD.',
        submitter_name_yomi='チムニーカブシキカイシャ',
        address='墨田区亀沢一丁目１番１５号',
        industry='小売業',
        sec_code='31780',
        corporate_number='9010601039989',
    ),
    'E23820': EdinetCodeEntry(
        edinet_code='E23820',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30228,
        fiscal_year_end='3月末日',
        submitter_name='トモニホールディングス株式会社',
        submitter_name_en='TOMONY Holdings,Inc.',
        submitter_name_yomi='トモニホールディングスカブシキカイシャ',
        address='高松市亀井町７番地１',
        industry='銀行業',
        sec_code='86000',
        corporate_number='5470001011928',
    ),
    'E23822': EdinetCodeEntry(
        edinet_code='E23822',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社双栄',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソウエイ',
        address='三条市西本成寺１－３０－３１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6110001016870',
    ),
    'E23829': EdinetCodeEntry(
        edinet_code='E23829',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1813,
        fiscal_year_end='12月末日',
        submitter_name='ヤーマン株式会社',
        submitter_name_en='YA-MAN LTD.',
        submitter_name_yomi='ヤーマンカブシキガイシャ',
        address='江東区古石場一丁目４番４号',
        industry='電気機器',
        sec_code='66300',
        corporate_number='5010601020184',
    ),
    'E23841': EdinetCodeEntry(
        edinet_code='E23841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='1月31日',
        submitter_name='丸善ＣＨＩホールディングス株式会社',
        submitter_name_en='Maruzen CHI Holdings Co., Ltd.',
        submitter_name_yomi='マルゼンシーエイチアイホールディングスカブシキガイシャ',
        address='新宿区市谷左内町３１番地２',
        industry='小売業',
        sec_code='31590',
        corporate_number='9011101055337',
    ),
    'E23857': EdinetCodeEntry(
        edinet_code='E23857',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社モリナカホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャモリナカホールディングス',
        address='吹田市江坂町一丁目２３番３８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120903000667',
    ),
    'E23871': EdinetCodeEntry(
        edinet_code='E23871',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2500,
        fiscal_year_end='3月31日',
        submitter_name='テクノホライゾン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テクノホライゾンカブシキカイシャ',
        address='名古屋市南区千竈通２丁目１３番地１',
        industry='電気機器',
        sec_code='66290',
        corporate_number='4180001088600',
    ),
    'E23880': EdinetCodeEntry(
        edinet_code='E23880',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='内藤株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナイトウカブシキガイシャ',
        address='名古屋市昭和区御器所通二丁目２４番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001008965',
    ),
    'E23885': EdinetCodeEntry(
        edinet_code='E23885',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='サンヨー食品株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンヨーショクヒンカブシキガイシャ',
        address='港区赤坂３ー５－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401012139',
    ),
    'E23887': EdinetCodeEntry(
        edinet_code='E23887',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='永田紙業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナガタシギョウカブシキガイシャ',
        address='深谷市長在家１９８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001086043',
    ),
    'E23890': EdinetCodeEntry(
        edinet_code='E23890',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩波\u3000清久',
        submitter_name_en=None,
        submitter_name_yomi='イワナミ\u3000キヨヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23897': EdinetCodeEntry(
        edinet_code='E23897',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社エフアールテイ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエフアールテイ',
        address='芦屋市月若町７番３プラネスーペリア芦屋２０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140002001223',
    ),
    'E23924': EdinetCodeEntry(
        edinet_code='E23924',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100045,
        fiscal_year_end='3月31日',
        submitter_name='ＳＯＭＰＯホールディングス株式会社',
        submitter_name_en='Sompo Holdings, Inc.',
        submitter_name_yomi='ソンポホールディングスカブシキガイシャ',
        address='新宿区西新宿一丁目２６番１号',
        industry='保険業',
        sec_code='86300',
        corporate_number='9011101055980',
    ),
    'E23926': EdinetCodeEntry(
        edinet_code='E23926',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22,
        fiscal_year_end=None,
        submitter_name='株式会社イーストアンドウエスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーストアンドウエスト',
        address='渋谷区桜丘町２０番１号渋谷インフォスタワー２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101050520',
    ),
    'E23929': EdinetCodeEntry(
        edinet_code='E23929',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社旭興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアサヒコウサン',
        address='品川区上大崎二丁目７番２６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010701012938',
    ),
    'E23943': EdinetCodeEntry(
        edinet_code='E23943',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=142,
        fiscal_year_end=None,
        submitter_name='鎌倉投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カマクラトウシンカブシキカイシャ',
        address='鎌倉市雪ノ下四丁目５番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8021001010747',
    ),
    'E23946': EdinetCodeEntry(
        edinet_code='E23946',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000啓子',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23967': EdinetCodeEntry(
        edinet_code='E23967',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社フラッグシップアセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフラッグシップアセットマネジメント',
        address='港区虎ノ門四丁目１番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401077188',
    ),
    'E23973': EdinetCodeEntry(
        edinet_code='E23973',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1868,
        fiscal_year_end='3月末日',
        submitter_name='リーディング証券株式会社',
        submitter_name_en='Leading Securities Co.,Ltd',
        submitter_name_yomi='リーディングショウケンカブシキカイシャ',
        address='中央区新川１－８－８',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='6010001090224',
    ),
    'E23976': EdinetCodeEntry(
        edinet_code='E23976',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1728,
        fiscal_year_end=None,
        submitter_name='一般財団法人ＷＮＩ気象文化創造センター',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンダブリューエヌアイキショウブンカソウゾウセンター',
        address='千葉市美浜区中瀬一丁目３番地幕張テクノガーデン',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040005002619',
    ),
    'E23992': EdinetCodeEntry(
        edinet_code='E23992',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤村\u3000春輝',
        submitter_name_en=None,
        submitter_name_yomi='フジムラ\u3000ハルキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E23995': EdinetCodeEntry(
        edinet_code='E23995',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1576,
        fiscal_year_end=None,
        submitter_name='Ｊｏｈｏ\u3000Ｃａｐｉｔａｌ，\u3000Ｌ．Ｌ．Ｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ジョホーキャピタルエルエルシー',
        address='米国デラウェア州、ニューキャッスル郡、ウィルミントン市、オレンジ・ストリート１２０９、コーポレーション・トラスト・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24017': EdinetCodeEntry(
        edinet_code='E24017',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エスクリ',
        submitter_name_en='ESCRIT INC.',
        submitter_name_yomi='カブシキガイシャエスクリ',
        address='港区西新橋二丁目１４番１号\u3000興和西新橋ビルＢ棟',
        industry='サービス業',
        sec_code='21960',
        corporate_number='9010401057687',
    ),
    'E24018': EdinetCodeEntry(
        edinet_code='E24018',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='上中商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウエナカショウジカブシキカイシャ',
        address='京都市下京区室町通五条上る坂東屋町２６６番地ロイヤルハイツ室町２０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001115586',
    ),
    'E24036': EdinetCodeEntry(
        edinet_code='E24036',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1041399,
        fiscal_year_end='12月31日',
        submitter_name='韓国石油公社',
        submitter_name_en=None,
        submitter_name_yomi='カンコクセキユコウシャ',
        address='大韓民国蔚山広域市中区宗家路３０５（牛亭洞）',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E24041': EdinetCodeEntry(
        edinet_code='E24041',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小熊\u3000信一',
        submitter_name_en=None,
        submitter_name_yomi='オグマ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24049': EdinetCodeEntry(
        edinet_code='E24049',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＹＩＮＧ\u3000ＬＵＯ',
        submitter_name_en=None,
        submitter_name_yomi='イン\u3000ルオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24050': EdinetCodeEntry(
        edinet_code='E24050',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100000,
        fiscal_year_end='3月31日',
        submitter_name='ＥＮＥＯＳホールディングス株式会社',
        submitter_name_en='ENEOS Holdings,Inc.',
        submitter_name_yomi='エネオスホールディングスカブシキカイシャ',
        address='千代田区大手町一丁目１番２号',
        industry='石油・石炭製品',
        sec_code='50200',
        corporate_number='9010001131743',
    ),
    'E24056': EdinetCodeEntry(
        edinet_code='E24056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小田\u3000博英',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000ヒロテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24060': EdinetCodeEntry(
        edinet_code='E24060',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16203,
        fiscal_year_end=None,
        submitter_name='株式会社地域経済活性化支援機構',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチイキケイザイカッセイカシエンキコウ',
        address='千代田区大手町一丁目６番１号\u3000大手町ビル９Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001128190',
    ),
    'E24073': EdinetCodeEntry(
        edinet_code='E24073',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8202,
        fiscal_year_end='3月末日',
        submitter_name='アニコム\u3000ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アニコム\u3000ホールディングスカブシキガイシャ',
        address='新宿区西新宿８－１７－１\u3000住友不動産新宿グランドタワー３９階',
        industry='保険業',
        sec_code='87150',
        corporate_number='7011101038616',
    ),
    'E24074': EdinetCodeEntry(
        edinet_code='E24074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000道子',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ミチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24095': EdinetCodeEntry(
        edinet_code='E24095',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯田\u3000一樹',
        submitter_name_en=None,
        submitter_name_yomi='イイダ\u3000イツキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24113': EdinetCodeEntry(
        edinet_code='E24113',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='藤和コンサル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウワコンサルカブシキガイシャ',
        address='宇都宮市平出工業団地４１－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8060001003162',
    ),
    'E24117': EdinetCodeEntry(
        edinet_code='E24117',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ドリーム・ワークス',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャドリームワークス',
        address='渋谷区代々木５－１５－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011002036240',
    ),
    'E24129': EdinetCodeEntry(
        edinet_code='E24129',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1076,
        fiscal_year_end='5月31日',
        submitter_name='株式会社大光',
        submitter_name_en='OOMITSU CO., LTD.',
        submitter_name_yomi='カブシキガイシャオオミツ',
        address='大垣市浅草二丁目６６番地',
        industry='卸売業',
        sec_code='31600',
        corporate_number='6200001013834',
    ),
    'E24134': EdinetCodeEntry(
        edinet_code='E24134',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='白井商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シライショウジカブシキカイシャ',
        address='野洲市南櫻１４７７番地８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1130001001000',
    ),
    'E24152': EdinetCodeEntry(
        edinet_code='E24152',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='コーヘン・アンド・スティアーズ・キャピタル・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='コーヘンアンドスティアーズキャピタルマネジメントインク',
        address='アメリカ合衆国\u3000１００１７\u3000ニューヨーク州、ニューヨーク、２８０\u3000パーク・アヴェニュー、１０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24158': EdinetCodeEntry(
        edinet_code='E24158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3509,
        fiscal_year_end='12月31日',
        submitter_name='株式会社セルシード',
        submitter_name_en='CellSeed Inc.',
        submitter_name_yomi='カブシキカイシャセルシード',
        address='江東区青海２－５－１０テレコムセンタービル１５Ｆ',
        industry='精密機器',
        sec_code='77760',
        corporate_number='9011101031759',
    ),
    'E24181': EdinetCodeEntry(
        edinet_code='E24181',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南野\u3000利久',
        submitter_name_en=None,
        submitter_name_yomi='ミナミノ\u3000トシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24182': EdinetCodeEntry(
        edinet_code='E24182',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社南野',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミナミノ',
        address='津市観音寺町４４６番地４２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2190001000838',
    ),
    'E24185': EdinetCodeEntry(
        edinet_code='E24185',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='株式会社ウエスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウエスト',
        address='渋谷区道玄坂１－１６－１５\u3000オペラハウス渋谷',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001057189',
    ),
    'E24187': EdinetCodeEntry(
        edinet_code='E24187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7186,
        fiscal_year_end='5月31日',
        submitter_name='ダイト株式会社',
        submitter_name_en='Daito Pharmaceutical Co., Ltd.',
        submitter_name_yomi='ダイトカブシキガイシャ',
        address='富山市八日町３２６番地',
        industry='医薬品',
        sec_code='45770',
        corporate_number='4230001001499',
    ),
    'E24192': EdinetCodeEntry(
        edinet_code='E24192',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エムティ商会株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムティショウカイカブシキカイシャ',
        address='港区六本木一丁目９番１８－２０１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3013301028482',
    ),
    'E24203': EdinetCodeEntry(
        edinet_code='E24203',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='日本レイ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンレイカブシキガイシャ',
        address='渋谷区広尾四丁目目１番１１－１４０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001018146',
    ),
    'E24206': EdinetCodeEntry(
        edinet_code='E24206',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='フレンドリー・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フレンドリーパートナーズカブシキカイシャ',
        address='千代田区丸の内２ー２ー１岸本ビルヂング２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001091627',
    ),
    'E24211': EdinetCodeEntry(
        edinet_code='E24211',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='重田\u3000光時',
        submitter_name_en=None,
        submitter_name_yomi='シゲタ\u3000ミツトキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24221': EdinetCodeEntry(
        edinet_code='E24221',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='Ｎａｇａｔａ\u3000ａｎｄ\u3000Ｃｏｍｐａｎｙ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナガタアンドカンパニーカブシキカイシャ',
        address='鹿児島市唐湊四丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6340001003086',
    ),
    'E24231': EdinetCodeEntry(
        edinet_code='E24231',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社レノ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャレノ',
        address='渋谷区南平台町３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401067113',
    ),
    'E24233': EdinetCodeEntry(
        edinet_code='E24233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平賀\u3000治郎',
        submitter_name_en=None,
        submitter_name_yomi='ヒラガ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24234': EdinetCodeEntry(
        edinet_code='E24234',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村井\u3000豪',
        submitter_name_en=None,
        submitter_name_yomi='ムライ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24248': EdinetCodeEntry(
        edinet_code='E24248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=887,
        fiscal_year_end='4月30日',
        submitter_name='アゼアス株式会社',
        submitter_name_en='AZEARTH Corporation',
        submitter_name_yomi='アゼアスカブシキカイシャ',
        address='台東区蔵前４－１３－７',
        industry='卸売業',
        sec_code='31610',
        corporate_number='7010501008071',
    ),
    'E24249': EdinetCodeEntry(
        edinet_code='E24249',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='豊山開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホウザンカイハツカブシキガイシャ',
        address='さいたま市中央区上落合２－３－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001007676',
    ),
    'E24271': EdinetCodeEntry(
        edinet_code='E24271',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関根\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='セキネ\u3000シュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24281': EdinetCodeEntry(
        edinet_code='E24281',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='Ｓ・ＴＥＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エステックカブシキガイシャ',
        address='新宿区岩戸町１４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011101050168',
    ),
    'E24288': EdinetCodeEntry(
        edinet_code='E24288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金森\u3000智',
        submitter_name_en=None,
        submitter_name_yomi='カナモリ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24289': EdinetCodeEntry(
        edinet_code='E24289',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金森\u3000武',
        submitter_name_en=None,
        submitter_name_yomi='カナモリ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24290': EdinetCodeEntry(
        edinet_code='E24290',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金森\u3000久',
        submitter_name_en=None,
        submitter_name_yomi='カナモリ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24305': EdinetCodeEntry(
        edinet_code='E24305',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社サリックスフーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサリックスフーズ',
        address='さいたま市中央区上落合二丁目３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4030001003391',
    ),
    'E24310': EdinetCodeEntry(
        edinet_code='E24310',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='株式会社大和インベストメント・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイワインベストメントマネジメント',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001128172',
    ),
    'E24314': EdinetCodeEntry(
        edinet_code='E24314',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩本\u3000博',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24315': EdinetCodeEntry(
        edinet_code='E24315',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='捧\u3000ミヨエ',
        submitter_name_en=None,
        submitter_name_yomi='ササゲ\u3000ミヨエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24321': EdinetCodeEntry(
        edinet_code='E24321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40500,
        fiscal_year_end=None,
        submitter_name='三菱ＵＦＪモルガンスタンレー証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシユーエフジェイモルガンスタンレーショウケンカブシキガイシャ',
        address='千代田区大手町１－９－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001129098',
    ),
    'E24322': EdinetCodeEntry(
        edinet_code='E24322',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='テラサキトラスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テラサキトラストカブシキカイシャ',
        address='大阪市淀川区西宮原１ー８ー２９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001006050',
    ),
    'E24334': EdinetCodeEntry(
        edinet_code='E24334',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ファストトラックイニシアティブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャファストトラックイニシアティブ',
        address='文京区本郷四丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001087029',
    ),
    'E24337': EdinetCodeEntry(
        edinet_code='E24337',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＥＱＵＥＤＧＥ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シークエッジインベストメントインターナショナルリミテッド',
        address='ＲＯＯＭ１１３５－１１３９，ＳＵＮ\u3000ＨＵＮＧ\u3000ＫＡＩ\u3000ＣＥＮＴＲＥ，３０\u3000ＨＡＲＢＯＵＲ\u3000ＲＯＡＤ，ＷＡＮＣＨＡＩ，ＨＯＮＧ\u3000ＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24340': EdinetCodeEntry(
        edinet_code='E24340',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=288,
        fiscal_year_end='6月30日',
        submitter_name='株式会社\u3000ＴＨＥグローバル社',
        submitter_name_en='The Global Ltd.',
        submitter_name_yomi='カブシキカイシャザグローバルシャ',
        address='新宿区西新宿二丁目４番１号',
        industry='不動産業',
        sec_code='32710',
        corporate_number='5011101056883',
    ),
    'E24347': EdinetCodeEntry(
        edinet_code='E24347',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=154298,
        fiscal_year_end=None,
        submitter_name='アドバンス・レジデンス投資法人',
        submitter_name_en=None,
        submitter_name_yomi='アドバンスレジデンストウシホウジン',
        address='千代田区神田神保町一丁目１０５番地神保町三井ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005014863',
    ),
    'E24372': EdinetCodeEntry(
        edinet_code='E24372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯野\u3000光俊',
        submitter_name_en=None,
        submitter_name_yomi='イイノ\u3000ミツトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24381': EdinetCodeEntry(
        edinet_code='E24381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩本\u3000哲夫',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24392': EdinetCodeEntry(
        edinet_code='E24392',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1250,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ボルテージ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャボルテージ',
        address='渋谷区恵比寿四丁目２０番３号恵比寿ガーデンプレイスタワー',
        industry='情報・通信業',
        sec_code='36390',
        corporate_number='7011001036785',
    ),
    'E24419': EdinetCodeEntry(
        edinet_code='E24419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000裕生',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ヒロオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24426': EdinetCodeEntry(
        edinet_code='E24426',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=54,
        fiscal_year_end=None,
        submitter_name='シーエス（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シーエス\u3000ケイマン\u3000リミテッド',
        address='ケイマン諸島、ＫＹ１－９００５、グランド・ケイマン、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシズ（ケイマン）リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24438': EdinetCodeEntry(
        edinet_code='E24438',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ヨシキホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヨシキホールディングス',
        address='千代田区霞が関１－４－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010901018060',
    ),
    'E24447': EdinetCodeEntry(
        edinet_code='E24447',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='越智\u3000八千代',
        submitter_name_en=None,
        submitter_name_yomi='オチ\u3000ヤチヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24448': EdinetCodeEntry(
        edinet_code='E24448',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='越智\u3000通広',
        submitter_name_en=None,
        submitter_name_yomi='オチ\u3000ミチヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24453': EdinetCodeEntry(
        edinet_code='E24453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=411,
        fiscal_year_end='3月31日',
        submitter_name='株式会社パピレス',
        submitter_name_en='PAPYLESS CO.,Ltd.',
        submitter_name_yomi='カブシキガイシャパピレス',
        address='千代田区紀尾井町３－１２',
        industry='情報・通信業',
        sec_code='36410',
        corporate_number='7013301014017',
    ),
    'E24457': EdinetCodeEntry(
        edinet_code='E24457',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1395,
        fiscal_year_end='3月31日',
        submitter_name='株式会社電算',
        submitter_name_en='DENSAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャデンサン',
        address='長野市鶴賀七瀬中町２７６番地６',
        industry='情報・通信業',
        sec_code='36400',
        corporate_number='1100001002083',
    ),
    'E24465': EdinetCodeEntry(
        edinet_code='E24465',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=438,
        fiscal_year_end='6月30日',
        submitter_name='Ｚｅｎｋｅｎ株式会社',
        submitter_name_en='Zenken Corporation',
        submitter_name_yomi='ゼンケンカブシキガイシャ',
        address='新宿区西新宿六丁目１８番１号\u3000住友不動産新宿セントラルパークタワー',
        industry='情報・通信業',
        sec_code='73710',
        corporate_number='4011101011096',
    ),
    'E24470': EdinetCodeEntry(
        edinet_code='E24470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='東\u3000康夫',
        submitter_name_en=None,
        submitter_name_yomi='アズマ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24479': EdinetCodeEntry(
        edinet_code='E24479',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=199,
        fiscal_year_end='1月31日',
        submitter_name='Ｍｉｋａｔｕｓ株式会社',
        submitter_name_en='Mikatus Inc.',
        submitter_name_yomi='ミカタスカブシキガイシャ',
        address='中央区日本橋馬喰町二丁目１番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6011101052989',
    ),
    'E24483': EdinetCodeEntry(
        edinet_code='E24483',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=44,
        fiscal_year_end=None,
        submitter_name='Ｃｏｌｕｍｂｉａ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ａｄｖｉｓｅｒｓ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='コロンビアマネジメントインベストメントアドバイザーズエルエルシー',
        address='７ｔｈ\u3000Ｆｌｏｏｒ，\u3000２９０\u3000Ｃｏｎｇｒｅｓｓ\u3000Ｓｔｒｅｅｔ，\u3000Ｂｏｓｔｏｎ，\u3000ＭＡ，\u3000０２２１０，\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24485': EdinetCodeEntry(
        edinet_code='E24485',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村上\u3000美晴',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000ヨシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24486': EdinetCodeEntry(
        edinet_code='E24486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='萩原株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハギハラカブシキガイシャ',
        address='倉敷市西阿知町西原８８４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8260001014437',
    ),
    'E24498': EdinetCodeEntry(
        edinet_code='E24498',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＭＧ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイエムジー',
        address='京都市右京区西院東貝川町３１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130001007809',
    ),
    'E24506': EdinetCodeEntry(
        edinet_code='E24506',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津谷\u3000祐司',
        submitter_name_en=None,
        submitter_name_yomi='ツタニ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24510': EdinetCodeEntry(
        edinet_code='E24510',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森山\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='モリヤマ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24512': EdinetCodeEntry(
        edinet_code='E24512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2979,
        fiscal_year_end='2月末日',
        submitter_name='インターライフホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インターライフホールディングスカブシキガイシャ',
        address='中央区銀座六丁目１３番１６号',
        industry='建設業',
        sec_code='14180',
        corporate_number='4011501016216',
    ),
    'E24521': EdinetCodeEntry(
        edinet_code='E24521',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='ＳＭＢＣベンチャーキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエムビーシーベンチャーキャピタルカブシキカイシャ',
        address='中央区八重洲一丁目３番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001095593',
    ),
    'E24534': EdinetCodeEntry(
        edinet_code='E24534',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小堺裕一郎',
        submitter_name_en=None,
        submitter_name_yomi='コサカイユウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24536': EdinetCodeEntry(
        edinet_code='E24536',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=400,
        fiscal_year_end='3月31日',
        submitter_name='ＯＣＨＩホールディングス株式会社',
        submitter_name_en='OCHI HOLDINGS CO.,LTD.',
        submitter_name_yomi='オチホールディングスカブシキガイシャ',
        address='福岡市中央区那の津三丁目１２番２０号',
        industry='卸売業',
        sec_code='31660',
        corporate_number='8290001047005',
    ),
    'E24541': EdinetCodeEntry(
        edinet_code='E24541',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24542': EdinetCodeEntry(
        edinet_code='E24542',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=142,
        fiscal_year_end=None,
        submitter_name='株式会社新潟日報社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニイガタニッポウシャ',
        address='新潟市万代３丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8110001004023',
    ),
    'E24545': EdinetCodeEntry(
        edinet_code='E24545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テレビ東京ホールディングス',
        submitter_name_en='TV TOKYO Holdings Corporation',
        submitter_name_yomi='カブシキガイシャテレビトウキョウホールディングス',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='94130',
        corporate_number='1010401090159',
    ),
    'E24550': EdinetCodeEntry(
        edinet_code='E24550',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=351,
        fiscal_year_end='10月31日',
        submitter_name='アイ・ケイ・ケイホールディングス株式会社',
        submitter_name_en='IKK Holdings Inc.',
        submitter_name_yomi='アイケイケイホールディングスカブシキカイシャ',
        address='伊万里市新天町７２２番地５',
        industry='サービス業',
        sec_code='21980',
        corporate_number='5300001005459',
    ),
    'E24552': EdinetCodeEntry(
        edinet_code='E24552',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社エヌセック',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャエヌセック',
        address='杉並区松庵一丁目１７番１５－３０８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011302001671',
    ),
    'E24558': EdinetCodeEntry(
        edinet_code='E24558',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミライト・ワン',
        submitter_name_en='MIRAIT ONE Corporation',
        submitter_name_yomi='カブシキガイシャミライトワン',
        address='江東区豊洲五丁目６番３６号',
        industry='建設業',
        sec_code='14170',
        corporate_number='6010601040090',
    ),
    'E24562': EdinetCodeEntry(
        edinet_code='E24562',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='オンキヨーホームエンターテイメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オンキヨーホームエンターテイメントカブシキガイシャ',
        address='東大阪市川俣１丁目１－４１\u3000ルクスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001154326',
    ),
    'E24568': EdinetCodeEntry(
        edinet_code='E24568',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='ＪＦＥエンジニアリング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイエフイーエンジニアリングカブシキカイシャ',
        address='千代田区内幸町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001008843',
    ),
    'E24576': EdinetCodeEntry(
        edinet_code='E24576',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=366,
        fiscal_year_end='9月30日',
        submitter_name='株式会社フーマイスターエレクトロニクス',
        submitter_name_en='Fuhrmeister Electronics Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフーマイスターエレクトロニクス',
        address='千代田区内神田二丁目３番３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='3010001028301',
    ),
    'E24581': EdinetCodeEntry(
        edinet_code='E24581',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=76450,
        fiscal_year_end=None,
        submitter_name='公益財団法人上原記念生命科学財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンウエハラキネンセイメイカガクザイダン',
        address='豊島区高田三丁目２６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013305001563',
    ),
    'E24593': EdinetCodeEntry(
        edinet_code='E24593',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3612862,
        fiscal_year_end='12月31日',
        submitter_name='中国農業銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクノウギョウギンコウコブンユウゲンコウシ',
        address='中華人民共和国１００００５北京市東城区建国門内大街６９号',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24603': EdinetCodeEntry(
        edinet_code='E24603',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社マイネン',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャマイネン',
        address='中央区日本橋３―２－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010002051626',
    ),
    'E24650': EdinetCodeEntry(
        edinet_code='E24650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='尾﨑\u3000朝樹',
        submitter_name_en=None,
        submitter_name_yomi='オザキ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24651': EdinetCodeEntry(
        edinet_code='E24651',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3095,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ＦＰＧ',
        submitter_name_en='Financial Partners Group Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャエフピージー',
        address='千代田区丸の内二丁目７番２号',
        industry='証券、商品先物取引業',
        sec_code='71480',
        corporate_number='3010001086522',
    ),
    'E24657': EdinetCodeEntry(
        edinet_code='E24657',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栗原\u3000勝',
        submitter_name_en=None,
        submitter_name_yomi='クリバラ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24665': EdinetCodeEntry(
        edinet_code='E24665',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=126,
        fiscal_year_end=None,
        submitter_name='ポラリス・キャピタル・マネージメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ポラリスキャピタルマネージメントエルエルシー',
        address='アメリカ合衆国マサチューセッツ州０２１１０、ボストン、ハイ・ストリート１２１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24666': EdinetCodeEntry(
        edinet_code='E24666',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='アルトラン・ビジネス・エスエー',
        submitter_name_en=None,
        submitter_name_yomi='アルトランビジネスエスエー',
        address='英領ヴァージン諸島、トートラ、ロードタウン、マンダー・ハウス３階、スイート３０１、私書箱３１５９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24681': EdinetCodeEntry(
        edinet_code='E24681',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000和斗志',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000カツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24682': EdinetCodeEntry(
        edinet_code='E24682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17952,
        fiscal_year_end='12月末日',
        submitter_name='シンバイオ製薬株式会社',
        submitter_name_en='SymBio Pharmaceuticals Limited',
        submitter_name_yomi='シンバイオセイヤクカブシキガイシャ',
        address='港区虎ノ門四丁目１番２８号',
        industry='医薬品',
        sec_code='45820',
        corporate_number='1010401057034',
    ),
    'E24684': EdinetCodeEntry(
        edinet_code='E24684',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='有限会社インテレクチュアル',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャインテレクチュアル',
        address='宇都宮市三番町１－５三番町ハイツ６０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010902001669',
    ),
    'E24685': EdinetCodeEntry(
        edinet_code='E24685',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=236840,
        fiscal_year_end='12月31日',
        submitter_name='ロイズ・バンク・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ロイズバンクピーエルシー',
        address='連合王国ＥＣ２Ｖ\u3000７ＨＮロンドン市グレシャム・ストリート２５番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24708': EdinetCodeEntry(
        edinet_code='E24708',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷村\u3000尚永',
        submitter_name_en=None,
        submitter_name_yomi='タニムラ\u3000ヒサナガ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24712': EdinetCodeEntry(
        edinet_code='E24712',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石原\u3000慎也',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24727': EdinetCodeEntry(
        edinet_code='E24727',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=150531,
        fiscal_year_end='12月31日',
        submitter_name='エスエイピー・エスイー',
        submitter_name_en=None,
        submitter_name_yomi='エスエイピー\u3000エスイー',
        address='ドイツ連邦共和国\u3000６９１９０\u3000ヴァルドルフ\u3000ディートマ・ホップ・アレー\u3000１６',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24736': EdinetCodeEntry(
        edinet_code='E24736',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=958,
        fiscal_year_end=None,
        submitter_name='ウエスタン・アセット・マネジメント・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウエスタンアセットマネジメントカンパニーリミテッド',
        address='イングランド、ＥＣ２Ａ\u3000２ＥＮ、ロンドン、プリムローズ・ストリート、エクスチェンジ・スクエア１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24744': EdinetCodeEntry(
        edinet_code='E24744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社岡本俊人',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオカモトシュンジ',
        address='宝塚市中州二丁目１０番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001082996',
    ),
    'E24745': EdinetCodeEntry(
        edinet_code='E24745',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=19519,
        fiscal_year_end=None,
        submitter_name='インベスコ・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='インベスコアセットマネジメントリミテッド',
        address='Ｐｅｒｐｅｔｕａｌ\u3000Ｐａｒｋ，\u3000Ｐｅｒｐｅｔｕａｌ\u3000Ｐａｒｋ\u3000Ｄｒｉｖｅ，\u3000Ｈｅｎｌｅｙ－ｏｎ－Ｔｈａｍｅｓ，\u3000Ｏｘｆｏｒｄｓｈｉｒｅ，\u3000ＲＧ９\u3000１ＨＨ，\u3000Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24747': EdinetCodeEntry(
        edinet_code='E24747',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=5787,
        fiscal_year_end='3月31日',
        submitter_name='ノムラ・ヨーロッパ・ファイナンス・エヌ・ブイ\u3000（Ｎｏｍｕｒａ\u3000Ｅｕｒｏｐｅ\u3000Ｆｉｎａｎｃｅ\u3000Ｎ．Ｖ．）',
        submitter_name_en=None,
        submitter_name_yomi='ノムラヨーロッパファイナンスエヌブイ',
        address='オランダ王国、アムステルダム市１０９６ＨＡ、アムステルプライン１、レンブラント・タワー１９階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24753': EdinetCodeEntry(
        edinet_code='E24753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=93,
        fiscal_year_end='8月31日',
        submitter_name='株式会社トランザクション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトランザクション',
        address='渋谷区渋谷３丁目２８番１３号',
        industry='その他製品',
        sec_code='78180',
        corporate_number='4011001032309',
    ),
    'E24755': EdinetCodeEntry(
        edinet_code='E24755',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3909,
        fiscal_year_end=None,
        submitter_name='アラムコ・オーバーシーズ・カンパニー・ビー・ヴィ',
        submitter_name_en=None,
        submitter_name_yomi='アラムコオーバーシーズカンパニービーヴィ',
        address='オランダ王国ハーグ、エー・ケー２５９５\u3000プリンセスベアトリクスラーン３５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24769': EdinetCodeEntry(
        edinet_code='E24769',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='学校法人東洋食品工業短期大学',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジントウヨウショクヒンコウギョウタンキダク',
        address='川西市南花屋敷４丁目２３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140005017976',
    ),
    'E24817': EdinetCodeEntry(
        edinet_code='E24817',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='ジャパンフードビジネス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンフードビジネスカブシキカイシャ',
        address='港区赤坂四丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001034548',
    ),
    'E24820': EdinetCodeEntry(
        edinet_code='E24820',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='坪田\u3000康信',
        submitter_name_en=None,
        submitter_name_yomi='ツボタ\u3000ヤスノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24827': EdinetCodeEntry(
        edinet_code='E24827',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='今井\u3000博文',
        submitter_name_en=None,
        submitter_name_yomi='イマイ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24838': EdinetCodeEntry(
        edinet_code='E24838',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='アルメイト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アルメイトカブシキガイシャ',
        address='池田市旭丘二丁目１２番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120901022467',
    ),
    'E24839': EdinetCodeEntry(
        edinet_code='E24839',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栢森\u3000雅勝',
        submitter_name_en=None,
        submitter_name_yomi='カヤモリ\u3000マサカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24840': EdinetCodeEntry(
        edinet_code='E24840',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=66459,
        fiscal_year_end='12月31日',
        submitter_name='釜山銀行',
        submitter_name_en=None,
        submitter_name_yomi='ブサンギンコウ',
        address='大韓民国釜山広域市南区ムンヒヨン金融路３０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24841': EdinetCodeEntry(
        edinet_code='E24841',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=748662,
        fiscal_year_end='3月31日',
        submitter_name='ＧＬＰプライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジーエルピープライベートリミテッド',
        address='シンガポール、０４８６２３、シンガポール・ランド・タワー＃３２－０１、ラッフルズ・プレイス５０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24846': EdinetCodeEntry(
        edinet_code='E24846',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='マルヨシセンター取引先持株会\u3000理事長\u3000小松義彦',
        submitter_name_en=None,
        submitter_name_yomi='マルヨシセンタートリヒキサキモチカブカイ\u3000リジチョウ\u3000コマツヨシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24847': EdinetCodeEntry(
        edinet_code='E24847',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1515986,
        fiscal_year_end='12月31日',
        submitter_name='ＡＩＡグループ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エイアイエイグループリミテッド',
        address='香港、コンノート・ロード・セントラル１、ＡＩＡセントラル、３５／Ｆ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E24854': EdinetCodeEntry(
        edinet_code='E24854',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ヒロエキスプレス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒロエキスプレス',
        address='目黒区八雲四丁目８番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1013201003554',
    ),
    'E24858': EdinetCodeEntry(
        edinet_code='E24858',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='ＡｖａｎＳｔｒａｔｅ株式会社',
        submitter_name_en='AvanStrate Inc.',
        submitter_name_yomi='アヴァンストレートカブシキガイシャ',
        address='品川区西五反田一丁目１１番１号',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='8190001018602',
    ),
    'E24859': EdinetCodeEntry(
        edinet_code='E24859',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000正信',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000マサノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24861': EdinetCodeEntry(
        edinet_code='E24861',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濵田\u3000長伸',
        submitter_name_en=None,
        submitter_name_yomi='ハマダ\u3000オサノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24872': EdinetCodeEntry(
        edinet_code='E24872',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=103,
        fiscal_year_end=None,
        submitter_name='シルチェスター・インターナショナル・インベスターズ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='シルチェスターインターナショナルインベステーズエルエルピー',
        address='英国ロンドン\u3000エスダブリュー１ワイ・５イーエス、ペル・メル８３－８５、ザ・メトカーフ３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24878': EdinetCodeEntry(
        edinet_code='E24878',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石川\u3000諭',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24910': EdinetCodeEntry(
        edinet_code='E24910',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮内\u3000輝司',
        submitter_name_en=None,
        submitter_name_yomi='ミヤウチ\u3000テルシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24917': EdinetCodeEntry(
        edinet_code='E24917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1967,
        fiscal_year_end='9月末日',
        submitter_name='イー・ガーディアン株式会社',
        submitter_name_en='E-Guardian Inc.',
        submitter_name_yomi='イーガーディアンカブシキガイシャ',
        address='港区虎ノ門１－２－８\u3000虎ノ門琴平タワー８Ｆ',
        industry='サービス業',
        sec_code='60500',
        corporate_number='2010401066249',
    ),
    'E24919': EdinetCodeEntry(
        edinet_code='E24919',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='疋田\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='ヒキダ\u3000ショウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24930': EdinetCodeEntry(
        edinet_code='E24930',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24951': EdinetCodeEntry(
        edinet_code='E24951',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ポーラ・オルビスホールディングス',
        submitter_name_en='POLA ORBIS HOLDINGS INC.',
        submitter_name_yomi='カブシキカイシャポーラオルビスホールディングス',
        address='品川区西五反田二丁目２番３号',
        industry='化学',
        sec_code='49270',
        corporate_number='4010701017916',
    ),
    'E24958': EdinetCodeEntry(
        edinet_code='E24958',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永瀬\u3000栄作',
        submitter_name_en=None,
        submitter_name_yomi='ナガセ\u3000エイサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24976': EdinetCodeEntry(
        edinet_code='E24976',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='國分\u3000勘兵衛',
        submitter_name_en=None,
        submitter_name_yomi='コクブ\u3000カンベエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24980': EdinetCodeEntry(
        edinet_code='E24980',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='オーセンティシティ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーセンティシティカブシキガイシャ',
        address='港区赤坂九丁目７番２号ミッドタウン・イースト４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010402028133',
    ),
    'E24981': EdinetCodeEntry(
        edinet_code='E24981',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='ミソノサービス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミソノサービスカブシキカイシャ',
        address='名古屋市北区平安二丁目１５番５６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001013562',
    ),
    'E24982': EdinetCodeEntry(
        edinet_code='E24982',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=286,
        fiscal_year_end='5月31日',
        submitter_name='株式会社メディカルネット',
        submitter_name_en='Medical Net , Inc.',
        submitter_name_yomi='カブシキガイシャメディカルネット',
        address='渋谷区幡ヶ谷１－３４－１４宝ビル３階',
        industry='情報・通信業',
        sec_code='36450',
        corporate_number='1011001036766',
    ),
    'E24991': EdinetCodeEntry(
        edinet_code='E24991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7319,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ノエビアホールディングス',
        submitter_name_en='noevir holdings co.,ltd.',
        submitter_name_yomi='カブシキカイシャノエビアホールディングス',
        address='神戸市中央区港島中町六丁目１３番地の１',
        industry='化学',
        sec_code='49280',
        corporate_number='3140001034179',
    ),
    'E24994': EdinetCodeEntry(
        edinet_code='E24994',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11823,
        fiscal_year_end='12月末日',
        submitter_name='株式会社テラプローブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテラプローブ',
        address='横浜市港北区新横浜二丁目７番１７号',
        industry='電気機器',
        sec_code='66270',
        corporate_number='9020001053623',
    ),
    'E24995': EdinetCodeEntry(
        edinet_code='E24995',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河越\u3000誠剛',
        submitter_name_en=None,
        submitter_name_yomi='カワゴエ\u3000セイゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E24998': EdinetCodeEntry(
        edinet_code='E24998',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1299,
        fiscal_year_end='8月31日',
        submitter_name='株式会社アスリナ',
        submitter_name_en='ASULINA Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアスリナ',
        address='品川区東品川二丁目３番１４号',
        industry='情報・通信業',
        sec_code='36470',
        corporate_number='7010401094468',
    ),
    'E25001': EdinetCodeEntry(
        edinet_code='E25001',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西村\u3000邦夫',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000クニオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25010': EdinetCodeEntry(
        edinet_code='E25010',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='株式会社ツジモトキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツジモトキャピタル',
        address='羽曳野市恵我之荘５－２－１５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120102017991',
    ),
    'E25019': EdinetCodeEntry(
        edinet_code='E25019',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ティー・サポート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーサポート',
        address='名古屋市中区栄三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180002045784',
    ),
    'E25022': EdinetCodeEntry(
        edinet_code='E25022',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮永\u3000憲一',
        submitter_name_en=None,
        submitter_name_yomi='ミヤナガ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25026': EdinetCodeEntry(
        edinet_code='E25026',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=66,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスアイ',
        address='名古屋市昭和区折戸町三丁目３番地の２３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001090240',
    ),
    'E25029': EdinetCodeEntry(
        edinet_code='E25029',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社しげる不動産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャシゲルフドウサン',
        address='昭島市中神町１１４８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2012802011114',
    ),
    'E25030': EdinetCodeEntry(
        edinet_code='E25030',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=32,
        fiscal_year_end=None,
        submitter_name='エム・エヌ・エス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエヌエスカブシキカイシャ',
        address='静岡市葵区北安東５－３４－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7080001000745',
    ),
    'E25035': EdinetCodeEntry(
        edinet_code='E25035',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='有限会社ＹＡＳＮＡＧ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャヤスナッグ',
        address='伊賀市上野東日南町１７１４番地の２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4190002012277',
    ),
    'E25043': EdinetCodeEntry(
        edinet_code='E25043',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=149673,
        fiscal_year_end='10月31日',
        submitter_name='シノプシス・インク',
        submitter_name_en=None,
        submitter_name_yomi='シノプシスインク',
        address='アメリカ合衆国\u3000９４０８５\u3000カリフォルニア州\u3000サニーベール、アルマナー・アベニュー６７５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E25044': EdinetCodeEntry(
        edinet_code='E25044',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000康友',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000ヤストモ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25046': EdinetCodeEntry(
        edinet_code='E25046',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西\u3000登茂一',
        submitter_name_en=None,
        submitter_name_yomi='ニシ\u3000トモカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25063': EdinetCodeEntry(
        edinet_code='E25063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='城戸\u3000恵子',
        submitter_name_en=None,
        submitter_name_yomi='キド\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25065': EdinetCodeEntry(
        edinet_code='E25065',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小澤\u3000秀樹',
        submitter_name_en=None,
        submitter_name_yomi='オザワ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25081': EdinetCodeEntry(
        edinet_code='E25081',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邊\u3000唯志',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25083': EdinetCodeEntry(
        edinet_code='E25083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000公康',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000キミヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25088': EdinetCodeEntry(
        edinet_code='E25088',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=641,
        fiscal_year_end=None,
        submitter_name='ピムコ・グローバル・アドバイザーズ（ルクセンブルグ）エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='ピムコグローバルアドバイザーズルクセンブルグエスエイ',
        address='ルクセンブルグ大公国、Ｌ－１５３６ルクセンブルグ、フォセ通り２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25089': EdinetCodeEntry(
        edinet_code='E25089',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高谷\u3000康久',
        submitter_name_en=None,
        submitter_name_yomi='タカタニ\u3000ヤスヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25096': EdinetCodeEntry(
        edinet_code='E25096',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ナカノコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャナカノコーポレーション',
        address='名古屋市瑞穂区東栄町八丁目１番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001090831',
    ),
    'E25100': EdinetCodeEntry(
        edinet_code='E25100',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社永幸',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイコウ',
        address='三鷹市井の頭五丁目２６番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5012401012238',
    ),
    'E25115': EdinetCodeEntry(
        edinet_code='E25115',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=112,
        fiscal_year_end='3月末日',
        submitter_name='株式会社新南愛知',
        submitter_name_en='Shin minami aichi Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシンミナミアイチ',
        address='知多郡美浜町大字野間字内扇４３番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='6180001096287',
    ),
    'E25139': EdinetCodeEntry(
        edinet_code='E25139',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000郷史',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25143': EdinetCodeEntry(
        edinet_code='E25143',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小形\u3000明彦',
        submitter_name_en=None,
        submitter_name_yomi='オガタ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25144': EdinetCodeEntry(
        edinet_code='E25144',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川\u3000義行',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25145': EdinetCodeEntry(
        edinet_code='E25145',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='依田\u3000雅',
        submitter_name_en=None,
        submitter_name_yomi='ヨダ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25148': EdinetCodeEntry(
        edinet_code='E25148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4309,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ジェイ・エス・ビー',
        submitter_name_en='J.S.B.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャジェイエスビー',
        address='京都市下京区因幡堂町６５５番地',
        industry='不動産業',
        sec_code='34800',
        corporate_number='2130001017499',
    ),
    'E25155': EdinetCodeEntry(
        edinet_code='E25155',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='君浪\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='キミナミ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25156': EdinetCodeEntry(
        edinet_code='E25156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6880,
        fiscal_year_end='12月31日',
        submitter_name='インテグラル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インテグラルカブシキガイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='その他金融業',
        sec_code='58420',
        corporate_number='9010001097340',
    ),
    'E25160': EdinetCodeEntry(
        edinet_code='E25160',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='ゼニス羽田ホールディングス株式会社',
        submitter_name_en='HANEDA ZENITH HOLDINGS Co.,Ltd.',
        submitter_name_yomi='ゼニスハネダホールディングスカブシキカイシャ',
        address='千代田区麹町五丁目７番地２',
        industry='ガラス・土石製品',
        sec_code=None,
        corporate_number='6011101059489',
    ),
    'E25165': EdinetCodeEntry(
        edinet_code='E25165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴＯＫＡＩホールディングス',
        submitter_name_en='TOKAI Holdings Corporation',
        submitter_name_yomi='カブシキガイシャトーカイホールディングス',
        address='静岡市葵区常磐町２丁目６番地の８',
        industry='卸売業',
        sec_code='31670',
        corporate_number='2080001017736',
    ),
    'E25169': EdinetCodeEntry(
        edinet_code='E25169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5956,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ゲームカードホールディングス',
        submitter_name_en='Gamecard Holdings, Inc.',
        submitter_name_yomi='カブシキカイシャゲームカードホールディングス',
        address='新宿区西新宿六丁目１８番１号',
        industry='機械',
        sec_code='62490',
        corporate_number='7010001139202',
    ),
    'E25175': EdinetCodeEntry(
        edinet_code='E25175',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=177666,
        fiscal_year_end=None,
        submitter_name='バークレイズ・ポートフォリオ',
        submitter_name_en=None,
        submitter_name_yomi='バークレイズポートフォリオ',
        address='ルクセンブルグ大公国、ルードランジュ\u3000Ｌ－３３６４、シャトー・ドー通り１０番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25179': EdinetCodeEntry(
        edinet_code='E25179',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='馬渕保',
        submitter_name_en=None,
        submitter_name_yomi='マブチタモツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25189': EdinetCodeEntry(
        edinet_code='E25189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森中\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='モリナカ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25201': EdinetCodeEntry(
        edinet_code='E25201',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='シコク共栄会\u3000理事長\u3000藪原健三',
        submitter_name_en=None,
        submitter_name_yomi='シコクキョウエイカイ\u3000リジチョウ\u3000ヤブハラケンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25206': EdinetCodeEntry(
        edinet_code='E25206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=291,
        fiscal_year_end='3月末日',
        submitter_name='株式会社駅探',
        submitter_name_en='Ekitan&Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエキタン',
        address='千代田区麹町五丁目４番地',
        industry='情報・通信業',
        sec_code='36460',
        corporate_number='9010001092069',
    ),
    'E25216': EdinetCodeEntry(
        edinet_code='E25216',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新妻\u3000尚祐',
        submitter_name_en=None,
        submitter_name_yomi='ニイツマ\u3000ナオヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25217': EdinetCodeEntry(
        edinet_code='E25217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25234': EdinetCodeEntry(
        edinet_code='E25234',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＴＳＩホールディングス',
        submitter_name_en='TSI HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャティーエスアイホールディングス',
        address='港区赤坂八丁目５番２７号',
        industry='繊維製品',
        sec_code='36080',
        corporate_number='3010001140386',
    ),
    'E25237': EdinetCodeEntry(
        edinet_code='E25237',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000三夫',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ミツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25252': EdinetCodeEntry(
        edinet_code='E25252',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安井\u3000隆太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤスイ\u3000リュウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25254': EdinetCodeEntry(
        edinet_code='E25254',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1109619,
        fiscal_year_end=None,
        submitter_name='Ｉｎｖｅｓｃｏ\u3000Ａｄｖｉｓｅｒｓ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='インベスコ\u3000アドバイザーズ\u3000インク',
        address='１３３１\u3000Ｓｐｒｉｎｇ\u3000Ｓｔｒｅｅｔ\u3000ＮＷ\u3000，Ｓｕｉｔｅ\u3000２５００，\u3000Ａｔｌａｎｔａ，\u3000ＧＡ\u3000３０３０９，\u3000Ｕｎｉｔｅｄ\u3000Ｓｔａｔｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25263': EdinetCodeEntry(
        edinet_code='E25263',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1431,
        fiscal_year_end='3月末日',
        submitter_name='ＡＧＳ株式会社',
        submitter_name_en='AGS Corporation',
        submitter_name_yomi='エージーエスカブシキガイシャ',
        address='さいたま市浦和区針ヶ谷四丁目３番２５号',
        industry='情報・通信業',
        sec_code='36480',
        corporate_number='2030001000011',
    ),
    'E25266': EdinetCodeEntry(
        edinet_code='E25266',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='九喜\u3000健三',
        submitter_name_en=None,
        submitter_name_yomi='クキ\u3000ケンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25269': EdinetCodeEntry(
        edinet_code='E25269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2720,
        fiscal_year_end='12月31日',
        submitter_name='ラクオリア創薬株式会社',
        submitter_name_en='RaQualia Pharma Inc.',
        submitter_name_yomi='ラクオリアソウヤクカブシキカイシャ',
        address='名古屋市中村区名駅南一丁目２１番１９号',
        industry='医薬品',
        sec_code='45790',
        corporate_number='3180001095399',
    ),
    'E25274': EdinetCodeEntry(
        edinet_code='E25274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ファースト・パシフィック・キャピタル有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ファーストパシフィックキャピタルユウゲンガイシャ',
        address='目黒区中根一丁目７番２０号－２０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5013202011148',
    ),
    'E25282': EdinetCodeEntry(
        edinet_code='E25282',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=700,
        fiscal_year_end='3月31日',
        submitter_name='日本ドライケミカル株式会社',
        submitter_name_en='Nippon Dry-Chemical CO.,LTD.',
        submitter_name_yomi='ニッポンドライケミカルカブシキガイシャ',
        address='北区田端六丁目１番１号',
        industry='機械',
        sec_code='19090',
        corporate_number='2010701007860',
    ),
    'E25283': EdinetCodeEntry(
        edinet_code='E25283',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=254,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ファインデックス',
        submitter_name_en='FINDEX Inc.',
        submitter_name_yomi='カブシキガイシャファインデックス',
        address='千代田区大手町一丁目７番２号',
        industry='情報・通信業',
        sec_code='36490',
        corporate_number='9500001003380',
    ),
    'E25288': EdinetCodeEntry(
        edinet_code='E25288',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='清久商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セイキュウショウジカブシキカイシャ',
        address='大阪市北区西天満１丁目１１番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001116930',
    ),
    'E25290': EdinetCodeEntry(
        edinet_code='E25290',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='太田油脂株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオタユシカブシキガイシャ',
        address='岡崎市福岡町字下荒追２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180301000553',
    ),
    'E25303': EdinetCodeEntry(
        edinet_code='E25303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12044,
        fiscal_year_end='3月31日',
        submitter_name='カルビー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カルビーカブシキガイシャ',
        address='千代田区丸の内一丁目８番３号',
        industry='食料品',
        sec_code='22290',
        corporate_number='8010001133757',
    ),
    'E25308': EdinetCodeEntry(
        edinet_code='E25308',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='工藤\u3000恭孝',
        submitter_name_en=None,
        submitter_name_yomi='クドウ\u3000ヤスタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25317': EdinetCodeEntry(
        edinet_code='E25317',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='ベル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ベルカブシキガイシャ',
        address='千代田区外神田二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001007066',
    ),
    'E25322': EdinetCodeEntry(
        edinet_code='E25322',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小島\u3000賢二',
        submitter_name_en=None,
        submitter_name_yomi='オジマ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25323': EdinetCodeEntry(
        edinet_code='E25323',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社オーエフコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーエフコーポレーション',
        address='松原市天美我堂二丁目２７５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120101029856',
    ),
    'E25329': EdinetCodeEntry(
        edinet_code='E25329',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ポラリス・キャピタル・グループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ポラリスキャピタルグループカブシキガイシャ',
        address='千代田区丸の内１丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001089698',
    ),
    'E25334': EdinetCodeEntry(
        edinet_code='E25334',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西川\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25339': EdinetCodeEntry(
        edinet_code='E25339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25351': EdinetCodeEntry(
        edinet_code='E25351',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ハチソン・ポート・ホールディングス・マネジメント・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ハチソンポートホールディングスマネジメントピーティーイーリミテッド',
        address='シンガポール\u3000０９８６３２、ハーバーフロント・アベニュー１、ケッペル・ベイ・タワー＃１４－０７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25360': EdinetCodeEntry(
        edinet_code='E25360',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='田中貴金属工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タナカキキンゾクコウギョウカブシキガイシャ',
        address='中央区日本橋茅場町２丁目６－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001127950',
    ),
    'E25374': EdinetCodeEntry(
        edinet_code='E25374',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｆｒｉｔｏ－Ｌａｙ\u3000Ｇｌｏｂａｌ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='フリトレーグローバルインベストメンツビーヴィ',
        address='オランダ王国\u3000ユトレヒト\u3000スタッズプラトー\u3000２２\u3000３５２１ＡＺ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25386': EdinetCodeEntry(
        edinet_code='E25386',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=773,
        fiscal_year_end='3月31日',
        submitter_name='ＳＥＭＩＴＥＣ株式会社',
        submitter_name_en='SEMITEC Corporation',
        submitter_name_yomi='セミテックカブシキカイシャ',
        address='墨田区錦糸一丁目７番７号',
        industry='電気機器',
        sec_code='66260',
        corporate_number='5010601008733',
    ),
    'E25387': EdinetCodeEntry(
        edinet_code='E25387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000成史',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000シゲフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25400': EdinetCodeEntry(
        edinet_code='E25400',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='ストーク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ストークカブシキガイシャ',
        address='大阪市西区南堀江１丁目１１番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001138676',
    ),
    'E25413': EdinetCodeEntry(
        edinet_code='E25413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='櫛引\u3000博敬',
        submitter_name_en=None,
        submitter_name_yomi='クシビキ\u3000ヒロノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25443': EdinetCodeEntry(
        edinet_code='E25443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ＭＥＲＦ',
        submitter_name_en='MERF Inc.',
        submitter_name_yomi='カブシキガイシャマーフ',
        address='射水市奈呉の江１２番地の２',
        industry='卸売業',
        sec_code='31680',
        corporate_number='3230001012407',
    ),
    'E25448': EdinetCodeEntry(
        edinet_code='E25448',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=78,
        fiscal_year_end=None,
        submitter_name='ジェイ・オー・ハンブロ・キャピタル・マネージメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジェイ\u3000オー\u3000ハンブロ\u3000キャピタル\u3000マネージメント\u3000リミテッド',
        address='英国ロンドンＳＷ１Ｙ\u3000４ＡＨ、セント・ジェームズ・マーケット１、レベル３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25450': EdinetCodeEntry(
        edinet_code='E25450',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='日東株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニットウカブシキカイシャ',
        address='江戸川区東葛西六丁目２３番４－３０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011701015458',
    ),
    'E25457': EdinetCodeEntry(
        edinet_code='E25457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='橘\u3000和博',
        submitter_name_en=None,
        submitter_name_yomi='タチバナ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25463': EdinetCodeEntry(
        edinet_code='E25463',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88877,
        fiscal_year_end=None,
        submitter_name='ＯＫＡＤＡ\u3000ＨＯＬＤＩＮＧＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ホールディングス\u3000リミテッド',
        address='６ｔｈ\u3000Ｆｌｏｏｒ，\u3000Ａｌｅｘａｎｄｒａ\u3000Ｈｏｕｓｅ，\u3000１８\u3000Ｃｈａｔｅｒ\u3000Ｒｏａｄ，\u3000Ｃｅｎｔｒａｌ，\u3000ＨＯＮＧ\u3000ＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25464': EdinetCodeEntry(
        edinet_code='E25464',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000一穗',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000カズホ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25478': EdinetCodeEntry(
        edinet_code='E25478',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='夏原\u3000平和',
        submitter_name_en=None,
        submitter_name_yomi='ナツハラ\u3000ヒラカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25488': EdinetCodeEntry(
        edinet_code='E25488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='買場\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='カイバ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25495': EdinetCodeEntry(
        edinet_code='E25495',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='Ｂｒｉｄｇｅ\u3000Ｃａｐｉｔａｌ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブリッジキャピタルアセットマネジメントカブシキガイシャ',
        address='千代田区九段南二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001088938',
    ),
    'E25512': EdinetCodeEntry(
        edinet_code='E25512',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='豊島株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨシマカブシキガイシャ',
        address='一宮市せんい二丁目５番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001083272',
    ),
    'E25518': EdinetCodeEntry(
        edinet_code='E25518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉村\u3000栄義',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000シゲヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25522': EdinetCodeEntry(
        edinet_code='E25522',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='服部\u3000信治',
        submitter_name_en=None,
        submitter_name_yomi='ハットリ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25527': EdinetCodeEntry(
        edinet_code='E25527',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平川\u3000昌紀',
        submitter_name_en=None,
        submitter_name_yomi='ヒラカワ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25542': EdinetCodeEntry(
        edinet_code='E25542',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='民秋\u3000清史',
        submitter_name_en=None,
        submitter_name_yomi='タミアキ\u3000キヨフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25551': EdinetCodeEntry(
        edinet_code='E25551',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2016,
        fiscal_year_end='2月末日',
        submitter_name='株式会社イートアンドホールディングス',
        submitter_name_en='EAT&HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイートアンドホールディングス',
        address='大阪市淀川区宮原３丁目３番３４号',
        industry='食料品',
        sec_code='28820',
        corporate_number='9120001102626',
    ),
    'E25560': EdinetCodeEntry(
        edinet_code='E25560',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大賀\u3000昭司',
        submitter_name_en=None,
        submitter_name_yomi='オオガ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25563': EdinetCodeEntry(
        edinet_code='E25563',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大賀\u3000昌彦',
        submitter_name_en=None,
        submitter_name_yomi='オオガ\u3000マサヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25610': EdinetCodeEntry(
        edinet_code='E25610',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒谷\u3000純久',
        submitter_name_en=None,
        submitter_name_yomi='クロタニ\u3000スミヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25617': EdinetCodeEntry(
        edinet_code='E25617',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='ＴＫホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーケーホールディングスカブシキガイシャ',
        address='甲賀市水口町日電２－２０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9160001005726',
    ),
    'E25620': EdinetCodeEntry(
        edinet_code='E25620',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1804,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディジタルメディアプロフェッショナル',
        submitter_name_en='Digital  Media Professionals Inc.',
        submitter_name_yomi='カブシキガイシャディジタルメディアプロフェッショナル',
        address='中野区中野４－１０－２',
        industry='情報・通信業',
        sec_code='36520',
        corporate_number='3012401013733',
    ),
    'E25621': EdinetCodeEntry(
        edinet_code='E25621',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=424,
        fiscal_year_end='3月31日',
        submitter_name='ハウスコム株式会社',
        submitter_name_en='HOUSECOM CORPORATION',
        submitter_name_yomi='ハウスコムカブシキガイシャ',
        address='港区港南２－１６－１',
        industry='不動産業',
        sec_code=None,
        corporate_number='7010401052343',
    ),
    'E25623': EdinetCodeEntry(
        edinet_code='E25623',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='坂本ドネイション・ファウンデイション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サカモトドネイションファウンデイションカブシキガイシャ',
        address='名古屋市中村区名駅四丁目６番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001101168',
    ),
    'E25632': EdinetCodeEntry(
        edinet_code='E25632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山科\u3000統',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシナ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25633': EdinetCodeEntry(
        edinet_code='E25633',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='和納\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='ワノウ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25640': EdinetCodeEntry(
        edinet_code='E25640',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田村\u3000隆盛',
        submitter_name_en=None,
        submitter_name_yomi='タムラ\u3000タカモリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25643': EdinetCodeEntry(
        edinet_code='E25643',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='有限会社藤和興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャトウワコウサン',
        address='大阪市大正区泉尾三丁目２０－３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120002014907',
    ),
    'E25648': EdinetCodeEntry(
        edinet_code='E25648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='3月31日',
        submitter_name='ウェルネオシュガー株式会社',
        submitter_name_en='WELLNEO SUGAR Co., Ltd.',
        submitter_name_yomi='ウェルネオシュガーカブシキガイシャ',
        address='中央区日本橋小網町１４番１号',
        industry='食料品',
        sec_code='21170',
        corporate_number='2010001142672',
    ),
    'E25649': EdinetCodeEntry(
        edinet_code='E25649',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ブリーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブリーズ',
        address='港区北青山２ー７ー１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5012401019316',
    ),
    'E25660': EdinetCodeEntry(
        edinet_code='E25660',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ワイコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャワイコーポレーション',
        address='名古屋市昭和区高峯町１６１番地アネシア八事高峯３３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180003014012',
    ),
    'E25661': EdinetCodeEntry(
        edinet_code='E25661',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エイチアンドワイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチアンドワイ',
        address='大阪市北区堂島二丁目４－４－４５０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001144813',
    ),
    'E25662': EdinetCodeEntry(
        edinet_code='E25662',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2538,
        fiscal_year_end='3月31日',
        submitter_name='サノヤスホールディングス株式会社',
        submitter_name_en='Sanoyas Holdings Corporation',
        submitter_name_yomi='サノヤスホールディングスカブシキガイシャ',
        address='大阪市北区中之島三丁目３番２３号',
        industry='輸送用機器',
        sec_code='70220',
        corporate_number='8120001166449',
    ),
    'E25664': EdinetCodeEntry(
        edinet_code='E25664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4207,
        fiscal_year_end='3月31日',
        submitter_name='パラマウントベッドホールディングス株式会社',
        submitter_name_en='PARAMOUNT BED HOLDINGS CO.,LTD.',
        submitter_name_yomi='パラマウントベッドホールディングスカブシキカイシャ',
        address='江東区東砂２－１４－５',
        industry='その他製品',
        sec_code='78170',
        corporate_number='4010601001508',
    ),
    'E25665': EdinetCodeEntry(
        edinet_code='E25665',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='宮越ホールディングス株式会社',
        submitter_name_en='Miyakoshi Holdings, Inc.',
        submitter_name_yomi='ミヤコシホールディングスカブシキガイシャ',
        address='大田区大森北一丁目２３番１号',
        industry='電気機器',
        sec_code='66200',
        corporate_number='6010801021964',
    ),
    'E25668': EdinetCodeEntry(
        edinet_code='E25668',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=503817,
        fiscal_year_end='12月31日',
        submitter_name='中国光大銀行股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクコウダイギンコウグウフェンユウゲンコンスウ',
        address='中華人民共和国北京市西城区太平橋大街２５号、甲２５号光大センター',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E25674': EdinetCodeEntry(
        edinet_code='E25674',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='本多興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホンダコウサンカブシキガイシャ',
        address='文京区西片一丁目１０番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010502010111',
    ),
    'E25675': EdinetCodeEntry(
        edinet_code='E25675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤尾\u3000政弘',
        submitter_name_en=None,
        submitter_name_yomi='フジオ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25678': EdinetCodeEntry(
        edinet_code='E25678',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=30000,
        fiscal_year_end='3月31日',
        submitter_name='大正製薬ホールディングス株式会社',
        submitter_name_en='TAISHO PHARMACEUTICAL HOLDINGS CO., LTD.',
        submitter_name_yomi='タイショウセイヤクホールディングスカブシキガイシャ',
        address='豊島区高田三丁目２４番１号',
        industry='医薬品',
        sec_code=None,
        corporate_number='2013301031198',
    ),
    'E25680': EdinetCodeEntry(
        edinet_code='E25680',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=154,
        fiscal_year_end=None,
        submitter_name='セールスフォース・インク',
        submitter_name_en=None,
        submitter_name_yomi='セールスフォースインク',
        address='アメリカ合衆国カリフォルニア州サンフランシスコ市４１５ミッション・ストリート、セールスフォース・タワー３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25682': EdinetCodeEntry(
        edinet_code='E25682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1779,
        fiscal_year_end='10月31日',
        submitter_name='株式会社モルフォ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモルフォ',
        address='千代田区西神田三丁目８番１号千代田ファーストビル東館１２階',
        industry='情報・通信業',
        sec_code='36530',
        corporate_number='5010001090118',
    ),
    'E25685': EdinetCodeEntry(
        edinet_code='E25685',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池浦\u3000捷行',
        submitter_name_en=None,
        submitter_name_yomi='イケウラ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25686': EdinetCodeEntry(
        edinet_code='E25686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6449,
        fiscal_year_end='3月31日',
        submitter_name='ＪＡＬＣＯホールディングス株式会社',
        submitter_name_en='JALCO Holdings Inc.',
        submitter_name_yomi='ジャルコ\u3000ホールディングス\u3000カブシキガイシャ',
        address='中央区日本橋２丁目１６番１１号',
        industry='電気機器',
        sec_code='66250',
        corporate_number='7010001142692',
    ),
    'E25692': EdinetCodeEntry(
        edinet_code='E25692',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=34,
        fiscal_year_end=None,
        submitter_name='クレディ・スイス・ファンド・マネジメント・エスエー',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスファンドマネジメントエスエー',
        address='ルクセンブルグ\u3000Ｌ－２１８０、ル・ジャン・モネ５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25706': EdinetCodeEntry(
        edinet_code='E25706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000索',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000モトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25707': EdinetCodeEntry(
        edinet_code='E25707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000昌子',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000マサコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25708': EdinetCodeEntry(
        edinet_code='E25708',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='日電ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニチデンホールディングスカブシキガイシャ',
        address='西宮市甲子園口１丁目１４番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5140001074347',
    ),
    'E25715': EdinetCodeEntry(
        edinet_code='E25715',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石塚\u3000二朗',
        submitter_name_en=None,
        submitter_name_yomi='イシヅカ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25718': EdinetCodeEntry(
        edinet_code='E25718',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山之上\u3000道廣',
        submitter_name_en=None,
        submitter_name_yomi='ヤマノウエ\u3000ミチヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25728': EdinetCodeEntry(
        edinet_code='E25728',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社関口興業社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセキグチコウギョウシャ',
        address='西宮市南郷町３番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001054397',
    ),
    'E25732': EdinetCodeEntry(
        edinet_code='E25732',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='文野\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='フミノ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25737': EdinetCodeEntry(
        edinet_code='E25737',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西川\u3000正洋',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25741': EdinetCodeEntry(
        edinet_code='E25741',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=273441,
        fiscal_year_end='12月31日',
        submitter_name='フランス相互信用連合銀行',
        submitter_name_en=None,
        submitter_name_yomi='フランスソウゴシンヨウレンゴウギンコウ',
        address='フランス、ストラスブール\u3000６７０００、リュ・フレデリック－ギヨーム・ライフアイゼン４',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E25742': EdinetCodeEntry(
        edinet_code='E25742',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=62795,
        fiscal_year_end='12月31日',
        submitter_name='ファースト・アブダビ・バンク・ピー・ジェー・エス・シー（Ｆｉｒｓｔ\u3000Ａｂｕ\u3000Ｄｈａｂｉ\u3000Ｂａｎｋ\u3000Ｐ．Ｊ．Ｓ．Ｃ．）',
        submitter_name_en=None,
        submitter_name_yomi='ファーストアブダビバンクピージェーエスシー',
        address='アラブ首長国連邦\u3000アブダビ\u3000私書箱６３１６\u3000ハリーファ・ビジネス・パーク\u3000アル・クルム地区\u3000エフ・エー・ビー・ビルディング',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E25743': EdinetCodeEntry(
        edinet_code='E25743',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀越\u3000毅一',
        submitter_name_en=None,
        submitter_name_yomi='ホリコシ\u3000キイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25745': EdinetCodeEntry(
        edinet_code='E25745',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀越\u3000裕史',
        submitter_name_en=None,
        submitter_name_yomi='ホリコシ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25761': EdinetCodeEntry(
        edinet_code='E25761',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=737,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ヒト・コミュニケーションズ',
        submitter_name_en='HITO-Communications,Inc.',
        submitter_name_yomi='カブシキガイシャヒトコミュニケーションズ',
        address='豊島区東池袋一丁目９番６号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8013301016185',
    ),
    'E25763': EdinetCodeEntry(
        edinet_code='E25763',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＪホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイジェイホールディングス',
        address='豊島区東池袋四丁目２１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1013301028550',
    ),
    'E25765': EdinetCodeEntry(
        edinet_code='E25765',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社武蔵野',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャムサシノ',
        address='小金井市東町四丁目３３番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2012401003396',
    ),
    'E25766': EdinetCodeEntry(
        edinet_code='E25766',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=203,
        fiscal_year_end=None,
        submitter_name='クイーンズゲート',
        submitter_name_en=None,
        submitter_name_yomi='クイーンズゲート',
        address='ケイマン諸島、ＫＹ１－１２０２、グランド・ケイマン、ハーバー・プレイス、サウス・チャーチ・ストリート１０３、私書箱３０４６４号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25785': EdinetCodeEntry(
        edinet_code='E25785',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20000,
        fiscal_year_end=None,
        submitter_name='アサヒビール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒビールカブシキカイシャ',
        address='墨田区吾妻橋１－２３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010601039873',
    ),
    'E25799': EdinetCodeEntry(
        edinet_code='E25799',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ビアンナ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビアンナ',
        address='千代田区大手町一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001088922',
    ),
    'E25806': EdinetCodeEntry(
        edinet_code='E25806',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='富通集団（香港）有限公司',
        submitter_name_en=None,
        submitter_name_yomi='フツウシュウダン\u3000ホンコン\u3000ユウゲンコンス',
        address='香港北角英皇道５１０号港運ビル７Ｆユニット７Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25807': EdinetCodeEntry(
        edinet_code='E25807',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮本\u3000彰',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25811': EdinetCodeEntry(
        edinet_code='E25811',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=53,
        fiscal_year_end='3月末日',
        submitter_name='株式会社関西ゴルフ倶楽部',
        submitter_name_en='KANSAI GOLF CLUB CO.,LTD',
        submitter_name_yomi='カブシキガイシャカンサイゴルフクラブ',
        address='三木市吉川町吉安８７７番地の１',
        industry='サービス業',
        sec_code=None,
        corporate_number='4140001036843',
    ),
    'E25817': EdinetCodeEntry(
        edinet_code='E25817',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=597,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ブレインパッド',
        submitter_name_en='BrainPad Inc.',
        submitter_name_yomi='カブシキガイシャブレインパッド',
        address='港区六本木三丁目１番１号',
        industry='情報・通信業',
        sec_code='36550',
        corporate_number='5010701015274',
    ),
    'E25830': EdinetCodeEntry(
        edinet_code='E25830',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=759643,
        fiscal_year_end='12月末日',
        submitter_name='クレディ・アグリコル・コーポレート・アンド・インベストメント・バンク',
        submitter_name_en=None,
        submitter_name_yomi='クレディ\u3000アグリコル\u3000コーポレート\u3000アンド\u3000インベストメント\u3000バンク',
        address='フランス国、モンルージュ・セデックス、９２５４７\u3000ＣＳ\u3000７００５２、レ・ゼタジュニ広場１２番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E25850': EdinetCodeEntry(
        edinet_code='E25850',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=51430,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ネクソン',
        submitter_name_en='NEXON Co., Ltd.',
        submitter_name_yomi='カブシキガイシャネクソン',
        address='港区六本木一丁目４番５号',
        industry='情報・通信業',
        sec_code='36590',
        corporate_number='6010001081280',
    ),
    'E25855': EdinetCodeEntry(
        edinet_code='E25855',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='有限会社ヤスコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャヤスコーポレーション',
        address='仙台市宮城野区鶴ヶ谷八丁目１６番地の１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9370002008871',
    ),
    'E25867': EdinetCodeEntry(
        edinet_code='E25867',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4720,
        fiscal_year_end='12月31日',
        submitter_name='ＫＬａｂ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クラブカブシキガイシャ',
        address='港区六本木六丁目１０番１号\u3000六本木ヒルズ森タワー',
        industry='情報・通信業',
        sec_code='36560',
        corporate_number='7010401041924',
    ),
    'E25870': EdinetCodeEntry(
        edinet_code='E25870',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=465,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＪＰＭＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェーピーエムシー',
        address='千代田区丸の内３－４－２',
        industry='不動産業',
        sec_code='32760',
        corporate_number='5010001083682',
    ),
    'E25878': EdinetCodeEntry(
        edinet_code='E25878',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='有限会社山本エステート',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャヤマモトエステート',
        address='豊中市緑丘二丁目１７番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120902022470',
    ),
    'E25881': EdinetCodeEntry(
        edinet_code='E25881',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000隆史',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000タカフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25884': EdinetCodeEntry(
        edinet_code='E25884',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7550,
        fiscal_year_end='4月末日',
        submitter_name='株式会社スリー・ディー・マトリックス',
        submitter_name_en='3-D Matrix,Ltd.',
        submitter_name_yomi='カブシキガイシャスリーディーマトリックス',
        address='千代田区麹町三丁目２番４号',
        industry='精密機器',
        sec_code='77770',
        corporate_number='4010001087940',
    ),
    'E25888': EdinetCodeEntry(
        edinet_code='E25888',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社イーブックイニシアティブジャパン',
        submitter_name_en='eBOOK Initiative Japan Co., Ltd.',
        submitter_name_yomi='カブシキガイシャイーブックイニシアティブジャパン',
        address='千代田区麹町一丁目１２番地１',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010001069108',
    ),
    'E25889': EdinetCodeEntry(
        edinet_code='E25889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社日本クリエイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニホンクリエイト',
        address='横浜市戸塚区平戸町１０８７番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5020001039824',
    ),
    'E25898': EdinetCodeEntry(
        edinet_code='E25898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1239,
        fiscal_year_end='1月末日',
        submitter_name='ポールトゥウィンホールディングス株式会社',
        submitter_name_en='Pole To Win Holdings, Inc.',
        submitter_name_yomi='ポールトゥウィンホールディングスカブシキカイシャ',
        address='新宿区西新宿二丁目４番１号',
        industry='情報・通信業',
        sec_code='36570',
        corporate_number='7011101063309',
    ),
    'E25899': EdinetCodeEntry(
        edinet_code='E25899',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＭＡホールディングス',
        submitter_name_en='JMA Holdings Inc.',
        submitter_name_yomi='カブシキガイシャジェイエムエーホールディングス',
        address='港区芝公園三丁目１番２２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401021831',
    ),
    'E25902': EdinetCodeEntry(
        edinet_code='E25902',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社トップ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトップ',
        address='横浜市青葉区新石川四丁目３２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001035825',
    ),
    'E25907': EdinetCodeEntry(
        edinet_code='E25907',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社日器',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッキ',
        address='大田区田園調布三丁目２８番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010801013973',
    ),
    'E25912': EdinetCodeEntry(
        edinet_code='E25912',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西木\u3000利彦',
        submitter_name_en=None,
        submitter_name_yomi='ニシキ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25916': EdinetCodeEntry(
        edinet_code='E25916',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='増田\u3000至克',
        submitter_name_en=None,
        submitter_name_yomi='マスダ\u3000ヨシカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25918': EdinetCodeEntry(
        edinet_code='E25918',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒土\u3000優子',
        submitter_name_en=None,
        submitter_name_yomi='クロツチ\u3000ユウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25932': EdinetCodeEntry(
        edinet_code='E25932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中野\u3000誠子',
        submitter_name_en=None,
        submitter_name_yomi='ナカノ\u3000セイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25935': EdinetCodeEntry(
        edinet_code='E25935',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＲホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌアールホールディングス',
        address='芦屋市松ノ内町６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001028987',
    ),
    'E25940': EdinetCodeEntry(
        edinet_code='E25940',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＫＴマネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エイチケイティマネジメントリミテッド',
        address='香港、クオーリ・ベイ、９７９\u3000キングス・ロード、タイクー・プレイス、ＰＣＣＷタワー、３９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25941': EdinetCodeEntry(
        edinet_code='E25941',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000清之輔',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000セイノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25961': EdinetCodeEntry(
        edinet_code='E25961',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='出原\u3000正博',
        submitter_name_en=None,
        submitter_name_yomi='イデハラ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25966': EdinetCodeEntry(
        edinet_code='E25966',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上原\u3000昭二',
        submitter_name_en=None,
        submitter_name_yomi='ウエハラ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25969': EdinetCodeEntry(
        edinet_code='E25969',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=233,
        fiscal_year_end='10月31日',
        submitter_name='ベルグアース株式会社',
        submitter_name_en='Berg Earth co.,Ltd.',
        submitter_name_yomi='ベルグアースカブシキガイシャ',
        address='宇和島市津島町北灘甲８８番地１',
        industry='水産・農林業',
        sec_code='13830',
        corporate_number='9500001015681',
    ),
    'E25976': EdinetCodeEntry(
        edinet_code='E25976',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社乃村',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャノムラ',
        address='渋谷区神山町３９－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011002009625',
    ),
    'E25991': EdinetCodeEntry(
        edinet_code='E25991',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｗｉｌｌｉａｍ\u3000Ｍａｂｅｙ',
        submitter_name_en=None,
        submitter_name_yomi='ウィリアム\u3000メイビー',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E25994': EdinetCodeEntry(
        edinet_code='E25994',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=425526,
        fiscal_year_end='12月末日',
        submitter_name='ノルデア・バンク・アクツィエボラーグ・プブリクト',
        submitter_name_en=None,
        submitter_name_yomi='ノルデアバンクアクツィエボラーグプブリクト',
        address='スウェーデン王国ＳＥ－１０５\u3000７１\u3000ストックホルム\u3000スモーランズガータン１７',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26002': EdinetCodeEntry(
        edinet_code='E26002',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='真田\u3000哲弥',
        submitter_name_en=None,
        submitter_name_yomi='サナダ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26004': EdinetCodeEntry(
        edinet_code='E26004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙宮\u3000章好',
        submitter_name_en=None,
        submitter_name_yomi='タカミヤ\u3000アキヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26006': EdinetCodeEntry(
        edinet_code='E26006',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2525,
        fiscal_year_end='12月31日',
        submitter_name='アメリカ・モバイル',
        submitter_name_en=None,
        submitter_name_yomi='アメリカ\u3000モバイル',
        address='カエ\u3000ラゴ\u3000ズリク\u3000２４５\u3000エディフィシオ\u3000テルセル\u3000グラナダ\u3000アンプリアシオン\u3000シウダッド\u3000デ\u3000メヒコ\u3000１１５２９\u3000メキシコ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26012': EdinetCodeEntry(
        edinet_code='E26012',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人深田地質研究所',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンフカダチシツケンキュウショ',
        address='文京区本駒込２丁目１３番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010005016750',
    ),
    'E26013': EdinetCodeEntry(
        edinet_code='E26013',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000通秀',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ミチヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26032': EdinetCodeEntry(
        edinet_code='E26032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=237,
        fiscal_year_end='12月末日',
        submitter_name='株式会社リブセンス',
        submitter_name_en='Livesense Inc.',
        submitter_name_yomi='カブシキガイシャリブセンス',
        address='港区海岸１丁目７番１号',
        industry='サービス業',
        sec_code='60540',
        corporate_number='9011001063308',
    ),
    'E26035': EdinetCodeEntry(
        edinet_code='E26035',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古川\u3000美智子',
        submitter_name_en=None,
        submitter_name_yomi='フルカワ\u3000ミチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26036': EdinetCodeEntry(
        edinet_code='E26036',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35,
        fiscal_year_end=None,
        submitter_name='株式会社アート・ギヤラリー富士見',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアートギヤラリーフジミ',
        address='名古屋市千種区揚羽町二丁目３７番地の２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180001003244',
    ),
    'E26044': EdinetCodeEntry(
        edinet_code='E26044',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ファウンテン',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャファウンテン',
        address='大阪市北区大深町３－１グランフロント大阪タワーＢ\u3000１６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140002027065',
    ),
    'E26061': EdinetCodeEntry(
        edinet_code='E26061',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3144,
        fiscal_year_end='3月31日',
        submitter_name='新田ゼラチン株式会社',
        submitter_name_en='Nitta Gelatin Inc.',
        submitter_name_yomi='ニッタゼラチンカブシキガイシャ',
        address='大阪市浪速区桜川四丁目４番２６号',
        industry='化学',
        sec_code='49770',
        corporate_number='2120001039437',
    ),
    'E26063': EdinetCodeEntry(
        edinet_code='E26063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='水野\u3000泰三',
        submitter_name_en=None,
        submitter_name_yomi='ミズノ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26071': EdinetCodeEntry(
        edinet_code='E26071',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池\u3000功',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26073': EdinetCodeEntry(
        edinet_code='E26073',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000恵美子',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000エミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26075': EdinetCodeEntry(
        edinet_code='E26075',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池\u3000昭夫',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26076': EdinetCodeEntry(
        edinet_code='E26076',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10513,
        fiscal_year_end=None,
        submitter_name='公益財団法人古岡奨学会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンフルオカショウガクカイ',
        address='品川区西五反田八丁目３番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010705001746',
    ),
    'E26077': EdinetCodeEntry(
        edinet_code='E26077',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=72438,
        fiscal_year_end=None,
        submitter_name='ＴＴＹ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ティーティーワイ\u3000マネジメント\u3000ビーヴイ',
        address='Ｐｒｉｎｓｅｎｇｒａｃｈｔ\u3000７６９\u3000Ａ，\u3000１０１７ＪＺ\u3000Ａｍｓｔｅｒｄａｍ，\u3000Ｔｈｅ\u3000Ｎｅｔｈｅｒｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26079': EdinetCodeEntry(
        edinet_code='E26079',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社テクノグローバル研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテクノグローバルケンキュウショ',
        address='渋谷区神宮前六丁目３４番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010701025790',
    ),
    'E26082': EdinetCodeEntry(
        edinet_code='E26082',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15346,
        fiscal_year_end='1月31日',
        submitter_name='ダブル・スコープ株式会社',
        submitter_name_en='W-SCOPE Corporation',
        submitter_name_yomi='ダブルスコープカブシキガイシャ',
        address='品川区東五反田一丁目２２番６号',
        industry='電気機器',
        sec_code='66190',
        corporate_number='2020001077950',
    ),
    'E26084': EdinetCodeEntry(
        edinet_code='E26084',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1250,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スターフライヤー',
        submitter_name_en='Star Flyer Inc.',
        submitter_name_yomi='カブシキカイシャスターフライヤー',
        address='北九州市小倉南区空港北町６番北九州空港スターフライヤー本社ビル',
        industry='空運業',
        sec_code='92060',
        corporate_number='6290801006558',
    ),
    'E26086': EdinetCodeEntry(
        edinet_code='E26086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=860,
        fiscal_year_end='12月末日',
        submitter_name='株式会社サンセイランディック',
        submitter_name_en='Sansei Landic Co.,Ltd',
        submitter_name_yomi='カブシキガイシャサンセイランディック',
        address='千代田区丸の内二丁目５番１号',
        industry='不動産業',
        sec_code='32770',
        corporate_number='8010001017712',
    ),
    'E26087': EdinetCodeEntry(
        edinet_code='E26087',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橘\u3000民義',
        submitter_name_en=None,
        submitter_name_yomi='タチバナ\u3000タミヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26088': EdinetCodeEntry(
        edinet_code='E26088',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本重\u3000光孝',
        submitter_name_en=None,
        submitter_name_yomi='モトシゲ\u3000ミツタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26089': EdinetCodeEntry(
        edinet_code='E26089',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000公三',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26095': EdinetCodeEntry(
        edinet_code='E26095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=380,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ミサワ',
        submitter_name_en='Misawa & Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャミサワ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='小売業',
        sec_code='31690',
        corporate_number='7013201019157',
    ),
    'E26096': EdinetCodeEntry(
        edinet_code='E26096',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=995,
        fiscal_year_end='12月31日',
        submitter_name='株式会社カイオム・バイオサイエンス',
        submitter_name_en='Chiome Bioscience Inc.',
        submitter_name_yomi='カブシキガイシャカイオムバイオサイエンス',
        address='渋谷区本町三丁目１２番１号',
        industry='医薬品',
        sec_code='45830',
        corporate_number='6011101054960',
    ),
    'E26105': EdinetCodeEntry(
        edinet_code='E26105',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='難波\u3000太郎',
        submitter_name_en=None,
        submitter_name_yomi='ナンバ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26109': EdinetCodeEntry(
        edinet_code='E26109',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=239368,
        fiscal_year_end='12月31日',
        submitter_name='ディー・エヌ・ビー・バンク\u3000エイ・エス・エイ（ＤＮＢ\u3000Ｂａｎｋ\u3000ＡＳＡ）',
        submitter_name_en=None,
        submitter_name_yomi='ディーエヌビーバンクエイエスエイ',
        address='ノルウェー王国\u3000オスロ市\u3000ドロニング・ユーフェミアス・ゲート３０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26111': EdinetCodeEntry(
        edinet_code='E26111',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤\u3000一俊',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000カズトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26115': EdinetCodeEntry(
        edinet_code='E26115',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000麻衣子',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000マイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26116': EdinetCodeEntry(
        edinet_code='E26116',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野澤\u3000慎吾',
        submitter_name_en=None,
        submitter_name_yomi='ノザワ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26121': EdinetCodeEntry(
        edinet_code='E26121',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000紘司',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26124': EdinetCodeEntry(
        edinet_code='E26124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1317,
        fiscal_year_end='3月31日',
        submitter_name='ジャパンマテリアル株式会社',
        submitter_name_en='JAPAN MATERIAL Co.,Ltd.',
        submitter_name_yomi='ジャパンマテリアルカブシキカイシャ',
        address='三重郡菰野町永井３０９８番２２',
        industry='サービス業',
        sec_code='60550',
        corporate_number='2190001015191',
    ),
    'E26141': EdinetCodeEntry(
        edinet_code='E26141',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笹\u3000晃弘',
        submitter_name_en=None,
        submitter_name_yomi='ササ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26144': EdinetCodeEntry(
        edinet_code='E26144',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山口\u3000一彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26149': EdinetCodeEntry(
        edinet_code='E26149',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桂\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='カツラ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26150': EdinetCodeEntry(
        edinet_code='E26150',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村上\u3000太一',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000タイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26151': EdinetCodeEntry(
        edinet_code='E26151',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ベインキャピタル・インベスターズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ベインキャピタルインベスターズエルエルシー',
        address='アメリカ合衆国\u3000デラウェア州１９８０７\u3000ウィルミントン\u3000ケネットパイク４００１\u3000スイート３０２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26157': EdinetCodeEntry(
        edinet_code='E26157',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ソルプティ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソルプティ',
        address='仙台市泉区泉中央二丁目１０番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1370001021032',
    ),
    'E26158': EdinetCodeEntry(
        edinet_code='E26158',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='崔\u3000元根',
        submitter_name_en=None,
        submitter_name_yomi='チェ\u3000ウォングン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26169': EdinetCodeEntry(
        edinet_code='E26169',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='亀井\u3000文行',
        submitter_name_en=None,
        submitter_name_yomi='カメイ\u3000フミユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26171': EdinetCodeEntry(
        edinet_code='E26171',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='城戸\u3000一弥',
        submitter_name_en=None,
        submitter_name_yomi='キド\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26178': EdinetCodeEntry(
        edinet_code='E26178',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='津田物産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツダブッサンカブシキガイシャ',
        address='姫路市八代東光寺町３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001059078',
    ),
    'E26192': EdinetCodeEntry(
        edinet_code='E26192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000久男',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヒサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26195': EdinetCodeEntry(
        edinet_code='E26195',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松﨑\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='マツザキ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26199': EdinetCodeEntry(
        edinet_code='E26199',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=163,
        fiscal_year_end=None,
        submitter_name='ＮＸＣ\u3000Ｃｏｒｐｏｒａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='エヌエックスシーコーポレーション',
        address='韓国済州特別自治道済州市ウンス通り１７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26204': EdinetCodeEntry(
        edinet_code='E26204',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='アイビーピー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイビーピーカブシキガイシャ',
        address='大阪市西区北堀江１丁目２番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001037082',
    ),
    'E26205': EdinetCodeEntry(
        edinet_code='E26205',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人小森文化科学財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンコモリブンカカガクザイダン',
        address='香取市玉造３丁目１番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3040005013528',
    ),
    'E26216': EdinetCodeEntry(
        edinet_code='E26216',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1480,
        fiscal_year_end='3月31日',
        submitter_name='株式会社大泉製作所',
        submitter_name_en='OHIZUMI MFG.CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオオイズミセイサクショ',
        address='中央区日本橋２丁目３－４\u3000日本橋プラザビル４階',
        industry='電気機器',
        sec_code=None,
        corporate_number='1030001027575',
    ),
    'E26218': EdinetCodeEntry(
        edinet_code='E26218',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＮＰオンザロード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテイエヌピーオンザロード',
        address='横浜市港北区新横浜二丁目３番地１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001044754',
    ),
    'E26220': EdinetCodeEntry(
        edinet_code='E26220',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹市\u3000克弘',
        submitter_name_en=None,
        submitter_name_yomi='タケイチ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26224': EdinetCodeEntry(
        edinet_code='E26224',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000智和',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000トモカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26225': EdinetCodeEntry(
        edinet_code='E26225',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=547037,
        fiscal_year_end='12月31日',
        submitter_name='新韓銀行',
        submitter_name_en=None,
        submitter_name_yomi='シンハンギンコウ',
        address='大韓民国ソウル特別市中区世宗大路９道２０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26231': EdinetCodeEntry(
        edinet_code='E26231',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社セルシス',
        submitter_name_en='CELSYS,Inc.',
        submitter_name_yomi='カブシキガイシャセルシス',
        address='新宿区西新宿４丁目１５番７号',
        industry='情報・通信業',
        sec_code='36630',
        corporate_number='1011101062869',
    ),
    'E26234': EdinetCodeEntry(
        edinet_code='E26234',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='龍\u3000潤生',
        submitter_name_en=None,
        submitter_name_yomi='リュウ\u3000ジュンセイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26239': EdinetCodeEntry(
        edinet_code='E26239',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮﨑\u3000勝',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26242': EdinetCodeEntry(
        edinet_code='E26242',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ティーエヌホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーエヌホールディングスカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4021001046811',
    ),
    'E26245': EdinetCodeEntry(
        edinet_code='E26245',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=397,
        fiscal_year_end=None,
        submitter_name='公益財団法人福田育英会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウウジンフクダイクエイカイ',
        address='新潟市中央区一番堀通町３番地１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4110005011102',
    ),
    'E26258': EdinetCodeEntry(
        edinet_code='E26258',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福岡靖介',
        submitter_name_en=None,
        submitter_name_yomi='フクオカ\u3000セイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26263': EdinetCodeEntry(
        edinet_code='E26263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ティーズ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャティーズ',
        address='杉並区永福二丁目１番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020002064969',
    ),
    'E26264': EdinetCodeEntry(
        edinet_code='E26264',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='思源国際発展有限公司',
        submitter_name_en=None,
        submitter_name_yomi='シゲンコクサイハッテンユウゲンコウシ',
        address='香港千諾道西８－１４号\u3000嘉安ビルディング２ＦＪ室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26267': EdinetCodeEntry(
        edinet_code='E26267',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安原\u3000禎二',
        submitter_name_en=None,
        submitter_name_yomi='ヤスハラ\u3000テイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26274': EdinetCodeEntry(
        edinet_code='E26274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='株式会社青木商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアオキショウテン',
        address='名古屋市中村区鳥居西通一丁目１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001029203',
    ),
    'E26277': EdinetCodeEntry(
        edinet_code='E26277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川崎\u3000まり',
        submitter_name_en=None,
        submitter_name_yomi='カワサキ\u3000マリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26281': EdinetCodeEntry(
        edinet_code='E26281',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小林\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26283': EdinetCodeEntry(
        edinet_code='E26283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社トリコロール２',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャトリコロールツー',
        address='中央区銀座三丁目１１番１９－８０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010003013854',
    ),
    'E26288': EdinetCodeEntry(
        edinet_code='E26288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉野\u3000勝秀',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノ\u3000カツヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26290': EdinetCodeEntry(
        edinet_code='E26290',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｃｏｍｉｎｉｘ',
        submitter_name_en='Cominix Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコミニックス',
        address='大阪市中央区南本町一丁目８番１４号',
        industry='卸売業',
        sec_code='31730',
        corporate_number='8120001092827',
    ),
    'E26291': EdinetCodeEntry(
        edinet_code='E26291',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蓮見\u3000正純',
        submitter_name_en=None,
        submitter_name_yomi='ハスミ\u3000マサズミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26298': EdinetCodeEntry(
        edinet_code='E26298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='楢﨑\u3000十紀',
        submitter_name_en=None,
        submitter_name_yomi='ナラザキ\u3000トキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26301': EdinetCodeEntry(
        edinet_code='E26301',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1586,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アイスタイル',
        submitter_name_en='istyle Inc.',
        submitter_name_yomi='カブシキカイシャアイスタイル',
        address='港区赤坂一丁目１２番３２号\u3000アーク森ビル３４階',
        industry='情報・通信業',
        sec_code='36600',
        corporate_number='1010401057595',
    ),
    'E26311': EdinetCodeEntry(
        edinet_code='E26311',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='司不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツカサフドウサンカブシキカイシャ',
        address='下都賀郡壬生町おもちゃのまち二丁目２１番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4060001023593',
    ),
    'E26322': EdinetCodeEntry(
        edinet_code='E26322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=356,
        fiscal_year_end='7月31日',
        submitter_name='ティーライフ株式会社',
        submitter_name_en='Tea Life Co.,Ltd',
        submitter_name_yomi='ティーライフカブシキカイシャ',
        address='島田市牛尾１１８番地',
        industry='小売業',
        sec_code='31720',
        corporate_number='3080001013429',
    ),
    'E26323': EdinetCodeEntry(
        edinet_code='E26323',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='美藤\u3000宏一郎',
        submitter_name_en=None,
        submitter_name_yomi='ミトウ\u3000コウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26324': EdinetCodeEntry(
        edinet_code='E26324',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉松\u3000徹郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシマツ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26326': EdinetCodeEntry(
        edinet_code='E26326',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=205,
        fiscal_year_end=None,
        submitter_name='クイーンズゲート',
        submitter_name_en=None,
        submitter_name_yomi='クイーンズゲート',
        address='ケイマン諸島、ＫＹ１－１２０２、グランド・ケイマン、ハーバー・プレイス、サウス・チャーチ・ストリート１０３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26327': EdinetCodeEntry(
        edinet_code='E26327',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=16731,
        fiscal_year_end='3月31日',
        submitter_name='ライフネット生命保険株式会社',
        submitter_name_en='LIFENET INSURANCE COMPANY',
        submitter_name_yomi='ライフネットセイメイホケンカブシキカイシャ',
        address='千代田区麹町二丁目１４番地２麹町ＮＫビル',
        industry='保険業',
        sec_code='71570',
        corporate_number='4010001112418',
    ),
    'E26332': EdinetCodeEntry(
        edinet_code='E26332',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=308,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エムアップホールディングス',
        submitter_name_en='mup holdings. Inc,',
        submitter_name_yomi='エムアップホールディングス\u3000カブシキカイシャ',
        address='渋谷区渋谷三丁目１２番１８号',
        industry='サービス業',
        sec_code='36610',
        corporate_number='3011001043835',
    ),
    'E26343': EdinetCodeEntry(
        edinet_code='E26343',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000博之',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26349': EdinetCodeEntry(
        edinet_code='E26349',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='マイルストーン・キャピタル・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マイルストーンキャピタルマネジメントカブシキガイシャ',
        address='千代田区大手町一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401097969',
    ),
    'E26361': EdinetCodeEntry(
        edinet_code='E26361',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀川\u3000一晃',
        submitter_name_en=None,
        submitter_name_yomi='ホリカワ\u3000カズアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26362': EdinetCodeEntry(
        edinet_code='E26362',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=52,
        fiscal_year_end='1月末日',
        submitter_name='エヌビディアコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='エヌビディアコーポレーション',
        address='アメリカ合衆国９５０５１\u3000カリフォルニア州\u3000サンタクララ\u3000サン・トーマス・エクスプレスウェイ\u3000２７８８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26369': EdinetCodeEntry(
        edinet_code='E26369',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=533,
        fiscal_year_end='7月31日',
        submitter_name='株式会社エイチームホールディングス',
        submitter_name_en='Ateam Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエイチームホールディングス',
        address='名古屋市中村区名駅三丁目２８番１２号\u3000大名古屋ビルヂング３２Ｆ',
        industry='情報・通信業',
        sec_code='36620',
        corporate_number='6180001055771',
    ),
    'E26383': EdinetCodeEntry(
        edinet_code='E26383',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エンシャント・アート・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='エンシャントアートエルピー',
        address='アメリカ合衆国テキサス州オースティン市５番ストリートウエスト５００\u3000１１１０号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26393': EdinetCodeEntry(
        edinet_code='E26393',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社リョウコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャリョウコーポレーション',
        address='荒川区南千住六丁目３７番１－３０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011502011848',
    ),
    'E26396': EdinetCodeEntry(
        edinet_code='E26396',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃａｙｍａｎ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＩＩ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイマン\u3000キャピタル\u3000マネジメント\u3000ツー\u3000インク',
        address='Ｏｎｅ\u3000Ｎｅｘｕｓ\u3000Ｗａｙ，\u3000Ｃａｍａｎａ\u3000Ｂａｙ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００５，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26419': EdinetCodeEntry(
        edinet_code='E26419',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='株式会社ハウスセゾン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハウスセゾン',
        address='京都市上京区河原町通今出川下る二丁目栄町３６４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1130001003599',
    ),
    'E26425': EdinetCodeEntry(
        edinet_code='E26425',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000宏典',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヒロノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26428': EdinetCodeEntry(
        edinet_code='E26428',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3038,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ベクトル',
        submitter_name_en='VECTOR INC.',
        submitter_name_yomi='カブシキカイシャベクトル',
        address='港区赤坂四丁目１５番１号',
        industry='サービス業',
        sec_code='60580',
        corporate_number='6010401027065',
    ),
    'E26433': EdinetCodeEntry(
        edinet_code='E26433',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000靖',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26438': EdinetCodeEntry(
        edinet_code='E26438',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000敏明',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26443': EdinetCodeEntry(
        edinet_code='E26443',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='こころネット株式会社',
        submitter_name_en='Cocolonet CO., LTD.',
        submitter_name_yomi='ココロネットカブシキカイシャ',
        address='福島市鎌田字舟戸前１５番地１',
        industry='サービス業',
        sec_code=None,
        corporate_number='8380001003122',
    ),
    'E26444': EdinetCodeEntry(
        edinet_code='E26444',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2759,
        fiscal_year_end='6月末日',
        submitter_name='株式会社チャーム・ケア・コーポレーション',
        submitter_name_en='CHARM CARE CORPORATION',
        submitter_name_yomi='カブシキガイシャチャームケアコーポレーション',
        address='大阪市北区中之島三丁目６番３２号',
        industry='サービス業',
        sec_code='60620',
        corporate_number='5120001109492',
    ),
    'E26445': EdinetCodeEntry(
        edinet_code='E26445',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='マスター・トラスト・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='マスター\u3000トラスト\u3000カンパニー',
        address='ケイマン諸島、ＫＹ１―１１０４、グランド・ケイマン、ジョージ・タウン、サウスチャーチ・ストリート、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26446': EdinetCodeEntry(
        edinet_code='E26446',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=172,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ユニバーサル園芸社',
        submitter_name_en='UNIVERSAL ENGEISHA CO.,LTD',
        submitter_name_yomi='カブシキガイシャ\u3000ユニバーサルエンゲイシャ',
        address='茨木市大字佐保１９３番地の２',
        industry='サービス業',
        sec_code='60610',
        corporate_number='3120901002294',
    ),
    'E26449': EdinetCodeEntry(
        edinet_code='E26449',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='細金\u3000千恵子',
        submitter_name_en=None,
        submitter_name_yomi='ホソガネ\u3000チエコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26452': EdinetCodeEntry(
        edinet_code='E26452',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=436,
        fiscal_year_end='12月末日',
        submitter_name='株式会社エコ・アセット',
        submitter_name_en='Eco Asset Incorporated',
        submitter_name_yomi='カブシキガイシャエコアセット',
        address='港区南青山１丁目１０番４号南青山ＮＫビル６階',
        industry='その他製品',
        sec_code=None,
        corporate_number='4010401062493',
    ),
    'E26454': EdinetCodeEntry(
        edinet_code='E26454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2222,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウチヤマホールディングス',
        submitter_name_en='UCHIYAMA HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャウチヤマホールディングス',
        address='北九州市小倉北区熊本２丁目１０－１０内山第２０ビル１Ｆ',
        industry='サービス業',
        sec_code='60590',
        corporate_number='5290801007284',
    ),
    'E26456': EdinetCodeEntry(
        edinet_code='E26456',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000高紀',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000タカノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26457': EdinetCodeEntry(
        edinet_code='E26457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菅野\u3000孝太郎',
        submitter_name_en=None,
        submitter_name_yomi='カンノ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26459': EdinetCodeEntry(
        edinet_code='E26459',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植田\u3000伸司',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000ノブジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26461': EdinetCodeEntry(
        edinet_code='E26461',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大島\u3000武信',
        submitter_name_en=None,
        submitter_name_yomi='オオシマ\u3000タケノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26466': EdinetCodeEntry(
        edinet_code='E26466',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人松永財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンマツナガザイダン',
        address='中央区日本橋３丁目８番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9240005007784',
    ),
    'E26472': EdinetCodeEntry(
        edinet_code='E26472',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26475': EdinetCodeEntry(
        edinet_code='E26475',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳川\u3000修一',
        submitter_name_en=None,
        submitter_name_yomi='ヤナガワ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26488': EdinetCodeEntry(
        edinet_code='E26488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田島\u3000哲康',
        submitter_name_en=None,
        submitter_name_yomi='タジマ\u3000テツヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26490': EdinetCodeEntry(
        edinet_code='E26490',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='崎谷\u3000文雄',
        submitter_name_en=None,
        submitter_name_yomi='サキヤ\u3000フミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26491': EdinetCodeEntry(
        edinet_code='E26491',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=120,
        fiscal_year_end=None,
        submitter_name='中銀アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウギンアセットマネジメントカブシキガイシャ',
        address='岡山市北区柳町二丁目１１番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6260001004357',
    ),
    'E26507': EdinetCodeEntry(
        edinet_code='E26507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='株式会社セブン・フィナンシャルサービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセブンフィナンシャルサービス',
        address='東京都千代田区二番町４番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001088493',
    ),
    'E26510': EdinetCodeEntry(
        edinet_code='E26510',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西江\u3000肇司',
        submitter_name_en=None,
        submitter_name_yomi='ニシエ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26517': EdinetCodeEntry(
        edinet_code='E26517',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000謙治',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26523': EdinetCodeEntry(
        edinet_code='E26523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='畑中\u3000千弘',
        submitter_name_en=None,
        submitter_name_yomi='ハタナカ\u3000チヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26527': EdinetCodeEntry(
        edinet_code='E26527',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社オフィスサポート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオフィスサポート',
        address='渋谷区南平台町３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001057535',
    ),
    'E26533': EdinetCodeEntry(
        edinet_code='E26533',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000祐輔',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26535': EdinetCodeEntry(
        edinet_code='E26535',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大久保\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='オオクボ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26544': EdinetCodeEntry(
        edinet_code='E26544',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000高生',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26549': EdinetCodeEntry(
        edinet_code='E26549',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=273,
        fiscal_year_end='2月末日',
        submitter_name='株式会社北の達人コーポレーション',
        submitter_name_en='Kitanotatsujin Corporation',
        submitter_name_yomi='カブシキガイシャキタノタツジンコーポレーション',
        address='札幌市中央区北一条西一丁目６番地',
        industry='化学',
        sec_code='29300',
        corporate_number='8430001028254',
    ),
    'E26562': EdinetCodeEntry(
        edinet_code='E26562',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=94,
        fiscal_year_end=None,
        submitter_name='株式会社佐藤企業',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサトウキギョウ',
        address='新潟市中央区東堀前通一番町３４５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1110001002058',
    ),
    'E26564': EdinetCodeEntry(
        edinet_code='E26564',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高岡\u3000伸夫',
        submitter_name_en=None,
        submitter_name_yomi='タカオカ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26570': EdinetCodeEntry(
        edinet_code='E26570',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='五洋食品産業株式会社',
        submitter_name_en='GOYO foods Industry Co., Ltd.',
        submitter_name_yomi='ゴヨウショクヒンサンギョウカブシキカイシャ',
        address='糸島市多久８１９番地２',
        industry='食料品',
        sec_code=None,
        corporate_number='3290001013226',
    ),
    'E26571': EdinetCodeEntry(
        edinet_code='E26571',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ジャパン・インダストリアル・ソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンインダストリアルソリューションズカブシキガイシャ',
        address='千代田区丸の内二丁目２番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001135547',
    ),
    'E26572': EdinetCodeEntry(
        edinet_code='E26572',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=270963,
        fiscal_year_end=None,
        submitter_name='アクティビア・プロパティーズ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='アクティビアプロパティーズトウシホウジン',
        address='渋谷区道玄坂一丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011005003537',
    ),
    'E26574': EdinetCodeEntry(
        edinet_code='E26574',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長嶋\u3000しのぶ',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000シノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26577': EdinetCodeEntry(
        edinet_code='E26577',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26579': EdinetCodeEntry(
        edinet_code='E26579',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=457,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ハピネス・アンド・ディ',
        submitter_name_en='happiness and d co ltd',
        submitter_name_yomi='カブシキカイシャ\u3000ハピネスアンドディ',
        address='中央区銀座一丁目１６－１',
        industry='小売業',
        sec_code='31740',
        corporate_number='4040001063955',
    ),
    'E26580': EdinetCodeEntry(
        edinet_code='E26580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000耕造',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26583': EdinetCodeEntry(
        edinet_code='E26583',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='内山\u3000文治',
        submitter_name_en=None,
        submitter_name_yomi='ウチヤマ\u3000フミハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26584': EdinetCodeEntry(
        edinet_code='E26584',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=328,
        fiscal_year_end=None,
        submitter_name='株式会社ジオブレイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジオブレイン',
        address='品川区東五反田５－２５－１９東京デザインセンター３Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010701025173',
    ),
    'E26594': EdinetCodeEntry(
        edinet_code='E26594',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='株式会社大江屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオエヤ',
        address='井原市井原町１２４７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6260001024719',
    ),
    'E26595': EdinetCodeEntry(
        edinet_code='E26595',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ムトウエンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャムトウエンタープライズ',
        address='横浜市神奈川区六角橋六丁目２２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5020001095157',
    ),
    'E26596': EdinetCodeEntry(
        edinet_code='E26596',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=179,
        fiscal_year_end='12月末日',
        submitter_name='株式会社モブキャストホールディングス',
        submitter_name_en='MOBCAST HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャモブキャストホールディングス',
        address='港区六本木６丁目８番１０号',
        industry='情報・通信業',
        sec_code='36640',
        corporate_number='4010701024945',
    ),
    'E26599': EdinetCodeEntry(
        edinet_code='E26599',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=60234,
        fiscal_year_end='12月31日',
        submitter_name='ビー・ピー・シー・イー・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='ビーピーシーイーエスエー',
        address='フランス国パリ市７５０１３\u3000ジェルメーヌ・サブロン通り７番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26600': EdinetCodeEntry(
        edinet_code='E26600',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田\u3000篤史',
        submitter_name_en=None,
        submitter_name_yomi='デン\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26601': EdinetCodeEntry(
        edinet_code='E26601',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田\u3000泰夫',
        submitter_name_en=None,
        submitter_name_yomi='デン\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26602': EdinetCodeEntry(
        edinet_code='E26602',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森坂\u3000拓実',
        submitter_name_en=None,
        submitter_name_yomi='モリサカ\u3000タクミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26608': EdinetCodeEntry(
        edinet_code='E26608',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下村\u3000隆彦',
        submitter_name_en=None,
        submitter_name_yomi='シモムラ\u3000タカヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26614': EdinetCodeEntry(
        edinet_code='E26614',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='羽山\u3000明',
        submitter_name_en=None,
        submitter_name_yomi='ハヤマ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26625': EdinetCodeEntry(
        edinet_code='E26625',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=307,
        fiscal_year_end='12月31日',
        submitter_name='日本エマージェンシーアシスタンス株式会社',
        submitter_name_en='Emergency Assistance Japan Co., Ltd.',
        submitter_name_yomi='ニホンエマージェンシーアシスタンスカブシキカイシャ',
        address='文京区小石川一丁目２１番１４号',
        industry='サービス業',
        sec_code='60630',
        corporate_number='8010001081502',
    ),
    'E26631': EdinetCodeEntry(
        edinet_code='E26631',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1884,
        fiscal_year_end='9月末日',
        submitter_name='株式会社アクトコール',
        submitter_name_en='ACTCALL INC.',
        submitter_name_yomi='カブシキガイシャアクトコール',
        address='新宿区四谷二丁目１２番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4011101044641',
    ),
    'E26632': EdinetCodeEntry(
        edinet_code='E26632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藪\u3000考樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤブ\u3000コウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26637': EdinetCodeEntry(
        edinet_code='E26637',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='池田興産有限会社',
        submitter_name_en=None,
        submitter_name_yomi='イケダコウサンユウゲンカイシャ',
        address='大野城市月の浦３丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9290002038605',
    ),
    'E26643': EdinetCodeEntry(
        edinet_code='E26643',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中島\u3000正三',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000ショウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26650': EdinetCodeEntry(
        edinet_code='E26650',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='株式会社ＬＳＩメディエンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエルエスアイメディエンス',
        address='港区芝浦一丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401068675',
    ),
    'E26656': EdinetCodeEntry(
        edinet_code='E26656',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＮＬＨＤ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエルエイチディーカブシキガイシャ',
        address='港区南麻布四丁目５番４８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401080861',
    ),
    'E26658': EdinetCodeEntry(
        edinet_code='E26658',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小原\u3000康嗣',
        submitter_name_en=None,
        submitter_name_yomi='オバラ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26661': EdinetCodeEntry(
        edinet_code='E26661',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジェーピーエムエーエムジャパンケイマンファンドリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、私書箱３０９、メイプルズ・コーポレート・サービシズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26675': EdinetCodeEntry(
        edinet_code='E26675',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=908,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ワイヤレスゲート',
        submitter_name_en='WirelessGate, Inc.',
        submitter_name_yomi='カブシキガイシャワイヤレスゲート',
        address='品川区東品川二丁目２番２０号',
        industry='情報・通信業',
        sec_code='94190',
        corporate_number='2010701015153',
    ),
    'E26676': EdinetCodeEntry(
        edinet_code='E26676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社エム・テイ興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエムテイコウサン',
        address='新宿区西落合三丁目２０番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011102002276',
    ),
    'E26683': EdinetCodeEntry(
        edinet_code='E26683',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舛田\u3000圭良',
        submitter_name_en=None,
        submitter_name_yomi='マスダ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26684': EdinetCodeEntry(
        edinet_code='E26684',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木下\u3000勝寿',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000カツヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26685': EdinetCodeEntry(
        edinet_code='E26685',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北川\u3000一子',
        submitter_name_en=None,
        submitter_name_yomi='キタガワ\u3000カズコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26686': EdinetCodeEntry(
        edinet_code='E26686',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28733,
        fiscal_year_end='3月31日',
        submitter_name='株式会社じもとホールディングス',
        submitter_name_en='Jimoto Holdings,Inc.',
        submitter_name_yomi='カブシキカイシャジモトホールディングス',
        address='仙台市青葉区一番町二丁目１番１号',
        industry='銀行業',
        sec_code='71610',
        corporate_number='9370001022386',
    ),
    'E26689': EdinetCodeEntry(
        edinet_code='E26689',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社サカイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサカイ',
        address='名古屋市千種区法王町二丁目２番地ー１０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001105533',
    ),
    'E26703': EdinetCodeEntry(
        edinet_code='E26703',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=381,
        fiscal_year_end='1月31日',
        submitter_name='株式会社エニグモ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエニグモ',
        address='港区赤坂四丁目８番１５号\u3000赤坂ＫＯＳＥＮビル４階',
        industry='情報・通信業',
        sec_code='36650',
        corporate_number='8010401088452',
    ),
    'E26704': EdinetCodeEntry(
        edinet_code='E26704',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=162,
        fiscal_year_end=None,
        submitter_name='カレラアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カレラアセットマネジメントカブシキカイシャ',
        address='港区赤坂一丁目１２番３２号アーク森ビル１２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001141324',
    ),
    'E26705': EdinetCodeEntry(
        edinet_code='E26705',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='ディー・ティー・ホールディングス株式会社',
        submitter_name_en='DT Holdings, inc.',
        submitter_name_yomi='ディーティーホールディングス',
        address='山形市諏訪町二丁目１番２０号',
        industry='陸運業',
        sec_code=None,
        corporate_number='7010601043423',
    ),
    'E26707': EdinetCodeEntry(
        edinet_code='E26707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=46525,
        fiscal_year_end='3月末日',
        submitter_name='日本軽金属ホールディングス株式会社',
        submitter_name_en='Nippon Light Metal Holdings Company, Ltd.',
        submitter_name_yomi='ニッポンケイキンゾクホールディングスカブシキガイシャ',
        address='港区新橋一丁目１番１３号',
        industry='非鉄金属',
        sec_code='57030',
        corporate_number='9010701027118',
    ),
    'E26711': EdinetCodeEntry(
        edinet_code='E26711',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石見\u3000安仁',
        submitter_name_en=None,
        submitter_name_yomi='イワミ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26712': EdinetCodeEntry(
        edinet_code='E26712',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=30000,
        fiscal_year_end='3月31日',
        submitter_name='日鉄日新製鋼株式会社',
        submitter_name_en='NIPPON STEEL NISSHIN CO., LTD.',
        submitter_name_yomi='ニッテツニッシンセイコウカブシキガイシャ',
        address='千代田区丸の内三丁目４番１号',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='8010001149423',
    ),
    'E26713': EdinetCodeEntry(
        edinet_code='E26713',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8000,
        fiscal_year_end='3月末日',
        submitter_name='株式会社東光高岳',
        submitter_name_en='TAKAOKA TOKO CO., LTD.',
        submitter_name_yomi='カブシキカイシャトウコウタカオカ',
        address='江東区豊洲五丁目６番３６号',
        industry='電気機器',
        sec_code='66170',
        corporate_number='5010601043417',
    ),
    'E26716': EdinetCodeEntry(
        edinet_code='E26716',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=285,
        fiscal_year_end='4月末日',
        submitter_name='ライクキッズ株式会社',
        submitter_name_en='LIKE Kids,Inc.',
        submitter_name_yomi='ライクキッズカブシキガイシャ',
        address='渋谷区道玄坂一丁目１２番１号\u3000渋谷マークシティ\u3000ウェスト',
        industry='サービス業',
        sec_code=None,
        corporate_number='5021001035887',
    ),
    'E26717': EdinetCodeEntry(
        edinet_code='E26717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=24,
        fiscal_year_end=None,
        submitter_name='辻不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツジフドウサンカブシキガイシャ',
        address='大阪市西淀川区姫島３丁目１番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001050129',
    ),
    'E26719': EdinetCodeEntry(
        edinet_code='E26719',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000淳',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26724': EdinetCodeEntry(
        edinet_code='E26724',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000中谷財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000ナカタニザイダン',
        address='品川区大崎１丁目２番２号アートヴィレッジ大崎セントラルタワー８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010705001797',
    ),
    'E26732': EdinetCodeEntry(
        edinet_code='E26732',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1553014,
        fiscal_year_end='12月31日',
        submitter_name='クレディ・アグリコル・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='クレディアグリコルエスエー',
        address='フランス、セデックス、モンルージュ、９２１２７、合衆国広場\u3000１２番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26738': EdinetCodeEntry(
        edinet_code='E26738',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙松\u3000孝之',
        submitter_name_en=None,
        submitter_name_yomi='タカマツ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26741': EdinetCodeEntry(
        edinet_code='E26741',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平井\u3000俊広',
        submitter_name_en=None,
        submitter_name_yomi='ヒライ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26746': EdinetCodeEntry(
        edinet_code='E26746',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='グローバル・ファンズ・トラスト・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='グローバルファンズトラストカンパニー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26751': EdinetCodeEntry(
        edinet_code='E26751',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=731814,
        fiscal_year_end='12月31日',
        submitter_name='中国人民保険集団股イ分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクジンミンホケンシュウダンコブンユウゲンコウシ',
        address='中華人民共和国北京市西長安街８８号１－１３階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E26753': EdinetCodeEntry(
        edinet_code='E26753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荒井\u3000毅',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26761': EdinetCodeEntry(
        edinet_code='E26761',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青山\u3000悦子',
        submitter_name_en=None,
        submitter_name_yomi='アオヤマ\u3000エツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26770': EdinetCodeEntry(
        edinet_code='E26770',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='須田\u3000将啓',
        submitter_name_en=None,
        submitter_name_yomi='スダ\u3000ショウケイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26810': EdinetCodeEntry(
        edinet_code='E26810',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='有限会社ニシムラ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャニシムラ',
        address='岐阜市菅生二丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2200002003490',
    ),
    'E26813': EdinetCodeEntry(
        edinet_code='E26813',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2013,
        fiscal_year_end='3月31日',
        submitter_name='アストマックス株式会社',
        submitter_name_en='ASTMAX Co., Ltd.',
        submitter_name_yomi='アストマックスカブシキガイシャ',
        address='品川区東五反田２－１０－２',
        industry='証券、商品先物取引業',
        sec_code='71620',
        corporate_number='6010701027087',
    ),
    'E26815': EdinetCodeEntry(
        edinet_code='E26815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=705,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯフィナンシャルホールディングス株式会社',
        submitter_name_en='GMO Financial Holdings, Inc.',
        submitter_name_yomi='ジーエムオーフィナンシャルホールディングスカブシキガイシャ',
        address='渋谷区道玄坂１－２－３渋谷フクラス',
        industry='証券、商品先物取引業',
        sec_code='71770',
        corporate_number='9011001072077',
    ),
    'E26818': EdinetCodeEntry(
        edinet_code='E26818',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000武弘',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000タケヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26821': EdinetCodeEntry(
        edinet_code='E26821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=547,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ありがとうサービス',
        submitter_name_en='ARIGATOU SERVICES COMPANY,LIMITED',
        submitter_name_yomi='カブシキガイシャアリガトウサービス',
        address='今治市八町西三丁目６番３０号',
        industry='小売業',
        sec_code='31770',
        corporate_number='2500001012603',
    ),
    'E26826': EdinetCodeEntry(
        edinet_code='E26826',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='サマーバンク合同会社',
        submitter_name_en=None,
        submitter_name_yomi='サマーバンクゴウドウカイシャ',
        address='横浜市中区竹之丸１２３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011103003961',
    ),
    'E26831': EdinetCodeEntry(
        edinet_code='E26831',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='5月31日',
        submitter_name='三協立山株式会社',
        submitter_name_en='Sankyo Tateyama,Inc.',
        submitter_name_yomi='サンキョウタテヤマカブシキガイシャ',
        address='高岡市早川７０番地',
        industry='金属製品',
        sec_code='59320',
        corporate_number='2230001010080',
    ),
    'E26836': EdinetCodeEntry(
        edinet_code='E26836',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2526,
        fiscal_year_end='6月30日',
        submitter_name='インパクトフィールド株式会社',
        submitter_name_en='Impact Field Inc.',
        submitter_name_yomi='インパクトフィールドカブシキガイシャ',
        address='渋谷区渋谷二丁目１２番１９号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9011001045116',
    ),
    'E26837': EdinetCodeEntry(
        edinet_code='E26837',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2332800,
        fiscal_year_end='3月末日',
        submitter_name='株式会社国際協力銀行',
        submitter_name_en='Japan Bank for International Cooperation',
        submitter_name_yomi='カブシキカイシャコクサイキョウリョクギンコウ',
        address='千代田区大手町１丁目４番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010001145977',
    ),
    'E26839': EdinetCodeEntry(
        edinet_code='E26839',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=418,
        fiscal_year_end='3月末日',
        submitter_name='キャリアリンク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キャリアリンクカブシキカイシャ',
        address='新宿区西新宿２丁目１番１号',
        industry='サービス業',
        sec_code='60700',
        corporate_number='2011101023151',
    ),
    'E26841': EdinetCodeEntry(
        edinet_code='E26841',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鴻池\u3000一信',
        submitter_name_en=None,
        submitter_name_yomi='コウノイケ\u3000カズノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26842': EdinetCodeEntry(
        edinet_code='E26842',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エー・ピーホールディングス',
        submitter_name_en='AP HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャエーピーホールディングス',
        address='港区高輪三丁目２５番２３号京急第２ビル１階',
        industry='小売業',
        sec_code='31750',
        corporate_number='6010401066278',
    ),
    'E26846': EdinetCodeEntry(
        edinet_code='E26846',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2219,
        fiscal_year_end=None,
        submitter_name='エッジポイント・インベストメント・グループ・インク',
        submitter_name_en=None,
        submitter_name_yomi='エッジポイント\u3000インベストメント\u3000グループ\u3000インク',
        address='カナダＭ５Ｓ\u3000２Ｘ９オンタリオ州トロント市ブロアーストリートウェスト１５０スイート７００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26849': EdinetCodeEntry(
        edinet_code='E26849',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=14000,
        fiscal_year_end=None,
        submitter_name='原子力損害賠償・廃炉等支援機構',
        submitter_name_en=None,
        submitter_name_yomi='ゲンシリョクソンガイバイショウハイロトウシエンキコウ',
        address='港区赤坂１－１１－４４\u3000赤坂インターシティ１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010405009863',
    ),
    'E26852': EdinetCodeEntry(
        edinet_code='E26852',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＴＯＳ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャティーオーエス',
        address='新宿区市谷船河原町１８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011103003142',
    ),
    'E26863': EdinetCodeEntry(
        edinet_code='E26863',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社コマツコーサン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコマツコーサン',
        address='小松市軽海町ウ１８番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5220002010581',
    ),
    'E26866': EdinetCodeEntry(
        edinet_code='E26866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='瀬田\u3000衛',
        submitter_name_en=None,
        submitter_name_yomi='セタ\u3000マモル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26869': EdinetCodeEntry(
        edinet_code='E26869',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1134,
        fiscal_year_end='12月31日',
        submitter_name='日本コンセプト株式会社',
        submitter_name_en='NIPPON CONCEPT CORPORATION',
        submitter_name_yomi='ニッポンコンセプトカブシキガイシャ',
        address='千代田区内幸町二丁目２番２号',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='9010001062088',
    ),
    'E26870': EdinetCodeEntry(
        edinet_code='E26870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津川\u3000洋子',
        submitter_name_en=None,
        submitter_name_yomi='ツガワ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26880': EdinetCodeEntry(
        edinet_code='E26880',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉川\u3000甲子次郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシカワ\u3000キネジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26895': EdinetCodeEntry(
        edinet_code='E26895',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岸本\u3000剛一',
        submitter_name_en=None,
        submitter_name_yomi='キシモト\u3000タケカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26904': EdinetCodeEntry(
        edinet_code='E26904',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福井\u3000康夫',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26913': EdinetCodeEntry(
        edinet_code='E26913',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中野\u3000光二',
        submitter_name_en=None,
        submitter_name_yomi='ナカノ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26914': EdinetCodeEntry(
        edinet_code='E26914',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1385,
        fiscal_year_end='3月末日',
        submitter_name='阿波製紙株式会社',
        submitter_name_en='AWA PAPER & TECHNOLOGICAL COMPANY, Inc.',
        submitter_name_yomi='アワセイシカブシキガイシャ',
        address='徳島市南矢三町三丁目１０番１８号',
        industry='パルプ・紙',
        sec_code='38960',
        corporate_number='8480001000084',
    ),
    'E26924': EdinetCodeEntry(
        edinet_code='E26924',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡\u3000義治',
        submitter_name_en=None,
        submitter_name_yomi='オカ\u3000ヨシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26926': EdinetCodeEntry(
        edinet_code='E26926',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6000,
        fiscal_year_end=None,
        submitter_name='日本テレビ放送網株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンテレビホウソウモウカブシキガイシャ',
        address='港区東新橋１－６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401099553',
    ),
    'E26933': EdinetCodeEntry(
        edinet_code='E26933',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=551,
        fiscal_year_end='3月末日',
        submitter_name='トレンダーズ株式会社',
        submitter_name_en='Trenders, Inc.',
        submitter_name_yomi='トレンダーズカブシキカイシャ',
        address='渋谷区東三丁目１６番３号',
        industry='サービス業',
        sec_code='60690',
        corporate_number='7011001034194',
    ),
    'E26934': EdinetCodeEntry(
        edinet_code='E26934',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社エムワイコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムワイコーポレーション',
        address='品川区大井六丁目１２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701026906',
    ),
    'E26936': EdinetCodeEntry(
        edinet_code='E26936',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山中\u3000康利',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナカ\u3000ヤストシ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26937': EdinetCodeEntry(
        edinet_code='E26937',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松元\u3000孝義',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000タカヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26941': EdinetCodeEntry(
        edinet_code='E26941',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀江\u3000正雄',
        submitter_name_en=None,
        submitter_name_yomi='ホリエ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26945': EdinetCodeEntry(
        edinet_code='E26945',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大橋\u3000進一',
        submitter_name_en=None,
        submitter_name_yomi='オオハシ\u3000インイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26947': EdinetCodeEntry(
        edinet_code='E26947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上野\u3000守生',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000モリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26953': EdinetCodeEntry(
        edinet_code='E26953',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000憲氏',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26954': EdinetCodeEntry(
        edinet_code='E26954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤本\u3000豊士',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000トヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26960': EdinetCodeEntry(
        edinet_code='E26960',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米山\u3000久',
        submitter_name_en=None,
        submitter_name_yomi='ヨネヤマ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E26965': EdinetCodeEntry(
        edinet_code='E26965',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='2月末日',
        submitter_name='株式会社安芸ゴルフ倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアキゴルフクラブ',
        address='東広島市河内町入野字大谷側１１９５７番地６',
        industry='サービス業',
        sec_code=None,
        corporate_number='7120001172720',
    ),
    'E26966': EdinetCodeEntry(
        edinet_code='E26966',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=736,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エストラスト',
        submitter_name_en='STrust Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエストラスト',
        address='下関市竹崎町四丁目１番２２号',
        industry='不動産業',
        sec_code='32800',
        corporate_number='4250001005176',
    ),
    'E26981': EdinetCodeEntry(
        edinet_code='E26981',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人業務スーパージャパンドリーム財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンギョウムスーパージャパンドリームザイダン',
        address='加古川市加古川町平野１２５番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140005020476',
    ),
    'E26987': EdinetCodeEntry(
        edinet_code='E26987',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社椿台',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツバキダイ',
        address='大阪市中央区高麗橋一丁目７番７ー２３０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001154930',
    ),
    'E26990': EdinetCodeEntry(
        edinet_code='E26990',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=31000,
        fiscal_year_end='3月末日',
        submitter_name='住信ＳＢＩネット銀行株式会社',
        submitter_name_en='SBI Sumishin Net Bank, Ltd.',
        submitter_name_yomi='スミシンエスビーアイネットギンコウカブシキカイシャ',
        address='港区六本木三丁目２番１号\u3000六本木グランドタワー',
        industry='銀行業',
        sec_code=None,
        corporate_number='6010401061386',
    ),
    'E26999': EdinetCodeEntry(
        edinet_code='E26999',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社合人社グループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゴウジンシャグループ',
        address='広島市中区袋町４番３１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001018675',
    ),
    'E27012': EdinetCodeEntry(
        edinet_code='E27012',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300000,
        fiscal_year_end='3月31日',
        submitter_name='新関西国際空港株式会社',
        submitter_name_en='NEW KANSAI INTERNATIONAL AIRPORT COMPANY,LTD.',
        submitter_name_yomi='シンカンサイコクサイクウコウカブシキカイシャ',
        address='泉南郡田尻町泉州空港中１番地',
        industry='倉庫・運輸関連',
        sec_code=None,
        corporate_number='1120001169813',
    ),
    'E27016': EdinetCodeEntry(
        edinet_code='E27016',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=777,
        fiscal_year_end='3月20日',
        submitter_name='株式会社アジュバンホールディングス',
        submitter_name_en='ADJUVANT HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャアジュバンホールディングス',
        address='神戸市中央区下山手通五丁目５番５号',
        industry='化学',
        sec_code='49290',
        corporate_number='2140001015675',
    ),
    'E27032': EdinetCodeEntry(
        edinet_code='E27032',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1150,
        fiscal_year_end='3月31日',
        submitter_name='キッズウェル・バイオ株式会社',
        submitter_name_en='Kidswell Bio Corporation',
        submitter_name_yomi='キッズウェルバイオカブシキガイシャ',
        address='中央区新川一丁目２番１２号',
        industry='医薬品',
        sec_code='45840',
        corporate_number='5430001027036',
    ),
    'E27035': EdinetCodeEntry(
        edinet_code='E27035',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社徳応舎',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトクオウシャ',
        address='大田区久が原六丁目２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010801020312',
    ),
    'E27037': EdinetCodeEntry(
        edinet_code='E27037',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永守\u3000貴樹',
        submitter_name_en=None,
        submitter_name_yomi='ナガモリ\u3000タカキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27038': EdinetCodeEntry(
        edinet_code='E27038',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1037,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＵＭＮファーマ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーエムエヌファーマ',
        address='秋田市御所野湯本四丁目２番３号',
        industry='医薬品',
        sec_code=None,
        corporate_number='9410001003282',
    ),
    'E27043': EdinetCodeEntry(
        edinet_code='E27043',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1026,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アビスト',
        submitter_name_en='ABIST Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャアビスト',
        address='三鷹市下連雀三丁目３６番１号',
        industry='サービス業',
        sec_code='60870',
        corporate_number='8011001065412',
    ),
    'E27046': EdinetCodeEntry(
        edinet_code='E27046',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=462,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グランディーズ',
        submitter_name_en='GRANDES,Inc.',
        submitter_name_yomi='カブシキカイシャグランディーズ',
        address='大分市都町２丁目１番１０号',
        industry='不動産業',
        sec_code='32610',
        corporate_number='1320001004512',
    ),
    'E27047': EdinetCodeEntry(
        edinet_code='E27047',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2824,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ｅｎｉｓｈ',
        submitter_name_en='enish,inc.',
        submitter_name_yomi='カブシキガイシャエニッシュ',
        address='港区六本木６－１－２０',
        industry='情報・通信業',
        sec_code='36670',
        corporate_number='9011001068959',
    ),
    'E27050': EdinetCodeEntry(
        edinet_code='E27050',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=562,
        fiscal_year_end='3月31日',
        submitter_name='株式会社テクノスジャパン',
        submitter_name_en='TECNOS  JAPAN  INCORPORATED',
        submitter_name_yomi='カブシキガイシャテクノスジャパン',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2011101054972',
    ),
    'E27051': EdinetCodeEntry(
        edinet_code='E27051',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=535,
        fiscal_year_end='3月31日',
        submitter_name='シュッピン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シュッピンカブシキカイシャ',
        address='新宿区西新宿１－１４－１１\u3000Ｄａｉｗａ西新宿ビル３階',
        industry='小売業',
        sec_code='31790',
        corporate_number='9011101039728',
    ),
    'E27052': EdinetCodeEntry(
        edinet_code='E27052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡本\u3000伊久男',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000イクオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27054': EdinetCodeEntry(
        edinet_code='E27054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13878,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ユーグレナ',
        submitter_name_en='Euglena Co., Ltd.',
        submitter_name_yomi='カブシキガイシャユーグレナ',
        address='港区芝五丁目２９番１１号',
        industry='食料品',
        sec_code='29310',
        corporate_number='8010001112570',
    ),
    'E27055': EdinetCodeEntry(
        edinet_code='E27055',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青山\u3000英生',
        submitter_name_en=None,
        submitter_name_yomi='アオヤマ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27059': EdinetCodeEntry(
        edinet_code='E27059',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=491,
        fiscal_year_end='3月31日',
        submitter_name='地盤ネットホールディングス株式会社',
        submitter_name_en='Jibannet Holdings Co., Ltd.',
        submitter_name_yomi='ジバンネットホールディングスカブシキガイシャ',
        address='新宿区新宿五丁目２番３号',
        industry='サービス業',
        sec_code='60720',
        corporate_number='9010001143631',
    ),
    'E27061': EdinetCodeEntry(
        edinet_code='E27061',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小菅\u3000敏一',
        submitter_name_en=None,
        submitter_name_yomi='コスゲ\u3000トシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27062': EdinetCodeEntry(
        edinet_code='E27062',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6635,
        fiscal_year_end='9月30日',
        submitter_name='株式会社コロプラ',
        submitter_name_en='COLOPL,Inc.',
        submitter_name_yomi='カブシキガイシャコロプラ',
        address='港区赤坂九丁目７番２号',
        industry='情報・通信業',
        sec_code='36680',
        corporate_number='7011001059638',
    ),
    'E27063': EdinetCodeEntry(
        edinet_code='E27063',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3406,
        fiscal_year_end='3月末日',
        submitter_name='パンチ工業株式会社',
        submitter_name_en='PUNCH INDUSTRY CO.,LTD.',
        submitter_name_yomi='パンチコウギョウカブシキガイシャ',
        address='品川区南大井六丁目２２番７号',
        industry='機械',
        sec_code='61650',
        corporate_number='7010401054620',
    ),
    'E27064': EdinetCodeEntry(
        edinet_code='E27064',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='12月31日',
        submitter_name='モバイルクリエイト株式会社',
        submitter_name_en='Mobile Create Co., Ltd.',
        submitter_name_yomi='モバイルクリエイトカブシキガイシャ',
        address='大分市東大道二丁目５番６０号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6320001003732',
    ),
    'E27066': EdinetCodeEntry(
        edinet_code='E27066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=699,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＩＢＪ',
        submitter_name_en='IBJ,Inc.',
        submitter_name_yomi='カブシキカイシャアイビージェー',
        address='新宿区西新宿一丁目２３番７号',
        industry='サービス業',
        sec_code='60710',
        corporate_number='9010001107009',
    ),
    'E27069': EdinetCodeEntry(
        edinet_code='E27069',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000栄治',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27071': EdinetCodeEntry(
        edinet_code='E27071',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1112505,
        fiscal_year_end='12月31日',
        submitter_name='エイチエスビーシー・ホールディングス・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーホールディングスピーエルシー',
        address='連合王国Ｅ１４\u3000５ＨＱロンドン市カナダ・スクエア８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27073': EdinetCodeEntry(
        edinet_code='E27073',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000忠泰',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000タダヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27074': EdinetCodeEntry(
        edinet_code='E27074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井本\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='イモト\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27076': EdinetCodeEntry(
        edinet_code='E27076',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='出雲\u3000充',
        submitter_name_en=None,
        submitter_name_yomi='イズモ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27078': EdinetCodeEntry(
        edinet_code='E27078',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49,
        fiscal_year_end=None,
        submitter_name='アモーヴァＡＭ・グローバルケイマンリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アモーヴァエーエムグローバルケイマンリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27080': EdinetCodeEntry(
        edinet_code='E27080',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='スマートキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スマートキャピタルカブシキカイシャ',
        address='渋谷区道玄坂一丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001066942',
    ),
    'E27087': EdinetCodeEntry(
        edinet_code='E27087',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='西澤管財株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシザワカンザイカブシキガイシャ',
        address='中央区銀座四丁目９番８号銀座王子ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001149282',
    ),
    'E27090': EdinetCodeEntry(
        edinet_code='E27090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000喜朗',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヨシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27092': EdinetCodeEntry(
        edinet_code='E27092',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=434510,
        fiscal_year_end=None,
        submitter_name='ＧＬＰ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ジーエルピートウシホウジン',
        address='中央区八重洲２丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405009877',
    ),
    'E27100': EdinetCodeEntry(
        edinet_code='E27100',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='唐川\u3000正明',
        submitter_name_en=None,
        submitter_name_yomi='カラカワ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27105': EdinetCodeEntry(
        edinet_code='E27105',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='有限会社群青',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャグンジョウ',
        address='さいたま市南区南浦和二丁目１８番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9030002004186',
    ),
    'E27113': EdinetCodeEntry(
        edinet_code='E27113',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=43074,
        fiscal_year_end='12月31日',
        submitter_name='ＯＰコーポレート・バンク・ピーエルシー（ＯＰ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｂａｎｋ\u3000ｐｌｃ）',
        submitter_name_en=None,
        submitter_name_yomi='オーピーコーポレートバンクピーエルシー',
        address='フィンランド共和国\u3000ヘルシンキ市\u3000００５１０\u3000ゲブハルディナウキオ\u3000１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27115': EdinetCodeEntry(
        edinet_code='E27115',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダイナムジャパンホールディングス',
        submitter_name_en='DYNAM JAPAN HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャダイナムジャパンホールディングス',
        address='荒川区西日暮里二丁目２５番１－７０２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5011501017114',
    ),
    'E27120': EdinetCodeEntry(
        edinet_code='E27120',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='德平\u3000正憲',
        submitter_name_en=None,
        submitter_name_yomi='トクヒラ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27122': EdinetCodeEntry(
        edinet_code='E27122',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村井\u3000雄司',
        submitter_name_en=None,
        submitter_name_yomi='ムライ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27124': EdinetCodeEntry(
        edinet_code='E27124',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='公文\u3000善之',
        submitter_name_en=None,
        submitter_name_yomi='クモン\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27125': EdinetCodeEntry(
        edinet_code='E27125',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安徳\u3000孝平',
        submitter_name_en=None,
        submitter_name_yomi='アントク\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27132': EdinetCodeEntry(
        edinet_code='E27132',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森久保\u3000哲司',
        submitter_name_en=None,
        submitter_name_yomi='モリクボ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27134': EdinetCodeEntry(
        edinet_code='E27134',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='馬場\u3000功淳',
        submitter_name_en=None,
        submitter_name_yomi='ババ\u3000ナルアツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27140': EdinetCodeEntry(
        edinet_code='E27140',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='池永辰朗',
        submitter_name_en=None,
        submitter_name_yomi='イケナガタツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27141': EdinetCodeEntry(
        edinet_code='E27141',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27146': EdinetCodeEntry(
        edinet_code='E27146',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='レッド・プラネット・ホールディングス・ピーティーイー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='レツドプラネツトールデイングスーテイーイーエルテイーデイー',
        address='シンガポール、１５０、セシルストリート、＃１４―０１（１５０\u3000Ｃｅｃｉｌ\u3000Ｓｔｒｅｅｔ\u3000＃１４―０１、ＳＩＮＧＡＰＯＲＥ\u3000０６９５４３）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27149': EdinetCodeEntry(
        edinet_code='E27149',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石坂\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='イシザカ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27150': EdinetCodeEntry(
        edinet_code='E27150',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中本\u3000哲宏',
        submitter_name_en=None,
        submitter_name_yomi='ナカモト\u3000テツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27152': EdinetCodeEntry(
        edinet_code='E27152',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中西\u3000一真',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27156': EdinetCodeEntry(
        edinet_code='E27156',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000慶',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ケイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27158': EdinetCodeEntry(
        edinet_code='E27158',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社エムジー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムジー',
        address='渋谷区代々木２－５－５新宿農協会館ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001050913',
    ),
    'E27159': EdinetCodeEntry(
        edinet_code='E27159',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=154451,
        fiscal_year_end=None,
        submitter_name='コンフォリア・レジデンシャル投資法人',
        submitter_name_en=None,
        submitter_name_yomi='コンフォリア\u3000レジデンシャルトウシホウジン',
        address='渋谷区道玄坂一丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011005003095',
    ),
    'E27166': EdinetCodeEntry(
        edinet_code='E27166',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='立川\u3000雅尉',
        submitter_name_en=None,
        submitter_name_yomi='タチカワ\u3000マサヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27168': EdinetCodeEntry(
        edinet_code='E27168',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27169': EdinetCodeEntry(
        edinet_code='E27169',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000順子',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ジュンコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27170': EdinetCodeEntry(
        edinet_code='E27170',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000昌樹',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27176': EdinetCodeEntry(
        edinet_code='E27176',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐鳥\u3000浩之',
        submitter_name_en=None,
        submitter_name_yomi='サトリ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27202': EdinetCodeEntry(
        edinet_code='E27202',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='2月末日',
        submitter_name='株式会社買取王国',
        submitter_name_en='KAITORIOKOKU Co.,Ltd',
        submitter_name_yomi='カブシキカイシャカイトリオウコク',
        address='名古屋市港区川西通５－１２',
        industry='小売業',
        sec_code='31810',
        corporate_number='8180001071932',
    ),
    'E27203': EdinetCodeEntry(
        edinet_code='E27203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='亀井\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='カメイ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27208': EdinetCodeEntry(
        edinet_code='E27208',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メドレックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメドレックス',
        address='東かがわ市西山４３１番地７',
        industry='医薬品',
        sec_code='45860',
        corporate_number='3470001011509',
    ),
    'E27210': EdinetCodeEntry(
        edinet_code='E27210',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=550,
        fiscal_year_end='3月31日',
        submitter_name='ウイン・パートナーズ株式会社',
        submitter_name_en='WIN-Partners Co., Ltd.',
        submitter_name_yomi='ウインパートナーズカブシキカイシャ',
        address='台東区台東四丁目２４番８号',
        industry='卸売業',
        sec_code='31830',
        corporate_number='9010501035080',
    ),
    'E27214': EdinetCodeEntry(
        edinet_code='E27214',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ワイズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイズカブシキガイシャ',
        address='静岡市葵区七間町１４番地の１\u3000ザ・エンブル七間町２７０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6080001017815',
    ),
    'E27215': EdinetCodeEntry(
        edinet_code='E27215',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=768,
        fiscal_year_end='4月末日',
        submitter_name='株式会社ビューティガレージ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビューティガレージ',
        address='世田谷区桜新町一丁目３４番２５号',
        industry='卸売業',
        sec_code='31800',
        corporate_number='6011301013031',
    ),
    'E27217': EdinetCodeEntry(
        edinet_code='E27217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下田\u3000寛二',
        submitter_name_en=None,
        submitter_name_yomi='シモダ\u3000カンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27220': EdinetCodeEntry(
        edinet_code='E27220',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=205,
        fiscal_year_end=None,
        submitter_name='株式会社アイビス・キャピタル・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイビスキャピタルパートナーズ',
        address='中央区銀座四丁目１２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001111975',
    ),
    'E27228': EdinetCodeEntry(
        edinet_code='E27228',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水上\u3000浩次',
        submitter_name_en=None,
        submitter_name_yomi='ミズカミ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27230': EdinetCodeEntry(
        edinet_code='E27230',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=482964,
        fiscal_year_end=None,
        submitter_name='日本プロロジスリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンプロロジスリートトウシホウジン',
        address='千代田区丸の内二丁目７番３号\u3000東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005019769',
    ),
    'E27231': EdinetCodeEntry(
        edinet_code='E27231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾下\u3000順治',
        submitter_name_en=None,
        submitter_name_yomi='オシタ\u3000ジュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27235': EdinetCodeEntry(
        edinet_code='E27235',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=203,
        fiscal_year_end='3月31日',
        submitter_name='協立情報通信株式会社',
        submitter_name_en='Kyoritsu Computer & Communication Co.,Ltd.',
        submitter_name_yomi='キョウリツジョウホウツウシンカブシキカイシャ',
        address='港区浜松町一丁目９番１０号',
        industry='サービス業',
        sec_code='36700',
        corporate_number='2010401008184',
    ),
    'E27236': EdinetCodeEntry(
        edinet_code='E27236',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社南青山不動産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミナミアオヤマフドウサン',
        address='渋谷区南平台町３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010403007715',
    ),
    'E27238': EdinetCodeEntry(
        edinet_code='E27238',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='坂本\u3000洋司',
        submitter_name_en=None,
        submitter_name_yomi='サカモト\u3000ヨウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27242': EdinetCodeEntry(
        edinet_code='E27242',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='合同会社ＴＫＣ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャティーケーシー',
        address='中央区東日本橋一丁目五番六号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011003004374',
    ),
    'E27246': EdinetCodeEntry(
        edinet_code='E27246',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社インスパイア・インベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャインスパイアインベストメント',
        address='港区南青山５目３番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401061009',
    ),
    'E27247': EdinetCodeEntry(
        edinet_code='E27247',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野村\u3000秀輝',
        submitter_name_en=None,
        submitter_name_yomi='ノムラ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27248': EdinetCodeEntry(
        edinet_code='E27248',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='供田\u3000修一',
        submitter_name_en=None,
        submitter_name_yomi='トモダ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27260': EdinetCodeEntry(
        edinet_code='E27260',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1259,
        fiscal_year_end='3月末日',
        submitter_name='オイシックス・ラ・大地株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オイシックスラダイチカブシキガイシャ',
        address='品川区大崎一丁目１１番２号',
        industry='サービス業',
        sec_code='31820',
        corporate_number='6010701012329',
    ),
    'E27273': EdinetCodeEntry(
        edinet_code='E27273',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5945,
        fiscal_year_end='3月31日',
        submitter_name='サンヨーホームズ株式会社',
        submitter_name_en='Sanyo Homes Corporation',
        submitter_name_yomi='サンヨーホームズカブシキカイシャ',
        address='大阪市西区西本町一丁目４番１号',
        industry='建設業',
        sec_code='14200',
        corporate_number='3120001039510',
    ),
    'E27275': EdinetCodeEntry(
        edinet_code='E27275',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=304734,
        fiscal_year_end=None,
        submitter_name='ニプシー・インターナショナル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ニプシーインターナショナルリミテッド',
        address='香港、ニューテリトリーズ、セン湾区、Ｕｋロード\u3000ヤン\u3000８、ニナタワー、第２タワー、３２階、３２０３及び３２０４室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27276': EdinetCodeEntry(
        edinet_code='E27276',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=442,
        fiscal_year_end='12月31日',
        submitter_name='ソフトマックス株式会社',
        submitter_name_en='SOFTMAX CO.,LTD',
        submitter_name_yomi='ソフトマックスカブシキガイシャ',
        address='鹿児島市加治屋町１２番１１号',
        industry='情報・通信業',
        sec_code='36710',
        corporate_number='8340001002433',
    ),
    'E27278': EdinetCodeEntry(
        edinet_code='E27278',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='有限会社中谷興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャナカタニコウサン',
        address='神戸市須磨区前池町６丁目２番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140002011863',
    ),
    'E27280': EdinetCodeEntry(
        edinet_code='E27280',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='9月30日',
        submitter_name='株式会社オルトプラス',
        submitter_name_en='AltPlusInc.',
        submitter_name_yomi='カブシキカイシャオルトプラス',
        address='豊島区東池袋三丁目１番１号',
        industry='情報・通信業',
        sec_code='36720',
        corporate_number='6011001065018',
    ),
    'E27281': EdinetCodeEntry(
        edinet_code='E27281',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フージャースホールディングス',
        submitter_name_en='Hoosiers Holdings Co., Ltd.',
        submitter_name_yomi='カブシキカイシャフージャースホールディングス',
        address='千代田区丸の内二丁目２番３号',
        industry='不動産業',
        sec_code='32840',
        corporate_number='7010001152568',
    ),
    'E27283': EdinetCodeEntry(
        edinet_code='E27283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='アルファレオ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アルファレオカブシキガイシャ',
        address='千代田区永田町二丁目１１番１号\u3000山王パークタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401093020',
    ),
    'E27286': EdinetCodeEntry(
        edinet_code='E27286',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='株式会社不二総業',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジソウギョウ',
        address='渋谷区神宮前四丁目３２番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001065256',
    ),
    'E27293': EdinetCodeEntry(
        edinet_code='E27293',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='向井山\u3000達也',
        submitter_name_en=None,
        submitter_name_yomi='ムカイヤマ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27294': EdinetCodeEntry(
        edinet_code='E27294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4329,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プレミアムウォーターホールディングス',
        submitter_name_en='Premium Water Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャプレミアムウォーターホールディングス',
        address='富士吉田市上吉田４５９７番地の１',
        industry='食料品',
        sec_code='25880',
        corporate_number='9090001010626',
    ),
    'E27295': EdinetCodeEntry(
        edinet_code='E27295',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神戸市',
        submitter_name_en=None,
        submitter_name_yomi='コウベシ',
        address='神戸市中央区加納町６－５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9000020281000',
    ),
    'E27296': EdinetCodeEntry(
        edinet_code='E27296',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＨＡＧコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーエイチエージーコーポレーション',
        address='千代田区三番町９番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010002043032',
    ),
    'E27297': EdinetCodeEntry(
        edinet_code='E27297',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='京都市',
        submitter_name_en=None,
        submitter_name_yomi='キョウトシ',
        address='京都市中京区寺町通御池上る上本能寺前町４８８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2000020261009',
    ),
    'E27298': EdinetCodeEntry(
        edinet_code='E27298',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='株式会社桑名カントリー倶楽部',
        submitter_name_en='The Kuwana Country Club Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクワナカントリークラブ',
        address='桑名市大字嘉例川８６１番地',
        industry='サービス業',
        sec_code=None,
        corporate_number='9190001020763',
    ),
    'E27303': EdinetCodeEntry(
        edinet_code='E27303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1161,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アサンテ',
        submitter_name_en='ASANTE INCORPORATED',
        submitter_name_yomi='カブシキガイシャアサンテ',
        address='新宿区新宿一丁目３３番１５号',
        industry='サービス業',
        sec_code='60730',
        corporate_number='2011101000803',
    ),
    'E27305': EdinetCodeEntry(
        edinet_code='E27305',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4310,
        fiscal_year_end='5月31日',
        submitter_name='タマホーム株式会社',
        submitter_name_en='Tama Home Co., Ltd.',
        submitter_name_yomi='タマホームカブシキガイシャ',
        address='港区高輪３丁目２２番９号',
        industry='建設業',
        sec_code='14190',
        corporate_number='7010401057862',
    ),
    'E27311': EdinetCodeEntry(
        edinet_code='E27311',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月末日',
        submitter_name='株式会社オウチーノ',
        submitter_name_en='O-uccino,Inc.',
        submitter_name_yomi='カブシキガイシャオウチーノ',
        address='港区三田一丁目４番２８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401059839',
    ),
    'E27312': EdinetCodeEntry(
        edinet_code='E27312',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2286,
        fiscal_year_end=None,
        submitter_name='チャイナ・アセット・マネジメント（香港）・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='チャイナアセットマネジメントホンコンリミテッド',
        address='香港、ガーデンロード１、バンク・オブ・チャイナ・タワー３７階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27314': EdinetCodeEntry(
        edinet_code='E27314',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＭＡＲＩＬＹＮ\u3000ＨＷＥＥＴＩＡＮＧ\u3000ＴＡＮＧ',
        submitter_name_en=None,
        submitter_name_yomi='マリリン\u3000ヒュティアン\u3000タン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27320': EdinetCodeEntry(
        edinet_code='E27320',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人ウエスコ学術振興財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンウエスコガクジュツシンコウザイダン',
        address='岡山市北区島田本町二丁目５－３５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5260005000147',
    ),
    'E27325': EdinetCodeEntry(
        edinet_code='E27325',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ストラテジックキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャストラテジックキャピタル',
        address='港区赤坂二丁目１７番２２号赤坂トラストタワー３Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001091831',
    ),
    'E27331': EdinetCodeEntry(
        edinet_code='E27331',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000拓郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000タクロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27332': EdinetCodeEntry(
        edinet_code='E27332',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000太一',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000タイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27333': EdinetCodeEntry(
        edinet_code='E27333',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000和夫',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27339': EdinetCodeEntry(
        edinet_code='E27339',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社シートック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシートック',
        address='港区西麻布四丁目２０番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010701025475',
    ),
    'E27350': EdinetCodeEntry(
        edinet_code='E27350',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＳＯＮ\u3000Ｆｉｎａｎｃｉａｌ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ソンフィナンシャルゴウドウガイシャ',
        address='中央区東日本橋二丁目２６番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401064050',
    ),
    'E27352': EdinetCodeEntry(
        edinet_code='E27352',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ダンキン\u3000ブランズ\u3000インターナショナル\u3000ホールディングス\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ダンキン\u3000ブランズ\u3000インターナショナル\u3000ホールディングス\u3000リミテッド',
        address='英国ロンドン\u3000フィンズゲート\u3000クランウッドストリート５－７、ＥＣ１Ｖ\u3000９ＥＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27361': EdinetCodeEntry(
        edinet_code='E27361',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5615,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ブロードリーフ',
        submitter_name_en='Broadleaf Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャブロードリーフ',
        address='品川区東品川四丁目１３番１４号',
        industry='情報・通信業',
        sec_code='36730',
        corporate_number='3010701023163',
    ),
    'E27366': EdinetCodeEntry(
        edinet_code='E27366',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小川\u3000浩平',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27368': EdinetCodeEntry(
        edinet_code='E27368',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='プロロジス・プロパティ・ジャパン特定目的会社',
        submitter_name_en=None,
        submitter_name_yomi='プロロジスプロパティジャパントクテイモクテキカイシャ',
        address='千代田区丸の内二丁目７番３号\u3000東京ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005015164',
    ),
    'E27393': EdinetCodeEntry(
        edinet_code='E27393',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='沓名\u3000裕一郎',
        submitter_name_en=None,
        submitter_name_yomi='クツナ\u3000ユウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27394': EdinetCodeEntry(
        edinet_code='E27394',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=884,
        fiscal_year_end='9月30日',
        submitter_name='株式会社オークファン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオークファン',
        address='品川区北品川五丁目１番１８号',
        industry='情報・通信業',
        sec_code='36740',
        corporate_number='7011001053434',
    ),
    'E27399': EdinetCodeEntry(
        edinet_code='E27399',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='畑中\u3000浩太郎',
        submitter_name_en=None,
        submitter_name_yomi='ハタナカ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27400': EdinetCodeEntry(
        edinet_code='E27400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='畑中\u3000雄介',
        submitter_name_en=None,
        submitter_name_yomi='ハタナカ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27405': EdinetCodeEntry(
        edinet_code='E27405',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000翔',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ショウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27412': EdinetCodeEntry(
        edinet_code='E27412',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='鈴与株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スズヨカブシキガイシャ',
        address='静岡市清水区入船町１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080001009460',
    ),
    'E27414': EdinetCodeEntry(
        edinet_code='E27414',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000武',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27416': EdinetCodeEntry(
        edinet_code='E27416',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社フォーシスアンドカンパニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフォーシスアンドカンパニー',
        address='渋谷区桜丘町３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001044074',
    ),
    'E27421': EdinetCodeEntry(
        edinet_code='E27421',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=646,
        fiscal_year_end='6月30日',
        submitter_name='株式会社クロス・マーケティンググループ',
        submitter_name_en='Cross Marketing Group Inc.',
        submitter_name_yomi='カブシキガイシャクロスマーケティンググループ',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code='36750',
        corporate_number='5010001153857',
    ),
    'E27426': EdinetCodeEntry(
        edinet_code='E27426',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=163,
        fiscal_year_end=None,
        submitter_name='株式会社ポートフォリア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャポートフォリア',
        address='渋谷区千駄ヶ谷一丁目８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010901027584',
    ),
    'E27439': EdinetCodeEntry(
        edinet_code='E27439',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='広島運輸株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒロシマウンユカブシキガイシャ',
        address='広島市南区西蟹屋二丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4240001009137',
    ),
    'E27444': EdinetCodeEntry(
        edinet_code='E27444',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=125,
        fiscal_year_end=None,
        submitter_name='株式会社ムネマサ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャムネマサ',
        address='杉並区永福１－３９－２３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011301007003',
    ),
    'E27449': EdinetCodeEntry(
        edinet_code='E27449',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川島\u3000利介',
        submitter_name_en=None,
        submitter_name_yomi='カワシマ\u3000リスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27464': EdinetCodeEntry(
        edinet_code='E27464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=422,
        fiscal_year_end='6月30日',
        submitter_name='トラストホールディングス株式会社',
        submitter_name_en='TRUST Holdings Inc.',
        submitter_name_yomi='トラストホールディングスカブシキガイシャ',
        address='福岡市博多区博多駅南五丁目１５番１８号',
        industry='不動産業',
        sec_code='32860',
        corporate_number='5290001063277',
    ),
    'E27472': EdinetCodeEntry(
        edinet_code='E27472',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＸキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスエックスキャピタル',
        address='港区虎ノ門４－１－２８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010601027277',
    ),
    'E27473': EdinetCodeEntry(
        edinet_code='E27473',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社船橋カントリー倶楽部',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフナバシカントリークラブ',
        address='白井市清戸７０３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001043940',
    ),
    'E27486': EdinetCodeEntry(
        edinet_code='E27486',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3956,
        fiscal_year_end='12月31日',
        submitter_name='ペプチドリーム株式会社',
        submitter_name_en='PeptiDream Inc.',
        submitter_name_yomi='ペプチドリームカブシキガイシャ',
        address='川崎市川崎区殿町三丁目２５番２３号',
        industry='医薬品',
        sec_code='45870',
        corporate_number='5013201015694',
    ),
    'E27488': EdinetCodeEntry(
        edinet_code='E27488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='水落\u3000憲吾',
        submitter_name_en=None,
        submitter_name_yomi='ミズオチ\u3000ケンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27498': EdinetCodeEntry(
        edinet_code='E27498',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='東拓観光有限会社',
        submitter_name_en=None,
        submitter_name_yomi='トウタクカンコウユウゲンガイシャ',
        address='広島市中区広瀬北町３番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1240002011160',
    ),
    'E27506': EdinetCodeEntry(
        edinet_code='E27506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=330,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ジェイエスエス',
        submitter_name_en='JSS CORPORATION',
        submitter_name_yomi='カブシキガイシャジェイエスエス',
        address='大阪市西区土佐堀一丁目４番１１号',
        industry='サービス業',
        sec_code='60740',
        corporate_number='1120001064799',
    ),
    'E27507': EdinetCodeEntry(
        edinet_code='E27507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='瀧上精機工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タキガミセイキコウギョウカブシキカイシャ',
        address='名古屋市港区須成町一丁目１番２３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001022155',
    ),
    'E27509': EdinetCodeEntry(
        edinet_code='E27509',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金\u3000武祚',
        submitter_name_en=None,
        submitter_name_yomi='キム\u3000ムジョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27530': EdinetCodeEntry(
        edinet_code='E27530',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=130,
        fiscal_year_end='3月31日',
        submitter_name='株式会社横田製作所',
        submitter_name_en='Yokota Manufacturing Co., Ltd.',
        submitter_name_yomi='カブシキガイシャヨコタセイサクショ',
        address='広島市中区南吉島一丁目３番６号',
        industry='機械',
        sec_code='62480',
        corporate_number='4240001012215',
    ),
    'E27557': EdinetCodeEntry(
        edinet_code='E27557',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='有限会社越智産業',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャオチサンギョウ',
        address='北葛城郡広陵町大字疋相３０９番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8150002010132',
    ),
    'E27559': EdinetCodeEntry(
        edinet_code='E27559',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊井\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='イイ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27561': EdinetCodeEntry(
        edinet_code='E27561',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=45711,
        fiscal_year_end='12月31日',
        submitter_name='スヴェンスカ・ハンデルスバンケン・エイ・ビー・プブリクト（Ｓｖｅｎｓｋａ\u3000Ｈａｎｄｅｌｓｂａｎｋｅｎ\u3000ＡＢ\u3000（ｐｕｂｌ））',
        submitter_name_en=None,
        submitter_name_yomi='スヴェンスカハンデルスバンケンエイビープブリクト',
        address='スウェーデン王国\u3000ＳＥ－１０６\u3000７０\u3000ストックホルム\u3000クングストラッドゴードシュガータン２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27562': EdinetCodeEntry(
        edinet_code='E27562',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1452,
        fiscal_year_end='3月末日',
        submitter_name='ＳＢＩ\u3000ＦｉｎＴｅｃｈ\u3000Ｓｏｌｕｔｉｏｎｓ株式会社',
        submitter_name_en='SBI FinTech Solutions Co., Ltd.',
        submitter_name_yomi='エスビーアイフィンテックソリューションズカブシキカイシャ',
        address='渋谷区渋谷２－１－１\u3000青山ファーストビル９Ｆ',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8011001068885',
    ),
    'E27567': EdinetCodeEntry(
        edinet_code='E27567',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=242,
        fiscal_year_end='6月30日',
        submitter_name='株式会社フォトクリエイト',
        submitter_name_en='Photocreate Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャフォトクリエイト',
        address='新宿区西新宿六丁目１６番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2011101034099',
    ),
    'E27569': EdinetCodeEntry(
        edinet_code='E27569',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＤＧベンチャーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディージーベンチャーズ',
        address='渋谷区恵比寿南三丁目５番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001061291',
    ),
    'E27571': EdinetCodeEntry(
        edinet_code='E27571',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ワサッチ・アドバイザーズ・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='ワサッチ\u3000アドバイザーズ\u3000エルピー',
        address='アメリカ合衆国\u3000８４１０８\u3000ユタ州ソールト・レーク・シティ、ワカラ・ウェイ\u3000５０５番３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27572': EdinetCodeEntry(
        edinet_code='E27572',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1161,
        fiscal_year_end='3月末日',
        submitter_name='ＩＣＤＡホールディングス株式会社',
        submitter_name_en='International Conglomerate of Distribution for Automobile Holdings Co., Ltd.',
        submitter_name_yomi='アイシーディーエーホールディングス',
        address='鈴鹿市飯野寺家町２３４番地の１',
        industry='小売業',
        sec_code='31840',
        corporate_number='2190001006257',
    ),
    'E27576': EdinetCodeEntry(
        edinet_code='E27576',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武永\u3000修一',
        submitter_name_en=None,
        submitter_name_yomi='タケナガ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27577': EdinetCodeEntry(
        edinet_code='E27577',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=491,
        fiscal_year_end=None,
        submitter_name='ＦＰＴファンド・マネジメント・ジョイント・ストック・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='エフピーティーファンドマネジメントジョイントストックカンパニー',
        address='ベトナム、ハノイ、カウ・ギアイ・ディストリクト・ディッチ・ヴォン・ハウ・ワード、デュイ・タン・ストリート、ライト・アンド・スモール・スケール・インダストリアル・エリア・ロットＢ１Ａ、ＴＴＣビルディング９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27579': EdinetCodeEntry(
        edinet_code='E27579',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2237,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ナローピーク',
        submitter_name_en='Narrow Peak,Inc.',
        submitter_name_yomi='カブシキガイシャナローピーク',
        address='新宿区新宿五丁目１７番１８号\u3000Ｈ＆Ｉビル',
        industry='保険業',
        sec_code=None,
        corporate_number='1011101060955',
    ),
    'E27580': EdinetCodeEntry(
        edinet_code='E27580',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4082,
        fiscal_year_end=None,
        submitter_name='スイス・リインシュアランス・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スイスリインシュアランスカンパニーリミテッド',
        address='スイス国チューリッヒ市ミテンケ６０、８００２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27584': EdinetCodeEntry(
        edinet_code='E27584',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=420,
        fiscal_year_end=None,
        submitter_name='ＨＡＹＡＴＥ\u3000ＰＡＲＴＮＥＲＳ\u3000ＰＴＥ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='ハヤテパートナーズ\u3000ピーティーイー\u3000エルティーディー',
        address='１４３セシル・ストリート、シンガポール０６９５４２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27585': EdinetCodeEntry(
        edinet_code='E27585',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2023,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リプロセル',
        submitter_name_en='ReproCELL Incorporated',
        submitter_name_yomi='カブシキガイシャリプロセル',
        address='横浜市港北区新横浜３－８－１１',
        industry='化学',
        sec_code='49780',
        corporate_number='2020001086778',
    ),
    'E27586': EdinetCodeEntry(
        edinet_code='E27586',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='八木通商株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤギツウショウカブシキカイシャ',
        address='大阪市中央区北浜３丁目１番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001077578',
    ),
    'E27596': EdinetCodeEntry(
        edinet_code='E27596',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000一郷',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000カズサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27615': EdinetCodeEntry(
        edinet_code='E27615',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=793,
        fiscal_year_end='3月31日',
        submitter_name='夢展望株式会社',
        submitter_name_en='DREAM VISION CO.,LTD.',
        submitter_name_yomi='ユメテンボウカブシキガイシャ',
        address='池田市石橋三丁目２番１号',
        industry='小売業',
        sec_code='31850',
        corporate_number='6120901020756',
    ),
    'E27616': EdinetCodeEntry(
        edinet_code='E27616',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='内野\u3000弘幸',
        submitter_name_en=None,
        submitter_name_yomi='ウチノ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27622': EdinetCodeEntry(
        edinet_code='E27622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=168384,
        fiscal_year_end='12月31日',
        submitter_name='サントリー食品インターナショナル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サントリーショクヒンインターナショナルカブシキガイシャ',
        address='港区芝浦三丁目１番１号',
        industry='食料品',
        sec_code='25870',
        corporate_number='8010401080079',
    ),
    'E27624': EdinetCodeEntry(
        edinet_code='E27624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2099,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カーリット',
        submitter_name_en='Carlit Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャカーリット',
        address='中央区京橋１丁目１７番１０号',
        industry='化学',
        sec_code='42750',
        corporate_number='6010001156165',
    ),
    'E27632': EdinetCodeEntry(
        edinet_code='E27632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='千野\u3000和俊',
        submitter_name_en=None,
        submitter_name_yomi='センノ\u3000カズトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27633': EdinetCodeEntry(
        edinet_code='E27633',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=77562,
        fiscal_year_end='3月末日',
        submitter_name='東急不動産ホールディングス株式会社',
        submitter_name_en='Tokyu Fudosan Holdings Corporation',
        submitter_name_yomi='トウキュウフドウサンホールディングスカブシキカイシャ',
        address='渋谷区道玄坂一丁目２１番１号',
        industry='不動産業',
        sec_code='32890',
        corporate_number='2011001096933',
    ),
    'E27636': EdinetCodeEntry(
        edinet_code='E27636',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='窪田\u3000規一',
        submitter_name_en=None,
        submitter_name_yomi='クボタ\u3000キイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27638': EdinetCodeEntry(
        edinet_code='E27638',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='リード\u3000パトリック\u3000クロフオード',
        submitter_name_en=None,
        submitter_name_yomi='リード\u3000パトリック\u3000クロフオード',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27641': EdinetCodeEntry(
        edinet_code='E27641',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000正治',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27646': EdinetCodeEntry(
        edinet_code='E27646',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=103365,
        fiscal_year_end='12月31日',
        submitter_name='ビーポスト・エスエー／エヌヴィー',
        submitter_name_en=None,
        submitter_name_yomi='ビーポストエスエーエヌヴィー',
        address='ベルギー王国\u3000１０００\u3000ブリュッセル\u3000サントル\u3000モネ－マンサントラン',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27651': EdinetCodeEntry(
        edinet_code='E27651',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='倉田\u3000陽一郎',
        submitter_name_en=None,
        submitter_name_yomi='クラタ\u3000ヨウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27652': EdinetCodeEntry(
        edinet_code='E27652',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=141951,
        fiscal_year_end=None,
        submitter_name='星野リゾート・リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ホシノリゾートリートトウシホウジン',
        address='中央区銀座一丁目１０番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005020156',
    ),
    'E27653': EdinetCodeEntry(
        edinet_code='E27653',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='レン・イー・ハン',
        submitter_name_en=None,
        submitter_name_yomi='レン\u3000イー\u3000ハン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27655': EdinetCodeEntry(
        edinet_code='E27655',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デジタルハーツホールディングス',
        submitter_name_en='DIGITAL HEARTS HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャデジタルハーツホールディングス',
        address='新宿区西新宿三丁目２０番２号',
        industry='サービス業',
        sec_code='36760',
        corporate_number='1010401108134',
    ),
    'E27665': EdinetCodeEntry(
        edinet_code='E27665',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65,
        fiscal_year_end=None,
        submitter_name='ブロード・ピーク・インベストメント・アドバイザーズ・ピーティイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ブロード\u3000ピーク\u3000インベストメント\u3000アドバイザーズ\u3000ピーティイー\u3000リミテッド',
        address='シンガポール\u3000２３８８５５、オーチャード・ロード２６０、ザ・ヒーレン＃１４－０２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27669': EdinetCodeEntry(
        edinet_code='E27669',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2421307,
        fiscal_year_end='12月31日',
        submitter_name='ザ・ホンコン・アンド・シャンハイ・バンキング・コーポレイション・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ザホンコンアンドシャンハイバンキングコーポレイションリミテッド',
        address='香港、クイーンズ・ロード・セントラル１番',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27671': EdinetCodeEntry(
        edinet_code='E27671',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5500,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＩＪＴＴ',
        submitter_name_en='IJTT Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアイジェイティティ',
        address='横浜市神奈川区金港町１番地７',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='3010401108149',
    ),
    'E27674': EdinetCodeEntry(
        edinet_code='E27674',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ティーワン',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャティーワン',
        address='広島市西区己斐本町一丁目２１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7240002010751',
    ),
    'E27677': EdinetCodeEntry(
        edinet_code='E27677',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='牛田\u3000幸吉',
        submitter_name_en=None,
        submitter_name_yomi='ウシダ\u3000コウキチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27678': EdinetCodeEntry(
        edinet_code='E27678',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺田\u3000俊彦',
        submitter_name_en=None,
        submitter_name_yomi='テラダ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27680': EdinetCodeEntry(
        edinet_code='E27680',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西里\u3000弘一',
        submitter_name_en=None,
        submitter_name_yomi='ニシザト\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27693': EdinetCodeEntry(
        edinet_code='E27693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6110,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ネクステージ',
        submitter_name_en='NEXTAGE Co., Ltd.',
        submitter_name_yomi='カブシキガイシャネクステージ',
        address='名古屋市中区新栄町一丁目１番地',
        industry='小売業',
        sec_code='31860',
        corporate_number='3180001067712',
    ),
    'E27699': EdinetCodeEntry(
        edinet_code='E27699',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21329,
        fiscal_year_end=None,
        submitter_name='Ｆａｒａｌｌｏｎ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000Ｌ．Ｌ．Ｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ファラロンキャピタルマネージメントエルエルシー',
        address='米国カリフォルニア州９４１１１、サンフランシスコ、ワン・マリタイム・プラザ、スイート２１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27703': EdinetCodeEntry(
        edinet_code='E27703',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横田\u3000博',
        submitter_name_en=None,
        submitter_name_yomi='ヨコタ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27704': EdinetCodeEntry(
        edinet_code='E27704',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三浦\u3000眞理夫',
        submitter_name_en=None,
        submitter_name_yomi='ミウラ\u3000マリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27706': EdinetCodeEntry(
        edinet_code='E27706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横田\u3000義之',
        submitter_name_en=None,
        submitter_name_yomi='ヨコタ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27723': EdinetCodeEntry(
        edinet_code='E27723',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社Ｎ・フィールド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌフィールド',
        address='大阪市北区堂島浜一丁目４番４号アクア堂島東館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001103529',
    ),
    'E27724': EdinetCodeEntry(
        edinet_code='E27724',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土肥\u3000雄治',
        submitter_name_en=None,
        submitter_name_yomi='ドヒ\u3000ユウジ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27725': EdinetCodeEntry(
        edinet_code='E27725',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土肥\u3000智雄',
        submitter_name_en=None,
        submitter_name_yomi='ドヒ\u3000トモオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27736': EdinetCodeEntry(
        edinet_code='E27736',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ベイビュー・アセット・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ベイビューアセットマネジメントカブシキカイシャ',
        address='千代田区一番町２９－１\u3000番町ハウス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001026748',
    ),
    'E27739': EdinetCodeEntry(
        edinet_code='E27739',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=585,
        fiscal_year_end=None,
        submitter_name='ポーラー・キャピタル・エル・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='ポーラーキャピタルエルエルピー',
        address='ロンドン、ＳＷ１Ｅ\u3000５ＪＤ、パレス\u3000ストリート１６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27743': EdinetCodeEntry(
        edinet_code='E27743',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='有限会社松永榮一',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャマツナガエイイチ',
        address='横浜市青葉区柿の木台３５番地９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010402036211',
    ),
    'E27747': EdinetCodeEntry(
        edinet_code='E27747',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='コーアツ工業共栄会\u3000理事長\u3000水迫繁一',
        submitter_name_en=None,
        submitter_name_yomi='ミズサコ\u3000シゲイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27754': EdinetCodeEntry(
        edinet_code='E27754',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥村\u3000征照',
        submitter_name_en=None,
        submitter_name_yomi='オクムラ\u3000ユキテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27756': EdinetCodeEntry(
        edinet_code='E27756',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3600,
        fiscal_year_end=None,
        submitter_name='日本コカ・コーラ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンコカコーラカブシキガイシャ',
        address='渋谷区渋谷４丁目６－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001017563',
    ),
    'E27759': EdinetCodeEntry(
        edinet_code='E27759',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月末日',
        submitter_name='飯田グループホールディングス株式会社',
        submitter_name_en='Iida Group Holdings Co., Ltd.',
        submitter_name_yomi='イイダグループホールディングスカブシキガイシャ',
        address='東京都武蔵野市西久保一丁目２番１１号',
        industry='不動産業',
        sec_code='32910',
        corporate_number='2012701012287',
    ),
    'E27761': EdinetCodeEntry(
        edinet_code='E27761',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1299,
        fiscal_year_end='11月末日',
        submitter_name='株式会社アメイズ',
        submitter_name_en='Amaze Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアメイズ',
        address='大分市西鶴崎一丁目７番１７号',
        industry='サービス業',
        sec_code='60760',
        corporate_number='1320001003869',
    ),
    'E27778': EdinetCodeEntry(
        edinet_code='E27778',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='植木\u3000威行',
        submitter_name_en=None,
        submitter_name_yomi='ウエキ\u3000タケユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27796': EdinetCodeEntry(
        edinet_code='E27796',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000昭二',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27798': EdinetCodeEntry(
        edinet_code='E27798',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ワイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワイ',
        address='目黒区目黒一丁目３３号ＢｉｒｄＰａｒｋ＃００６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001094327',
    ),
    'E27799': EdinetCodeEntry(
        edinet_code='E27799',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社大友アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオトモアセットマネジメント',
        address='中央区銀座２丁目５番１８号銀座白井ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001153886',
    ),
    'E27812': EdinetCodeEntry(
        edinet_code='E27812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='広田\u3000靖治',
        submitter_name_en=None,
        submitter_name_yomi='ヒロタ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27815': EdinetCodeEntry(
        edinet_code='E27815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=817,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ミラタップ',
        submitter_name_en='miratap inc.',
        submitter_name_yomi='カブシキガイシャミラタップ',
        address='大阪市北区大深町５番５４号',
        industry='小売業',
        sec_code='31870',
        corporate_number='5120001080628',
    ),
    'E27819': EdinetCodeEntry(
        edinet_code='E27819',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='掛谷\u3000和俊',
        submitter_name_en=None,
        submitter_name_yomi='カケタニ\u3000カズトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27829': EdinetCodeEntry(
        edinet_code='E27829',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000教義',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ノリヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27833': EdinetCodeEntry(
        edinet_code='E27833',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='細谷\u3000可祝',
        submitter_name_en=None,
        submitter_name_yomi='ホソヤ\u3000カシク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27838': EdinetCodeEntry(
        edinet_code='E27838',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1322273,
        fiscal_year_end='12月31日',
        submitter_name='アッヴィ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アッヴィインク',
        address='アメリカ合衆国６００６４イリノイ州ノース・シカゴ、ノース・ウォーキーガン・ロード１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27839': EdinetCodeEntry(
        edinet_code='E27839',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1105,
        fiscal_year_end='12月31日',
        submitter_name='アボット・ラボラトリーズ',
        submitter_name_en=None,
        submitter_name_yomi='アボットラボラトリーズ',
        address='アメリカ合衆国６００６４－６４００イリノイ州アボット・パーク、アボットパークロード１００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E27840': EdinetCodeEntry(
        edinet_code='E27840',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=79,
        fiscal_year_end=None,
        submitter_name='株式会社建材社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケンザイシャ',
        address='芦屋市楠町３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140001000324',
    ),
    'E27842': EdinetCodeEntry(
        edinet_code='E27842',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20235,
        fiscal_year_end='9月30日',
        submitter_name='株式会社オープンハウスグループ',
        submitter_name_en='Open House Group Co., Ltd',
        submitter_name_yomi='カブシキガイシャオープンハウスグループ',
        address='千代田区丸の内２－７－２ＪＰタワー２０階',
        industry='不動産業',
        sec_code='32880',
        corporate_number='5011001028165',
    ),
    'E27846': EdinetCodeEntry(
        edinet_code='E27846',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有本\u3000達也',
        submitter_name_en=None,
        submitter_name_yomi='アリモト\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27851': EdinetCodeEntry(
        edinet_code='E27851',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000肇',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27852': EdinetCodeEntry(
        edinet_code='E27852',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山岡\u3000新太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマオカ\u3000シンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27855': EdinetCodeEntry(
        edinet_code='E27855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=992,
        fiscal_year_end='5月31日',
        submitter_name='ＥＲＩホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イーアールアイホールディングスカブシキガイシャ',
        address='港区赤坂８－１０－２４',
        industry='サービス業',
        sec_code='60830',
        corporate_number='4010401109146',
    ),
    'E27862': EdinetCodeEntry(
        edinet_code='E27862',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人渋谷育英会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンシブヤイクエイカイ',
        address='福山市東深津町四丁目２０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8240005007769',
    ),
    'E27867': EdinetCodeEntry(
        edinet_code='E27867',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ライラック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャライラック',
        address='大阪市北区梅田１丁目３－１－７００',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001097729',
    ),
    'E27868': EdinetCodeEntry(
        edinet_code='E27868',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1524,
        fiscal_year_end='6月30日',
        submitter_name='株式会社エンビプロ・ホールディングス',
        submitter_name_en='ENVIPRO HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャエンビプロホールディングス',
        address='富士宮市山宮３５０７番地の１９',
        industry='鉄鋼',
        sec_code='56980',
        corporate_number='4080101012395',
    ),
    'E27869': EdinetCodeEntry(
        edinet_code='E27869',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='穴見\u3000賢一',
        submitter_name_en=None,
        submitter_name_yomi='アナミ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27870': EdinetCodeEntry(
        edinet_code='E27870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='穴見\u3000保雄',
        submitter_name_en=None,
        submitter_name_yomi='アナミ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27871': EdinetCodeEntry(
        edinet_code='E27871',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='穴見\u3000加代',
        submitter_name_en=None,
        submitter_name_yomi='アナミ\u3000カヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27873': EdinetCodeEntry(
        edinet_code='E27873',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＨＩＢＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチアイビーシーカブシキカイシャ',
        address='千代田区九段南四丁目２番１１号\u3000アビスタ市ヶ谷ビル２階Ｃ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401081082',
    ),
    'E27877': EdinetCodeEntry(
        edinet_code='E27877',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=502,
        fiscal_year_end='9月30日',
        submitter_name='株式会社システム情報',
        submitter_name_en='SYSTEM INFORMATION CO.,LTD',
        submitter_name_yomi='カブシキガイシャシステムジョウホウ',
        address='中央区勝どき１丁目７番３号\u3000勝どきサンスクェア７階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3010001003551',
    ),
    'E27884': EdinetCodeEntry(
        edinet_code='E27884',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=59164,
        fiscal_year_end=None,
        submitter_name='Ｏｎｅリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ワンリートトウシホウジン',
        address='千代田区大手町一丁目５番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005021096',
    ),
    'E27889': EdinetCodeEntry(
        edinet_code='E27889',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野口\u3000和輝',
        submitter_name_en=None,
        submitter_name_yomi='ノグチ\u3000カズテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27894': EdinetCodeEntry(
        edinet_code='E27894',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=389,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ショーケース',
        submitter_name_en='Showcase Inc.',
        submitter_name_yomi='カブシキガイシャショーケース',
        address='港区六本木一丁目９番９号',
        industry='サービス業',
        sec_code='39090',
        corporate_number='2010401036607',
    ),
    'E27900': EdinetCodeEntry(
        edinet_code='E27900',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エナリス',
        submitter_name_en='ENERES Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャエナリス',
        address='千代田区神田駿河台二丁目５番地１\u3000御茶ノ水ファーストビル',
        industry='サービス業',
        sec_code=None,
        corporate_number='9011801020788',
    ),
    'E27907': EdinetCodeEntry(
        edinet_code='E27907',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松原\u3000春男',
        submitter_name_en=None,
        submitter_name_yomi='マツバラ\u3000ハルオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27910': EdinetCodeEntry(
        edinet_code='E27910',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社アドメテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアドメテック',
        address='松山市空港通１丁目８番１６号\u3000えざき本社ビル\u3000５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5500001005265',
    ),
    'E27912': EdinetCodeEntry(
        edinet_code='E27912',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000悟',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27913': EdinetCodeEntry(
        edinet_code='E27913',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='十亀\u3000洋三',
        submitter_name_en=None,
        submitter_name_yomi='ソガメ\u3000ヨウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27917': EdinetCodeEntry(
        edinet_code='E27917',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=231,
        fiscal_year_end=None,
        submitter_name='ファイブスター投信投資顧問株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ファイブスタートウシントウシコモンカブシキガイシャ',
        address='中央区入船一丁目２番９号\u3000八丁堀ＭＦビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001124760',
    ),
    'E27919': EdinetCodeEntry(
        edinet_code='E27919',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荒井\u3000正昭',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27921': EdinetCodeEntry(
        edinet_code='E27921',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=62,
        fiscal_year_end=None,
        submitter_name='グローバル・ファンズ・トラスト・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='グローバル\u3000ファンズ\u3000トラスト\u3000カンパニー',
        address='ケイマン諸島、ＫＹ１―１１０４、グランド・ケイマン、ジョージ・タウン、サウスチャーチ・ストリート、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27923': EdinetCodeEntry(
        edinet_code='E27923',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平松\u3000裕将',
        submitter_name_en=None,
        submitter_name_yomi='ヒラマツ\u3000ヒロマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27929': EdinetCodeEntry(
        edinet_code='E27929',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='カンロ共栄会\u3000理事長\u3000小林\u3000米治郎',
        submitter_name_en=None,
        submitter_name_yomi='カンロキョウエイカイ\u3000リジチョウ\u3000コバヤシ\u3000ヨネジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27932': EdinetCodeEntry(
        edinet_code='E27932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27934': EdinetCodeEntry(
        edinet_code='E27934',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐野\u3000文勝',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000フミカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27936': EdinetCodeEntry(
        edinet_code='E27936',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐野\u3000富和',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000トミカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27938': EdinetCodeEntry(
        edinet_code='E27938',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山根\u3000知子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマネ\u3000トモコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E27948': EdinetCodeEntry(
        edinet_code='E27948',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社ケイエムエフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャケイエムエフ',
        address='横浜市中区北仲通５－５７－２－２８０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001022936',
    ),
    'E27955': EdinetCodeEntry(
        edinet_code='E27955',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='越智\u3000勝寛',
        submitter_name_en=None,
        submitter_name_yomi='オチ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30002': EdinetCodeEntry(
        edinet_code='E30002',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5909,
        fiscal_year_end='2月末日',
        submitter_name='株式会社メディアドゥ',
        submitter_name_en='MEDIA DO Co., Ltd.',
        submitter_name_yomi='カブシキガイシャメディアドゥ',
        address='千代田区一ツ橋一丁目１番１号',
        industry='情報・通信業',
        sec_code='36780',
        corporate_number='2180001047905',
    ),
    'E30005': EdinetCodeEntry(
        edinet_code='E30005',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=59181,
        fiscal_year_end='3月末日',
        submitter_name='ヴェダンタ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ヴェダンタリミテッド',
        address='インド共和国、マハラシュトラ州４０００９３、ムンバイ市、アンデリー（東）、チャカラ、アトゥール・プロジェクツ、コーポレート・アベニュー、ユニット１０３、Ｃウィング、１階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E30006': EdinetCodeEntry(
        edinet_code='E30006',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三宅\u3000孝彦',
        submitter_name_en=None,
        submitter_name_yomi='ミヤケ\u3000タカヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30010': EdinetCodeEntry(
        edinet_code='E30010',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2363,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ビジョン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビジョン',
        address='新宿区西新宿六丁目５番１号',
        industry='情報・通信業',
        sec_code='94160',
        corporate_number='9011101033243',
    ),
    'E30012': EdinetCodeEntry(
        edinet_code='E30012',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ウチヤマ・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャウチヤマインターナショナル',
        address='大阪市北区梅田一丁目１番３－９１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120901001132',
    ),
    'E30019': EdinetCodeEntry(
        edinet_code='E30019',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1613,
        fiscal_year_end=None,
        submitter_name='バターフィールド・バンク（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バターフィールドバンクケイマンリミテッド',
        address='ケイマン諸島、ＫＹ１‐１１０７、グランド・ケイマン、私書箱７０５、フォート・ストリート６８、バターフィールド・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30020': EdinetCodeEntry(
        edinet_code='E30020',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1553,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ＡＮＡＰホールディングス',
        submitter_name_en='ANAP HOLDINGS INC.',
        submitter_name_yomi='カブシキカイシャアナップホールディングス',
        address='港区南青山四丁目２０番１９号',
        industry='小売業',
        sec_code='31890',
        corporate_number='4011001003243',
    ),
    'E30022': EdinetCodeEntry(
        edinet_code='E30022',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2893,
        fiscal_year_end='9月30日',
        submitter_name='Ｍ＆Ａキャピタルパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムアンドエーキャピタルパートナーズカブシキカイシャ',
        address='中央区八重洲二丁目２番１号',
        industry='サービス業',
        sec_code='60800',
        corporate_number='3010001107385',
    ),
    'E30024': EdinetCodeEntry(
        edinet_code='E30024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='有限会社Ｂｅｎｒｉ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャベンリ',
        address='名古屋市瑞穂区大喜町３－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180002059205',
    ),
    'E30034': EdinetCodeEntry(
        edinet_code='E30034',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松永\u3000諭',
        submitter_name_en=None,
        submitter_name_yomi='マツナガ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30037': EdinetCodeEntry(
        edinet_code='E30037',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=87550,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＳＭＢＣ信託銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスエムビーシーシンタクギンコウ',
        address='千代田区丸の内一丁目３番２号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1010401017640',
    ),
    'E30042': EdinetCodeEntry(
        edinet_code='E30042',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=400,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ウエスコホールディングス',
        submitter_name_en='Wesco Holdings Inc.',
        submitter_name_yomi='カブシキガイシャウエスコホールディングス',
        address='岡山市北区島田本町２丁目５番３５号',
        industry='サービス業',
        sec_code='60910',
        corporate_number='6260001026756',
    ),
    'E30047': EdinetCodeEntry(
        edinet_code='E30047',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2508,
        fiscal_year_end='3月31日',
        submitter_name='株式会社じげん',
        submitter_name_en='ZIGExN Co., Ltd.',
        submitter_name_yomi='カブシキガイシャジゲン',
        address='港区虎ノ門三丁目４番８号',
        industry='情報・通信業',
        sec_code='36790',
        corporate_number='2010401098688',
    ),
    'E30048': EdinetCodeEntry(
        edinet_code='E30048',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8000,
        fiscal_year_end='12月末日',
        submitter_name='Ｋ＆Ｏエナジーグループ株式会社',
        submitter_name_en='K&O Energy Group Inc.',
        submitter_name_yomi='ケイアンドオーエナジーグループカブシキカイシャ',
        address='茂原市茂原６６１番地',
        industry='鉱業',
        sec_code='16630',
        corporate_number='4010001157909',
    ),
    'E30053': EdinetCodeEntry(
        edinet_code='E30053',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=831,
        fiscal_year_end='12月末日',
        submitter_name='アライドアーキテクツ株式会社',
        submitter_name_en='Allied Architects, Inc.',
        submitter_name_yomi='アライドアーキテクツカブシキガイシャ',
        address='渋谷区恵比寿一丁目１９番１５号ウノサワ東急ビル',
        industry='サービス業',
        sec_code='60810',
        corporate_number='5011001045516',
    ),
    'E30054': EdinetCodeEntry(
        edinet_code='E30054',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000美智雄',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30058': EdinetCodeEntry(
        edinet_code='E30058',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2744,
        fiscal_year_end='12月31日',
        submitter_name='オンコリスバイオファーマ株式会社',
        submitter_name_en='Oncolys BioPharma Inc.',
        submitter_name_yomi='オンコリスバイオファーマカブシキカイシャ',
        address='港区虎ノ門４－１－２８虎ノ門タワーズオフィス１０階',
        industry='医薬品',
        sec_code='45880',
        corporate_number='4010401053237',
    ),
    'E30060': EdinetCodeEntry(
        edinet_code='E30060',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社中島董商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナカシマトウショウテン',
        address='渋谷区渋谷１－４－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001016726',
    ),
    'E30062': EdinetCodeEntry(
        edinet_code='E30062',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤本\u3000太一',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000タイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30064': EdinetCodeEntry(
        edinet_code='E30064',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=229484,
        fiscal_year_end=None,
        submitter_name='イオンリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='イオンリートトウシホウジン',
        address='千代田区内神田一丁目１４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005019820',
    ),
    'E30065': EdinetCodeEntry(
        edinet_code='E30065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=863,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ライドオンエクスプレスホールディングス',
        submitter_name_en='RIDE ON EXPRESS  HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャライドオンエクスプレスホールディングス',
        address='港区三田三丁目５番２７号',
        industry='サービス業',
        sec_code='60820',
        corporate_number='2010401067115',
    ),
    'E30066': EdinetCodeEntry(
        edinet_code='E30066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=596,
        fiscal_year_end='3月末日',
        submitter_name='アズマハウス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アズマハウスカブシキガイシャ',
        address='和歌山県和歌山市黒田１丁目２番１７号',
        industry='不動産業',
        sec_code='32930',
        corporate_number='1170001000122',
    ),
    'E30071': EdinetCodeEntry(
        edinet_code='E30071',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1487,
        fiscal_year_end='6月30日',
        submitter_name='ヒューマン・メタボローム・テクノロジーズ株式会社',
        submitter_name_en='Human Metabolome Technologies, Inc.',
        submitter_name_yomi='ヒューマンメタボロームテクノロジーズカブシキガイシャ',
        address='鶴岡市覚岸寺字水上２４６番地２',
        industry='サービス業',
        sec_code='60900',
        corporate_number='5390001008172',
    ),
    'E30078': EdinetCodeEntry(
        edinet_code='E30078',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000純子',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ジュンコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30085': EdinetCodeEntry(
        edinet_code='E30085',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=489,
        fiscal_year_end='3月末日',
        submitter_name='エンカレッジ・テクノロジ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンカレッジテクノロジカブシキカイシャ',
        address='中央区日本橋浜町三丁目３番２号',
        industry='情報・通信業',
        sec_code='36820',
        corporate_number='4010001084285',
    ),
    'E30091': EdinetCodeEntry(
        edinet_code='E30091',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ホットリンク',
        submitter_name_en='Hotto Link Inc.',
        submitter_name_yomi='カブシキガイシャホットリンク',
        address='千代田区富士見１－３－１１',
        industry='サービス業',
        sec_code='36800',
        corporate_number='6010001104149',
    ),
    'E30100': EdinetCodeEntry(
        edinet_code='E30100',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社なにわ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナニワ',
        address='新宿区大久保２丁目２１番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101058414',
    ),
    'E30103': EdinetCodeEntry(
        edinet_code='E30103',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=117495,
        fiscal_year_end='3月31日',
        submitter_name='株式会社めぶきフィナンシャルグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメブキフィナンシャルグループ',
        address='中央区日本橋室町二丁目１番１号',
        industry='銀行業',
        sec_code='71670',
        corporate_number='1060001007582',
    ),
    'E30108': EdinetCodeEntry(
        edinet_code='E30108',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='王子マネジメントオフィス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オウジマネジメントオフィスカブシキガイシャ',
        address='中央区銀座四丁目７番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001146304',
    ),
    'E30109': EdinetCodeEntry(
        edinet_code='E30109',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=600,
        fiscal_year_end=None,
        submitter_name='王子マテリア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オウジマテリアカブシキガイシャ',
        address='中央区銀座５－１２－８王子ホールディングス１号館６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001074355',
    ),
    'E30114': EdinetCodeEntry(
        edinet_code='E30114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3451,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ブイキューブ',
        submitter_name_en='V-cube, Inc.',
        submitter_name_yomi='カブシキガイシャブイキューブ',
        address='港区白金一丁目１７番３号',
        industry='情報・通信業',
        sec_code='36810',
        corporate_number='8013201010775',
    ),
    'E30118': EdinetCodeEntry(
        edinet_code='E30118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='ＣＹＢＥＲＤＹＮＥ株式会社',
        submitter_name_en='CYBERDYNE Inc.',
        submitter_name_yomi='サイバーダインカブシキガイシャ',
        address='つくば市学園南二丁目２番地１',
        industry='精密機器',
        sec_code='77790',
        corporate_number='8050001016537',
    ),
    'E30119': EdinetCodeEntry(
        edinet_code='E30119',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=872,
        fiscal_year_end='3月末日',
        submitter_name='アーキテクツ・スタジオ・ジャパン株式会社',
        submitter_name_en='ARCHITECTS STUDIO JAPAN INC.',
        submitter_name_yomi='アーキテクツスタジオジャパンカブシキガイシャ',
        address='千代田区丸の内三丁目４番２号',
        industry='サービス業',
        sec_code='60850',
        corporate_number='7010401074016',
    ),
    'E30120': EdinetCodeEntry(
        edinet_code='E30120',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=233,
        fiscal_year_end='2月末日',
        submitter_name='シンメンテホールディングス株式会社',
        submitter_name_en='Shin Maint Holdings Co.,Ltd.',
        submitter_name_yomi='シンメンテホールディングスカブシキガイシャ',
        address='品川区東大井二丁目１３番８号',
        industry='サービス業',
        sec_code='60860',
        corporate_number='3010701013924',
    ),
    'E30124': EdinetCodeEntry(
        edinet_code='E30124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=836,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イーグランド',
        submitter_name_en="e'grand Co.,Ltd",
        submitter_name_yomi='カブシキガイシャイーグランド',
        address='千代田区神田美土代町１番地',
        industry='不動産業',
        sec_code='32940',
        corporate_number='9010001084487',
    ),
    'E30125': EdinetCodeEntry(
        edinet_code='E30125',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大部\u3000仁',
        submitter_name_en=None,
        submitter_name_yomi='オオブ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30126': EdinetCodeEntry(
        edinet_code='E30126',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1903,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本アクア',
        submitter_name_en='Nippon Aqua Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニホンアクア',
        address='港区港南二丁目１６番２号',
        industry='建設業',
        sec_code='14290',
        corporate_number='4020001061696',
    ),
    'E30127': EdinetCodeEntry(
        edinet_code='E30127',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=158,
        fiscal_year_end=None,
        submitter_name='徳威国際発展有限公司',
        submitter_name_en=None,
        submitter_name_yomi='トクイコクサイハッテンユウゲンコウシ',
        address='香港千諾道西８－１４号\u3000嘉安ビルディング２ＦＪ室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30130': EdinetCodeEntry(
        edinet_code='E30130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シグマクシス・ホールディングス',
        submitter_name_en='SIGMAXYZ Holdings Inc.',
        submitter_name_yomi='カブシキカイシャシグマクシスホールディングス',
        address='港区虎ノ門四丁目１番２８号',
        industry='サービス業',
        sec_code='60880',
        corporate_number='6010401075873',
    ),
    'E30133': EdinetCodeEntry(
        edinet_code='E30133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2554,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ダイキアクシス',
        submitter_name_en='Daiki Axis Co.,Ltd',
        submitter_name_yomi='カブシキガイシャダイキアクシス',
        address='松山市美沢一丁目９番１号',
        industry='その他製品',
        sec_code='42450',
        corporate_number='4500001005530',
    ),
    'E30135': EdinetCodeEntry(
        edinet_code='E30135',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000進也',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30138': EdinetCodeEntry(
        edinet_code='E30138',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＨＭＯＴＯホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオモトホールディングス',
        address='岡山市北区内山下１丁目１番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5260002008317',
    ),
    'E30140': EdinetCodeEntry(
        edinet_code='E30140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2187,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ウィルグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウィルグループ',
        address='中野区本町１－３２－２',
        industry='サービス業',
        sec_code='60890',
        corporate_number='9011001061435',
    ),
    'E30143': EdinetCodeEntry(
        edinet_code='E30143',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐野\u3000公彦',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000キミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30144': EdinetCodeEntry(
        edinet_code='E30144',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='エーシージー・マネージメント・プライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エーシージー\u3000マネージメント\u3000プライベート\u3000リミテッド',
        address='シンガポール\u3000トリプルワンサマセット\u3000＃０６－１９\u3000サマセット・ロード１１１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30145': EdinetCodeEntry(
        edinet_code='E30145',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社トリプルＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトリプルエー',
        address='千代田区神田神保町一丁目３５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001150519',
    ),
    'E30148': EdinetCodeEntry(
        edinet_code='E30148',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='弘鈴興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウレイコウサンカブシキカイシャ',
        address='守口市東郷通１－２－１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001173536',
    ),
    'E30155': EdinetCodeEntry(
        edinet_code='E30155',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ベストプランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベストプランニング',
        address='瑞穂市穂積１１０７番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2200001027540',
    ),
    'E30157': EdinetCodeEntry(
        edinet_code='E30157',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊ河本株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイカワモトカブシキガイシャ',
        address='白岡市新白岡一丁目６番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6030001098785',
    ),
    'E30158': EdinetCodeEntry(
        edinet_code='E30158',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ＫＡＷＡＭＯＴＯ\u3000ＣＭＫ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カワモト\u3000シーエムケイカブシキガイシャ',
        address='目黒区青葉台一丁目４番７－６０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001097068',
    ),
    'E30160': EdinetCodeEntry(
        edinet_code='E30160',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社プランニングセンター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプランニングセンター',
        address='千代田区神田神保町一丁目３５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001030796',
    ),
    'E30161': EdinetCodeEntry(
        edinet_code='E30161',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社エム・エム・ヨーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムエムヨーク',
        address='港区虎ノ門四丁目１番３４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401068814',
    ),
    'E30164': EdinetCodeEntry(
        edinet_code='E30164',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='6月30日',
        submitter_name='株式会社日本能率協会マネジメントセンター',
        submitter_name_en='JMA Management Center Inc.',
        submitter_name_yomi='ニホンノウリツキョウカイマネジメントセンター',
        address='中央区日本橋二丁目７番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010401023056',
    ),
    'E30167': EdinetCodeEntry(
        edinet_code='E30167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000恭嗣',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30173': EdinetCodeEntry(
        edinet_code='E30173',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='6月末日',
        submitter_name='株式会社渡神',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトカミ',
        address='福岡市中央区荒戸三丁目３番１９号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7290001061394',
    ),
    'E30181': EdinetCodeEntry(
        edinet_code='E30181',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000清久',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000キヨヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30184': EdinetCodeEntry(
        edinet_code='E30184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅田\u3000源',
        submitter_name_en=None,
        submitter_name_yomi='ウメダ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30188': EdinetCodeEntry(
        edinet_code='E30188',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社エーエヌホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーエヌホールディングス',
        address='千代田区丸の内三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001156497',
    ),
    'E30189': EdinetCodeEntry(
        edinet_code='E30189',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='間下\u3000直晃',
        submitter_name_en=None,
        submitter_name_yomi='マシタ\u3000ナオアキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30200': EdinetCodeEntry(
        edinet_code='E30200',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6694,
        fiscal_year_end='12月31日',
        submitter_name='モンクレール・エスピーエー',
        submitter_name_en=None,
        submitter_name_yomi='モンクレールエスピーエー',
        address='イタリア、ミラノ２０１４４、エリンコ・ステンダール通り４７',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E30201': EdinetCodeEntry(
        edinet_code='E30201',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000壮秀',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000マサヒデ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30202': EdinetCodeEntry(
        edinet_code='E30202',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松尾\u3000幸一郎',
        submitter_name_en=None,
        submitter_name_yomi='マツオ\u3000コウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30217': EdinetCodeEntry(
        edinet_code='E30217',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='長堀クリエイト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナガホリクリエイトカブシキカイシャ',
        address='文京区湯島２－３０ー１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001156594',
    ),
    'E30219': EdinetCodeEntry(
        edinet_code='E30219',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='家髙\u3000利康',
        submitter_name_en=None,
        submitter_name_yomi='ヤタカ\u3000トシヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30220': EdinetCodeEntry(
        edinet_code='E30220',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000篤三',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000アツゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30225': EdinetCodeEntry(
        edinet_code='E30225',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平尾丈',
        submitter_name_en=None,
        submitter_name_yomi='ヒラオジョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30233': EdinetCodeEntry(
        edinet_code='E30233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丸山\u3000雄平',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ユウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30243': EdinetCodeEntry(
        edinet_code='E30243',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中北\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='ナカキタ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30257': EdinetCodeEntry(
        edinet_code='E30257',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000一憲',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000カズノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30267': EdinetCodeEntry(
        edinet_code='E30267',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃｏｒｎｗａｌｌ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='コーンウォールキャピタルマネジメントエルピー',
        address='１３４５\u3000Ａｖｅｎｕｅ\u3000ｏｆ\u3000ｔｈｅ\u3000Ａｍｅｒｉｃａｓ；\u3000２ｎｄ\u3000Ｆｌｏｏｒ，\u3000Ｎｅｗ\u3000Ｙｏｒｋ，\u3000ＮＹ\u3000１０１０５\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30278': EdinetCodeEntry(
        edinet_code='E30278',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000憲昌',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000ノリマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30287': EdinetCodeEntry(
        edinet_code='E30287',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内藤\u3000秀雄',
        submitter_name_en=None,
        submitter_name_yomi='ナイトウ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30291': EdinetCodeEntry(
        edinet_code='E30291',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='ヒューリックリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ヒューリックリートトウシホウジン',
        address='千代田区神田駿河台二丁目３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005021694',
    ),
    'E30293': EdinetCodeEntry(
        edinet_code='E30293',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江見\u3000朗',
        submitter_name_en=None,
        submitter_name_yomi='エミ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30299': EdinetCodeEntry(
        edinet_code='E30299',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クラフト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャクラフト',
        address='品川区西五反田八丁目１番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401109153',
    ),
    'E30302': EdinetCodeEntry(
        edinet_code='E30302',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='左右田\u3000稔',
        submitter_name_en=None,
        submitter_name_yomi='ソウダ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30303': EdinetCodeEntry(
        edinet_code='E30303',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社東名商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトウメイショウジ',
        address='名古屋市中区丸の内二丁目１番３３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001048407',
    ),
    'E30309': EdinetCodeEntry(
        edinet_code='E30309',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＫエレクトリック・インベストメンツ・マネジャー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エイチケイエレクトリックインベストメンツマネジャーリミテッド',
        address='香港、４４\u3000ケネディ・ロード',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30310': EdinetCodeEntry(
        edinet_code='E30310',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20830,
        fiscal_year_end=None,
        submitter_name='株式会社インテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャインテック',
        address='富山市牛島新町５－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2230001000255',
    ),
    'E30319': EdinetCodeEntry(
        edinet_code='E30319',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山澤\u3000廣',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30343': EdinetCodeEntry(
        edinet_code='E30343',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='矢島\u3000婦美子',
        submitter_name_en=None,
        submitter_name_yomi='ヤジマ\u3000フミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30344': EdinetCodeEntry(
        edinet_code='E30344',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='矢島\u3000さやか',
        submitter_name_en=None,
        submitter_name_yomi='ヤジマ\u3000サヤカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30345': EdinetCodeEntry(
        edinet_code='E30345',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野村\u3000しのぶ',
        submitter_name_en=None,
        submitter_name_yomi='ノムラ\u3000シノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30348': EdinetCodeEntry(
        edinet_code='E30348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=59,
        fiscal_year_end=None,
        submitter_name='株式会社オイエコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャオイエコーポレーション',
        address='吹田市高野台五丁目４番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120902005606',
    ),
    'E30354': EdinetCodeEntry(
        edinet_code='E30354',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ジュエルソース・ジャパン・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジュエルソースジャパンホールディングスカブシキガイシャ',
        address='横浜市神奈川区鶴屋町三丁目３３番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010501031601',
    ),
    'E30355': EdinetCodeEntry(
        edinet_code='E30355',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江口\u3000久',
        submitter_name_en=None,
        submitter_name_yomi='エグチ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30365': EdinetCodeEntry(
        edinet_code='E30365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='東\u3000行男',
        submitter_name_en=None,
        submitter_name_yomi='アズマ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30371': EdinetCodeEntry(
        edinet_code='E30371',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000和子',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000カズコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30387': EdinetCodeEntry(
        edinet_code='E30387',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社池田企画事務所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイケダキカクジムショ',
        address='港区南麻布三丁目５番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010701025606',
    ),
    'E30389': EdinetCodeEntry(
        edinet_code='E30389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000良介',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30390': EdinetCodeEntry(
        edinet_code='E30390',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大原\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='オオハラ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30391': EdinetCodeEntry(
        edinet_code='E30391',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='三菱パワー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシパワーカブシキガイシャ',
        address='横浜市西区みなとみらい三丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001101277',
    ),
    'E30394': EdinetCodeEntry(
        edinet_code='E30394',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000文隆',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000フミタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30398': EdinetCodeEntry(
        edinet_code='E30398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=883,
        fiscal_year_end='12月末日',
        submitter_name='株式会社サイバーリンクス',
        submitter_name_en='CYBERLINKS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャサイバーリンクス',
        address='和歌山市紀三井寺８４９番地の３',
        industry='情報・通信業',
        sec_code='36830',
        corporate_number='3170001001614',
    ),
    'E30401': EdinetCodeEntry(
        edinet_code='E30401',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3264,
        fiscal_year_end='12月31日',
        submitter_name='アキュセラ・インク（Ａｃｕｃｅｌａ\u3000Ｉｎｃ．）',
        submitter_name_en=None,
        submitter_name_yomi='アキュセラインク',
        address='アメリカ合衆国、９８１０１ワシントン州、シアトル市、セカンド・アベニュー１３０１、スイート４２００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E30407': EdinetCodeEntry(
        edinet_code='E30407',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=77,
        fiscal_year_end=None,
        submitter_name='ＬＩＭ\u3000Ａｄｖｉｓｏｒｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='リム\u3000アドバイザーズ\u3000リミテッド',
        address='香港、セントラル、ダッデル、ストリート１１、ルットンジー・ハウス１９階、１９０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30410': EdinetCodeEntry(
        edinet_code='E30410',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田島\u3000通利',
        submitter_name_en=None,
        submitter_name_yomi='タジマ\u3000ミチトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30414': EdinetCodeEntry(
        edinet_code='E30414',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社新東通信',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシントウツウシン',
        address='名古屋市中区丸の内３－１６－２９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001036792',
    ),
    'E30423': EdinetCodeEntry(
        edinet_code='E30423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000良一',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30425': EdinetCodeEntry(
        edinet_code='E30425',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=70,
        fiscal_year_end=None,
        submitter_name='株式会社研創エンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケンソウエンタープライズ',
        address='広島市安佐北区上深川町４４８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4240001003123',
    ),
    'E30434': EdinetCodeEntry(
        edinet_code='E30434',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大田\u3000昭彦',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30438': EdinetCodeEntry(
        edinet_code='E30438',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5426,
        fiscal_year_end='3月31日',
        submitter_name='ダイキョーニシカワ株式会社',
        submitter_name_en='DaikyoNishikawa Corporation',
        submitter_name_yomi='ダイキョーニシカワカブシキガイシャ',
        address='東広島市寺家産業団地５番１号',
        industry='化学',
        sec_code='42460',
        corporate_number='3240001036909',
    ),
    'E30440': EdinetCodeEntry(
        edinet_code='E30440',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=450,
        fiscal_year_end=None,
        submitter_name='株式会社ホシ・クリエート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャホシ\u3000クリエート',
        address='港区高輪１丁目２７番３７号\u3000高輪ザ・レジデンス３５０１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401104849',
    ),
    'E30443': EdinetCodeEntry(
        edinet_code='E30443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9117,
        fiscal_year_end='3月末日',
        submitter_name='ＡＺ－ＣＯＭ丸和ホールディングス株式会社',
        submitter_name_en='AZ-COM MARUWA Holdings Inc.',
        submitter_name_yomi='アズコムマルワホールディングスカブシキガイシャ',
        address='吉川市旭７番地１',
        industry='陸運業',
        sec_code='90900',
        corporate_number='8030001065742',
    ),
    'E30445': EdinetCodeEntry(
        edinet_code='E30445',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2325,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エンバイオ・ホールディングス',
        submitter_name_en='EnBio Holdings,Inc',
        submitter_name_yomi='カブシキカイシャエンバイオホールディングス',
        address='千代田区鍛冶町二丁目２番２号',
        industry='サービス業',
        sec_code='60920',
        corporate_number='9010001095930',
    ),
    'E30451': EdinetCodeEntry(
        edinet_code='E30451',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1910,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホットマン',
        submitter_name_en='HOTMAN Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャホットマン',
        address='仙台市太白区西多賀四丁目４番１７号',
        industry='小売業',
        sec_code='31900',
        corporate_number='3370001002204',
    ),
    'E30454': EdinetCodeEntry(
        edinet_code='E30454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4198,
        fiscal_year_end='8月31日',
        submitter_name='日本ＢＳ放送株式会社',
        submitter_name_en='Nippon BS Broadcasting Corporation',
        submitter_name_yomi='ニホンビーエスホウソウカブシキガイシャ',
        address='千代田区神田駿河台二丁目５番地',
        industry='情報・通信業',
        sec_code='94140',
        corporate_number='5010001101469',
    ),
    'E30461': EdinetCodeEntry(
        edinet_code='E30461',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=54,
        fiscal_year_end='9月末日',
        submitter_name='株式会社エニマリ',
        submitter_name_en='anymarry Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエニマリ',
        address='東京都中央区銀座二丁目６ー７',
        industry='サービス業',
        sec_code=None,
        corporate_number='9010001135967',
    ),
    'E30466': EdinetCodeEntry(
        edinet_code='E30466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディー・エル・イー',
        submitter_name_en='DLE Inc.',
        submitter_name_yomi='カブシキガイシヤデイーエルイー',
        address='千代田区麹町三丁目３番地４',
        industry='情報・通信業',
        sec_code='36860',
        corporate_number='6010001084845',
    ),
    'E30474': EdinetCodeEntry(
        edinet_code='E30474',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='トーテックアメニティ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トーテックアメニティカブシキガイシャ',
        address='名古屋市西区名駅二丁目２７番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001038759',
    ),
    'E30475': EdinetCodeEntry(
        edinet_code='E30475',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=147,
        fiscal_year_end=None,
        submitter_name='キルターン・パートナーズ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='キルターンパートナーズエルエルピー',
        address='英国スコットランドＥＨ２\u3000４ＤＦ、エディンバラ、シャーロット・スクエア２２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30476': EdinetCodeEntry(
        edinet_code='E30476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=676,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エスクロー・エージェント・ジャパン',
        submitter_name_en='Escrow Agent Japan ,Inc.',
        submitter_name_yomi='カブシキガイシャエスクローエージェントジャパン',
        address='千代田区大手町二丁目２番１号\u3000新大手町ビル４階',
        industry='サービス業',
        sec_code='60930',
        corporate_number='7010001108108',
    ),
    'E30478': EdinetCodeEntry(
        edinet_code='E30478',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='窪田\u3000良',
        submitter_name_en=None,
        submitter_name_yomi='クボタ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30479': EdinetCodeEntry(
        edinet_code='E30479',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1838,
        fiscal_year_end='3月末日',
        submitter_name='トレックス・セミコンダクター株式会社',
        submitter_name_en='TOREX SEMICONDUCTOR LTD.',
        submitter_name_yomi='トレックスセミコンダクターカブシキガイシャ',
        address='中央区新川一丁目２４番１号',
        industry='電気機器',
        sec_code='66160',
        corporate_number='2010001079907',
    ),
    'E30481': EdinetCodeEntry(
        edinet_code='E30481',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=114362,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ジャパンディスプレイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジャパンディスプレイ',
        address='港区西新橋三丁目７番１号',
        industry='電気機器',
        sec_code='67400',
        corporate_number='6040001059563',
    ),
    'E30482': EdinetCodeEntry(
        edinet_code='E30482',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12269,
        fiscal_year_end=None,
        submitter_name='ＬＳＶ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='エルエスブイアセットマネジメント',
        address='アメリカ合衆国デラウェア州ウィルミントン、リトル・フォールズ・ドライブ２５１、コーポレーション・サービス・カンパニー気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30484': EdinetCodeEntry(
        edinet_code='E30484',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社広島ベンチャーキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒロシマベンチャーキャピタル',
        address='広島市中区銀山町３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5240001009961',
    ),
    'E30487': EdinetCodeEntry(
        edinet_code='E30487',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=392,
        fiscal_year_end=None,
        submitter_name='Ｏｄｅｙ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='オデイアセットマネジメントエルエルピー',
        address='英国、ロンドン、アッパー・ブルック・ストリート１８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30488': EdinetCodeEntry(
        edinet_code='E30488',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=91,
        fiscal_year_end=None,
        submitter_name='京葉住設株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイヨウジュウセツカブシキガイシャ',
        address='船橋市市場３－１７－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2040001026121',
    ),
    'E30494': EdinetCodeEntry(
        edinet_code='E30494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鷹野保雄',
        submitter_name_en=None,
        submitter_name_yomi='タカノヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30496': EdinetCodeEntry(
        edinet_code='E30496',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山崎\u3000由真子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ユマコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30498': EdinetCodeEntry(
        edinet_code='E30498',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000晶子',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30501': EdinetCodeEntry(
        edinet_code='E30501',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=12000,
        fiscal_year_end='6月20日',
        submitter_name='株式会社ジョイフル本田',
        submitter_name_en='JOYFUL HONDA CO.,LTD.',
        submitter_name_yomi='カブシキカイシャジョイフルホンダ',
        address='土浦市富士崎一丁目１６番２号',
        industry='小売業',
        sec_code='31910',
        corporate_number='6050001009303',
    ),
    'E30504': EdinetCodeEntry(
        edinet_code='E30504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1196,
        fiscal_year_end='11月末日',
        submitter_name='株式会社白鳩',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシロハト',
        address='京都市伏見区竹田向代町５０５番地',
        industry='小売業',
        sec_code='31920',
        corporate_number='2130001014736',
    ),
    'E30505': EdinetCodeEntry(
        edinet_code='E30505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村上\u3000恒夫',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000ツネオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30506': EdinetCodeEntry(
        edinet_code='E30506',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22,
        fiscal_year_end=None,
        submitter_name='株式会社サイバーコア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサイバーコア',
        address='和歌山市友田町五丁目４６番地１（１２０２号）',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9170001004207',
    ),
    'E30507': EdinetCodeEntry(
        edinet_code='E30507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=647,
        fiscal_year_end=None,
        submitter_name='三菱商事プラスチック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシショウジプラスチックカブシキガイシャ',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001099942',
    ),
    'E30513': EdinetCodeEntry(
        edinet_code='E30513',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=126515,
        fiscal_year_end=None,
        submitter_name='日本リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンリートトウシホウジン',
        address='港区新橋一丁目１８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005015824',
    ),
    'E30515': EdinetCodeEntry(
        edinet_code='E30515',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=198,
        fiscal_year_end=None,
        submitter_name='Ｔｙｂｏｕｒｎｅ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000（ＨＫ）\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='タイボーン\u3000キャピタル\u3000マネジメント\u3000エイチケー\u3000リミテッド',
        address='香港、コンノートロードセントラル１、エーアイエーセントラル３０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30518': EdinetCodeEntry(
        edinet_code='E30518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000賀一',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30519': EdinetCodeEntry(
        edinet_code='E30519',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西村\u3000実',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30522': EdinetCodeEntry(
        edinet_code='E30522',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='シンフォニー・フィナンシャル・パートナーズ（シンガポール）ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シンフォニーフィナンシャルパートナーズシンガポールピーティーイーリミテッド',
        address='シンガポール\u3000０４８６１９、リパブリック・プラザ、＃２７－０４、ラッフルズ・プレイス９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30523': EdinetCodeEntry(
        edinet_code='E30523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='増野\u3000繁',
        submitter_name_en=None,
        submitter_name_yomi='マスノ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30525': EdinetCodeEntry(
        edinet_code='E30525',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河本\u3000隆雄',
        submitter_name_en=None,
        submitter_name_yomi='コウモト\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30533': EdinetCodeEntry(
        edinet_code='E30533',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=150,
        fiscal_year_end='12月31日',
        submitter_name='ＷＨグループ・リミテッド（萬洲国際有限公司）',
        submitter_name_en=None,
        submitter_name_yomi='ダブリューエイチグループリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ジョージ・タウン、サウス・チャーチ・ストリート、アグランド・ハウス、メイプルズ・コーポレート・サービシズ・リミテッド\u3000私書箱３０９',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E30537': EdinetCodeEntry(
        edinet_code='E30537',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=550,
        fiscal_year_end='9月30日',
        submitter_name='株式会社フィックスターズ',
        submitter_name_en='Fixstars Corporation',
        submitter_name_yomi='カブシキガイシャフィックスターズ',
        address='港区芝浦１丁目１番１号',
        industry='情報・通信業',
        sec_code='36870',
        corporate_number='8010701023423',
    ),
    'E30539': EdinetCodeEntry(
        edinet_code='E30539',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='Ｚ\u3000Ｖｅｎｔｕｒｅ\u3000Ｃａｐｉｔａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼットベンチャーキャピタルカブシキガイシャ',
        address='千代田区紀尾井町１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401101241',
    ),
    'E30540': EdinetCodeEntry(
        edinet_code='E30540',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='椎木\u3000隆太',
        submitter_name_en=None,
        submitter_name_yomi='シイキ\u3000リュウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30543': EdinetCodeEntry(
        edinet_code='E30543',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アスティ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアスティ',
        address='広島市西区商工センター２－１５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7240001017616',
    ),
    'E30545': EdinetCodeEntry(
        edinet_code='E30545',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='荻原\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='オギハラ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30557': EdinetCodeEntry(
        edinet_code='E30557',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='磯川\u3000隆一',
        submitter_name_en=None,
        submitter_name_yomi='イソカワ\u3000タカイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30559': EdinetCodeEntry(
        edinet_code='E30559',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='和佐見\u3000勝',
        submitter_name_en=None,
        submitter_name_yomi='ワサミ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30565': EdinetCodeEntry(
        edinet_code='E30565',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤阪\u3000知之',
        submitter_name_en=None,
        submitter_name_yomi='フジサカ\u3000トモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30567': EdinetCodeEntry(
        edinet_code='E30567',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='アスパラントグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アスパラントグループカブシキカイシャ',
        address='港区赤坂２－２３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401102237',
    ),
    'E30580': EdinetCodeEntry(
        edinet_code='E30580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000隆太',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000リュウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30595': EdinetCodeEntry(
        edinet_code='E30595',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本間英明',
        submitter_name_en=None,
        submitter_name_yomi='ホンマヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30596': EdinetCodeEntry(
        edinet_code='E30596',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社中央グループホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチュウオウグループホールディングス',
        address='北佐久郡軽井沢町大字軽井沢１１３０番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001125535',
    ),
    'E30598': EdinetCodeEntry(
        edinet_code='E30598',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=302,
        fiscal_year_end='5月31日',
        submitter_name='株式会社東武住販',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトウブジュウハン',
        address='下関市岬之町１１番４６号',
        industry='不動産業',
        sec_code='32970',
        corporate_number='2250001005979',
    ),
    'E30601': EdinetCodeEntry(
        edinet_code='E30601',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社テレビ朝日',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテレビアサヒ',
        address='港区六本木６－９－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401108393',
    ),
    'E30609': EdinetCodeEntry(
        edinet_code='E30609',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57,
        fiscal_year_end=None,
        submitter_name='合同会社ユープランニング',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャユープランニング',
        address='大阪市中央区島之内一丁目１０番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120002082021',
    ),
    'E30617': EdinetCodeEntry(
        edinet_code='E30617',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池上\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='イケガミ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30620': EdinetCodeEntry(
        edinet_code='E30620',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='インベスコ・オフィス・ジェイリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='インベスコオフィスジェイリートトウシホウジン',
        address='港区六本木六丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010405012556',
    ),
    'E30627': EdinetCodeEntry(
        edinet_code='E30627',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荻野\u3000利浩',
        submitter_name_en=None,
        submitter_name_yomi='オギノ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30634': EdinetCodeEntry(
        edinet_code='E30634',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木\u3000聡',
        submitter_name_en=None,
        submitter_name_yomi='ミキ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30635': EdinetCodeEntry(
        edinet_code='E30635',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000智彦',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000トモヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30636': EdinetCodeEntry(
        edinet_code='E30636',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='原\u3000行範',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000ユキノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30637': EdinetCodeEntry(
        edinet_code='E30637',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスルクスエクイティシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30640': EdinetCodeEntry(
        edinet_code='E30640',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='株式会社キリン堂ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキリンドウホールディングス',
        address='大阪市淀川区宮原四丁目５番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001185772',
    ),
    'E30643': EdinetCodeEntry(
        edinet_code='E30643',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=94,
        fiscal_year_end=None,
        submitter_name='株式会社三桂製作所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンケイセイサクショ',
        address='大田区下丸子４－２１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010801004386',
    ),
    'E30648': EdinetCodeEntry(
        edinet_code='E30648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3552,
        fiscal_year_end='9月30日',
        submitter_name='株式会社フリークアウト・ホールディングス',
        submitter_name_en='FreakOut Holdings, inc.',
        submitter_name_yomi='カブシキガイシャフリークアウトホールディングス',
        address='港区六本木六丁目３番１号',
        industry='サービス業',
        sec_code='60940',
        corporate_number='2010401092006',
    ),
    'E30649': EdinetCodeEntry(
        edinet_code='E30649',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2552,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ムゲンエステート',
        submitter_name_en='MUGEN ESTATE Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャムゲンエステート',
        address='千代田区大手町一丁目９番７号',
        industry='不動産業',
        sec_code='32990',
        corporate_number='8010001058665',
    ),
    'E30650': EdinetCodeEntry(
        edinet_code='E30650',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2022,
        fiscal_year_end='9月末日',
        submitter_name='メドピア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メドピアカブシキガイシャ',
        address='中央区築地１－１３－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='8011001073431',
    ),
    'E30656': EdinetCodeEntry(
        edinet_code='E30656',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=335,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヨシックスホールディングス',
        submitter_name_en='Yossix Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャヨシックスホールディングス',
        address='名古屋市東区徳川１丁目９番３０号',
        industry='小売業',
        sec_code='32210',
        corporate_number='3180001018582',
    ),
    'E30662': EdinetCodeEntry(
        edinet_code='E30662',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石野\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='イシノ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30664': EdinetCodeEntry(
        edinet_code='E30664',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）ストラテジー・エクストラ・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスルクスストラテジーエクストラシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30667': EdinetCodeEntry(
        edinet_code='E30667',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=124496,
        fiscal_year_end='12月末日',
        submitter_name='スタンダード・チャータード・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='スタンダードチャータードピーエルシー',
        address='連合王国ＥＣ２Ｖ\u3000５ＤＤロンドン市、ベイジング・ホール・アベニュー１番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E30682': EdinetCodeEntry(
        edinet_code='E30682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=612,
        fiscal_year_end='3月31日',
        submitter_name='株式会社レアジョブ',
        submitter_name_en='RareJob, Inc.',
        submitter_name_yomi='カブシキガイシャレアジョブ',
        address='渋谷区神宮前六丁目２７番８号',
        industry='サービス業',
        sec_code='60960',
        corporate_number='8011001064760',
    ),
    'E30688': EdinetCodeEntry(
        edinet_code='E30688',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='東野\u3000哲郎',
        submitter_name_en=None,
        submitter_name_yomi='ヒガシノ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30689': EdinetCodeEntry(
        edinet_code='E30689',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=450,
        fiscal_year_end=None,
        submitter_name='あおぞら投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アオゾラトウシンカブシキガイシャ',
        address='千代田区麹町六丁目１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001158535',
    ),
    'E30690': EdinetCodeEntry(
        edinet_code='E30690',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田島\u3000徹也',
        submitter_name_en=None,
        submitter_name_yomi='タジマ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30692': EdinetCodeEntry(
        edinet_code='E30692',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=179,
        fiscal_year_end='3月31日',
        submitter_name='ポバール興業株式会社',
        submitter_name_en='POVAL KOGYO CO.,LTD.',
        submitter_name_yomi='ポバールコウギョウカブシキカイシャ',
        address='名古屋市中村区野田町字中深３０番地',
        industry='化学',
        sec_code='42470',
        corporate_number='9180001032652',
    ),
    'E30694': EdinetCodeEntry(
        edinet_code='E30694',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河本\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='コウモト\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30695': EdinetCodeEntry(
        edinet_code='E30695',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1829,
        fiscal_year_end=None,
        submitter_name='Ｍａｗｅｒ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='メイワーインベストメントマネジメントリミテッド',
        address='カナダ、アルバータ州、カルガリー、テンス・アベニュー・エス・ダブリュ－５１７、スイート６００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30697': EdinetCodeEntry(
        edinet_code='E30697',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=461,
        fiscal_year_end='12月31日',
        submitter_name='ＯＡＴアグリオ株式会社',
        submitter_name_en='OAT Agrio Co., Ltd.',
        submitter_name_yomi='オウエイティーアグリオカブシキガイシャ',
        address='千代田区神田小川町一丁目３番１号',
        industry='化学',
        sec_code='49790',
        corporate_number='2010001135528',
    ),
    'E30698': EdinetCodeEntry(
        edinet_code='E30698',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=559,
        fiscal_year_end='9月30日',
        submitter_name='株式会社イグニス',
        submitter_name_en='IGNIS LTD.',
        submitter_name_yomi='カブシキガイシャイグニス',
        address='渋谷区恵比寿一丁目１９番１９号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6011001065323',
    ),
    'E30699': EdinetCodeEntry(
        edinet_code='E30699',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1488,
        fiscal_year_end='7月31日',
        submitter_name='株式会社エターナルホスピタリティグループ',
        submitter_name_en='Eternal Hospitality Group Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエターナルホスピタリティグループ',
        address='大阪市浪速区立葉一丁目２番１２号',
        industry='小売業',
        sec_code='31930',
        corporate_number='9120001011711',
    ),
    'E30700': EdinetCodeEntry(
        edinet_code='E30700',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30701': EdinetCodeEntry(
        edinet_code='E30701',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000進一',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30703': EdinetCodeEntry(
        edinet_code='E30703',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=141,
        fiscal_year_end=None,
        submitter_name='マニュライフ・インベストメント・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マニュライフインベストメントマネジメントカブシキカイシャ',
        address='千代田区丸の内１丁目８番１号\u3000丸の内トラストタワーＮ館１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001106942',
    ),
    'E30707': EdinetCodeEntry(
        edinet_code='E30707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='細谷\u3000圭二',
        submitter_name_en=None,
        submitter_name_yomi='ホソヤ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30708': EdinetCodeEntry(
        edinet_code='E30708',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｒ－１合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アールワンゴウドウガイシャ',
        address='中央区日本橋室町３－３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003018148',
    ),
    'E30709': EdinetCodeEntry(
        edinet_code='E30709',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ノザワクリエーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャノザワクリエーション',
        address='新潟県新潟市中央区有明台１番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4110001029791',
    ),
    'E30723': EdinetCodeEntry(
        edinet_code='E30723',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=950,
        fiscal_year_end=None,
        submitter_name='フィリップ証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フィリップショウケンカブシキカイシャ',
        address='中央区日本橋兜町４－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001052923',
    ),
    'E30726': EdinetCodeEntry(
        edinet_code='E30726',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1593,
        fiscal_year_end='10月31日',
        submitter_name='株式会社グッドコムアセット',
        submitter_name_en='Good Com Asset Co., Ltd.',
        submitter_name_yomi='カブシキガイシャグッドコムアセット',
        address='新宿区西新宿七丁目２０番１号住友不動産西新宿ビル',
        industry='不動産業',
        sec_code='34750',
        corporate_number='5011101047222',
    ),
    'E30727': EdinetCodeEntry(
        edinet_code='E30727',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ホワイト\u3000ナイト\u3000インベストメント\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ホワイト\u3000ナイト\u3000インベストメント\u3000リミテッド',
        address='セイシェル共和国、マヘ島、プロビデンス\u3000インダストリアル\u3000エステート、私書箱５０５号、ドゥ\u3000チッポラ通り、ナンバー４ディーイーケーケーハウス１階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30728': EdinetCodeEntry(
        edinet_code='E30728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='フィード・ワン株式会社',
        submitter_name_en='FEED ONE CO.,LTD.',
        submitter_name_yomi='フィードワンカブシキガイシャ',
        address='横浜市西区みなとみらい五丁目１番２号',
        industry='食料品',
        sec_code='20600',
        corporate_number='7020001107810',
    ),
    'E30730': EdinetCodeEntry(
        edinet_code='E30730',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=183,
        fiscal_year_end='3月末日',
        submitter_name='クラウドバンク株式会社',
        submitter_name_en='Crowd Bank Corp.',
        submitter_name_yomi='クラウドバンクカブシキガイシャ',
        address='港区六本木七丁目４番４号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010401114508',
    ),
    'E30731': EdinetCodeEntry(
        edinet_code='E30731',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=65613,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＡＤＯＫＡＷＡ',
        submitter_name_en='KADOKAWA CORPORATION',
        submitter_name_yomi='カブシキガイシャカドカワ',
        address='千代田区富士見二丁目１３番３号',
        industry='情報・通信業',
        sec_code='94680',
        corporate_number='2010001163289',
    ),
    'E30732': EdinetCodeEntry(
        edinet_code='E30732',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石見\u3000陽',
        submitter_name_en=None,
        submitter_name_yomi='イワミ\u3000ヨウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30735': EdinetCodeEntry(
        edinet_code='E30735',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1886,
        fiscal_year_end=None,
        submitter_name='ピクテ・アセット・マネジメント（ヨーロッパ）エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='ピクテアセットマネジメントヨーロッパエスエイ',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－２２２６\u3000フォート・ニーダーグリュヌバルト通り６Ｂ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30738': EdinetCodeEntry(
        edinet_code='E30738',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2796,
        fiscal_year_end='4月30日',
        submitter_name='日本ビューホテル株式会社',
        submitter_name_en='NIPPON VIEW HOTEL CO.,LTD.',
        submitter_name_yomi='ニホンビューホテルカブシキガイシャ',
        address='台東区西浅草３－１７－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010501010540',
    ),
    'E30739': EdinetCodeEntry(
        edinet_code='E30739',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤雄一',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30744': EdinetCodeEntry(
        edinet_code='E30744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=82,
        fiscal_year_end=None,
        submitter_name='日本エンジェルズ・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンエンジェルズインベストメントカブシキカイシャ',
        address='千代田区一番町９－８\u3000ノザワビルディング８Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401073112',
    ),
    'E30746': EdinetCodeEntry(
        edinet_code='E30746',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27500,
        fiscal_year_end='3月末日',
        submitter_name='株式会社東京きらぼしフィナンシャルグループ',
        submitter_name_en='Tokyo Kiraboshi Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャトウキョウキラボシフィナンシャルグループ',
        address='港区南青山三丁目１０番４３号',
        industry='銀行業',
        sec_code='71730',
        corporate_number='9011101071326',
    ),
    'E30750': EdinetCodeEntry(
        edinet_code='E30750',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神田\u3000隆生',
        submitter_name_en=None,
        submitter_name_yomi='カンダ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30767': EdinetCodeEntry(
        edinet_code='E30767',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西尾\u3000隆裕',
        submitter_name_en=None,
        submitter_name_yomi='ニシオ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30772': EdinetCodeEntry(
        edinet_code='E30772',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=382,
        fiscal_year_end=None,
        submitter_name='マルホ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルホカブシキガイシャ',
        address='大阪市北区中津一丁目５番２２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001070786',
    ),
    'E30780': EdinetCodeEntry(
        edinet_code='E30780',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神田\u3000有華',
        submitter_name_en=None,
        submitter_name_yomi='カンダ\u3000ユカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30781': EdinetCodeEntry(
        edinet_code='E30781',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神田\u3000亜希',
        submitter_name_en=None,
        submitter_name_yomi='カンダ\u3000アキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30784': EdinetCodeEntry(
        edinet_code='E30784',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宇佐美\u3000進典',
        submitter_name_en=None,
        submitter_name_yomi='ウサミ\u3000シンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30786': EdinetCodeEntry(
        edinet_code='E30786',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本田\u3000謙',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000ユズル',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30797': EdinetCodeEntry(
        edinet_code='E30797',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000智久',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000トモヒサ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30799': EdinetCodeEntry(
        edinet_code='E30799',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下出\u3000啓介',
        submitter_name_en=None,
        submitter_name_yomi='シモイデ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30803': EdinetCodeEntry(
        edinet_code='E30803',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大石\u3000正德',
        submitter_name_en=None,
        submitter_name_yomi='オオイシ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30804': EdinetCodeEntry(
        edinet_code='E30804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ＫＩＭアセント',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャケイアイエムアセント',
        address='佐賀市高木瀬東二丁目２番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4300002005649',
    ),
    'E30809': EdinetCodeEntry(
        edinet_code='E30809',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000岳',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ガク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30812': EdinetCodeEntry(
        edinet_code='E30812',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='日本道路興運株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンドウロコウウンカブシキガイシャ',
        address='新宿区西新宿６－６－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101016571',
    ),
    'E30814': EdinetCodeEntry(
        edinet_code='E30814',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5610,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミライト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミライト',
        address='江東区豊洲５丁目６番３６号',
        industry='建設業',
        sec_code=None,
        corporate_number='2010601040251',
    ),
    'E30816': EdinetCodeEntry(
        edinet_code='E30816',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11956269,
        fiscal_year_end='12月31日',
        submitter_name='フランス預金供託公庫',
        submitter_name_en=None,
        submitter_name_yomi='フランスヨキンキョウタクコウコ',
        address='フランス、パリ市７５００７、リュ・ド・リール５６',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E30818': EdinetCodeEntry(
        edinet_code='E30818',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯室\u3000喜正',
        submitter_name_en=None,
        submitter_name_yomi='イイムロ\u3000ヨシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30819': EdinetCodeEntry(
        edinet_code='E30819',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｉｎｖｅｓｃｏ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='インベスコ\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='３５００\u3000Ｌａｃｅｙ\u3000Ｒｏａｄ，\u3000Ｓｕｉｔｅ\u3000７００，\u3000Ｄｏｗｎｅｒｓ\u3000Ｇｒｏｖｅ\u3000ＩＬ\u3000６０５１５，\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30829': EdinetCodeEntry(
        edinet_code='E30829',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2500,
        fiscal_year_end=None,
        submitter_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジェイピーモルガンマンサールマネジメントリミテッド',
        address='連合王国\u3000ロンドンＥ１４\u3000５ＪＰ\u3000バンク\u3000ストリート２５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30831': EdinetCodeEntry(
        edinet_code='E30831',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='銭\u3000コン',
        submitter_name_en=None,
        submitter_name_yomi='セン\u3000コン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30834': EdinetCodeEntry(
        edinet_code='E30834',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大倉\u3000忠司',
        submitter_name_en=None,
        submitter_name_yomi='オオクラ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30836': EdinetCodeEntry(
        edinet_code='E30836',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=318,
        fiscal_year_end='9月末日',
        submitter_name='株式会社イルグルム',
        submitter_name_en='YRGLM Inc.',
        submitter_name_yomi='カブシキカイシャイルグルム',
        address='大阪市北区梅田二丁目２番２２号',
        industry='サービス業',
        sec_code='36900',
        corporate_number='3120001104842',
    ),
    'E30840': EdinetCodeEntry(
        edinet_code='E30840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青井\u3000和夫',
        submitter_name_en=None,
        submitter_name_yomi='アオイ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30841': EdinetCodeEntry(
        edinet_code='E30841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11661,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジャパンインベストメントアドバイザー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジャパンインベストメントアドバイザー',
        address='千代田区霞が関三丁目２番１号霞が関コモンゲート西館２１階',
        industry='証券、商品先物取引業',
        sec_code='71720',
        corporate_number='7010401085533',
    ),
    'E30852': EdinetCodeEntry(
        edinet_code='E30852',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='セレクト・エクイティ・ジーピー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='セレクトエクイティジーピーエルエルシー',
        address='１０００３\u3000アメリカ合衆国ニューヨーク州ニューヨーク市ラファイエット・ストリート３８０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30856': EdinetCodeEntry(
        edinet_code='E30856',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='9月30日',
        submitter_name='株式会社デジタルプラス',
        submitter_name_en='DIGITAL PLUS, Inc.',
        submitter_name_yomi='カブシキガイシャデジタルプラス',
        address='渋谷区元代々木町３０番１３号',
        industry='情報・通信業',
        sec_code='36910',
        corporate_number='8011001045298',
    ),
    'E30857': EdinetCodeEntry(
        edinet_code='E30857',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=299,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯプロダクトプラットフォーム株式会社',
        submitter_name_en='GMO Product Platform, Inc.',
        submitter_name_yomi='ジーエムオープロダクトプラットフォームカブシキガイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='情報・通信業',
        sec_code='36950',
        corporate_number='6011001038345',
    ),
    'E30860': EdinetCodeEntry(
        edinet_code='E30860',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='重里\u3000育孝',
        submitter_name_en=None,
        submitter_name_yomi='シゲサト\u3000ヤスタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30863': EdinetCodeEntry(
        edinet_code='E30863',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=32000,
        fiscal_year_end='3月31日',
        submitter_name='ＪＡ三井リース株式会社',
        submitter_name_en='JA MITSUI LEASING, LTD.',
        submitter_name_yomi='ジェイエイミツイリースカブシキカイシャ',
        address='中央区銀座八丁目１３番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='8010701022466',
    ),
    'E30865': EdinetCodeEntry(
        edinet_code='E30865',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リボミック',
        submitter_name_en='RIBOMIC Inc.',
        submitter_name_yomi='カブシキガイシャリボミック',
        address='港区白金台３－１６－１３\u3000白金台ウスイビル６階',
        industry='医薬品',
        sec_code='45910',
        corporate_number='7010401056971',
    ),
    'E30866': EdinetCodeEntry(
        edinet_code='E30866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000征男',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ユクオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30877': EdinetCodeEntry(
        edinet_code='E30877',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=286,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＦＦＲＩセキュリティ',
        submitter_name_en='FFRI Security, Inc.',
        submitter_name_yomi='カブシキガイシャエフエフアールアイセキュリティ',
        address='千代田区丸の内三丁目３番１号',
        industry='情報・通信業',
        sec_code='36920',
        corporate_number='3011101046226',
    ),
    'E30880': EdinetCodeEntry(
        edinet_code='E30880',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=379,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アンビションＤＸホールディングス',
        submitter_name_en='AMBITION DX HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアンビションディーエックスホールディングス',
        address='渋谷区神宮前二丁目３４番１７号住友不動産原宿ビル１８階',
        industry='不動産業',
        sec_code='33000',
        corporate_number='4011001072940',
    ),
    'E30881': EdinetCodeEntry(
        edinet_code='E30881',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=627,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ジェネレーションパス',
        submitter_name_en='GENERATION PASS CO.,LTD',
        submitter_name_yomi='カブシキガイシャジェネレーションパス',
        address='新宿区西新宿６－１２－１\u3000西新宿パークウエストビル５Ｆ',
        industry='小売業',
        sec_code='31950',
        corporate_number='9011101032971',
    ),
    'E30898': EdinetCodeEntry(
        edinet_code='E30898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3313,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ホットランドホールディングス',
        submitter_name_en='HOTLAND HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャホットランドホールディングス',
        address='中央区新富一丁目９番６号',
        industry='小売業',
        sec_code='31960',
        corporate_number='6370301002917',
    ),
    'E30902': EdinetCodeEntry(
        edinet_code='E30902',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='公益財団法人明光教育研究所',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンメイコウキョウイクケンキュウショ',
        address='新宿区西新宿七丁目２０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011105006394',
    ),
    'E30906': EdinetCodeEntry(
        edinet_code='E30906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池\u3000誠晃',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30908': EdinetCodeEntry(
        edinet_code='E30908',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=863,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アルファポリス',
        submitter_name_en='AlphaPolis.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアルファポリス',
        address='渋谷区恵比寿四丁目２０番３号恵比寿ガーデンプレイスタワー１９Ｆ',
        industry='情報・通信業',
        sec_code='94670',
        corporate_number='3011001035097',
    ),
    'E30909': EdinetCodeEntry(
        edinet_code='E30909',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＯＰＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーピーアイカブシキカイシャ',
        address='大阪市平野区加美西二丁目８番３１号',
        industry='化学',
        sec_code=None,
        corporate_number='8120001022131',
    ),
    'E30910': EdinetCodeEntry(
        edinet_code='E30910',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エクステンド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエクステンド',
        address='埼玉県草加市北谷二丁目１８番４０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401113491',
    ),
    'E30915': EdinetCodeEntry(
        edinet_code='E30915',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30917': EdinetCodeEntry(
        edinet_code='E30917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6571,
        fiscal_year_end='3月31日',
        submitter_name='ヤマシンフィルタ株式会社',
        submitter_name_en='YAMASHIN-FILTER CORP.',
        submitter_name_yomi='ヤマシンフィルタカブシキガイシャ',
        address='横浜市中区桜木町一丁目１番地８',
        industry='機械',
        sec_code='62400',
        corporate_number='5020001023159',
    ),
    'E30918': EdinetCodeEntry(
        edinet_code='E30918',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=443,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オプティム',
        submitter_name_en='OPTiM CORPORATION',
        submitter_name_yomi='カブシキガイシャオプティム',
        address='佐賀市本庄町１',
        industry='情報・通信業',
        sec_code='36940',
        corporate_number='4300001001392',
    ),
    'E30919': EdinetCodeEntry(
        edinet_code='E30919',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2158,
        fiscal_year_end='12月末日',
        submitter_name='株式会社セレス',
        submitter_name_en='CERES INC.',
        submitter_name_yomi='カブシキガイシャセレス',
        address='渋谷区桜丘町１番１号',
        industry='情報・通信業',
        sec_code='36960',
        corporate_number='1010401073460',
    ),
    'E30921': EdinetCodeEntry(
        edinet_code='E30921',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山﨑\u3000敦彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000アツヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30929': EdinetCodeEntry(
        edinet_code='E30929',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=573,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エラン',
        submitter_name_en='ELAN Corporation',
        submitter_name_yomi='カブシキガイシャエラン',
        address='松本市出川町１５番１２号',
        industry='サービス業',
        sec_code='60990',
        corporate_number='1100001014640',
    ),
    'E30930': EdinetCodeEntry(
        edinet_code='E30930',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本創発グループ',
        submitter_name_en='JAPAN Creative Platform Group Co., Ltd.',
        submitter_name_yomi='カブシキガイシャニホンソウハツグループ',
        address='台東区上野三丁目２４番６号',
        industry='その他製品',
        sec_code='78140',
        corporate_number='9011501020139',
    ),
    'E30933': EdinetCodeEntry(
        edinet_code='E30933',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福田\u3000博一',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30935': EdinetCodeEntry(
        edinet_code='E30935',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩田\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='イワタ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30950': EdinetCodeEntry(
        edinet_code='E30950',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='白岩\u3000直人',
        submitter_name_en=None,
        submitter_name_yomi='シライワ\u3000ナオト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30954': EdinetCodeEntry(
        edinet_code='E30954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飴\u3000久晴',
        submitter_name_en=None,
        submitter_name_yomi='アメ\u3000ヒサハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30956': EdinetCodeEntry(
        edinet_code='E30956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山崎\u3000裕明',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30957': EdinetCodeEntry(
        edinet_code='E30957',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山崎\u3000敬明',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30961': EdinetCodeEntry(
        edinet_code='E30961',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久野\u3000貴嗣',
        submitter_name_en=None,
        submitter_name_yomi='クノ\u3000タカツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30962': EdinetCodeEntry(
        edinet_code='E30962',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡本\u3000洋明',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30965': EdinetCodeEntry(
        edinet_code='E30965',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=260480,
        fiscal_year_end=None,
        submitter_name='グランジャー・ピーク・グローバル・アドバイザーズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='グランジャー\u3000ピーク\u3000グローバル\u3000アドバイザーズ\u3000エルエルシー',
        address='アメリカ合衆国８４１０１ユタ州ソールト・レーク・シティ、サウス・メイン・ストリート１３６番、スイート７２０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30969': EdinetCodeEntry(
        edinet_code='E30969',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=21,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ＳＨＩＦＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシフト',
        address='港区麻布台一丁目３番１号\u3000麻布台ヒルズ\u3000森ＪＰタワー',
        industry='情報・通信業',
        sec_code='36970',
        corporate_number='8010401073462',
    ),
    'E30970': EdinetCodeEntry(
        edinet_code='E30970',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐瀬\u3000守男',
        submitter_name_en=None,
        submitter_name_yomi='サセ\u3000モリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30974': EdinetCodeEntry(
        edinet_code='E30974',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='赤浦\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='アカウラ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30975': EdinetCodeEntry(
        edinet_code='E30975',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='設楽\u3000真吾',
        submitter_name_en=None,
        submitter_name_yomi='シタラ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30976': EdinetCodeEntry(
        edinet_code='E30976',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000秀明',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30977': EdinetCodeEntry(
        edinet_code='E30977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='都木\u3000聡',
        submitter_name_en=None,
        submitter_name_yomi='タカギ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30978': EdinetCodeEntry(
        edinet_code='E30978',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鵜飼\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='ウカイ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30979': EdinetCodeEntry(
        edinet_code='E30979',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金居\u3000良治',
        submitter_name_en=None,
        submitter_name_yomi='カナイ\u3000リョウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30982': EdinetCodeEntry(
        edinet_code='E30982',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=857,
        fiscal_year_end='3月末日',
        submitter_name='今村証券株式会社',
        submitter_name_en='The Imamura Securities Co.,Ltd.',
        submitter_name_yomi='イマムラショウケンカブシキガイシャ',
        address='金沢市十間町２５番地',
        industry='証券、商品先物取引業',
        sec_code='71750',
        corporate_number='9220001001223',
    ),
    'E30983': EdinetCodeEntry(
        edinet_code='E30983',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=42,
        fiscal_year_end=None,
        submitter_name='双葉不動産建設株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フタバフドウサンケンセツ',
        address='双葉郡浪江町大字権現堂字上続町１８－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6380001016687',
    ),
    'E30986': EdinetCodeEntry(
        edinet_code='E30986',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松田\u3000元',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000ゲン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30992': EdinetCodeEntry(
        edinet_code='E30992',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20967,
        fiscal_year_end=None,
        submitter_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
        submitter_name_en=None,
        submitter_name_yomi='ルクセンブルク\u3000ミツビシ\u3000ユーエフジェイ\u3000インベスターサービスギンコウ\u3000エス\u3000エイ',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－１１５０\u3000アーロン通り\u3000２８７－２８９番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E30993': EdinetCodeEntry(
        edinet_code='E30993',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=219,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エムケイシステム',
        submitter_name_en='MKSystem Corporation',
        submitter_name_yomi='カブシキガイシャエムケイシステム',
        address='大阪市北区中崎西二丁目４番１２号',
        industry='情報・通信業',
        sec_code='39100',
        corporate_number='7120001075907',
    ),
    'E30994': EdinetCodeEntry(
        edinet_code='E30994',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=490,
        fiscal_year_end=None,
        submitter_name='いちよしアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イチヨシアセットマネジメントカブシキカイシャ',
        address='中央区日本橋茅場町１－５－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001036852',
    ),
    'E30996': EdinetCodeEntry(
        edinet_code='E30996',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=784,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ＣＲＩ・ミドルウェア',
        submitter_name_en='CRI Middleware Co., Ltd.',
        submitter_name_yomi='カブシキガイシャシーアールアイミドルウェア',
        address='渋谷区桜丘町２０番１号\u3000渋谷インフォスタワー１１階',
        industry='情報・通信業',
        sec_code='36980',
        corporate_number='6011001062642',
    ),
    'E30997': EdinetCodeEntry(
        edinet_code='E30997',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41450,
        fiscal_year_end=None,
        submitter_name='トーセイ・リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='トーセイリートトウシホウジン',
        address='港区芝浦四丁目５番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405013103',
    ),
    'E30998': EdinetCodeEntry(
        edinet_code='E30998',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='アトラグループ株式会社',
        submitter_name_en='Artra Group Corporation',
        submitter_name_yomi='アトラグループカブシキカイシャ',
        address='大阪市西区立売堀四丁目６番９号',
        industry='サービス業',
        sec_code='60290',
        corporate_number='6120001113618',
    ),
    'E30999': EdinetCodeEntry(
        edinet_code='E30999',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=360,
        fiscal_year_end='8月31日',
        submitter_name='日本ＰＣサービス株式会社',
        submitter_name_en='Japan PC Service Co., Ltd.',
        submitter_name_yomi='ニホンピーシーサービスカブシキカイシャ',
        address='吹田市広芝町９番３３号',
        industry='サービス業',
        sec_code='60250',
        corporate_number='9120901014607',
    ),
    'E31003': EdinetCodeEntry(
        edinet_code='E31003',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000弘明',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31004': EdinetCodeEntry(
        edinet_code='E31004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='櫻井\u3000英治',
        submitter_name_en=None,
        submitter_name_yomi='サクライ\u3000ヒデハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31005': EdinetCodeEntry(
        edinet_code='E31005',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000信弘',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000ノブヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31009': EdinetCodeEntry(
        edinet_code='E31009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=545,
        fiscal_year_end='3月末日',
        submitter_name='弁護士ドットコム株式会社',
        submitter_name_en='Bengo4.com,Inc.',
        submitter_name_yomi='ベンゴシドットコムカブシキカイシャ',
        address='港区六本木四丁目１番４号',
        industry='サービス業',
        sec_code='60270',
        corporate_number='7010401059818',
    ),
    'E31012': EdinetCodeEntry(
        edinet_code='E31012',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1909,
        fiscal_year_end='3月末日',
        submitter_name='株式会社大冷',
        submitter_name_en='DAIREI CO.,LTD',
        submitter_name_yomi='カブシキガイシャダイレイ',
        address='中央区月島２－３－１',
        industry='食料品',
        sec_code='28830',
        corporate_number='2010001048993',
    ),
    'E31016': EdinetCodeEntry(
        edinet_code='E31016',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31017': EdinetCodeEntry(
        edinet_code='E31017',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菅谷\u3000俊二',
        submitter_name_en=None,
        submitter_name_yomi='スガヤ\u3000シュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31018': EdinetCodeEntry(
        edinet_code='E31018',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='大都（香港）實業有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ダイトホンコンジツギョウユウゲンコウシ',
        address='Ｒｏｏｍ\u3000Ｃ，３／Ｆ，Ｃａｍｅｒｏｎ\u3000Ｃｏｍｍｅｒｃｉａｌ\u3000Ｂｕｉｌｄｉｎｇ，４６８\u3000Ｈｅｎｎｅｓｓｙ\u3000Ｒｏａｄ\u3000Ｃａｕｓｅｗａｙ\u3000Ｂａｙ，\u3000Ｈ．Ｋ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31019': EdinetCodeEntry(
        edinet_code='E31019',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=741,
        fiscal_year_end='9月30日',
        submitter_name='株式会社クラウドワークス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクラウドワークス',
        address='渋谷区道玄坂一丁目８番３号',
        industry='情報・通信業',
        sec_code='39000',
        corporate_number='6010401098453',
    ),
    'E31020': EdinetCodeEntry(
        edinet_code='E31020',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＰＣカッパ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスピーシーカッパ',
        address='横浜市西区みなとみらい二丁目２番１号ランドマークタワー１２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7020001107728',
    ),
    'E31023': EdinetCodeEntry(
        edinet_code='E31023',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=372,
        fiscal_year_end='12月末日',
        submitter_name='マークラインズ株式会社',
        submitter_name_en='MarkLines Co.,Ltd.',
        submitter_name_yomi='マークラインズカブシキガイシャ',
        address='港区六本木７ー１５ー９六本木セントラルタワー１４階',
        industry='情報・通信業',
        sec_code='39010',
        corporate_number='5010401043352',
    ),
    'E31024': EdinetCodeEntry(
        edinet_code='E31024',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1992,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ビーロット',
        submitter_name_en='B-Lot Company Limited',
        submitter_name_yomi='カブシキカイシャビーロット',
        address='港区新橋一丁目１１番７号',
        industry='不動産業',
        sec_code='34520',
        corporate_number='2010401078582',
    ),
    'E31026': EdinetCodeEntry(
        edinet_code='E31026',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='合同会社リフレーミング',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャリフレーミング',
        address='中央区銀座六丁目１０－１－８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010403011981',
    ),
    'E31029': EdinetCodeEntry(
        edinet_code='E31029',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=534,
        fiscal_year_end='2月末日',
        submitter_name='ＳＦＰホールディングス株式会社',
        submitter_name_en='SFP Holdings Co., Ltd.',
        submitter_name_yomi='エスエフピーホールディングスカブシキカイシャ',
        address='世田谷区玉川二丁目２４番７号',
        industry='小売業',
        sec_code='31980',
        corporate_number='6010901028439',
    ),
    'E31030': EdinetCodeEntry(
        edinet_code='E31030',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6929,
        fiscal_year_end='6月30日',
        submitter_name='テクノプロ・ホールディングス株式会社',
        submitter_name_en='TechnoPro Holdings, Inc.',
        submitter_name_yomi='テクノプロホールディングスカブシキカイシャ',
        address='港区六本木六丁目１０番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010401063398',
    ),
    'E31035': EdinetCodeEntry(
        edinet_code='E31035',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1047,
        fiscal_year_end='3月末日',
        submitter_name='株式会社フルッタフルッタ',
        submitter_name_en='FRUTA FRUTA INC.',
        submitter_name_yomi='カブシキガイシャフルッタフルッタ',
        address='千代田区九段北３丁目２番２８号',
        industry='食料品',
        sec_code='25860',
        corporate_number='4010001094581',
    ),
    'E31036': EdinetCodeEntry(
        edinet_code='E31036',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4072,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アドベンチャー',
        submitter_name_en='Adventure, Inc.',
        submitter_name_yomi='カブシキガイシャアドベンチャー',
        address='渋谷区恵比寿４－２０－３恵比寿ガーデンプレイスタワー４Ｆ',
        industry='サービス業',
        sec_code='60300',
        corporate_number='5011001050532',
    ),
    'E31037': EdinetCodeEntry(
        edinet_code='E31037',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=803,
        fiscal_year_end='12月31日',
        submitter_name='竹本容器株式会社',
        submitter_name_en='Takemoto Yohki Co., Ltd.',
        submitter_name_yomi='タケモトヨウキカブシキガイシャ',
        address='台東区西浅草一丁目５番１５号',
        industry='化学',
        sec_code='42480',
        corporate_number='9010501007633',
    ),
    'E31038': EdinetCodeEntry(
        edinet_code='E31038',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=165151,
        fiscal_year_end=None,
        submitter_name='積水ハウス・リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='セキスイハウスリートトウシホウジン',
        address='港区赤坂四丁目１５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405013111',
    ),
    'E31042': EdinetCodeEntry(
        edinet_code='E31042',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5438,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＲＳ\u3000Ｔｅｃｈｎｏｌｏｇｉｅｓ',
        submitter_name_en='RS Technologies Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャアールエステクノロジーズ',
        address='品川区大井一丁目４７番１号',
        industry='金属製品',
        sec_code='34450',
        corporate_number='3010701024500',
    ),
    'E31052': EdinetCodeEntry(
        edinet_code='E31052',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99,
        fiscal_year_end='8月31日',
        submitter_name='株式会社Ｕ－ＮＥＸＴ\u3000ＨＯＬＤＩＮＧＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーネクストホールディングス',
        address='品川区上大崎三丁目１番１号',
        industry='情報・通信業',
        sec_code='94180',
        corporate_number='3011001067132',
    ),
    'E31054': EdinetCodeEntry(
        edinet_code='E31054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=795,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイ・アールジャパンホールディングス',
        submitter_name_en='IR Japan Holdings, Ltd.',
        submitter_name_yomi='カブシキガイシャアイアールジャパンホールディングス',
        address='千代田区霞が関三丁目２番５号',
        industry='サービス業',
        sec_code='60350',
        corporate_number='6010001165694',
    ),
    'E31055': EdinetCodeEntry(
        edinet_code='E31055',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=277,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯ\u3000ＴＥＣＨ株式会社',
        submitter_name_en='GMO TECH,Inc.',
        submitter_name_yomi='ジーエムオーテックカブシキカイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4011001060929',
    ),
    'E31056': EdinetCodeEntry(
        edinet_code='E31056',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=981,
        fiscal_year_end='12月31日',
        submitter_name='メディカル・データ・ビジョン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メディカルデータビジョンカブシキガイシャ',
        address='千代田区神田美土代町７番地',
        industry='情報・通信業',
        sec_code='39020',
        corporate_number='7010001087640',
    ),
    'E31060': EdinetCodeEntry(
        edinet_code='E31060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6481,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ｇｕｍｉ',
        submitter_name_en='gumi Inc.',
        submitter_name_yomi='カブシキカイシャグミ',
        address='新宿区西新宿四丁目３４番７号',
        industry='情報・通信業',
        sec_code='39030',
        corporate_number='8011101056625',
    ),
    'E31064': EdinetCodeEntry(
        edinet_code='E31064',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11946,
        fiscal_year_end='3月31日',
        submitter_name='メタウォーター株式会社',
        submitter_name_en='METAWATER Co.,Ltd.',
        submitter_name_yomi='メタウォーターカブシキガイシャ',
        address='千代田区神田須田町一丁目２５番地',
        industry='電気・ガス業',
        sec_code='95510',
        corporate_number='8010401075293',
    ),
    'E31065': EdinetCodeEntry(
        edinet_code='E31065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5168,
        fiscal_year_end='3月末日',
        submitter_name='イーレックス株式会社',
        submitter_name_en='eREX Co.,Ltd.',
        submitter_name_yomi='イーレックスカブシキガイシャ',
        address='中央区京橋２丁目２番１号京橋エドグラン１４階',
        industry='電気・ガス業',
        sec_code='95170',
        corporate_number='2010001066839',
    ),
    'E31070': EdinetCodeEntry(
        edinet_code='E31070',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2154,
        fiscal_year_end='12月31日',
        submitter_name='株式会社スノーピーク',
        submitter_name_en='Snow Peak, Inc.',
        submitter_name_yomi='カブシキガイシャスノーピーク',
        address='三条市中野原４５６番地',
        industry='その他製品',
        sec_code=None,
        corporate_number='3110001014316',
    ),
    'E31071': EdinetCodeEntry(
        edinet_code='E31071',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=431,
        fiscal_year_end='12月31日',
        submitter_name='ＭＲＴ株式会社',
        submitter_name_en='MRT Inc.',
        submitter_name_yomi='エムアールティカブシキガイシャ',
        address='渋谷区神南１－１８－２\u3000フレーム神南坂３階',
        industry='サービス業',
        sec_code='60340',
        corporate_number='3011101059533',
    ),
    'E31074': EdinetCodeEntry(
        edinet_code='E31074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西原\u3000聖一郎',
        submitter_name_en=None,
        submitter_name_yomi='ニシハラ\u3000セイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31079': EdinetCodeEntry(
        edinet_code='E31079',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=419,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エクストリーム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエクストリーム',
        address='豊島区西池袋１－１１－１メトロポリタンプラザビル２１Ｆ',
        industry='サービス業',
        sec_code='60330',
        corporate_number='6013301021476',
    ),
    'E31084': EdinetCodeEntry(
        edinet_code='E31084',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=63,
        fiscal_year_end=None,
        submitter_name='ＦＩＬ・インベストメント・マネジメント（ルクセンブルグ）エス・エイ・アール・エル',
        submitter_name_en=None,
        submitter_name_yomi='エフ\u3000アイ\u3000エル\u3000インベストメント\u3000マネジメント\u3000ルクセンブルグ\u3000エス\u3000エイ\u3000アール\u3000エル',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－１２４６\u3000アルバート・ボルシェット通り\u3000２ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31085': EdinetCodeEntry(
        edinet_code='E31085',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17,
        fiscal_year_end=None,
        submitter_name='ＨＳＢＣマネジメント（ガーンジー）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシー\u3000マネジメント\u3000ガーンジー\u3000リミテッド',
        address='チャネル諸島、ＧＹ１\u3000１ＷＡ、ガーンジー、セント・ピーター・ポート、セント・ジュリアンズ・アベニュー、アーノルド・ハウス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31086': EdinetCodeEntry(
        edinet_code='E31086',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=78,
        fiscal_year_end=None,
        submitter_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アイキューイーキューマネジメントバミューダリミテッド',
        address='バーミューダ、ハミルトンＨＭ１１、リード・ストリート２０番、ウィリアムズ・ハウス４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31087': EdinetCodeEntry(
        edinet_code='E31087',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5187,
        fiscal_year_end=None,
        submitter_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='ブラックロックファンドマネジメントカンパニーエスエー',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－１８５５、Ｊ．Ｆ．ケネディ通り\u3000３５Ａ番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31089': EdinetCodeEntry(
        edinet_code='E31089',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=96,
        fiscal_year_end='12月末日',
        submitter_name='ＺＥＴＡ株式会社',
        submitter_name_en='ZETA INC',
        submitter_name_yomi='ゼータカブシキガイシャ',
        address='世田谷区三軒茶屋二丁目１１番２２号',
        industry='サービス業',
        sec_code='60310',
        corporate_number='3010701018824',
    ),
    'E31093': EdinetCodeEntry(
        edinet_code='E31093',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=523,
        fiscal_year_end='12月31日',
        submitter_name='株式会社カヤック',
        submitter_name_en='KAYAC Inc.',
        submitter_name_yomi='カブシキガイシャカヤック',
        address='鎌倉市御成町１１番８号',
        industry='情報・通信業',
        sec_code='39040',
        corporate_number='7021001010079',
    ),
    'E31096': EdinetCodeEntry(
        edinet_code='E31096',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000昌平',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ショウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31097': EdinetCodeEntry(
        edinet_code='E31097',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮内\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ミヤウチ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31099': EdinetCodeEntry(
        edinet_code='E31099',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='望月\u3000雅博',
        submitter_name_en=None,
        submitter_name_yomi='モチヅキ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31102': EdinetCodeEntry(
        edinet_code='E31102',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000進一',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31103': EdinetCodeEntry(
        edinet_code='E31103',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=172,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インターワークス',
        submitter_name_en='Interworks,Inc',
        submitter_name_yomi='カブシキガイシャインターワークス',
        address='港区西新橋１－６－２１ＮＢＦ虎ノ門ビル８階',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010401060158',
    ),
    'E31104': EdinetCodeEntry(
        edinet_code='E31104',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1101,
        fiscal_year_end='3月末日',
        submitter_name='綿半ホールディングス株式会社',
        submitter_name_en='Watahan&Co.,Ltd.',
        submitter_name_yomi='ワタハンホールディングスカブシキガイシャ',
        address='飯田市北方１０２３番地１',
        industry='小売業',
        sec_code='31990',
        corporate_number='4100001022855',
    ),
    'E31105': EdinetCodeEntry(
        edinet_code='E31105',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丹下\u3000大',
        submitter_name_en=None,
        submitter_name_yomi='タンゲ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31109': EdinetCodeEntry(
        edinet_code='E31109',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片山晃',
        submitter_name_en=None,
        submitter_name_yomi='カタヤマアキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31110': EdinetCodeEntry(
        edinet_code='E31110',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='レモンガス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='レモンガスカブシキガイシャ',
        address='平塚市高根一丁目１番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8021001036718',
    ),
    'E31112': EdinetCodeEntry(
        edinet_code='E31112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000健人',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ケント',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31117': EdinetCodeEntry(
        edinet_code='E31117',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='國光\u3000宏尚',
        submitter_name_en=None,
        submitter_name_yomi='クニミツ\u3000ヒロナオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31121': EdinetCodeEntry(
        edinet_code='E31121',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='元榮\u3000太一郎',
        submitter_name_en=None,
        submitter_name_yomi='モトエ\u3000タイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31123': EdinetCodeEntry(
        edinet_code='E31123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=221,
        fiscal_year_end='3月末日',
        submitter_name='東京ボード工業株式会社',
        submitter_name_en='Tokyo Board Industries co.,ltd.',
        submitter_name_yomi='トウキョウボードコウギョウカブシキガイシャ',
        address='江東区新木場二丁目１１番１号',
        industry='その他製品',
        sec_code='78150',
        corporate_number='2010601034286',
    ),
    'E31126': EdinetCodeEntry(
        edinet_code='E31126',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5860,
        fiscal_year_end=None,
        submitter_name='パーカー\u3000ハネフィン\u3000マニュファクチュアリング（ユーケー）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='パーカーハネフィンマニュファクチュアリングユーケーリミテッド',
        address='パーカーハウス\u3000５５メイランズアベニュー\u3000ヘメル\u3000ヘンプステッド\u3000ハートフォードシャー\u3000エイチピー２\u3000４エスジェイ\u3000イングランド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31127': EdinetCodeEntry(
        edinet_code='E31127',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橋本\u3000大也',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000ダイヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31130': EdinetCodeEntry(
        edinet_code='E31130',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本銀行',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンギンコウ',
        address='中央区日本橋本石町二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005002599',
    ),
    'E31131': EdinetCodeEntry(
        edinet_code='E31131',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1516,
        fiscal_year_end='3月末日',
        submitter_name='データセクション株式会社',
        submitter_name_en='Datasection Inc.',
        submitter_name_yomi='データセクションカブシキカイシャ',
        address='品川区西五反田１丁目３番８号',
        industry='情報・通信業',
        sec_code='39050',
        corporate_number='7010401083082',
    ),
    'E31133': EdinetCodeEntry(
        edinet_code='E31133',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＵＮＯ－ＨＯＬＤＩＮＧＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウノホールディングス',
        address='渋谷区恵比寿１丁目２３番地１３号アルカイビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401068100',
    ),
    'E31137': EdinetCodeEntry(
        edinet_code='E31137',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000浩一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000コウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31156': EdinetCodeEntry(
        edinet_code='E31156',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000洋',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ヒロイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31159': EdinetCodeEntry(
        edinet_code='E31159',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='2月末日',
        submitter_name='ユナイテッド・スーパーマーケット・ホールディングス株式会社',
        submitter_name_en='United Super Markets Holdings Inc.',
        submitter_name_yomi='ユナイテッドスーパーマーケットホールディングスカブシキガイシャ',
        address='千代田区神田相生町１番地',
        industry='小売業',
        sec_code='32220',
        corporate_number='8010001166286',
    ),
    'E31163': EdinetCodeEntry(
        edinet_code='E31163',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉岡\u3000昌成',
        submitter_name_en=None,
        submitter_name_yomi='ヨシオカ\u3000マサナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31167': EdinetCodeEntry(
        edinet_code='E31167',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14040,
        fiscal_year_end='3月31日',
        submitter_name='マクニカホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マクニカホールディングスカブシキカイシャ',
        address='横浜市港北区新横浜１－６－３',
        industry='卸売業',
        sec_code='31320',
        corporate_number='9020001110309',
    ),
    'E31170': EdinetCodeEntry(
        edinet_code='E31170',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='イオンマーケットインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イオンマーケットインベストメントカブシキカイシャ',
        address='千葉市美浜区中瀬１－５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1190001005251',
    ),
    'E31171': EdinetCodeEntry(
        edinet_code='E31171',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000明人',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000アキト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31172': EdinetCodeEntry(
        edinet_code='E31172',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='西垣林業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシガキリンギョウカブシキガイシャ',
        address='桜井市大字戒重１３７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6150001009466',
    ),
    'E31175': EdinetCodeEntry(
        edinet_code='E31175',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000シュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31177': EdinetCodeEntry(
        edinet_code='E31177',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤修',
        submitter_name_en=None,
        submitter_name_yomi='サイトウオサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31181': EdinetCodeEntry(
        edinet_code='E31181',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山井\u3000太',
        submitter_name_en=None,
        submitter_name_yomi='ヤマイ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31185': EdinetCodeEntry(
        edinet_code='E31185',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='今村\u3000九治',
        submitter_name_en=None,
        submitter_name_yomi='イマムラ\u3000クジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31186': EdinetCodeEntry(
        edinet_code='E31186',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='今村\u3000直喜',
        submitter_name_en=None,
        submitter_name_yomi='イマムラ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31188': EdinetCodeEntry(
        edinet_code='E31188',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31189': EdinetCodeEntry(
        edinet_code='E31189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳澤\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギサワ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31190': EdinetCodeEntry(
        edinet_code='E31190',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久場\u3000智喜',
        submitter_name_en=None,
        submitter_name_yomi='クバ\u3000トモヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31191': EdinetCodeEntry(
        edinet_code='E31191',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='貝畑\u3000政徳',
        submitter_name_en=None,
        submitter_name_yomi='カイハタ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31193': EdinetCodeEntry(
        edinet_code='E31193',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉井\u3000伸一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシイ\u3000シンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31194': EdinetCodeEntry(
        edinet_code='E31194',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹本\u3000笑子',
        submitter_name_en=None,
        submitter_name_yomi='タケモト\u3000エミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31197': EdinetCodeEntry(
        edinet_code='E31197',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='深澤\u3000隆弘',
        submitter_name_en=None,
        submitter_name_yomi='フカザワ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31199': EdinetCodeEntry(
        edinet_code='E31199',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社フルタ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフルタ',
        address='中央区月島二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5230001006919',
    ),
    'E31204': EdinetCodeEntry(
        edinet_code='E31204',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=101,
        fiscal_year_end=None,
        submitter_name='株式会社総合生活サービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソウゴウセイカツサービス',
        address='豊島区西池袋一丁目４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3013301036287',
    ),
    'E31205': EdinetCodeEntry(
        edinet_code='E31205',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='酒井\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31206': EdinetCodeEntry(
        edinet_code='E31206',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='馬場\u3000稔正',
        submitter_name_en=None,
        submitter_name_yomi='ババ\u3000トシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31207': EdinetCodeEntry(
        edinet_code='E31207',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社冨田医療研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトミタイリョウシンリョウジョ',
        address='渋谷区恵比寿西一丁目１８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001073588',
    ),
    'E31208': EdinetCodeEntry(
        edinet_code='E31208',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古田\u3000耕司',
        submitter_name_en=None,
        submitter_name_yomi='フルタ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31210': EdinetCodeEntry(
        edinet_code='E31210',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=114,
        fiscal_year_end=None,
        submitter_name='イノベーション・エンジン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イノベーション\u3000エンジンカブシキガイシャ',
        address='港区芝二丁目３番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401058612',
    ),
    'E31211': EdinetCodeEntry(
        edinet_code='E31211',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2050,
        fiscal_year_end=None,
        submitter_name='日本ベンチャーキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンベンチャーキャピタルカブシキガイシャ',
        address='千代田区丸の内二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401023170',
    ),
    'E31216': EdinetCodeEntry(
        edinet_code='E31216',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1347,
        fiscal_year_end='6月30日',
        submitter_name='ＫｅｅＰｅｒ技研株式会社',
        submitter_name_en='KeePer Technical Laboratory Co., Ltd.',
        submitter_name_yomi='キーパーギケンカブシキカイシャ',
        address='大府市吉川町４丁目１７番地',
        industry='サービス業',
        sec_code='60360',
        corporate_number='3180001094120',
    ),
    'E31220': EdinetCodeEntry(
        edinet_code='E31220',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1055,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000ホクリヨウ',
        submitter_name_en='Hokuryo Co., Ltd.',
        submitter_name_yomi='カブシキガイシャホクリヨウ',
        address='札幌市白石区中央二条三丁目６番１５号',
        industry='食料品',
        sec_code='13840',
        corporate_number='2430001028862',
    ),
    'E31228': EdinetCodeEntry(
        edinet_code='E31228',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長澤\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ナガサワ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31236': EdinetCodeEntry(
        edinet_code='E31236',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人みどり会',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンミドリカイ',
        address='大阪市西区南堀江三丁目９番２１号ネオハイツ南堀江１１０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120005017296',
    ),
    'E31237': EdinetCodeEntry(
        edinet_code='E31237',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久世\u3000博之',
        submitter_name_en=None,
        submitter_name_yomi='キュウセ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31238': EdinetCodeEntry(
        edinet_code='E31238',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ａホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイホールディングスカブシキガイシャ',
        address='港区海岸１丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701019678',
    ),
    'E31245': EdinetCodeEntry(
        edinet_code='E31245',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＷｉＬ\u3000Ｆｕｎｄ\u3000Ｉ\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ウィルファンドワン\u3000エルピー',
        address='１０２\u3000Ｕｎｉｖｅｒｓｉｔｙ\u3000Ａｖｅ．，\u3000Ｓｕｉｔｅ\u3000１Ａ\u3000Ｐａｌｏ\u3000Ａｌｔｏ，\u3000ＣＡ\u3000９４３０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31248': EdinetCodeEntry(
        edinet_code='E31248',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=83,
        fiscal_year_end='7月31日',
        submitter_name='楽待株式会社',
        submitter_name_en='RAKUMACHI,INC.',
        submitter_name_yomi='ラクマチカブシキガイシャ',
        address='中央区有楽町三丁目３番５号住友不動産八丁堀ビル５階',
        industry='サービス業',
        sec_code='60370',
        corporate_number='4010401065075',
    ),
    'E31250': EdinetCodeEntry(
        edinet_code='E31250',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5939,
        fiscal_year_end=None,
        submitter_name='ウエリントン・マネージメント・カンパニー・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='ウエリントン\u3000マネージメント\u3000カンパニー\u3000エルエルピー',
        address='アメリカ合衆国、０２２１０\u3000マサチューセッツ州ボストン、コングレス・ストリート２８０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31252': EdinetCodeEntry(
        edinet_code='E31252',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=464,
        fiscal_year_end=None,
        submitter_name='ウエリントン・マネージメント・ホンコン・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウエリントンマネージメントホンコンリミテッド',
        address='香港、クオリー・ベイ、キングス・ロード９７９、ワン・タイクー・プレイス１４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31254': EdinetCodeEntry(
        edinet_code='E31254',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=419,
        fiscal_year_end=None,
        submitter_name='ウエリントン・マネージメント・シンガポール・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウエリントンマネージメントシンガポールピーティーイーリミテッド',
        address='シンガポール共和国０１８９８１、マリーナ・ベイ・ファイナンシャル・センター、タワー１、＃０３－０１、８マリーナブルバード',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31256': EdinetCodeEntry(
        edinet_code='E31256',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=466,
        fiscal_year_end='11月30日',
        submitter_name='シリコンスタジオ株式会社',
        submitter_name_en='Silicon Studio Corporation',
        submitter_name_yomi='シリコンスタジオカブシキガイシャ',
        address='渋谷区恵比寿一丁目２１番３号',
        industry='情報・通信業',
        sec_code='39070',
        corporate_number='5011001033280',
    ),
    'E31257': EdinetCodeEntry(
        edinet_code='E31257',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='Ｃ．Ｉ．Ｆ．ＨＯＬＤＩＮＧ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーアイエフホールディングカブシキカイシャ',
        address='渋谷区東１－２－２０ー１２０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001066677',
    ),
    'E31264': EdinetCodeEntry(
        edinet_code='E31264',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田邊次良',
        submitter_name_en=None,
        submitter_name_yomi='タナベ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31267': EdinetCodeEntry(
        edinet_code='E31267',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=370,
        fiscal_year_end=None,
        submitter_name='株式会社シンプレクス・ファイナンシャル・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシンプレクスファイナンシャルホールディングス',
        address='千代田区丸の内１－５－１新丸の内ビルディング２７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001103796',
    ),
    'E31270': EdinetCodeEntry(
        edinet_code='E31270',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田邊\u3000洋一郎',
        submitter_name_en=None,
        submitter_name_yomi='タナベ\u3000ヨウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31276': EdinetCodeEntry(
        edinet_code='E31276',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1050,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＡＬＢＥＲＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルベルト',
        address='新宿区北新宿二丁目２１番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5011001045086',
    ),
    'E31277': EdinetCodeEntry(
        edinet_code='E31277',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=74,
        fiscal_year_end=None,
        submitter_name='ユナイテッド・マネージャーズ・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユナイテッドマネージャーズジャパンカブシキカイシャ',
        address='港区虎ノ門一丁目１６番８号\u3000虎ノ門石井ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401056026',
    ),
    'E31280': EdinetCodeEntry(
        edinet_code='E31280',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=37018,
        fiscal_year_end=None,
        submitter_name='ヘルスケア＆メディカル投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ヘルスケアアンドメディカルトウシホウジン',
        address='千代田区神田小川町三丁目３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005023345',
    ),
    'E31284': EdinetCodeEntry(
        edinet_code='E31284',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3457,
        fiscal_year_end='6月30日',
        submitter_name='株式会社Ａｎｄ\u3000Ｄｏホールディングス',
        submitter_name_en='&Do Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアンドドゥホールディングス',
        address='京都市中京区烏丸通錦小路上ル手洗水町６７０番地',
        industry='不動産業',
        sec_code='34570',
        corporate_number='6130001037568',
    ),
    'E31291': EdinetCodeEntry(
        edinet_code='E31291',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=48,
        fiscal_year_end='2月28日',
        submitter_name='株式会社エスエルディー',
        submitter_name_en='SLD Entertainment Inc.',
        submitter_name_yomi='カブシキカイシャエスエルディー',
        address='港区芝四丁目１番２３号',
        industry='小売業',
        sec_code='32230',
        corporate_number='1011001043721',
    ),
    'E31294': EdinetCodeEntry(
        edinet_code='E31294',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=489,
        fiscal_year_end=None,
        submitter_name='ウエリントン・マネージメント・ジャパン・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウエリントンマネージメントジャパンピーティーイーリミテッド',
        address='東京都千代田区丸の内一丁目１番１号パレスビル７階（日本における営業所）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7700150000136',
    ),
    'E31295': EdinetCodeEntry(
        edinet_code='E31295',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='株式会社晴山',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセイザン',
        address='三重郡川越町高松９２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5190001022391',
    ),
    'E31298': EdinetCodeEntry(
        edinet_code='E31298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000洋子',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31306': EdinetCodeEntry(
        edinet_code='E31306',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=728,
        fiscal_year_end='5月31日',
        submitter_name='ファーストコーポレーション株式会社',
        submitter_name_en='First-corporation Inc.',
        submitter_name_yomi='ファーストコーポレーションカブシキカイシャ',
        address='杉並区荻窪四丁目３０番１６号',
        industry='建設業',
        sec_code='14300',
        corporate_number='2012701011066',
    ),
    'E31311': EdinetCodeEntry(
        edinet_code='E31311',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水嶋\u3000浩雅',
        submitter_name_en=None,
        submitter_name_yomi='ミズシマ\u3000ヒロマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31321': EdinetCodeEntry(
        edinet_code='E31321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1318,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ゼネラル・オイスター',
        submitter_name_en='General Oyster,Inc.',
        submitter_name_yomi='カブシキガイシャゼネラルオイスター',
        address='中央区日本橋茅場町２丁目１３番１３号',
        industry='小売業',
        sec_code='32240',
        corporate_number='5010001089060',
    ),
    'E31331': EdinetCodeEntry(
        edinet_code='E31331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=504,
        fiscal_year_end='12月31日',
        submitter_name='株式会社モバイルファクトリー',
        submitter_name_en='Mobile Factory, Inc.',
        submitter_name_yomi='カブシキガイシャモバイルファクトリー',
        address='品川区東五反田五丁目２２番３３号',
        industry='情報・通信業',
        sec_code='39120',
        corporate_number='9010001145867',
    ),
    'E31335': EdinetCodeEntry(
        edinet_code='E31335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4905,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ヘリオス',
        submitter_name_en='HEALIOS K.K.',
        submitter_name_yomi='カブシキガイシャヘリオス',
        address='千代田区有楽町一丁目７番１号',
        industry='医薬品',
        sec_code='45930',
        corporate_number='3290001055549',
    ),
    'E31336': EdinetCodeEntry(
        edinet_code='E31336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=324,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コラボス',
        submitter_name_en='Collabos Corporation',
        submitter_name_yomi='カブシキガイシャコラボス',
        address='千代田区三番町８－１\u3000三番町東急ビル８階',
        industry='情報・通信業',
        sec_code='39080',
        corporate_number='6010001076248',
    ),
    'E31338': EdinetCodeEntry(
        edinet_code='E31338',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺田\u3000健彦',
        submitter_name_en=None,
        submitter_name_yomi='テラダ\u3000タケヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31339': EdinetCodeEntry(
        edinet_code='E31339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関本\u3000晃靖',
        submitter_name_en=None,
        submitter_name_yomi='セキモト\u3000テルヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31340': EdinetCodeEntry(
        edinet_code='E31340',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='ＳＴＭ\u3000ＨＥＲＩＴＡＧＥ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='エスティーエム\u3000ヘリテージ\u3000ピーティーイー\u3000エルティーディー',
        address='１８\u3000ＲＯＢＩＮＳＯＮ\u3000ＲＯＡＤ\u3000＃１５－０１\u3000１８\u3000ＲＯＢＩＮＳＯＮ\u3000ＳＩＮＧＡＰＯＲＥ（０４８５４７）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31343': EdinetCodeEntry(
        edinet_code='E31343',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='6月30日',
        submitter_name='株式会社イード',
        submitter_name_en='IID, Inc.',
        submitter_name_yomi='カブシキガイシャイード',
        address='中野区本町一丁目３２番２号',
        industry='サービス業',
        sec_code='60380',
        corporate_number='5011201013586',
    ),
    'E31344': EdinetCodeEntry(
        edinet_code='E31344',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=582,
        fiscal_year_end='6月30日',
        submitter_name='株式会社プラッツ',
        submitter_name_en='Platz Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャプラッツ',
        address='大野城市仲畑二丁目３番１７号',
        industry='その他製品',
        sec_code='78130',
        corporate_number='9290001041576',
    ),
    'E31346': EdinetCodeEntry(
        edinet_code='E31346',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='坂口\u3000直大',
        submitter_name_en=None,
        submitter_name_yomi='サカグチナオヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31348': EdinetCodeEntry(
        edinet_code='E31348',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3407,
        fiscal_year_end='12月末日',
        submitter_name='株式会社Ａｉｍｉｎｇ',
        submitter_name_en='Aiming Inc.',
        submitter_name_yomi='カブシキガイシャエイミング',
        address='渋谷区千駄ヶ谷５－３１－１１\u3000住友不動産新宿南口ビル５階',
        industry='情報・通信業',
        sec_code='39110',
        corporate_number='7011101060669',
    ),
    'E31352': EdinetCodeEntry(
        edinet_code='E31352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石川\u3000吉之助',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000ヨシノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31354': EdinetCodeEntry(
        edinet_code='E31354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月末日',
        submitter_name='ＧｒｅｅｎＢｅｅ株式会社',
        submitter_name_en='GreenBee, Inc.',
        submitter_name_yomi='グリーンビーカブシキカイシャ',
        address='中央区新川二丁目３番１号',
        industry='情報・通信業',
        sec_code='39130',
        corporate_number='5010001132290',
    ),
    'E31367': EdinetCodeEntry(
        edinet_code='E31367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=594,
        fiscal_year_end='3月末日',
        submitter_name='株式会社海帆',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカイハン',
        address='名古屋市中村区名駅４丁目１５‐１５\u3000名古屋総合市場ビル３ＦＯ号',
        industry='小売業',
        sec_code='31330',
        corporate_number='2180001059198',
    ),
    'E31378': EdinetCodeEntry(
        edinet_code='E31378',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ｔｅｍｐｅｒｅｄ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='テンパードインベストメンントマネジメントリミテッド',
        address='２２０－１４５\u3000Ｃｈａｄｗｉｃｋ\u3000Ｃｏｕｒｔ，\u3000Ｎｏｒｔｈ\u3000Ｖａｎｃｏｕｖｅｒ，\u3000ＢＣ\u3000Ｃａｎａｄａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31379': EdinetCodeEntry(
        edinet_code='E31379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=616,
        fiscal_year_end='5月31日',
        submitter_name='株式会社三機サービス',
        submitter_name_en='SANKI SERVICE CORPORATION',
        submitter_name_yomi='カブシキガイシャサンキサービス',
        address='姫路市阿保甲５７６番地１',
        industry='サービス業',
        sec_code='60440',
        corporate_number='3140001059036',
    ),
    'E31381': EdinetCodeEntry(
        edinet_code='E31381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=801,
        fiscal_year_end='3月末日',
        submitter_name='株式会社日本動物高度医療センター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニホンドウブツコウドイリョウセンター',
        address='川崎市高津区久地二丁目５番８号',
        industry='サービス業',
        sec_code='60390',
        corporate_number='4020001077222',
    ),
    'E31382': EdinetCodeEntry(
        edinet_code='E31382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=89,
        fiscal_year_end='1月末日',
        submitter_name='サンバイオ株式会社',
        submitter_name_en='SanBio Company Limited',
        submitter_name_yomi='サンバイオカブシキガイシャ',
        address='中央区明石町８番１号',
        industry='医薬品',
        sec_code='45920',
        corporate_number='6010601044067',
    ),
    'E31383': EdinetCodeEntry(
        edinet_code='E31383',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社イナバホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイナバホールディングス',
        address='大田区矢口２丁目５番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010801014013',
    ),
    'E31386': EdinetCodeEntry(
        edinet_code='E31386',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=607,
        fiscal_year_end='4月30日',
        submitter_name='Ｈａｍｅｅ株式会社',
        submitter_name_en='Hamee Corp.',
        submitter_name_yomi='ハミィカブシキカイシャ',
        address='小田原市栄町二丁目１２番１０号\u3000Ｓｑｕａｒｅ\u3000Ｏ２',
        industry='小売業',
        sec_code='31340',
        corporate_number='9021001033474',
    ),
    'E31387': EdinetCodeEntry(
        edinet_code='E31387',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）ファンド・ソリューションズ・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエス\u3000ルクス\u3000ファンド\u3000ソリューションズ\u3000シキャブ',
        address='ルクセンブルク市\u3000キルシュベルク地区Ｌ－１８５５\u3000Ｊ．Ｆ．ケネディ通り４９番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31395': EdinetCodeEntry(
        edinet_code='E31395',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='都築木材株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツヅキモクザイカブシキガイシャ',
        address='伊那市日影３３６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2100001020794',
    ),
    'E31398': EdinetCodeEntry(
        edinet_code='E31398',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ブラックロック・グローバル・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='ブラックロックグローバルファンズ',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－２４５３、ユージン・リュペール通り２－４番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31399': EdinetCodeEntry(
        edinet_code='E31399',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮嶌\u3000裕二',
        submitter_name_en=None,
        submitter_name_yomi='ミヤジマ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31406': EdinetCodeEntry(
        edinet_code='E31406',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安藤\u3000正弘',
        submitter_name_en=None,
        submitter_name_yomi='アンドウ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31407': EdinetCodeEntry(
        edinet_code='E31407',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=415,
        fiscal_year_end=None,
        submitter_name='株式会社なかの',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャナカノ',
        address='名古屋市緑区篠の風三丁目３８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001009628',
    ),
    'E31408': EdinetCodeEntry(
        edinet_code='E31408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='7月末日',
        submitter_name='日本スキー場開発株式会社',
        submitter_name_en='Nippon Ski Resort Development Co. Ltd.',
        submitter_name_yomi='ニホンスキージョウカイハツカブシキガイシャ',
        address='北安曇郡白馬村大字北城６３２９番地１',
        industry='サービス業',
        sec_code='60400',
        corporate_number='6010001097087',
    ),
    'E31416': EdinetCodeEntry(
        edinet_code='E31416',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='茂木\u3000貴雄',
        submitter_name_en=None,
        submitter_name_yomi='モテギ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31418': EdinetCodeEntry(
        edinet_code='E31418',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='サンフンカイ・ストラテジック・キャピタル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='サンフンカイストラテジックキャピタルリミテッド',
        address='香港、コーズウェイ・ベイ、ハイサン・アベニュー３３、リー・ガーデン・ワン４２階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31421': EdinetCodeEntry(
        edinet_code='E31421',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1800,
        fiscal_year_end=None,
        submitter_name='協同乳業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウドウニュウギョウカブシキガイシャ',
        address='中央区日本橋小網町１７－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001046343',
    ),
    'E31424': EdinetCodeEntry(
        edinet_code='E31424',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='10月31日',
        submitter_name='株式会社イトクロ',
        submitter_name_en='ItoKuro Inc.',
        submitter_name_yomi='カブシキガイシャイトクロ',
        address='品川区上大崎３丁目１番１号',
        industry='サービス業',
        sec_code='60490',
        corporate_number='4010401062386',
    ),
    'E31425': EdinetCodeEntry(
        edinet_code='E31425',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=649,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯデザインワン株式会社',
        submitter_name_en='GMO DesignOne, Inc.',
        submitter_name_yomi='ジーエムオーデザインワンカブシキガイシャ',
        address='新宿区新宿二丁目１６番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3010401088283',
    ),
    'E31429': EdinetCodeEntry(
        edinet_code='E31429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河端\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='カワバタ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31431': EdinetCodeEntry(
        edinet_code='E31431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='京橋興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウバシコウサンカブシキガイシャ',
        address='港区虎ノ門四丁目３番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001011892',
    ),
    'E31432': EdinetCodeEntry(
        edinet_code='E31432',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000利秋',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31435': EdinetCodeEntry(
        edinet_code='E31435',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ヨウテイホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨウテイホールディングスゴウドウカイシャ',
        address='港区西新橋一丁目１番１号ＥＰコンサルティングサービス内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010403012936',
    ),
    'E31436': EdinetCodeEntry(
        edinet_code='E31436',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=346,
        fiscal_year_end='12月末日',
        submitter_name='ＪＩＧ－ＳＡＷ株式会社',
        submitter_name_en='JIG-SAW INC.',
        submitter_name_yomi='ジグソーカブシキガイシャ',
        address='札幌市北区北八条西三丁目３２番',
        industry='情報・通信業',
        sec_code='39140',
        corporate_number='3430001027574',
    ),
    'E31437': EdinetCodeEntry(
        edinet_code='E31437',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＥＫＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーケーエス',
        address='福岡市早良区西新４－１－１－３１０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8290001056699',
    ),
    'E31439': EdinetCodeEntry(
        edinet_code='E31439',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福山\u3000明利',
        submitter_name_en=None,
        submitter_name_yomi='フクヤマ\u3000アキトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31440': EdinetCodeEntry(
        edinet_code='E31440',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井谷\u3000憲次',
        submitter_name_en=None,
        submitter_name_yomi='イタニ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31441': EdinetCodeEntry(
        edinet_code='E31441',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5391,
        fiscal_year_end='7月31日',
        submitter_name='株式会社シーアールイー',
        submitter_name_en='CRE, Inc.',
        submitter_name_yomi='カブシキガイシャシーアールイー',
        address='港区虎ノ門二丁目１０番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='7010001129517',
    ),
    'E31444': EdinetCodeEntry(
        edinet_code='E31444',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000英司',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31446': EdinetCodeEntry(
        edinet_code='E31446',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=436,
        fiscal_year_end='3月末日',
        submitter_name='株式会社レントラックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャレントラックス',
        address='江戸川区西葛西五丁目２番３号',
        industry='サービス業',
        sec_code='60450',
        corporate_number='6011701010603',
    ),
    'E31447': EdinetCodeEntry(
        edinet_code='E31447',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='方\u3000永義',
        submitter_name_en=None,
        submitter_name_yomi='ホウ\u3000ナガヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31448': EdinetCodeEntry(
        edinet_code='E31448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月30日',
        submitter_name='株式会社リンクバル',
        submitter_name_en='LINKBAL INC.',
        submitter_name_yomi='カブシキガイシャリンクバル',
        address='中央区明石町７番１４号',
        industry='サービス業',
        sec_code='60460',
        corporate_number='1010001143952',
    ),
    'E31450': EdinetCodeEntry(
        edinet_code='E31450',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='貝塚\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='カイヅカ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31452': EdinetCodeEntry(
        edinet_code='E31452',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=118224,
        fiscal_year_end='10月31日',
        submitter_name='キーサイト・テクノロジーズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='キーサイトテクノロジーズインク',
        address='アメリカ合衆国カリフォルニア州９５４０３、サンタローザ、ファウンテングローブ・パークウェイ１４００',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E31453': EdinetCodeEntry(
        edinet_code='E31453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=464,
        fiscal_year_end='2月末日',
        submitter_name='株式会社テラスカイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテラスカイ',
        address='中央区日本橋２－１１－２',
        industry='情報・通信業',
        sec_code='39150',
        corporate_number='5010001125410',
    ),
    'E31454': EdinetCodeEntry(
        edinet_code='E31454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4099,
        fiscal_year_end='5月31日',
        submitter_name='株式会社Ｇｕｎｏｓｙ',
        submitter_name_en='Gunosy Inc.',
        submitter_name_yomi='カブシキガイシャグノシー',
        address='渋谷区渋谷二丁目２４番１２号',
        industry='サービス業',
        sec_code='60470',
        corporate_number='5010401102810',
    ),
    'E31457': EdinetCodeEntry(
        edinet_code='E31457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森\u3000雅弘',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31458': EdinetCodeEntry(
        edinet_code='E31458',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永田\u3000豊志',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000トヨシ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31459': EdinetCodeEntry(
        edinet_code='E31459',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉弘\u3000和正',
        submitter_name_en=None,
        submitter_name_yomi='ヨシヒロ\u3000カズマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31470': EdinetCodeEntry(
        edinet_code='E31470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久田\u3000敏貴',
        submitter_name_en=None,
        submitter_name_yomi='ヒサダ\u3000トシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31471': EdinetCodeEntry(
        edinet_code='E31471',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢＩファイナンシャルサービシーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイファイナンシャルサービシーズカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401100313',
    ),
    'E31472': EdinetCodeEntry(
        edinet_code='E31472',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=119,
        fiscal_year_end=None,
        submitter_name='ＶＩＥＴＮＡＭ\u3000ＰＲＥＣＩＳＩＯＮ\u3000ＩＮＤＵＳＴＲＩＡＬ\u3000ＣＯ．，ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ベトナムプレシジョンインダストリアルカンパニーリミテッド',
        address='Ｎｏ．４，Ｆｒａｎｋｙ\u3000Ｂｕｉｌｄｉｎｇ，\u3000Ｐｒｏｖｉｄｅｎｃｅ\u3000Ｉｎｄｕｓｔｒｉａｌ\u3000Ｅｓｔａｔｅ，Ｍａｈｅ，Ｓｅｙｃｈｅｌｌｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31476': EdinetCodeEntry(
        edinet_code='E31476',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='ニッセイ・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッセイキャピタルカブシキカイシャ',
        address='千代田区丸の内二丁目３番２号郵船ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001025943',
    ),
    'E31479': EdinetCodeEntry(
        edinet_code='E31479',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='椎葉\u3000忠志',
        submitter_name_en=None,
        submitter_name_yomi='シイバ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31486': EdinetCodeEntry(
        edinet_code='E31486',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000貴史',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31488': EdinetCodeEntry(
        edinet_code='E31488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蒲生\u3000徳子',
        submitter_name_en=None,
        submitter_name_yomi='ガモウ\u3000ノリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31490': EdinetCodeEntry(
        edinet_code='E31490',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000まり',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000マリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31492': EdinetCodeEntry(
        edinet_code='E31492',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=225,
        fiscal_year_end=None,
        submitter_name='Ｇｏｏｄｈａｒｔ\u3000Ｐａｒｔｎｅｒｓ\u3000ＬＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='グッドハート\u3000パートナーズ\u3000エルエルピー',
        address='Ｑｕｅｅｎｓｌａｎｄ\u3000Ｈｏｕｓｅ\u3000３９３\u3000Ｓｔｒａｎｄ\u3000Ｌｏｎｄｏｎ\u3000ＷＣ２Ｒ\u3000０ＬＴ\u3000Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31493': EdinetCodeEntry(
        edinet_code='E31493',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=43,
        fiscal_year_end=None,
        submitter_name='バークレイズ・マルチマネージャー・ファンド・パブリック・リミテッド・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='バークレイズマルチマネージャーファンドパブリックリミテッドカンパニー',
        address='アイルランド、ダブリン２、グランド・カナル・スクエア２、６階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31494': EdinetCodeEntry(
        edinet_code='E31494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村田\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='ムラタ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31497': EdinetCodeEntry(
        edinet_code='E31497',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='エコ・キャピタル合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エコキャピタルゴウドウカイシャ',
        address='港区北青山三丁目５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003021575',
    ),
    'E31499': EdinetCodeEntry(
        edinet_code='E31499',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＡＯＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーオーアイカブシキガイシャ',
        address='小田原市栄町２ー１２ー１５釼持ビル２０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7021001055454',
    ),
    'E31501': EdinetCodeEntry(
        edinet_code='E31501',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='斉藤\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31504': EdinetCodeEntry(
        edinet_code='E31504',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=304549,
        fiscal_year_end='12月31日',
        submitter_name='マラヤン・バンキング・ベルハッド',
        submitter_name_en=None,
        submitter_name_yomi='マラヤンバンキングベルハッド',
        address='マレーシア\u3000クアラルンプール５００５０\u3000ジャラン・トゥン・ペラック１００\u3000メナラ・メイバンク１４階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E31507': EdinetCodeEntry(
        edinet_code='E31507',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='深川\u3000堅治',
        submitter_name_en=None,
        submitter_name_yomi='フカガワ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31509': EdinetCodeEntry(
        edinet_code='E31509',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｌｏ，Ｓｅｎ－Ｃｈｏｕ',
        submitter_name_en=None,
        submitter_name_yomi='ロウ\u3000センチョウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31510': EdinetCodeEntry(
        edinet_code='E31510',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｌｏ，Ｌｉ－Ｃｈｕｎ',
        submitter_name_en=None,
        submitter_name_yomi='ローリーチュン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31515': EdinetCodeEntry(
        edinet_code='E31515',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社セガグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセガグループ',
        address='品川区西品川一丁目１－１住友不動産大崎ガーデンタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010701030662',
    ),
    'E31516': EdinetCodeEntry(
        edinet_code='E31516',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='株式会社不二',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジ',
        address='浜松市中央区神田町１１７９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6080401004603',
    ),
    'E31518': EdinetCodeEntry(
        edinet_code='E31518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山川\u3000真考',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワ\u3000マスナル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31521': EdinetCodeEntry(
        edinet_code='E31521',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1123,
        fiscal_year_end=None,
        submitter_name='Ｐｒｉｎｃｉｐａｌ\u3000Ｇｌｏｂａｌ\u3000Ｉｎｖｅｓｔｏｒｓ，ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='プリンシパルグローバルインベスターズエルエルシー',
        address='アメリカ合衆国アイオワ州デモイン市ハイストリート７１１番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31524': EdinetCodeEntry(
        edinet_code='E31524',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1044,
        fiscal_year_end='6月30日',
        submitter_name='株式会社スマートバリュー',
        submitter_name_en='Smartvalue Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャスマートバリュー',
        address='大阪市中央区道修町３丁目６番１号',
        industry='情報・通信業',
        sec_code='94170',
        corporate_number='6120101002687',
    ),
    'E31526': EdinetCodeEntry(
        edinet_code='E31526',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ミズノ・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミズノホールディングス',
        address='名古屋市中区丸の内二丁目９番４０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001117578',
    ),
    'E31533': EdinetCodeEntry(
        edinet_code='E31533',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='スカイオーシャン・アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スカイオーシャンアセットマネジメントカブシキガイシャ',
        address='横浜市西区みなとみらい３－１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020001108566',
    ),
    'E31536': EdinetCodeEntry(
        edinet_code='E31536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川西\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='カワニシ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31537': EdinetCodeEntry(
        edinet_code='E31537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森\u3000敬太',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000ケイタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31538': EdinetCodeEntry(
        edinet_code='E31538',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000知広',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31541': EdinetCodeEntry(
        edinet_code='E31541',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3500,
        fiscal_year_end=None,
        submitter_name='国分ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コクブホールディングスカブシキガイシャ',
        address='中央区日本橋一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001137401',
    ),
    'E31542': EdinetCodeEntry(
        edinet_code='E31542',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=349,
        fiscal_year_end='3月31日',
        submitter_name='株式会社中村超硬',
        submitter_name_en='NAKAMURA CHOUKOU CO., LTD.',
        submitter_name_yomi='カブシキガイシャナカムラチョウコウ',
        address='堺市西区鶴田町２７番２７号',
        industry='機械',
        sec_code='61660',
        corporate_number='1120101005629',
    ),
    'E31543': EdinetCodeEntry(
        edinet_code='E31543',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13102968,
        fiscal_year_end='4月末日',
        submitter_name='メドトロニック・パブリック・リミテッド・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='メドトロニックパブリックリミテッドカンパニー',
        address='アイルランド共和国、ゴールウェイ、パークモア・ビジネスパーク西、ビルディング２',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E31546': EdinetCodeEntry(
        edinet_code='E31546',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=660,
        fiscal_year_end=None,
        submitter_name='ＫＯＰＥＲＮＩＫ\u3000ＧＬＯＢＡＬ\u3000ＩＮＶＥＳＴＯＲＳ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='コペルニック\u3000グローバル\u3000インヴェスターズ\u3000エルエルシー',
        address='２７１１\u3000Ｃｅｎｔｅｒｖｉｌｌｅ\u3000Ｒｏａｄ，Ｓｕｉｔｅ\u3000４００，\u3000Ｃｉｔｙ\u3000ｏｆ\u3000Ｗｉｌｍｉｎｇｔｏｎ，\u3000Ｄｅｌａｗａｒｅ\u3000１９８０８，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31547': EdinetCodeEntry(
        edinet_code='E31547',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高畠\u3000昭雄',
        submitter_name_en=None,
        submitter_name_yomi='タカハタ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31548': EdinetCodeEntry(
        edinet_code='E31548',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000新司',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000シンジ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31551': EdinetCodeEntry(
        edinet_code='E31551',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=306,
        fiscal_year_end='6月30日',
        submitter_name='株式会社マーケットエンタープライズ',
        submitter_name_en='MarketEnterprise Co.,Ltd',
        submitter_name_yomi='カブシキガイシャマーケットエンタープライズ',
        address='墨田区亀沢三丁目３番１４号',
        industry='サービス業',
        sec_code='31350',
        corporate_number='7010601032252',
    ),
    'E31552': EdinetCodeEntry(
        edinet_code='E31552',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000諒子',
        submitter_name_en=None,
        submitter_name_yomi='ナカシマ\u3000リョウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31555': EdinetCodeEntry(
        edinet_code='E31555',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000義兼',
        submitter_name_en=None,
        submitter_name_yomi='ナカシマ\u3000ヨシカネ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31560': EdinetCodeEntry(
        edinet_code='E31560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5379,
        fiscal_year_end='3月末日',
        submitter_name='株式会社メニコン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャメニコン',
        address='名古屋市中区葵三丁目２１番１９号',
        industry='精密機器',
        sec_code='77800',
        corporate_number='7180001017589',
    ),
    'E31573': EdinetCodeEntry(
        edinet_code='E31573',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=453,
        fiscal_year_end='6月30日',
        submitter_name='デジタル・インフォメーション・テクノロジー株式会社',
        submitter_name_en='Digital Information Technologies Corporation',
        submitter_name_yomi='デジタルインフォメーションテクノロジーカブシキガイシャ',
        address='中央区八丁堀四丁目５番４号',
        industry='情報・通信業',
        sec_code='39160',
        corporate_number='9010001103734',
    ),
    'E31574': EdinetCodeEntry(
        edinet_code='E31574',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=279,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ファンデリー',
        submitter_name_en='Fundely Co., Ltd.',
        submitter_name_yomi='カブシキガイシャファンデリー',
        address='北区赤羽二丁目５１番３号',
        industry='小売業',
        sec_code='31370',
        corporate_number='5011501004062',
    ),
    'E31575': EdinetCodeEntry(
        edinet_code='E31575',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1253,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ナガオカ',
        submitter_name_en='NAGAOKA INTERNATIONAL CORPORATION',
        submitter_name_yomi='カブシキカイシャナガオカ',
        address='大阪市中央区安土町一丁目８番１５号',
        industry='機械',
        sec_code='62390',
        corporate_number='5120101043534',
    ),
    'E31580': EdinetCodeEntry(
        edinet_code='E31580',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=169,
        fiscal_year_end='2月末日',
        submitter_name='株式会社サーバーワークス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサーバーワークス',
        address='新宿区揚場町１番２１号',
        industry='情報・通信業',
        sec_code='44340',
        corporate_number='1011101054073',
    ),
    'E31581': EdinetCodeEntry(
        edinet_code='E31581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川畑\u3000泰史',
        submitter_name_en=None,
        submitter_name_yomi='カワバタ\u3000ヤスフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31583': EdinetCodeEntry(
        edinet_code='E31583',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｌｕｘ）ストラテジー・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスルクスストラテジーシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31585': EdinetCodeEntry(
        edinet_code='E31585',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=503,
        fiscal_year_end='2月末日',
        submitter_name='パイプドＨＤ株式会社',
        submitter_name_en='PiPEDO HD, Inc.',
        submitter_name_yomi='パイプドホールディングスカブシキカイシャ',
        address='港区赤坂２丁目９番１１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010401120239',
    ),
    'E31587': EdinetCodeEntry(
        edinet_code='E31587',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='株式会社ハマダ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハマダ',
        address='姫路市網干区新在家１２６１－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001060770',
    ),
    'E31588': EdinetCodeEntry(
        edinet_code='E31588',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=335,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エコノス',
        submitter_name_en='ECONOS Co., Ltd',
        submitter_name_yomi='カブシキガイシャエコノス',
        address='札幌市白石区北郷四条十三丁目３番２５号',
        industry='小売業',
        sec_code=None,
        corporate_number='3430001029991',
    ),
    'E31594': EdinetCodeEntry(
        edinet_code='E31594',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=164,
        fiscal_year_end='3月31日',
        submitter_name='冨士ダイス株式会社',
        submitter_name_en='Fuji Die Co.,Ltd.',
        submitter_name_yomi='フジダイスカブシキガイシャ',
        address='大田区下丸子二丁目１７番１０号',
        industry='機械',
        sec_code='61670',
        corporate_number='4010801010218',
    ),
    'E31598': EdinetCodeEntry(
        edinet_code='E31598',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11438,
        fiscal_year_end=None,
        submitter_name='ＲＵＳＳＥＬＬ\u3000ＩＮＶＥＳＴＭＥＮＴＳ\u3000ＩＭＰＬＥＭＥＮＴＡＴＩＯＮ\u3000ＳＥＲＶＩＣＥＳ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ラッセル\u3000インベストメント\u3000インプリメンテーション\u3000サービシーズ\u3000エル\u3000エル\u3000シー',
        address='４０１\u3000Ｕｎｉｏｎ\u3000Ｓｔｒｅｅｔ，\u3000１８ｔｈ\u3000Ｆｌｏｏｒ，\u3000Ｓｅａｔｔｌｅ，\u3000ＷＡ\u3000９８１０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31602': EdinetCodeEntry(
        edinet_code='E31602',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=558,
        fiscal_year_end='6月30日',
        submitter_name='株式会社平山ホールディングス',
        submitter_name_en='HIRAYAMA HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャヒラヤマホールディングス',
        address='港区港南１丁目８番４０号',
        industry='精密機器',
        sec_code='77810',
        corporate_number='8010401098518',
    ),
    'E31603': EdinetCodeEntry(
        edinet_code='E31603',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｌａｉ\u3000Ｍａｎｋｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='ライ\u3000マンコン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31604': EdinetCodeEntry(
        edinet_code='E31604',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=82654,
        fiscal_year_end=None,
        submitter_name='サムティ・レジデンシャル投資法人',
        submitter_name_en=None,
        submitter_name_yomi='サムティレジデンシャルトウシホウジン',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005023705',
    ),
    'E31607': EdinetCodeEntry(
        edinet_code='E31607',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000勝也',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31608': EdinetCodeEntry(
        edinet_code='E31608',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石澤\u3000淳一',
        submitter_name_en=None,
        submitter_name_yomi='イシザワ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31609': EdinetCodeEntry(
        edinet_code='E31609',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大久保\u3000利昭',
        submitter_name_en=None,
        submitter_name_yomi='オオクボ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31612': EdinetCodeEntry(
        edinet_code='E31612',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社九州フィナンシャルグループ',
        submitter_name_en='Kyushu Financial Group,Inc.',
        submitter_name_yomi='カブシキカイシャキュウシュウフィナンシャルグループ',
        address='鹿児島市金生町６番６号',
        industry='銀行業',
        sec_code='71800',
        corporate_number='2340001018765',
    ),
    'E31614': EdinetCodeEntry(
        edinet_code='E31614',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1321,
        fiscal_year_end='6月末日',
        submitter_name='株式会社Ｌｉｂ\u3000Ｗｏｒｋ',
        submitter_name_en='Lib Work Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャリブワーク',
        address='山鹿市鍋田１７８番地１',
        industry='建設業',
        sec_code='14310',
        corporate_number='7330001010363',
    ),
    'E31618': EdinetCodeEntry(
        edinet_code='E31618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鍵本\u3000忠尚',
        submitter_name_en=None,
        submitter_name_yomi='カギモト\u3000タダヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31621': EdinetCodeEntry(
        edinet_code='E31621',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西野\u3000伸一郎',
        submitter_name_en=None,
        submitter_name_yomi='ニシノ\u3000シンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31622': EdinetCodeEntry(
        edinet_code='E31622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=215,
        fiscal_year_end='6月末日',
        submitter_name='株式会社クレステック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクレステック',
        address='浜松市中央区東三方町６９番地',
        industry='その他製品',
        sec_code='78120',
        corporate_number='1080401001547',
    ),
    'E31624': EdinetCodeEntry(
        edinet_code='E31624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2486,
        fiscal_year_end='3月31日',
        submitter_name='大木ヘルスケアホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオキヘルスケアホールディングスカブシキガイシャ',
        address='文京区音羽二丁目１番４号',
        industry='卸売業',
        sec_code='34170',
        corporate_number='2010001170789',
    ),
    'E31625': EdinetCodeEntry(
        edinet_code='E31625',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=162,
        fiscal_year_end='12月末日',
        submitter_name='株式会社富士山マガジンサービス',
        submitter_name_en='Fujisan Magazine Service Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャフジサンマガジンサービス',
        address='渋谷区南平台町１６番１１号',
        industry='小売業',
        sec_code='31380',
        corporate_number='1011001038837',
    ),
    'E31626': EdinetCodeEntry(
        edinet_code='E31626',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1051,
        fiscal_year_end='3月末日',
        submitter_name='株式会社アイリッジ',
        submitter_name_en='iRidge,Inc.',
        submitter_name_yomi='カブシキガイシャアイリッジ',
        address='港区麻布台一丁目１１番９号',
        industry='情報・通信業',
        sec_code='39170',
        corporate_number='4011001071991',
    ),
    'E31627': EdinetCodeEntry(
        edinet_code='E31627',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=7,
        fiscal_year_end='4月30日',
        submitter_name='株式会社東京クラシック',
        submitter_name_en='TOKYO CLASSIC CO.,LTD.',
        submitter_name_yomi='カブシキガイシャトウキョウクラシック',
        address='大阪市中央区伏見町四丁目４番９号オーエックス淀屋橋ビル９Ｆ',
        industry='サービス業',
        sec_code=None,
        corporate_number='7120001190680',
    ),
    'E31630': EdinetCodeEntry(
        edinet_code='E31630',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小田\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31631': EdinetCodeEntry(
        edinet_code='E31631',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1425,
        fiscal_year_end=None,
        submitter_name='兼松コミュニケーションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カネマツコミュニケーションズカブシキガイシャ',
        address='渋谷区代々木三丁目２２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101031601',
    ),
    'E31632': EdinetCodeEntry(
        edinet_code='E31632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40000,
        fiscal_year_end='3月31日',
        submitter_name='コスモエネルギーホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コスモエネルギーホールディングスカブシキカイシャ',
        address='港区芝浦一丁目１番１号',
        industry='石油・石炭製品',
        sec_code='50210',
        corporate_number='1010401120741',
    ),
    'E31633': EdinetCodeEntry(
        edinet_code='E31633',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16194,
        fiscal_year_end='3月末日',
        submitter_name='デクセリアルズ株式会社',
        submitter_name_en='Dexerials Corporation',
        submitter_name_yomi='デクセリアルズカブシキガイシャ',
        address='下野市下坪山１７２４',
        industry='化学',
        sec_code='49800',
        corporate_number='4010001147620',
    ),
    'E31635': EdinetCodeEntry(
        edinet_code='E31635',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4000,
        fiscal_year_end='3月末日',
        submitter_name='株式会社Ｃ＆Ｆロジホールディングス',
        submitter_name_en='Chilled & Frozen Logistics Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシーアンドエフロジホールディングス',
        address='新宿区若松町３３番８号',
        industry='陸運業',
        sec_code=None,
        corporate_number='6011101074769',
    ),
    'E31636': EdinetCodeEntry(
        edinet_code='E31636',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中澤\u3000正幸',
        submitter_name_en=None,
        submitter_name_yomi='ナカザワ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31638': EdinetCodeEntry(
        edinet_code='E31638',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='剣豪集団株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケンゴウシュウダンカブシキカイシャ',
        address='神戸市東灘区向洋町中１－１７アジアワンセンター',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001021843',
    ),
    'E31640': EdinetCodeEntry(
        edinet_code='E31640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2091,
        fiscal_year_end='3月末日',
        submitter_name='ＰＣＩホールディングス株式会社',
        submitter_name_en='PCI Holdings, Inc.',
        submitter_name_yomi='ピーシーアイホールディングスカブシキガイシャ',
        address='港区虎ノ門一丁目２１番１９号',
        industry='情報・通信業',
        sec_code='39180',
        corporate_number='2010701018957',
    ),
    'E31649': EdinetCodeEntry(
        edinet_code='E31649',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平山\u3000惠一',
        submitter_name_en=None,
        submitter_name_yomi='ヒラヤマ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31650': EdinetCodeEntry(
        edinet_code='E31650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000公祐',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000コウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31652': EdinetCodeEntry(
        edinet_code='E31652',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31653': EdinetCodeEntry(
        edinet_code='E31653',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加茂\u3000知之',
        submitter_name_en=None,
        submitter_name_yomi='カモ\u3000トモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31654': EdinetCodeEntry(
        edinet_code='E31654',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小林\u3000泰士',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31657': EdinetCodeEntry(
        edinet_code='E31657',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平山\u3000善一',
        submitter_name_en=None,
        submitter_name_yomi='ヒラヤマ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31658': EdinetCodeEntry(
        edinet_code='E31658',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=29360,
        fiscal_year_end='3月末日',
        submitter_name='昭和リース株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウワリースカブシキガイシャ',
        address='中央区日本橋室町二丁目４番３号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010001142187',
    ),
    'E31659': EdinetCodeEntry(
        edinet_code='E31659',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市川\u3000憲和',
        submitter_name_en=None,
        submitter_name_yomi='イチカワ\u3000ノリカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31660': EdinetCodeEntry(
        edinet_code='E31660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='市川\u3000聡',
        submitter_name_en=None,
        submitter_name_yomi='イチカワ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31662': EdinetCodeEntry(
        edinet_code='E31662',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渋谷\u3000順',
        submitter_name_en=None,
        submitter_name_yomi='ジブヤ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31665': EdinetCodeEntry(
        edinet_code='E31665',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渋谷\u3000一正',
        submitter_name_en=None,
        submitter_name_yomi='シブヤ\u3000カズマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31666': EdinetCodeEntry(
        edinet_code='E31666',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ハクトコーポレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハクトコーポレーションカブシキカイシャ',
        address='芦屋市岩園町１５－２４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140001029595',
    ),
    'E31670': EdinetCodeEntry(
        edinet_code='E31670',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ａｐａｍａｎ\u3000Ｎｅｔｗｏｒｋ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アパマンネットワークカブシキガイシャ',
        address='千代田区丸の内一丁目８番１号丸の内トラストタワーＮ館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001098999',
    ),
    'E31671': EdinetCodeEntry(
        edinet_code='E31671',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6597,
        fiscal_year_end=None,
        submitter_name='アバディーン・インベストメント・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アバディーン\u3000インベストメント\u3000マネジメント\u3000リミテッド',
        address='英国\u3000スコットランド\u3000エディンバラ\u3000ジョージストリート\u3000１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31672': EdinetCodeEntry(
        edinet_code='E31672',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=27,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ユリアインターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャユリアインターナショナル',
        address='新宿区新宿二丁目４番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='4011101053436',
    ),
    'E31676': EdinetCodeEntry(
        edinet_code='E31676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4300,
        fiscal_year_end=None,
        submitter_name='名古屋中小企業投資育成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナゴヤチュウショウキギョウトウシイクセイカブシキガイシャ',
        address='名古屋市中村区名駅南一丁目１６番３０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001031846',
    ),
    'E31678': EdinetCodeEntry(
        edinet_code='E31678',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='ちばぎんアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チバギンアセットマネジメントカブシキカイシャ',
        address='墨田区江東橋二丁目１３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010601038669',
    ),
    'E31681': EdinetCodeEntry(
        edinet_code='E31681',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=600,
        fiscal_year_end='9月30日',
        submitter_name='株式会社パルマ',
        submitter_name_en='Palma Co., Ltd.',
        submitter_name_yomi='カブシキガイシャパルマ',
        address='千代田区麹町四丁目５番地２０',
        industry='不動産業',
        sec_code='34610',
        corporate_number='6010001082675',
    ),
    'E31686': EdinetCodeEntry(
        edinet_code='E31686',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ニッテン共栄会\u3000会長\u3000杉山\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='ニッテンキョウエイカイ\u3000カイチョウ\u3000スギヤマ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31692': EdinetCodeEntry(
        edinet_code='E31692',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙林\u3000彰',
        submitter_name_en=None,
        submitter_name_yomi='タカバヤシ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31693': EdinetCodeEntry(
        edinet_code='E31693',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=46,
        fiscal_year_end=None,
        submitter_name='株式会社トヨトミ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトヨトミ',
        address='名古屋市千種区山門町一丁目４８番地の８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001004855',
    ),
    'E31694': EdinetCodeEntry(
        edinet_code='E31694',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1013,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アクアライン',
        submitter_name_en='Aqualine Ltd.',
        submitter_name_yomi='カブシキガイシャアクアライン',
        address='広島市中区上八丁堀８番８号第１ウエノヤビル６階',
        industry='サービス業',
        sec_code='61730',
        corporate_number='3240001014666',
    ),
    'E31696': EdinetCodeEntry(
        edinet_code='E31696',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社マミ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマミ',
        address='名古屋市東区葵一丁目２番２０号シティタワー葵８１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001002965',
    ),
    'E31714': EdinetCodeEntry(
        edinet_code='E31714',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='矢作\u3000玲子',
        submitter_name_en=None,
        submitter_name_yomi='ヤハギ\u3000レイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31718': EdinetCodeEntry(
        edinet_code='E31718',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新庄\u3000美智子',
        submitter_name_en=None,
        submitter_name_yomi='シンジョウ\u3000ミチコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31720': EdinetCodeEntry(
        edinet_code='E31720',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='大和企業投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイワキギョウトウシカブシキガイシャ',
        address='千代田区丸の内１－９－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001153347',
    ),
    'E31723': EdinetCodeEntry(
        edinet_code='E31723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1181,
        fiscal_year_end='12月31日',
        submitter_name='株式会社土木管理総合試験所',
        submitter_name_en='C.E.Management Integrated Laboratory Co.Ltd',
        submitter_name_yomi='カブシキカイシャドボクカンリソウゴウシケンジョ',
        address='長野市篠ノ井御幣川８７７番地１',
        industry='サービス業',
        sec_code='61710',
        corporate_number='8100001002184',
    ),
    'E31729': EdinetCodeEntry(
        edinet_code='E31729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1134,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ラクト・ジャパン',
        submitter_name_en='Lacto Japan Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャラクトジャパン',
        address='中央区日本橋二丁目１１番２号',
        industry='卸売業',
        sec_code='31390',
        corporate_number='5010001051615',
    ),
    'E31731': EdinetCodeEntry(
        edinet_code='E31731',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=843,
        fiscal_year_end='1月31日',
        submitter_name='ベステラ株式会社',
        submitter_name_en='BESTERRA CO., LTD',
        submitter_name_yomi='ベステラカブシキガイシャ',
        address='江東区平野三丁目２番６号',
        industry='建設業',
        sec_code='14330',
        corporate_number='7010601021305',
    ),
    'E31732': EdinetCodeEntry(
        edinet_code='E31732',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メタップス',
        submitter_name_en='Metaps Inc.',
        submitter_name_yomi='カブシキガイシャメタップス',
        address='渋谷区渋谷２－２４－１２\u3000渋谷スクランブルスクエア',
        industry='サービス業',
        sec_code=None,
        corporate_number='2011101057356',
    ),
    'E31734': EdinetCodeEntry(
        edinet_code='E31734',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12000,
        fiscal_year_end=None,
        submitter_name='ＣＴ\u3000ＢＲＩＧＨＴ\u3000ＨＯＬＤＩＮＧＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シテイ\u3000ブライト\u3000ホルディングス\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000Ⅱ，Ｒｏａｄ\u3000Ｔｏｗｎ，Ｔｏｒｔｏｌａ，ＶＧ１１１０，Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31741': EdinetCodeEntry(
        edinet_code='E31741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=971,
        fiscal_year_end='8月31日',
        submitter_name='ＪＥＳＣＯホールディングス株式会社',
        submitter_name_en='JESCO Holdings, Inc.',
        submitter_name_yomi='ジェスコホールディングスカブシキガイシャ',
        address='新宿区中落合三丁目２５番１４号',
        industry='建設業',
        sec_code='14340',
        corporate_number='1011101008616',
    ),
    'E31742': EdinetCodeEntry(
        edinet_code='E31742',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=576,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＴＯＫＹＯ\u3000ＢＡＳＥ',
        submitter_name_en='TOKYO BASE Co., Ltd.',
        submitter_name_yomi='カブシキガイシャトウキョウベース',
        address='港区南青山３丁目１１番１３号',
        industry='小売業',
        sec_code='34150',
        corporate_number='9011001058992',
    ),
    'E31743': EdinetCodeEntry(
        edinet_code='E31743',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=96,
        fiscal_year_end='8月末日',
        submitter_name='ユーピーアール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユーピーアールカブシキカイシャ',
        address='宇部市寿町三丁目５番２６号',
        industry='サービス業',
        sec_code='70650',
        corporate_number='5250001003039',
    ),
    'E31744': EdinetCodeEntry(
        edinet_code='E31744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＧＣＩアセット・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジーシーアイアセットマネジメント',
        address='千代田区大手町二丁目６－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001076579',
    ),
    'E31745': EdinetCodeEntry(
        edinet_code='E31745',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=428,
        fiscal_year_end='4月30日',
        submitter_name='株式会社Ａｌｌ\u3000Ａｄｓ',
        submitter_name_en='All Ads, Inc.',
        submitter_name_yomi='カブシキカイシャオルアズ',
        address='港区南青山一丁目２番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7011001070909',
    ),
    'E31746': EdinetCodeEntry(
        edinet_code='E31746',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀬口\u3000力',
        submitter_name_en=None,
        submitter_name_yomi='セグチ\u3000チカラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31747': EdinetCodeEntry(
        edinet_code='E31747',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀬口\u3000悦子',
        submitter_name_en=None,
        submitter_name_yomi='セグチ\u3000エツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31748': EdinetCodeEntry(
        edinet_code='E31748',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3500000,
        fiscal_year_end='3月31日',
        submitter_name='日本郵政株式会社',
        submitter_name_en='Japan Post Holdings Co., Ltd.',
        submitter_name_yomi='ニッポンユウセイカブシキガイシャ',
        address='千代田区大手町二丁目３番１号',
        industry='サービス業',
        sec_code='61780',
        corporate_number='5010001112697',
    ),
    'E31749': EdinetCodeEntry(
        edinet_code='E31749',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=325,
        fiscal_year_end='12月末日',
        submitter_name='ピクスタ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピクスタカブシキガイシャ',
        address='渋谷区渋谷２丁目２１番１号\u3000渋谷ヒカリエ３３階\u3000ＪｕｓｔＣｏ\u3000Ｓｈｉｂｕｙａ\u3000Ｈｉｋａｒｉｅ',
        industry='小売業',
        sec_code='34160',
        corporate_number='1011001067555',
    ),
    'E31750': EdinetCodeEntry(
        edinet_code='E31750',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社日比谷コンピュータシステム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒビヤコンピュータシステム',
        address='江東区東陽二丁目４番３８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010601026369',
    ),
    'E31751': EdinetCodeEntry(
        edinet_code='E31751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1718,
        fiscal_year_end='9月30日',
        submitter_name='リネットジャパングループ株式会社',
        submitter_name_en='RenetJapanGroup,Inc.',
        submitter_name_yomi='リネットジャパングループカブシキガイシャ',
        address='大府市柊山町三丁目３３番地',
        industry='小売業',
        sec_code='35560',
        corporate_number='8180001093877',
    ),
    'E31754': EdinetCodeEntry(
        edinet_code='E31754',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=443,
        fiscal_year_end='9月30日',
        submitter_name='アイビーシー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイビーシーカブシキカイシャ',
        address='中央区新川一丁目８番８号',
        industry='情報・通信業',
        sec_code='39200',
        corporate_number='6010001080514',
    ),
    'E31755': EdinetCodeEntry(
        edinet_code='E31755',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=500000,
        fiscal_year_end='3月末日',
        submitter_name='株式会社かんぽ生命保険',
        submitter_name_en='JAPAN POST INSURANCE Co. ,  Ltd.',
        submitter_name_yomi='カブシキガイシャカンポセイメイホケン',
        address='千代田区大手町二丁目３番１号',
        industry='保険業',
        sec_code='71810',
        corporate_number='6010001112696',
    ),
    'E31759': EdinetCodeEntry(
        edinet_code='E31759',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大垣内\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='オオコウチ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31760': EdinetCodeEntry(
        edinet_code='E31760',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社Ｙ＆Ｕ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイアンドユー',
        address='千代田区神田神保町二丁目１０番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001101610',
    ),
    'E31762': EdinetCodeEntry(
        edinet_code='E31762',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長野\u3000貴浩',
        submitter_name_en=None,
        submitter_name_yomi='ナガノ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31763': EdinetCodeEntry(
        edinet_code='E31763',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮本\u3000邦久',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000クニヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31768': EdinetCodeEntry(
        edinet_code='E31768',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山木\u3000学',
        submitter_name_en=None,
        submitter_name_yomi='ヤマキ\u3000マナブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31769': EdinetCodeEntry(
        edinet_code='E31769',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000裕之',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31772': EdinetCodeEntry(
        edinet_code='E31772',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000順之亮',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ジュンノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31774': EdinetCodeEntry(
        edinet_code='E31774',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='明海興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メイカイコウサンカブシキガイシャ',
        address='神戸市中央区京町７６番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001011258',
    ),
    'E31775': EdinetCodeEntry(
        edinet_code='E31775',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3500000,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ゆうちょ銀行',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユウチョギンコウ',
        address='千代田区丸の内二丁目７番２号',
        industry='銀行業',
        sec_code='71820',
        corporate_number='5010001112730',
    ),
    'E31776': EdinetCodeEntry(
        edinet_code='E31776',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=621,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ブランジスタ',
        submitter_name_en='Brangista inc.',
        submitter_name_yomi='カブシキガイシャブランジスタ',
        address='渋谷区桜丘町２０番４号ネクシィーズスクエアビル',
        industry='サービス業',
        sec_code='61760',
        corporate_number='4011001035708',
    ),
    'E31791': EdinetCodeEntry(
        edinet_code='E31791',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1000,
        fiscal_year_end='3月末日',
        submitter_name='輸出入・港湾関連情報処理センター株式会社',
        submitter_name_en='Nippon Automated Cargo And Port Consolidated System, Inc.',
        submitter_name_yomi='ユシュツニュウコウワンカンレンジョウホウショリセンターカブシキガイシャ',
        address='港区浜松町１丁目３番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3020001081423',
    ),
    'E31800': EdinetCodeEntry(
        edinet_code='E31800',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤航陽',
        submitter_name_en=None,
        submitter_name_yomi='サトウカツアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31815': EdinetCodeEntry(
        edinet_code='E31815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=466,
        fiscal_year_end='7月31日',
        submitter_name='株式会社バルニバービ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャバルニバービ',
        address='大阪市中央区南船場４丁目１２番２１号',
        industry='サービス業',
        sec_code='34180',
        corporate_number='1120001087528',
    ),
    'E31817': EdinetCodeEntry(
        edinet_code='E31817',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=287,
        fiscal_year_end='12月31日',
        submitter_name='ＡｐｐＢａｎｋ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アップバンクカブシキカイシャ',
        address='新宿区新宿１－１９－１０',
        industry='サービス業',
        sec_code='61770',
        corporate_number='4021001047248',
    ),
    'E31818': EdinetCodeEntry(
        edinet_code='E31818',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本\u3000俊洋',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31819': EdinetCodeEntry(
        edinet_code='E31819',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福田\u3000幸雄',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31820': EdinetCodeEntry(
        edinet_code='E31820',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＧＥＮＥＳＩＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェネシス',
        address='京都市中京区烏丸通御池下る虎屋町５６６－１\u3000井門明治安田生命ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4130001053856',
    ),
    'E31829': EdinetCodeEntry(
        edinet_code='E31829',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中水\u3000英紀',
        submitter_name_en=None,
        submitter_name_yomi='ナカミズ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31830': EdinetCodeEntry(
        edinet_code='E31830',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷\u3000正人',
        submitter_name_en=None,
        submitter_name_yomi='タニ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31835': EdinetCodeEntry(
        edinet_code='E31835',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉野\u3000炳樹',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノアキタツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31840': EdinetCodeEntry(
        edinet_code='E31840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉野\u3000佳秀',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノ\u3000ヨシヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31841': EdinetCodeEntry(
        edinet_code='E31841',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＥＲＲＡ・ＥＳＨＩＮＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テラエシノカブシキガイシャ',
        address='中央区勝どき６丁目３番１－４９０６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001167208',
    ),
    'E31848': EdinetCodeEntry(
        edinet_code='E31848',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1351,
        fiscal_year_end=None,
        submitter_name='情報技術開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジョウホウギジュツカイハツカブシキカイシャ',
        address='新宿区西新宿六丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001106943',
    ),
    'E31851': EdinetCodeEntry(
        edinet_code='E31851',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=362,
        fiscal_year_end='3月31日',
        submitter_name='ブライトパス・バイオ株式会社',
        submitter_name_en='BrightPath Biotherapeutics Co., Ltd.',
        submitter_name_yomi='ブライトパスバイオカブシキガイシャ',
        address='川崎市川崎区殿町三丁目２５番２２号',
        industry='医薬品',
        sec_code='45940',
        corporate_number='8290001050314',
    ),
    'E31854': EdinetCodeEntry(
        edinet_code='E31854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=761,
        fiscal_year_end='12月末日',
        submitter_name='ＧＭＯメディア株式会社',
        submitter_name_en='GMO Media, Inc.',
        submitter_name_yomi='ジーエムオーメディアカブシキカイシャ',
        address='渋谷区桜丘町２６番１号',
        industry='サービス業',
        sec_code='61800',
        corporate_number='6011001038592',
    ),
    'E31855': EdinetCodeEntry(
        edinet_code='E31855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=44,
        fiscal_year_end='3月末日',
        submitter_name='タメニー株式会社',
        submitter_name_en='Tameny Inc.',
        submitter_name_yomi='タメニーカブシキガイシャ',
        address='品川区大崎一丁目２０番３号',
        industry='サービス業',
        sec_code='61810',
        corporate_number='3010701024252',
    ),
    'E31857': EdinetCodeEntry(
        edinet_code='E31857',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＣＰ１号',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシーピーイチゴウ',
        address='千代田区内幸町１－２－１\u3000日土地内幸町ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010403013690',
    ),
    'E31862': EdinetCodeEntry(
        edinet_code='E31862',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='ＳＰＲＩＮＧ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スプリングカブシキガイシャ',
        address='新宿区西新宿三丁目２番９号\u3000新宿ワシントンホテルビル本館２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011101044938',
    ),
    'E31863': EdinetCodeEntry(
        edinet_code='E31863',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='村田ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ムラタホールディングス',
        address='新宿区西新宿三丁目２番９号\u3000新宿ワシントンホテルビル本館２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101074319',
    ),
    'E31866': EdinetCodeEntry(
        edinet_code='E31866',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＢＥＮＥＦＩＴ\u3000ＰＯＷＥＲ\u3000ＩＮＣ．',
        submitter_name_en=None,
        submitter_name_yomi='ベネフィット\u3000パワー\u3000インク',
        address='ＯＭＣ\u3000Ｃｈａｍｂｅｒｓ，Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ１，Ｒｏａｄ\u3000Ｔｏｗｎ，Ｔｏｒｔｏｌａ，Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31869': EdinetCodeEntry(
        edinet_code='E31869',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古俣\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='コマタ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31870': EdinetCodeEntry(
        edinet_code='E31870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31871': EdinetCodeEntry(
        edinet_code='E31871',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1038,
        fiscal_year_end='1月31日',
        submitter_name='株式会社鎌倉新書',
        submitter_name_en='Kamakura Shinsho, Ltd.',
        submitter_name_yomi='カブシキガイシャカマクラシンショ',
        address='中央区京橋二丁目１４番１号',
        industry='サービス業',
        sec_code='61840',
        corporate_number='9010001040382',
    ),
    'E31878': EdinetCodeEntry(
        edinet_code='E31878',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=378,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ラクス',
        submitter_name_en='RAKUS Co.,Ltd',
        submitter_name_yomi='カブシキガイシャラクス',
        address='大阪市北区鶴野町１－９',
        industry='情報・通信業',
        sec_code='39230',
        corporate_number='9120001097305',
    ),
    'E31879': EdinetCodeEntry(
        edinet_code='E31879',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='アートポートインベスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アートポートインベストカブシキガイシャ',
        address='港区六本木七丁目６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001175699',
    ),
    'E31880': EdinetCodeEntry(
        edinet_code='E31880',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久保\u3000千晶',
        submitter_name_en=None,
        submitter_name_yomi='クボ\u3000チアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31883': EdinetCodeEntry(
        edinet_code='E31883',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｏａｓｉｓ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｃｏｍｐａｎｙ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='オアシス\u3000マネジメント\u3000カンパニー\u3000リミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、私書箱３０９、メイプルズ・コーポレート・サービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31889': EdinetCodeEntry(
        edinet_code='E31889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=39697,
        fiscal_year_end=None,
        submitter_name='いちごホテルリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='イチゴホテルリートトウシホウジン',
        address='千代田区丸の内二丁目６番１号丸の内パークビルディング２０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005024193',
    ),
    'E31893': EdinetCodeEntry(
        edinet_code='E31893',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1354,
        fiscal_year_end=None,
        submitter_name='Ｍ＆Ｇインベストメント・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エムアンドジーインベストメントマネジメントリミテッド',
        address='英国、ロンドン、フェンチャーチ・アベニュー１０、ＥＣ３Ｍ\u3000５ＡＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31896': EdinetCodeEntry(
        edinet_code='E31896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=27035,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ベルシステム２４ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベルシステムニジュウヨンホールディングス',
        address='港区虎ノ門四丁目１番１号',
        industry='サービス業',
        sec_code='61830',
        corporate_number='4010001161381',
    ),
    'E31897': EdinetCodeEntry(
        edinet_code='E31897',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社松栄管理',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマツザカカンリ',
        address='水戸市千波町６１３番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001170110',
    ),
    'E31901': EdinetCodeEntry(
        edinet_code='E31901',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=783,
        fiscal_year_end='2月末日',
        submitter_name='株式会社メタリアル',
        submitter_name_en='MetaReal Corporation',
        submitter_name_yomi='カブシキガイシャメタリアル',
        address='千代田区神田神保町三丁目７番１号',
        industry='サービス業',
        sec_code='61820',
        corporate_number='1010001088074',
    ),
    'E31902': EdinetCodeEntry(
        edinet_code='E31902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=297,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ネオジャパン',
        submitter_name_en='NEOJAPAN Inc.',
        submitter_name_yomi='カブシキガイシャネオジャパン',
        address='横浜市西区みなとみらい二丁目２番１号横浜ランドマークタワー１０階',
        industry='情報・通信業',
        sec_code='39210',
        corporate_number='6020001009165',
    ),
    'E31903': EdinetCodeEntry(
        edinet_code='E31903',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='箕浦\u3000幹彦',
        submitter_name_en=None,
        submitter_name_yomi='ミノウラ\u3000ミキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31905': EdinetCodeEntry(
        edinet_code='E31905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=680,
        fiscal_year_end='3月末日',
        submitter_name='あんしん保証株式会社',
        submitter_name_en='Anshin Guarantor Service Co.,Ltd.',
        submitter_name_yomi='アンシンホショウカブシキガイシャ',
        address='品川区東品川四丁目１２番４号',
        industry='その他金融業',
        sec_code='71830',
        corporate_number='9010401049214',
    ),
    'E31906': EdinetCodeEntry(
        edinet_code='E31906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柴田\u3000高幸',
        submitter_name_en=None,
        submitter_name_yomi='シバタ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31908': EdinetCodeEntry(
        edinet_code='E31908',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ソラ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソラカブシキガイシャ',
        address='港区東麻布２－２６－１６\u3000富士レジデンス３０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401113831',
    ),
    'E31909': EdinetCodeEntry(
        edinet_code='E31909',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥田\u3000弘男',
        submitter_name_en=None,
        submitter_name_yomi='オクダ\u3000ヒロオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31912': EdinetCodeEntry(
        edinet_code='E31912',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永瀬\u3000昭幸',
        submitter_name_en=None,
        submitter_name_yomi='ナガセ\u3000アキユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31915': EdinetCodeEntry(
        edinet_code='E31915',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永瀬\u3000昭典',
        submitter_name_en=None,
        submitter_name_yomi='ナガセ\u3000アキノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31918': EdinetCodeEntry(
        edinet_code='E31918',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=139,
        fiscal_year_end='10月31日',
        submitter_name='アートグリーン株式会社',
        submitter_name_en='ArtGreen Co.,Ltd',
        submitter_name_yomi='アートグリーンカブシキカイシャ',
        address='江東区福住一丁目８番８号',
        industry='卸売業',
        sec_code='34190',
        corporate_number='7010401048812',
    ),
    'E31921': EdinetCodeEntry(
        edinet_code='E31921',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='齊藤\u3000章浩',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31922': EdinetCodeEntry(
        edinet_code='E31922',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大坪\u3000克也',
        submitter_name_en=None,
        submitter_name_yomi='オオツボ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31924': EdinetCodeEntry(
        edinet_code='E31924',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1057,
        fiscal_year_end='2月末日',
        submitter_name='中本パックス株式会社',
        submitter_name_en='NAKAMOTO PACKS CO.,LTD.',
        submitter_name_yomi='ナカモトパックスカブシキガイシャ',
        address='大阪市天王寺区空堀町２番８号',
        industry='その他製品',
        sec_code='78110',
        corporate_number='8120001024730',
    ),
    'E31925': EdinetCodeEntry(
        edinet_code='E31925',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ｒｏｂｏｔ\u3000ｈｏｍｅ',
        submitter_name_en='robot home Inc.',
        submitter_name_yomi='カブシキガイシャロボットホーム',
        address='中央区銀座６丁目１０ー１',
        industry='不動産業',
        sec_code='14350',
        corporate_number='3290001025873',
    ),
    'E31926': EdinetCodeEntry(
        edinet_code='E31926',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社プロシードゥス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプロシードゥス',
        address='横浜市青葉区あざみ野南３－１７－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001049850',
    ),
    'E31927': EdinetCodeEntry(
        edinet_code='E31927',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮下\u3000泰明',
        submitter_name_en=None,
        submitter_name_yomi='ミヤシタ\u3000ヤスアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31928': EdinetCodeEntry(
        edinet_code='E31928',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村井\u3000智建',
        submitter_name_en=None,
        submitter_name_yomi='ムライ\u3000トモタケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31930': EdinetCodeEntry(
        edinet_code='E31930',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=404,
        fiscal_year_end=None,
        submitter_name='ＲＭＢ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='アールエムビー\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='１１５\u3000ＳＯＵＴＨ\u3000ＬＡＳＡＬＬＥ\u3000ＡＶＥＮＵＥ，\u3000３４ＴＨ\u3000ＦＬＯＯＲ，\u3000ＣＨＩＣＡＧＯ，\u3000ＩＬ\u3000６０６０３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31931': EdinetCodeEntry(
        edinet_code='E31931',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=245196,
        fiscal_year_end=None,
        submitter_name='野村不動産マスターファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ノムラフドウサンマスターファンドトウシホウジン',
        address='港区芝浦一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011105006979',
    ),
    'E31932': EdinetCodeEntry(
        edinet_code='E31932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伴\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='バン\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31936': EdinetCodeEntry(
        edinet_code='E31936',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=648,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オープンドア',
        submitter_name_en='Open Door Inc.',
        submitter_name_yomi='カブシキガイシャオープンドア',
        address='港区赤坂二丁目１７番７号',
        industry='情報・通信業',
        sec_code='39260',
        corporate_number='5010401032495',
    ),
    'E31937': EdinetCodeEntry(
        edinet_code='E31937',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31946': EdinetCodeEntry(
        edinet_code='E31946',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=464,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ミズホメディー',
        submitter_name_en='MIZUHO MEDY CO.,LTD.',
        submitter_name_yomi='カブシキガイシャミズホメディー',
        address='鳥栖市藤木町５番地の４',
        industry='医薬品',
        sec_code='45950',
        corporate_number='2300001006311',
    ),
    'E31947': EdinetCodeEntry(
        edinet_code='E31947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福島\u3000勇人',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31948': EdinetCodeEntry(
        edinet_code='E31948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=171,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ランドコンピュータ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャランドコンピュータ',
        address='港区芝浦四丁目１３番２３号',
        industry='情報・通信業',
        sec_code='39240',
        corporate_number='1010701021061',
    ),
    'E31949': EdinetCodeEntry(
        edinet_code='E31949',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000裕久',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ヒロヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31954': EdinetCodeEntry(
        edinet_code='E31954',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=17117,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ツバキ・ナカシマ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツバキナカシマ',
        address='葛城市尺土１９番地',
        industry='機械',
        sec_code='64640',
        corporate_number='2150001014908',
    ),
    'E31955': EdinetCodeEntry(
        edinet_code='E31955',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=354,
        fiscal_year_end='3月末日',
        submitter_name='ソーシャルワイヤー株式会社',
        submitter_name_en='SOCIALWIRE CO., LTD.',
        submitter_name_yomi='ソーシャルワイヤーカブシキガイシャ',
        address='港区芝浦三丁目９番１号\u3000芝浦ルネサイトタワー６階',
        industry='情報・通信業',
        sec_code='39290',
        corporate_number='3011101058626',
    ),
    'E31957': EdinetCodeEntry(
        edinet_code='E31957',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=261,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ダブルスタンダード',
        submitter_name_en='Double Standard Inc.',
        submitter_name_yomi='カブシキガイシャダブルスタンダード',
        address='港区赤坂三丁目３番３号',
        industry='情報・通信業',
        sec_code='39250',
        corporate_number='1013201019245',
    ),
    'E31958': EdinetCodeEntry(
        edinet_code='E31958',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1011,
        fiscal_year_end='3月末日',
        submitter_name='ＳＭＮ株式会社',
        submitter_name_en='SMN Corporation',
        submitter_name_yomi='エスエムエヌカブシキガイシャ',
        address='品川区大崎二丁目１１番１号',
        industry='サービス業',
        sec_code='61850',
        corporate_number='3010701021828',
    ),
    'E31959': EdinetCodeEntry(
        edinet_code='E31959',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=245,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グラフィコ',
        submitter_name_en='GRAPHICO,Inc.',
        submitter_name_yomi='カブシキカイシャグラフィコ',
        address='品川区大崎一丁目６番１号',
        industry='その他製品',
        sec_code=None,
        corporate_number='2011001035255',
    ),
    'E31962': EdinetCodeEntry(
        edinet_code='E31962',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢田\u3000峰之',
        submitter_name_en=None,
        submitter_name_yomi='ヤタ\u3000ミネユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31965': EdinetCodeEntry(
        edinet_code='E31965',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=446,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＰＲ\u3000ＴＩＭＥＳ',
        submitter_name_en='PR TIMES, Inc.',
        submitter_name_yomi='カブシキガイシャピーアールタイムズ',
        address='港区赤坂一丁目１１番４４号赤坂インターシティ８階',
        industry='情報・通信業',
        sec_code='39220',
        corporate_number='4010401060191',
    ),
    'E31966': EdinetCodeEntry(
        edinet_code='E31966',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森\u3000輝幸',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000テルユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31968': EdinetCodeEntry(
        edinet_code='E31968',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='8月末日',
        submitter_name='アクサスホールディングス株式会社',
        submitter_name_en='AXAS HOLDINGS CO.,LTD.',
        submitter_name_yomi='アクサスホールディングスカブシキカイシャ',
        address='徳島市山城西四丁目２番',
        industry='小売業',
        sec_code='35360',
        corporate_number='3480001009568',
    ),
    'E31970': EdinetCodeEntry(
        edinet_code='E31970',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=613,
        fiscal_year_end='3月末日',
        submitter_name='プロパティエージェント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プロパティエージェントカブシキガイシャ',
        address='新宿区西新宿６－５－１\u3000新宿アイランドタワー４１階',
        industry='不動産業',
        sec_code=None,
        corporate_number='3011101036771',
    ),
    'E31977': EdinetCodeEntry(
        edinet_code='E31977',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=283,
        fiscal_year_end='3月末日',
        submitter_name='株式会社フーバーブレイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフーバーブレイン',
        address='千代田区紀尾井町４－１ニューオータニガーデンコート２２Ｆ',
        industry='情報・通信業',
        sec_code='39270',
        corporate_number='3010001077133',
    ),
    'E31979': EdinetCodeEntry(
        edinet_code='E31979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4821,
        fiscal_year_end='3月31日',
        submitter_name='ケイアイスター不動産株式会社',
        submitter_name_en='KI-STAR REAL ESTATE CO.,LTD',
        submitter_name_yomi='ケイアイスターフドウサンカブシキガイシャ',
        address='本庄市西富田７６２番地１',
        industry='不動産業',
        sec_code='34650',
        corporate_number='3030001060211',
    ),
    'E31980': EdinetCodeEntry(
        edinet_code='E31980',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河合\u3000宏光',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000ヒロミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31981': EdinetCodeEntry(
        edinet_code='E31981',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小山内\u3000謙太郎',
        submitter_name_en=None,
        submitter_name_yomi='オサナイ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31988': EdinetCodeEntry(
        edinet_code='E31988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='羽鳥\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='ハトリ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31990': EdinetCodeEntry(
        edinet_code='E31990',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三津原\u3000博',
        submitter_name_en=None,
        submitter_name_yomi='ミツハラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31991': EdinetCodeEntry(
        edinet_code='E31991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=46,
        fiscal_year_end='12月31日',
        submitter_name='株式会社マイネット',
        submitter_name_en='Mynet Inc.',
        submitter_name_yomi='カブシキカイシャマイネット',
        address='港区北青山二丁目１１番３号',
        industry='情報・通信業',
        sec_code='39280',
        corporate_number='7010001100444',
    ),
    'E31995': EdinetCodeEntry(
        edinet_code='E31995',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ヒロコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒロコーポレーション',
        address='大垣市外渕２丁目３８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3200001014091',
    ),
    'E31996': EdinetCodeEntry(
        edinet_code='E31996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浮舟\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='ウキフネ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E31997': EdinetCodeEntry(
        edinet_code='E31997',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社一蔵',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイチクラ',
        address='さいたま市北区大成町四丁目６９９番地１',
        industry='サービス業',
        sec_code='61860',
        corporate_number='4030001000777',
    ),
    'E32004': EdinetCodeEntry(
        edinet_code='E32004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ジェイコブソン\u3000陽子',
        submitter_name_en=None,
        submitter_name_yomi='ジェイコブソン\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32007': EdinetCodeEntry(
        edinet_code='E32007',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＡＡＡ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーエーエーカブシキガイシャ',
        address='墨田区押上二丁目１４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010601009131',
    ),
    'E32008': EdinetCodeEntry(
        edinet_code='E32008',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松嶋\u3000祥文',
        submitter_name_en=None,
        submitter_name_yomi='マツシマ\u3000ヨシフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32010': EdinetCodeEntry(
        edinet_code='E32010',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='関根\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='セキネ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32011': EdinetCodeEntry(
        edinet_code='E32011',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='りそなアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リソナアセットマネジメントカブシキガイシャ',
        address='江東区木場一丁目５番６５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010601048309',
    ),
    'E32015': EdinetCodeEntry(
        edinet_code='E32015',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='フォーカス・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='フォーカスシキャブ',
        address='ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り\u3000３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32021': EdinetCodeEntry(
        edinet_code='E32021',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='グローバル・オポチュニティーズ・アクセス',
        submitter_name_en=None,
        submitter_name_yomi='グローバルオポチュニティーズアクセス',
        address='ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32022': EdinetCodeEntry(
        edinet_code='E32022',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=150078,
        fiscal_year_end='3月31日',
        submitter_name='株式会社横浜フィナンシャルグループ',
        submitter_name_en='Yokohama Financial Group, Inc.',
        submitter_name_yomi='カブシキカイシャヨコハマフィナンシャルグループ',
        address='中央区日本橋２丁目７番１号',
        industry='銀行業',
        sec_code='71860',
        corporate_number='8010001174710',
    ),
    'E32023': EdinetCodeEntry(
        edinet_code='E32023',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='五石\u3000順一',
        submitter_name_en=None,
        submitter_name_yomi='ゴイシ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32025': EdinetCodeEntry(
        edinet_code='E32025',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000はる代',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ハルヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32026': EdinetCodeEntry(
        edinet_code='E32026',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3800,
        fiscal_year_end='3月31日',
        submitter_name='ＮＣホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌシーホールディングスカブシキガイシャ',
        address='千代田区神田鍛冶町三丁目６番地３',
        industry='機械',
        sec_code=None,
        corporate_number='4010001174821',
    ),
    'E32027': EdinetCodeEntry(
        edinet_code='E32027',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塙\u3000圭二',
        submitter_name_en=None,
        submitter_name_yomi='ハナワ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32028': EdinetCodeEntry(
        edinet_code='E32028',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢＩアセットマネジメントグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイアセットマネジメントグループカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401111550',
    ),
    'E32029': EdinetCodeEntry(
        edinet_code='E32029',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='マルチ・マネージャー・アクセス',
        submitter_name_en=None,
        submitter_name_yomi='マルチマネージャーアクセス',
        address='ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り\u3000３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32032': EdinetCodeEntry(
        edinet_code='E32032',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000純代',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000スミヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32033': EdinetCodeEntry(
        edinet_code='E32033',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='嶋津\u3000貴和',
        submitter_name_en=None,
        submitter_name_yomi='シマヅ\u3000タカカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32037': EdinetCodeEntry(
        edinet_code='E32037',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｉｒｌ）ファンド・ソリューションズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスアイルランドファンドソリューションズピーエルシー',
        address='アイルランド共和国、ダブリン２、サー・ジョン・ロジャーソンズ・キー、リバーサイド・ワン',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32040': EdinetCodeEntry(
        edinet_code='E32040',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=443947,
        fiscal_year_end=None,
        submitter_name='ＰＩＭＣＯセレクト・ファンズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ピムコセレクトファンズピーエルシー',
        address='アイルランド、Ｄ０２\u3000ＨＤ３２、ダブリン２、サー・ジョン・ロジャーソンズ・キー７８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32041': EdinetCodeEntry(
        edinet_code='E32041',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松屋取引先持株会\u3000理事長\u3000黒川光博',
        submitter_name_en=None,
        submitter_name_yomi='マツヤトリヒキサキモチカブカイ\u3000リジチョウ\u3000クロカワミツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32042': EdinetCodeEntry(
        edinet_code='E32042',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=206768,
        fiscal_year_end=None,
        submitter_name='ラサールロジポート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ラサールロジポートトウシホウジン',
        address='千代田区丸の内一丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005024495',
    ),
    'E32044': EdinetCodeEntry(
        edinet_code='E32044',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社レダグループホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャレダグループホールディングス',
        address='千代田区紀尾井町４番１号ニューオータニガーデンコート４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001073630',
    ),
    'E32048': EdinetCodeEntry(
        edinet_code='E32048',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古木\u3000大咲',
        submitter_name_en=None,
        submitter_name_yomi='フルキ\u3000ダイサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32049': EdinetCodeEntry(
        edinet_code='E32049',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐野\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32051': EdinetCodeEntry(
        edinet_code='E32051',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中西\u3000聖',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000セイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32052': EdinetCodeEntry(
        edinet_code='E32052',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社壽世堂',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジュセイドウ',
        address='大阪市中央区北浜３丁目５番２９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001081406',
    ),
    'E32061': EdinetCodeEntry(
        edinet_code='E32061',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000祐孝',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ヒロタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32063': EdinetCodeEntry(
        edinet_code='E32063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村崇則',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラタカノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32064': EdinetCodeEntry(
        edinet_code='E32064',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=928,
        fiscal_year_end=None,
        submitter_name='弘塑科技股分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ホンソーカーチーゴーフェンヨウシェンゴンスー',
        address='中華民国新竹市香山区塩水里９隣中華路六段８９号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32065': EdinetCodeEntry(
        edinet_code='E32065',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人大川',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンオオカワ',
        address='岡崎市薮田一丁目１０番地２０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180305008459',
    ),
    'E32069': EdinetCodeEntry(
        edinet_code='E32069',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30003,
        fiscal_year_end='3月31日',
        submitter_name='伊藤ハム米久ホールディングス株式会社',
        submitter_name_en='ITOHAM YONEKYU HOLDINGS INC.',
        submitter_name_yomi='イトウハムヨネキュウホールディングスカブシキガイシャ',
        address='目黒区三田１丁目６番２１号',
        industry='食料品',
        sec_code='22960',
        corporate_number='6011001110293',
    ),
    'E32072': EdinetCodeEntry(
        edinet_code='E32072',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='唐川\u3000文成',
        submitter_name_en=None,
        submitter_name_yomi='カラカワ\u3000フミナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32073': EdinetCodeEntry(
        edinet_code='E32073',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三嶋\u3000隆',
        submitter_name_en=None,
        submitter_name_yomi='ミシマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32077': EdinetCodeEntry(
        edinet_code='E32077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上原\u3000仁',
        submitter_name_en=None,
        submitter_name_yomi='ウエハラ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32078': EdinetCodeEntry(
        edinet_code='E32078',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=275,
        fiscal_year_end=None,
        submitter_name='松岡冷蔵株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マツオカレイゾウカブシキカイシャ',
        address='港区港南５－３－２３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401028013',
    ),
    'E32081': EdinetCodeEntry(
        edinet_code='E32081',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田坂\u3000吉朗',
        submitter_name_en=None,
        submitter_name_yomi='タサカ\u3000ヨシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32092': EdinetCodeEntry(
        edinet_code='E32092',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32101': EdinetCodeEntry(
        edinet_code='E32101',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='ＵＧＳアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユージーエスアセットマネジメントカブシキガイシャ',
        address='港区赤坂六丁目５番３８－８０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401082876',
    ),
    'E32107': EdinetCodeEntry(
        edinet_code='E32107',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社Ｂｏｌｄ\u3000Ｉｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャボールドインベストメント',
        address='千代田区丸の内２－４－１\u3000丸の内ビルディング２３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001112660',
    ),
    'E32108': EdinetCodeEntry(
        edinet_code='E32108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=382,
        fiscal_year_end='1月末日',
        submitter_name='株式会社バリューゴルフ',
        submitter_name_en='VALUE GOLF Inc.',
        submitter_name_yomi='カブシキガイシャバリューゴルフ',
        address='港区芝四丁目３番５号ファースト岡田ビル５Ｆ',
        industry='情報・通信業',
        sec_code='39310',
        corporate_number='1010401055616',
    ),
    'E32109': EdinetCodeEntry(
        edinet_code='E32109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1101,
        fiscal_year_end='3月末日',
        submitter_name='ヒロセ通商株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒロセツウショウカブシキガイシャ',
        address='大阪市西区新町一丁目３番１９号ＭＧビルディング',
        industry='その他金融業',
        sec_code='71850',
        corporate_number='9120001106932',
    ),
    'E32115': EdinetCodeEntry(
        edinet_code='E32115',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32117': EdinetCodeEntry(
        edinet_code='E32117',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ゼネラルアサヒ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャゼネラルアサヒ',
        address='福岡市東区松田３丁目７７７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9290001003394',
    ),
    'E32119': EdinetCodeEntry(
        edinet_code='E32119',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=534,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ブラス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブラス',
        address='名古屋市中村区名駅２－３６－２０\u3000アイムビル４Ｆ',
        industry='サービス業',
        sec_code='24240',
        corporate_number='5180001085084',
    ),
    'E32122': EdinetCodeEntry(
        edinet_code='E32122',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小柴\u3000眞治',
        submitter_name_en=None,
        submitter_name_yomi='コシバ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32130': EdinetCodeEntry(
        edinet_code='E32130',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土屋\u3000仁朗',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤ\u3000キミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32135': EdinetCodeEntry(
        edinet_code='E32135',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=155,
        fiscal_year_end=None,
        submitter_name='ファースト・イースタン・アジア・ホールディングス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ファーストイースタンアジアホールディングスリミテッド',
        address='中華人民共和国香港特別行政区\u3000ヘネシーロード２８\u3000２１階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32138': EdinetCodeEntry(
        edinet_code='E32138',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=926,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ヨシムラ・フード・ホールディングス',
        submitter_name_en='Yoshimura Food Holdings K.K.',
        submitter_name_yomi='カブシキガイシャヨシムラフードホールディングス',
        address='千代田区内幸町二丁目２番２号',
        industry='サービス業',
        sec_code='28840',
        corporate_number='6010001128643',
    ),
    'E32139': EdinetCodeEntry(
        edinet_code='E32139',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＳＰＲＩＮＧ\u3000ＩＮＶＥＳＴＭＥＮＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スプリングインベストメントカブシキガイシャ',
        address='新宿区西新宿三丁目２番９号\u3000新宿ワシントンホテルビル本館２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101061064',
    ),
    'E32141': EdinetCodeEntry(
        edinet_code='E32141',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=74,
        fiscal_year_end='7月31日',
        submitter_name='株式会社はてな',
        submitter_name_en='Hatena Co., Ltd',
        submitter_name_yomi='カブシキガイシャハテナ',
        address='港区南青山６－５－５５\u3000青山サンライトビル４階',
        industry='情報・通信業',
        sec_code='39300',
        corporate_number='1013201014709',
    ),
    'E32143': EdinetCodeEntry(
        edinet_code='E32143',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近藤\u3000淳也',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000ジュンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32144': EdinetCodeEntry(
        edinet_code='E32144',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=45,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＬＩＴＡＬＩＣＯパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリタリコパートナーズ',
        address='目黒区上目黒２－１－１',
        industry='サービス業',
        sec_code=None,
        corporate_number='7370001013965',
    ),
    'E32146': EdinetCodeEntry(
        edinet_code='E32146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=248,
        fiscal_year_end='3月31日',
        submitter_name='昭栄薬品株式会社',
        submitter_name_en='SHOEI YAKUHIN CO.,LTD.',
        submitter_name_yomi='ショウエイヤクヒンカブシキガイシャ',
        address='大阪市中央区安土町一丁目５番１号',
        industry='卸売業',
        sec_code='35370',
        corporate_number='4120001015147',
    ),
    'E32148': EdinetCodeEntry(
        edinet_code='E32148',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000文樹',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000フミキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32149': EdinetCodeEntry(
        edinet_code='E32149',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ニッセンリベット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッセンリベットカブシキガイシャ',
        address='東大阪市東山町１０番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1122001005799',
    ),
    'E32150': EdinetCodeEntry(
        edinet_code='E32150',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＲＥＶＩＣパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='レヴィックパートナーズカブシキガイシャ',
        address='千代田区大手町一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001166474',
    ),
    'E32151': EdinetCodeEntry(
        edinet_code='E32151',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='ＪＰ投信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイピートウシンカブシキガイシャ',
        address='中央区日本橋人形町一丁目１１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001169910',
    ),
    'E32153': EdinetCodeEntry(
        edinet_code='E32153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2573,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フェニックスバイオ',
        submitter_name_en='PhoenixBio Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフェニックスバイオ',
        address='東広島市鏡山三丁目４番１号',
        industry='サービス業',
        sec_code='61900',
        corporate_number='3240001023089',
    ),
    'E32156': EdinetCodeEntry(
        edinet_code='E32156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1278,
        fiscal_year_end='9月30日',
        submitter_name='株式会社グローバルキッズＣＯＭＰＡＮＹ',
        submitter_name_en='Global Kids Company Corp.',
        submitter_name_yomi='カブシキガイシャグローバルキッズカンパニー',
        address='千代田区富士見２丁目１４番３６号',
        industry='サービス業',
        sec_code='61890',
        corporate_number='1010001170889',
    ),
    'E32157': EdinetCodeEntry(
        edinet_code='E32157',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日華共栄会\u3000理事長\u3000出口隆弘',
        submitter_name_en=None,
        submitter_name_yomi='ニッカキョウエイカイ\u3000リジチョウ\u3000デグチタカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32158': EdinetCodeEntry(
        edinet_code='E32158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=390,
        fiscal_year_end='3月31日',
        submitter_name='アグレ都市デザイン株式会社',
        submitter_name_en='Agratio urban design Inc.',
        submitter_name_yomi='アグレトシデザインカブシキガイシャ',
        address='新宿区西新宿２－６－１',
        industry='不動産業',
        sec_code='34670',
        corporate_number='8012401019024',
    ),
    'E32159': EdinetCodeEntry(
        edinet_code='E32159',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=604,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベネフィットジャパン',
        submitter_name_en='BENEFIT JAPAN Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャベネフィットジャパン',
        address='大阪市中央区道修町一丁目５－１８',
        industry='情報・通信業',
        sec_code='39340',
        corporate_number='7120001089122',
    ),
    'E32161': EdinetCodeEntry(
        edinet_code='E32161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=336,
        fiscal_year_end='3月31日',
        submitter_name='チエル株式会社',
        submitter_name_en='CHIeru Co.,Ltd.',
        submitter_name_yomi='チエルカブシキガイシャ',
        address='品川区東品川２－２－２４',
        industry='情報・通信業',
        sec_code='39330',
        corporate_number='7011101025151',
    ),
    'E32163': EdinetCodeEntry(
        edinet_code='E32163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20,
        fiscal_year_end='4月30日',
        submitter_name='株式会社グリーンエナジー＆カンパニー',
        submitter_name_en='GreenEnergy & Company Inc.',
        submitter_name_yomi='カブシキカイシャグリーンエナジーアンドカンパニー',
        address='板野郡松茂町中喜来字群恵３９番地１',
        industry='建設業',
        sec_code='14360',
        corporate_number='6480001006042',
    ),
    'E32166': EdinetCodeEntry(
        edinet_code='E32166',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴江\u3000崇文',
        submitter_name_en=None,
        submitter_name_yomi='スズエ\u3000タカフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32168': EdinetCodeEntry(
        edinet_code='E32168',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=354,
        fiscal_year_end='12月末日',
        submitter_name='富士ソフトサービスビューロ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジソフトサービスビューロカブシキガイシャ',
        address='墨田区江東橋二丁目１９番７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010601027646',
    ),
    'E32169': EdinetCodeEntry(
        edinet_code='E32169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4729,
        fiscal_year_end='3月31日',
        submitter_name='ユー・エム・シー・エレクトロニクス株式会社',
        submitter_name_en='UMC Electronics Co.,Ltd.',
        submitter_name_yomi='ユーエムシーエレクトロニクスカブシキガイシャ',
        address='上尾市瓦葺７２１番地',
        industry='電気機器',
        sec_code='66150',
        corporate_number='1030001044117',
    ),
    'E32174': EdinetCodeEntry(
        edinet_code='E32174',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＥＥＮ\u3000ＣＯＵＮＴＲＹ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='キーンカントリーリミテッド',
        address='６／Ｆ\u3000ＳＥＡ\u3000ＢＩＲＤ\u3000ＨＯＵＳＥ\u3000２２－２８\u3000ＷＹＮＤＨＡＭ\u3000ＳＴＲＥＥＴ\u3000ＣＥＮＴＲＡＬ\u3000ＨＫ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32176': EdinetCodeEntry(
        edinet_code='E32176',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='カルチュア・エンタテインメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カルチュアエンタテインメントカブシキガイシャ',
        address='東京都品川区上大崎３丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001103060',
    ),
    'E32181': EdinetCodeEntry(
        edinet_code='E32181',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=397,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ウイルプラスホールディングス',
        submitter_name_en='WILLPLUS Holdings Corporation',
        submitter_name_yomi='カブシキカイシャウイルプラスホールディングス',
        address='港区芝五丁目１３番１５号',
        industry='小売業',
        sec_code='35380',
        corporate_number='8010801017606',
    ),
    'E32182': EdinetCodeEntry(
        edinet_code='E32182',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＥホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーイーホールディングス',
        address='静岡市清水区三保３８７番地７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9080001017671',
    ),
    'E32185': EdinetCodeEntry(
        edinet_code='E32185',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=153,
        fiscal_year_end=None,
        submitter_name='ＢＩＦＦＩＧＮＡＮＤＩ\u3000ＳＰＡ',
        submitter_name_en=None,
        submitter_name_yomi='ビフィナンディカブシキガイシャ',
        address='ＩＴＡＬＹ\u3000ＣＡＳＳＯＬＮＯＶＯ\u3000（ＰＶ）\u3000ＶＩＡ\u3000ＣＩＲＣＯＮＶＡＬＬＡＺＩＯＮＥ\u3000ＥＳＴ，\u3000２－４－６\u3000ＣＡＰ\u3000２７０２３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32186': EdinetCodeEntry(
        edinet_code='E32186',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社和円商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワエンショウジ',
        address='中央区日本橋久松町９－１２和円ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001078269',
    ),
    'E32187': EdinetCodeEntry(
        edinet_code='E32187',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='成瀬\u3000隆章',
        submitter_name_en=None,
        submitter_name_yomi='ナルセ\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32188': EdinetCodeEntry(
        edinet_code='E32188',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社マサユキコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマサユキコーポレーション',
        address='半田市亀崎月見町二丁目５８番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001121833',
    ),
    'E32189': EdinetCodeEntry(
        edinet_code='E32189',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1044,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イワキ',
        submitter_name_en='IWAKI CO., LTD.',
        submitter_name_yomi='カブシキガイシャイワキ',
        address='千代田区神田須田町二丁目６番６号',
        industry='機械',
        sec_code='62370',
        corporate_number='3010001011026',
    ),
    'E32190': EdinetCodeEntry(
        edinet_code='E32190',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社中本',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナカモト',
        address='鎌倉市坂ノ下３２番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401115267',
    ),
    'E32192': EdinetCodeEntry(
        edinet_code='E32192',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エー．ピー．エフ．グループ・シーオー・エルティディ',
        submitter_name_en=None,
        submitter_name_yomi='エーピーエフグループシーオーエルティディ',
        address='英領ヴァージン諸島、トートラ、ロードタウン、パームグローブハウス、ピー．オー．ボックス４３８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32193': EdinetCodeEntry(
        edinet_code='E32193',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=157,
        fiscal_year_end='9月30日',
        submitter_name='株式会社キャリア',
        submitter_name_en='CAREER CO.,LTD',
        submitter_name_yomi='カブシキカイシャキャリア',
        address='世田谷区太子堂４丁目１番１号\u3000キャロットタワー１４階',
        industry='サービス業',
        sec_code='61980',
        corporate_number='2011101052670',
    ),
    'E32194': EdinetCodeEntry(
        edinet_code='E32194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2923,
        fiscal_year_end='9月末日',
        submitter_name='株式会社エアトリ',
        submitter_name_en='AirTrip Corp.',
        submitter_name_yomi='カブシキガイシャエアトリ',
        address='港区愛宕２－５－１愛宕グリーンヒルズＭＯＲＩタワー１９階',
        industry='サービス業',
        sec_code='61910',
        corporate_number='6010401072978',
    ),
    'E32198': EdinetCodeEntry(
        edinet_code='E32198',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=513,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイドママーケティングコミュニケーション',
        submitter_name_en='Aidma Marketing Communication Corporation',
        submitter_name_yomi='カブシキガイシャアイドママーケティングコミュニケーション',
        address='富山市豊田町一丁目３番３１号',
        industry='情報・通信業',
        sec_code='94660',
        corporate_number='4230001000030',
    ),
    'E32200': EdinetCodeEntry(
        edinet_code='E32200',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2719,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アカツキ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアカツキ',
        address='品川区上大崎二丁目１３番３０号',
        industry='情報・通信業',
        sec_code='39320',
        corporate_number='2011001065541',
    ),
    'E32203': EdinetCodeEntry(
        edinet_code='E32203',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=597,
        fiscal_year_end='3月31日',
        submitter_name='バーチャレクス・ホールディングス株式会社',
        submitter_name_en='virtualex holdings, inc.',
        submitter_name_yomi='バーチャレクスホールディングスカブシキガイシャ',
        address='港区虎ノ門四丁目３番１３号',
        industry='サービス業',
        sec_code='61930',
        corporate_number='3010401059383',
    ),
    'E32204': EdinetCodeEntry(
        edinet_code='E32204',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社丸八ホールディングス',
        submitter_name_en='MARUHACHI HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキカイシャマルハチホールディングス',
        address='横浜市港北区新横浜三丁目８番地１２',
        industry='繊維製品',
        sec_code='35040',
        corporate_number='7020001095089',
    ),
    'E32212': EdinetCodeEntry(
        edinet_code='E32212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河合\u3000達明',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000タツアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32214': EdinetCodeEntry(
        edinet_code='E32214',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＫマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティケイマネジメントカブシキカイシャ',
        address='神戸市中央区栄町通一丁目１番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1480001008539',
    ),
    'E32215': EdinetCodeEntry(
        edinet_code='E32215',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=80000,
        fiscal_year_end='3月31日',
        submitter_name='東京電力パワーグリッド株式会社',
        submitter_name_en='TEPCO Power Grid, Incorporated',
        submitter_name_yomi='トウキョウデンリョクパワーグリッドカブシキガイシャ',
        address='千代田区内幸町１丁目１番３号',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='3010001166927',
    ),
    'E32216': EdinetCodeEntry(
        edinet_code='E32216',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='アクアウェッジ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アクアウェッジカブシキガイシャ',
        address='港区港南二丁目１６番１号品川イーストワンタワー４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010801026381',
    ),
    'E32217': EdinetCodeEntry(
        edinet_code='E32217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松下\u3000美樹',
        submitter_name_en=None,
        submitter_name_yomi='マツシタ\u3000ミキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32218': EdinetCodeEntry(
        edinet_code='E32218',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='染谷\u3000真沙美',
        submitter_name_en=None,
        submitter_name_yomi='ソメヤ\u3000マサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32219': EdinetCodeEntry(
        edinet_code='E32219',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河田\u3000優子',
        submitter_name_en=None,
        submitter_name_yomi='カワタ\u3000ユウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32220': EdinetCodeEntry(
        edinet_code='E32220',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1394,
        fiscal_year_end='9月末日',
        submitter_name='ハイアス・アンド・カンパニー株式会社',
        submitter_name_en='HyAS&Co.Inc.',
        submitter_name_yomi='ハイアスアンドカンパニーカブシキカイシャ',
        address='品川区上大崎二丁目２４番９号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010401064032',
    ),
    'E32221': EdinetCodeEntry(
        edinet_code='E32221',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=63,
        fiscal_year_end=None,
        submitter_name='みさき投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミサキトウシカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401108137',
    ),
    'E32222': EdinetCodeEntry(
        edinet_code='E32222',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉村\u3000元久',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000モトヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32224': EdinetCodeEntry(
        edinet_code='E32224',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='ソニー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソニーカブシキガイシャ',
        address='港区港南一丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401045660',
    ),
    'E32225': EdinetCodeEntry(
        edinet_code='E32225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月末日',
        submitter_name='株式会社グローバルウェイ',
        submitter_name_en='Globalway, Inc.',
        submitter_name_yomi='カブシキガイシャグローバルウェイ',
        address='港区浜松町一丁目７番３号',
        industry='情報・通信業',
        sec_code='39360',
        corporate_number='7010401055461',
    ),
    'E32227': EdinetCodeEntry(
        edinet_code='E32227',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社川嶋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカワシマ',
        address='浜松市中央区湖東町３２２２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3080401001355',
    ),
    'E32235': EdinetCodeEntry(
        edinet_code='E32235',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原田政樹',
        submitter_name_en=None,
        submitter_name_yomi='ハラダマサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32237': EdinetCodeEntry(
        edinet_code='E32237',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='サイブリッジコーポレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイブリッジコーポレーションカブシキガイシャ',
        address='港区南青山２丁目２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1240001016202',
    ),
    'E32238': EdinetCodeEntry(
        edinet_code='E32238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1461,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エディア',
        submitter_name_en='Edia Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエディア',
        address='千代田区一ツ橋２‐４‐３光文恒産ビル７階',
        industry='情報・通信業',
        sec_code='39350',
        corporate_number='3010001072274',
    ),
    'E32246': EdinetCodeEntry(
        edinet_code='E32246',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='三和商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンワショウジカブシキガイシャ',
        address='橿原市雲梯町５９４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4150001010500',
    ),
    'E32250': EdinetCodeEntry(
        edinet_code='E32250',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社グロービス・キャピタル・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグロービスキャピタルパートナーズ',
        address='千代田区二番町５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001101361',
    ),
    'E32253': EdinetCodeEntry(
        edinet_code='E32253',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=52745,
        fiscal_year_end=None,
        submitter_name='スターアジア不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='スターアジアフドウサントウシホウジン',
        address='港区愛宕二丁目５番１号愛宕グリーンヒルズＭＯＲＩタワー１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010405014383',
    ),
    'E32254': EdinetCodeEntry(
        edinet_code='E32254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2229,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ＪＭホールディングス',
        submitter_name_en='JM HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジェイエムホールディングス',
        address='土浦市卸町二丁目３番３０号',
        industry='小売業',
        sec_code='35390',
        corporate_number='1050001011577',
    ),
    'E32255': EdinetCodeEntry(
        edinet_code='E32255',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ｂｌａｃｋ\u3000Ｃｌｏｖｅｒ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ブラッククローバーリミテッド',
        address='Ｓｅｒｔｕｓ\u3000Ｃｈａｍｂｅｒｓ，\u3000Ｓｅｃｏｎｄ\u3000Ｆｌｏｏｒ，\u3000Ｔｈｅ\u3000Ｑｕａｄｒａｎｔ，\u3000Ｍａｎｇｌｉｅｒ\u3000Ｓｔｒｅｅｔ，\u3000ＰＯ\u3000Ｂｏｘ\u3000３３４，\u3000Ｖｉｃｔｏｒｉａ，\u3000Ｍａｈｅ，\u3000Ｓｅｙｃｈｅｌｌｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32257': EdinetCodeEntry(
        edinet_code='E32257',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松村\u3000米浩',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000ヨネヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32262': EdinetCodeEntry(
        edinet_code='E32262',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川居\u3000睦',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000ムツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32263': EdinetCodeEntry(
        edinet_code='E32263',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000崇弘',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32266': EdinetCodeEntry(
        edinet_code='E32266',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社ＣＳ企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシーエスキカク',
        address='品川区東五反田１－１０－１１－５０６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010801026315',
    ),
    'E32268': EdinetCodeEntry(
        edinet_code='E32268',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村田\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='ムラタ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32272': EdinetCodeEntry(
        edinet_code='E32272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石橋健藏',
        submitter_name_en=None,
        submitter_name_yomi='イシバシ\u3000ケンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32273': EdinetCodeEntry(
        edinet_code='E32273',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人Ｎｅｘｔ\u3000Ｗｉｓｄｏｍ\u3000Ｆｏｕｎｄａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンネクストウィズダムファウンデーション',
        address='千代田区麹町１－４－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005022166',
    ),
    'E32274': EdinetCodeEntry(
        edinet_code='E32274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｈ・ウチヤマ・ホールディングス有限会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチウチヤマホールディングスユウゲンガイシャ',
        address='さいたま市見沼区東大宮七丁目４３番地１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9030002019267',
    ),
    'E32275': EdinetCodeEntry(
        edinet_code='E32275',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｓ・ウチヤマ・ホールディングス有限会社',
        submitter_name_en=None,
        submitter_name_yomi='エスウチヤマホールディングスユウゲンガイシャ',
        address='さいたま市見沼区大和田町一丁目６３７番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9030002019052',
    ),
    'E32277': EdinetCodeEntry(
        edinet_code='E32277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000敦弥',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000アツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32280': EdinetCodeEntry(
        edinet_code='E32280',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=19409,
        fiscal_year_end=None,
        submitter_name='タカラレーベン・インフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='タカラレーベンインフラトウシホウジン',
        address='千代田区大手町二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005024239',
    ),
    'E32281': EdinetCodeEntry(
        edinet_code='E32281',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='塩田元規',
        submitter_name_en=None,
        submitter_name_yomi='シオタゲンキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32283': EdinetCodeEntry(
        edinet_code='E32283',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='香田哲朗',
        submitter_name_en=None,
        submitter_name_yomi='コウダテツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32284': EdinetCodeEntry(
        edinet_code='E32284',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｏ・ウチヤマ・ホールディングス有限会社',
        submitter_name_en=None,
        submitter_name_yomi='オーウチヤマホールディングスユウゲンガイシャ',
        address='川崎市川崎区伊勢町２３番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7020002104633',
    ),
    'E32288': EdinetCodeEntry(
        edinet_code='E32288',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='12月末日',
        submitter_name='株式会社明日クリエイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアスクリエイト',
        address='福岡市中央区平尾浄水町３番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010401105805',
    ),
    'E32291': EdinetCodeEntry(
        edinet_code='E32291',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3833752,
        fiscal_year_end='10月31日',
        submitter_name='ヒューレット・パッカード・エンタープライズ・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ヒューレットパッカードエンタープライズカンパニー',
        address='アメリカ合衆国７７３８９、テキサス州、スプリング、イースト・モッシイ・オークス・ロード１７０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32292': EdinetCodeEntry(
        edinet_code='E32292',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11882,
        fiscal_year_end='3月31日',
        submitter_name='ＳＧホールディングス株式会社',
        submitter_name_en='SG Holdings Co., Ltd.',
        submitter_name_yomi='エスジーホールディングスカブシキガイシャ',
        address='京都市南区上鳥羽角田町６８番地',
        industry='陸運業',
        sec_code='91430',
        corporate_number='9130001026717',
    ),
    'E32299': EdinetCodeEntry(
        edinet_code='E32299',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中正\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='ナカショウ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32301': EdinetCodeEntry(
        edinet_code='E32301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤中\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='フジナカ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32307': EdinetCodeEntry(
        edinet_code='E32307',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='株式会社洋大',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヨウダイ',
        address='世田谷区玉川田園調布二丁目１２番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401030523',
    ),
    'E32309': EdinetCodeEntry(
        edinet_code='E32309',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='株式会社旺文社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオウブンシャ',
        address='新宿区横寺町５５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011101026036',
    ),
    'E32317': EdinetCodeEntry(
        edinet_code='E32317',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐久間\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='サクマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32320': EdinetCodeEntry(
        edinet_code='E32320',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口\u3000拓己',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000タクミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32321': EdinetCodeEntry(
        edinet_code='E32321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='合同会社ＴＣＴＳ０９',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャティーシーティーエスゼロキュウ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003019657',
    ),
    'E32323': EdinetCodeEntry(
        edinet_code='E32323',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='細合\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='ホソアイ\u3000トシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32324': EdinetCodeEntry(
        edinet_code='E32324',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='友延\u3000雅昭',
        submitter_name_en=None,
        submitter_name_yomi='トモノベ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32325': EdinetCodeEntry(
        edinet_code='E32325',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石原\u3000愛',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000アイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32326': EdinetCodeEntry(
        edinet_code='E32326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松井\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='マツイ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32329': EdinetCodeEntry(
        edinet_code='E32329',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蛯谷\u3000貴',
        submitter_name_en=None,
        submitter_name_yomi='エビタニ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32332': EdinetCodeEntry(
        edinet_code='E32332',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='株式会社ランドネットワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャランドネットワーク',
        address='渋谷区道玄坂１－１６－１５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101049380',
    ),
    'E32337': EdinetCodeEntry(
        edinet_code='E32337',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ミダスプロジェクト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミダスプロジェクト',
        address='港区赤坂八丁目１１番３７号\u3000いちご乃木坂ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401068111',
    ),
    'E32339': EdinetCodeEntry(
        edinet_code='E32339',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社マリモ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマリモ',
        address='広島市西区庚午北一丁目１７番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5240001014672',
    ),
    'E32341': EdinetCodeEntry(
        edinet_code='E32341',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大石\u3000崇徳',
        submitter_name_en=None,
        submitter_name_yomi='オオイシ\u3000ムネノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32350': EdinetCodeEntry(
        edinet_code='E32350',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='マリモ地方創生リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='マリモチホウソウセイリートトウシホウジン',
        address='港区虎ノ門二丁目３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010405014550',
    ),
    'E32351': EdinetCodeEntry(
        edinet_code='E32351',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=494,
        fiscal_year_end='8月31日',
        submitter_name='株式会社農業総合研究所',
        submitter_name_en='Nousouken Corporation',
        submitter_name_yomi='カブシキガイシャノウギョウソウゴウケンキュウジョ',
        address='和歌山市黒田９９番地１２',
        industry='サービス業',
        sec_code='35410',
        corporate_number='5170001006371',
    ),
    'E32352': EdinetCodeEntry(
        edinet_code='E32352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濵村\u3000聖一',
        submitter_name_en=None,
        submitter_name_yomi='ハマムラ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32353': EdinetCodeEntry(
        edinet_code='E32353',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＡＮＤＹ\u3000＆\u3000ＰＡＲＴＮＥＲＳ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='アンディ\u3000アンド\u3000パートナーズ\u3000プライベート\u3000リミティッド',
        address='３５０\u3000ＯＲＣＨＡＲＤ\u3000ＲＯＡＤ，\u3000＃１９－０２，\u3000ＳＨＡＷ\u3000ＨＯＵＳＥ，\u3000ＳＩＮＧＡＰＯＲＥ\u3000２３８８６８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32354': EdinetCodeEntry(
        edinet_code='E32354',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大津\u3000和行',
        submitter_name_en=None,
        submitter_name_yomi='オオツ\u3000カズユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32355': EdinetCodeEntry(
        edinet_code='E32355',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柿内\u3000和徳',
        submitter_name_en=None,
        submitter_name_yomi='カキウチ\u3000カズノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32359': EdinetCodeEntry(
        edinet_code='E32359',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川瀬\u3000太志',
        submitter_name_en=None,
        submitter_name_yomi='カワセ\u3000フトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32360': EdinetCodeEntry(
        edinet_code='E32360',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='各務\u3000正人',
        submitter_name_en=None,
        submitter_name_yomi='カカム\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32364': EdinetCodeEntry(
        edinet_code='E32364',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1245,
        fiscal_year_end='6月30日',
        submitter_name='株式会社やまみ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマミ',
        address='三原市沼田西町小原字袖掛７３－５',
        industry='食料品',
        sec_code='28200',
        corporate_number='4240001040001',
    ),
    'E32373': EdinetCodeEntry(
        edinet_code='E32373',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=440,
        fiscal_year_end='6月30日',
        submitter_name='株式会社バリューデザイン',
        submitter_name_en='VALUEDESIGN INC.',
        submitter_name_yomi='カブシキガイシャバリューデザイン',
        address='中央区八丁堀三丁目３番５号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010001101786',
    ),
    'E32374': EdinetCodeEntry(
        edinet_code='E32374',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='原尾\u3000正紀',
        submitter_name_en=None,
        submitter_name_yomi='ハラオ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32376': EdinetCodeEntry(
        edinet_code='E32376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人サムコ科学技術振興財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンサムコカガクギジュツシンコウザイダン',
        address='京都市伏見区竹田藁屋町３６番地サムコ株式会社内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130005014559',
    ),
    'E32379': EdinetCodeEntry(
        edinet_code='E32379',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ジーエムシーエム・ベンチャー・キャピタル・パートーズ・ワン・インク',
        submitter_name_en=None,
        submitter_name_yomi='ジーエムシーエムベンチャーキャピタルパートーズワンインク',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000２，Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000ＶＧ１１１０，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32380': EdinetCodeEntry(
        edinet_code='E32380',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=823,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ストライク',
        submitter_name_en='Strike Company, Limited',
        submitter_name_yomi='カブシキガイシャストライク',
        address='千代田区大手町一丁目２番１号',
        industry='サービス業',
        sec_code='61960',
        corporate_number='7010001079968',
    ),
    'E32381': EdinetCodeEntry(
        edinet_code='E32381',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='5月15日',
        submitter_name='サツドラホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サツドラホールディングスカブシキガイシャ',
        address='札幌市東区北八条東四丁目１番２０号',
        industry='小売業',
        sec_code='35440',
        corporate_number='6430001072213',
    ),
    'E32382': EdinetCodeEntry(
        edinet_code='E32382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2011,
        fiscal_year_end='2月末日',
        submitter_name='アレンザホールディングス株式会社',
        submitter_name_en='Alleanza Holdings Co., Ltd.',
        submitter_name_yomi='アレンザホールディングスカブシキガイシャ',
        address='福島市太平寺字堰ノ上５８番地',
        industry='小売業',
        sec_code='35460',
        corporate_number='3380001027299',
    ),
    'E32391': EdinetCodeEntry(
        edinet_code='E32391',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='境\u3000弘治',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32393': EdinetCodeEntry(
        edinet_code='E32393',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='荒井\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32395': EdinetCodeEntry(
        edinet_code='E32395',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='ＶＩＳ\u3000Ａｄｖｉｓｏｒｓ，ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='ブイアイエス\u3000アドバイザーズ\u3000エルピー',
        address='４８８\u3000Ｍａｄｉｓｏｎ\u3000Ａｖｅｎｕｅ\u3000２１ｓｔ\u3000ｆｌｏｏｒ\u3000Ｎｅｗ\u3000Ｙｏｒｋ，\u3000ＮＹ\u3000１００２２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32396': EdinetCodeEntry(
        edinet_code='E32396',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福井\u3000隆一郎',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000リュウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32397': EdinetCodeEntry(
        edinet_code='E32397',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=305,
        fiscal_year_end='8月31日',
        submitter_name='株式会社セラク',
        submitter_name_en='SERAKU.,Co.Ltd.',
        submitter_name_yomi='セラクカブシキカイシャ',
        address='新宿区西新宿７丁目５番２５号',
        industry='サービス業',
        sec_code='61990',
        corporate_number='1011101032087',
    ),
    'E32400': EdinetCodeEntry(
        edinet_code='E32400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1331,
        fiscal_year_end='9月末日',
        submitter_name='株式会社アトラエ',
        submitter_name_en='Atrae, Inc.',
        submitter_name_yomi='カブシキガイシャアトラエ',
        address='港区麻布十番１－１０－１０',
        industry='情報・通信業',
        sec_code='61940',
        corporate_number='6010401060842',
    ),
    'E32405': EdinetCodeEntry(
        edinet_code='E32405',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ホープ',
        submitter_name_en='HOPE, INC.',
        submitter_name_yomi='カブシキガイシャホープ',
        address='福岡市中央区薬院一丁目１４番５号\u3000ＭＧ薬院ビル',
        industry='サービス業',
        sec_code='61950',
        corporate_number='3290001029577',
    ),
    'E32408': EdinetCodeEntry(
        edinet_code='E32408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=799,
        fiscal_year_end='3月末日',
        submitter_name='株式会社Ｕｂｉｃｏｍホールディングス',
        submitter_name_en='Ubicom Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャユビコムホールデイングス',
        address='千代田区一番町２１',
        industry='情報・通信業',
        sec_code='39370',
        corporate_number='8010401059998',
    ),
    'E32410': EdinetCodeEntry(
        edinet_code='E32410',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菊水取引先持株会\u3000理事長\u3000藤田\u3000哲郎',
        submitter_name_en=None,
        submitter_name_yomi='キクスイトリヒキサキモチカブカイ\u3000リジチョウ\u3000フジタ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32412': EdinetCodeEntry(
        edinet_code='E32412',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=720,
        fiscal_year_end='3月31日',
        submitter_name='ジェイリース株式会社',
        submitter_name_en='J-LEASE CO.,LTD.',
        submitter_name_yomi='ジェイリースカブシキガイシャ',
        address='大分市都町１丁目３番１９号\u3000大分中央ビル７階',
        industry='その他金融業',
        sec_code='71870',
        corporate_number='3320001003867',
    ),
    'E32413': EdinetCodeEntry(
        edinet_code='E32413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤原\u3000克朗',
        submitter_name_en=None,
        submitter_name_yomi='フジワラ\u3000カツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32419': EdinetCodeEntry(
        edinet_code='E32419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='賀川\u3000正宣',
        submitter_name_en=None,
        submitter_name_yomi='カガワ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32420': EdinetCodeEntry(
        edinet_code='E32420',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1037,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベガコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベガコーポレーション',
        address='福岡市博多区祇園町７－２０\u3000博多祇園センタープレイス４Ｆ',
        industry='小売業',
        sec_code='35420',
        corporate_number='9290001052160',
    ),
    'E32425': EdinetCodeEntry(
        edinet_code='E32425',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5,
        fiscal_year_end='3月31日',
        submitter_name='ライフアンドデザイン・グループ株式会社',
        submitter_name_en='Life And Design Group Co.,Ltd.',
        submitter_name_yomi='ライフアンドデザイングループカブシキガイシャ',
        address='中央区日本橋三丁目１３番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3130001057908',
    ),
    'E32427': EdinetCodeEntry(
        edinet_code='E32427',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=673,
        fiscal_year_end='2月末日',
        submitter_name='株式会社コメダホールディングス',
        submitter_name_en='KOMEDA Holdings Co., Ltd',
        submitter_name_yomi='カブシキガイシャコメダホールディングス',
        address='名古屋市東区葵三丁目１２番２３号',
        industry='卸売業',
        sec_code='35430',
        corporate_number='2180001116676',
    ),
    'E32428': EdinetCodeEntry(
        edinet_code='E32428',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=34223,
        fiscal_year_end=None,
        submitter_name='日本ホテル＆レジデンシャル投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンホテルアンドレジデンシャルトウシホウジン',
        address='港区赤坂二丁目１２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005025163',
    ),
    'E32429': EdinetCodeEntry(
        edinet_code='E32429',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3250,
        fiscal_year_end=None,
        submitter_name='旭化成ホームズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサヒカセイホームズカブシキガイシャ',
        address='千代田区神田神保町一丁目１０５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101001453',
    ),
    'E32430': EdinetCodeEntry(
        edinet_code='E32430',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='平安ジャパン・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピンアンジャパンインベストメントカブシキガイシャ',
        address='千代田区大手町一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401121513',
    ),
    'E32431': EdinetCodeEntry(
        edinet_code='E32431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社\u3000みやしろ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャ\u3000ミヤシロ',
        address='箕面市粟生新家５－４－７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120903001910',
    ),
    'E32436': EdinetCodeEntry(
        edinet_code='E32436',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀内\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='ホリウチ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32437': EdinetCodeEntry(
        edinet_code='E32437',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ワイエムアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイエムアセットマネジメントカブシキカイシャ',
        address='下関市竹崎町四丁目２番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2250001015730',
    ),
    'E32442': EdinetCodeEntry(
        edinet_code='E32442',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1175,
        fiscal_year_end=None,
        submitter_name='ホライズン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホライズンカブシキガイシャ',
        address='京都市東山区大仏南門通大和大路東入三丁目下ル本瓦町６６０－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401116778',
    ),
    'E32443': EdinetCodeEntry(
        edinet_code='E32443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯岡\u3000孝之',
        submitter_name_en=None,
        submitter_name_yomi='イイオカ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32444': EdinetCodeEntry(
        edinet_code='E32444',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1400,
        fiscal_year_end=None,
        submitter_name='マネックス・アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マネックスアセットマネジメントカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001170135',
    ),
    'E32446': EdinetCodeEntry(
        edinet_code='E32446',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='Ｂ\u3000Ｄａｓｈ\u3000Ｖｅｎｔｕｒｅｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーダッシュベンチャーズカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401098475',
    ),
    'E32447': EdinetCodeEntry(
        edinet_code='E32447',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社西日本フィナンシャルホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニシニッポンフィナンシャルホールディングス',
        address='福岡市博多区博多駅前三丁目１番１号',
        industry='銀行業',
        sec_code='71890',
        corporate_number='5290001075355',
    ),
    'E32448': EdinetCodeEntry(
        edinet_code='E32448',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2500,
        fiscal_year_end='3月31日',
        submitter_name='野村貿易株式会社',
        submitter_name_en='Nomura Trading Co., Ltd.',
        submitter_name_yomi='ノムラボウエキカブシキカイシャ',
        address='大阪市中央区安土町１丁目７番３号',
        industry='卸売業',
        sec_code=None,
        corporate_number='5120001074101',
    ),
    'E32449': EdinetCodeEntry(
        edinet_code='E32449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人千尋会',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンチヒロカイ',
        address='大阪市天王寺区上本町八丁目４番１５－１３０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120005018685',
    ),
    'E32450': EdinetCodeEntry(
        edinet_code='E32450',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='三井不動産ロジスティクスパーク投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ミツイフドウサンロジスティクスパークトウシホウジン',
        address='中央区銀座六丁目８番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005025065',
    ),
    'E32451': EdinetCodeEntry(
        edinet_code='E32451',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='フリージアホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フリージアホールディングスカブシキガイシャ',
        address='千代田区神田東松下町１７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001175926',
    ),
    'E32452': EdinetCodeEntry(
        edinet_code='E32452',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='フリージアキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フリージアキャピタルカブシキガイシャ',
        address='千代田区神田東松下町１７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001175927',
    ),
    'E32453': EdinetCodeEntry(
        edinet_code='E32453',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社歯愛メディカル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシイアイメディカル',
        address='白山市鹿島町一号９番地１',
        industry='卸売業',
        sec_code=None,
        corporate_number='7220001009185',
    ),
    'E32454': EdinetCodeEntry(
        edinet_code='E32454',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='及川\u3000智正',
        submitter_name_en=None,
        submitter_name_yomi='オイカワ\u3000トモマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32456': EdinetCodeEntry(
        edinet_code='E32456',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=149,
        fiscal_year_end='6月30日',
        submitter_name='リファインバース株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リファインバースカブシキガイシャ',
        address='中央区日本橋人形町三丁目１０番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010001088555',
    ),
    'E32458': EdinetCodeEntry(
        edinet_code='E32458',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社Ｈａｋｕｈｏｄｏ\u3000ＤＹ\u3000ＯＮＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャハクホウドウディーワイワン',
        address='港区赤坂五丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001113101',
    ),
    'E32459': EdinetCodeEntry(
        edinet_code='E32459',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社プレンティー',
        submitter_name_en=None,
        submitter_name_yomi='カブシイキガイシャプレンティー',
        address='品川区上大崎２－２５－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101018893',
    ),
    'E32460': EdinetCodeEntry(
        edinet_code='E32460',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永津\u3000嘉人',
        submitter_name_en=None,
        submitter_name_yomi='ナガツ\u3000ヨシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32461': EdinetCodeEntry(
        edinet_code='E32461',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社飯田',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイイダ',
        address='加賀市田尻町西１９０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8220001013046',
    ),
    'E32462': EdinetCodeEntry(
        edinet_code='E32462',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大房\u3000翔',
        submitter_name_en=None,
        submitter_name_yomi='オオフサ\u3000ショウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32463': EdinetCodeEntry(
        edinet_code='E32463',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池\u3000恵理香',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000エリカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32466': EdinetCodeEntry(
        edinet_code='E32466',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='臼井\u3000貴弘',
        submitter_name_en=None,
        submitter_name_yomi='ウスイ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32468': EdinetCodeEntry(
        edinet_code='E32468',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=223,
        fiscal_year_end='6月末日',
        submitter_name='株式会社デュアルタップ',
        submitter_name_en='Dualtap Co., Ltd.',
        submitter_name_yomi='カブシキカイシャデュアルタップ',
        address='中央区日本橋久松町４番７号',
        industry='不動産業',
        sec_code='34690',
        corporate_number='2010701017604',
    ),
    'E32470': EdinetCodeEntry(
        edinet_code='E32470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山名\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32471': EdinetCodeEntry(
        edinet_code='E32471',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山名\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32478': EdinetCodeEntry(
        edinet_code='E32478',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=42536,
        fiscal_year_end=None,
        submitter_name='ホンハイジンミゴンイェ・グーフェン・ヨーシェン・コンスー',
        submitter_name_en=None,
        submitter_name_yomi='ホンハイジンミゴンイェグーフェンヨーシェンコンスー',
        address='タイワン、ニュー・タイペイ・シティ２３６、トゥーチョン・ディストリクト、ジョンシャン・ロード６６号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32480': EdinetCodeEntry(
        edinet_code='E32480',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15679,
        fiscal_year_end=None,
        submitter_name='フォックスコン・テクノロジー・ピーティーイー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='フォックスコンテクノロジーピーティーイーエルティーディー',
        address='（２３８１６４）シンガポール\u3000＃１３‐３３\u3000サマーセット１１１\u3000サマーセット・ロード１１１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32481': EdinetCodeEntry(
        edinet_code='E32481',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=250000,
        fiscal_year_end=None,
        submitter_name='ＳＩＯ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エスアイオーインターナショナルホールディングスリミテッド',
        address='Ｆｌｏｏｒ\u3000４，\u3000Ｗｉｌｌｏｗ\u3000Ｈｏｕｓｅ，\u3000Ｃｒｉｃｋｅｔ\u3000Ｓｑｕａｒｅ，\u3000Ｐ\u3000Ｏ\u3000Ｂｏｘ\u3000２８０４，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－１１１２，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32482': EdinetCodeEntry(
        edinet_code='E32482',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青木\u3000正之',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32484': EdinetCodeEntry(
        edinet_code='E32484',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｄｉｍｅｎｓｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディメンション',
        address='大田区南千束一丁目８番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010801022624',
    ),
    'E32486': EdinetCodeEntry(
        edinet_code='E32486',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月末日',
        submitter_name='Ｇ－ＦＡＣＴＯＲＹ株式会社',
        submitter_name_en='G-FACTORY CO.,LTD.',
        submitter_name_yomi='ジーファクトリーカブシキカイシャ',
        address='新宿区西新宿一丁目２５番１号',
        industry='不動産業',
        sec_code='34740',
        corporate_number='5011101035359',
    ),
    'E32491': EdinetCodeEntry(
        edinet_code='E32491',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片平\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='カタヒラ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32492': EdinetCodeEntry(
        edinet_code='E32492',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3367,
        fiscal_year_end=None,
        submitter_name='公益財団法人日鉄鉱業奨学会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンニッテツコウギョウショウガクカイ',
        address='新宿区四谷三丁目１番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011105000193',
    ),
    'E32494': EdinetCodeEntry(
        edinet_code='E32494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丸山\u3000栄樹',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000エイキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32495': EdinetCodeEntry(
        edinet_code='E32495',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='9月30日',
        submitter_name='株式会社インソース',
        submitter_name_en='Insource Co.,Ltd',
        submitter_name_yomi='カブシキガイシャインソース',
        address='千代田区神田小川町三丁目２０番地',
        industry='サービス業',
        sec_code='62000',
        corporate_number='5010001080795',
    ),
    'E32497': EdinetCodeEntry(
        edinet_code='E32497',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神林\u3000忠弘',
        submitter_name_en=None,
        submitter_name_yomi='カンバヤシ\u3000タダヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32505': EdinetCodeEntry(
        edinet_code='E32505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新居\u3000佳英',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000ヨシヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32512': EdinetCodeEntry(
        edinet_code='E32512',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='浮城\u3000智和',
        submitter_name_en=None,
        submitter_name_yomi='ウキシロ\u3000トモカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32516': EdinetCodeEntry(
        edinet_code='E32516',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='時津\u3000孝康',
        submitter_name_en=None,
        submitter_name_yomi='トキツ\u3000タカヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32518': EdinetCodeEntry(
        edinet_code='E32518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永野\u3000祐司',
        submitter_name_en=None,
        submitter_name_yomi='ナガノ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32523': EdinetCodeEntry(
        edinet_code='E32523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='舟橋孝之',
        submitter_name_en=None,
        submitter_name_yomi='フナハシタカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32524': EdinetCodeEntry(
        edinet_code='E32524',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川端\u3000久美子',
        submitter_name_en=None,
        submitter_name_yomi='カワバタ\u3000クミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32526': EdinetCodeEntry(
        edinet_code='E32526',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮崎\u3000浩美',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキ\u3000ヒロミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32527': EdinetCodeEntry(
        edinet_code='E32527',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮﨑\u3000龍己',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキ\u3000タツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32534': EdinetCodeEntry(
        edinet_code='E32534',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000清人',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000キヨト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32541': EdinetCodeEntry(
        edinet_code='E32541',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='越智\u3000晶',
        submitter_name_en=None,
        submitter_name_yomi='オチ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32546': EdinetCodeEntry(
        edinet_code='E32546',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='明治安田生命２０１６基金特定目的会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイニセンジュウロクキキントクテイモクテキカイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005025451',
    ),
    'E32549': EdinetCodeEntry(
        edinet_code='E32549',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=282,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ベイカレント',
        submitter_name_en='BayCurrent, Inc.',
        submitter_name_yomi='ベイカレント',
        address='港区麻布台一丁目３番１号',
        industry='サービス業',
        sec_code='65320',
        corporate_number='7010401111553',
    ),
    'E32551': EdinetCodeEntry(
        edinet_code='E32551',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人出光文化福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンイデミツブンカフクシザイダン',
        address='目黒区青葉台三丁目４番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013205001655',
    ),
    'E32552': EdinetCodeEntry(
        edinet_code='E32552',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人出光美術館',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンイデミツビジュツカン',
        address='千代田区有楽町１－９－４蚕糸会館１０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010005015208',
    ),
    'E32554': EdinetCodeEntry(
        edinet_code='E32554',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000久夫',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000ヒサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32560': EdinetCodeEntry(
        edinet_code='E32560',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='工藤\u3000恭輔',
        submitter_name_en=None,
        submitter_name_yomi='クドウ\u3000キョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32571': EdinetCodeEntry(
        edinet_code='E32571',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=789,
        fiscal_year_end='11月30日',
        submitter_name='株式会社フィル・カンパニー',
        submitter_name_en='Phil Company,Inc.',
        submitter_name_yomi='カブシキカイシャフィルカンパニー',
        address='中央区築地３丁目１番１２号',
        industry='建設業',
        sec_code='32670',
        corporate_number='6010001141308',
    ),
    'E32577': EdinetCodeEntry(
        edinet_code='E32577',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1209,
        fiscal_year_end='9月末日',
        submitter_name='株式会社デファクトスタンダード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデファクトスタンダード',
        address='大田区平和島三丁目３番８号',
        industry='小売業',
        sec_code=None,
        corporate_number='1010801019955',
    ),
    'E32579': EdinetCodeEntry(
        edinet_code='E32579',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='五味\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ゴミ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32585': EdinetCodeEntry(
        edinet_code='E32585',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='貫\u3000啓二',
        submitter_name_en=None,
        submitter_name_yomi='ヌキ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32591': EdinetCodeEntry(
        edinet_code='E32591',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=319,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ノムラシステムコーポレーション',
        submitter_name_en='Nomura System Corporation Co, Ltd.',
        submitter_name_yomi='カブシキガイシャノムラシステムコーポレーション',
        address='渋谷区恵比寿一丁目１９番１９号',
        industry='情報・通信業',
        sec_code='39400',
        corporate_number='3011001035642',
    ),
    'E32592': EdinetCodeEntry(
        edinet_code='E32592',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=305,
        fiscal_year_end='11月30日',
        submitter_name='株式会社串カツ田中ホールディングス',
        submitter_name_en='KUSHIKATSU TANAKA HOLDINGS CO.',
        submitter_name_yomi='カブシキガイシャクシカツタナカホールディングス',
        address='品川区東五反田一丁目７番６号',
        industry='小売業',
        sec_code='35470',
        corporate_number='8010901029204',
    ),
    'E32598': EdinetCodeEntry(
        edinet_code='E32598',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000伸彰',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32601': EdinetCodeEntry(
        edinet_code='E32601',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=354,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｏｒｃｈｅｓｔｒａ\u3000Ｈｏｌｄｉｎｇｓ',
        submitter_name_en='Orchestra Holdings Inc.',
        submitter_name_yomi='オーケストラホールディングス',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='サービス業',
        sec_code='65330',
        corporate_number='3011001061184',
    ),
    'E32602': EdinetCodeEntry(
        edinet_code='E32602',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000正則',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32603': EdinetCodeEntry(
        edinet_code='E32603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=192,
        fiscal_year_end='9月30日',
        submitter_name='株式会社カナミックネットワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカナミックネットワーク',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='情報・通信業',
        sec_code='39390',
        corporate_number='9010701012714',
    ),
    'E32604': EdinetCodeEntry(
        edinet_code='E32604',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野村\u3000芳光',
        submitter_name_en=None,
        submitter_name_yomi='ノムラ\u3000ヨシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32608': EdinetCodeEntry(
        edinet_code='E32608',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野市\u3000裕作',
        submitter_name_en=None,
        submitter_name_yomi='ノイチ\u3000ユウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32613': EdinetCodeEntry(
        edinet_code='E32613',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000亨樹',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トシキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32614': EdinetCodeEntry(
        edinet_code='E32614',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='有限会社エム・ティ・シー開発',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエムティシーカイハツ',
        address='芦屋市船戸町１２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140002027206',
    ),
    'E32618': EdinetCodeEntry(
        edinet_code='E32618',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＳＫ\u3000ｃａｐｉｔａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーエスケーキャピタルカブシキカイシャ',
        address='港区港南２丁目５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001102262',
    ),
    'E32619': EdinetCodeEntry(
        edinet_code='E32619',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=935,
        fiscal_year_end='9月30日',
        submitter_name='株式会社キャピタル・アセット・プランニング',
        submitter_name_en='Capital Asset Planning, Inc.',
        submitter_name_yomi='カブシキカイシャキャピタルアセットプランニング',
        address='大阪市北区堂島二丁目４番２７号',
        industry='情報・通信業',
        sec_code='39650',
        corporate_number='3120001077956',
    ),
    'E32620': EdinetCodeEntry(
        edinet_code='E32620',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1006,
        fiscal_year_end='3月31日',
        submitter_name='株式会社チェンジホールディングス',
        submitter_name_en='CHANGE Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャチェンジホールディングス',
        address='港区虎ノ門三丁目１７番１号',
        industry='情報・通信業',
        sec_code='39620',
        corporate_number='4011001048627',
    ),
    'E32624': EdinetCodeEntry(
        edinet_code='E32624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=285,
        fiscal_year_end='12月31日',
        submitter_name='シルバーエッグ・テクノロジー株式会社',
        submitter_name_en='Silver Egg Technology CO.,Ltd.',
        submitter_name_yomi='シルバーエッグテクノロジーカブシキガイシャ',
        address='吹田市江坂町一丁目２３番４３号',
        industry='情報・通信業',
        sec_code='39610',
        corporate_number='2120901013128',
    ),
    'E32626': EdinetCodeEntry(
        edinet_code='E32626',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='慶キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨシキャピタルカブシキガイシャ',
        address='港区港南２丁目５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001102263',
    ),
    'E32627': EdinetCodeEntry(
        edinet_code='E32627',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000慶郎',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヨシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32631': EdinetCodeEntry(
        edinet_code='E32631',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='守分\u3000孝治',
        submitter_name_en=None,
        submitter_name_yomi='モリワケ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32632': EdinetCodeEntry(
        edinet_code='E32632',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='サウスダコタ\u3000トラストカンパニー\u3000エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='サウスダコタ\u3000トラストカンパニー\u3000エルエルシー',
        address='アメリカ合衆国サウスダコタ州ジオックスフォールズサウスフィリップスアヴェニュー２０１スィート２００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32636': EdinetCodeEntry(
        edinet_code='E32636',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='12月末日',
        submitter_name='モルガン・スタンレー・ファイナンス・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='モルガン\u3000スタンレー\u3000ファイナンス\u3000エルエルシー',
        address='アメリカ合衆国\u3000１００３６\u3000ニューヨーク州ニューヨーク\u3000ブロードウェイ１５８５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32642': EdinetCodeEntry(
        edinet_code='E32642',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8855,
        fiscal_year_end='12月31日',
        submitter_name='ＫＨネオケム株式会社',
        submitter_name_en='KH Neochem Co.,Ltd.',
        submitter_name_yomi='ケイエイチネオケムカブシキガイシャ',
        address='中央区日本橋室町二丁目３番１号',
        industry='化学',
        sec_code='41890',
        corporate_number='8010001136966',
    ),
    'E32647': EdinetCodeEntry(
        edinet_code='E32647',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=882,
        fiscal_year_end='3月末日',
        submitter_name='株式会社シンクロ・フード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンクロフード',
        address='渋谷区恵比寿南一丁目７番８号',
        industry='情報・通信業',
        sec_code='39630',
        corporate_number='9011001044563',
    ),
    'E32654': EdinetCodeEntry(
        edinet_code='E32654',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='株式会社Ｋａｗａｓｈｉｍａ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカワシマ',
        address='練馬区富士見台四丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011601020181',
    ),
    'E32659': EdinetCodeEntry(
        edinet_code='E32659',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26,
        fiscal_year_end=None,
        submitter_name='有限会社ジャスト',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャジャスト',
        address='宇陀郡曽爾村大字今井６３４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4150002000830',
    ),
    'E32660': EdinetCodeEntry(
        edinet_code='E32660',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='12月31日',
        submitter_name='ＡＯＩ\u3000ＴＹＯ\u3000Ｈｏｌｄｉｎｇｓ\u3000株式会社',
        submitter_name_en='AOI TYO Holdings Inc.',
        submitter_name_yomi='アオイティーワイオーホールディングスカブシキガイシャ',
        address='品川区東品川二丁目２番２４号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010401129071',
    ),
    'E32662': EdinetCodeEntry(
        edinet_code='E32662',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人大西・アオイ記念財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンオオニシアオイキネンザイダン',
        address='高松市上林町１４８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9470005005831',
    ),
    'E32664': EdinetCodeEntry(
        edinet_code='E32664',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ノバレーゼ',
        submitter_name_en='NOVARESE,Inc.',
        submitter_name_yomi='カブシキガイシャノバレーゼ',
        address='中央区銀座一丁目８番１４号',
        industry='サービス業',
        sec_code='91600',
        corporate_number='1010001177471',
    ),
    'E32673': EdinetCodeEntry(
        edinet_code='E32673',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7189,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ユーザベース',
        submitter_name_en='Uzabase, Inc.',
        submitter_name_yomi='カブシキカイシャユーザベース',
        address='千代田区丸の内二丁目５番２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010401075212',
    ),
    'E32679': EdinetCodeEntry(
        edinet_code='E32679',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16000,
        fiscal_year_end='3月31日',
        submitter_name='九州旅客鉄道株式会社',
        submitter_name_en='Kyushu Railway Company',
        submitter_name_yomi='キュウシュウリョカクテツドウカブシキカイシャ',
        address='福岡市博多区博多駅前三丁目２５番２１号',
        industry='陸運業',
        sec_code='91420',
        corporate_number='6290001012621',
    ),
    'E32680': EdinetCodeEntry(
        edinet_code='E32680',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000俊彦',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32681': EdinetCodeEntry(
        edinet_code='E32681',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野口\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='ノグチ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32682': EdinetCodeEntry(
        edinet_code='E32682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=61,
        fiscal_year_end='9月末日',
        submitter_name='株式会社岐阜造園',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャギフゾウエン',
        address='岐阜市茜部菱野四丁目７９番地の１',
        industry='建設業',
        sec_code='14380',
        corporate_number='4200001001361',
    ),
    'E32683': EdinetCodeEntry(
        edinet_code='E32683',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=400,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ＦＣホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエフシーホールディングス',
        address='福岡市博多区博多駅東三丁目６番１８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3290001076297',
    ),
    'E32685': EdinetCodeEntry(
        edinet_code='E32685',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＣＬＳＡ\u3000Ｓｕｎｒｉｓｅ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000（Ｎｏｎ－Ｕ．Ｓ．）\u3000Ｌｉｍｉｔｅｄ\u3000ＩＩ',
        submitter_name_en=None,
        submitter_name_yomi='シーエルエスエー\u3000サンライズ\u3000マネジメント\u3000ノン\u3000ユーエス\u3000リミテッド\u3000ツー',
        address='ケイマン諸島、グランドケイマン、ジョージタウン、ハッチンズ・ドライブ、クリケット・スクエア、私書箱２６８１、コンヤーズ・トラスト・カンパニー（ケイマン）・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32686': EdinetCodeEntry(
        edinet_code='E32686',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＣＬＳＡ\u3000Ｓｕｎｒｉｓｅ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ\u3000ＩＩ',
        submitter_name_en=None,
        submitter_name_yomi='シーエルエスエー\u3000サンライズ\u3000マネジメント\u3000リミテッド\u3000ツー',
        address='ケイマン諸島、グランドケイマン、ジョージタウン、ハッチンズ・ドライブ、クリケット・スクエア、私書箱２６８１、コンヤーズ・トラスト・カンパニー（ケイマン）・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32687': EdinetCodeEntry(
        edinet_code='E32687',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=152,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アイモバイル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイモバイル',
        address='渋谷区桜丘町２２－１４\u3000Ｎ．Ｅ．Ｓ．ビルＮ棟２階',
        industry='サービス業',
        sec_code='65350',
        corporate_number='4011001059087',
    ),
    'E32689': EdinetCodeEntry(
        edinet_code='E32689',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新野\u3000良介',
        submitter_name_en=None,
        submitter_name_yomi='ニイノ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32690': EdinetCodeEntry(
        edinet_code='E32690',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='サンデン取引先持株会\u3000理事長\u3000古賀友二',
        submitter_name_en=None,
        submitter_name_yomi='サンデントリヒキサキモチカブカイ\u3000リジチョウ\u3000コガユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32691': EdinetCodeEntry(
        edinet_code='E32691',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社エスエム・エンタテインメント・ジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエスエムエンタテインメントジャパン',
        address='港区六本木三丁目２番１号住友不動産六本木グランドタワー２１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401060106',
    ),
    'E32692': EdinetCodeEntry(
        edinet_code='E32692',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60000,
        fiscal_year_end=None,
        submitter_name='第一生命保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイイチセイメイホケンカブシキガイシャ',
        address='千代田区有楽町一丁目１３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001174683',
    ),
    'E32693': EdinetCodeEntry(
        edinet_code='E32693',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社和田ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワダホールディングス',
        address='大阪市西区新町１－１４－２１－３１０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120002068505',
    ),
    'E32697': EdinetCodeEntry(
        edinet_code='E32697',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8258,
        fiscal_year_end='2月末日',
        submitter_name='株式会社バロックジャパンリミテッド',
        submitter_name_en='Baroque Japan Limited',
        submitter_name_yomi='バロックジャパンリミテッド',
        address='目黒区青葉台４－７－７\u3000青葉台ヒルズ１１階',
        industry='小売業',
        sec_code='35480',
        corporate_number='9013201014379',
    ),
    'E32700': EdinetCodeEntry(
        edinet_code='E32700',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000拓真',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タクマ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32701': EdinetCodeEntry(
        edinet_code='E32701',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000稔',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32705': EdinetCodeEntry(
        edinet_code='E32705',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=213,
        fiscal_year_end=None,
        submitter_name='株式会社フィールド・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='フィールドパートナーズ',
        address='港区虎ノ門一丁目２番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001114490',
    ),
    'E32706': EdinetCodeEntry(
        edinet_code='E32706',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ナマイ・アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナマイアセットマネジメント',
        address='世田谷区玉川台二丁目２２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010901035324',
    ),
    'E32715': EdinetCodeEntry(
        edinet_code='E32715',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤代\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='フジシロ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32716': EdinetCodeEntry(
        edinet_code='E32716',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大須賀\u3000康人',
        submitter_name_en=None,
        submitter_name_yomi='オオスガ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32717': EdinetCodeEntry(
        edinet_code='E32717',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾上\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='オノエ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32718': EdinetCodeEntry(
        edinet_code='E32718',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='トーマス・アクイナス・フォーリー',
        submitter_name_en=None,
        submitter_name_yomi='トーマス\u3000アクイナス\u3000フォーリー',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32719': EdinetCodeEntry(
        edinet_code='E32719',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='株式会社シークエッジ・ジャパン・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシークエッジジャパンホールディングス',
        address='岸和田市荒木町二丁目１８番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120101036936',
    ),
    'E32721': EdinetCodeEntry(
        edinet_code='E32721',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永田浩一',
        submitter_name_en=None,
        submitter_name_yomi='ナガタコウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32724': EdinetCodeEntry(
        edinet_code='E32724',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡﨑\u3000勇',
        submitter_name_en=None,
        submitter_name_yomi='オカザキ\u3000イサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32725': EdinetCodeEntry(
        edinet_code='E32725',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4954,
        fiscal_year_end=None,
        submitter_name='いちごグリーンインフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='イチゴグリーンインフラトウシホウジン',
        address='千代田区丸の内二丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005025499',
    ),
    'E32726': EdinetCodeEntry(
        edinet_code='E32726',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅田\u3000優祐',
        submitter_name_en=None,
        submitter_name_yomi='ウメダ\u3000ユウスケ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32727': EdinetCodeEntry(
        edinet_code='E32727',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='稲垣\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='イナガキ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32728': EdinetCodeEntry(
        edinet_code='E32728',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神保\u3000吉寿',
        submitter_name_en=None,
        submitter_name_yomi='ジンボ\u3000ヨシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32729': EdinetCodeEntry(
        edinet_code='E32729',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000範光',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ノリミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32732': EdinetCodeEntry(
        edinet_code='E32732',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000彰',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32733': EdinetCodeEntry(
        edinet_code='E32733',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石原\u3000徹哉',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32734': EdinetCodeEntry(
        edinet_code='E32734',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金田\u3000憲治',
        submitter_name_en=None,
        submitter_name_yomi='カネダ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32735': EdinetCodeEntry(
        edinet_code='E32735',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福留\u3000大士',
        submitter_name_en=None,
        submitter_name_yomi='フクドメ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32736': EdinetCodeEntry(
        edinet_code='E32736',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=391,
        fiscal_year_end='2月末日',
        submitter_name='株式会社スタジオアタオ',
        submitter_name_en='STUDIO ATAO Co.Ltd.',
        submitter_name_yomi='カブシキガイシャスタジオアタオ',
        address='神戸市中央区御幸通８丁目１番６号',
        industry='小売業',
        sec_code='35500',
        corporate_number='8140001028011',
    ),
    'E32744': EdinetCodeEntry(
        edinet_code='E32744',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=51892,
        fiscal_year_end=None,
        submitter_name='投資法人みらい',
        submitter_name_en=None,
        submitter_name_yomi='トウシホウジンミライ',
        address='千代田区西神田三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010405014402',
    ),
    'E32745': EdinetCodeEntry(
        edinet_code='E32745',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社東横イン',
        submitter_name_en='Toyoko-Inn Co.,Ltd',
        submitter_name_yomi='カブシキガイシャトウヨコイン',
        address='大田区新蒲田１－７－４',
        industry='サービス業',
        sec_code=None,
        corporate_number='8010801008365',
    ),
    'E32750': EdinetCodeEntry(
        edinet_code='E32750',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1217,
        fiscal_year_end='2月末日',
        submitter_name='株式会社エルテス',
        submitter_name_en='Eltes Co., Ltd.',
        submitter_name_yomi='カブシキカイシャエルテス',
        address='紫波郡紫波町紫波中央駅前二丁目３番地９４',
        industry='情報・通信業',
        sec_code='39670',
        corporate_number='4010401099544',
    ),
    'E32753': EdinetCodeEntry(
        edinet_code='E32753',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=996,
        fiscal_year_end='12月31日',
        submitter_name='ＷＡＳＨハウス株式会社',
        submitter_name_en='WASHHOUSE CO.,LTD.',
        submitter_name_yomi='ウォシュハウスカブシキカイシャ',
        address='宮崎市新栄町８６番地１',
        industry='サービス業',
        sec_code='65370',
        corporate_number='7350001002813',
    ),
    'E32757': EdinetCodeEntry(
        edinet_code='E32757',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊島\u3000半七',
        submitter_name_en=None,
        submitter_name_yomi='トヨシマ\u3000ハンシチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32760': EdinetCodeEntry(
        edinet_code='E32760',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社フィンテックマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャフィンテックマネジメント',
        address='大阪市北区堂島二丁目４番４－６１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120003011600',
    ),
    'E32763': EdinetCodeEntry(
        edinet_code='E32763',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=391,
        fiscal_year_end='3月末日',
        submitter_name='株式会社イントラスト',
        submitter_name_en='Entrust Inc.',
        submitter_name_yomi='カブシキガイシャイントラスト',
        address='千代田区麹町一丁目４番地',
        industry='その他金融業',
        sec_code='71910',
        corporate_number='6010001133718',
    ),
    'E32766': EdinetCodeEntry(
        edinet_code='E32766',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=348,
        fiscal_year_end='3月末日',
        submitter_name='株式会社イノベーション',
        submitter_name_en='Innovation Inc.',
        submitter_name_yomi='カブシキガイシャイノベーション',
        address='渋谷区渋谷３‐１０‐１３ＴＯＫＹＵＲＥＩＴ渋谷Ｒビル３Ｆ',
        industry='情報・通信業',
        sec_code='39700',
        corporate_number='5011001035806',
    ),
    'E32769': EdinetCodeEntry(
        edinet_code='E32769',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=98253,
        fiscal_year_end='12月31日',
        submitter_name='ハンファ・ソリューションズ・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ハンファソリューションズコーポレーション',
        address='大韓民国ソウル特別市中区清渓川路８６',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32770': EdinetCodeEntry(
        edinet_code='E32770',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=817,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＪＭＣ',
        submitter_name_en='JMC CORPORATION',
        submitter_name_yomi='カブシキガイシャジェイエムシー',
        address='横浜市港北区新横浜２－５－５',
        industry='非鉄金属',
        sec_code='57040',
        corporate_number='2020001035875',
    ),
    'E32773': EdinetCodeEntry(
        edinet_code='E32773',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='あすかホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アスカホールディングスカブシキガイシャ',
        address='港区南青山３－１－３６青山丸竹ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011002028050',
    ),
    'E32774': EdinetCodeEntry(
        edinet_code='E32774',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栗山\u3000博司',
        submitter_name_en=None,
        submitter_name_yomi='クリヤマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32779': EdinetCodeEntry(
        edinet_code='E32779',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1402,
        fiscal_year_end='12月31日',
        submitter_name='ロードスターキャピタル株式会社',
        submitter_name_en='Loadstar Capital K.K.',
        submitter_name_yomi='ロードスターキャピタルカブシキガイシャ',
        address='中央区銀座一丁目９番１３号\u3000プライム銀座柳通りビル７Ｆ',
        industry='不動産業',
        sec_code='34820',
        corporate_number='9011001072894',
    ),
    'E32781': EdinetCodeEntry(
        edinet_code='E32781',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='公益財団法人Ｔａｚａｋｉ財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンタザキザイダン',
        address='千代田区神田神保町一丁目１０５番地\u3000神保町三井ビルディング１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005025623',
    ),
    'E32784': EdinetCodeEntry(
        edinet_code='E32784',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=273,
        fiscal_year_end='12月31日',
        submitter_name='株式会社シンシア',
        submitter_name_en='Sincere Co., LTD.',
        submitter_name_yomi='カブシキガイシャシンシア',
        address='文京区本郷１丁目２８番３４号',
        industry='精密機器',
        sec_code='77820',
        corporate_number='5010001121120',
    ),
    'E32785': EdinetCodeEntry(
        edinet_code='E32785',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='エンデバー・ユナイテッド・パートナーズ・ツー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンデバーユナイテッドパートナーズツーカブシキガイシャ',
        address='千代田区丸の内二丁目５番１号丸の内二丁目ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001176660',
    ),
    'E32786': EdinetCodeEntry(
        edinet_code='E32786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ユニオン・ベイ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャユニオンベイ',
        address='大田区山王四丁目６番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011103003136',
    ),
    'E32790': EdinetCodeEntry(
        edinet_code='E32790',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000幸夫',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32791': EdinetCodeEntry(
        edinet_code='E32791',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｄｒｅａｍ\u3000Ｂｒｉｄｇｅ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ドリームブリッジカブシキガイシャ',
        address='渋谷区桜丘町２９ー３５渋谷Ｄマンション６Ｗ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001117934',
    ),
    'E32793': EdinetCodeEntry(
        edinet_code='E32793',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=154,
        fiscal_year_end='3月31日',
        submitter_name='フォーライフ株式会社',
        submitter_name_en='FORLIFE Co., Ltd.',
        submitter_name_yomi='フォーライフカブシキガイシャ',
        address='横浜市港北区大倉山１－１４－１１',
        industry='不動産業',
        sec_code='34770',
        corporate_number='8020001036389',
    ),
    'E32794': EdinetCodeEntry(
        edinet_code='E32794',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=335,
        fiscal_year_end='3月31日',
        submitter_name='株式会社うるる',
        submitter_name_en='ULURU.CO.,LTD.',
        submitter_name_yomi='カブシキカイシャウルル',
        address='中央区晴海３丁目１２－１\u3000ＫＤＸ晴海ビル９Ｆ',
        industry='情報・通信業',
        sec_code='39790',
        corporate_number='6010001096659',
    ),
    'E32795': EdinetCodeEntry(
        edinet_code='E32795',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=395,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ディスラプターズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディスラプターズ',
        address='港区南青山２丁目５番地１７号',
        industry='サービス業',
        sec_code='65380',
        corporate_number='4010401081592',
    ),
    'E32796': EdinetCodeEntry(
        edinet_code='E32796',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=419,
        fiscal_year_end='12月末日',
        submitter_name='株式会社船場',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセンバ',
        address='港区芝浦一丁目２番３号',
        industry='サービス業',
        sec_code='65400',
        corporate_number='4010501032297',
    ),
    'E32798': EdinetCodeEntry(
        edinet_code='E32798',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='板倉\u3000広高',
        submitter_name_en=None,
        submitter_name_yomi='イタクラ\u3000ヒロタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32800': EdinetCodeEntry(
        edinet_code='E32800',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人西川記念財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンニシカワキネンザイダン',
        address='広島市西区三篠町二丁目２番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4240005013399',
    ),
    'E32801': EdinetCodeEntry(
        edinet_code='E32801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＭＳ－Ｊａｐａｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムエスジャパン',
        address='千代田区富士見２－１０－２\u3000飯田橋グラン・ブルーム',
        industry='サービス業',
        sec_code='65390',
        corporate_number='9120001111949',
    ),
    'E32802': EdinetCodeEntry(
        edinet_code='E32802',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松村\u3000幸治',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000ユキハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32803': EdinetCodeEntry(
        edinet_code='E32803',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1061,
        fiscal_year_end='3月31日',
        submitter_name='日本モーゲージサービス株式会社',
        submitter_name_en='Mortgage Service Japan Limited',
        submitter_name_yomi='ニホンモーゲージサービスカブシキガイシャ',
        address='港区新橋４丁目３番１号',
        industry='その他金融業',
        sec_code='71920',
        corporate_number='2010401062405',
    ),
    'E32806': EdinetCodeEntry(
        edinet_code='E32806',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1271928,
        fiscal_year_end='7月1日',
        submitter_name='ウエスタン・デジタル・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ウエスタンデジタルコーポレーション',
        address='アメリカ合衆国カリフォルニア州９５１１９、サンタクララ郡、サンノゼ、グレート・オークス・パークウェイ５６０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32808': EdinetCodeEntry(
        edinet_code='E32808',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小栗\u3000勝郎',
        submitter_name_en=None,
        submitter_name_yomi='オグリ\u3000カツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32811': EdinetCodeEntry(
        edinet_code='E32811',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=245,
        fiscal_year_end='3月末日',
        submitter_name='グレイステクノロジー株式会社',
        submitter_name_en='GRACE TECHNOLOGY, INC.',
        submitter_name_yomi='グレイステクノロジーカブシキカイシャ',
        address='港区虎ノ門三丁目８番２１号\u3000虎ノ門３３森ビル７Ｆ',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001070226',
    ),
    'E32814': EdinetCodeEntry(
        edinet_code='E32814',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='10月末日',
        submitter_name='ＳＣＡＴ株式会社',
        submitter_name_en='SCAT Inc.',
        submitter_name_yomi='スキャットカブシキカイシャ',
        address='小山市城東一丁目６番３３号',
        industry='情報・通信業',
        sec_code='39740',
        corporate_number='8060001014432',
    ),
    'E32815': EdinetCodeEntry(
        edinet_code='E32815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=318,
        fiscal_year_end='12月31日',
        submitter_name='セグエグループ株式会社',
        submitter_name_en='Segue Group Co,.Ltd.',
        submitter_name_yomi='セグエグループカブシキガイシャ',
        address='中央区新川１‐１６‐３',
        industry='情報・通信業',
        sec_code='39680',
        corporate_number='9010001164479',
    ),
    'E32819': EdinetCodeEntry(
        edinet_code='E32819',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='富田\u3000直人',
        submitter_name_en=None,
        submitter_name_yomi='トミダ\u3000ナオト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32821': EdinetCodeEntry(
        edinet_code='E32821',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌティーアイ',
        address='鎌倉市由比ガ浜四丁目６番８－３０５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001105043',
    ),
    'E32825': EdinetCodeEntry(
        edinet_code='E32825',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社エイトレッド',
        submitter_name_en='ATLED CORP.',
        submitter_name_yomi='カブシキガイシャエイトレッド',
        address='渋谷区渋谷二丁目１５番１号',
        industry='情報・通信業',
        sec_code='39690',
        corporate_number='9011001051741',
    ),
    'E32826': EdinetCodeEntry(
        edinet_code='E32826',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='児玉\u3000康孝',
        submitter_name_en=None,
        submitter_name_yomi='コダマ\u3000ヤスタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32828': EdinetCodeEntry(
        edinet_code='E32828',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＤＨ\u3000ＲＵＮＷＡＹ\u3000ＩＮＶＥＳＴＭＥＮＴ（ＨＫ）\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シーディーエイチ\u3000ランウェイ\u3000インベストメント\u3000ホンコン\u3000リミテッド',
        address='香港、コンノートロードセントラル１３３、アライアンスビルディング、６階、ユニット６０６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32830': EdinetCodeEntry(
        edinet_code='E32830',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000幹雄',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ミキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32846': EdinetCodeEntry(
        edinet_code='E32846',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000静枝',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000シズエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32848': EdinetCodeEntry(
        edinet_code='E32848',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=59,
        fiscal_year_end=None,
        submitter_name='大協リース株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイキョウリースカブシキガイシャ',
        address='新潟市中央区文京町１２番３１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4110001002971',
    ),
    'E32849': EdinetCodeEntry(
        edinet_code='E32849',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=573078,
        fiscal_year_end='6月末日',
        submitter_name='ラム・リサーチ・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ラムリサーチコーポレーション',
        address='アメリカ合衆国\u3000９４５３８\u3000カリフォルニア州、フレモント、クッシング・パークウェイ４６５０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32854': EdinetCodeEntry(
        edinet_code='E32854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月31日',
        submitter_name='窪田製薬ホールディングス株式会社',
        submitter_name_en='Kubota Pharmaceutical Holdings Co., Ltd.',
        submitter_name_yomi='クボタセイヤクホールディングスカブシキカイシャ',
        address='千代田区霞が関３丁目７番１号',
        industry='医薬品',
        sec_code='45960',
        corporate_number='3011001108646',
    ),
    'E32855': EdinetCodeEntry(
        edinet_code='E32855',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1084,
        fiscal_year_end='12月末日',
        submitter_name='株式会社シャノン',
        submitter_name_en='SHANON Inc.',
        submitter_name_yomi='カブシキガイシャシャノン',
        address='浜松町二丁目２番１２号',
        industry='情報・通信業',
        sec_code='39760',
        corporate_number='1010401052638',
    ),
    'E32858': EdinetCodeEntry(
        edinet_code='E32858',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000宏憲',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ヒロノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32859': EdinetCodeEntry(
        edinet_code='E32859',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000孝憲',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000タカノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32863': EdinetCodeEntry(
        edinet_code='E32863',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='有本\u3000隆浩',
        submitter_name_en=None,
        submitter_name_yomi='アリモト\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32866': EdinetCodeEntry(
        edinet_code='E32866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長嶋\u3000義和',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32867': EdinetCodeEntry(
        edinet_code='E32867',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11090,
        fiscal_year_end=None,
        submitter_name='日本再生可能エネルギーインフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ニホンサイセイカノウエネルギーインフラトウシホウジン',
        address='港区虎ノ門一丁目２番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010405015023',
    ),
    'E32868': EdinetCodeEntry(
        edinet_code='E32868',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=929194,
        fiscal_year_end='12月末日',
        submitter_name='ロイズ・バンキング・グループ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ロイズバンキンググループピーエルシー',
        address='連合王国ＥＨ１\u3000１ＹＺエディンバラ市ザ・マウンド',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E32873': EdinetCodeEntry(
        edinet_code='E32873',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='株式会社ビルダーズシステム研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビルダーズシステムケンキュウショ',
        address='渋谷区東３丁目６番１８－２０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401063731',
    ),
    'E32874': EdinetCodeEntry(
        edinet_code='E32874',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='サマーリバー合同会社',
        submitter_name_en=None,
        submitter_name_yomi='サマーリバーゴウドウカイシャ',
        address='横浜市中区竹之丸１２３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011103004227',
    ),
    'E32879': EdinetCodeEntry(
        edinet_code='E32879',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1007,
        fiscal_year_end=None,
        submitter_name='Ｙａｃｋｔｍａｎ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='ヤクトマンアセットマネージメントエルピー',
        address='アメリカ合衆国テキサス州オースティン、ブリッジポイント・パークウェイ６３００、ビルディング・ワン、スイート５００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32885': EdinetCodeEntry(
        edinet_code='E32885',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菅原\u3000貴弘',
        submitter_name_en=None,
        submitter_name_yomi='スガワラ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32888': EdinetCodeEntry(
        edinet_code='E32888',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ＫＭＳＴ\u3000ＨＯＬＤＩＮＧＳ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイエムエスティホールディングスカブシキカイシャ',
        address='横浜市港北区篠原西町３０番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001109679',
    ),
    'E32890': EdinetCodeEntry(
        edinet_code='E32890',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡邊\u3000大知',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ダイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32895': EdinetCodeEntry(
        edinet_code='E32895',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='マルコム・エフ・マクリーン４世',
        submitter_name_en=None,
        submitter_name_yomi='マルコム\u3000エフ\u3000マクリーン\u3000ヨンセイ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32898': EdinetCodeEntry(
        edinet_code='E32898',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000達夫',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32899': EdinetCodeEntry(
        edinet_code='E32899',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000浩之',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32901': EdinetCodeEntry(
        edinet_code='E32901',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='桑原\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='クワバラ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32906': EdinetCodeEntry(
        edinet_code='E32906',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=245,
        fiscal_year_end='12月31日',
        submitter_name='株式会社安江工務店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤスエコウムテン',
        address='名古屋市中区栄二丁目２番２３号',
        industry='建設業',
        sec_code=None,
        corporate_number='5180001024430',
    ),
    'E32908': EdinetCodeEntry(
        edinet_code='E32908',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安江\u3000久樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤスエ\u3000ヒサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32909': EdinetCodeEntry(
        edinet_code='E32909',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社お金のデザイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオカネノデザイン',
        address='中央区新川１－１７－２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001155055',
    ),
    'E32914': EdinetCodeEntry(
        edinet_code='E32914',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安江\u3000将寛',
        submitter_name_en=None,
        submitter_name_yomi='ヤスエ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32918': EdinetCodeEntry(
        edinet_code='E32918',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000武志',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32919': EdinetCodeEntry(
        edinet_code='E32919',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='インテグラル・オーエス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インテグラルオーエスカブシキガイシャ',
        address='千代田区丸の内１－９－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001177813',
    ),
    'E32921': EdinetCodeEntry(
        edinet_code='E32921',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=730,
        fiscal_year_end=None,
        submitter_name='ＰＲＥＳＴＩＧＥ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000（Ｓ）\u3000ＰＴＥ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='プレステージインターナショナルシンガポールプライベートリミテッド',
        address='５８３\u3000ＯＲＣＨＡＲＤ\u3000ＲＯＡＤ＃０９－０３\u3000ＦＯＲＵＭ\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32926': EdinetCodeEntry(
        edinet_code='E32926',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4750,
        fiscal_year_end=None,
        submitter_name='シンプレクス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンプレクスカブシキカイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401127151',
    ),
    'E32932': EdinetCodeEntry(
        edinet_code='E32932',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人ＴＡＫＥＵＣＨＩ育英奨学会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンタケウチイクエイショウガッカイ',
        address='埴科郡坂城町上平２０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5100005011705',
    ),
    'E32938': EdinetCodeEntry(
        edinet_code='E32938',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人津川モーター研究財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンツガワモーターケンキュウザイダン',
        address='足柄上郡松田町松田惣領１５７７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1021005010460',
    ),
    'E32940': EdinetCodeEntry(
        edinet_code='E32940',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='愛須\u3000康之',
        submitter_name_en=None,
        submitter_name_yomi='アイス\u3000ヤスユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32943': EdinetCodeEntry(
        edinet_code='E32943',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大塚\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32946': EdinetCodeEntry(
        edinet_code='E32946',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥本\u3000健二',
        submitter_name_en=None,
        submitter_name_yomi='オクモト\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32948': EdinetCodeEntry(
        edinet_code='E32948',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000健一郎',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ケンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32949': EdinetCodeEntry(
        edinet_code='E32949',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永島\u3000毅一郎',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000キイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32951': EdinetCodeEntry(
        edinet_code='E32951',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=145,
        fiscal_year_end='2月末日',
        submitter_name='株式会社日宣',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニッセン',
        address='千代田区神田司町２－６－５\u3000日宣神田第２ビル',
        industry='サービス業',
        sec_code='65430',
        corporate_number='8010001071429',
    ),
    'E32954': EdinetCodeEntry(
        edinet_code='E32954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西尾\u3000公志',
        submitter_name_en=None,
        submitter_name_yomi='ニシオ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32956': EdinetCodeEntry(
        edinet_code='E32956',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=212,
        fiscal_year_end='2月末日',
        submitter_name='フュージョン株式会社',
        submitter_name_en='Fusion Co.,Ltd.',
        submitter_name_yomi='フュージョンカブシキカイシャ',
        address='札幌市中央区北四条西四丁目１番地',
        industry='サービス業',
        sec_code='39770',
        corporate_number='7430001015237',
    ),
    'E32957': EdinetCodeEntry(
        edinet_code='E32957',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='スイス・リー・ライフ・キャピタル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='スイスリーライフキャピタルリミテッド',
        address='スイス国チューリッヒ市ミテンケ５０／６０、８００２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32959': EdinetCodeEntry(
        edinet_code='E32959',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＳＢＩ\u3000Ｖｅｎｔｕｒｅｓ\u3000Ｔｗｏ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイベンチャーズツーカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401120171',
    ),
    'E32961': EdinetCodeEntry(
        edinet_code='E32961',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松村\u3000信子',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000ノブコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32965': EdinetCodeEntry(
        edinet_code='E32965',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=515,
        fiscal_year_end='2月末日',
        submitter_name='ユナイテッド＆コレクティブ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユナイテッドアンドコレクティブカブシキガイシャ',
        address='千代田区麹町２－５－１ＷｅＷｏｒｋ半蔵門ＰＲＥＸＳｏｕｔｈ',
        industry='小売業',
        sec_code='35570',
        corporate_number='8010401089756',
    ),
    'E32966': EdinetCodeEntry(
        edinet_code='E32966',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='ジェイドグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイドグループカブシキイガイシャ',
        address='渋谷区元代々木町３０－１３ＯＮＥＳＴ元代々木スクエア',
        industry='小売業',
        sec_code='35580',
        corporate_number='5010401097274',
    ),
    'E32967': EdinetCodeEntry(
        edinet_code='E32967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2178,
        fiscal_year_end='3月末日',
        submitter_name='株式会社レノバ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャレノバ',
        address='中央区京橋二丁目２番１号',
        industry='電気・ガス業',
        sec_code='95190',
        corporate_number='7011001037180',
    ),
    'E32969': EdinetCodeEntry(
        edinet_code='E32969',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1000,
        fiscal_year_end='3月末日',
        submitter_name='日本住宅ローン株式会社',
        submitter_name_en='The Mortgage Corporation of JAPAN,Limited',
        submitter_name_yomi='ニホンジュウタクローンカブシキガイシャ',
        address='渋谷区代々木二丁目１番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='6010001082997',
    ),
    'E32970': EdinetCodeEntry(
        edinet_code='E32970',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='ＷＭパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダブリュエムパートナーズカブシキガイシャ',
        address='千代田区麹町三丁目２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401106610',
    ),
    'E32973': EdinetCodeEntry(
        edinet_code='E32973',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木南\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='キミナミ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32975': EdinetCodeEntry(
        edinet_code='E32975',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本田\u3000大作',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000ダイサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32976': EdinetCodeEntry(
        edinet_code='E32976',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤井\u3000光郎',
        submitter_name_en=None,
        submitter_name_yomi='サワイ\u3000ミツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32977': EdinetCodeEntry(
        edinet_code='E32977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤井\u3000弘行',
        submitter_name_en=None,
        submitter_name_yomi='サワイ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32988': EdinetCodeEntry(
        edinet_code='E32988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社グリーンズ',
        submitter_name_en='GREENS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャグリーンズ',
        address='四日市市浜田町５番３号',
        industry='サービス業',
        sec_code='65470',
        corporate_number='5190001014736',
    ),
    'E32989': EdinetCodeEntry(
        edinet_code='E32989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2334,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ファンペップ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャファンペップ',
        address='茨木市彩都あさぎ七丁目７－１５',
        industry='医薬品',
        sec_code='48810',
        corporate_number='1011001097115',
    ),
    'E32990': EdinetCodeEntry(
        edinet_code='E32990',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=326,
        fiscal_year_end='3月31日',
        submitter_name='ファイズホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ファイズホールディングスカブシキガイシャ',
        address='大阪市北区梅田三丁目４番５号毎日インテシオ１３階',
        industry='サービス業',
        sec_code='93250',
        corporate_number='3120001179942',
    ),
    'E32991': EdinetCodeEntry(
        edinet_code='E32991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=282,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ほぼ日',
        submitter_name_en='Hobonichi Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャホボニチ',
        address='千代田区神田錦町三丁目１８番地',
        industry='小売業',
        sec_code='35600',
        corporate_number='1010401048826',
    ),
    'E32992': EdinetCodeEntry(
        edinet_code='E32992',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1893,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ビーグリー',
        submitter_name_en='Beaglee Inc.',
        submitter_name_yomi='カブシキカイシャビーグリー',
        address='港区北青山２－１３－５',
        industry='情報・通信業',
        sec_code='39810',
        corporate_number='3010401109114',
    ),
    'E32994': EdinetCodeEntry(
        edinet_code='E32994',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='クレー\u3000アンドリュー\u3000ローゼンバーグ',
        submitter_name_en=None,
        submitter_name_yomi='クレー\u3000アンドリュー\u3000ローゼンバーグ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32995': EdinetCodeEntry(
        edinet_code='E32995',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='バーバラ\u3000ダニエル\u3000ボエカー\u3000プリマック',
        submitter_name_en=None,
        submitter_name_yomi='バーバラ\u3000ダニエル\u3000ボエカー\u3000プリマック',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E32996': EdinetCodeEntry(
        edinet_code='E32996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有吉\u3000和枝',
        submitter_name_en=None,
        submitter_name_yomi='アリヨシ\u3000カズエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33000': EdinetCodeEntry(
        edinet_code='E33000',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＦＯＯＤ\u3000＆\u3000ＬＩＦＥ\u3000ＣＯＭＰＡＮＩＥＳ',
        submitter_name_en='FOOD & LIFE COMPANIES LTD.',
        submitter_name_yomi='カブシキガイシャフードアンドライフカンパニーズ',
        address='吹田市江坂町一丁目２２番２号',
        industry='小売業',
        sec_code='35630',
        corporate_number='8120901035199',
    ),
    'E33005': EdinetCodeEntry(
        edinet_code='E33005',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=252,
        fiscal_year_end='3月末日',
        submitter_name='株式会社インターネットインフィニティー',
        submitter_name_en='internet infinity INC.',
        submitter_name_yomi='カブシキガイシャインターネットインフィニティー',
        address='千代田区二番町１１番地１９',
        industry='サービス業',
        sec_code='65450',
        corporate_number='2010001088949',
    ),
    'E33009': EdinetCodeEntry(
        edinet_code='E33009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=329,
        fiscal_year_end='12月31日',
        submitter_name='フルテック株式会社',
        submitter_name_en='Fulltech Co.Ltd.',
        submitter_name_yomi='フルテックカブシキガイシャ',
        address='札幌市中央区北１３条西１７丁目１番３１号',
        industry='サービス業',
        sec_code='65460',
        corporate_number='3430001013822',
    ),
    'E33011': EdinetCodeEntry(
        edinet_code='E33011',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2139,
        fiscal_year_end='3月31日',
        submitter_name='株式会社力の源ホールディングス',
        submitter_name_en='CHIKARANOMOTO HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャチカラノモトホールディングス',
        address='福岡市中央区大名一丁目１３番１４号',
        industry='小売業',
        sec_code='35610',
        corporate_number='7290001001697',
    ),
    'E33015': EdinetCodeEntry(
        edinet_code='E33015',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='能美\u3000裕一',
        submitter_name_en=None,
        submitter_name_yomi='ノミ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33016': EdinetCodeEntry(
        edinet_code='E33016',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=181,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ピーバンドットコム',
        submitter_name_en='p-ban.com Corp.',
        submitter_name_yomi='カブシキガイシャピーバンドットコム',
        address='千代田区五番町１４番地五番町光ビル４Ｆ',
        industry='卸売業',
        sec_code='35590',
        corporate_number='9010001131479',
    ),
    'E33024': EdinetCodeEntry(
        edinet_code='E33024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社インフロー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャインフロー',
        address='世田谷区松原１－３８－５田坂ビル４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001148841',
    ),
    'E33025': EdinetCodeEntry(
        edinet_code='E33025',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=42,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ズーム',
        submitter_name_en='ZOOM CORPORATION',
        submitter_name_yomi='カブシキカイシャズーム',
        address='千代田区神田駿河台４丁目４番地３',
        industry='電気機器',
        sec_code='66940',
        corporate_number='9010001089577',
    ),
    'E33026': EdinetCodeEntry(
        edinet_code='E33026',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=252,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ユーザーローカル',
        submitter_name_en='User Local, Inc.',
        submitter_name_yomi='カブシキガイシャユーザーローカル',
        address='港区芝浦三丁目１番２１号',
        industry='情報・通信業',
        sec_code='39840',
        corporate_number='9011001069346',
    ),
    'E33027': EdinetCodeEntry(
        edinet_code='E33027',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三好\u3000稔美',
        submitter_name_en=None,
        submitter_name_yomi='ミヨシ\u3000トシミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33028': EdinetCodeEntry(
        edinet_code='E33028',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平井\u3000昭光',
        submitter_name_en=None,
        submitter_name_yomi='ヒライ\u3000アキミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33029': EdinetCodeEntry(
        edinet_code='E33029',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='グランディ・ストックメイト\u3000理事長\u3000落合\u3000幸男',
        submitter_name_en=None,
        submitter_name_yomi='グランディ\u3000ストックメイト\u3000リジチョウ\u3000オチアイ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33034': EdinetCodeEntry(
        edinet_code='E33034',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=608,
        fiscal_year_end='3月31日',
        submitter_name='ジャパンエレベーターサービスホールディングス株式会社',
        submitter_name_en='JAPAN ELEVATOR SERVICE HOLDINGS CO.,LTD.',
        submitter_name_yomi='ジャパンエレベーターサービスホールディングスカブシキカイシャ',
        address='中央区日本橋一丁目３番１３号',
        industry='サービス業',
        sec_code='65440',
        corporate_number='5010001019182',
    ),
    'E33035': EdinetCodeEntry(
        edinet_code='E33035',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=417014,
        fiscal_year_end=None,
        submitter_name='ソシエテ\u3000ドゥ\u3000パーティシパシオン\u3000ヴァレオ',
        submitter_name_en=None,
        submitter_name_yomi='ソシエテ\u3000ドゥ\u3000パーティシパシオン\u3000ヴァレオ',
        address='フランス、パリ、７５０１７、ル・ドゥ・クールセル１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33036': EdinetCodeEntry(
        edinet_code='E33036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石田\u3000甲',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000コウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33037': EdinetCodeEntry(
        edinet_code='E33037',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=521,
        fiscal_year_end='2月末日',
        submitter_name='株式会社Ｎｏ．１',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナンバーワン',
        address='千代田区内幸町一丁目５番２号',
        industry='卸売業',
        sec_code='35620',
        corporate_number='8010001136248',
    ),
    'E33039': EdinetCodeEntry(
        edinet_code='E33039',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1193,
        fiscal_year_end='12月31日',
        submitter_name='株式会社オロ',
        submitter_name_en='ORO Co., Ltd.',
        submitter_name_yomi='カブシキガイシャオロ',
        address='目黒区目黒三丁目９番１号',
        industry='情報・通信業',
        sec_code='39830',
        corporate_number='7013201012673',
    ),
    'E33040': EdinetCodeEntry(
        edinet_code='E33040',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=379,
        fiscal_year_end='9月末日',
        submitter_name='テモナ株式会社',
        submitter_name_en='TEMONA.inc.',
        submitter_name_yomi='テモナカブシキガイシャ',
        address='渋谷区渋谷２－１２－１９',
        industry='情報・通信業',
        sec_code='39850',
        corporate_number='4010601036512',
    ),
    'E33044': EdinetCodeEntry(
        edinet_code='E33044',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=836,
        fiscal_year_end='12月31日',
        submitter_name='ソレイジア・ファーマ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソレイジア\u3000ファーマカブシキカイシャ',
        address='港区芝公園二丁目１１番１号',
        industry='医薬品',
        sec_code='45970',
        corporate_number='9010401075961',
    ),
    'E33050': EdinetCodeEntry(
        edinet_code='E33050',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2185,
        fiscal_year_end='3月末日',
        submitter_name='ウェーブロックホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウェーブロックホールディングスカブシキカイシャ',
        address='中央区明石町８番１号',
        industry='その他製品',
        sec_code='79400',
        corporate_number='5010001061812',
    ),
    'E33051': EdinetCodeEntry(
        edinet_code='E33051',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000将雄',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33052': EdinetCodeEntry(
        edinet_code='E33052',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='桃太郎源株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モモタロウゲンカブシキガイシャ',
        address='岡山市北区柳町一丁目１２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9260001010245',
    ),
    'E33056': EdinetCodeEntry(
        edinet_code='E33056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='星\u3000知也',
        submitter_name_en=None,
        submitter_name_yomi='ホシ\u3000トモヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33058': EdinetCodeEntry(
        edinet_code='E33058',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='桶山\u3000雄平',
        submitter_name_en=None,
        submitter_name_yomi='オケヤマ\u3000ユウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33060': EdinetCodeEntry(
        edinet_code='E33060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大津\u3000穰',
        submitter_name_en=None,
        submitter_name_yomi='オオツ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33061': EdinetCodeEntry(
        edinet_code='E33061',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大津\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='オオツ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33063': EdinetCodeEntry(
        edinet_code='E33063',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18808,
        fiscal_year_end=None,
        submitter_name='レッドプラネットホテルズリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='レッドプラネットホテルズリミテッド',
        address='ケイマン諸島、ＫＹ１－９００７、グランドケイマン、カマナベイ、８９ネクサスウェイ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33064': EdinetCodeEntry(
        edinet_code='E33064',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='花井\u3000秀勝',
        submitter_name_en=None,
        submitter_name_yomi='ハナイ\u3000ヒデカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33066': EdinetCodeEntry(
        edinet_code='E33066',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金森\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='カナモリ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33070': EdinetCodeEntry(
        edinet_code='E33070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='坂井\u3000英也',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000ヒデヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33073': EdinetCodeEntry(
        edinet_code='E33073',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=24596,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＬＩＸＩＬビバ',
        submitter_name_en='LIXIL VIVA CORPORATION',
        submitter_name_yomi='カブシキカイシャリクシルビバ',
        address='さいたま市浦和区上木崎一丁目１３番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='2030001041872',
    ),
    'E33074': EdinetCodeEntry(
        edinet_code='E33074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='糸井\u3000重里',
        submitter_name_en=None,
        submitter_name_yomi='イトイ\u3000シゲサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33075': EdinetCodeEntry(
        edinet_code='E33075',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000あんだ',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000アンダ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33077': EdinetCodeEntry(
        edinet_code='E33077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田邊\u3000勝己',
        submitter_name_en=None,
        submitter_name_yomi='タナベ\u3000カツキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33081': EdinetCodeEntry(
        edinet_code='E33081',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000裕輔',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33082': EdinetCodeEntry(
        edinet_code='E33082',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1300,
        fiscal_year_end=None,
        submitter_name='ＮＳ建材薄板株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエスケンザイウスイタカブシキカイシャ',
        address='中央区日本橋２－７－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001062323',
    ),
    'E33087': EdinetCodeEntry(
        edinet_code='E33087',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=188797,
        fiscal_year_end=None,
        submitter_name='ソフトバンクグループジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソフトバンクグループジャパンカブシキカイシャ',
        address='港区海岸一丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401054854',
    ),
    'E33090': EdinetCodeEntry(
        edinet_code='E33090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河野\u3000貴輝',
        submitter_name_en=None,
        submitter_name_yomi='カワノ\u3000タカテル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33097': EdinetCodeEntry(
        edinet_code='E33097',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江口\u3000新',
        submitter_name_en=None,
        submitter_name_yomi='エグチ\u3000シン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33098': EdinetCodeEntry(
        edinet_code='E33098',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社リバーフィールド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリバーフィールド',
        address='東京都中央区京橋１丁目１－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001125124',
    ),
    'E33101': EdinetCodeEntry(
        edinet_code='E33101',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高山\u3000泰仁',
        submitter_name_en=None,
        submitter_name_yomi='タカヤマ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33105': EdinetCodeEntry(
        edinet_code='E33105',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人トランスコスモス財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジントランスコスモスザイダン',
        address='港区南青山１－１－１新青山ビル西館１６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7170005005839',
    ),
    'E33106': EdinetCodeEntry(
        edinet_code='E33106',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='清水地所株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シミズジショカブシキガイシャ',
        address='中央区京橋二丁目１８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001046156',
    ),
    'E33109': EdinetCodeEntry(
        edinet_code='E33109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=226,
        fiscal_year_end='1月31日',
        submitter_name='アセンテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アセンテックカブシキカイシャ',
        address='千代田区神田練塀町３番地',
        industry='卸売業',
        sec_code='35650',
        corporate_number='2011101051771',
    ),
    'E33110': EdinetCodeEntry(
        edinet_code='E33110',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月末日',
        submitter_name='株式会社旅工房',
        submitter_name_en='TABIKOBO Co. Ltd.',
        submitter_name_yomi='カブシキガイシャタビコウボウ',
        address='豊島区東池袋三丁目１番１号サンシャイン６０・４６階',
        industry='サービス業',
        sec_code='65480',
        corporate_number='4013301007221',
    ),
    'E33116': EdinetCodeEntry(
        edinet_code='E33116',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＩＮＧＤＯＭ\u3000ＣＡＰＩＴＡＬ\u3000ＲＥＳＯＵＲＣＥＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='キングダム\u3000キャピタル\u3000リソーシス\u3000リミテッド',
        address='２６３\u3000Ｍａｉｎ\u3000Ｓｔｒｅｅｔ\u3000Ｐ．Ｏ．Ｂｏｘ\u3000２１９６\u3000Ｒｏａｄ\u3000Ｔｏｗｎ\u3000Ｔｏｒｔｏｌａ\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33119': EdinetCodeEntry(
        edinet_code='E33119',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35765,
        fiscal_year_end=None,
        submitter_name='ソシエテ・ジェネラル証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソシエテジェネラルショウケンカブシキカイシャ',
        address='千代田区丸の内一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401068862',
    ),
    'E33122': EdinetCodeEntry(
        edinet_code='E33122',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河原\u3000成美',
        submitter_name_en=None,
        submitter_name_yomi='カワハラ\u3000シゲミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33123': EdinetCodeEntry(
        edinet_code='E33123',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26150,
        fiscal_year_end=None,
        submitter_name='株式会社海外需要開拓支援機構',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカイガイジュヨウカイタクシエンキコウ',
        address='港区六本木六丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401108794',
    ),
    'E33124': EdinetCodeEntry(
        edinet_code='E33124',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石田\u3000克史',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000カツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33126': EdinetCodeEntry(
        edinet_code='E33126',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社光優ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャコウユウホールディングス',
        address='横浜市港北区日吉二丁目１１番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001113691',
    ),
    'E33130': EdinetCodeEntry(
        edinet_code='E33130',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古野\u3000重幸',
        submitter_name_en=None,
        submitter_name_yomi='フルノ\u3000シゲユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33131': EdinetCodeEntry(
        edinet_code='E33131',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57,
        fiscal_year_end=None,
        submitter_name='丸井織物株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルイオリモノカブシキガイシャ',
        address='鹿島郡中能登町久乃木井部１５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4220001015673',
    ),
    'E33139': EdinetCodeEntry(
        edinet_code='E33139',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='辰已\u3000崇之',
        submitter_name_en=None,
        submitter_name_yomi='タツミ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33140': EdinetCodeEntry(
        edinet_code='E33140',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社ＥＰＡＲＫ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーパーク',
        address='港区芝浦四丁目１６番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7013301024040',
    ),
    'E33141': EdinetCodeEntry(
        edinet_code='E33141',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケーアイ',
        address='港区虎ノ門一丁目２３番２号虎ノ門ヒルズレジデンス４００１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401115649',
    ),
    'E33142': EdinetCodeEntry(
        edinet_code='E33142',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='別宮\u3000圭一',
        submitter_name_en=None,
        submitter_name_yomi='ベック\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33147': EdinetCodeEntry(
        edinet_code='E33147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川田\u3000篤',
        submitter_name_en=None,
        submitter_name_yomi='カワタ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33148': EdinetCodeEntry(
        edinet_code='E33148',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日野\u3000靖久',
        submitter_name_en=None,
        submitter_name_yomi='ヒノ\u3000ヤスヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33175': EdinetCodeEntry(
        edinet_code='E33175',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='インドネシア共和国',
        submitter_name_en=None,
        submitter_name_yomi='インドネシアキョウワコク',
        address='Ｆｒａｎｓ\u3000Ｓｅｄａ\u3000Ｂｕｉｌｄｉｎｇ\u3000２ｎｄ\u3000Ｆｌｏｏｒ，Ｊａｌａｎ\u3000Ｄｒ\u3000Ｗａｈｉｄｉｎ\u3000Ｒａｙａ\u3000Ｎｏ．\u3000１\u3000Ｊａｋａｒｔａ\u3000１０７１０，\u3000Ｉｎｄｏｎｅｓｉａ',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E33179': EdinetCodeEntry(
        edinet_code='E33179',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='伊藤忠フードインベストメント合同会社',
        submitter_name_en=None,
        submitter_name_yomi='イトウチュウフードインベストメント',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403016299',
    ),
    'E33189': EdinetCodeEntry(
        edinet_code='E33189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯島\u3000雅宏',
        submitter_name_en=None,
        submitter_name_yomi='イイジマ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33191': EdinetCodeEntry(
        edinet_code='E33191',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村木雄哉',
        submitter_name_en=None,
        submitter_name_yomi='ムラキタケヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33195': EdinetCodeEntry(
        edinet_code='E33195',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='莅戸\u3000道人',
        submitter_name_en=None,
        submitter_name_yomi='ノゾキド\u3000ミチヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33197': EdinetCodeEntry(
        edinet_code='E33197',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｓｏｕｎｄ‐Ｓｅｒｖｉｃｅ\u3000Ｍｕｓｉｋａｎｌａｇｅｎ‐Ｖｅｒｔｒｉｅｂｓｇｅｓｅｌｌｓｃｈａｆｔ\u3000ｍｂＨ',
        submitter_name_en=None,
        submitter_name_yomi='サウンドサービス\u3000ミュージックシステム\u3000ディストリビュータ\u3000ユウゲンカイシャ',
        address='Ｂｅｒｌｉｎ\u3000Ｐａｒｉｓｅｒ\u3000Ｓｔｒ．９，１０７１９\u3000Ｂｅｒｌｉｎ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33201': EdinetCodeEntry(
        edinet_code='E33201',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山野\u3000義友',
        submitter_name_en=None,
        submitter_name_yomi='ヤマノ\u3000ヨシトモ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33209': EdinetCodeEntry(
        edinet_code='E33209',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＵＮＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャオーユーエヌエイチ',
        address='新宿区新宿２－１６－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001151296',
    ),
    'E33214': EdinetCodeEntry(
        edinet_code='E33214',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ｇａｔｚ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャガッツ',
        address='渋谷区神宮前六丁目２８番９号東武ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010801026544',
    ),
    'E33215': EdinetCodeEntry(
        edinet_code='E33215',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江藤\u3000公則',
        submitter_name_en=None,
        submitter_name_yomi='エトウ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33222': EdinetCodeEntry(
        edinet_code='E33222',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000直浩',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ナオヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33225': EdinetCodeEntry(
        edinet_code='E33225',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡\u3000靖子',
        submitter_name_en=None,
        submitter_name_yomi='オカ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33226': EdinetCodeEntry(
        edinet_code='E33226',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永森\u3000信一',
        submitter_name_en=None,
        submitter_name_yomi='ナガモリ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33228': EdinetCodeEntry(
        edinet_code='E33228',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000山﨑砂利商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ヤマザキジャリショウテン',
        address='大津市浜大津四丁目７番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3160001001994',
    ),
    'E33229': EdinetCodeEntry(
        edinet_code='E33229',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33231': EdinetCodeEntry(
        edinet_code='E33231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小栗\u3000洋行',
        submitter_name_en=None,
        submitter_name_yomi='オグリ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33232': EdinetCodeEntry(
        edinet_code='E33232',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=60,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ビーブレイクシステムズ',
        submitter_name_en='bBreak Systems Company, Limited',
        submitter_name_yomi='ビーブレイクシステムズ',
        address='品川区東五反田２－１０－２',
        industry='情報・通信業',
        sec_code='39860',
        corporate_number='7010701013986',
    ),
    'E33233': EdinetCodeEntry(
        edinet_code='E33233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000敬一郎',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000ケイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33235': EdinetCodeEntry(
        edinet_code='E33235',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=376,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ＳＹＳホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスワイエスホールディングス',
        address='名古屋市東区代官町３５番１６号',
        industry='情報・通信業',
        sec_code='39880',
        corporate_number='5180001110767',
    ),
    'E33236': EdinetCodeEntry(
        edinet_code='E33236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000裕紀',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ヒロノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33237': EdinetCodeEntry(
        edinet_code='E33237',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=615,
        fiscal_year_end='8月31日',
        submitter_name='エコモット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エコモットカブシキガイシャ',
        address='札幌市中央区北一条東一丁目２番５号',
        industry='サービス業',
        sec_code='39870',
        corporate_number='6430001034659',
    ),
    'E33238': EdinetCodeEntry(
        edinet_code='E33238',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2871,
        fiscal_year_end='12月31日',
        submitter_name='Ｕｎｉｐｏｓ株式会社',
        submitter_name_en='Unipos Inc.',
        submitter_name_yomi='ユニポスカブシキガイシャ',
        address='渋谷区神宮前５ー５２ー２青山オーバルビル７Ｆ',
        industry='サービス業',
        sec_code=None,
        corporate_number='4011001092468',
    ),
    'E33242': EdinetCodeEntry(
        edinet_code='E33242',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=716,
        fiscal_year_end='9月末日',
        submitter_name='シェアリングテクノロジー株式会社',
        submitter_name_en='SHARINGTECHNOLOGY INC.',
        submitter_name_yomi='シェアリングテクノロジーカブシキガイシャ',
        address='名古屋市中村区名駅一丁目１番１号\u3000ＪＰタワー名古屋１９Ｆ',
        industry='情報・通信業',
        sec_code='39890',
        corporate_number='2180001061708',
    ),
    'E33244': EdinetCodeEntry(
        edinet_code='E33244',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福村\u3000寛敏',
        submitter_name_en=None,
        submitter_name_yomi='フクムラ\u3000ヒロトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33245': EdinetCodeEntry(
        edinet_code='E33245',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='花矢\u3000卓司',
        submitter_name_en=None,
        submitter_name_yomi='ハナヤ\u3000タクジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33247': EdinetCodeEntry(
        edinet_code='E33247',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=342,
        fiscal_year_end='3月末日',
        submitter_name='ディーエムソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディーエムソリューションズカブシキガイシャ',
        address='武蔵野市御殿山一丁目１番３号',
        industry='サービス業',
        sec_code='65490',
        corporate_number='9012401014057',
    ),
    'E33254': EdinetCodeEntry(
        edinet_code='E33254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=551,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ＧａｍｅＷｉｔｈ',
        submitter_name_en='GameWith,Inc.',
        submitter_name_yomi='カブシキガイシャゲームウィズ',
        address='港区三田一丁目４番１号',
        industry='情報・通信業',
        sec_code='65520',
        corporate_number='2010401106079',
    ),
    'E33256': EdinetCodeEntry(
        edinet_code='E33256',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白岩\u3000次郎',
        submitter_name_en=None,
        submitter_name_yomi='シライワ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33257': EdinetCodeEntry(
        edinet_code='E33257',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上川\u3000伸彦',
        submitter_name_en=None,
        submitter_name_yomi='カミカワ\u3000ノブヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33258': EdinetCodeEntry(
        edinet_code='E33258',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000明',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33261': EdinetCodeEntry(
        edinet_code='E33261',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='有限会社宮脇商事',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャミヤワキショウジ',
        address='高松市三名町７９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6470002006835',
    ),
    'E33263': EdinetCodeEntry(
        edinet_code='E33263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社光和',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコウワ',
        address='春日井市中央台七丁目１番地の２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180002065899',
    ),
    'E33270': EdinetCodeEntry(
        edinet_code='E33270',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='ＮＣＢキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌシービーキャピタルカブシキカイシャ',
        address='福岡市博多区下川端町２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290001068733',
    ),
    'E33272': EdinetCodeEntry(
        edinet_code='E33272',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=696,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ツナググループ・ホールディングス',
        submitter_name_en='TSUNAGU GROUP HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャツナググループホールディングス',
        address='千代田区神田三崎町三丁目１－１６',
        industry='サービス業',
        sec_code='65510',
        corporate_number='8010001107240',
    ),
    'E33282': EdinetCodeEntry(
        edinet_code='E33282',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=710,
        fiscal_year_end='7月末日',
        submitter_name='株式会社シルバーライフ',
        submitter_name_en='SILVER LIFE CO., LTD.',
        submitter_name_yomi='カブシキカイシャシルバーライフ',
        address='新宿区西新宿４－３２－４\u3000ハイネスロフティ２階',
        industry='卸売業',
        sec_code='92620',
        corporate_number='7010901028669',
    ),
    'E33283': EdinetCodeEntry(
        edinet_code='E33283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='株式会社デジタルフォルン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャデジタルフォルン',
        address='横浜市西区みなとみらい２－３－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001117832',
    ),
    'E33284': EdinetCodeEntry(
        edinet_code='E33284',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='正垣\u3000泰彦',
        submitter_name_en=None,
        submitter_name_yomi='ショウガキ\u3000ヤスヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33288': EdinetCodeEntry(
        edinet_code='E33288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福嶋\u3000康博',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33293': EdinetCodeEntry(
        edinet_code='E33293',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='アドミラルキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アドミラルキャピタルカブシキガイシャ',
        address='千代田区内幸町一丁目３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401062170',
    ),
    'E33294': EdinetCodeEntry(
        edinet_code='E33294',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=31,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＳＫＩＹＡＫＩ',
        submitter_name_en='SKIYAKI Inc.',
        submitter_name_yomi='カブシキガイシャスキヤキ',
        address='渋谷区道玄坂１丁目１４番６号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1011001059701',
    ),
    'E33295': EdinetCodeEntry(
        edinet_code='E33295',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='ソウルドアウト株式会社',
        submitter_name_en='SoldOut, Inc.',
        submitter_name_yomi='ソウルドアウトカブシキガイシャ',
        address='文京区後楽一丁目４番１４号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001129394',
    ),
    'E33296': EdinetCodeEntry(
        edinet_code='E33296',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人Ｉ－Ｏ\u3000ＤＡＴＡ財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンアイオーデータザイダン',
        address='金沢市桜田町三丁目１０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6220005008143',
    ),
    'E33301': EdinetCodeEntry(
        edinet_code='E33301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='坂田\u3000潤一',
        submitter_name_en=None,
        submitter_name_yomi='サカタ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33305': EdinetCodeEntry(
        edinet_code='E33305',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=371,
        fiscal_year_end='12月31日',
        submitter_name='ユニフォームネクスト株式会社',
        submitter_name_en='UNIFORM NEXT CO., LTD.',
        submitter_name_yomi='ユニフォームネクストカブシキガイシャ',
        address='福井市八重巻町２５号８１番地',
        industry='小売業',
        sec_code='35660',
        corporate_number='2210001004332',
    ),
    'E33309': EdinetCodeEntry(
        edinet_code='E33309',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27,
        fiscal_year_end=None,
        submitter_name='３Ｄ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='スリーディーインベストメントパートナーズピーティーイーエルティーディー',
        address='シンガポール共和国０３９１９２、テマセクアベニュー１、ミレニアタワー＃２０－０２Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33312': EdinetCodeEntry(
        edinet_code='E33312',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='芙蓉土地建物株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フヨウトチタテモノカブシキガイシャ',
        address='大阪市北区茶屋町８番２１－３００４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001088737',
    ),
    'E33313': EdinetCodeEntry(
        edinet_code='E33313',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=84,
        fiscal_year_end='7月末日',
        submitter_name='株式会社クロスフォー',
        submitter_name_en='Crossfor Co.,Ltd',
        submitter_name_yomi='カブシキカイシャクロスフォー',
        address='甲府市国母７－１１－４',
        industry='その他製品',
        sec_code='78100',
        corporate_number='1090001001062',
    ),
    'E33317': EdinetCodeEntry(
        edinet_code='E33317',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000則明',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ノリアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33318': EdinetCodeEntry(
        edinet_code='E33318',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000弦',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ユヅル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33323': EdinetCodeEntry(
        edinet_code='E33323',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=593,
        fiscal_year_end='1月31日',
        submitter_name='株式会社トラース・オン・プロダクト',
        submitter_name_en='TRaaS On Product Inc.',
        submitter_name_yomi='カブシキガイシャトラースオンプロダクト',
        address='横浜市西区北幸２－９－３０横浜西口加藤ビル',
        industry='電気機器',
        sec_code='66960',
        corporate_number='7020001042025',
    ),
    'E33325': EdinetCodeEntry(
        edinet_code='E33325',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人日本文化伝承会館',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンニホンブンカデンショウカイカン',
        address='あきる野市草花２５１０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5013105001675',
    ),
    'E33326': EdinetCodeEntry(
        edinet_code='E33326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米田\u3000光宏',
        submitter_name_en=None,
        submitter_name_yomi='ヨネダ\u3000ミツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33327': EdinetCodeEntry(
        edinet_code='E33327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000英助',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000エイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33328': EdinetCodeEntry(
        edinet_code='E33328',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='今泉\u3000卓也',
        submitter_name_en=None,
        submitter_name_yomi='イマイズミ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33329': EdinetCodeEntry(
        edinet_code='E33329',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='入澤\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='イリサワ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33332': EdinetCodeEntry(
        edinet_code='E33332',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=750,
        fiscal_year_end=None,
        submitter_name='明治安田生命２０１７基金特定目的会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイニセンジュウシチキキントクテイモクテキカイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005026998',
    ),
    'E33344': EdinetCodeEntry(
        edinet_code='E33344',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='合同会社塩井興産',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシオイコウサン',
        address='佐世保市木風町１４７３－１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9310002010230',
    ),
    'E33345': EdinetCodeEntry(
        edinet_code='E33345',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=282,
        fiscal_year_end='10月31日',
        submitter_name='株式会社キャストリコ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャキャストリコ',
        address='中央区晴海一丁目８番１２号\u3000晴海アイランドトリトンスクエアオフィスタワーＺ２９階',
        industry='電気機器',
        sec_code='66950',
        corporate_number='4010001096017',
    ),
    'E33346': EdinetCodeEntry(
        edinet_code='E33346',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='4月末日',
        submitter_name='株式会社ビジョナリーホールディングス',
        submitter_name_en='VISIONARYHOLDINGS CO. , LTD.',
        submitter_name_yomi='カブシキカイシャビジョナリーホールディングス',
        address='中央区日本橋堀留町１丁目９番１１号ＮＥＷＳ日本橋堀留町６階',
        industry='小売業',
        sec_code=None,
        corporate_number='8010401134850',
    ),
    'E33350': EdinetCodeEntry(
        edinet_code='E33350',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2000,
        fiscal_year_end=None,
        submitter_name='三菱地所物流リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシジショブツリュウリートトウシホウジン',
        address='千代田区丸の内一丁目６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005025573',
    ),
    'E33357': EdinetCodeEntry(
        edinet_code='E33357',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=436,
        fiscal_year_end='9月30日',
        submitter_name='株式会社エスユーエス',
        submitter_name_en='SUS Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャ\u3000エスユーエス',
        address='京都市下京区四条通烏丸東入ル長刀鉾町８\u3000京都三井ビルディング５階',
        industry='サービス業',
        sec_code='65540',
        corporate_number='6130001017685',
    ),
    'E33358': EdinetCodeEntry(
        edinet_code='E33358',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='引字\u3000圭祐',
        submitter_name_en=None,
        submitter_name_yomi='ヒキジ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33359': EdinetCodeEntry(
        edinet_code='E33359',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=834,
        fiscal_year_end='9月30日',
        submitter_name='ＵＵＵＭ株式会社',
        submitter_name_en='UUUM co.,ltd',
        submitter_name_yomi='ウームガブシキガイシャ',
        address='港区赤坂９丁目７番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9011001095607',
    ),
    'E33363': EdinetCodeEntry(
        edinet_code='E33363',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｎｉｐｐｏｎ\u3000Ｏｐｐｏｒｔｕｎｉｔｙ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンオポチュニティーマネジメントエルエルシー',
        address='アメリカ合衆国デラウェア州ウィルミントン、リトル・フォールズ・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33364': EdinetCodeEntry(
        edinet_code='E33364',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=304,
        fiscal_year_end='8月末日',
        submitter_name='ウォンテッドリー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウォンテッドリーカブシキカイシャ',
        address='港区白金台５－１２－７\u3000ＭＧ白金台ビル４階',
        industry='情報・通信業',
        sec_code='39910',
        corporate_number='9011001066673',
    ),
    'E33365': EdinetCodeEntry(
        edinet_code='E33365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小黒正義',
        submitter_name_en=None,
        submitter_name_yomi='オグロマサヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33367': EdinetCodeEntry(
        edinet_code='E33367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=908,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ニーズウェル',
        submitter_name_en='Needs Well Inc.',
        submitter_name_yomi='カブシキガイシャニーズウェル',
        address='千代田区紀尾井町４－１\u3000ニューオータニ\u3000ガーデンコート１３階',
        industry='情報・通信業',
        sec_code='39920',
        corporate_number='3011101025642',
    ),
    'E33370': EdinetCodeEntry(
        edinet_code='E33370',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土橋\u3000秀位',
        submitter_name_en=None,
        submitter_name_yomi='ドバシ\u3000ヒデタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33371': EdinetCodeEntry(
        edinet_code='E33371',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000勇人',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33372': EdinetCodeEntry(
        edinet_code='E33372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='近藤\u3000シゲ',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000シゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33374': EdinetCodeEntry(
        edinet_code='E33374',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='有限会社エステート興業',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエステートコウギョウ',
        address='練馬区東大泉３－２７－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011602001582',
    ),
    'E33375': EdinetCodeEntry(
        edinet_code='E33375',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='有限会社マトバリース',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャマトバリース',
        address='練馬区東大泉３－２７－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011602009289',
    ),
    'E33376': EdinetCodeEntry(
        edinet_code='E33376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ビーエムエル企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーエムエルキカク',
        address='練馬区東大泉３－２７－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011601005714',
    ),
    'E33378': EdinetCodeEntry(
        edinet_code='E33378',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=250,
        fiscal_year_end=None,
        submitter_name='みなとキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミナトキャピタルカブシキガイシャ',
        address='神戸市中央区多聞通２丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5140001020879',
    ),
    'E33380': EdinetCodeEntry(
        edinet_code='E33380',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前川\u3000昌之',
        submitter_name_en=None,
        submitter_name_yomi='マエカワ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33381': EdinetCodeEntry(
        edinet_code='E33381',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2646,
        fiscal_year_end='12月31日',
        submitter_name='西本Ｗｉｓｍｅｔｔａｃホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシモトウィズメタックホールディングスカブシキガイシャ',
        address='神戸市中央区磯辺通四丁目１番３８号',
        industry='卸売業',
        sec_code=None,
        corporate_number='7140001009895',
    ),
    'E33382': EdinetCodeEntry(
        edinet_code='E33382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=346,
        fiscal_year_end='9月末日',
        submitter_name='大阪油化工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオサカユカコウギョウカブシキガイシャ',
        address='枚方市春日西町二丁目２７番３３号',
        industry='化学',
        sec_code='41240',
        corporate_number='2120001149244',
    ),
    'E33384': EdinetCodeEntry(
        edinet_code='E33384',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=350,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ピー・ビーシステムズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャピービーシステムズ',
        address='福岡市博多区東比恵三丁目３番２４号',
        industry='情報・通信業',
        sec_code='44470',
        corporate_number='2290001015909',
    ),
    'E33385': EdinetCodeEntry(
        edinet_code='E33385',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='冨田\u3000和久',
        submitter_name_en=None,
        submitter_name_yomi='トミタ\u3000カズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33386': EdinetCodeEntry(
        edinet_code='E33386',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＲＡ\u3000Ｒｅａｌ\u3000Ｅｓｔａｔｅ\u3000Ｉｎｖｅｓｔｏｒｓ\u3000ＸＶＩＩＩ\u3000Ｐｔｅ．Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='エーアールエー\u3000リアル\u3000エステート\u3000インベスターズ\u3000エイティーン\u3000プライベート\u3000リミテッド',
        address='５\u3000Ｔｅｍａｓｅｋ\u3000Ｂｏｕｌｅｖａｒｄ，\u3000＃１２－０１\u3000Ｓｕｎｔｅｃ\u3000Ｔｏｗｅｒ\u3000５，\u3000Ｓｉｎｇａｐｏｒｅ\u3000０３８９８５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33390': EdinetCodeEntry(
        edinet_code='E33390',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25783,
        fiscal_year_end='11月30日',
        submitter_name='株式会社マネーフォワード',
        submitter_name_en='Money Forward, Inc.',
        submitter_name_yomi='カブシキガイシャマネーフォワード',
        address='港区芝浦３－１－２１ｍｓｂ\u3000Ｔａｍａｃｈｉ田町ステーションタワーＳ\u3000２１Ｆ',
        industry='情報・通信業',
        sec_code='39940',
        corporate_number='6011101063359',
    ),
    'E33391': EdinetCodeEntry(
        edinet_code='E33391',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ＰＫＳＨＡ\u3000Ｔｅｃｈｎｏｌｏｇｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャパークシャテクノロジー',
        address='文京区本郷２－３５－１０\u3000本郷瀬川ビル４Ｆ',
        industry='情報・通信業',
        sec_code='39930',
        corporate_number='5011101064787',
    ),
    'E33392': EdinetCodeEntry(
        edinet_code='E33392',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=469,
        fiscal_year_end='6月30日',
        submitter_name='株式会社壽屋',
        submitter_name_en='KOTOBUKIYA CO., LTD.',
        submitter_name_yomi='カブシキカイシャコトブキヤ',
        address='立川市緑町４－５',
        industry='その他製品',
        sec_code='78090',
        corporate_number='7012801000492',
    ),
    'E33393': EdinetCodeEntry(
        edinet_code='E33393',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=494,
        fiscal_year_end='5月31日',
        submitter_name='ヤマシタヘルスケアホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタヘルスケアホールディングスカブシキガイシャ',
        address='福岡市博多区下川端町２番１号',
        industry='卸売業',
        sec_code='92650',
        corporate_number='2290001079821',
    ),
    'E33395': EdinetCodeEntry(
        edinet_code='E33395',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='真邉\u3000正男',
        submitter_name_en=None,
        submitter_name_yomi='マナベ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33398': EdinetCodeEntry(
        edinet_code='E33398',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤吉\u3000英彦',
        submitter_name_en=None,
        submitter_name_yomi='フジヨシ\u3000ヒデヒコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33400': EdinetCodeEntry(
        edinet_code='E33400',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社オーディーシー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーディーシー',
        address='さいたま市浦和区本太一丁目３１番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2030001101841',
    ),
    'E33402': EdinetCodeEntry(
        edinet_code='E33402',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福島\u3000慶多',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000ケイタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33403': EdinetCodeEntry(
        edinet_code='E33403',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福島\u3000トシ',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000トシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33406': EdinetCodeEntry(
        edinet_code='E33406',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日本金属取引先持株会\u3000理事長\u3000五箇\u3000一善',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンキンゾクトリヒキサキモチカブカイ\u3000リジチョウ\u3000ゴカ\u3000カズヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33409': EdinetCodeEntry(
        edinet_code='E33409',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='仲\u3000暁子',
        submitter_name_en=None,
        submitter_name_yomi='ナカ\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33411': EdinetCodeEntry(
        edinet_code='E33411',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長友\u3000孝祥',
        submitter_name_en=None,
        submitter_name_yomi='ナガトモ\u3000タカヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33412': EdinetCodeEntry(
        edinet_code='E33412',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=337,
        fiscal_year_end='3月31日',
        submitter_name='ウェルビー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウェルビーカブシキガイシャ',
        address='中央区銀座二丁目３番６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010401097027',
    ),
    'E33416': EdinetCodeEntry(
        edinet_code='E33416',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1077,
        fiscal_year_end='6月20日',
        submitter_name='Ｇｅｎｋｙ\u3000ＤｒｕｇＳｔｏｒｅｓ株式会社',
        submitter_name_en='Genky DrugStores Co., Ltd.',
        submitter_name_yomi='ゲンキードラッグストアーズカブシキガイシャ',
        address='坂井市丸岡町下久米田３８字３３番',
        industry='小売業',
        sec_code='92670',
        corporate_number='5210001016969',
    ),
    'E33418': EdinetCodeEntry(
        edinet_code='E33418',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='綿引\u3000一',
        submitter_name_en=None,
        submitter_name_yomi='ワタヒキ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33426': EdinetCodeEntry(
        edinet_code='E33426',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=3548,
        fiscal_year_end='12月31日',
        submitter_name='テックポイント・インク（Ｔｅｃｈｐｏｉｎｔ，Ｉｎｃ．）',
        submitter_name_en=None,
        submitter_name_yomi='テックポイントインク',
        address='アメリカ合衆国、９５１３１カリフォルニア州、サンノゼ市、ノースファーストストリート２５５０、スイート５５０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E33430': EdinetCodeEntry(
        edinet_code='E33430',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='株式会社ハマダコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハマダコム',
        address='姫路市網干区新在家１２６１－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001062692',
    ),
    'E33433': EdinetCodeEntry(
        edinet_code='E33433',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=38396,
        fiscal_year_end=None,
        submitter_name='カナディアン・ソーラー・インフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='カナディアンソーラーインフラトウシホウジン',
        address='港区虎ノ門二丁目４番７号\u3000Ｔ－ＬＩＴＥ１３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011105007806',
    ),
    'E33435': EdinetCodeEntry(
        edinet_code='E33435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=308,
        fiscal_year_end='3月末日',
        submitter_name='株式会社イノベーションホールディングス',
        submitter_name_en='Innovation Holdings CO.,LTD.',
        submitter_name_yomi='カブシキガイシャイノベーションホールディングス',
        address='新宿区新宿四丁目１番６号\u3000ＪＲ新宿ミライナタワー１１階',
        industry='不動産業',
        sec_code='34840',
        corporate_number='7011101062525',
    ),
    'E33437': EdinetCodeEntry(
        edinet_code='E33437',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16,
        fiscal_year_end=None,
        submitter_name='ＳＡＭＡＲＡＮＧ\u3000ＵＣＩＴＳ',
        submitter_name_en=None,
        submitter_name_yomi='サマラン\u3000ユーシッツ',
        address='１１ａ\u3000Ａｖｅｎｕｅ\u3000Ｍｏｎｔｅｒｅｙ\u3000Ｌ－２１６３\u3000Ｌｕｘｅｍｂｏｕｒｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33440': EdinetCodeEntry(
        edinet_code='E33440',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ケイアイテイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシカイシャケイアイテイ',
        address='新宿区新宿１丁目３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101005998',
    ),
    'E33447': EdinetCodeEntry(
        edinet_code='E33447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=310,
        fiscal_year_end=None,
        submitter_name='コムテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コムテックカブシキガイシャ',
        address='小田原市城山三丁目８番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5021001054747',
    ),
    'E33448': EdinetCodeEntry(
        edinet_code='E33448',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川田\u3000尚吾',
        submitter_name_en=None,
        submitter_name_yomi='カワダ\u3000ショウゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33457': EdinetCodeEntry(
        edinet_code='E33457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅田\u3000裕真',
        submitter_name_en=None,
        submitter_name_yomi='ウメダ\u3000ユウマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33458': EdinetCodeEntry(
        edinet_code='E33458',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鎌田\u3000和樹',
        submitter_name_en=None,
        submitter_name_yomi='カマダ\u3000カズキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33462': EdinetCodeEntry(
        edinet_code='E33462',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000康雄',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33463': EdinetCodeEntry(
        edinet_code='E33463',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社日本地下技術',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニホンチカギジュツ',
        address='鹿児島市伊敷五丁目１６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1340001003413',
    ),
    'E33464': EdinetCodeEntry(
        edinet_code='E33464',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社南日本運輸建設',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミナミニホンウンユケンセツ',
        address='薩摩川内市永利町１３５５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6340001008696',
    ),
    'E33469': EdinetCodeEntry(
        edinet_code='E33469',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=25584,
        fiscal_year_end='3月末日',
        submitter_name='三井住友トラスト・パナソニックファイナンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツイスミトモトラストパナソニックファイナンスカブシキガイシャ',
        address='港区芝浦一丁目２番３号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='1010001146146',
    ),
    'E33470': EdinetCodeEntry(
        edinet_code='E33470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000公男',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000キミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33475': EdinetCodeEntry(
        edinet_code='E33475',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ヘ・シェン・オーバーシーズ・ホールディングス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ヘシェンオーバーシーズホールディングスリミテッド',
        address='英国領バージン諸島、ＶＧ１１１０、トルトラ島ロードタウン、ウィッカム・カイⅡ、ヴィストラ・コーポレート・サービス・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33479': EdinetCodeEntry(
        edinet_code='E33479',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41,
        fiscal_year_end=None,
        submitter_name='株式会社ニイタカＳＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニイタカエスシー',
        address='大阪市淀川区新高一丁目８番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001057309',
    ),
    'E33481': EdinetCodeEntry(
        edinet_code='E33481',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000尚史',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ナオフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33482': EdinetCodeEntry(
        edinet_code='E33482',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上野山\u3000勝也',
        submitter_name_en=None,
        submitter_name_yomi='ウエノヤマ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33484': EdinetCodeEntry(
        edinet_code='E33484',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=445754,
        fiscal_year_end='12月31日',
        submitter_name='Ｇｅｎｔｉｎｇ\u3000Ｓｉｎｇａｐｏｒｅ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ゲンティンシンガポールリミテッド',
        address='１０\u3000Ｓｅｎｔｏｓａ\u3000Ｇａｔｅｗａｙ，\u3000Ｒｅｓｏｒｔｓ\u3000Ｗｏｒｌｄ\u3000Ｓｅｎｔｏｓａ，\u3000Ｓｉｎｇａｐｏｒｅ\u3000０９８２７０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E33485': EdinetCodeEntry(
        edinet_code='E33485',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1582,
        fiscal_year_end='1月31日',
        submitter_name='株式会社Ｃａｓａ',
        submitter_name_en='Casa Inc.',
        submitter_name_yomi='カブシキガイシャカーサ',
        address='新宿区西新宿二丁目６番１号',
        industry='その他金融業',
        sec_code='71960',
        corporate_number='4010001155540',
    ),
    'E33486': EdinetCodeEntry(
        edinet_code='E33486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ヤマノビューティメイトグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマノビューティメイトグループ',
        address='渋谷区代々木１－３０－７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001097623',
    ),
    'E33487': EdinetCodeEntry(
        edinet_code='E33487',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='臼井\u3000英美',
        submitter_name_en=None,
        submitter_name_yomi='ウスイ\u3000エイミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33490': EdinetCodeEntry(
        edinet_code='E33490',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000亨',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33491': EdinetCodeEntry(
        edinet_code='E33491',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=57,
        fiscal_year_end='2月末日',
        submitter_name='株式会社幸和製作所',
        submitter_name_en='KOWA CO.,LTD.',
        submitter_name_yomi='カブシキカイシャコウワセイサクショ',
        address='堺市堺区海山町３丁１５９番地１',
        industry='その他製品',
        sec_code='78070',
        corporate_number='4120101002219',
    ),
    'E33494': EdinetCodeEntry(
        edinet_code='E33494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='洲崎\u3000良朗',
        submitter_name_en=None,
        submitter_name_yomi='スサキ\u3000ヨシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33495': EdinetCodeEntry(
        edinet_code='E33495',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5593,
        fiscal_year_end=None,
        submitter_name='公益財団法人洲崎福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンスサキフクシザイダン',
        address='中央区日本橋室町三丁目２番１号\u3000日本橋室町三井タワー１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405007781',
    ),
    'E33497': EdinetCodeEntry(
        edinet_code='E33497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=532,
        fiscal_year_end='5月31日',
        submitter_name='株式会社シー・エス・ランバー',
        submitter_name_en='C.S. LUMBER CO., INC',
        submitter_name_yomi='カブシキガイシャシーエスランバー',
        address='千葉市花見川区幕張本郷一丁目１６番３号',
        industry='その他製品',
        sec_code='78080',
        corporate_number='1040001057646',
    ),
    'E33498': EdinetCodeEntry(
        edinet_code='E33498',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000一行',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000カズユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33500': EdinetCodeEntry(
        edinet_code='E33500',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='辻\u3000庸介',
        submitter_name_en=None,
        submitter_name_yomi='ツジ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33508': EdinetCodeEntry(
        edinet_code='E33508',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｒｅｎｒｅｎ\u3000Ｌｉａｎｈｅ\u3000Ｈｏｌｄｉｎｇｓ',
        submitter_name_en=None,
        submitter_name_yomi='レンレン\u3000リアンヒェ\u3000ホールディングス',
        address='Ｍａｐｌｅｓ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｌｉｍｉｔｅｄ，\u3000ＰＯ\u3000Ｂｏｘ\u3000３０９，\u3000Ｕｇｌａｎｄ\u3000Ｈｏｕｓｅ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０４，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33509': EdinetCodeEntry(
        edinet_code='E33509',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='貞松\u3000成',
        submitter_name_en=None,
        submitter_name_yomi='サダマツ\u3000ジョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33511': EdinetCodeEntry(
        edinet_code='E33511',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西岡\u3000勇人',
        submitter_name_en=None,
        submitter_name_yomi='ニシオカ\u3000ユウト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33512': EdinetCodeEntry(
        edinet_code='E33512',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福岡\u3000夏奈子',
        submitter_name_en=None,
        submitter_name_yomi='フクオカ\u3000カナコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33514': EdinetCodeEntry(
        edinet_code='E33514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1694,
        fiscal_year_end='8月31日',
        submitter_name='ポエック株式会社',
        submitter_name_en='Puequ Co., LTD.',
        submitter_name_yomi='ポエックカブシキカイシャ',
        address='福山市南蔵王町二丁目１番１２号',
        industry='卸売業',
        sec_code='92640',
        corporate_number='5240001032096',
    ),
    'E33515': EdinetCodeEntry(
        edinet_code='E33515',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=485,
        fiscal_year_end='11月末日',
        submitter_name='クックビズ株式会社',
        submitter_name_en='Cookbiz Co.,Ltd.',
        submitter_name_yomi='クックビズカブシキカイシャ',
        address='大阪市北区芝田２丁目７番１８号',
        industry='サービス業',
        sec_code='65580',
        corporate_number='7120001128193',
    ),
    'E33519': EdinetCodeEntry(
        edinet_code='E33519',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=782,
        fiscal_year_end='2月末日',
        submitter_name='サインポスト株式会社',
        submitter_name_en='Signpost Corporation',
        submitter_name_yomi='サインポストカブシキカイシャ',
        address='中央区日本橋本町四丁目１２番２０号',
        industry='情報・通信業',
        sec_code='39960',
        corporate_number='1010001107305',
    ),
    'E33525': EdinetCodeEntry(
        edinet_code='E33525',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='リュー\u3000フン\u3000カイ',
        submitter_name_en=None,
        submitter_name_yomi='リュー\u3000フン\u3000カイ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33528': EdinetCodeEntry(
        edinet_code='E33528',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25439,
        fiscal_year_end=None,
        submitter_name='デンソー・インターナショナル・アメリカ',
        submitter_name_en=None,
        submitter_name_yomi='デンソー\u3000インターナショナル\u3000アメリカ',
        address='２４７７７\u3000Ｄｅｎｓｏ\u3000Ｄｒｉｖｅ，Ｓｏｕｔｈｆｉｅｌｄ，ＭＩ\u3000４８０３３\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33534': EdinetCodeEntry(
        edinet_code='E33534',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=52,
        fiscal_year_end=None,
        submitter_name='コバス・アセット・マネジメント・エスジーアイアイシー・エスエー',
        submitter_name_en=None,
        submitter_name_yomi='コバス\u3000アセット\u3000マネジメント\u3000エスジーアイアイシー\u3000エスエー',
        address='スペイン２８０４６マドリード、カステリャーナ通り５３、２階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33535': EdinetCodeEntry(
        edinet_code='E33535',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1120,
        fiscal_year_end='3月31日',
        submitter_name='技研ホールディングス株式会社',
        submitter_name_en='Giken Holdings Co., Ltd.',
        submitter_name_yomi='ギケンホールディングスカブシキガイシャ',
        address='千代田区神田東松下町１７番地',
        industry='建設業',
        sec_code='14430',
        corporate_number='2011301023802',
    ),
    'E33540': EdinetCodeEntry(
        edinet_code='E33540',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森田\u3000泰弘',
        submitter_name_en=None,
        submitter_name_yomi='モリタ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33541': EdinetCodeEntry(
        edinet_code='E33541',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩野\u3000達志',
        submitter_name_en=None,
        submitter_name_yomi='イワノ\u3000タツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33545': EdinetCodeEntry(
        edinet_code='E33545',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀田\u3000哲平',
        submitter_name_en=None,
        submitter_name_yomi='ホッタ\u3000テッペイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33547': EdinetCodeEntry(
        edinet_code='E33547',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1100,
        fiscal_year_end=None,
        submitter_name='カナディアン・ソーラー・プロジェクト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カナディアンソーラープロジェクトカブシキカイシャ',
        address='新宿区西新宿２－１－１新宿三井ビル４３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101070093',
    ),
    'E33553': EdinetCodeEntry(
        edinet_code='E33553',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=582,
        fiscal_year_end='12月31日',
        submitter_name='株式会社トレードワークス',
        submitter_name_en='TRADE WORKS Co., Ltd',
        submitter_name_yomi='カブシキカイシャトレードワークス',
        address='港区赤坂五丁目２番２０号',
        industry='情報・通信業',
        sec_code='39970',
        corporate_number='1010001085245',
    ),
    'E33557': EdinetCodeEntry(
        edinet_code='E33557',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20,
        fiscal_year_end='3月末日',
        submitter_name='ＡＩＡＩグループ株式会社',
        submitter_name_en='AIAI Group Corporation',
        submitter_name_yomi='アイアイグループカブシキガイシャ',
        address='墨田区錦糸一丁目２番１号',
        industry='サービス業',
        sec_code='65570',
        corporate_number='6010601048836',
    ),
    'E33566': EdinetCodeEntry(
        edinet_code='E33566',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=691548,
        fiscal_year_end=None,
        submitter_name='ピンアン・ライフ・インシュアランス・カンパニー・オブ・チャイナ・リミテッド（中国平安人寿保険股フン有限公司）',
        submitter_name_en=None,
        submitter_name_yomi='ピンアン\u3000ライフ\u3000インシュアランス\u3000カンパニー\u3000オブ\u3000チャイナ\u3000リミテッド',
        address='中華人民共和国広東省深セン市福田区益田路５０３３号平安金融センター１４、１５、１６、３７、４１、４４、４５、４６、５４、５８、５９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33570': EdinetCodeEntry(
        edinet_code='E33570',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='3月31日',
        submitter_name='株式会社\u3000一家ダイニングプロジェクト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000イッカダイニングプロジェクト',
        address='市川市東大和田二丁目４番１０号',
        industry='小売業',
        sec_code=None,
        corporate_number='2040001027978',
    ),
    'E33574': EdinetCodeEntry(
        edinet_code='E33574',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=615,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マツオカコーポレーション',
        submitter_name_en='MATSUOKA CORPORATION',
        submitter_name_yomi='カブシキガイシャマツオカコーポレーション',
        address='福山市西町二丁目８番１９号',
        industry='繊維製品',
        sec_code='36110',
        corporate_number='7240001034000',
    ),
    'E33575': EdinetCodeEntry(
        edinet_code='E33575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000一',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33576': EdinetCodeEntry(
        edinet_code='E33576',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='フランクリン・テンプルトン・インベストメント・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='フランクリンテンプルトンインベストメントファンズ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－１２４６、アルバート・ボルシェット通り８Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33577': EdinetCodeEntry(
        edinet_code='E33577',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ミダックホールディングス',
        submitter_name_en='MIDAC HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャミダックホールディングス',
        address='浜松市中央区有玉南町２１６３番地',
        industry='サービス業',
        sec_code='65640',
        corporate_number='6080401005304',
    ),
    'E33579': EdinetCodeEntry(
        edinet_code='E33579',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=582,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グローバル・リンク・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグローバルリンクマンジメント',
        address='渋谷区道玄坂一丁目１２番１号',
        industry='不動産業',
        sec_code='34860',
        corporate_number='3011001044453',
    ),
    'E33580': EdinetCodeEntry(
        edinet_code='E33580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='樺島\u3000弘明',
        submitter_name_en=None,
        submitter_name_yomi='カバシマ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33581': EdinetCodeEntry(
        edinet_code='E33581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='李\u3000成一',
        submitter_name_en=None,
        submitter_name_yomi='リ\u3000ソンイル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33583': EdinetCodeEntry(
        edinet_code='E33583',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=494,
        fiscal_year_end='3月末日',
        submitter_name='ヴィスコ・テクノロジーズ株式会社',
        submitter_name_en='ViSCO Technologies Corporation',
        submitter_name_yomi='ヴィスコテクノロジーズカブシキガイシャ',
        address='港区海岸一丁目１１番１号ニューピア竹芝ノースタワー',
        industry='電気機器',
        sec_code=None,
        corporate_number='1010401052489',
    ),
    'E33586': EdinetCodeEntry(
        edinet_code='E33586',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メドレー',
        submitter_name_en='MEDLEY,INC.',
        submitter_name_yomi='カブシキガイシャメドレー',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='44800',
        corporate_number='4010401082351',
    ),
    'E33587': EdinetCodeEntry(
        edinet_code='E33587',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='塚原\u3000厚',
        submitter_name_en=None,
        submitter_name_yomi='ツカハラ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33588': EdinetCodeEntry(
        edinet_code='E33588',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=306,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エル・ティー・エス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエルティーエス',
        address='港区元赤坂１ー３－１３',
        industry='サービス業',
        sec_code='65600',
        corporate_number='8011101053812',
    ),
    'E33592': EdinetCodeEntry(
        edinet_code='E33592',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000貴久',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000タカヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33594': EdinetCodeEntry(
        edinet_code='E33594',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=400,
        fiscal_year_end='12月31日',
        submitter_name='株式会社オプトラン',
        submitter_name_en='OPTORUN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャオプトラン',
        address='川越市竹野１０番地１',
        industry='機械',
        sec_code='62350',
        corporate_number='1030001056764',
    ),
    'E33595': EdinetCodeEntry(
        edinet_code='E33595',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=915,
        fiscal_year_end='3月末日',
        submitter_name='株式会社イオレ',
        submitter_name_en='eole Inc.',
        submitter_name_yomi='カブシキカイシャイオレ',
        address='中央区日本橋横山町６番１６号',
        industry='サービス業',
        sec_code='23340',
        corporate_number='3010901015200',
    ),
    'E33597': EdinetCodeEntry(
        edinet_code='E33597',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮地\u3000正剛',
        submitter_name_en=None,
        submitter_name_yomi='ミヤジ\u3000セイゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33598': EdinetCodeEntry(
        edinet_code='E33598',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='ブルーテック株式会社',
        submitter_name_en='BlueTec Inc.',
        submitter_name_yomi='ブルーテックカブシキカイシャ',
        address='港区虎ノ門三丁目１８番１９号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5010401098909',
    ),
    'E33601': EdinetCodeEntry(
        edinet_code='E33601',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=212,
        fiscal_year_end='9月末日',
        submitter_name='株式会社みらいワークス',
        submitter_name_en='Mirai Works Inc.',
        submitter_name_yomi='カブシキガイシャミライワークス',
        address='港区東新橋二丁目８番１号７階',
        industry='サービス業',
        sec_code='65630',
        corporate_number='4011001072890',
    ),
    'E33602': EdinetCodeEntry(
        edinet_code='E33602',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＨＡＮＡＴＯＵＲ\u3000ＪＡＰＡＮ',
        submitter_name_en='HANATOUR JAPAN CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハナツアージャパン',
        address='港区虎ノ門五丁目１２番１号',
        industry='サービス業',
        sec_code='65610',
        corporate_number='3010401058864',
    ),
    'E33603': EdinetCodeEntry(
        edinet_code='E33603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1640,
        fiscal_year_end='3月31日',
        submitter_name='森六株式会社',
        submitter_name_en='MORIROKU COMPANY, LTD.',
        submitter_name_yomi='モリロクカブシキガイシャ',
        address='港区南青山一丁目１番１号',
        industry='化学',
        sec_code='42490',
        corporate_number='9010401054420',
    ),
    'E33607': EdinetCodeEntry(
        edinet_code='E33607',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藪ノ\u3000賢次',
        submitter_name_en=None,
        submitter_name_yomi='ヤブノ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33609': EdinetCodeEntry(
        edinet_code='E33609',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社悠晴',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユハ',
        address='立川市錦町二丁目３番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001068847',
    ),
    'E33610': EdinetCodeEntry(
        edinet_code='E33610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='2月末日',
        submitter_name='株式会社パパネッツ',
        submitter_name_en='PAPANETS CO.,Ltd.',
        submitter_name_yomi='カブシキカイシャパパネッツ',
        address='越谷市越ケ谷１－５－１７\u3000パパネッツ越谷ビル９階',
        industry='倉庫・運輸関連',
        sec_code='93880',
        corporate_number='9030001067804',
    ),
    'E33611': EdinetCodeEntry(
        edinet_code='E33611',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社花明',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャハナアカリ',
        address='北葛飾郡松伏町大字上赤岩１５３０－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3030001113209',
    ),
    'E33613': EdinetCodeEntry(
        edinet_code='E33613',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='工藤智昭',
        submitter_name_en=None,
        submitter_name_yomi='クドウトモアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33615': EdinetCodeEntry(
        edinet_code='E33615',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1546,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ジーニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジーニー',
        address='新宿区西新宿６－８－１',
        industry='情報・通信業',
        sec_code='65620',
        corporate_number='7010401087406',
    ),
    'E33616': EdinetCodeEntry(
        edinet_code='E33616',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=431,
        fiscal_year_end='3月末日',
        submitter_name='株式会社オプティマスグループ',
        submitter_name_en='OPTIMUS GROUP COMPANY LIMITED',
        submitter_name_yomi='カブシキガイシャオプティマスグループ',
        address='港区芝二丁目５番６号',
        industry='卸売業',
        sec_code='92680',
        corporate_number='9010401116022',
    ),
    'E33617': EdinetCodeEntry(
        edinet_code='E33617',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社アレクシア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアレクシア',
        address='北葛飾郡松伏町築比地７９５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7400001000167',
    ),
    'E33621': EdinetCodeEntry(
        edinet_code='E33621',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='Ｇｅｎｓ\u3000Ｇｌｏｂａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゲンズグローバルカブシキガイシャ',
        address='名古屋市中村区名駅一丁目１番１号ＪＰＴｏｗｅｒＮａｇｏｙａ２１Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001129827',
    ),
    'E33622': EdinetCodeEntry(
        edinet_code='E33622',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3778,
        fiscal_year_end='3月31日',
        submitter_name='株式会社カチタス',
        submitter_name_en='KATITAS Co., Ltd.',
        submitter_name_yomi='カブシキカイシャカチタス',
        address='桐生市美原町４番２号',
        industry='不動産業',
        sec_code='89190',
        corporate_number='6070001016685',
    ),
    'E33623': EdinetCodeEntry(
        edinet_code='E33623',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1067,
        fiscal_year_end='3月末日',
        submitter_name='株式会社アイ・ピー・エス',
        submitter_name_en='IPS, Inc.',
        submitter_name_yomi='カブシキガイシャアイピーエス',
        address='中央区築地四丁目１番１号\u3000東劇ビル８階',
        industry='情報・通信業',
        sec_code='43900',
        corporate_number='5010001072421',
    ),
    'E33624': EdinetCodeEntry(
        edinet_code='E33624',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1680,
        fiscal_year_end='3月末日',
        submitter_name='プレミアグループ株式会社',
        submitter_name_en='Premium Group Co., Ltd.',
        submitter_name_yomi='プレミアグループカブシキガイシャ',
        address='港区虎ノ門二丁目１０番４号オークラプレステージタワー',
        industry='その他金融業',
        sec_code='71990',
        corporate_number='8010001168159',
    ),
    'E33625': EdinetCodeEntry(
        edinet_code='E33625',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6000,
        fiscal_year_end='3月末日',
        submitter_name='ＳＢＩアルヒ株式会社',
        submitter_name_en='SBI ARUHI Corporation',
        submitter_name_yomi='エスビーアイアルヒカブシキガイシャ',
        address='千代田区平河町一丁目４番３号',
        industry='その他金融業',
        sec_code='71980',
        corporate_number='1010001160717',
    ),
    'E33626': EdinetCodeEntry(
        edinet_code='E33626',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=298,
        fiscal_year_end='12月31日',
        submitter_name='株式会社すららネット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスララネット',
        address='千代田区内神田一丁目１４番１０号',
        industry='情報・通信業',
        sec_code='39980',
        corporate_number='7010001136802',
    ),
    'E33628': EdinetCodeEntry(
        edinet_code='E33628',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='武長\u3000太郎',
        submitter_name_en=None,
        submitter_name_yomi='タケナガ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33629': EdinetCodeEntry(
        edinet_code='E33629',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3777,
        fiscal_year_end=None,
        submitter_name='ケイン・アンダーソン・ラドニック・インベストメント・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ケイン\u3000アンダーソン\u3000ラドニック\u3000インベストメント\u3000マネジメント\u3000エルエルシー',
        address='９００６７カリフォルニア州、ロサンゼルス、アヴェニュー・オブ・スターズ２０００、スイート１１１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33632': EdinetCodeEntry(
        edinet_code='E33632',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='信越エンジニアリング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンエツエンジニアリングカブシキカイシャ',
        address='千代田区神田錦町二丁目９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001018613',
    ),
    'E33633': EdinetCodeEntry(
        edinet_code='E33633',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=827,
        fiscal_year_end='3月31日',
        submitter_name='株式会社要興業',
        submitter_name_en='KANAME KOGYO CO.,LTD.',
        submitter_name_yomi='カブシキカイシャカナメコウギョウ',
        address='豊島区池袋二丁目１４番８号池袋エヌエスビル',
        industry='サービス業',
        sec_code='65660',
        corporate_number='7013301003168',
    ),
    'E33636': EdinetCodeEntry(
        edinet_code='E33636',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='アヤル・ファースト・インベストメント・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='アヤル\u3000ファースト\u3000インベストメント\u3000カンパニー',
        address='サウジアラビア王国、１３５１９リヤド市、アルアキーク地区６７９０、フィナンシャル・ブールバード３１２１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33637': EdinetCodeEntry(
        edinet_code='E33637',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本郵政キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンユウセイキャピタルカブシキカイシャ',
        address='千代田区大手町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001187433',
    ),
    'E33638': EdinetCodeEntry(
        edinet_code='E33638',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=953,
        fiscal_year_end='3月末日',
        submitter_name='ＡＢホテル株式会社',
        submitter_name_en='ABHOTEL CO., LTD.',
        submitter_name_yomi='エービーホテルカブシキガイシャ',
        address='安城市三河安城町一丁目９番地２',
        industry='サービス業',
        sec_code='65650',
        corporate_number='1180301027293',
    ),
    'E33641': EdinetCodeEntry(
        edinet_code='E33641',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市川俊雄',
        submitter_name_en=None,
        submitter_name_yomi='イチカワトシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33642': EdinetCodeEntry(
        edinet_code='E33642',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＢ開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エービーカイハツカブシキガイシャ',
        address='安城市三河安城本町二丁目１３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180303003382',
    ),
    'E33648': EdinetCodeEntry(
        edinet_code='E33648',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='道しるべ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミチシルベカブシキガイシャ',
        address='港区麻布十番一丁目５番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401126639',
    ),
    'E33649': EdinetCodeEntry(
        edinet_code='E33649',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蒲原\u3000寧',
        submitter_name_en=None,
        submitter_name_yomi='カンバラ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33650': EdinetCodeEntry(
        edinet_code='E33650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥井\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='オクイ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33651': EdinetCodeEntry(
        edinet_code='E33651',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社五六',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゴロウ',
        address='目黒区目黒本町二丁目２６番地１９号ランドステージ学芸大学１０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401110846',
    ),
    'E33652': EdinetCodeEntry(
        edinet_code='E33652',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000直人',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ナオヒト',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33653': EdinetCodeEntry(
        edinet_code='E33653',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17,
        fiscal_year_end=None,
        submitter_name='Ｓｗｅｄｂａｎｋ\u3000Ｒｏｂｕｒ\u3000Ｆｏｎｄｅｒ\u3000ＡＢ',
        submitter_name_en=None,
        submitter_name_yomi='スウェドバンク\u3000ロブル\u3000フォンダー\u3000アクチエボラグ',
        address='Ｌａｎｄｓｖａｇｅｎ\u3000４０，\u3000１７２\u3000６３\u3000Ｓｕｎｄｂｙｂｅｒｇ，\u3000Ｓｔｏｃｋｈｏｌｍ，\u3000Ｓｗｅｄｅｎ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33654': EdinetCodeEntry(
        edinet_code='E33654',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=193,
        fiscal_year_end=None,
        submitter_name='学校法人日吉台学園',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジンヒヨシダイガクエン',
        address='富里市日吉台五丁目２５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040005006149',
    ),
    'E33658': EdinetCodeEntry(
        edinet_code='E33658',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月末日',
        submitter_name='マネックスファイナンス株式会社',
        submitter_name_en='Monex Finance Corporation',
        submitter_name_yomi='マネックスファイナンスカブシキガイシャ',
        address='港区赤坂１－１２－３２',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010401130452',
    ),
    'E33660': EdinetCodeEntry(
        edinet_code='E33660',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社千代',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセンダイ',
        address='千葉市稲毛区長沼原町９４２番地２９７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5040001100831',
    ),
    'E33664': EdinetCodeEntry(
        edinet_code='E33664',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=73535,
        fiscal_year_end=None,
        submitter_name='ＣＲＥロジスティクスファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='シーアールイーロジスティクスファンドトウシホウジン',
        address='港区虎ノ門二丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010405014815',
    ),
    'E33667': EdinetCodeEntry(
        edinet_code='E33667',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='浅見\u3000勝弘',
        submitter_name_en=None,
        submitter_name_yomi='アサミ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33671': EdinetCodeEntry(
        edinet_code='E33671',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='稲葉\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='イナバ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33675': EdinetCodeEntry(
        edinet_code='E33675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉田\u3000秀明',
        submitter_name_en=None,
        submitter_name_yomi='タマダ\u3000ヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33676': EdinetCodeEntry(
        edinet_code='E33676',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉田\u3000栄一',
        submitter_name_en=None,
        submitter_name_yomi='タマダ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33677': EdinetCodeEntry(
        edinet_code='E33677',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社秀一',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒデイチ',
        address='堺市堺区緑ヶ丘中町四丁４番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120101030483',
    ),
    'E33684': EdinetCodeEntry(
        edinet_code='E33684',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='ＡＺ－Ｓｔａｒ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エージースターカブシキガイシャ',
        address='港区赤坂二丁目３番５号赤坂スターゲートプラザ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001166071',
    ),
    'E33685': EdinetCodeEntry(
        edinet_code='E33685',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='釆女\u3000信二郎',
        submitter_name_en=None,
        submitter_name_yomi='ウネメ\u3000シンジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33686': EdinetCodeEntry(
        edinet_code='E33686',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='来山\u3000哲二',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33688': EdinetCodeEntry(
        edinet_code='E33688',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000裕之',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33690': EdinetCodeEntry(
        edinet_code='E33690',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000勝弘',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33691': EdinetCodeEntry(
        edinet_code='E33691',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000由起子',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000ユキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33693': EdinetCodeEntry(
        edinet_code='E33693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社三十三フィナンシャルグループ',
        submitter_name_en='San ju San Financial Group,Inc',
        submitter_name_yomi='カブシキガイシャサンジュウサンフィナンシャルグループ',
        address='松阪市京町５１０番地',
        industry='銀行業',
        sec_code='73220',
        corporate_number='2190001025439',
    ),
    'E33697': EdinetCodeEntry(
        edinet_code='E33697',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桐山\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='キリヤマ\u3000\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33698': EdinetCodeEntry(
        edinet_code='E33698',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='一般財団法人ＩＣ齋藤育英会',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンアイシーサイトウイクエイカイ',
        address='港区港南二丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010705001941',
    ),
    'E33699': EdinetCodeEntry(
        edinet_code='E33699',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='足立\u3000秀之',
        submitter_name_en=None,
        submitter_name_yomi='アダチ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33700': EdinetCodeEntry(
        edinet_code='E33700',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='セントラル・リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='セントラルリートトウシホウジン',
        address='港区赤坂一丁目１１番３０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010405016090',
    ),
    'E33701': EdinetCodeEntry(
        edinet_code='E33701',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=29589,
        fiscal_year_end='3月末日',
        submitter_name='株式会社関西みらいフィナンシャルグループ',
        submitter_name_en='kansai Mirai Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャカンサイミライフィナンシャルグループ',
        address='大阪市中央区備後町二丁目２番１号',
        industry='銀行業',
        sec_code=None,
        corporate_number='6120001209556',
    ),
    'E33702': EdinetCodeEntry(
        edinet_code='E33702',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2012,
        fiscal_year_end='12月31日',
        submitter_name='ＦＩＧ株式会社',
        submitter_name_en='Future Innovation Group, Inc.',
        submitter_name_yomi='エフアイジーカブシキカイシャ',
        address='大分市東大道二丁目５番６０号',
        industry='情報・通信業',
        sec_code='43920',
        corporate_number='4320001016471',
    ),
    'E33703': EdinetCodeEntry(
        edinet_code='E33703',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人ＳＧＨ文化スポーツ振興財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンエスジーエイチブンカスポーツシンコウザイダン',
        address='守山市水保町北川２８９１番地４４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1160005009383',
    ),
    'E33705': EdinetCodeEntry(
        edinet_code='E33705',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='東\u3000正志',
        submitter_name_en=None,
        submitter_name_yomi='ヒガシ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33707': EdinetCodeEntry(
        edinet_code='E33707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='李\u3000炳燦',
        submitter_name_en=None,
        submitter_name_yomi='イ\u3000ピョンチャン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33708': EdinetCodeEntry(
        edinet_code='E33708',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=442,
        fiscal_year_end=None,
        submitter_name='株式会社シティアスコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシティアスコム',
        address='福岡市早良区百道浜２－２－２２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290001005248',
    ),
    'E33711': EdinetCodeEntry(
        edinet_code='E33711',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=569,
        fiscal_year_end=None,
        submitter_name='ＨＡＮＡＴＯＵＲ\u3000ＳＥＲＶＩＣＥ\u3000ＩＮＣ．',
        submitter_name_en=None,
        submitter_name_yomi='ハナツアー\u3000サービス\u3000インク',
        address='大韓民国ソウル市鍾路区仁寺洞５ギル４１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33712': EdinetCodeEntry(
        edinet_code='E33712',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=36813,
        fiscal_year_end=None,
        submitter_name='公益財団法人福武財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンフクタケザイダン',
        address='香川郡直島町２２４９番地７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9470005005328',
    ),
    'E33717': EdinetCodeEntry(
        edinet_code='E33717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='東洋額装株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウヨウガクソウカブシキガイシャ',
        address='福山市加茂町字八軒屋３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001031439',
    ),
    'E33718': EdinetCodeEntry(
        edinet_code='E33718',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='峯村\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='ミネムラ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33720': EdinetCodeEntry(
        edinet_code='E33720',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ａｃａｄｉａｎ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='アカディアンアセットマネージメントエルエルシー',
        address='アメリカ合衆国マサチューセッツ州、ボストン、２０階、フランクリン・ストリート２６０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33724': EdinetCodeEntry(
        edinet_code='E33724',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社新生ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンセイホールディングス',
        address='京都市下京区北小路通油小路東入文覚町３６９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9130001045709',
    ),
    'E33727': EdinetCodeEntry(
        edinet_code='E33727',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＲＯＢＥＲＴ\u3000ＡＮＤＲＥＷ\u3000ＹＯＵＮＧ',
        submitter_name_en=None,
        submitter_name_yomi='ロバート\u3000アンドリュー\u3000ヤング',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33728': EdinetCodeEntry(
        edinet_code='E33728',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＭＡＲＴＩＮ\u3000ＦＲＡＳＥＲ\u3000ＭＣＣＵＬＬＯＵＧＨ',
        submitter_name_en=None,
        submitter_name_yomi='マーティン\u3000フレイザー\u3000マッカラック',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33731': EdinetCodeEntry(
        edinet_code='E33731',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2282,
        fiscal_year_end=None,
        submitter_name='コスモ・レディー（チャイナ）ホールディングス・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='コスモレディーチャイナホールディングスカンパニーリミテッド',
        address='ケイマン諸島、ＫＹ１ー１１０８、グランド・ケイマン、７５フォート・ストリート、クリフトンハウス、エステラ・トラスト（ケイマン）リミテッド、私書籍１３５０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33739': EdinetCodeEntry(
        edinet_code='E33739',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡\u3000丈詞',
        submitter_name_en=None,
        submitter_name_yomi='オカ\u3000タケフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33742': EdinetCodeEntry(
        edinet_code='E33742',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=52,
        fiscal_year_end=None,
        submitter_name='サイブリッジグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイブリッジグループカブシキガイシャ',
        address='港区南青山二丁目２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401082114',
    ),
    'E33746': EdinetCodeEntry(
        edinet_code='E33746',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='いずみキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イズミキャピタルカブシキガイシャ',
        address='港区六本木四丁目８番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401099801',
    ),
    'E33750': EdinetCodeEntry(
        edinet_code='E33750',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松岡\u3000典之',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33755': EdinetCodeEntry(
        edinet_code='E33755',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金\u3000大仲',
        submitter_name_en=None,
        submitter_name_yomi='キム\u3000テジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33758': EdinetCodeEntry(
        edinet_code='E33758',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社インターネット総合研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャインターネットソウゴウケンキュウショ',
        address='新宿区西新宿一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101081981',
    ),
    'E33760': EdinetCodeEntry(
        edinet_code='E33760',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山中\u3000信哉',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナカ\u3000ノブヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33771': EdinetCodeEntry(
        edinet_code='E33771',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近藤\u3000保',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000タモツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33776': EdinetCodeEntry(
        edinet_code='E33776',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=693,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＥＲＩＯホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセリオホールディングス',
        address='大阪市北区堂島一丁目５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001198713',
    ),
    'E33777': EdinetCodeEntry(
        edinet_code='E33777',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=817,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ジェイテックコーポレーション',
        submitter_name_en='JTEC CORPORATION',
        submitter_name_yomi='カブシキガイシャジェイテックコーポレーション',
        address='茨木市彩都やまぶき２丁目５番３８号',
        industry='金属製品',
        sec_code='34460',
        corporate_number='5140001023717',
    ),
    'E33779': EdinetCodeEntry(
        edinet_code='E33779',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＯＲＯ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='モロゴウドウガイシャ',
        address='目黒区下目黒１丁目８番１号アルコタワー７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010003026609',
    ),
    'E33784': EdinetCodeEntry(
        edinet_code='E33784',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=318,
        fiscal_year_end='1月31日',
        submitter_name='株式会社Ｍマート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムマート',
        address='新宿区西新宿六丁目５番１号',
        industry='情報・通信業',
        sec_code='43800',
        corporate_number='8011101033863',
    ),
    'E33786': EdinetCodeEntry(
        edinet_code='E33786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='日本投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホントウシカブシキカイシャ',
        address='港区南青山二丁目２番１５号ウィン青山３１２号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001179593',
    ),
    'E33789': EdinetCodeEntry(
        edinet_code='E33789',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡本\u3000祥治',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000ナガハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33790': EdinetCodeEntry(
        edinet_code='E33790',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=551,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リグア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリグア',
        address='大阪市中央区淡路町二丁目６番６号\u3000淡路町パークビル２号館',
        industry='サービス業',
        sec_code='70900',
        corporate_number='7120001108848',
    ),
    'E33793': EdinetCodeEntry(
        edinet_code='E33793',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='株式会社Ｅ－ＢＯＮＤホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイーボンドホールディングス',
        address='北葛飾郡松伏町築比地７９５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2030001067331',
    ),
    'E33794': EdinetCodeEntry(
        edinet_code='E33794',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1995,
        fiscal_year_end='3月31日',
        submitter_name='神戸天然物化学株式会社',
        submitter_name_en='KNC Laboratories Co., Ltd.',
        submitter_name_yomi='コウベテンネンブツカガクカブシキガイシャ',
        address='神戸市中央区港島南町七丁目１番地の１９',
        industry='サービス業',
        sec_code='65680',
        corporate_number='3140001022497',
    ),
    'E33800': EdinetCodeEntry(
        edinet_code='E33800',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1485,
        fiscal_year_end='5月31日',
        submitter_name='ジェイフロンティア株式会社',
        submitter_name_en='J Frontier Co.,Ltd.',
        submitter_name_yomi='ジェイフロンティアカブシキガイシャ',
        address='渋谷区渋谷二丁目９番９号',
        industry='情報・通信業',
        sec_code='29340',
        corporate_number='9011001063340',
    ),
    'E33807': EdinetCodeEntry(
        edinet_code='E33807',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1146,
        fiscal_year_end='8月31日',
        submitter_name='バリュエンスホールディングス株式会社',
        submitter_name_en='Valuence Holdings Inc.',
        submitter_name_yomi='バリュエンスホールディングスカブシキカイシャ',
        address='港区南青山五丁目６番１９号\u3000ＭＡ５',
        industry='卸売業',
        sec_code='92700',
        corporate_number='6120001168182',
    ),
    'E33812': EdinetCodeEntry(
        edinet_code='E33812',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3666,
        fiscal_year_end=None,
        submitter_name='株式会社ザイマックスグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャザイマックスグループ',
        address='港区赤坂一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401072742',
    ),
    'E33814': EdinetCodeEntry(
        edinet_code='E33814',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蜂谷\u3000二郎',
        submitter_name_en=None,
        submitter_name_yomi='ハチヤ\u3000ジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33815': EdinetCodeEntry(
        edinet_code='E33815',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2006,
        fiscal_year_end='3月31日',
        submitter_name='日総工産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッソウコウサンカブシキカイシャ',
        address='横浜市港北区新横浜一丁目４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='6020001030402',
    ),
    'E33817': EdinetCodeEntry(
        edinet_code='E33817',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＳＩＮＯ\u3000ＲＩＣＨＥＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='サイノーリッチーズリミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000ＩＩ，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000ＶＧ１１１０，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33818': EdinetCodeEntry(
        edinet_code='E33818',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2400,
        fiscal_year_end=None,
        submitter_name='アムンディ・ルクセンブルク・エス・エー',
        submitter_name_en=None,
        submitter_name_yomi='アムンディルクセンブルクエスエー',
        address='ルクセンブルク大公国、ルクセンブルクＬ－２５２０、アレ・シャファー５番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33819': EdinetCodeEntry(
        edinet_code='E33819',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=681,
        fiscal_year_end='3月末日',
        submitter_name='株式会社フェイスネットワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフェイスネットワーク',
        address='渋谷区千駄ヶ谷三丁目２番１号',
        industry='不動産業',
        sec_code='34890',
        corporate_number='6013201013986',
    ),
    'E33822': EdinetCodeEntry(
        edinet_code='E33822',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=709,
        fiscal_year_end='3月31日',
        submitter_name='株式会社共和コーポレーション',
        submitter_name_en='Kyowa Corporation',
        submitter_name_yomi='カブシキカイシャキョウワコーポレーション',
        address='長野市若里三丁目１０番２８号',
        industry='サービス業',
        sec_code='65700',
        corporate_number='1100001000797',
    ),
    'E33823': EdinetCodeEntry(
        edinet_code='E33823',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉岡\u3000慧治',
        submitter_name_en=None,
        submitter_name_yomi='ヨシオカ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33825': EdinetCodeEntry(
        edinet_code='E33825',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=540,
        fiscal_year_end='3月31日',
        submitter_name='ビープラッツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビープラッツカブシキガイシャ',
        address='千代田区神田練塀町３番地',
        industry='情報・通信業',
        sec_code='43810',
        corporate_number='6010001119584',
    ),
    'E33832': EdinetCodeEntry(
        edinet_code='E33832',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='原地所株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハラジショカブシキガイシャ',
        address='横浜市中区山下町１１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020001028423',
    ),
    'E33834': EdinetCodeEntry(
        edinet_code='E33834',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='信和株式会社',
        submitter_name_en='Shinwa Co., Ltd.',
        submitter_name_yomi='シンワカブシキガイシャ',
        address='海津市平田町仏師川字村中３０番７',
        industry='金属製品',
        sec_code='34470',
        corporate_number='9010001162433',
    ),
    'E33838': EdinetCodeEntry(
        edinet_code='E33838',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1337,
        fiscal_year_end='6月30日',
        submitter_name='キュービーネットホールディングス株式会社',
        submitter_name_en='QB Net Holdings Co.,Ltd.',
        submitter_name_yomi='キュービーネットホールディングスカブシキカイシャ',
        address='渋谷区神泉町８番１６号',
        industry='サービス業',
        sec_code='65710',
        corporate_number='6010001163541',
    ),
    'E33839': EdinetCodeEntry(
        edinet_code='E33839',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=494,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ファイバーゲート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャファイバーゲート',
        address='札幌市中央区南一条西八丁目１０－３\u3000第２８桂和ビル４階',
        industry='情報・通信業',
        sec_code='94500',
        corporate_number='7430001029022',
    ),
    'E33840': EdinetCodeEntry(
        edinet_code='E33840',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8375,
        fiscal_year_end='3月31日',
        submitter_name='ＳＢＩインシュアランスグループ株式会社',
        submitter_name_en='SBI Insurance Group Co., Ltd.',
        submitter_name_yomi='エスビーアイインシュアランスグループカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='保険業',
        sec_code='73260',
        corporate_number='6010401128870',
    ),
    'E33841': EdinetCodeEntry(
        edinet_code='E33841',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33845': EdinetCodeEntry(
        edinet_code='E33845',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='猪又\u3000將哲',
        submitter_name_en=None,
        submitter_name_yomi='イノマタ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33850': EdinetCodeEntry(
        edinet_code='E33850',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='キング・テラス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='キング\u3000テラス\u3000リミテッド',
        address='英領ヴァージン諸島、ＶＧ１１１０、トルトラ、ロード・タウン、ウィックハムズ・ケイ２、ヴィストラ・コーポレート・サービシズ・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33853': EdinetCodeEntry(
        edinet_code='E33853',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='9月末日',
        submitter_name='株式会社レモンガスふくおか',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャレモンガスフクオカ',
        address='大野城市御笠川６－２－２０',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='9290001041304',
    ),
    'E33854': EdinetCodeEntry(
        edinet_code='E33854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=211,
        fiscal_year_end='6月30日',
        submitter_name='Ｓｏｌｖｖｙ株式会社',
        submitter_name_en='Solvvy Inc.',
        submitter_name_yomi='ソルヴィーカブシキガイシャ',
        address='東京都新宿区西新宿四丁目３３番４号',
        industry='その他金融業',
        sec_code='73200',
        corporate_number='9011001061773',
    ),
    'E33855': EdinetCodeEntry(
        edinet_code='E33855',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000梨絵',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000リエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33856': EdinetCodeEntry(
        edinet_code='E33856',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='紀陽興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キヨウコウサンカブシキカイシャ',
        address='和歌山市中之島２２４９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4170001000912',
    ),
    'E33857': EdinetCodeEntry(
        edinet_code='E33857',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='エイシオン\u3000パートナーズ\u3000リミテッド（Ａｃｉｏｎ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｌｉｍｉｔｅｄ）',
        submitter_name_en=None,
        submitter_name_yomi='エイシオン\u3000パートナーズ\u3000リミテッド',
        address='香港、サイバーポートロード１００、サイバーポート１、７階、７１６－７１７（Ｕｎｉｔｓ\u3000７１６－７１７，Ｌｅｖｅｌ７，Ｃｙｂｅｒｐｏｒｔ１，１００Ｃｙｂｅｒｐｏｒｔ\u3000Ｒｏａｄ，Ｈｏｎｇ\u3000Ｋｏｎｇ）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33858': EdinetCodeEntry(
        edinet_code='E33858',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='12月末日',
        submitter_name='株式会社和心',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワゴコロ',
        address='渋谷区千駄ヶ谷３－２０－１２',
        industry='小売業',
        sec_code='92710',
        corporate_number='6011001072625',
    ),
    'E33863': EdinetCodeEntry(
        edinet_code='E33863',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=169,
        fiscal_year_end='2月末日',
        submitter_name='株式会社アズ企画設計',
        submitter_name_en='Azplanning Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアズキカクセッケイ',
        address='川口市戸塚二丁目１２番２０号',
        industry='不動産業',
        sec_code='34900',
        corporate_number='9030001073546',
    ),
    'E33864': EdinetCodeEntry(
        edinet_code='E33864',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コンヴァノ',
        submitter_name_en='Convano Inc.',
        submitter_name_yomi='カブシキガイシャコンヴァノ',
        address='渋谷区桜丘町２２－１４\u3000Ｎ．Ｅ．Ｓ．ビルＳ棟Ｂ３Ｆ',
        industry='サービス業',
        sec_code='65740',
        corporate_number='8011001095822',
    ),
    'E33865': EdinetCodeEntry(
        edinet_code='E33865',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='徳力基彦',
        submitter_name_en=None,
        submitter_name_yomi='トクリキモトヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33866': EdinetCodeEntry(
        edinet_code='E33866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上田\u3000怜史',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33868': EdinetCodeEntry(
        edinet_code='E33868',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=443,
        fiscal_year_end='12月31日',
        submitter_name='ＣＲＡＶＩＡ株式会社',
        submitter_name_en='CRAVIA Inc.',
        submitter_name_yomi='クラヴィアカブシキガイシャ',
        address='港区芝大門二丁目３番６号',
        industry='サービス業',
        sec_code='65730',
        corporate_number='6011001056801',
    ),
    'E33877': EdinetCodeEntry(
        edinet_code='E33877',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='磯崎\u3000功典',
        submitter_name_en=None,
        submitter_name_yomi='イソザキ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33878': EdinetCodeEntry(
        edinet_code='E33878',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ヤマエ第一食栄会\u3000理事長\u3000布施\u3000孝之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマエダイイチショクエイカイ\u3000リジチョウ\u3000フセ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33880': EdinetCodeEntry(
        edinet_code='E33880',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=111,
        fiscal_year_end='4月末日',
        submitter_name='ＨＥＲＯＺ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒーローズカブシキガイシャ',
        address='港区芝五丁目３１番１７号ＰＭＯ田町２Ｆ',
        industry='情報・通信業',
        sec_code='43820',
        corporate_number='7010401081739',
    ),
    'E33881': EdinetCodeEntry(
        edinet_code='E33881',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5881,
        fiscal_year_end='2月末日',
        submitter_name='オープングループ株式会社',
        submitter_name_en='OPEN Group, Inc.',
        submitter_name_yomi='オープングループカブシキガイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='サービス業',
        sec_code='65720',
        corporate_number='1010401098870',
    ),
    'E33882': EdinetCodeEntry(
        edinet_code='E33882',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=259,
        fiscal_year_end='3月31日',
        submitter_name='ブティックス株式会社',
        submitter_name_en='Boutiques, Inc.',
        submitter_name_yomi='ブティックスカブシキガイシャ',
        address='港区三田１－４－２８',
        industry='小売業',
        sec_code='92720',
        corporate_number='7010701023374',
    ),
    'E33883': EdinetCodeEntry(
        edinet_code='E33883',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人京都青少年育成スポーツ財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンキョウトセイショウネンイクセイスポーツザイダン',
        address='京都市下京区東洞院通綾小路下ル扇酒屋町２８９番地デ・リードビル２０４号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1130005002952',
    ),
    'E33885': EdinetCodeEntry(
        edinet_code='E33885',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='前田\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33887': EdinetCodeEntry(
        edinet_code='E33887',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若濵\u3000久',
        submitter_name_en=None,
        submitter_name_yomi='ワカハマ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33890': EdinetCodeEntry(
        edinet_code='E33890',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔｒｙｆｕｎｄｓ\u3000Ｉｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトライファンズインベストメント',
        address='港区芝三丁目１番１４号芝公園阪神ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401135054',
    ),
    'E33891': EdinetCodeEntry(
        edinet_code='E33891',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='ＳＦプロパティマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエフプロパティマネジメントカブシキガイシャ',
        address='港区港南二丁目１５番１号品川インターシティＡ棟２８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001187191',
    ),
    'E33892': EdinetCodeEntry(
        edinet_code='E33892',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='嵜本\u3000晋輔',
        submitter_name_en=None,
        submitter_name_yomi='サキモト\u3000シンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33893': EdinetCodeEntry(
        edinet_code='E33893',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12426,
        fiscal_year_end=None,
        submitter_name='阪急阪神不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハンキュウハンシンフドウサンカブシキカイシャ',
        address='大阪市北区芝田一丁目１番４号\u3000阪急ターミナルビル内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001059681',
    ),
    'E33895': EdinetCodeEntry(
        edinet_code='E33895',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='林\u3000隆弘',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33896': EdinetCodeEntry(
        edinet_code='E33896',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000知裕',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33898': EdinetCodeEntry(
        edinet_code='E33898',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=305393,
        fiscal_year_end='4月末日',
        submitter_name='ネットアップ・インク',
        submitter_name_en=None,
        submitter_name_yomi='ネットアップ\u3000インク',
        address='３０６０\u3000Ｏｌｓｅｎ\u3000Ｄｒｉｖｅ，\u3000Ｓａｎ\u3000Ｊｏｓｅ，\u3000Ｃａｌｉｆｏｒｎｉａ\u3000９５１２８，\u3000Ｕｎｉｔｅｄ\u3000Ｓｔａｔｅｓ',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E33899': EdinetCodeEntry(
        edinet_code='E33899',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='広瀬\u3000克利',
        submitter_name_en=None,
        submitter_name_yomi='ヒロセ\u3000カツトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33900': EdinetCodeEntry(
        edinet_code='E33900',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='ＫＮＣ興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケーエヌシーコウサンカブシキガイシャ',
        address='神戸市西区美賀多台二丁目１２番地の７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001030681',
    ),
    'E33901': EdinetCodeEntry(
        edinet_code='E33901',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮内\u3000仁志',
        submitter_name_en=None,
        submitter_name_yomi='ミヤウチ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33903': EdinetCodeEntry(
        edinet_code='E33903',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=175,
        fiscal_year_end='3月31日',
        submitter_name='ヒューマン・アソシエイツ・ホールディングス株式会社',
        submitter_name_en='HUMAN ASSOCIATES HOLDINGS, Inc.',
        submitter_name_yomi='ヒューマンアソシエイツホールディングスカブシキガイシャ',
        address='港区南青山一丁目３番３号\u3000青山一丁目タワー４階',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010401025296',
    ),
    'E33904': EdinetCodeEntry(
        edinet_code='E33904',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社鹿児島東インド会社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカゴシマヒガシインドガイシャ',
        address='大島郡大和村国直２６４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010402031539',
    ),
    'E33906': EdinetCodeEntry(
        edinet_code='E33906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33910': EdinetCodeEntry(
        edinet_code='E33910',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=216,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ニッソウ',
        submitter_name_en='Nissou Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニッソウ',
        address='世田谷区経堂１－８－１７',
        industry='建設業',
        sec_code='14440',
        corporate_number='3010901009251',
    ),
    'E33912': EdinetCodeEntry(
        edinet_code='E33912',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=750,
        fiscal_year_end=None,
        submitter_name='日本生命第１回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイイッカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001189543',
    ),
    'E33922': EdinetCodeEntry(
        edinet_code='E33922',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＵＢＳ（Ｉｒｌ）ＥＴＦ\u3000ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスアイアールエルイーティーエフピーエルシー',
        address='アイルランド共和国、ダブリン２、アールスフォート・テラス５、２階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33923': EdinetCodeEntry(
        edinet_code='E33923',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＥＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシード',
        address='渋谷区恵比寿西一丁目１４番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001099997',
    ),
    'E33924': EdinetCodeEntry(
        edinet_code='E33924',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='インテグラル・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インテグラル\u3000パートナーズカブシキガイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001144777',
    ),
    'E33925': EdinetCodeEntry(
        edinet_code='E33925',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3617,
        fiscal_year_end=None,
        submitter_name='キヤノンＩＴソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キヤノンアイティソリューションズカブシキカイシャ',
        address='東京都港区港南２－１６－６\u3000キヤノンＳタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010701025982',
    ),
    'E33927': EdinetCodeEntry(
        edinet_code='E33927',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='津村\u3000尚史',
        submitter_name_en=None,
        submitter_name_yomi='ツムラ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33928': EdinetCodeEntry(
        edinet_code='E33928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52,
        fiscal_year_end='2月末日',
        submitter_name='株式会社コレックホールディングス',
        submitter_name_en='CORREC HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャコレックホールディングス',
        address='豊島区南池袋２丁目３２番４号',
        industry='サービス業',
        sec_code='65780',
        corporate_number='2013301031289',
    ),
    'E33929': EdinetCodeEntry(
        edinet_code='E33929',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉野\u3000公亮',
        submitter_name_en=None,
        submitter_name_yomi='スギノ\u3000コウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33935': EdinetCodeEntry(
        edinet_code='E33935',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3315,
        fiscal_year_end='3月末日',
        submitter_name='アイペット損害保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイペットソンガイホケンカブシキガイシャ',
        address='港区六本木一丁目８番７号',
        industry='保険業',
        sec_code=None,
        corporate_number='6010001087807',
    ),
    'E33938': EdinetCodeEntry(
        edinet_code='E33938',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森\u3000智宏',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33943': EdinetCodeEntry(
        edinet_code='E33943',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ガルフ・ジャパン１',
        submitter_name_en=None,
        submitter_name_yomi='ガルフジャパンワン',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ウグランドハウス私書箱３０９、メイプルズ・コーポレート・サービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33948': EdinetCodeEntry(
        edinet_code='E33948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=396,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ベストワンドットコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベストワンドットコム',
        address='新宿区富久町１６番６号',
        industry='サービス業',
        sec_code='65770',
        corporate_number='9011001045578',
    ),
    'E33957': EdinetCodeEntry(
        edinet_code='E33957',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1084,
        fiscal_year_end='2月末日',
        submitter_name='ウイングアーク１ｓｔ株式会社',
        submitter_name_en='WingArc1st Inc.',
        submitter_name_yomi='ウイングアークファーストカブシキガイシャ',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='44320',
        corporate_number='9010001174206',
    ),
    'E33958': EdinetCodeEntry(
        edinet_code='E33958',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ティー・ロウ・プライス・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティロウプライスジャパンカブシキカイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001185795',
    ),
    'E33959': EdinetCodeEntry(
        edinet_code='E33959',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本\u3000俊人',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000トシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33961': EdinetCodeEntry(
        edinet_code='E33961',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮本\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33966': EdinetCodeEntry(
        edinet_code='E33966',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2798,
        fiscal_year_end='7月31日',
        submitter_name='ラクスル株式会社',
        submitter_name_en='RAKSUL INC.',
        submitter_name_yomi='ラクスルカブシキガイシャ',
        address='品川区上大崎二丁目２４番９号',
        industry='情報・通信業',
        sec_code='43840',
        corporate_number='9010401089631',
    ),
    'E33968': EdinetCodeEntry(
        edinet_code='E33968',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='ゴーディアン・キャピタル・シンガポール・プライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ゴーディアンキャピタルシンガポールプライベートリミテッド',
        address='シンガポール０６９５３６、セシル・ストリート１３５、フィリピン・エアラインズ・ビルディング＃１２－０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33969': EdinetCodeEntry(
        edinet_code='E33969',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クシムインサイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクシムインサイト',
        address='港区南青山二丁目１２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001119364',
    ),
    'E33970': EdinetCodeEntry(
        edinet_code='E33970',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000唯雄',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000タダオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33977': EdinetCodeEntry(
        edinet_code='E33977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平田\u3000一久',
        submitter_name_en=None,
        submitter_name_yomi='ヒラタ\u3000カズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33978': EdinetCodeEntry(
        edinet_code='E33978',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大角\u3000暢之',
        submitter_name_en=None,
        submitter_name_yomi='オオスミ\u3000ノブユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33979': EdinetCodeEntry(
        edinet_code='E33979',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000知道',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000トモミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33987': EdinetCodeEntry(
        edinet_code='E33987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡部\u3000昭彦',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33988': EdinetCodeEntry(
        edinet_code='E33988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神澤\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='カミサワ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33989': EdinetCodeEntry(
        edinet_code='E33989',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=106,
        fiscal_year_end=None,
        submitter_name='ステート・ストリート・グローバル・アドバイザーズ・トラスト・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ステートストリートグローバルアドバイザーズトラストカンパニー',
        address='米国\u3000０２２１０\u3000マサチューセッツ州\u3000ボストン\u3000アイロン・ストリート\u3000ワン',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33990': EdinetCodeEntry(
        edinet_code='E33990',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7827416,
        fiscal_year_end=None,
        submitter_name='バンガード・ウェルズリー・インカム・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='バンガードウェルズリーインカムファンド',
        address='アメリカ合衆国１９３５５\u3000ペンシルバニア州\u3000マルバーン市\u3000バンガード・ブルーヴァード１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33993': EdinetCodeEntry(
        edinet_code='E33993',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='遠南企業股分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ユエンナンチイエグフェンヨウシェンコンス',
        address='台湾台北市信義區信義路６段３５號３樓',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33994': EdinetCodeEntry(
        edinet_code='E33994',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新村\u3000祐三',
        submitter_name_en=None,
        submitter_name_yomi='シンムラ\u3000ユウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33996': EdinetCodeEntry(
        edinet_code='E33996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='安達\u3000慶高',
        submitter_name_en=None,
        submitter_name_yomi='アダチ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33997': EdinetCodeEntry(
        edinet_code='E33997',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹林\u3000俊介',
        submitter_name_en=None,
        submitter_name_yomi='タケバヤシ\u3000シュンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E33998': EdinetCodeEntry(
        edinet_code='E33998',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉川淳史',
        submitter_name_en=None,
        submitter_name_yomi='ヨシカワアツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34000': EdinetCodeEntry(
        edinet_code='E34000',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森永\u3000秀一',
        submitter_name_en=None,
        submitter_name_yomi='モリナガ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34006': EdinetCodeEntry(
        edinet_code='E34006',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=250000,
        fiscal_year_end='3月31日',
        submitter_name='大阪市高速電気軌道株式会社',
        submitter_name_en='Osaka Metro Co., Ltd.',
        submitter_name_yomi='オオサカシコウソクデンキキドウカブシキガイシャ',
        address='大阪市西区九条南一丁目１２番６２号',
        industry='陸運業',
        sec_code=None,
        corporate_number='6120001206256',
    ),
    'E34007': EdinetCodeEntry(
        edinet_code='E34007',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='坂本\u3000和久',
        submitter_name_en=None,
        submitter_name_yomi='サカモト\u3000カズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34010': EdinetCodeEntry(
        edinet_code='E34010',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荒川拓也',
        submitter_name_en=None,
        submitter_name_yomi='アラカワタクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34018': EdinetCodeEntry(
        edinet_code='E34018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=386,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ライトアップ',
        submitter_name_en='Writeup Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャライトアップ',
        address='渋谷区渋谷二丁目１５番１号',
        industry='情報・通信業',
        sec_code='65800',
        corporate_number='1011001041171',
    ),
    'E34023': EdinetCodeEntry(
        edinet_code='E34023',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リヴァンプ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリヴァンプ',
        address='港区北青山２－１２－１６北青山吉川ビル３Ｆ',
        industry='サービス業',
        sec_code=None,
        corporate_number='4010401059044',
    ),
    'E34025': EdinetCodeEntry(
        edinet_code='E34025',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ディーエフ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディーエフ',
        address='瀬戸市内田町一丁目２９６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001121291',
    ),
    'E34028': EdinetCodeEntry(
        edinet_code='E34028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=32,
        fiscal_year_end='9月末日',
        submitter_name='株式会社アミファ',
        submitter_name_en='Amifa Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアミファ',
        address='港区北青山二丁目１３番５号',
        industry='卸売業',
        sec_code='78000',
        corporate_number='1010001110663',
    ),
    'E34030': EdinetCodeEntry(
        edinet_code='E34030',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=41,
        fiscal_year_end=None,
        submitter_name='Ｈｏｎｇｏ\u3000ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホンゴウホールディングスカブシキカイシャ',
        address='新宿区西新宿一丁目２５番１号新宿センタービル３１Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101010418',
    ),
    'E34031': EdinetCodeEntry(
        edinet_code='E34031',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=507,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＳＩＧグループ',
        submitter_name_en='SIG Group Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエスアイジーグループ',
        address='千代田区九段北四丁目２番１号',
        industry='情報・通信業',
        sec_code='43860',
        corporate_number='7010001001114',
    ),
    'E34032': EdinetCodeEntry(
        edinet_code='E34032',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中川\u3000善司',
        submitter_name_en=None,
        submitter_name_yomi='ナカガワ\u3000ゼンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34036': EdinetCodeEntry(
        edinet_code='E34036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000英生',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34038': EdinetCodeEntry(
        edinet_code='E34038',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='グレート・フォーチュン・インターナショナル・ディベロップメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='グレートフォーチュンインターナショナルディベロップメントリミテッド',
        address='ケイマン諸島、グランド・ケイマン\u3000ＫＹ１－１２０５、ウェスト・ベイ・ロード８０２、ハイビスカス・ウェイ、グランド・パビリオン、私書箱３１１１９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34039': EdinetCodeEntry(
        edinet_code='E34039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤田\u3000秀太',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000ヒデタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34040': EdinetCodeEntry(
        edinet_code='E34040',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=891,
        fiscal_year_end=None,
        submitter_name='Ｒ\u3000ＦＩＮＡＮＣＩＡＬ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='アール\u3000フィナンシャル\u3000インベストメント\u3000ピーティーイー\u3000エルティーディー',
        address='３２８\u3000ノースブリッジロード\u3000＃０２－２０\u3000ラッフルズショッピングアーケード\u3000シンガポール\u3000１８８７１９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34042': EdinetCodeEntry(
        edinet_code='E34042',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷本\u3000隆廣',
        submitter_name_en=None,
        submitter_name_yomi='タニモト\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34044': EdinetCodeEntry(
        edinet_code='E34044',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＶａｌｕｅＡｃｔ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｓｔｅｒ\u3000Ｆｕｎｄ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='バリューアクトキャピタルマスターファンドエルピー',
        address='イギリス領バージン諸島、トルトラ島、ロード・タウン、私書箱７１、クレイグミュール・チェンバーズ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34045': EdinetCodeEntry(
        edinet_code='E34045',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=73,
        fiscal_year_end='6月30日',
        submitter_name='ロジザード株式会社',
        submitter_name_en='Logizard Co.,Ltd.',
        submitter_name_yomi='ロジザードカブシキカイシャ',
        address='中央区日本橋人形町三丁目３番６号',
        industry='情報・通信業',
        sec_code='43910',
        corporate_number='1010401053173',
    ),
    'E34047': EdinetCodeEntry(
        edinet_code='E34047',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米山\u3000実香',
        submitter_name_en=None,
        submitter_name_yomi='ヨネヤマ\u3000ミカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34051': EdinetCodeEntry(
        edinet_code='E34051',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=33,
        fiscal_year_end=None,
        submitter_name='株式会社實業之日本社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジツギョウノニホンシャ',
        address='港区南青山六丁目６番２２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001046252',
    ),
    'E34052': EdinetCodeEntry(
        edinet_code='E34052',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=143,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エーアイ',
        submitter_name_en='AI,Inc.',
        submitter_name_yomi='カブシキガイシャエーアイ',
        address='文京区西片一丁目１５番１５号',
        industry='情報・通信業',
        sec_code='43880',
        corporate_number='8010001127602',
    ),
    'E34053': EdinetCodeEntry(
        edinet_code='E34053',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1422,
        fiscal_year_end='9月30日',
        submitter_name='株式会社スプリックス',
        submitter_name_en='SPRIX, Ltd.',
        submitter_name_yomi='カブシキガイシャスプリックス',
        address='長岡市東坂之上町二丁目２番地１',
        industry='サービス業',
        sec_code='70300',
        corporate_number='7110001022686',
    ),
    'E34054': EdinetCodeEntry(
        edinet_code='E34054',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16776,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＭＴＧ',
        submitter_name_en='MTG Co., Ltd.',
        submitter_name_yomi='カブシキカイシャエムティージー',
        address='名古屋市中村区本陣通２丁目３２番',
        industry='その他製品',
        sec_code='78060',
        corporate_number='6180001051390',
    ),
    'E34055': EdinetCodeEntry(
        edinet_code='E34055',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30623,
        fiscal_year_end=None,
        submitter_name='ブローニング・アームズ・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='ブローニング\u3000アームズ\u3000カンパニー',
        address='アメリカ合衆国、ユタ州８４０５０、モーガン、ブローニングプレイス\u3000１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34064': EdinetCodeEntry(
        edinet_code='E34064',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=47874,
        fiscal_year_end='6月30日',
        submitter_name='株式会社メルカリ',
        submitter_name_en='Mercari, Inc.',
        submitter_name_yomi='カブシキカイシャメルカリ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー１８階',
        industry='情報・通信業',
        sec_code='43850',
        corporate_number='6010701027558',
    ),
    'E34065': EdinetCodeEntry(
        edinet_code='E34065',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1236,
        fiscal_year_end='3月31日',
        submitter_name='ダイヤモンドエレクトリックホールディングス株式会社',
        submitter_name_en='DIAMOND ELECTRIC HOLDINGS CO.,LTD.',
        submitter_name_yomi='ダイヤモンドエレクトリックホールディングスカブシキガイシャ',
        address='大阪市淀川区塚本一丁目１５番２７号',
        industry='電気機器',
        sec_code='66990',
        corporate_number='4120001216273',
    ),
    'E34067': EdinetCodeEntry(
        edinet_code='E34067',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本\u3000恭攝',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000ヤスカネ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34069': EdinetCodeEntry(
        edinet_code='E34069',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=190,
        fiscal_year_end=None,
        submitter_name='株式会社グローバルキャスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグローバルキャスト',
        address='名古屋市中村区平池町４－６０ー１２グローバルゲート１４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180001078253',
    ),
    'E34070': EdinetCodeEntry(
        edinet_code='E34070',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=36,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インバウンドテック',
        submitter_name_en='Inbound Tech Inc.',
        submitter_name_yomi='カブシキカイシャインバウンドテック',
        address='新宿区新宿二丁目３番１３号\u3000大橋ビル',
        industry='サービス業',
        sec_code='70310',
        corporate_number='4011101072956',
    ),
    'E34071': EdinetCodeEntry(
        edinet_code='E34071',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='6月末日',
        submitter_name='コーア商事ホールディングス株式会社',
        submitter_name_en='KOA SHOJI HOLDINGS CO.,LTD.',
        submitter_name_yomi='コーアショウジホールディングスカブシキカイシャ',
        address='横浜市港北区日吉七丁目１３－１５',
        industry='医薬品',
        sec_code='92730',
        corporate_number='6020001109452',
    ),
    'E34073': EdinetCodeEntry(
        edinet_code='E34073',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木下\u3000紀夫',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34074': EdinetCodeEntry(
        edinet_code='E34074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栗林\u3000憲介',
        submitter_name_en=None,
        submitter_name_yomi='クリバヤシ\u3000ケンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34075': EdinetCodeEntry(
        edinet_code='E34075',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栗林\u3000圭介',
        submitter_name_en=None,
        submitter_name_yomi='クリバヤシ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34082': EdinetCodeEntry(
        edinet_code='E34082',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=407,
        fiscal_year_end='3月31日',
        submitter_name='ログリー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ログリーカブシキガイシャ',
        address='渋谷区恵比寿一丁目１９番１５号',
        industry='サービス業',
        sec_code='65790',
        corporate_number='9010001121488',
    ),
    'E34083': EdinetCodeEntry(
        edinet_code='E34083',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=87255,
        fiscal_year_end=None,
        submitter_name='ＭＩＲＡＲＴＨ不動産投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ミラースフドウサントウシホウジン',
        address='千代田区大手町二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405016072',
    ),
    'E34084': EdinetCodeEntry(
        edinet_code='E34084',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹内\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34088': EdinetCodeEntry(
        edinet_code='E34088',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下大薗\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='シモオオゾノ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34090': EdinetCodeEntry(
        edinet_code='E34090',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=332,
        fiscal_year_end='3月31日',
        submitter_name='プロパティデータバンク株式会社',
        submitter_name_en='Property Data Bank,Inc.',
        submitter_name_yomi='プロパティデータバンクカブシキガイシャ',
        address='港区浜松町一丁目３０番５号',
        industry='情報・通信業',
        sec_code='43890',
        corporate_number='7010401042534',
    ),
    'E34091': EdinetCodeEntry(
        edinet_code='E34091',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=275,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アクリート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアクリート',
        address='千代田区神田小川町三丁目２８番５号',
        industry='情報・通信業',
        sec_code='43950',
        corporate_number='1010901034136',
    ),
    'E34094': EdinetCodeEntry(
        edinet_code='E34094',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=467,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＺＵＵ',
        submitter_name_en='ZUU Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャ',
        address='港区麻布台一丁目３番１号',
        industry='サービス業',
        sec_code='43870',
        corporate_number='4011001094365',
    ),
    'E34095': EdinetCodeEntry(
        edinet_code='E34095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=561,
        fiscal_year_end='9月末日',
        submitter_name='株式会社キャンディル',
        submitter_name_en='CANDEAL Co., Ltd.',
        submitter_name_yomi='カブシキガイシャキャンディル',
        address='新宿区北山伏町１番１１号',
        industry='建設業',
        sec_code='14460',
        corporate_number='6010001162361',
    ),
    'E34097': EdinetCodeEntry(
        edinet_code='E34097',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=610,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サン・ライフホールディング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンライフホールディング',
        address='平塚市馬入本町１３番１１号',
        industry='サービス業',
        sec_code='70400',
        corporate_number='4021001065753',
    ),
    'E34098': EdinetCodeEntry(
        edinet_code='E34098',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000直',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ナオシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34099': EdinetCodeEntry(
        edinet_code='E34099',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=63,
        fiscal_year_end=None,
        submitter_name='株式会社ひかりホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒカリホールディングス',
        address='多治見市笠原町１２２３番地１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4200001032051',
    ),
    'E34102': EdinetCodeEntry(
        edinet_code='E34102',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='ブックオフグループホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブックオフグループホールディングスカブシキガイシャ',
        address='相模原市南区古淵二丁目１４番２０号',
        industry='小売業',
        sec_code='92780',
        corporate_number='4021001065745',
    ),
    'E34104': EdinetCodeEntry(
        edinet_code='E34104',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='白石\u3000崇',
        submitter_name_en=None,
        submitter_name_yomi='シライシ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34106': EdinetCodeEntry(
        edinet_code='E34106',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ジェンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェンス',
        address='神戸市東灘区本山南町三丁目５番１０ー３１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001051124',
    ),
    'E34107': EdinetCodeEntry(
        edinet_code='E34107',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000進太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000シンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34109': EdinetCodeEntry(
        edinet_code='E34109',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社スペースバリューホールディングス',
        submitter_name_en='SPACE VALUE HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャスペースバリューホールディングス',
        address='港区芝三丁目４番１２号',
        industry='建設業',
        sec_code=None,
        corporate_number='5220001022512',
    ),
    'E34110': EdinetCodeEntry(
        edinet_code='E34110',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='マルチ・マネージャー・アクセスⅡ',
        submitter_name_en=None,
        submitter_name_yomi='マルチマネージャーアクセスツー',
        address='ルクセンブルグＬ－１８５５、Ｊ．Ｆ．ケネディ通り\u3000３３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34111': EdinetCodeEntry(
        edinet_code='E34111',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=723,
        fiscal_year_end='6月30日',
        submitter_name='株式会社システムサポートホールディングス',
        submitter_name_en='System Support Holdings Inc.',
        submitter_name_yomi='カブシキカイシャシステムサポートホールディングス',
        address='金沢市本町一丁目５番２号リファーレ９階',
        industry='情報・通信業',
        sec_code='43960',
        corporate_number='3220001003282',
    ),
    'E34112': EdinetCodeEntry(
        edinet_code='E34112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='富島\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='トミシマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34113': EdinetCodeEntry(
        edinet_code='E34113',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社第四北越フィナンシャルグループ',
        submitter_name_en='Daishi Hokuetsu Financial Group,Inc.',
        submitter_name_yomi='カブシキガイシャダイシホクエツフィナンシャルグループ',
        address='新潟市中央区東堀前通７番町１０７１番地１',
        industry='銀行業',
        sec_code='73270',
        corporate_number='3110001033555',
    ),
    'E34114': EdinetCodeEntry(
        edinet_code='E34114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=530,
        fiscal_year_end='7月末日',
        submitter_name='ＶＡＬＵＥＮＥＸ株式会社',
        submitter_name_en='VALUENEX JAPAN Inc.',
        submitter_name_yomi='バリューネックスカブシキガイシャ',
        address='文京区小日向四丁目５番１６号',
        industry='情報・通信業',
        sec_code='44220',
        corporate_number='3010001125817',
    ),
    'E34115': EdinetCodeEntry(
        edinet_code='E34115',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小野田\u3000英治',
        submitter_name_en=None,
        submitter_name_yomi='オノダ\u3000ヒデハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34116': EdinetCodeEntry(
        edinet_code='E34116',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=562,
        fiscal_year_end='9月30日',
        submitter_name='株式会社バンク・オブ・イノベーション',
        submitter_name_en='Bank of Innovation, Inc.',
        submitter_name_yomi='カブシキガイシャバンクオブイノベーション',
        address='新宿区新宿六丁目２７番３０号',
        industry='情報・通信業',
        sec_code='43930',
        corporate_number='1011101050080',
    ),
    'E34118': EdinetCodeEntry(
        edinet_code='E34118',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石原\u3000千雅',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000カズマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34119': EdinetCodeEntry(
        edinet_code='E34119',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='倉地\u3000太',
        submitter_name_en=None,
        submitter_name_yomi='クラチ\u3000フトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34120': EdinetCodeEntry(
        edinet_code='E34120',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='倉地\u3000猛',
        submitter_name_en=None,
        submitter_name_yomi='クラチ\u3000タケル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34121': EdinetCodeEntry(
        edinet_code='E34121',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='楠野\u3000寿也',
        submitter_name_en=None,
        submitter_name_yomi='クスノ\u3000トシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34130': EdinetCodeEntry(
        edinet_code='E34130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=130,
        fiscal_year_end='12月末日',
        submitter_name='株式会社イボキン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイボキン',
        address='たつの市揖保川町正條３７９番地',
        industry='サービス業',
        sec_code='56990',
        corporate_number='1140001038603',
    ),
    'E34131': EdinetCodeEntry(
        edinet_code='E34131',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000克実',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000カツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34134': EdinetCodeEntry(
        edinet_code='E34134',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＨＳ興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスコウサンカブシキガイシャ',
        address='神戸市中央区雲井通二丁目１番６－１００２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1140001100156',
    ),
    'E34135': EdinetCodeEntry(
        edinet_code='E34135',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='総合メディカルホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソウゴウメディカルホールディングスカブシキガイシャ',
        address='福岡市中央区天神二丁目１４番８号',
        industry='小売業',
        sec_code=None,
        corporate_number='9290001082975',
    ),
    'E34137': EdinetCodeEntry(
        edinet_code='E34137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ベルテクスコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャベルテクスコーポレーション',
        address='千代田区麹町五丁目１番地',
        industry='ガラス・土石製品',
        sec_code='52900',
        corporate_number='4010001195330',
    ),
    'E34138': EdinetCodeEntry(
        edinet_code='E34138',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＶａｌｕｅＡｃｔ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='バリューアクトキャピタルマネジメントエルピー',
        address='アメリカ合衆国、１９８０１、デラウェア州ニューキャッスル郡、ウィルミントン、オレンジストリート１２０９、コーポレーション・トラスト・センター、ザ・コーポレーション・トラスト・カンパニー気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34140': EdinetCodeEntry(
        edinet_code='E34140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=445,
        fiscal_year_end='11月30日',
        submitter_name='株式会社エクスモーション',
        submitter_name_en='eXmotion Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエクスモーション',
        address='品川区大崎２丁目１１番１号',
        industry='情報・通信業',
        sec_code='43940',
        corporate_number='5010401077862',
    ),
    'E34142': EdinetCodeEntry(
        edinet_code='E34142',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=621,
        fiscal_year_end='12月31日',
        submitter_name='株式会社マネジメントソリューションズ',
        submitter_name_en='Management Solutions Co.,Ltd',
        submitter_name_yomi='カブシキガイシャマネジメントソリューションズ',
        address='港区赤坂９丁目７番１号',
        industry='サービス業',
        sec_code='70330',
        corporate_number='9010401062357',
    ),
    'E34144': EdinetCodeEntry(
        edinet_code='E34144',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='冨田\u3000和成',
        submitter_name_en=None,
        submitter_name_yomi='トミタ\u3000カズマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34145': EdinetCodeEntry(
        edinet_code='E34145',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岸本\u3000雅久',
        submitter_name_en=None,
        submitter_name_yomi='キシモト\u3000マサヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34146': EdinetCodeEntry(
        edinet_code='E34146',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='廣飯\u3000伸一',
        submitter_name_en=None,
        submitter_name_yomi='ヒロイ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34147': EdinetCodeEntry(
        edinet_code='E34147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34148': EdinetCodeEntry(
        edinet_code='E34148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2025,
        fiscal_year_end='10月末日',
        submitter_name='株式会社プロレド・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプロレドパートナーズ',
        address='港区芝公園１－１－１\u3000住友不動産御成門タワー７階',
        industry='サービス業',
        sec_code='70340',
        corporate_number='3010401075612',
    ),
    'E34149': EdinetCodeEntry(
        edinet_code='E34149',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柿沼佑一',
        submitter_name_en=None,
        submitter_name_yomi='カキヌマユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34153': EdinetCodeEntry(
        edinet_code='E34153',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='常石\u3000博之',
        submitter_name_en=None,
        submitter_name_yomi='ツネイシ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34154': EdinetCodeEntry(
        edinet_code='E34154',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000大志',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000タイシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34157': EdinetCodeEntry(
        edinet_code='E34157',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34158': EdinetCodeEntry(
        edinet_code='E34158',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='樋口\u3000智裕',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34160': EdinetCodeEntry(
        edinet_code='E34160',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙原\u3000義弘',
        submitter_name_en=None,
        submitter_name_yomi='タカハラ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34163': EdinetCodeEntry(
        edinet_code='E34163',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡本\u3000均',
        submitter_name_en=None,
        submitter_name_yomi='オカモト\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34165': EdinetCodeEntry(
        edinet_code='E34165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1909,
        fiscal_year_end='3月31日',
        submitter_name='ＳＡＡＦホールディングス株式会社',
        submitter_name_en='SAAF Holdings Co., Ltd.',
        submitter_name_yomi='サーフホールディングスカブシキガイシャ',
        address='江東区豊洲三丁目２番２４号',
        industry='建設業',
        sec_code='14470',
        corporate_number='6010001195295',
    ),
    'E34166': EdinetCodeEntry(
        edinet_code='E34166',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片岡\u3000稔喜',
        submitter_name_en=None,
        submitter_name_yomi='カタオカ\u3000ノリヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34167': EdinetCodeEntry(
        edinet_code='E34167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉永\u3000浩和',
        submitter_name_en=None,
        submitter_name_yomi='ヨシナガ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34168': EdinetCodeEntry(
        edinet_code='E34168',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮下\u3000幸治',
        submitter_name_en=None,
        submitter_name_yomi='ミヤシタ\u3000コウジ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34169': EdinetCodeEntry(
        edinet_code='E34169',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石川\u3000純生',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000スミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34172': EdinetCodeEntry(
        edinet_code='E34172',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='首藤\u3000利幸',
        submitter_name_en=None,
        submitter_name_yomi='シュトウ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34173': EdinetCodeEntry(
        edinet_code='E34173',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000秀樹',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34174': EdinetCodeEntry(
        edinet_code='E34174',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福井\u3000道夫',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34177': EdinetCodeEntry(
        edinet_code='E34177',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7272,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＧＡ\u3000ｔｅｃｈｎｏｌｏｇｉｅｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジーエーテクノロジーズ',
        address='港区六本木三丁目２番１号\u3000住友不動産六本木グランドタワー４０階',
        industry='不動産業',
        sec_code='34910',
        corporate_number='9011001093998',
    ),
    'E34179': EdinetCodeEntry(
        edinet_code='E34179',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='杉本\u3000惠昭',
        submitter_name_en=None,
        submitter_name_yomi='スギモト\u3000ヤスアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34191': EdinetCodeEntry(
        edinet_code='E34191',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='株式会社メディカルインキュベータジャパン',
        submitter_name_en=None,
        submitter_name_yomi='メディカルインキュベータジャパン',
        address='港区赤坂一丁目１１番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401138465',
    ),
    'E34192': EdinetCodeEntry(
        edinet_code='E34192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000八郎',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000ハチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34199': EdinetCodeEntry(
        edinet_code='E34199',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='9月30日',
        submitter_name='株式会社くふう住まい',
        submitter_name_en='Kufu Sumai Inc.',
        submitter_name_yomi='カブシキガイシャクフウスマイ',
        address='港区三田一丁目４番２８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='3010401141208',
    ),
    'E34201': EdinetCodeEntry(
        edinet_code='E34201',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=610,
        fiscal_year_end=None,
        submitter_name='明治安田生命２０１８基金特定目的会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイニセンジュウハチキキントクテイモクテキカイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005028686',
    ),
    'E34202': EdinetCodeEntry(
        edinet_code='E34202',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='ゴー・イーティーエフ・ソリューションズ・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='ゴーイーティーエフソリューションズエルエルピー',
        address='英国ＥＣ２Ｒ\u3000５ＡＡ、ロンドン、ワン・コールマン・ストリート',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34205': EdinetCodeEntry(
        edinet_code='E34205',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16,
        fiscal_year_end=None,
        submitter_name='新生クレアシオンパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンセイクレアシオンパートナーズカブシキガイシャ',
        address='中央区日本橋室町二丁目４番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001153708',
    ),
    'E34210': EdinetCodeEntry(
        edinet_code='E34210',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000晃生',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34216': EdinetCodeEntry(
        edinet_code='E34216',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＣＨＩＮ\u3000ＹＥＵ\u3000ＹＡＯ',
        submitter_name_en=None,
        submitter_name_yomi='チン\u3000ユーヤオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34217': EdinetCodeEntry(
        edinet_code='E34217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松下\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='マツシタ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34221': EdinetCodeEntry(
        edinet_code='E34221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='11月30日',
        submitter_name='株式会社フロンティア',
        submitter_name_en='Frontier Inc.',
        submitter_name_yomi='カブシキガイシャフロンティア',
        address='福岡市中央区天神２丁目３番３６号ｉｂｂｆｕｋｕｏｋａ',
        industry='サービス業',
        sec_code='42500',
        corporate_number='8250001010775',
    ),
    'E34223': EdinetCodeEntry(
        edinet_code='E34223',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='ＢＦＡＭ\u3000Ｐａｒｔｎｅｒｓ\u3000（Ｈｏｎｇ\u3000Ｋｏｎｇ）\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ビーファム\u3000パートナーズ\u3000ホンコン\u3000リミテッド',
        address='香港、エレクトリック・ロード１４８、３５階、スイート３５０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34224': EdinetCodeEntry(
        edinet_code='E34224',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月末日',
        submitter_name='フィリピン共和国',
        submitter_name_en=None,
        submitter_name_yomi='フィリピンキョウワコク',
        address='ロハス大通りコーナー、パブロ・オカンポ・シニア通り、マニラ１００４、フィリピン',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E34225': EdinetCodeEntry(
        edinet_code='E34225',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=801,
        fiscal_year_end='8月31日',
        submitter_name='株式会社チームスピリット',
        submitter_name_en='TeamSpirit Inc.',
        submitter_name_yomi='カブシキガイシャチームスピリット',
        address='千代田区内幸町２丁目１番６号\u3000日比谷パークフロント１９階',
        industry='情報・通信業',
        sec_code='43970',
        corporate_number='1010001116826',
    ),
    'E34230': EdinetCodeEntry(
        edinet_code='E34230',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荻島\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='オギシマ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34233': EdinetCodeEntry(
        edinet_code='E34233',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5932200,
        fiscal_year_end='12月31日',
        submitter_name='Ｔｅｓｌａ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='テスラインク',
        address='アメリカ合衆国テキサス州オースティン、テスラ・ロード１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E34234': EdinetCodeEntry(
        edinet_code='E34234',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000紀之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34235': EdinetCodeEntry(
        edinet_code='E34235',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='立石\u3000直孝',
        submitter_name_en=None,
        submitter_name_yomi='タテイシ\u3000ナオタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34238': EdinetCodeEntry(
        edinet_code='E34238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=70,
        fiscal_year_end='8月31日',
        submitter_name='ａｎｄ\u3000ｆａｃｔｏｒｙ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アンドファクトリーカブシキカイシャ',
        address='目黒区青葉台三丁目６番２８号',
        industry='サービス業',
        sec_code='70350',
        corporate_number='7011001102001',
    ),
    'E34245': EdinetCodeEntry(
        edinet_code='E34245',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=136,
        fiscal_year_end=None,
        submitter_name='Ｏｌｄ\u3000Ｐｅａｋ\u3000Ｇｒｏｕｐ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='オールドピークグループリミテッド',
        address='ｃ／ｏ\u3000Ｏｌｄ\u3000Ｐｅａｋ\u3000Ｌｔｄ．，\u3000Ｓｕｉｔｅ\u3000９０１，\u3000９ｔｈ\u3000Ｆｌｏｏｒ，\u3000２８\u3000Ｈｅｎｎｅｓｓｙ\u3000Ｒｏａｄ，\u3000Ｗａｎｃｈａｉ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34247': EdinetCodeEntry(
        edinet_code='E34247',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社レゾンディレクション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャレゾンディレクション',
        address='大阪市中央区北浜２－６－１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140001048523',
    ),
    'E34249': EdinetCodeEntry(
        edinet_code='E34249',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ナルミヤ・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナルミヤインターナショナル',
        address='港区芝公園二丁目４番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='6010001176345',
    ),
    'E34251': EdinetCodeEntry(
        edinet_code='E34251',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='樋口\u3000龍',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34252': EdinetCodeEntry(
        edinet_code='E34252',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000信也',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34254': EdinetCodeEntry(
        edinet_code='E34254',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='ａｕアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーユーアセットマネジメントカブシキガイシャ',
        address='千代田区西神田三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001188789',
    ),
    'E34255': EdinetCodeEntry(
        edinet_code='E34255',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=14021,
        fiscal_year_end=None,
        submitter_name='東京インフラ・エネルギー投資法人',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウインフラエネルギートウシホウジン',
        address='千代田区麹町二丁目３番地\u3000麹町プレイス８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010005027582',
    ),
    'E34256': EdinetCodeEntry(
        edinet_code='E34256',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=345,
        fiscal_year_end='9月30日',
        submitter_name='香陵住販株式会社',
        submitter_name_en='Koryojyuhan Co., Ltd.',
        submitter_name_yomi='コウリョウジュウハンカブシキガイシャ',
        address='水戸市南町二丁目４番３３号',
        industry='不動産業',
        sec_code='34950',
        corporate_number='2050001000950',
    ),
    'E34258': EdinetCodeEntry(
        edinet_code='E34258',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐谷\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='サタニ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34259': EdinetCodeEntry(
        edinet_code='E34259',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000卓司',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タクジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34265': EdinetCodeEntry(
        edinet_code='E34265',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=707,
        fiscal_year_end=None,
        submitter_name='リーガル・アンド・ジェネラル・インベストメント・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='リーガルアンドジェネラルインベストメントマネジメントリミテッド',
        address='英国ＥＣ２Ｒ\u3000５ＡＡ、ロンドン、ワン・コールマン・ストリート',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34268': EdinetCodeEntry(
        edinet_code='E34268',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋元\u3000康',
        submitter_name_en=None,
        submitter_name_yomi='アキモト\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34269': EdinetCodeEntry(
        edinet_code='E34269',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小松\u3000匡',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34270': EdinetCodeEntry(
        edinet_code='E34270',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000一三',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000カズミ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34271': EdinetCodeEntry(
        edinet_code='E34271',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1387,
        fiscal_year_end='9月30日',
        submitter_name='株式会社マリオン',
        submitter_name_en='Mullion Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャマリオン',
        address='新宿区富久町９番１１号',
        industry='不動産業',
        sec_code='34940',
        corporate_number='5011101020237',
    ),
    'E34272': EdinetCodeEntry(
        edinet_code='E34272',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='イーエス・プラットフォーム・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='イーエスプラットフォームエルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランドハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34273': EdinetCodeEntry(
        edinet_code='E34273',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=631,
        fiscal_year_end='9月30日',
        submitter_name='ＫＬＡＳＳ株式会社',
        submitter_name_en='KLASS Corporation',
        submitter_name_yomi='クラスカブシキガイシャ',
        address='たつの市龍野町日飼１９０番地',
        industry='機械',
        sec_code='62330',
        corporate_number='7140001038325',
    ),
    'E34275': EdinetCodeEntry(
        edinet_code='E34275',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋山\u3000龍作',
        submitter_name_en=None,
        submitter_name_yomi='アキヤマ\u3000リュウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34276': EdinetCodeEntry(
        edinet_code='E34276',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=453,
        fiscal_year_end='12月31日',
        submitter_name='株式会社テノ．ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテノホールディングス',
        address='福岡市博多区上呉服町１０番１０号',
        industry='サービス業',
        sec_code='70370',
        corporate_number='2290001072306',
    ),
    'E34279': EdinetCodeEntry(
        edinet_code='E34279',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='オートメックス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オートメックスカブシキカイシャ',
        address='中央区京橋一丁目５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010501031857',
    ),
    'E34281': EdinetCodeEntry(
        edinet_code='E34281',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=694,
        fiscal_year_end='6月末日',
        submitter_name='株式会社アイリックコーポレーション',
        submitter_name_en='IRRC Corporation',
        submitter_name_yomi='カブシキガイシャアイリックコーポレーション',
        address='文京区本郷二丁目２７番２０号',
        industry='保険業',
        sec_code='73250',
        corporate_number='6010001065944',
    ),
    'E34282': EdinetCodeEntry(
        edinet_code='E34282',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='シュバイツェル・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シュバイツェルインベストメントカブシキガイシャ',
        address='千代田区平河町二丁目４番１４号\u3000平河町ＫＳビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001183816',
    ),
    'E34283': EdinetCodeEntry(
        edinet_code='E34283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社大建エンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイケンエンタープライズ',
        address='港区麻布十番二丁目８番１２―９０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401059951',
    ),
    'E34285': EdinetCodeEntry(
        edinet_code='E34285',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=416,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アズーム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアズーム',
        address='渋谷区代々木二丁目１番１号',
        industry='不動産業',
        sec_code='34960',
        corporate_number='9011001062508',
    ),
    'E34288': EdinetCodeEntry(
        edinet_code='E34288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=295,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ブロードバンドセキュリティ',
        submitter_name_en='BroadBand Security, Inc.',
        submitter_name_yomi='カブシキガイシャブロードバンドセキュリティ',
        address='新宿区西新宿８－５－１',
        industry='情報・通信業',
        sec_code='43980',
        corporate_number='8011101038136',
    ),
    'E34289': EdinetCodeEntry(
        edinet_code='E34289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3514,
        fiscal_year_end='8月31日',
        submitter_name='霞ヶ関キャピタル株式会社',
        submitter_name_en='Kasumigaseki Capital Co., Ltd.',
        submitter_name_yomi='カスミガセキキャピタルカブシキカイシャ',
        address='千代田区霞が関３丁目２番１号\u3000霞が関コモンゲート西館２２階',
        industry='不動産業',
        sec_code='34980',
        corporate_number='3370103000741',
    ),
    'E34290': EdinetCodeEntry(
        edinet_code='E34290',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=164,
        fiscal_year_end='12月31日',
        submitter_name='フロンティア・マネジメント株式会社',
        submitter_name_en='Frontier Management Inc.',
        submitter_name_yomi='フロンティアマネジメントカブシキガイシャ',
        address='港区六本木三丁目２番１号',
        industry='サービス業',
        sec_code='70380',
        corporate_number='1010001121867',
    ),
    'E34292': EdinetCodeEntry(
        edinet_code='E34292',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社マキ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャマキ',
        address='府中市目崎町７０番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2240002046899',
    ),
    'E34294': EdinetCodeEntry(
        edinet_code='E34294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=226,
        fiscal_year_end='12月31日',
        submitter_name='株式会社イーエムネットジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイーエムネットジャパン',
        address='新宿区西新宿六丁目１０番１号',
        industry='サービス業',
        sec_code='70360',
        corporate_number='1011101066507',
    ),
    'E34301': EdinetCodeEntry(
        edinet_code='E34301',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社サウス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサウス',
        address='津市観音寺町４４６番地４２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8190001025771',
    ),
    'E34308': EdinetCodeEntry(
        edinet_code='E34308',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=841,
        fiscal_year_end=None,
        submitter_name='日本生命第２回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイニカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001193813',
    ),
    'E34313': EdinetCodeEntry(
        edinet_code='E34313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='持塚\u3000朗',
        submitter_name_en=None,
        submitter_name_yomi='モチヅカ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34317': EdinetCodeEntry(
        edinet_code='E34317',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=189,
        fiscal_year_end=None,
        submitter_name='Ｄｒａｐｅｒ\u3000Ｎｅｘｕｓ\u3000Ｖｅｎｔｕｒｅ\u3000Ｐａｒｔｎｅｒｓ\u3000ＩＩ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ドレイパー\u3000ネクサス\u3000ベンチャー\u3000パートナーズ\u3000ツー\u3000エルエルシー',
        address='６１５\u3000Ｓｏｕｔｈ\u3000ＤｕＰｏｎｔ\u3000Ｈｉｇｈｗａｙ，\u3000Ｄｏｖｅｒ，\u3000Ｃｏｕｎｔｙ\u3000ｏｆ\u3000Ｋｅｎｔ，\u3000ＤＥ\u3000１９９０１，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34318': EdinetCodeEntry(
        edinet_code='E34318',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=5113,
        fiscal_year_end='3月31日',
        submitter_name='ＤｅｌｔａーＦｌｙ\u3000Ｐｈａｒｍａ株式会社',
        submitter_name_en='Delta-Fly Pharma, Inc.',
        submitter_name_yomi='デルタフライファーマカブシキカイシャ',
        address='徳島市川内町宮島錦野３７番地の５',
        industry='医薬品',
        sec_code='45980',
        corporate_number='6480001006521',
    ),
    'E34321': EdinetCodeEntry(
        edinet_code='E34321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1041,
        fiscal_year_end='12月31日',
        submitter_name='イーソル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イーソルカブシキガイシャ',
        address='中野区本町一丁目３２番２号',
        industry='情報・通信業',
        sec_code='44200',
        corporate_number='9011201009845',
    ),
    'E34322': EdinetCodeEntry(
        edinet_code='E34322',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=2351,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ＬｅＴｅｃｈ',
        submitter_name_en='LeTech Corporation',
        submitter_name_yomi='カブシキガイシャリテック',
        address='大阪市北区堂山町３番３号',
        industry='不動産業',
        sec_code=None,
        corporate_number='2120001096841',
    ),
    'E34323': EdinetCodeEntry(
        edinet_code='E34323',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='エスケー興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスケーコウサンカブシキガイシャ',
        address='芦屋市岩園町４３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001068102',
    ),
    'E34325': EdinetCodeEntry(
        edinet_code='E34325',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阪上\u3000正章',
        submitter_name_en=None,
        submitter_name_yomi='サカガミ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34326': EdinetCodeEntry(
        edinet_code='E34326',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18,
        fiscal_year_end='3月31日',
        submitter_name='エキサイトホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エキサイトホールディングスカブシキガイシャ',
        address='港区南麻布３丁目２０番１号',
        industry='情報・通信業',
        sec_code='55710',
        corporate_number='3010001193533',
    ),
    'E34331': EdinetCodeEntry(
        edinet_code='E34331',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=539,
        fiscal_year_end='12月末日',
        submitter_name='ブリッジインターナショナル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブリッジインターナショナルカブシキカイシャ',
        address='世田谷区太子堂４丁目１－１キャロットタワー',
        industry='サービス業',
        sec_code='70390',
        corporate_number='2010901015622',
    ),
    'E34332': EdinetCodeEntry(
        edinet_code='E34332',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志野文哉',
        submitter_name_en=None,
        submitter_name_yomi='シノフミヤ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34333': EdinetCodeEntry(
        edinet_code='E34333',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藍澤\u3000卓弥',
        submitter_name_en=None,
        submitter_name_yomi='アイザワ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34335': EdinetCodeEntry(
        edinet_code='E34335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=291,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ディ・アイ・システム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディアイシステム',
        address='千代田区丸の内二丁目１番１号',
        industry='情報・通信業',
        sec_code='44210',
        corporate_number='3010401052264',
    ),
    'E34336': EdinetCodeEntry(
        edinet_code='E34336',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=777,
        fiscal_year_end='10月末日',
        submitter_name='株式会社ギフトホールディングス',
        submitter_name_en='GIFT HOLDINGS INC.',
        submitter_name_yomi='カブシキカイシャギフトホールディングス',
        address='渋谷区桜丘町１－１渋谷サクラステージＳＨＩＢＵＹＡタワー３６階',
        industry='小売業',
        sec_code='92790',
        corporate_number='3012301007868',
    ),
    'E34337': EdinetCodeEntry(
        edinet_code='E34337',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='一般社団法人ホンジン・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンホンジンホールディングス',
        address='中央区日本橋兜町１番１０号日証館３０５号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011105004561',
    ),
    'E34343': EdinetCodeEntry(
        edinet_code='E34343',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小原\u3000崇幹',
        submitter_name_en=None,
        submitter_name_yomi='オハラ\u3000タカマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34352': EdinetCodeEntry(
        edinet_code='E34352',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=442,
        fiscal_year_end='9月末日',
        submitter_name='ＣＲＧホールディングス株式会社',
        submitter_name_en='CRG HOLDINGS CO.,LTD.',
        submitter_name_yomi='シーアールジーホールディングスカブシキガイシャ',
        address='新宿区西新宿２－１－１',
        industry='サービス業',
        sec_code='70410',
        corporate_number='7011101067961',
    ),
    'E34356': EdinetCodeEntry(
        edinet_code='E34356',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アジリスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアジリスト',
        address='金沢市円光寺３丁目２１－３５',
        industry='不動産業',
        sec_code=None,
        corporate_number='2220001014801',
    ),
    'E34363': EdinetCodeEntry(
        edinet_code='E34363',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=815,
        fiscal_year_end='8月31日',
        submitter_name='プリントネット株式会社',
        submitter_name_en='PRINTNET INC.',
        submitter_name_yomi='プリントネットカブシキカイシャ',
        address='鹿児島市城南町１０番７号',
        industry='その他製品',
        sec_code='78050',
        corporate_number='9340001008231',
    ),
    'E34366': EdinetCodeEntry(
        edinet_code='E34366',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='薄井\u3000宗明',
        submitter_name_en=None,
        submitter_name_yomi='ウスイ\u3000ソウメイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34367': EdinetCodeEntry(
        edinet_code='E34367',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菅原\u3000敏道',
        submitter_name_en=None,
        submitter_name_yomi='スガワラ\u3000トシミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34368': EdinetCodeEntry(
        edinet_code='E34368',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000勝敏',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000カツトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34370': EdinetCodeEntry(
        edinet_code='E34370',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笠谷\u3000喜代年',
        submitter_name_en=None,
        submitter_name_yomi='カサヤ\u3000キヨトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34371': EdinetCodeEntry(
        edinet_code='E34371',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1769,
        fiscal_year_end=None,
        submitter_name='Ｎｉｈｏｎ\u3000ＩＦＡ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='ニホンアイエフエイパートナーズリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、私書箱３０９、メイプルズ・コーポレート・サービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34373': EdinetCodeEntry(
        edinet_code='E34373',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1126,
        fiscal_year_end=None,
        submitter_name='ＥＭＮＥＴ\u3000ＩＮＣ．',
        submitter_name_en=None,
        submitter_name_yomi='イーエムネット\u3000インク',
        address='大韓民国、ソウル市九老区デジタル通り３４ー２７、１４階（九老洞、ＤＡＥＲＹＵＮＧポストタワー３）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34376': EdinetCodeEntry(
        edinet_code='E34376',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='脇田\u3000栄一',
        submitter_name_en=None,
        submitter_name_yomi='ワキタ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34379': EdinetCodeEntry(
        edinet_code='E34379',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アクセスグループ・ホールディングス',
        submitter_name_en='ACCESS GROUP HOLDINGS CO., LTD.',
        submitter_name_yomi='カブシキガイシャアクセスグループホールディングス',
        address='港区南青山一丁目１番１号',
        industry='サービス業',
        sec_code='70420',
        corporate_number='5010401081443',
    ),
    'E34380': EdinetCodeEntry(
        edinet_code='E34380',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='シェパーズ・ヒル・パートナーズ・ツー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='シェパーズヒルパートナーズツーエルティーディー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランドハウス、私書箱３０９、メープル・コーポレート・サービス・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34381': EdinetCodeEntry(
        edinet_code='E34381',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ソノラ・パートナーズ・ツー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='ソノラパートナーズツーエルティーディー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランドハウス、私書箱３０９、メープル・コーポレート・サービス・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34382': EdinetCodeEntry(
        edinet_code='E34382',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='マナスル・パートナーズ・ツー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='マナスルパートナーズツーエルティーディー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランドハウス、私書箱３０９、メープル・コーポレート・サービス・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34384': EdinetCodeEntry(
        edinet_code='E34384',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｙ’ｓ\u3000ｃｏｒｐｏｒａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイズコーポレーション',
        address='千代田区平河町一丁目６番地１５号ＵＳビル８Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001188347',
    ),
    'E34385': EdinetCodeEntry(
        edinet_code='E34385',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000勇也',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ユウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34387': EdinetCodeEntry(
        edinet_code='E34387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000春樹',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ハルキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34389': EdinetCodeEntry(
        edinet_code='E34389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平野\u3000平幸',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000ヒラユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34392': EdinetCodeEntry(
        edinet_code='E34392',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='阿知波\u3000眞人',
        submitter_name_en=None,
        submitter_name_yomi='アチハ\u3000マヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34393': EdinetCodeEntry(
        edinet_code='E34393',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山岸\u3000吉晴',
        submitter_name_en=None,
        submitter_name_yomi='ヤマギシ\u3000ヨシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34394': EdinetCodeEntry(
        edinet_code='E34394',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='勝本\u3000竜二',
        submitter_name_en=None,
        submitter_name_yomi='カツモト\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34396': EdinetCodeEntry(
        edinet_code='E34396',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='赤坂\u3000圭一',
        submitter_name_en=None,
        submitter_name_yomi='アカサカ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34397': EdinetCodeEntry(
        edinet_code='E34397',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=38107,
        fiscal_year_end=None,
        submitter_name='エスコンジャパンリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='エスコンジャパンリートトウシホウジン',
        address='港区虎ノ門二丁目１０番４号オークラプレステージタワー２０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005025721',
    ),
    'E34401': EdinetCodeEntry(
        edinet_code='E34401',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000正一郎',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000ショウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34402': EdinetCodeEntry(
        edinet_code='E34402',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松岡\u3000真宏',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34406': EdinetCodeEntry(
        edinet_code='E34406',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13636,
        fiscal_year_end='3月末日',
        submitter_name='住友三井オートサービス株式会社',
        submitter_name_en='Sumitomo Mitsui Auto Service Company, Limited',
        submitter_name_yomi='スミトモミツイオートサービスカブシキガイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4011101010726',
    ),
    'E34407': EdinetCodeEntry(
        edinet_code='E34407',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='寺井\u3000秀藏',
        submitter_name_en=None,
        submitter_name_yomi='テライ\u3000ヒデゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34408': EdinetCodeEntry(
        edinet_code='E34408',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑崎\u3000重雄',
        submitter_name_en=None,
        submitter_name_yomi='ハタサキ\u3000シゲオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34410': EdinetCodeEntry(
        edinet_code='E34410',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江島\u3000淸',
        submitter_name_en=None,
        submitter_name_yomi='エシマ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34412': EdinetCodeEntry(
        edinet_code='E34412',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菅田\u3000洋司',
        submitter_name_en=None,
        submitter_name_yomi='スガタ\u3000ヨウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34414': EdinetCodeEntry(
        edinet_code='E34414',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口\u3000茂樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34416': EdinetCodeEntry(
        edinet_code='E34416',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=129,
        fiscal_year_end=None,
        submitter_name='Ｓｃｉｏｎ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ，ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='サイオンアセットマネジメントエルエルシー',
        address='米国デラウェア州ドーバー市、サウス・デュポント・ハイウェイ３５００番地、郵便番号１９９０１、Ｉｎｃｏｒｐｏｒａｔｉｎｇ\u3000Ｓｅｒｖｉｃｅｓ，Ｌｔｄ．方',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34417': EdinetCodeEntry(
        edinet_code='E34417',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＦＣＰ１８',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエフシーピージュウハチ',
        address='福岡市博多区上川端町１２番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4290001082682',
    ),
    'E34418': EdinetCodeEntry(
        edinet_code='E34418',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=113559,
        fiscal_year_end=None,
        submitter_name='モーニングスター・インク',
        submitter_name_en=None,
        submitter_name_yomi='モーニングスター\u3000インク',
        address='米国６０６０４イリノイ州シカゴ、サウス・ラサール・ストリート２０８、スイート８１４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34419': EdinetCodeEntry(
        edinet_code='E34419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000融正',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ミチマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34421': EdinetCodeEntry(
        edinet_code='E34421',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小田原\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='オダワラ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34423': EdinetCodeEntry(
        edinet_code='E34423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='頃安\u3000憲司',
        submitter_name_en=None,
        submitter_name_yomi='コロヤス\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34424': EdinetCodeEntry(
        edinet_code='E34424',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='頃安\u3000雅樹',
        submitter_name_en=None,
        submitter_name_yomi='コロヤス\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34429': EdinetCodeEntry(
        edinet_code='E34429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田川\u3000翔',
        submitter_name_en=None,
        submitter_name_yomi='タガワ\u3000ショウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34430': EdinetCodeEntry(
        edinet_code='E34430',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古澤\u3000孝',
        submitter_name_en=None,
        submitter_name_yomi='フルサワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34431': EdinetCodeEntry(
        edinet_code='E34431',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34434': EdinetCodeEntry(
        edinet_code='E34434',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＮＣＪ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000アイエヌシイジェイ',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001195118',
    ),
    'E34437': EdinetCodeEntry(
        edinet_code='E34437',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笹島\u3000竜也',
        submitter_name_en=None,
        submitter_name_yomi='ササジマ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34442': EdinetCodeEntry(
        edinet_code='E34442',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='英進館株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイシンカンカブシキカイシャ',
        address='福岡市中央区今泉一丁目１１番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4290001073426',
    ),
    'E34445': EdinetCodeEntry(
        edinet_code='E34445',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=37750,
        fiscal_year_end=None,
        submitter_name='ＦＷＤ生命保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフダブリューディーセイメイホケンカブシキガイシャ',
        address='中央区日本橋本町２－２－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401099187',
    ),
    'E34452': EdinetCodeEntry(
        edinet_code='E34452',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29259,
        fiscal_year_end=None,
        submitter_name='エネクス・インフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='エネクスインフラトウシホウジン',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010405016987',
    ),
    'E34453': EdinetCodeEntry(
        edinet_code='E34453',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='合同会社インバウンドインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャインバウンドインベストメント',
        address='千代田区神田神保町二丁目１９番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003028211',
    ),
    'E34454': EdinetCodeEntry(
        edinet_code='E34454',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=552,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヴィス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヴィス',
        address='大阪市北区大深町４番２０号',
        industry='サービス業',
        sec_code='50710',
        corporate_number='8120001041552',
    ),
    'E34455': EdinetCodeEntry(
        edinet_code='E34455',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=539,
        fiscal_year_end='9月30日',
        submitter_name='株式会社レオクラン',
        submitter_name_en='LEOCLAN Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャレオクラン',
        address='摂津市千里丘二丁目４番２６号',
        industry='卸売業',
        sec_code='76810',
        corporate_number='1120901010233',
    ),
    'E34466': EdinetCodeEntry(
        edinet_code='E34466',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平野\u3000哲司',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34470': EdinetCodeEntry(
        edinet_code='E34470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=857,
        fiscal_year_end='3月末日',
        submitter_name='オーウエル株式会社',
        submitter_name_en='O-WELL CORPORATION',
        submitter_name_yomi='オーウエルカブシキカイシャ',
        address='大阪市西淀川区御幣島五丁目１３番９号',
        industry='卸売業',
        sec_code='76700',
        corporate_number='6120001049291',
    ),
    'E34471': EdinetCodeEntry(
        edinet_code='E34471',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=65,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＦＵＪＩジャパン',
        submitter_name_en='FUJI JAPAN CO. LTD.',
        submitter_name_yomi='カブシキガイシャフジジャパン',
        address='札幌市中央区大通西１０丁目４南大通ビル東館８階',
        industry='建設業',
        sec_code='14490',
        corporate_number='9430001030028',
    ),
    'E34472': EdinetCodeEntry(
        edinet_code='E34472',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000忠幸',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000タダユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34476': EdinetCodeEntry(
        edinet_code='E34476',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=79,
        fiscal_year_end=None,
        submitter_name='株式会社ＡｍｉｄＡホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアミダホールディングス',
        address='大阪市西区靱本町一丁目１３番１号\u3000ドットコムビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001095002',
    ),
    'E34479': EdinetCodeEntry(
        edinet_code='E34479',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=292,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ツクイスタッフ',
        submitter_name_en='TSUKUI STAFF CORPORATION',
        submitter_name_yomi='カブシキガイシャツクイスタッフ',
        address='横浜市港南区上大岡西一丁目６番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='8020001114260',
    ),
    'E34484': EdinetCodeEntry(
        edinet_code='E34484',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=849,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ピアラ',
        submitter_name_en='PIALA INC.',
        submitter_name_yomi='カブシキカイシャピアラ',
        address='渋谷区恵比寿四丁目２０番３号恵比寿ガーデンプレイスタワー１３階',
        industry='サービス業',
        sec_code='70440',
        corporate_number='6011001059993',
    ),
    'E34485': EdinetCodeEntry(
        edinet_code='E34485',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇内\u3000章起',
        submitter_name_en=None,
        submitter_name_yomi='ウナイ\u3000ノリオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34486': EdinetCodeEntry(
        edinet_code='E34486',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=297,
        fiscal_year_end='3月31日',
        submitter_name='ＴＡＮＡＫＥＮ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タナケンカブシキガイシャ',
        address='港区東新橋一丁目９番１号',
        industry='建設業',
        sec_code='14500',
        corporate_number='7010401017288',
    ),
    'E34487': EdinetCodeEntry(
        edinet_code='E34487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=833,
        fiscal_year_end='3月末日',
        submitter_name='ＴＤＳＥ株式会社',
        submitter_name_en='TDSE Inc.',
        submitter_name_yomi='ティディエスイーカブシキガイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='サービス業',
        sec_code='70460',
        corporate_number='2011001097163',
    ),
    'E34495': EdinetCodeEntry(
        edinet_code='E34495',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=340051,
        fiscal_year_end=None,
        submitter_name='ＮＴＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌティティカブシキカイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401062934',
    ),
    'E34497': EdinetCodeEntry(
        edinet_code='E34497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=366,
        fiscal_year_end='9月30日',
        submitter_name='株式会社Ａｍａｚｉａ',
        submitter_name_en='Amazia, inc.',
        submitter_name_yomi='カブシキガイシャアメイジア',
        address='渋谷区桜丘町１－２',
        industry='情報・通信業',
        sec_code='44240',
        corporate_number='4011001062405',
    ),
    'E34498': EdinetCodeEntry(
        edinet_code='E34498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=120,
        fiscal_year_end='12月末日',
        submitter_name='アルー株式会社',
        submitter_name_en='Alue Co., Ltd.',
        submitter_name_yomi='アルーカブシキガイシャ',
        address='千代田区九段北一丁目１３番５号',
        industry='サービス業',
        sec_code='70430',
        corporate_number='6010001145804',
    ),
    'E34499': EdinetCodeEntry(
        edinet_code='E34499',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヤシマキザイ',
        submitter_name_en='Yashima & Co., Ltd.',
        submitter_name_yomi='カブシキカイシャヤシマキザイ',
        address='中央区日本橋兜町６番５号',
        industry='卸売業',
        sec_code='76770',
        corporate_number='9010001059407',
    ),
    'E34504': EdinetCodeEntry(
        edinet_code='E34504',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='東京貴宝取引先持株会\u3000理事長\u3000近藤\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウキホウトリヒキサキモチカブカイ\u3000リジチョウ\u3000コンドウ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34506': EdinetCodeEntry(
        edinet_code='E34506',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＳＡＯ\u3000ＩＩＩ\u3000ＧＰ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='エスエーオー\u3000スリー\u3000ジーピー\u3000リミテッド',
        address='Ｔｈｅ\u3000ｏｆｆｉｃｅｓ\u3000ｏｆ\u3000Ｍａｐｌｅｓ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｌｉｍｉｔｅｄ，\u3000ＰＯ\u3000Ｂｏｘ\u3000３０９，\u3000Ｕｇｌａｎｄ\u3000Ｈｏｕｓｅ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０４，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34507': EdinetCodeEntry(
        edinet_code='E34507',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13,
        fiscal_year_end='3月31日',
        submitter_name='Ｋｕｄａｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クダンカブシキガイシャ',
        address='渋谷区神南一丁目２３番１４号',
        industry='情報・通信業',
        sec_code='44250',
        corporate_number='9010001164256',
    ),
    'E34508': EdinetCodeEntry(
        edinet_code='E34508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1823,
        fiscal_year_end='12月31日',
        submitter_name='ベルトラ株式会社',
        submitter_name_en='VELTRA Corporation',
        submitter_name_yomi='ベルトラカブシキカイシャ',
        address='中央区日本橋２－１３－１２',
        industry='サービス業',
        sec_code='70480',
        corporate_number='2011101049188',
    ),
    'E34509': EdinetCodeEntry(
        edinet_code='E34509',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=429,
        fiscal_year_end='12月31日',
        submitter_name='株式会社シノプス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシノプス',
        address='豊中市新千里東町一丁目５番３号',
        industry='情報・通信業',
        sec_code='44280',
        corporate_number='2120001132027',
    ),
    'E34513': EdinetCodeEntry(
        edinet_code='E34513',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=31,
        fiscal_year_end='9月30日',
        submitter_name='リビン・テクノロジーズ株式会社',
        submitter_name_en='Living Technologies Inc.',
        submitter_name_yomi='リビンテクノロジーズカブシキガイシャ',
        address='中央区日本橋堀留町一丁目８番１２号',
        industry='情報・通信業',
        sec_code='44450',
        corporate_number='9010001086161',
    ),
    'E34514': EdinetCodeEntry(
        edinet_code='E34514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3021,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＡＣＳＬ',
        submitter_name_en='ACSL Ltd.',
        submitter_name_yomi='カブシキガイシャエーシーエスエル',
        address='江戸川区臨海町三丁目６番４号２階',
        industry='機械',
        sec_code='62320',
        corporate_number='9040001083503',
    ),
    'E34520': EdinetCodeEntry(
        edinet_code='E34520',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＰＯＨ\u3000ＦＯＷ\u3000ＬＡＩ',
        submitter_name_en=None,
        submitter_name_yomi='ポー\u3000フォライ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34522': EdinetCodeEntry(
        edinet_code='E34522',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=69,
        fiscal_year_end='12月31日',
        submitter_name='ＧＬＣ\u3000ＧＲＯＵＰ株式会社',
        submitter_name_en='GLC GROUP, INC.',
        submitter_name_yomi='ジーエルシーグループカブシキガイシャ',
        address='福岡市博多区博多駅前三丁目４番１号',
        industry='不動産業',
        sec_code='29700',
        corporate_number='7330001008449',
    ),
    'E34523': EdinetCodeEntry(
        edinet_code='E34523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙村\u3000隼人',
        submitter_name_en=None,
        submitter_name_yomi='タカムラ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34531': EdinetCodeEntry(
        edinet_code='E34531',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社サンテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンテック',
        address='堺市堺区戎島町二丁３０番地１－８０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001178360',
    ),
    'E34536': EdinetCodeEntry(
        edinet_code='E34536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横川\u3000端',
        submitter_name_en=None,
        submitter_name_yomi='ヨコカワ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34537': EdinetCodeEntry(
        edinet_code='E34537',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=800,
        fiscal_year_end='3月末日',
        submitter_name='ポート株式会社',
        submitter_name_en='PORT INC.',
        submitter_name_yomi='ポートカブシキガイシャ',
        address='新宿区西新宿八丁目１７番１号',
        industry='情報・通信業',
        sec_code='70470',
        corporate_number='8011001069074',
    ),
    'E34538': EdinetCodeEntry(
        edinet_code='E34538',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ヒト・コミュニケーションズ・ホールディングス',
        submitter_name_en='HITO-Communications Holdings,Inc.',
        submitter_name_yomi='カブシキカイシャヒトコミュニケーションズホールディングス',
        address='豊島区東池袋１－９－６',
        industry='情報・通信業',
        sec_code='44330',
        corporate_number='6013301043545',
    ),
    'E34539': EdinetCodeEntry(
        edinet_code='E34539',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ハイツ・キャピタル・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='ハイツキャピタルマネジメントインク',
        address='アメリカ合衆国、１９８０１、デラウェア州、ウィルミントン、スイート７１５、１２０１Ｎオレンジストリート、ワン・コマース・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34542': EdinetCodeEntry(
        edinet_code='E34542',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29,
        fiscal_year_end=None,
        submitter_name='クレディ・スイス・ファンド・マネジメント・エスエイ',
        submitter_name_en=None,
        submitter_name_yomi='クレディスイスファンドマネジメントエスエイ',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－２１８０、\u3000ジャン・モネ通り５番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34544': EdinetCodeEntry(
        edinet_code='E34544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ＥｄｕＬａｂ',
        submitter_name_en='EduLab, Inc.',
        submitter_name_yomi='カブシキガイシャエデュラボ',
        address='港区港南１－８－１５Ｗビル１３階',
        industry='情報・通信業',
        sec_code='44270',
        corporate_number='6010401117444',
    ),
    'E34545': EdinetCodeEntry(
        edinet_code='E34545',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5150,
        fiscal_year_end='3月末日',
        submitter_name='アルテリア・ネットワークス株式会社',
        submitter_name_en='ARTERIA Networks Corporation',
        submitter_name_yomi='アルテリアネットワークスカブシキガイシャ',
        address='港区新橋六丁目９番８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='8010401123151',
    ),
    'E34548': EdinetCodeEntry(
        edinet_code='E34548',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=521148,
        fiscal_year_end='12月31日',
        submitter_name='ノルデア・バンクＡｂｐ',
        submitter_name_en=None,
        submitter_name_yomi='ノルデアバンクエービーピー',
        address='フィンランド共和国ヘルシンキ市ＦＩ－０００２０ノルデア\u3000サタマラダンカトゥ５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E34549': EdinetCodeEntry(
        edinet_code='E34549',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大塚\u3000浩史',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34552': EdinetCodeEntry(
        edinet_code='E34552',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＩｎｆｌｅＸｉｏｎ\u3000ＩＩ\u3000Ｉｎｖｅｓｔｍｅｎｔ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='インフレクション\u3000ツー\u3000インベストメント\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34557': EdinetCodeEntry(
        edinet_code='E34557',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=132,
        fiscal_year_end='9月30日',
        submitter_name='株式会社マクアケ',
        submitter_name_en='Makuake, Inc.',
        submitter_name_yomi='カブシキカイシャマクアケ',
        address='渋谷区渋谷２－１６－１\u3000Ｄａｉｗａ渋谷宮益坂ビル１０Ｆ',
        industry='情報・通信業',
        sec_code='44790',
        corporate_number='5011001094810',
    ),
    'E34558': EdinetCodeEntry(
        edinet_code='E34558',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000俊昭',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34565': EdinetCodeEntry(
        edinet_code='E34565',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1600,
        fiscal_year_end='12月31日',
        submitter_name='セントラルフォレストグループ株式会社',
        submitter_name_en='Central Forest Group, Inc.',
        submitter_name_yomi='セントラルフォレストグループカブシキガイシャ',
        address='名古屋市熱田区川並町４番８号',
        industry='卸売業',
        sec_code='76750',
        corporate_number='2180001135998',
    ),
    'E34566': EdinetCodeEntry(
        edinet_code='E34566',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='ひびき・パース・アドバイザーズ',
        submitter_name_en=None,
        submitter_name_yomi='ヒビキパースアドバイザーズ',
        address='シンガポール共和国０４８６１９、ラッフルズプレイス９、リパブリックプラザ＃２６－０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34568': EdinetCodeEntry(
        edinet_code='E34568',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='パスロジ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パスロジカブシキガイシャ',
        address='千代田区神田神保町一丁目６番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001091039',
    ),
    'E34569': EdinetCodeEntry(
        edinet_code='E34569',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飛鳥\u3000貴雄',
        submitter_name_en=None,
        submitter_name_yomi='アスカ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34570': EdinetCodeEntry(
        edinet_code='E34570',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=67758,
        fiscal_year_end=None,
        submitter_name='マクド・エー・ピー・エム・イー・エー・シンガポール・インベストメンツ\u3000ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='マクドエーピーエムイーエーシンガポールインベストメンツピーティーイーリミテッド',
        address='シンガポール\u3000１１９９６３、エムタワー、＃２２－０１－０３、アレクサンドラ・ロード４６０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34572': EdinetCodeEntry(
        edinet_code='E34572',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川\u3000潤之',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34573': EdinetCodeEntry(
        edinet_code='E34573',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河本\u3000幸士郎',
        submitter_name_en=None,
        submitter_name_yomi='コウモト\u3000コウシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34574': EdinetCodeEntry(
        edinet_code='E34574',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ノルデア１・シキャブ',
        submitter_name_en=None,
        submitter_name_yomi='ノルデアワンシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－２２２０、ニュードルフ通り５６２番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34575': EdinetCodeEntry(
        edinet_code='E34575',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='インベスコ・ファンズ',
        submitter_name_en=None,
        submitter_name_yomi='インベスコファンズ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－２４５３、ユージーン・ルパート通り２－４\u3000ベルティゴ・ビルディング－ポラリス',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34576': EdinetCodeEntry(
        edinet_code='E34576',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｇｌｏｂａｌ\u3000Ａｌｐｈａ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='グローバルアルファキャピタルマネージメントエルティーディー',
        address='カナダ、ケベック州モントリオール市マギル・カレッジ１３００‐１８００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34577': EdinetCodeEntry(
        edinet_code='E34577',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='株式会社スノーボールキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスノーボールキャピタル',
        address='港区虎ノ門５－１２－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001121082',
    ),
    'E34581': EdinetCodeEntry(
        edinet_code='E34581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二木\u3000渉',
        submitter_name_en=None,
        submitter_name_yomi='フタギ\u3000ワタル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34582': EdinetCodeEntry(
        edinet_code='E34582',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齊藤\u3000精良',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000セイリョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34583': EdinetCodeEntry(
        edinet_code='E34583',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=589,
        fiscal_year_end=None,
        submitter_name='Ｐｅｎｉｎｓｕｌａ\u3000Ｒｏｃｋ\u3000Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='ペニンシュラロックリミテッド',
        address='ＶＧ１１１０、英領バージン諸島、トルトラ、ロードタウン、サーフランシスドレイクハイウェイ３０７６、エレンスケルトンビルディング４階、ポルトクリス\u3000チャンバース',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34585': EdinetCodeEntry(
        edinet_code='E34585',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=530,
        fiscal_year_end=None,
        submitter_name='ハンサード・インターナショナル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ハンサードインターナショナルリミテッド',
        address='マン島、ダグラス、アソルストリート５５、ＩＭ９９\u3000１ＱＬ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34587': EdinetCodeEntry(
        edinet_code='E34587',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=161,
        fiscal_year_end='3月31日',
        submitter_name='ｇｏｏｄｄａｙｓホールディングス株式会社',
        submitter_name_en='gooddays holdings,Inc.',
        submitter_name_yomi='グッドディズホールディングスカブシキガイシャ',
        address='千代田区有楽町二丁目１０番１号',
        industry='情報・通信業',
        sec_code='44370',
        corporate_number='9010001174040',
    ),
    'E34588': EdinetCodeEntry(
        edinet_code='E34588',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小川\u3000秀治',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000ヒデハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34591': EdinetCodeEntry(
        edinet_code='E34591',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='繁澤\u3000潤一郎',
        submitter_name_en=None,
        submitter_name_yomi='ハンザワ\u3000ジュンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34595': EdinetCodeEntry(
        edinet_code='E34595',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=70,
        fiscal_year_end=None,
        submitter_name='アセット・バリュー・インベスターズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アセットバリューインベスターズリミテッド',
        address='英国ロンドン市、キャベンディッシュ\u3000スクエア\u3000２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34596': EdinetCodeEntry(
        edinet_code='E34596',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000規生',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34597': EdinetCodeEntry(
        edinet_code='E34597',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='合同会社サクセスインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャサクセスインベストメント',
        address='中央区日本橋馬喰町２丁目５番１２号６Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003025093',
    ),
    'E34598': EdinetCodeEntry(
        edinet_code='E34598',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6339,
        fiscal_year_end=None,
        submitter_name='創新工業技術移轉股分有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ソウシンコウギョウギジュツイテンコフンユウゲンコウシ',
        address='中華民国（台湾）\u3000台北市大安區和平東路２段１０６號６階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34601': EdinetCodeEntry(
        edinet_code='E34601',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000英人',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ヒデト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34602': EdinetCodeEntry(
        edinet_code='E34602',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000優',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34605': EdinetCodeEntry(
        edinet_code='E34605',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永島\u3000徹三',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000テツゾウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34608': EdinetCodeEntry(
        edinet_code='E34608',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙村\u3000淳一',
        submitter_name_en=None,
        submitter_name_yomi='タカムラ\u3000ジュンイチ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34619': EdinetCodeEntry(
        edinet_code='E34619',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人ＨＤＰ',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンエイチディーピー',
        address='渋谷区桜丘町２０番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011005005612',
    ),
    'E34621': EdinetCodeEntry(
        edinet_code='E34621',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大野\u3000智弘',
        submitter_name_en=None,
        submitter_name_yomi='オオノ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34622': EdinetCodeEntry(
        edinet_code='E34622',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=73,
        fiscal_year_end=None,
        submitter_name='Ｐａｘａｌａｎ\u3000Ｓ．ａ\u3000ｒ．ｌ．',
        submitter_name_en=None,
        submitter_name_yomi='パクサランサール',
        address='６\u3000アムエック\u3000Ｌ９１５７\u3000ハイダーシャイト\u3000ルクセンブルク大公国',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34625': EdinetCodeEntry(
        edinet_code='E34625',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='春日\u3000博文',
        submitter_name_en=None,
        submitter_name_yomi='カスガ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34633': EdinetCodeEntry(
        edinet_code='E34633',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=317,
        fiscal_year_end='2月末日',
        submitter_name='リックソフト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リックソフトカブシキガイシャ',
        address='千代田区大手町２－１－１大手町野村ビル８階',
        industry='情報・通信業',
        sec_code='44290',
        corporate_number='1010001124218',
    ),
    'E34634': EdinetCodeEntry(
        edinet_code='E34634',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='2月28日',
        submitter_name='株式会社識学',
        submitter_name_en='SHIKIGAKU.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャシキガク',
        address='品川区大崎二丁目９番３号大崎ウエストシティビル１階',
        industry='サービス業',
        sec_code='70490',
        corporate_number='7011001104435',
    ),
    'E34635': EdinetCodeEntry(
        edinet_code='E34635',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='廣田\u3000拓郎',
        submitter_name_en=None,
        submitter_name_yomi='ヒロタ\u3000タクロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34636': EdinetCodeEntry(
        edinet_code='E34636',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松田\u3000浩史',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000ヒロシ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34637': EdinetCodeEntry(
        edinet_code='E34637',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社東京大学エッジキャピタルパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトウキョウダイガクエッジキャピタルパートナーズ',
        address='文京区本郷七丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001190786',
    ),
    'E34641': EdinetCodeEntry(
        edinet_code='E34641',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ケアシステムズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケアシステムズ',
        address='足立区梅田七丁目３２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011801025716',
    ),
    'E34643': EdinetCodeEntry(
        edinet_code='E34643',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1154,
        fiscal_year_end='4月末日',
        submitter_name='株式会社スマレジ',
        submitter_name_en='Smaregi,Inc.',
        submitter_name_yomi='カブシキガイシャスマレジ',
        address='大阪市中央区本町四丁目２番１２号',
        industry='情報・通信業',
        sec_code='44310',
        corporate_number='3120002064771',
    ),
    'E34644': EdinetCodeEntry(
        edinet_code='E34644',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=583,
        fiscal_year_end='5月31日',
        submitter_name='ダイコー通産株式会社',
        submitter_name_en='DAIKO TSUSAN CO.,LTD.',
        submitter_name_yomi='ダイコーツウサンカブシキガイシャ',
        address='松山市姫原三丁目６番１１号',
        industry='卸売業',
        sec_code='76730',
        corporate_number='6500001002468',
    ),
    'E34652': EdinetCodeEntry(
        edinet_code='E34652',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='南谷\u3000純',
        submitter_name_en=None,
        submitter_name_yomi='ミナミタニ\u3000ジュン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34653': EdinetCodeEntry(
        edinet_code='E34653',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='南谷\u3000のどか',
        submitter_name_en=None,
        submitter_name_yomi='ミナミタニ\u3000ノドカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34655': EdinetCodeEntry(
        edinet_code='E34655',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='捧\u3000雄一郎',
        submitter_name_en=None,
        submitter_name_yomi='ササゲ\u3000ユウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34657': EdinetCodeEntry(
        edinet_code='E34657',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=33,
        fiscal_year_end='4月30日',
        submitter_name='株式会社フロンティアインターナショナル',
        submitter_name_en='FRONTIER INTERNATIONAL INC.',
        submitter_name_yomi='フロンティアインターナショナル',
        address='渋谷区渋谷三丁目３番５号',
        industry='サービス業',
        sec_code='70500',
        corporate_number='4011001031764',
    ),
    'E34662': EdinetCodeEntry(
        edinet_code='E34662',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社南谷ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャミナミタニホールディングス',
        address='守口市梅町２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120003013739',
    ),
    'E34663': EdinetCodeEntry(
        edinet_code='E34663',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=826,
        fiscal_year_end='5月末日',
        submitter_name='東海ソフト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウカイソフトカブシキガイシャ',
        address='名古屋市中村区則武二丁目１６番１号',
        industry='情報・通信業',
        sec_code='44300',
        corporate_number='1180001031538',
    ),
    'E34674': EdinetCodeEntry(
        edinet_code='E34674',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本多秀光',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000ヒデミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34675': EdinetCodeEntry(
        edinet_code='E34675',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=48505,
        fiscal_year_end='12月31日',
        submitter_name='株式會社大韓航空',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイカンコウクウ',
        address='大韓民国０７５０５ソウル特別市江西区ハヌルギル２６０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E34678': EdinetCodeEntry(
        edinet_code='E34678',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ディスリーン・グループ・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='ディスリーングループエルピー',
        address='アメリカ合衆国０６９０５コネチカット州スタンフォード、サマー・ストリート２７７７、スイート３０１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E34679': EdinetCodeEntry(
        edinet_code='E34679',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=459,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＨＣ',
        submitter_name_en='KHC Ltd.',
        submitter_name_yomi='カブシキガイシャケイエイチシー',
        address='明石市花園町２番地の２',
        industry='建設業',
        sec_code=None,
        corporate_number='7140001034712',
    ),
    'E34683': EdinetCodeEntry(
        edinet_code='E34683',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=7129,
        fiscal_year_end='2月末日',
        submitter_name='株式会社横浜インポートマート',
        submitter_name_en='Yokohama Import Mart Inc.',
        submitter_name_yomi='カブシキガイシャヨコハマインポートマート',
        address='横浜市中区新港二丁目２番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='2020001029398',
    ),
    'E34684': EdinetCodeEntry(
        edinet_code='E34684',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49442,
        fiscal_year_end=None,
        submitter_name='サンケイリアルエステート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='サンケイリアルエステートトウシホウジン',
        address='千代田区内神田二丁目３番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005029390',
    ),
    'E34691': EdinetCodeEntry(
        edinet_code='E34691',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アルファレオホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アルファレオホールディングスゴウドウカイシャ',
        address='千代田区永田町二丁目１１番１号山王パークタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403013287',
    ),
    'E34699': EdinetCodeEntry(
        edinet_code='E34699',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コプロ・ホールディングス',
        submitter_name_en='COPRO-HOLDINGS. Co., Ltd.',
        submitter_name_yomi='カブシキガイシャコプロホールディングス',
        address='名古屋市中村区名駅三丁目２８番１２号\u3000大名古屋ビルヂング２５階',
        industry='サービス業',
        sec_code='70590',
        corporate_number='7180001059094',
    ),
    'E34700': EdinetCodeEntry(
        edinet_code='E34700',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='掬川\u3000正純',
        submitter_name_en=None,
        submitter_name_yomi='キクカワ\u3000マサズミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34704': EdinetCodeEntry(
        edinet_code='E34704',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='1月31日',
        submitter_name='株式会社あさくま',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアサクマ',
        address='日進市赤池町西組３２番地',
        industry='小売業',
        sec_code='76780',
        corporate_number='9180001066601',
    ),
    'E34707': EdinetCodeEntry(
        edinet_code='E34707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=831,
        fiscal_year_end='11月末日',
        submitter_name='スター・マイカ・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スターマイカホールディングスカブシキガイシャ',
        address='港区虎ノ門４－３－１\u3000城山トラストタワー２８階',
        industry='不動産業',
        sec_code='29750',
        corporate_number='4010401060489',
    ),
    'E34711': EdinetCodeEntry(
        edinet_code='E34711',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松澤\u3000孝一',
        submitter_name_en=None,
        submitter_name_yomi='マツザワ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34712': EdinetCodeEntry(
        edinet_code='E34712',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社カオナビ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカオナビ',
        address='渋谷区渋谷２丁目２４番１２号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6011201014757',
    ),
    'E34715': EdinetCodeEntry(
        edinet_code='E34715',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河村\u3000幸俊',
        submitter_name_en=None,
        submitter_name_yomi='カワムラ\u3000ユキトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34716': EdinetCodeEntry(
        edinet_code='E34716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=391,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エヌ・シー・エヌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌシーエヌ',
        address='千代田区永田町２丁目１３番５号',
        industry='サービス業',
        sec_code='70570',
        corporate_number='6200001017075',
    ),
    'E34717': EdinetCodeEntry(
        edinet_code='E34717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＢＳインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエスインベストメントカブシキガイシャ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401143151',
    ),
    'E34719': EdinetCodeEntry(
        edinet_code='E34719',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植野\u3000弘嗣',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ヒロツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34720': EdinetCodeEntry(
        edinet_code='E34720',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1082,
        fiscal_year_end='3月末日',
        submitter_name='ギークス株式会社',
        submitter_name_en='geechs inc.',
        submitter_name_yomi='ギークスカブシキガイシャ',
        address='渋谷区道玄坂二丁目１１番１号',
        industry='サービス業',
        sec_code='70600',
        corporate_number='2011001061870',
    ),
    'E34721': EdinetCodeEntry(
        edinet_code='E34721',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=916,
        fiscal_year_end='12月末日',
        submitter_name='株式会社Ｗｅｌｂｙ',
        submitter_name_en='Welby Inc.',
        submitter_name_yomi='カブシキカイシャウェルビー',
        address='中央区日本橋本町二丁目７番１号',
        industry='情報・通信業',
        sec_code='44380',
        corporate_number='9011001070865',
    ),
    'E34722': EdinetCodeEntry(
        edinet_code='E34722',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=498,
        fiscal_year_end='3月31日',
        submitter_name='共栄セキュリティーサービス株式会社',
        submitter_name_en='Kyoei Security Service Co., Ltd.',
        submitter_name_yomi='キョウエイセキュリティーサービスカブシキカイシャ',
        address='千代田区九段南一丁目６番１７号千代田会館',
        industry='サービス業',
        sec_code='70580',
        corporate_number='8010001088704',
    ),
    'E34725': EdinetCodeEntry(
        edinet_code='E34725',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=295,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フレアス',
        submitter_name_en='Fureasu Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャフレアス',
        address='中巨摩郡昭和町西条１５１４番地',
        industry='サービス業',
        sec_code='70620',
        corporate_number='4090001004657',
    ),
    'E34728': EdinetCodeEntry(
        edinet_code='E34728',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000文彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000フミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34729': EdinetCodeEntry(
        edinet_code='E34729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=629,
        fiscal_year_end='8月末日',
        submitter_name='株式会社東名',
        submitter_name_en='TOUMEI CO., LTD.',
        submitter_name_yomi='カブシキガイシャトウメイ',
        address='四日市市八田二丁目１番３９号',
        industry='情報・通信業',
        sec_code='44390',
        corporate_number='2190001015679',
    ),
    'E34731': EdinetCodeEntry(
        edinet_code='E34731',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＧＸ\u3000ＰＡＲＴＮＥＲＳ\u3000ＣＯ．，\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ジーエックス\u3000パートナーズ\u3000リミテッド',
        address='中華人民共和国香港特別行政区\u3000コーズウェイベイ\u3000ジャッフェロード\u3000４１４ー４２４\u3000チャイナウィール・センター\u3000８階\u3000ユニットＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34735': EdinetCodeEntry(
        edinet_code='E34735',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=343,
        fiscal_year_end='12月31日',
        submitter_name='日本ホスピスホールディングス株式会社',
        submitter_name_en='Japan Hospice Holdings Inc.',
        submitter_name_yomi='ニホンホスピスホールディングスカブシキガイシャ',
        address='千代田区丸の内三丁目３番１号',
        industry='サービス業',
        sec_code='70610',
        corporate_number='5010001180645',
    ),
    'E34736': EdinetCodeEntry(
        edinet_code='E34736',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=85000,
        fiscal_year_end='3月31日',
        submitter_name='アクサ・ホールディングス・ジャパン株式会社',
        submitter_name_en='AXA Holdings Japan Co., Ltd',
        submitter_name_yomi='アクサホールディングスジャパンカブシキガイシャ',
        address='港区白金一丁目１７番３号',
        industry='保険業',
        sec_code=None,
        corporate_number='9010401144808',
    ),
    'E34737': EdinetCodeEntry(
        edinet_code='E34737',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000竜也',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34738': EdinetCodeEntry(
        edinet_code='E34738',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井石\u3000裕二',
        submitter_name_en=None,
        submitter_name_yomi='イセキ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34739': EdinetCodeEntry(
        edinet_code='E34739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=612,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ヴィッツ',
        submitter_name_en='WITZ Corporation',
        submitter_name_yomi='カブシキガイシャヴィッツ',
        address='名古屋市中区新栄町一丁目１番地',
        industry='情報・通信業',
        sec_code='44400',
        corporate_number='9180001045035',
    ),
    'E34740': EdinetCodeEntry(
        edinet_code='E34740',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='服部\u3000博行',
        submitter_name_en=None,
        submitter_name_yomi='ハットリ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34742': EdinetCodeEntry(
        edinet_code='E34742',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='脇田\u3000周爾',
        submitter_name_en=None,
        submitter_name_yomi='ワキタ\u3000シュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34744': EdinetCodeEntry(
        edinet_code='E34744',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森川\u3000聡久',
        submitter_name_en=None,
        submitter_name_yomi='モリカワ\u3000アキヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34745': EdinetCodeEntry(
        edinet_code='E34745',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000秀一',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34746': EdinetCodeEntry(
        edinet_code='E34746',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武田\u3000英幸',
        submitter_name_en=None,
        submitter_name_yomi='タケダ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34747': EdinetCodeEntry(
        edinet_code='E34747',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=766,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＮＡＴＴＹ\u3000ＳＷＡＮＫＹホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナッティースワンキー',
        address='新宿区西新宿１－１９－８\u3000新東京ビル７階',
        industry='小売業',
        sec_code='76740',
        corporate_number='9012401017051',
    ),
    'E34748': EdinetCodeEntry(
        edinet_code='E34748',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1102,
        fiscal_year_end='6月30日',
        submitter_name='株式会社Ｂｉｒｄｍａｎ',
        submitter_name_en='Birdman Inc.',
        submitter_name_yomi='カブシキガイシャバードマン',
        address='渋谷区松濤一丁目５番３号',
        industry='サービス業',
        sec_code='70630',
        corporate_number='8010001148284',
    ),
    'E34750': EdinetCodeEntry(
        edinet_code='E34750',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＫＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイキ',
        address='世田谷区成城７丁目３４番１９号\u3000ラ・ボール成城１０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101080855',
    ),
    'E34752': EdinetCodeEntry(
        edinet_code='E34752',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='ＰＧＧＭ\u3000Ｖｅｒｍｏｇｅｎｓｂｅｈｅｅｒ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ピージージーエム\u3000フェルモーホンビヘーア\u3000ビーブイ',
        address='Ｎｏｏｒｄｗｅｇ\u3000Ｎｏｏｒｄ\u3000１５０，\u3000３７０４\u3000ＪＧ，\u3000Ｚｅｉｓｔ，\u3000Ｔｈｅ\u3000Ｎｅｔｈｅｒｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34754': EdinetCodeEntry(
        edinet_code='E34754',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3512,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ミンカブ・ジ・インフォノイド',
        submitter_name_en='MINKABU THE INFONOID, Inc.',
        submitter_name_yomi='カブシキカイシャミンカブジインフォノイド',
        address='千代田区九段北一丁目８番１０号',
        industry='情報・通信業',
        sec_code='44360',
        corporate_number='4010401098942',
    ),
    'E34756': EdinetCodeEntry(
        edinet_code='E34756',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小倉\u3000博',
        submitter_name_en=None,
        submitter_name_yomi='オグラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34759': EdinetCodeEntry(
        edinet_code='E34759',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='伸和工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンワコウギョウカブシキガイシャ',
        address='大阪市天王寺区玉造元町２－３２－２０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001023845',
    ),
    'E34767': EdinetCodeEntry(
        edinet_code='E34767',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=154,
        fiscal_year_end=None,
        submitter_name='ファンドロジック（ジャージー）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ファンドロジックジャージーリミテッド',
        address='ジャージー、ＪＥ１\u3000０ＢＤ、セント・ヘリア、エスプラネード４７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34768': EdinetCodeEntry(
        edinet_code='E34768',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西村\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34770': EdinetCodeEntry(
        edinet_code='E34770',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ライフステージやまと',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャライフステージヤマト',
        address='広島市中区中町３－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9240001017218',
    ),
    'E34771': EdinetCodeEntry(
        edinet_code='E34771',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大野\u3000寿美',
        submitter_name_en=None,
        submitter_name_yomi='オオノ\u3000トシミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34772': EdinetCodeEntry(
        edinet_code='E34772',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安藤\u3000広大',
        submitter_name_en=None,
        submitter_name_yomi='アンドウ\u3000コウダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34773': EdinetCodeEntry(
        edinet_code='E34773',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福冨謙二',
        submitter_name_en=None,
        submitter_name_yomi='フクトミ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34774': EdinetCodeEntry(
        edinet_code='E34774',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＲＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーアールエス',
        address='世田谷区代田一丁目１８番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010901041071',
    ),
    'E34777': EdinetCodeEntry(
        edinet_code='E34777',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=70,
        fiscal_year_end=None,
        submitter_name='株式会社光優',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャコウユウ',
        address='横浜市港北区日吉二丁目１１番２５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001039050',
    ),
    'E34781': EdinetCodeEntry(
        edinet_code='E34781',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3935,
        fiscal_year_end=None,
        submitter_name='大阪厚生信用金庫',
        submitter_name_en=None,
        submitter_name_yomi='オオサカコウセイシンヨウキンコ',
        address='大阪市中央区島之内１丁目２０番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120005002335',
    ),
    'E34787': EdinetCodeEntry(
        edinet_code='E34787',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='德田\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='トクダ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34788': EdinetCodeEntry(
        edinet_code='E34788',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000博士',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34789': EdinetCodeEntry(
        edinet_code='E34789',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='湊\u3000隆太朗',
        submitter_name_en=None,
        submitter_name_yomi='ミナト\u3000リュウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34790': EdinetCodeEntry(
        edinet_code='E34790',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='望月\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='モチヅキ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34792': EdinetCodeEntry(
        edinet_code='E34792',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='百目鬼\u3000孝一',
        submitter_name_en=None,
        submitter_name_yomi='ドウメキ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34793': EdinetCodeEntry(
        edinet_code='E34793',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社リタメコ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリタメコ',
        address='名古屋市中村区名駅一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001125843',
    ),
    'E34796': EdinetCodeEntry(
        edinet_code='E34796',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邊\u3000伸一郎',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000シンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34797': EdinetCodeEntry(
        edinet_code='E34797',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古井\u3000貴',
        submitter_name_en=None,
        submitter_name_yomi='フルイ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34798': EdinetCodeEntry(
        edinet_code='E34798',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=33,
        fiscal_year_end=None,
        submitter_name='Ｋ＆Ｐパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイアンドピーパートナーズカブシキカイシャ',
        address='千代田区内神田一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401105862',
    ),
    'E34799': EdinetCodeEntry(
        edinet_code='E34799',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西口\u3000高生',
        submitter_name_en=None,
        submitter_name_yomi='ニシグチ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34800': EdinetCodeEntry(
        edinet_code='E34800',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=288,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ビーアンドピー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーアンドピー',
        address='大阪市西区江戸堀二丁目６番３３号',
        industry='その他製品',
        sec_code='78040',
        corporate_number='7120001046701',
    ),
    'E34811': EdinetCodeEntry(
        edinet_code='E34811',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000秀和',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヒデカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34812': EdinetCodeEntry(
        edinet_code='E34812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水谷\u3000慎介',
        submitter_name_en=None,
        submitter_name_yomi='ミズタニ\u3000シンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34814': EdinetCodeEntry(
        edinet_code='E34814',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=333,
        fiscal_year_end='10月31日',
        submitter_name='トビラシステムズ株式会社',
        submitter_name_en='Tobila Systems Inc.',
        submitter_name_yomi='トビラシステムズカブシキガイシャ',
        address='名古屋市中区錦二丁目５番１２号',
        industry='情報・通信業',
        sec_code='44410',
        corporate_number='9180001066502',
    ),
    'E34815': EdinetCodeEntry(
        edinet_code='E34815',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='明田\u3000篤',
        submitter_name_en=None,
        submitter_name_yomi='アキタ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34819': EdinetCodeEntry(
        edinet_code='E34819',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=437,
        fiscal_year_end='9月末日',
        submitter_name='株式会社グッドスピード',
        submitter_name_en='GOODSPEED. CO., LTD.',
        submitter_name_yomi='カブシキガイシャグッドスピード',
        address='名古屋市東区泉二丁目２８番２３号',
        industry='小売業',
        sec_code=None,
        corporate_number='4180001057902',
    ),
    'E34820': EdinetCodeEntry(
        edinet_code='E34820',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000久統',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヒサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34823': EdinetCodeEntry(
        edinet_code='E34823',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ニューメリック・インベスターズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ニューメリックインベスターズエルエルシー',
        address='アメリカ合衆国、０２２１０マサチューセッツ州、ボストン、ブールバード４、ピア２００、５階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34826': EdinetCodeEntry(
        edinet_code='E34826',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='Ｊ－ＳＴＡＲ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイスターカブシキカイシャ',
        address='千代田区有楽町一丁目１３番２号\u3000第一生命日比谷ファースト１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001126841',
    ),
    'E34827': EdinetCodeEntry(
        edinet_code='E34827',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＰ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケーピーカブシキカイシャ',
        address='大田区久が原６－８－１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010801028558',
    ),
    'E34829': EdinetCodeEntry(
        edinet_code='E34829',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=984,
        fiscal_year_end=None,
        submitter_name='ブラック・クリーク・インベストメント・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='ブラック\u3000クリーク\u3000インベストメント\u3000マネジメント\u3000インク',
        address='カナダＭ５Ｊ\u3000２Ｍ２、オンタリオ州トロント、フロント・ストリート・ウェスト１２３、スィート１２００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34830': EdinetCodeEntry(
        edinet_code='E34830',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松下\u3000智樹',
        submitter_name_en=None,
        submitter_name_yomi='マツシタ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34832': EdinetCodeEntry(
        edinet_code='E34832',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田鎖\u3000郁夫',
        submitter_name_en=None,
        submitter_name_yomi='タクサリ\u3000イクオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34833': EdinetCodeEntry(
        edinet_code='E34833',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柳橋\u3000仁機',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギハシ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34836': EdinetCodeEntry(
        edinet_code='E34836',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2732,
        fiscal_year_end=None,
        submitter_name='ゴールドマン・サックス・アセット・マネジメント・ファンド・サービシズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ゴールドマンサックスアセットマネジメントファンドサービシズリミテッド',
        address='アイルランド、ダブリン２、セント・スティーブンス・グリーン４７‐４９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34837': EdinetCodeEntry(
        edinet_code='E34837',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100000,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＪＥＲＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェラ',
        address='中央区日本橋二丁目５番１号',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='6010001167617',
    ),
    'E34840': EdinetCodeEntry(
        edinet_code='E34840',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤野\u3000正司',
        submitter_name_en=None,
        submitter_name_yomi='サワノ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34841': EdinetCodeEntry(
        edinet_code='E34841',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大石\u3000良',
        submitter_name_en=None,
        submitter_name_yomi='オオイシ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34843': EdinetCodeEntry(
        edinet_code='E34843',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='合同会社あっとプラニング',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャアットプラニング',
        address='千代田区九段南一丁目６番１７号千代田会館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011603002032',
    ),
    'E34847': EdinetCodeEntry(
        edinet_code='E34847',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='合同会社モンシャーレ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャモンシャーレ',
        address='豊島区東池袋一丁目５番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1013303003881',
    ),
    'E34850': EdinetCodeEntry(
        edinet_code='E34850',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='比木\u3000武',
        submitter_name_en=None,
        submitter_name_yomi='ヒキ\u3000タケル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34851': EdinetCodeEntry(
        edinet_code='E34851',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=342,
        fiscal_year_end='3月末日',
        submitter_name='株式会社アイ・パートナーズフィナンシャル',
        submitter_name_en='Ai Partners Financial Inc.',
        submitter_name_yomi='カブシキガイシャアイパートナーズフィナンシャル',
        address='横浜市西区南幸２－２０－５',
        industry='その他金融業',
        sec_code='73450',
        corporate_number='3020001046095',
    ),
    'E34852': EdinetCodeEntry(
        edinet_code='E34852',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=691,
        fiscal_year_end=None,
        submitter_name='日本生命第３回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイサンカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001198998',
    ),
    'E34853': EdinetCodeEntry(
        edinet_code='E34853',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=477,
        fiscal_year_end='7月末日',
        submitter_name='Ｌｉｎｋ－Ｕグループ株式会社',
        submitter_name_en='Link-U Group Inc.',
        submitter_name_yomi='リンクユーグループカブシキガイシャ',
        address='千代田区外神田二丁目２番３号',
        industry='情報・通信業',
        sec_code='44460',
        corporate_number='6010701028399',
    ),
    'E34854': EdinetCodeEntry(
        edinet_code='E34854',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='合同会社ＲＳＩファンド１号',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアールエスアイファンドイチゴウ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010003023462',
    ),
    'E34856': EdinetCodeEntry(
        edinet_code='E34856',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瓜生\u3000憲',
        submitter_name_en=None,
        submitter_name_yomi='ウリュウ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34858': EdinetCodeEntry(
        edinet_code='E34858',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='廣岡\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='ヒロオカ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34862': EdinetCodeEntry(
        edinet_code='E34862',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34866': EdinetCodeEntry(
        edinet_code='E34866',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ハウテレビジョン',
        submitter_name_en='Howtelevision,Inc',
        submitter_name_yomi='カブシキカイシャハウテレビジョン',
        address='港区赤坂一丁目１２番３２号',
        industry='サービス業',
        sec_code='70640',
        corporate_number='4011601015654',
    ),
    'E34867': EdinetCodeEntry(
        edinet_code='E34867',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ブライトリンクパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブライトリンクパートナーズ',
        address='世田谷区下馬５丁目２１－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013201017110',
    ),
    'E34869': EdinetCodeEntry(
        edinet_code='E34869',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1727824,
        fiscal_year_end='12月31日',
        submitter_name='イーベイ・インク',
        submitter_name_en=None,
        submitter_name_yomi='イーベイインク',
        address='アメリカ合衆国\u3000カリフォルニア州\u3000９５１２５\u3000サンノゼ\u3000ハミルトン・アベニュー２０２５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E34874': EdinetCodeEntry(
        edinet_code='E34874',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社キョウデンエリアネット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキョウデンエリアネット',
        address='品川区東五反田五丁目２番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401090522',
    ),
    'E34877': EdinetCodeEntry(
        edinet_code='E34877',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1039,
        fiscal_year_end=None,
        submitter_name='双日建材株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソウジツケンザイカブシキカイシャ',
        address='千代田区大手町１－７－２\u3000東京サンケイビル２１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001053740',
    ),
    'E34878': EdinetCodeEntry(
        edinet_code='E34878',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社フリーウェイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフリーウェイ',
        address='品川区東五反田５－２－２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401074378',
    ),
    'E34879': EdinetCodeEntry(
        edinet_code='E34879',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＶＯＹＡＧＥＧＲＯＵＰ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャボヤージュグループ',
        address='渋谷区道玄坂１丁目２１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001124981',
    ),
    'E34880': EdinetCodeEntry(
        edinet_code='E34880',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='3月31日',
        submitter_name='バルテス・ホールディングス株式会社',
        submitter_name_en='VALTES HOLDINGS CO.,LTD.',
        submitter_name_yomi='バルテスホールディングスカブシキガイシャ',
        address='大阪市西区阿波座１丁目３番１５号',
        industry='情報・通信業',
        sec_code='44420',
        corporate_number='1120001107293',
    ),
    'E34881': EdinetCodeEntry(
        edinet_code='E34881',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000幸子',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000サチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34883': EdinetCodeEntry(
        edinet_code='E34883',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4500,
        fiscal_year_end=None,
        submitter_name='株式会社ケイエスピー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイエスピー',
        address='川崎市高津区坂戸３－２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001066154',
    ),
    'E34885': EdinetCodeEntry(
        edinet_code='E34885',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤登\u3000拓',
        submitter_name_en=None,
        submitter_name_yomi='サワノボリ\u3000タク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34889': EdinetCodeEntry(
        edinet_code='E34889',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大友\u3000宏一',
        submitter_name_en=None,
        submitter_name_yomi='オオトモ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34891': EdinetCodeEntry(
        edinet_code='E34891',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＪＴＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイティーシー',
        address='新宿区左門町２番地６',
        industry='小売業',
        sec_code=None,
        corporate_number='9320001006914',
    ),
    'E34896': EdinetCodeEntry(
        edinet_code='E34896',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=236228,
        fiscal_year_end=None,
        submitter_name='グレンジャー・グローバル・ホールディングス・インク',
        submitter_name_en=None,
        submitter_name_yomi='グレンジャー\u3000グローバル\u3000ホールディングス\u3000インク',
        address='アメリカ合衆国イリノイ州６００４５、レーク・フォレスト、グレンジャー・パークウェイ１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34900': EdinetCodeEntry(
        edinet_code='E34900',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=226909,
        fiscal_year_end=None,
        submitter_name='グレンジャー・インターナショナル・インク',
        submitter_name_en=None,
        submitter_name_yomi='グレンジャー\u3000インターナショナル\u3000インク',
        address='アメリカ合衆国イリノイ州６００４５、レーク・フォレスト、グレンジャー・パークウェイ１００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34902': EdinetCodeEntry(
        edinet_code='E34902',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊達\u3000晃洋',
        submitter_name_en=None,
        submitter_name_yomi='ダテ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34904': EdinetCodeEntry(
        edinet_code='E34904',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社エスエヌ興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスエヌコウサン',
        address='京都市中京区烏丸通二条下ル秋野々町５１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130001020024',
    ),
    'E34908': EdinetCodeEntry(
        edinet_code='E34908',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社アルデシアインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルデシアインベストメント',
        address='中央区銀座７丁目１３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011701021746',
    ),
    'E34909': EdinetCodeEntry(
        edinet_code='E34909',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹中\u3000洋',
        submitter_name_en=None,
        submitter_name_yomi='タケナカ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34911': EdinetCodeEntry(
        edinet_code='E34911',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井元\u3000義昭',
        submitter_name_en=None,
        submitter_name_yomi='イモト\u3000ヨシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34919': EdinetCodeEntry(
        edinet_code='E34919',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥田\u3000香代子',
        submitter_name_en=None,
        submitter_name_yomi='オクダ\u3000カヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34926': EdinetCodeEntry(
        edinet_code='E34926',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷川\u3000龍二',
        submitter_name_en=None,
        submitter_name_yomi='タニガワ\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34929': EdinetCodeEntry(
        edinet_code='E34929',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山口\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34930': EdinetCodeEntry(
        edinet_code='E34930',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｍｉｄｗｅｓｔ\u3000Ｍｉｎａｔｏ\u3000ＧＰ，\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ミッドウエストミナトジーピーリミテッド',
        address='Ｃｌｉｆｔｏｎ\u3000Ｈｏｕｓｅ，７５\u3000Ｆｏｒｔ\u3000Ｓｔｒｅｅｔ，\u3000Ｐ．Ｏ．Ｂｏｘ\u3000１３５０，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34931': EdinetCodeEntry(
        edinet_code='E34931',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｐａｃｉｆｉｃ\u3000Ｍｉｎａｔｏ\u3000ＩＩ\u3000ＧＰ，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='パシフィックミナトツージーピーリミテッド',
        address='Ｃｌｉｆｔｏｎ\u3000Ｈｏｕｓｅ，７５\u3000Ｆｏｒｔ\u3000Ｓｔｒｅｅｔ，\u3000Ｐ．Ｏ．Ｂｏｘ\u3000１３５０，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34932': EdinetCodeEntry(
        edinet_code='E34932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000正行',
        submitter_name_en=None,
        submitter_name_yomi='ワダマサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34935': EdinetCodeEntry(
        edinet_code='E34935',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4669,
        fiscal_year_end=None,
        submitter_name='ディーエクスシー・ユーエス（オランダ）・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ディーエクスシー\u3000ユーエス\u3000オランダ\u3000エルエルシー',
        address='アメリカ合衆国テキサス州７５０２４、プラーノ、レガシードライブ５４００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34938': EdinetCodeEntry(
        edinet_code='E34938',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=182,
        fiscal_year_end='3月31日',
        submitter_name='日本グランデ株式会社',
        submitter_name_en='Nippon Grande Co.,Ltd.',
        submitter_name_yomi='ニッポングランデカブシキカイシャ',
        address='札幌市中央区大通西五丁目１番地１',
        industry='不動産業',
        sec_code='29760',
        corporate_number='6430001028578',
    ),
    'E34940': EdinetCodeEntry(
        edinet_code='E34940',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平野\u3000雅博',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34943': EdinetCodeEntry(
        edinet_code='E34943',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社薬王堂ホールディングス',
        submitter_name_en='YAKUODO HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャヤクオウドウホールディングス',
        address='紫波郡矢巾町医大通二丁目７番７号',
        industry='小売業',
        sec_code='76790',
        corporate_number='5400001014747',
    ),
    'E34944': EdinetCodeEntry(
        edinet_code='E34944',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=335,
        fiscal_year_end='9月30日',
        submitter_name='大英産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイエイサンギョウカブシキカイシャ',
        address='北九州市八幡西区下上津役四丁目１番３６号',
        industry='不動産業',
        sec_code='29740',
        corporate_number='4290801010181',
    ),
    'E34945': EdinetCodeEntry(
        edinet_code='E34945',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社東京共同会計事務所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトウキョウキョウドウカイケイジムショ',
        address='千代田区丸の内一丁目４番１号丸の内永楽ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010002016029',
    ),
    'E34947': EdinetCodeEntry(
        edinet_code='E34947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金子\u3000光夫',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000ミツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34950': EdinetCodeEntry(
        edinet_code='E34950',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000真史',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34954': EdinetCodeEntry(
        edinet_code='E34954',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=74,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ピアズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャピアズ',
        address='港区港南二丁目１６番４号',
        industry='サービス業',
        sec_code='70660',
        corporate_number='8180001056958',
    ),
    'E34956': EdinetCodeEntry(
        edinet_code='E34956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山上\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='ヤマガミ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34958': EdinetCodeEntry(
        edinet_code='E34958',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='音成\u3000洋介',
        submitter_name_en=None,
        submitter_name_yomi='オトナリ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34960': EdinetCodeEntry(
        edinet_code='E34960',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7203,
        fiscal_year_end='5月31日',
        submitter_name='Ｓａｎｓａｎ株式会社',
        submitter_name_en='Sansan, Inc.',
        submitter_name_yomi='サンサンカブシキガイシャ',
        address='渋谷区桜丘町１番１号',
        industry='情報・通信業',
        sec_code='44430',
        corporate_number='4010001120965',
    ),
    'E34964': EdinetCodeEntry(
        edinet_code='E34964',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桑野\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='クワノ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34965': EdinetCodeEntry(
        edinet_code='E34965',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4158,
        fiscal_year_end='9月30日',
        submitter_name='新日本製薬株式会社',
        submitter_name_en='Shinnihonseiyaku Co., Ltd.',
        submitter_name_yomi='シンニホンセイヤクカブシキガイシャ',
        address='福岡市中央区大手門一丁目４番７号',
        industry='化学',
        sec_code='49310',
        corporate_number='5290001023017',
    ),
    'E34968': EdinetCodeEntry(
        edinet_code='E34968',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社サイブリッジ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサイブリッジ',
        address='中央区日本橋室町一丁目１３番１号ＤＫノア４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011003005276',
    ),
    'E34973': EdinetCodeEntry(
        edinet_code='E34973',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=961,
        fiscal_year_end='9月末日',
        submitter_name='株式会社プレイド',
        submitter_name_en='PLAID, Inc.',
        submitter_name_yomi='プレイドカブシキガイシャ',
        address='中央区銀座６－１０－１',
        industry='情報・通信業',
        sec_code='41650',
        corporate_number='7010401096035',
    ),
    'E34974': EdinetCodeEntry(
        edinet_code='E34974',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=292,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インフォネット',
        submitter_name_en='infoNet inc.',
        submitter_name_yomi='カブシキガイシャインフォネット',
        address='港区新橋４－２１－３',
        industry='情報・通信業',
        sec_code='44440',
        corporate_number='2010001142978',
    ),
    'E34975': EdinetCodeEntry(
        edinet_code='E34975',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99,
        fiscal_year_end='3月31日',
        submitter_name='ブランディングテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブランディングテクノロジーカブシキガイシャ',
        address='渋谷区南平台町１５番１３号帝都渋谷ビル４階',
        industry='サービス業',
        sec_code='70670',
        corporate_number='2011001038472',
    ),
    'E34980': EdinetCodeEntry(
        edinet_code='E34980',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=32,
        fiscal_year_end=None,
        submitter_name='ビーアンドアイ・キャピタル・エイジー',
        submitter_name_en=None,
        submitter_name_yomi='ビーアンドアイキャピタルエイジー',
        address='スイス、チューリッヒ、ＣＨ‐８００１、ジルシュトラーセ３７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34983': EdinetCodeEntry(
        edinet_code='E34983',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='普済堂株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プジドウカブシキガイシャ',
        address='中央区築地７丁目１１番５号２０１室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001193342',
    ),
    'E34988': EdinetCodeEntry(
        edinet_code='E34988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺田\u3000親弘',
        submitter_name_en=None,
        submitter_name_yomi='テラダ\u3000チカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E34990': EdinetCodeEntry(
        edinet_code='E34990',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＡＴＡＳＥ\u3000ＨＯＬＤＩＮＧＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハタセホールディングス',
        address='中央区日本橋二丁目１ー３\u3000アーバンネット日本橋二丁目ビル１０Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101072305',
    ),
    'E34991': EdinetCodeEntry(
        edinet_code='E34991',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=850,
        fiscal_year_end=None,
        submitter_name='住友生命第１回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001200626',
    ),
    'E34994': EdinetCodeEntry(
        edinet_code='E34994',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=542,
        fiscal_year_end='10月31日',
        submitter_name='株式会社アシロ',
        submitter_name_en='ASIRO Inc.',
        submitter_name_yomi='カブシキカイシャアシロ',
        address='新宿区西新宿七丁目７番６号',
        industry='サービス業',
        sec_code='73780',
        corporate_number='9011101076787',
    ),
    'E34995': EdinetCodeEntry(
        edinet_code='E34995',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='5月末日',
        submitter_name='フィードフォースグループ株式会社',
        submitter_name_en='Feedforce Group Inc.',
        submitter_name_yomi='フィードフォースグループカブシキガイシャ',
        address='港区南青山一丁目２番６号',
        industry='サービス業',
        sec_code='70680',
        corporate_number='7010001098357',
    ),
    'E34999': EdinetCodeEntry(
        edinet_code='E34999',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=32,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ステムリム',
        submitter_name_en='StemRIM Inc.',
        submitter_name_yomi='カブシキガイシャステムリム',
        address='茨木市彩都あさぎ７丁目７番１５号',
        industry='医薬品',
        sec_code='45990',
        corporate_number='6120901018131',
    ),
    'E35002': EdinetCodeEntry(
        edinet_code='E35002',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近藤\u3000裕貴',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35004': EdinetCodeEntry(
        edinet_code='E35004',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5781,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ブシロード',
        submitter_name_en='Bushiroad Inc.',
        submitter_name_yomi='カブシキガイシャブシロード',
        address='中野区中央一丁目３８番１号',
        industry='その他製品',
        sec_code='78030',
        corporate_number='8011201012032',
    ),
    'E35006': EdinetCodeEntry(
        edinet_code='E35006',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大園\u3000信',
        submitter_name_en=None,
        submitter_name_yomi='オオソノ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35007': EdinetCodeEntry(
        edinet_code='E35007',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一ノ瀬\u3000知子',
        submitter_name_en=None,
        submitter_name_yomi='イチノセ\u3000トモコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35008': EdinetCodeEntry(
        edinet_code='E35008',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大園\u3000英彦',
        submitter_name_en=None,
        submitter_name_yomi='オオソノ\u3000ヒデヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35010': EdinetCodeEntry(
        edinet_code='E35010',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000裕紀',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35012': EdinetCodeEntry(
        edinet_code='E35012',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='祖父江\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='ソフエ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35013': EdinetCodeEntry(
        edinet_code='E35013',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='日本投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホントウシカブシキガイシャ',
        address='港区虎ノ門二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001221066',
    ),
    'E35014': EdinetCodeEntry(
        edinet_code='E35014',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＳＩホールディングス株式会社',
        submitter_name_en='SI Holdings plc',
        submitter_name_yomi='エスアイホールディングスカブシキガイシャ',
        address='中央区八重洲二丁目７番１６号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010001204424',
    ),
    'E35015': EdinetCodeEntry(
        edinet_code='E35015',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000厚',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35018': EdinetCodeEntry(
        edinet_code='E35018',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000輝明',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000テルアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35019': EdinetCodeEntry(
        edinet_code='E35019',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000武幸',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000タケユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35023': EdinetCodeEntry(
        edinet_code='E35023',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='Ｍｅｇａｚｏｎｅ\u3000Ｃｌｏｕｄ\u3000Ｃｏｒｐｏｒａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='メガゾーンクラウドカブシキカイシャ',
        address='７４，\u3000Ｇｗａｃｈｅｏｎ－ｄａｅｒｏ\u3000７－ｇｉｌ，\u3000Ｇｗａｃｈｅｏｎ－ｓｉ，\u3000Ｇｙｅｏｎｇｇｉ－ｄｏ，\u3000Ｒｅｐｕｂｌｉｃ\u3000ｏｆ\u3000Ｋｏｒｅａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35024': EdinetCodeEntry(
        edinet_code='E35024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='川合商会株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カワイショウカイカブシキカイシャ',
        address='中央区日本橋人形町３丁目６ー８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001176126',
    ),
    'E35025': EdinetCodeEntry(
        edinet_code='E35025',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='観音堂\u3000靖',
        submitter_name_en=None,
        submitter_name_yomi='カンノウドウ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35028': EdinetCodeEntry(
        edinet_code='E35028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=22,
        fiscal_year_end='7月31日',
        submitter_name='株式会社ツクルバ',
        submitter_name_en='TSUKURUBA Inc.',
        submitter_name_yomi='カブシキガイシャツクルバ',
        address='渋谷区恵比寿四丁目３番１４号\u3000恵比寿ＳＳビル',
        industry='不動産業',
        sec_code='29780',
        corporate_number='3011001070524',
    ),
    'E35030': EdinetCodeEntry(
        edinet_code='E35030',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=580,
        fiscal_year_end=None,
        submitter_name='明治安田生命２０１９基金特定目的会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイニセンジュウキュウキキントクテイモクテキカイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010005030306',
    ),
    'E35035': EdinetCodeEntry(
        edinet_code='E35035',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久保田\u3000一臣',
        submitter_name_en=None,
        submitter_name_yomi='クボタ\u3000カズミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35036': EdinetCodeEntry(
        edinet_code='E35036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塚田\u3000耕司',
        submitter_name_en=None,
        submitter_name_yomi='ツカダ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35039': EdinetCodeEntry(
        edinet_code='E35039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000英二郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000エイジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35044': EdinetCodeEntry(
        edinet_code='E35044',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木谷\u3000高明',
        submitter_name_en=None,
        submitter_name_yomi='キダニ\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35050': EdinetCodeEntry(
        edinet_code='E35050',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=145,
        fiscal_year_end=None,
        submitter_name='日本生命２０１９基金流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイニセンジュウキュウキキンリュウドウカカブシキカイシャ',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001201846',
    ),
    'E35056': EdinetCodeEntry(
        edinet_code='E35056',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='英知興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチコウサンカブシキガイシャ',
        address='西宮市上甲東園１丁目２３番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001185895',
    ),
    'E35057': EdinetCodeEntry(
        edinet_code='E35057',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='学校法人駿河台学園',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジンスルガダイガクエン',
        address='千代田区神田駿河台二丁目１２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005002343',
    ),
    'E35058': EdinetCodeEntry(
        edinet_code='E35058',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内藤\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='ナイトウ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35059': EdinetCodeEntry(
        edinet_code='E35059',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社都市構想',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトシコウソウ',
        address='新宿区西新宿三丁目５番３号西新宿ダイヤモンドパレス３０６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101081145',
    ),
    'E35062': EdinetCodeEntry(
        edinet_code='E35062',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松原\u3000裕樹',
        submitter_name_en=None,
        submitter_name_yomi='マツバラ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35063': EdinetCodeEntry(
        edinet_code='E35063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000剛史',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35064': EdinetCodeEntry(
        edinet_code='E35064',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＫＭＴファイナンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイケイエムティファイナンス',
        address='横浜市青葉区美しが丘五丁目１４番地６はづきビル４０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001104596',
    ),
    'E35070': EdinetCodeEntry(
        edinet_code='E35070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有賀\u3000克成',
        submitter_name_en=None,
        submitter_name_yomi='アルガ\u3000カツナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35072': EdinetCodeEntry(
        edinet_code='E35072',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉塚\u3000元一',
        submitter_name_en=None,
        submitter_name_yomi='タマツカ\u3000ゲンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35074': EdinetCodeEntry(
        edinet_code='E35074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊川\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='キクカワ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35075': EdinetCodeEntry(
        edinet_code='E35075',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ユーシージーピー\u3000ＩＶ，エル．ピー．',
        submitter_name_en=None,
        submitter_name_yomi='ユーシージーピー\u3000フォー\u3000エル\u3000ピー',
        address='ケイマン諸島、グランド・ケイマン\u3000ＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシーズ（ケイマン）リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35076': EdinetCodeEntry(
        edinet_code='E35076',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ユニゾン\u3000キャピタル\u3000パートナーズ\u3000ＩＶ（Ｆ），エル．ピー．',
        submitter_name_en=None,
        submitter_name_yomi='ユニゾン\u3000キャピタル\u3000パートナーズ\u3000フォー\u3000エフ\u3000エル\u3000ピー',
        address='ケイマン諸島、グランド・ケイマン\u3000ＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシーズ（ケイマン）リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35085': EdinetCodeEntry(
        edinet_code='E35085',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='富永\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='トミナガ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35089': EdinetCodeEntry(
        edinet_code='E35089',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=464,
        fiscal_year_end='9月30日',
        submitter_name='株式会社サイバー・バズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサイバーバズ',
        address='渋谷区桜丘町１２番１０号',
        industry='サービス業',
        sec_code='70690',
        corporate_number='2011001046938',
    ),
    'E35090': EdinetCodeEntry(
        edinet_code='E35090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森田\u3000泰成',
        submitter_name_en=None,
        submitter_name_yomi='モリタ\u3000ヤスナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35096': EdinetCodeEntry(
        edinet_code='E35096',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=511,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ギフティ',
        submitter_name_en='giftee Inc.',
        submitter_name_yomi='カブシキガイシャギフティ',
        address='品川区東五反田２－１０－２',
        industry='情報・通信業',
        sec_code='44490',
        corporate_number='4011001073617',
    ),
    'E35098': EdinetCodeEntry(
        edinet_code='E35098',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大久保\u3000俊幸',
        submitter_name_en=None,
        submitter_name_yomi='オオクボ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35099': EdinetCodeEntry(
        edinet_code='E35099',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＤＣＩパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディーシーアイパートナーズカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001160723',
    ),
    'E35104': EdinetCodeEntry(
        edinet_code='E35104',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='玉井\u3000克人',
        submitter_name_en=None,
        submitter_name_yomi='タマイ\u3000カツト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35105': EdinetCodeEntry(
        edinet_code='E35105',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村真広',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35106': EdinetCodeEntry(
        edinet_code='E35106',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村上浩輝',
        submitter_name_en=None,
        submitter_name_yomi='ムカラミ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35109': EdinetCodeEntry(
        edinet_code='E35109',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='フォローウインド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フォローウインドカブシキガイシャ',
        address='姫路市夢前町菅生澗１３５５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140001064303',
    ),
    'E35111': EdinetCodeEntry(
        edinet_code='E35111',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人鵜飼家持株会',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンウカイケモチカブカイ',
        address='八王子市城山手一丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010105002025',
    ),
    'E35114': EdinetCodeEntry(
        edinet_code='E35114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=153,
        fiscal_year_end='6月30日',
        submitter_name='ＨＰＣシステムズ株式会社',
        submitter_name_en='HPC SYSTEMS Inc.',
        submitter_name_yomi='エイチピーシーシステムズカブシキガイシャ',
        address='港区海岸三丁目９番１５号',
        industry='情報・通信業',
        sec_code='65970',
        corporate_number='4010401096252',
    ),
    'E35116': EdinetCodeEntry(
        edinet_code='E35116',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=902,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＢｕｙＳｅｌｌ\u3000Ｔｅｃｈｎｏｌｏｇｉｅｓ',
        submitter_name_en='BuySell Technologies Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャバイセルテクノロジーズ',
        address='新宿区四谷四丁目２８番８号ＰＡＬＴビル',
        industry='卸売業',
        sec_code='76850',
        corporate_number='4010001074187',
    ),
    'E35117': EdinetCodeEntry(
        edinet_code='E35117',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13,
        fiscal_year_end='12月末日',
        submitter_name='ＡＩ\u3000ＣＲＯＳＳ株式会社',
        submitter_name_en='AI CROSS Inc.',
        submitter_name_yomi='エーアイクロスカブシキガイシャ',
        address='港区西新橋三丁目１６番１１号',
        industry='情報・通信業',
        sec_code='44760',
        corporate_number='4010401117090',
    ),
    'E35118': EdinetCodeEntry(
        edinet_code='E35118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月末日',
        submitter_name='ＳＯＬＩＺＥ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソライズホールディングスカブシキガイシャ',
        address='千代田区三番町６番３号',
        industry='サービス業',
        sec_code='58710',
        corporate_number='1010001137277',
    ),
    'E35123': EdinetCodeEntry(
        edinet_code='E35123',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=324,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＢＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチビーエー',
        address='札幌市中央区北４条西７丁目１番地８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8430001022439',
    ),
    'E35124': EdinetCodeEntry(
        edinet_code='E35124',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2682,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ｋｕｂｅｌｌ',
        submitter_name_en='kubell Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクベル',
        address='港区南青山１－２４－３ＷｅＷｏｒｋ乃木坂',
        industry='情報・通信業',
        sec_code='44480',
        corporate_number='9120901014004',
    ),
    'E35125': EdinetCodeEntry(
        edinet_code='E35125',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=284,
        fiscal_year_end='7月31日',
        submitter_name='株式会社浜木綿',
        submitter_name_en='HAMAYUU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハマユウ',
        address='名古屋市昭和区山手通三丁目１３－１',
        industry='小売業',
        sec_code='76820',
        corporate_number='5180001009159',
    ),
    'E35129': EdinetCodeEntry(
        edinet_code='E35129',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中部\u3000哲二',
        submitter_name_en=None,
        submitter_name_yomi='ナカベ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35133': EdinetCodeEntry(
        edinet_code='E35133',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ポプラ社',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャポプラシャ',
        address='品川区西五反田三丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101019789',
    ),
    'E35134': EdinetCodeEntry(
        edinet_code='E35134',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10013,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ＳＮＫ',
        submitter_name_en='SNK CORPORATION',
        submitter_name_yomi='カブシキカイシャエスエヌケイ',
        address='吹田市江坂町一丁目１６番１７号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6120901008215',
    ),
    'E35136': EdinetCodeEntry(
        edinet_code='E35136',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ワシントンホテル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワシントンホテルカブシキカイシャ',
        address='名古屋市千種区内山三丁目２３番５号',
        industry='サービス業',
        sec_code='46910',
        corporate_number='3180001042070',
    ),
    'E35137': EdinetCodeEntry(
        edinet_code='E35137',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=377,
        fiscal_year_end='12月31日',
        submitter_name='株式会社パワーソリューションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャパワーソリューションズ',
        address='千代田区九段北一丁目１３番５号',
        industry='情報・通信業',
        sec_code='44500',
        corporate_number='6010001106038',
    ),
    'E35139': EdinetCodeEntry(
        edinet_code='E35139',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=874,
        fiscal_year_end='12月末日',
        submitter_name='コーユーレンティア株式会社',
        submitter_name_en='Koyou Rentia Co.,Ltd.',
        submitter_name_yomi='コーユーレンティアカブシキガイシャ',
        address='港区新橋六丁目１７番１５号',
        industry='サービス業',
        sec_code='70810',
        corporate_number='3010401025419',
    ),
    'E35140': EdinetCodeEntry(
        edinet_code='E35140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52,
        fiscal_year_end='9月30日',
        submitter_name='株式会社アンビスホールディングス',
        submitter_name_en='Amvis Holdings, Inc.',
        submitter_name_yomi='カブシキカイシャアンビスホールディングス',
        address='中央区京橋一丁目６番１号',
        industry='サービス業',
        sec_code='70710',
        corporate_number='1010001178809',
    ),
    'E35141': EdinetCodeEntry(
        edinet_code='E35141',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社インスパイアＰＮＢパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャインスパイアピーエヌビーパートナーズ',
        address='港区南青山５丁目３番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401105997',
    ),
    'E35144': EdinetCodeEntry(
        edinet_code='E35144',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=397,
        fiscal_year_end='1月31日',
        submitter_name='株式会社アールプランナー',
        submitter_name_en='Arr Planner Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアールプランナー',
        address='名古屋市東区東桜一丁目１３番３号',
        industry='不動産業',
        sec_code='29830',
        corporate_number='8180001060415',
    ),
    'E35150': EdinetCodeEntry(
        edinet_code='E35150',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=521,
        fiscal_year_end='9月末日',
        submitter_name='ＨＥＮＮＧＥ株式会社',
        submitter_name_en='HENNGE K.K.',
        submitter_name_yomi='ヘンゲカブシキカイシャ',
        address='渋谷区南平台町１６番２８号\u3000ＤＡＩＷＡ渋谷スクエア',
        industry='情報・通信業',
        sec_code='44750',
        corporate_number='2011001034562',
    ),
    'E35151': EdinetCodeEntry(
        edinet_code='E35151',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='若山\u3000健彦',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000タケヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35152': EdinetCodeEntry(
        edinet_code='E35152',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1368039,
        fiscal_year_end='12月31日',
        submitter_name='インドネシア国営電力公社',
        submitter_name_en=None,
        submitter_name_yomi='インドネシアコクエイデンリョクコウシャ',
        address='インドネシア共和国南ジャカルタ市クバヨラン・バル、トルノジョヨ通りブロックМ－Ｉ、１３５号',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E35153': EdinetCodeEntry(
        edinet_code='E35153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4122,
        fiscal_year_end='3月31日',
        submitter_name='ＳＲＥホールディングス株式会社',
        submitter_name_en='SRE Holdings Corporation',
        submitter_name_yomi='エスアールイーホールディングスカブシキカイシャ',
        address='港区赤坂一丁目８番１号',
        industry='不動産業',
        sec_code='29800',
        corporate_number='1010001160048',
    ),
    'E35154': EdinetCodeEntry(
        edinet_code='E35154',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ロバート\u3000コリック',
        submitter_name_en=None,
        submitter_name_yomi='ロバート\u3000コリック',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35157': EdinetCodeEntry(
        edinet_code='E35157',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=476,
        fiscal_year_end='9月末日',
        submitter_name='株式会社インティメート・マージャー',
        submitter_name_en='Intimate Merger, Inc.',
        submitter_name_yomi='カブシキガイシャインティメートマージャー',
        address='港区六本木三丁目５番２７号\u3000六本木山田ビル４階',
        industry='サービス業',
        sec_code='70720',
        corporate_number='4010001154311',
    ),
    'E35159': EdinetCodeEntry(
        edinet_code='E35159',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35160': EdinetCodeEntry(
        edinet_code='E35160',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='ハヤテインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハヤテインベストメントカブシキガイシャ',
        address='中央区日本橋兜町６－５\u3000兜町第６平和ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001100421',
    ),
    'E35163': EdinetCodeEntry(
        edinet_code='E35163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8513,
        fiscal_year_end='12月末日',
        submitter_name='ＢＡＳＥ株式会社',
        submitter_name_en='BASE, INC.',
        submitter_name_yomi='ベイスカブシキガイシャ',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='44770',
        corporate_number='7010401103229',
    ),
    'E35164': EdinetCodeEntry(
        edinet_code='E35164',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1042,
        fiscal_year_end='12月末日',
        submitter_name='ベース株式会社',
        submitter_name_en='BASE CO.,LTD.',
        submitter_name_yomi='ベースカブシキガイシャ',
        address='千代田区外神田四丁目１４番１号',
        industry='情報・通信業',
        sec_code='44810',
        corporate_number='9010001063813',
    ),
    'E35168': EdinetCodeEntry(
        edinet_code='E35168',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柴原\u3000慶一',
        submitter_name_en=None,
        submitter_name_yomi='シバハラ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35169': EdinetCodeEntry(
        edinet_code='E35169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1425,
        fiscal_year_end='10月末日',
        submitter_name='セルソース株式会社',
        submitter_name_en='CellSource Co.,Ltd.',
        submitter_name_yomi='セルソースカブシキガイシャ',
        address='渋谷区渋谷一丁目２３番２１号',
        industry='サービス業',
        sec_code='48800',
        corporate_number='3010401121829',
    ),
    'E35170': EdinetCodeEntry(
        edinet_code='E35170',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1653,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ダブルエー',
        submitter_name_en='WA,Inc.',
        submitter_name_yomi='カブシキガイシャダブルエー',
        address='渋谷区恵比寿一丁目２０番１８号',
        industry='小売業',
        sec_code='76830',
        corporate_number='2011001053257',
    ),
    'E35173': EdinetCodeEntry(
        edinet_code='E35173',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000和雄',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35174': EdinetCodeEntry(
        edinet_code='E35174',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000玲子',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000レイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35176': EdinetCodeEntry(
        edinet_code='E35176',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永留\u3000義己',
        submitter_name_en=None,
        submitter_name_yomi='ナガトメ\u3000ヨシキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35177': EdinetCodeEntry(
        edinet_code='E35177',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮本\u3000和明',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000カズアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35178': EdinetCodeEntry(
        edinet_code='E35178',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小椋\u3000一宏',
        submitter_name_en=None,
        submitter_name_yomi='オグラ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35179': EdinetCodeEntry(
        edinet_code='E35179',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三宅\u3000秀夫',
        submitter_name_en=None,
        submitter_name_yomi='ミヤケ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35183': EdinetCodeEntry(
        edinet_code='E35183',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=63,
        fiscal_year_end=None,
        submitter_name='Ｇ１０\u3000ＣＡＰＩＴＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ジーテン\u3000キャピタル\u3000リミテッド',
        address='４ｔｈ\u3000Ｆｌｏｏｒ，\u3000３\u3000Ｍｏｒｅ\u3000Ｌｏｎｄｏｎ\u3000Ｒｉｖｅｒｓｉｄｅ，\u3000Ｌｏｎｄｏｎ，\u3000Ｅｎｇｌａｎｄ，\u3000ＳＥ１\u3000２ＡＱ，\u3000ｔｈｅ\u3000Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35184': EdinetCodeEntry(
        edinet_code='E35184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙村\u3000彰典',
        submitter_name_en=None,
        submitter_name_yomi='タカムラ\u3000アキノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35185': EdinetCodeEntry(
        edinet_code='E35185',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関戸\u3000智行',
        submitter_name_en=None,
        submitter_name_yomi='セキド\u3000トモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35187': EdinetCodeEntry(
        edinet_code='E35187',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=96,
        fiscal_year_end='1月末日',
        submitter_name='株式会社ジェイック',
        submitter_name_en='JAIC Co., Ltd.',
        submitter_name_yomi='カブシキカイシャジェイック',
        address='千代田区神田神保町一丁目１０１番\u3000神保町１０１ビル７階',
        industry='サービス業',
        sec_code='70730',
        corporate_number='1010001066022',
    ),
    'E35188': EdinetCodeEntry(
        edinet_code='E35188',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金\u3000惠',
        submitter_name_en=None,
        submitter_name_yomi='キン\u3000メグミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35189': EdinetCodeEntry(
        edinet_code='E35189',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='太洋不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウフドウサンカブシキカイシャ',
        address='渋谷区笹塚一丁目５６番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8013201003440',
    ),
    'E35191': EdinetCodeEntry(
        edinet_code='E35191',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＤＥＡ\u3000Ｃａｐｉｔａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイデアキャピタル',
        address='中央区京橋２丁目７番８号ＦＰＧ\u3000ｌｉｎｋｓ\u3000ＫＹＯＢＡＳＨＩ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001126921',
    ),
    'E35192': EdinetCodeEntry(
        edinet_code='E35192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000侑佑',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35195': EdinetCodeEntry(
        edinet_code='E35195',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=14,
        fiscal_year_end=None,
        submitter_name='株式会社Ｆｕｎ＆Ｃｒｅａｔｉｖｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャファンアンドクリエイティブ',
        address='渋谷区恵比寿一丁目２１番１８ー５０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120901016449',
    ),
    'E35197': EdinetCodeEntry(
        edinet_code='E35197',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000愉三',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ユウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35200': EdinetCodeEntry(
        edinet_code='E35200',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000俊行',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35202': EdinetCodeEntry(
        edinet_code='E35202',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000章一',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000ショウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35203': EdinetCodeEntry(
        edinet_code='E35203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長野\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='ナガノ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35206': EdinetCodeEntry(
        edinet_code='E35206',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='ヤフー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤフーカブシキガイシャ',
        address='千代田区紀尾井町１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001200818',
    ),
    'E35208': EdinetCodeEntry(
        edinet_code='E35208',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＰＯ法人Ｃｉｇ塾',
        submitter_name_en=None,
        submitter_name_yomi='エヌピーオーホウジンシーアイジージュク',
        address='佐賀市高木瀬東２丁目２番３５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7300005006088',
    ),
    'E35209': EdinetCodeEntry(
        edinet_code='E35209',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=128,
        fiscal_year_end=None,
        submitter_name='ニューバーガー・バーマン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニューバーガーバーマンカブシキカイシャ',
        address='千代田区丸の内１－５ー１新丸の内ビルディング１２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001126515',
    ),
    'E35212': EdinetCodeEntry(
        edinet_code='E35212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安倍\u3000寛信',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000ヒロノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35216': EdinetCodeEntry(
        edinet_code='E35216',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=62,
        fiscal_year_end=None,
        submitter_name='Ｐｌｅｉａｄ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ａｄｖｉｓｏｒｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='プレイアド\u3000インベストメント\u3000アドバイザーズ\u3000リミテッド',
        address='２６ｔｈ\u3000Ｆｌｏｏｒ，Ａｓｉａ\u3000Ｐａｃｉｆｉｃ\u3000Ｃｅｎｔｒｅ，８\u3000Ｗｙｎｄｈａｍ\u3000Ｓｔｒｅｅｔ，Ｃｅｎｔｒａｌ，Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35219': EdinetCodeEntry(
        edinet_code='E35219',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=86765,
        fiscal_year_end='12月31日',
        submitter_name='バラック・ファンドＳＰＣリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='バラックファンドエスピーシーリミテッド',
        address='ケイマン諸島、ＫＹ１－１００２、グランド・ケイマン、私書箱１０２４０、サウス・チャーチ通り１０３、ハーバー・プレース４階、ハーニーズ・サービセズ（ケイマン）リミテッド気付',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E35220': EdinetCodeEntry(
        edinet_code='E35220',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1700,
        fiscal_year_end='12月末日',
        submitter_name='恵和株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイワカブシキカイシャ',
        address='中央区日本橋茅場町２－１０－５',
        industry='化学',
        sec_code='42510',
        corporate_number='1120001051649',
    ),
    'E35222': EdinetCodeEntry(
        edinet_code='E35222',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社髙井企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタカイキカク',
        address='伊勢原市高森６丁目１５番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5021001065810',
    ),
    'E35223': EdinetCodeEntry(
        edinet_code='E35223',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='グロース・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グロースキャピタルカブシキカイシャ',
        address='港区南青山三丁目８番４０号青山センタービル２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401144827',
    ),
    'E35226': EdinetCodeEntry(
        edinet_code='E35226',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='太田\u3000睦',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000ムツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35227': EdinetCodeEntry(
        edinet_code='E35227',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000達哉',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35228': EdinetCodeEntry(
        edinet_code='E35228',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳瀬\u3000文孝',
        submitter_name_en=None,
        submitter_name_yomi='ヤナセ\u3000フミタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35229': EdinetCodeEntry(
        edinet_code='E35229',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｌｉｕ\u3000Ｙａｎｇ',
        submitter_name_en=None,
        submitter_name_yomi='リウ\u3000ヤン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35230': EdinetCodeEntry(
        edinet_code='E35230',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=19323,
        fiscal_year_end='12月末日',
        submitter_name='楽天カード株式会社',
        submitter_name_en='Rakuten Card Co.,Ltd.',
        submitter_name_yomi='ラクテンカードカブシキガイシャ',
        address='港区南青山二丁目６番２１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='2010701019377',
    ),
    'E35232': EdinetCodeEntry(
        edinet_code='E35232',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='星野\u3000陽一',
        submitter_name_en=None,
        submitter_name_yomi='ホシノ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35234': EdinetCodeEntry(
        edinet_code='E35234',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1395,
        fiscal_year_end='8月31日',
        submitter_name='ホームポジション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホームポジションカブシキカイシャ',
        address='静岡市清水区吉川２６０番地',
        industry='不動産業',
        sec_code='29990',
        corporate_number='5080001004715',
    ),
    'E35235': EdinetCodeEntry(
        edinet_code='E35235',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2100,
        fiscal_year_end=None,
        submitter_name='株式会社ＷｅａｌｔｈＢｒｏｔｈｅｒｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウエルスブラザーズ',
        address='港区芝大門一丁目３番１０号コスモタワービル７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401132566',
    ),
    'E35236': EdinetCodeEntry(
        edinet_code='E35236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中谷\u3000宅雄',
        submitter_name_en=None,
        submitter_name_yomi='ナカタニ\u3000タクヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35237': EdinetCodeEntry(
        edinet_code='E35237',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｆｉｒｓｔ\u3000Ｌｉｎｋ\u3000Ｉｎｃ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ファースト\u3000リンク\u3000インク\u3000リミテッド',
        address='香港チャイワン、サン・イップ・ストリート８、エイト・コマーシャルタワー・フラット１２０８－９号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35238': EdinetCodeEntry(
        edinet_code='E35238',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=172,
        fiscal_year_end='11月30日',
        submitter_name='株式会社トゥエンティーフォーセブンホールディングス',
        submitter_name_en='Twenty-four seven Holdings Inc.',
        submitter_name_yomi='カブシキガイシャトゥエンティーフォーセブンホールディングス',
        address='品川区東品川二丁目３番１２号',
        industry='サービス業',
        sec_code='70740',
        corporate_number='6010001115154',
    ),
    'E35239': EdinetCodeEntry(
        edinet_code='E35239',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=101,
        fiscal_year_end=None,
        submitter_name='光通信株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒカリツウシンカブシキガイシャ',
        address='豊島区西池袋一丁目４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001143423',
    ),
    'E35240': EdinetCodeEntry(
        edinet_code='E35240',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3100,
        fiscal_year_end=None,
        submitter_name='ＮＨＮ\u3000ＪＡＰＡＮ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエイチエヌジャパンカブシキガイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001094268',
    ),
    'E35243': EdinetCodeEntry(
        edinet_code='E35243',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='兼子\u3000浩之',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35244': EdinetCodeEntry(
        edinet_code='E35244',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000成信',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ナルノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35247': EdinetCodeEntry(
        edinet_code='E35247',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡部\u3000典子',
        submitter_name_en=None,
        submitter_name_yomi='オカベ\u3000ノリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35248': EdinetCodeEntry(
        edinet_code='E35248',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小島礼大',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000ヒロオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35250': EdinetCodeEntry(
        edinet_code='E35250',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=54,
        fiscal_year_end='11月30日',
        submitter_name='ＡＨＣグループ株式会社',
        submitter_name_en='AHC GROUP INC.',
        submitter_name_yomi='エイエイチシーグループカブシキガイシャ',
        address='千代田区岩本町二丁目１１番９号',
        industry='サービス業',
        sec_code='70830',
        corporate_number='4010001139584',
    ),
    'E35252': EdinetCodeEntry(
        edinet_code='E35252',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＢＩサーチ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイビーアイサーチ',
        address='港区芝大門２－７－１－４０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401055992',
    ),
    'E35254': EdinetCodeEntry(
        edinet_code='E35254',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=77293,
        fiscal_year_end=None,
        submitter_name='ＳＯＳｉＬＡ物流リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ソシラブツリュウリートトウシホウジン',
        address='中央区京橋一丁目１７番１０号\u3000住友商事京橋ビル９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005030387',
    ),
    'E35258': EdinetCodeEntry(
        edinet_code='E35258',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=310,
        fiscal_year_end='9月30日',
        submitter_name='名南Ｍ＆Ａ株式会社',
        submitter_name_en='meinan M&A co.,ltd.',
        submitter_name_yomi='メイナンエムアンドエーカブシキガイシャ',
        address='名古屋市中村区名駅一丁目１番１号\u3000ＪＰタワー名古屋',
        industry='サービス業',
        sec_code='70760',
        corporate_number='1180001116041',
    ),
    'E35259': EdinetCodeEntry(
        edinet_code='E35259',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=228,
        fiscal_year_end=None,
        submitter_name='株式会社名南経営コンサルティング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメイナンケイエイコンサルティング',
        address='名古屋市中村区名駅一丁目１番１号ＪＰタワー名古屋',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180001022965',
    ),
    'E35263': EdinetCodeEntry(
        edinet_code='E35263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本出版販売株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンシュッパンハンバイカブシキカイシャ',
        address='千代田区神田駿河台４丁目３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001199727',
    ),
    'E35264': EdinetCodeEntry(
        edinet_code='E35264',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鶴岡\u3000裕太',
        submitter_name_en=None,
        submitter_name_yomi='ツルオカ\u3000ユウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35276': EdinetCodeEntry(
        edinet_code='E35276',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='天野\u3000一八',
        submitter_name_en=None,
        submitter_name_yomi='アマノ\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35278': EdinetCodeEntry(
        edinet_code='E35278',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=388,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ビザスク',
        submitter_name_en='VisasQ Inc.',
        submitter_name_yomi='カブシキガイシャビザスク',
        address='目黒区青葉台四丁目７番７号住友不動産青葉台ヒルズ９Ｆ',
        industry='情報・通信業',
        sec_code='44900',
        corporate_number='5010001145747',
    ),
    'E35279': EdinetCodeEntry(
        edinet_code='E35279',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000剛志',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35280': EdinetCodeEntry(
        edinet_code='E35280',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=11226,
        fiscal_year_end='12月31日',
        submitter_name='Ｓｐｉｂｅｒ株式会社',
        submitter_name_en='Spiber Inc.',
        submitter_name_yomi='スパイバーカブシキガイシャ',
        address='鶴岡市覚岸寺字水上２３４番地１',
        industry='その他製品',
        sec_code=None,
        corporate_number='5390001008354',
    ),
    'E35282': EdinetCodeEntry(
        edinet_code='E35282',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=637,
        fiscal_year_end=None,
        submitter_name='日本生命第４回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイヨンカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001204590',
    ),
    'E35283': EdinetCodeEntry(
        edinet_code='E35283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ブイ・シー・エヌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャブイシーエヌ',
        address='渋谷区恵比寿西１－８－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001029248',
    ),
    'E35284': EdinetCodeEntry(
        edinet_code='E35284',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=246,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ウィルズ',
        submitter_name_en='WILLs Inc.',
        submitter_name_yomi='カブシキガイシャウィルズ',
        address='港区虎ノ門二丁目３番１７号虎ノ門２丁目タワー',
        industry='情報・通信業',
        sec_code='44820',
        corporate_number='5011001056678',
    ),
    'E35285': EdinetCodeEntry(
        edinet_code='E35285',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='簗島\u3000亮次',
        submitter_name_en=None,
        submitter_name_yomi='ヤナシマ\u3000リョウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35287': EdinetCodeEntry(
        edinet_code='E35287',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=59,
        fiscal_year_end='3月末日',
        submitter_name='ランサーズ株式会社',
        submitter_name_en='LANCERS,INC.',
        submitter_name_yomi='ランサーズカブシキガイシャ',
        address='渋谷区渋谷三丁目１０番１３号',
        industry='情報・通信業',
        sec_code='44840',
        corporate_number='6021001024617',
    ),
    'E35288': EdinetCodeEntry(
        edinet_code='E35288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=138,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＡＬｉＮＫインターネット',
        submitter_name_en='ALiNK Internet, INC.',
        submitter_name_yomi='カブシキガイシャアリンクインターネット',
        address='豊島区南池袋二丁目２９番１１号京王プレッソイン池袋２階',
        industry='サービス業',
        sec_code='70770',
        corporate_number='6011001094074',
    ),
    'E35289': EdinetCodeEntry(
        edinet_code='E35289',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=308,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジモティー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジモティー',
        address='品川区西五反田１－２－１０',
        industry='サービス業',
        sec_code='70820',
        corporate_number='3011001068337',
    ),
    'E35291': EdinetCodeEntry(
        edinet_code='E35291',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35000,
        fiscal_year_end=None,
        submitter_name='ａｕフィナンシャルホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーユーフィナンシャルホールディングスカブシキカイシャ',
        address='港区高輪２丁目２１番２号\u3000ＴＨＥ\u3000ＬＩＮＫＰＩＬＬＡＲ１\u3000ＮＯＲＴＨ１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001198199',
    ),
    'E35292': EdinetCodeEntry(
        edinet_code='E35292',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長村\u3000惠弌',
        submitter_name_en=None,
        submitter_name_yomi='オサムラ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35294': EdinetCodeEntry(
        edinet_code='E35294',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月末日',
        submitter_name='株式会社テクノフレックス',
        submitter_name_en='TECHNOFLEX CORPORATION',
        submitter_name_yomi='カブシキガイシャテクノフレックス',
        address='台東区蔵前一丁目５番１号',
        industry='金属製品',
        sec_code='34490',
        corporate_number='3010501032975',
    ),
    'E35297': EdinetCodeEntry(
        edinet_code='E35297',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ミアヘルサ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミアヘルサカブシキガイシャ',
        address='新宿区市谷仲之町３番１９号',
        industry='小売業',
        sec_code=None,
        corporate_number='4011101029023',
    ),
    'E35298': EdinetCodeEntry(
        edinet_code='E35298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='裙本\u3000理人',
        submitter_name_en=None,
        submitter_name_yomi='ツマモト\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35299': EdinetCodeEntry(
        edinet_code='E35299',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='有限会社コモリ企画',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャコモリキカク',
        address='名古屋市昭和区白金二丁目４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180002044876',
    ),
    'E35300': EdinetCodeEntry(
        edinet_code='E35300',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='正喜商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マサキショウジカブシキガイシャ',
        address='千代田区内神田２－８－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001018693',
    ),
    'E35302': EdinetCodeEntry(
        edinet_code='E35302',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2266,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ロコガイド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャロコガイド',
        address='港区三田一丁目４番２８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1011001111726',
    ),
    'E35303': EdinetCodeEntry(
        edinet_code='E35303',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=488,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ランディックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャランディックス',
        address='世田谷区新町３－２２－２\u3000ランディックスビルファースト',
        industry='不動産業',
        sec_code='29810',
        corporate_number='3010901014739',
    ),
    'E35304': EdinetCodeEntry(
        edinet_code='E35304',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=444,
        fiscal_year_end=None,
        submitter_name='農林中金バリューインベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノウリンチュウキンバリューインベストメンツカブシキガイシャ',
        address='千代田区内幸町二丁目２番３号\u3000日比谷国際ビル１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001163354',
    ),
    'E35307': EdinetCodeEntry(
        edinet_code='E35307',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=311,
        fiscal_year_end='12月31日',
        submitter_name='ユナイトアンドグロウ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユナイトアンドグロウカブシキガイシャ',
        address='千代田区神田駿河台四丁目３番地',
        industry='情報・通信業',
        sec_code='44860',
        corporate_number='4011101061083',
    ),
    'E35308': EdinetCodeEntry(
        edinet_code='E35308',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25163,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＭＤＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジェイエムディーシー',
        address='港区芝大門二丁目５番５号',
        industry='情報・通信業',
        sec_code='44830',
        corporate_number='6010403010531',
    ),
    'E35309': EdinetCodeEntry(
        edinet_code='E35309',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000修士',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000シュウシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35310': EdinetCodeEntry(
        edinet_code='E35310',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河野\u3000恭佑',
        submitter_name_en=None,
        submitter_name_yomi='コウノ\u3000キョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35311': EdinetCodeEntry(
        edinet_code='E35311',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エムジェイ・アール合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エムジェイアールゴウドウガイシャ',
        address='足柄下郡湯河原町吉浜１４８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010903003523',
    ),
    'E35313': EdinetCodeEntry(
        edinet_code='E35313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森川\u3000智',
        submitter_name_en=None,
        submitter_name_yomi='モリカワ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35316': EdinetCodeEntry(
        edinet_code='E35316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山川\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35317': EdinetCodeEntry(
        edinet_code='E35317',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='シリアルインキュベート株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シリアルインキュベートカブシキガイシャ',
        address='渋谷区渋谷１－２０－１\u3000井門美竹ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001103679',
    ),
    'E35318': EdinetCodeEntry(
        edinet_code='E35318',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2207,
        fiscal_year_end='3月末日',
        submitter_name='株式会社Ｆａｓｔ\u3000Ｆｉｔｎｅｓｓ\u3000Ｊａｐａｎ',
        submitter_name_en='Fast Fitness Japan Incorporated',
        submitter_name_yomi='カブシキガイシャファストフィットネスジャパン',
        address='新宿区西新宿六丁目３番１号',
        industry='サービス業',
        sec_code='70920',
        corporate_number='8030001054043',
    ),
    'E35319': EdinetCodeEntry(
        edinet_code='E35319',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000洋人',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ヒロト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35320': EdinetCodeEntry(
        edinet_code='E35320',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ハヤテマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハヤテマネジメントカブシキガイシャ',
        address='中央区日本橋兜町６－５\u3000兜町第６平和ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001204635',
    ),
    'E35321': EdinetCodeEntry(
        edinet_code='E35321',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑野\u3000幸治',
        submitter_name_en=None,
        submitter_name_yomi='ハタノ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35322': EdinetCodeEntry(
        edinet_code='E35322',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='有限会社ＳＨホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャエスエッチホールディングス',
        address='港区赤坂１－１２－３２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011002026750',
    ),
    'E35323': EdinetCodeEntry(
        edinet_code='E35323',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社スポーツフィールド',
        submitter_name_en='Sportsfield Co., Ltd.',
        submitter_name_yomi='カブシキガイシャスポーツフィールド',
        address='新宿区市谷本村町３番２９号\u3000ＦＯＲＥＣＡＳＴ市ヶ谷４Ｆ',
        industry='サービス業',
        sec_code='70800',
        corporate_number='2011001063479',
    ),
    'E35324': EdinetCodeEntry(
        edinet_code='E35324',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=47599,
        fiscal_year_end=None,
        submitter_name='ネオファースト生命保険株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ネオファーストセイメイホケンカブシキガイシャ',
        address='品川区大崎２－１１－１大崎ウィズタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101052339',
    ),
    'E35325': EdinetCodeEntry(
        edinet_code='E35325',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='フリー株式会社',
        submitter_name_en='freee K.K.',
        submitter_name_yomi='フリーカブシキカイシャ',
        address='東京都品川区大崎一丁目２番２号',
        industry='情報・通信業',
        sec_code='44780',
        corporate_number='7010401100770',
    ),
    'E35327': EdinetCodeEntry(
        edinet_code='E35327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='肖\u3000俊偉',
        submitter_name_en=None,
        submitter_name_yomi='ショウ\u3000シュンイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35329': EdinetCodeEntry(
        edinet_code='E35329',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35330': EdinetCodeEntry(
        edinet_code='E35330',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=625,
        fiscal_year_end='12月31日',
        submitter_name='株式会社スペースマーケット',
        submitter_name_en='Spacemarket Inc.',
        submitter_name_yomi='カブシキカイシャスペースマーケット',
        address='渋谷区神宮前六丁目２５番１４号',
        industry='情報・通信業',
        sec_code='44870',
        corporate_number='9011301020099',
    ),
    'E35331': EdinetCodeEntry(
        edinet_code='E35331',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡本吉起',
        submitter_name_en=None,
        submitter_name_yomi='オカモトヨシキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35332': EdinetCodeEntry(
        edinet_code='E35332',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='川井\u3000啓',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000ケイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35333': EdinetCodeEntry(
        edinet_code='E35333',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7989,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＴＯＷＥＲ',
        submitter_name_en='JTOWER Inc.',
        submitter_name_yomi='カブシキガイシャジェイタワー',
        address='港区南青山二丁目２番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5011001090314',
    ),
    'E35334': EdinetCodeEntry(
        edinet_code='E35334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=373,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ひとまいる',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒトマイル',
        address='北区豊島二丁目３番１号',
        industry='卸売業',
        sec_code='76860',
        corporate_number='2011501000964',
    ),
    'E35335': EdinetCodeEntry(
        edinet_code='E35335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=269,
        fiscal_year_end='3月31日',
        submitter_name='ＷＤＢココ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダブリューディービーココカブシキガイシャ',
        address='中央区晴海一丁目８－１１',
        industry='サービス業',
        sec_code='70790',
        corporate_number='9010001139654',
    ),
    'E35336': EdinetCodeEntry(
        edinet_code='E35336',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ｕｎｅａｒｔｈ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='アンアースインターナショナルリミテッド',
        address='Ｆ２０，１ｓｔ\u3000Ｆｌｏｏｒ，Ｅｄｅｎ\u3000Ｐｌａｚａ，Ｅｄｅｎ\u3000Ｉｓｌａｎｄ，Ｓｅｙｃｈｅｌｌｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35339': EdinetCodeEntry(
        edinet_code='E35339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000俊介',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000シュンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35340': EdinetCodeEntry(
        edinet_code='E35340',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6283,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＡＤワークスグループ',
        submitter_name_en='A.D.Works Group Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャエーディーワークスグループ',
        address='千代田区内幸町二丁目２番３号',
        industry='不動産業',
        sec_code='29820',
        corporate_number='1010001208771',
    ),
    'E35341': EdinetCodeEntry(
        edinet_code='E35341',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='ＩＮＣＬＵＳＩＶＥ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インクルーシブホールディングスカブシキカイシャ',
        address='港区虎ノ門４－１－１',
        industry='サービス業',
        sec_code='70780',
        corporate_number='3010401068418',
    ),
    'E35344': EdinetCodeEntry(
        edinet_code='E35344',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＱＬＳホールディングス',
        submitter_name_en='QLS Holdings Co., Ltd',
        submitter_name_yomi='カブシキガイシャキューエルエスホールディングス',
        address='大阪市浪速区難波中一丁目１２－５\u3000難波室町ビル３階',
        industry='サービス業',
        sec_code='70750',
        corporate_number='9120001219189',
    ),
    'E35345': EdinetCodeEntry(
        edinet_code='E35345',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1233,
        fiscal_year_end='3月31日',
        submitter_name='ＡＩ\u3000ｉｎｓｉｄｅ株式会社',
        submitter_name_en='AI inside Inc.',
        submitter_name_yomi='エーアイインサイドカブシキガイシャ',
        address='渋谷区渋谷三丁目８番１２号',
        industry='情報・通信業',
        sec_code='44880',
        corporate_number='6011001106762',
    ),
    'E35347': EdinetCodeEntry(
        edinet_code='E35347',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡久地\u3000択',
        submitter_name_en=None,
        submitter_name_yomi='トグチ\u3000タク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35348': EdinetCodeEntry(
        edinet_code='E35348',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥田\u3000清人',
        submitter_name_en=None,
        submitter_name_yomi='オクダ\u3000キヨヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35349': EdinetCodeEntry(
        edinet_code='E35349',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35350': EdinetCodeEntry(
        edinet_code='E35350',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='雨田\u3000武史',
        submitter_name_en=None,
        submitter_name_yomi='アメダ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35354': EdinetCodeEntry(
        edinet_code='E35354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=410,
        fiscal_year_end='12月31日',
        submitter_name='株式会社サイバーセキュリティクラウド',
        submitter_name_en='Cyber Security Cloud , Inc.',
        submitter_name_yomi='カブシキガイシャサイバーセキュリティクラウド',
        address='品川区上大崎３－１－１ＪＲ東急目黒ビル１３階',
        industry='情報・通信業',
        sec_code='44930',
        corporate_number='9011001066277',
    ),
    'E35359': EdinetCodeEntry(
        edinet_code='E35359',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='須田\u3000騎一朗',
        submitter_name_en=None,
        submitter_name_yomi='スダ\u3000キイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35360': EdinetCodeEntry(
        edinet_code='E35360',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='中央日本土地建物グループ株式会社',
        submitter_name_en='Chuo-Nittochi Group Co., Ltd.',
        submitter_name_yomi='チュウオウニホントチタテモノグループカブシキガイシャ',
        address='千代田区霞が関一丁目４番１号',
        industry='不動産業',
        sec_code=None,
        corporate_number='3010001208844',
    ),
    'E35364': EdinetCodeEntry(
        edinet_code='E35364',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松島\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='マツシマ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35366': EdinetCodeEntry(
        edinet_code='E35366',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀧口\u3000浩平',
        submitter_name_en=None,
        submitter_name_yomi='タキグチ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35368': EdinetCodeEntry(
        edinet_code='E35368',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊田\u3000剛一郎',
        submitter_name_en=None,
        submitter_name_yomi='トヨダ\u3000ゴウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35369': EdinetCodeEntry(
        edinet_code='E35369',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ティーエムアセット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーエムアセット',
        address='市川市堀之内四丁目１０番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040001030664',
    ),
    'E35371': EdinetCodeEntry(
        edinet_code='E35371',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='汐留Ｚホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='シオドメゼットホールディングスゴウドウカイシャ',
        address='港区東新橋１丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001111252',
    ),
    'E35375': EdinetCodeEntry(
        edinet_code='E35375',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＲＢＪ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アールビージェイカブシキカイシャ',
        address='港区虎ノ門二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401149270',
    ),
    'E35377': EdinetCodeEntry(
        edinet_code='E35377',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＫＹグループホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャスカイグループホールディングス',
        address='千代田区神田須田町１－１２山萬ビル９０７号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011501013853',
    ),
    'E35378': EdinetCodeEntry(
        edinet_code='E35378',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='端羽\u3000英子',
        submitter_name_en=None,
        submitter_name_yomi='ハシバ\u3000エイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35379': EdinetCodeEntry(
        edinet_code='E35379',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3500,
        fiscal_year_end=None,
        submitter_name='ルックスオティカ・グループ・エスピーエー',
        submitter_name_en=None,
        submitter_name_yomi='ルックスオティカグループエスピーエー',
        address='イタリア\u3000２０１２３\u3000ミラノ\u3000ピアッツァーレ・ルイージ・カドルナ３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35380': EdinetCodeEntry(
        edinet_code='E35380',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='古賀\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='コガ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35381': EdinetCodeEntry(
        edinet_code='E35381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='梢\u3000政樹',
        submitter_name_en=None,
        submitter_name_yomi='コズエ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35388': EdinetCodeEntry(
        edinet_code='E35388',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＢＡＳＥ沖縄野球球団',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベースオキナワヤキュウキュウダン',
        address='宜野湾市真志喜二丁目２７番８号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7360001026002',
    ),
    'E35389': EdinetCodeEntry(
        edinet_code='E35389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木下\u3000昭彦',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35391': EdinetCodeEntry(
        edinet_code='E35391',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000ＨＯＳＯＫＡＷＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャホソカワ',
        address='渋谷区道玄坂一丁目１９番１３号５Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010901035577',
    ),
    'E35392': EdinetCodeEntry(
        edinet_code='E35392',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋好\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='アキヨシ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35393': EdinetCodeEntry(
        edinet_code='E35393',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社シティインデックスイレブンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシティインデックスイレブンス',
        address='渋谷区南平台町３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401082024',
    ),
    'E35395': EdinetCodeEntry(
        edinet_code='E35395',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木\u3000綠',
        submitter_name_en=None,
        submitter_name_yomi='ミキ\u3000ミドリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35396': EdinetCodeEntry(
        edinet_code='E35396',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＬＦ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティーエルエフ',
        address='中央区銀座６丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9013303003940',
    ),
    'E35397': EdinetCodeEntry(
        edinet_code='E35397',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ワングローブキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワングローブキャピタル',
        address='品川区西五反田一丁目１１番１号アイオス五反田駅前',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401143901',
    ),
    'E35398': EdinetCodeEntry(
        edinet_code='E35398',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＵＧアセット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスユージーアセットカブシキガイシャ',
        address='港区六本木１丁目５番３－１８０４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401146839',
    ),
    'E35400': EdinetCodeEntry(
        edinet_code='E35400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='蓮本\u3000泰之',
        submitter_name_en=None,
        submitter_name_yomi='ハスモト\u3000ヤスユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35410': EdinetCodeEntry(
        edinet_code='E35410',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＡＪホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエイジェイホールディングスカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号明治安田生命ビル１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001202602',
    ),
    'E35411': EdinetCodeEntry(
        edinet_code='E35411',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=68,
        fiscal_year_end=None,
        submitter_name='株式会社森本本店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャモリモトホンテン',
        address='一宮市浅野字西大土九十六番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001085147',
    ),
    'E35413': EdinetCodeEntry(
        edinet_code='E35413',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社富士教育創研',
        submitter_name_en=None,
        submitter_name_yomi='フジキョウイクソウケン',
        address='大阪市天王寺区上本町五丁目３番９－１１０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001115585',
    ),
    'E35415': EdinetCodeEntry(
        edinet_code='E35415',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000克成',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000カツナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35419': EdinetCodeEntry(
        edinet_code='E35419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩田\u3000匡平',
        submitter_name_en=None,
        submitter_name_yomi='イワタ\u3000キョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35420': EdinetCodeEntry(
        edinet_code='E35420',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤田\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35421': EdinetCodeEntry(
        edinet_code='E35421',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000敦史',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35422': EdinetCodeEntry(
        edinet_code='E35422',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000康子',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35423': EdinetCodeEntry(
        edinet_code='E35423',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=120,
        fiscal_year_end=None,
        submitter_name='ジャパン・インフラファンド投資法人',
        submitter_name_en=None,
        submitter_name_yomi='ジャパン\u3000インフラファンドトウシホウジン',
        address='中央区日本橋茅場町二丁目１０番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010005030940',
    ),
    'E35432': EdinetCodeEntry(
        edinet_code='E35432',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='株式会社カルティブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカルティブ',
        address='港区元麻布二丁目７番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401067661',
    ),
    'E35436': EdinetCodeEntry(
        edinet_code='E35436',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森本\u3000翔太',
        submitter_name_en=None,
        submitter_name_yomi='モリモト\u3000ショウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35439': EdinetCodeEntry(
        edinet_code='E35439',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='重松\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='シゲマツ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35442': EdinetCodeEntry(
        edinet_code='E35442',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ミダスキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミダスキャピタル',
        address='千代田区九段南２－２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001186226',
    ),
    'E35443': EdinetCodeEntry(
        edinet_code='E35443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='篠﨑\u3000克志',
        submitter_name_en=None,
        submitter_name_yomi='シノザキ\u3000カツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35444': EdinetCodeEntry(
        edinet_code='E35444',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加地\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='カジ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35446': EdinetCodeEntry(
        edinet_code='E35446',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4346,
        fiscal_year_end=None,
        submitter_name='ＧＭＯクリック証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーエムオークリックショウケンカブシキカイシャ',
        address='渋谷区道玄坂１－２－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001045946',
    ),
    'E35447': EdinetCodeEntry(
        edinet_code='E35447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='Ｂｏｎｄｓ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｇｒｏｕｐ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ボンズインベストメントグループカブシキガイシャ',
        address='渋谷区千駄ヶ谷３丁目３－３２－３０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001166268',
    ),
    'E35448': EdinetCodeEntry(
        edinet_code='E35448',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社アクアマリーン',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャアクアマリーン',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010003023929',
    ),
    'E35449': EdinetCodeEntry(
        edinet_code='E35449',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=744,
        fiscal_year_end='3月31日',
        submitter_name='木村工機株式会社',
        submitter_name_en='KIMURA KOHKI Co.,Ltd.',
        submitter_name_yomi='キムラコウキカブシキガイシャ',
        address='大阪市中央区上町Ａ番２３号',
        industry='機械',
        sec_code='62310',
        corporate_number='9120001077892',
    ),
    'E35450': EdinetCodeEntry(
        edinet_code='E35450',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エリオット・インベストメント・マネージメント・エルピー（Ｅｌｌｉｏｔｔ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌ．Ｐ．）',
        submitter_name_en=None,
        submitter_name_yomi='エリオットインベストメントマネージメントエルピー',
        address='アメリカ合衆国、デラウェア州１９８０１、ニューカッスル群、ウィルミントン、オレンジストリート１２０９、コーポレーション・トラスト・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35451': EdinetCodeEntry(
        edinet_code='E35451',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊地知\u3000和義',
        submitter_name_en=None,
        submitter_name_yomi='イジチ\u3000カズヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35453': EdinetCodeEntry(
        edinet_code='E35453',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='有限会社スプラウト',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャスプラウト',
        address='千代田区神田須田町一丁目１２番地山萬ビル９０７号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010002037532',
    ),
    'E35459': EdinetCodeEntry(
        edinet_code='E35459',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＩＸＧＳ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='アイエックスジーエス\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35460': EdinetCodeEntry(
        edinet_code='E35460',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ディーシーエム・インターナショナル・シックス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ディーシーエムインターナショナルシックスリミテッド',
        address='ケイマン諸島、ＫＹ１－９０１０、グランド・ケイマン、クリケット・スクエア、ウィロウ・ハウス４階、キャンベルズ・コーポレート・サービシズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35464': EdinetCodeEntry(
        edinet_code='E35464',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='株式会社富士ロジテックホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジロジテックホールディングス',
        address='静岡市清水区清開二丁目２番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080001004503',
    ),
    'E35466': EdinetCodeEntry(
        edinet_code='E35466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=404,
        fiscal_year_end='3月31日',
        submitter_name='コンピューターマネージメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コンピューターマネージメントカブシキカイシャ',
        address='大阪市北区梅田一丁目１３番１号',
        industry='情報・通信業',
        sec_code='44910',
        corporate_number='8120001028938',
    ),
    'E35467': EdinetCodeEntry(
        edinet_code='E35467',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='ワイドフレンズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイドフレンズカブシキガイシャ',
        address='中央区月島一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401009869',
    ),
    'E35468': EdinetCodeEntry(
        edinet_code='E35468',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ディパーチャー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ディパーチャーリミテッド',
        address='英国領西インド諸島ケイマン諸島グランドケイマン、ジョージタウン、サウスチャーチストリート、クイーンズゲートハウス、私書箱１０９３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2700150005024',
    ),
    'E35470': EdinetCodeEntry(
        edinet_code='E35470',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=159,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ウイルテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウイルテック',
        address='大阪市淀川区東三国四丁目３番１号',
        industry='サービス業',
        sec_code='70870',
        corporate_number='3120001157048',
    ),
    'E35473': EdinetCodeEntry(
        edinet_code='E35473',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中谷\u3000正和',
        submitter_name_en=None,
        submitter_name_yomi='ナカタニ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35482': EdinetCodeEntry(
        edinet_code='E35482',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ペイロール',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャペイロール',
        address='江東区有明三丁目５番７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='9010001183108',
    ),
    'E35483': EdinetCodeEntry(
        edinet_code='E35483',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=238,
        fiscal_year_end='3月31日',
        submitter_name='フォースタートアップス株式会社',
        submitter_name_en='for Startups, Inc.',
        submitter_name_yomi='フォースタートアップスカブシキカイシャ',
        address='港区麻布台一丁目３番１号',
        industry='サービス業',
        sec_code='70890',
        corporate_number='1011201019356',
    ),
    'E35485': EdinetCodeEntry(
        edinet_code='E35485',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＫＳ\u3000Ａｖｉａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャケーエスアビエーション',
        address='金沢市泉が丘２丁目１２番１３番',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8220003002071',
    ),
    'E35486': EdinetCodeEntry(
        edinet_code='E35486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社Ａ８７０',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエーハチナナマル',
        address='金沢市泉野町１丁目８番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7220003002072',
    ),
    'E35487': EdinetCodeEntry(
        edinet_code='E35487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=117,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フォーラムエンジニアリング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフォーラムエンジニアリング',
        address='港区虎ノ門二丁目１０番４号',
        industry='サービス業',
        sec_code='70880',
        corporate_number='3010401025641',
    ),
    'E35488': EdinetCodeEntry(
        edinet_code='E35488',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=848,
        fiscal_year_end='8月31日',
        submitter_name='株式会社カーブスホールディングス',
        submitter_name_en='CURVES HOLDINGS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャカーブスホールディングス',
        address='港区芝浦三丁目９番１号',
        industry='サービス業',
        sec_code='70850',
        corporate_number='5070001005771',
    ),
    'E35489': EdinetCodeEntry(
        edinet_code='E35489',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｓｍｉｌｅ\u3000Ｈｏｌｄｉｎｇｓ',
        submitter_name_en='Smile Holdings Inc.',
        submitter_name_yomi='カブシキガイシャスマイルホールディングス',
        address='品川区西五反田一丁目３番８号',
        industry='サービス業',
        sec_code='70840',
        corporate_number='3010701035613',
    ),
    'E35490': EdinetCodeEntry(
        edinet_code='E35490',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12663,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000小笠原敏晶記念財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000オガサワラトシアキキネンザイダン',
        address='港区芝５丁目２７番６号\u3000泉田町ビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010405000062',
    ),
    'E35491': EdinetCodeEntry(
        edinet_code='E35491',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=89,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ミクリード',
        submitter_name_en='MICREED Co., Ltd.',
        submitter_name_yomi='カブシキガイシャミクリード',
        address='中央区日本橋二丁目１６番１３号',
        industry='卸売業',
        sec_code='76870',
        corporate_number='7011501018184',
    ),
    'E35493': EdinetCodeEntry(
        edinet_code='E35493',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=788,
        fiscal_year_end='2月末日',
        submitter_name='株式会社関通',
        submitter_name_en='KANTSU CO.,LTD.',
        submitter_name_yomi='カブシキガイシャカンツウ',
        address='尼崎市西向島町１１１番地の４',
        industry='倉庫・運輸関連',
        sec_code='93260',
        corporate_number='7122001008714',
    ),
    'E35495': EdinetCodeEntry(
        edinet_code='E35495',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=159,
        fiscal_year_end='5月31日',
        submitter_name='株式会社きずなホールディングス',
        submitter_name_en='KIZUNA HOLDINGS Corp.',
        submitter_name_yomi='キズナホールディングス',
        address='港区浜松町二丁目２番１２号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401131878',
    ),
    'E35496': EdinetCodeEntry(
        edinet_code='E35496',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3079,
        fiscal_year_end='3月31日',
        submitter_name='ステラファーマ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ステラファーマカブシキガイシャ',
        address='大阪市中央区高麗橋三丁目２番７号\u3000ＯＲＩＸ高麗橋ビル',
        industry='医薬品',
        sec_code='48880',
        corporate_number='5120001124194',
    ),
    'E35497': EdinetCodeEntry(
        edinet_code='E35497',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1200,
        fiscal_year_end='3月末日',
        submitter_name='日本インシュレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンインシュレーションカブシキガイシャ',
        address='大阪市中央区南船場一丁目１８番１７号',
        industry='ガラス・土石製品',
        sec_code='53680',
        corporate_number='1120001040610',
    ),
    'E35504': EdinetCodeEntry(
        edinet_code='E35504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=358,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ゼネテック',
        submitter_name_en='GENETEC CORPORATION',
        submitter_name_yomi='カブシキガイシャゼネテック',
        address='新宿区西新宿六丁目５番１号',
        industry='情報・通信業',
        sec_code='44920',
        corporate_number='7011101011259',
    ),
    'E35505': EdinetCodeEntry(
        edinet_code='E35505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000正文',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000マサブミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35508': EdinetCodeEntry(
        edinet_code='E35508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=358,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リビングプラットフォーム',
        submitter_name_en='Living Platform, Ltd.',
        submitter_name_yomi='カブシキカイシャリビングプラットフォーム',
        address='札幌市中央区南二条西二十丁目２９１番地',
        industry='サービス業',
        sec_code='70910',
        corporate_number='4430001059195',
    ),
    'E35510': EdinetCodeEntry(
        edinet_code='E35510',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1939,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ペルセウスプロテオミクス',
        submitter_name_en='Perseus Proteomics Inc.',
        submitter_name_yomi='カブシキカイシャペルセウスプロテオミクス',
        address='目黒区駒場四丁目７番６号',
        industry='医薬品',
        sec_code='48820',
        corporate_number='1013201011111',
    ),
    'E35512': EdinetCodeEntry(
        edinet_code='E35512',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='北國総合リース株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホツコクソウゴウリースカブシキガイシヤ',
        address='金沢市広岡２丁目１２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4220001006202',
    ),
    'E35514': EdinetCodeEntry(
        edinet_code='E35514',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99,
        fiscal_year_end='12月末日',
        submitter_name='アディッシュ株式会社',
        submitter_name_en='adish Co., Ltd.',
        submitter_name_yomi='アディッシュカブシキガイシャ',
        address='品川区西五反田一丁目２１番８号',
        industry='サービス業',
        sec_code='70930',
        corporate_number='1010701029988',
    ),
    'E35516': EdinetCodeEntry(
        edinet_code='E35516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=836,
        fiscal_year_end='3月31日',
        submitter_name='サイバートラスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイバートラストカブシキガイシャ',
        address='港区赤坂一丁目１２番３２号\u3000アーク森ビル３１階',
        industry='情報・通信業',
        sec_code='44980',
        corporate_number='3010401064771',
    ),
    'E35518': EdinetCodeEntry(
        edinet_code='E35518',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2700,
        fiscal_year_end='12月末日',
        submitter_name='株式会社モダリス',
        submitter_name_en='Modalis Therapeutics Corporation',
        submitter_name_yomi='カブシキガイシャモダリス',
        address='中央区日本橋本町三丁目１１番５号',
        industry='医薬品',
        sec_code='48830',
        corporate_number='1010001172984',
    ),
    'E35521': EdinetCodeEntry(
        edinet_code='E35521',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保木\u3000潤一',
        submitter_name_en=None,
        submitter_name_yomi='ホギジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35522': EdinetCodeEntry(
        edinet_code='E35522',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000洋文',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35525': EdinetCodeEntry(
        edinet_code='E35525',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木戸\u3000修',
        submitter_name_en=None,
        submitter_name_yomi='キド\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35527': EdinetCodeEntry(
        edinet_code='E35527',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000貴博',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35528': EdinetCodeEntry(
        edinet_code='E35528',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福田\u3000晴久',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ハルヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35534': EdinetCodeEntry(
        edinet_code='E35534',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=403,
        fiscal_year_end='4月末日',
        submitter_name='株式会社Ｍａｃｂｅｅ\u3000Ｐｌａｎｅｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマクビープラネット',
        address='渋谷区渋谷３ー１１ー１１ＩＶＹイーストビル５階',
        industry='サービス業',
        sec_code='70950',
        corporate_number='7011001107074',
    ),
    'E35535': EdinetCodeEntry(
        edinet_code='E35535',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=818,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ドラフト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャドラフト',
        address='港区南青山五丁目６番１９号',
        industry='建設業',
        sec_code=None,
        corporate_number='1011001067646',
    ),
    'E35536': EdinetCodeEntry(
        edinet_code='E35536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山下\u3000泰樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000タイジュ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35538': EdinetCodeEntry(
        edinet_code='E35538',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社辰巳',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタツミ',
        address='足立区竹の塚６－８－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011801013260',
    ),
    'E35541': EdinetCodeEntry(
        edinet_code='E35541',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上遠野\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='カトウノ\u3000シュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35542': EdinetCodeEntry(
        edinet_code='E35542',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=53,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＱＤレーザ',
        submitter_name_en='QD Laser, Inc.',
        submitter_name_yomi='カブシキガイシャキューディーレーザ',
        address='川崎市川崎区南渡田町１番１号',
        industry='電気機器',
        sec_code='66130',
        corporate_number='8020001085428',
    ),
    'E35543': EdinetCodeEntry(
        edinet_code='E35543',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1715,
        fiscal_year_end='3月31日',
        submitter_name='リバーホールディングス株式会社',
        submitter_name_en='REVER HOLDINGS CORPORATION',
        submitter_name_yomi='リバーホールディングスカブシキカイシャ',
        address='千代田区大手町一丁目７番２号東京サンケイビル１５階',
        industry='鉄鋼',
        sec_code=None,
        corporate_number='9010601034255',
    ),
    'E35544': EdinetCodeEntry(
        edinet_code='E35544',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=751,
        fiscal_year_end='2月末日',
        submitter_name='バリオセキュア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バリオセキュアカブシキカイシャ',
        address='千代田区神田錦町一丁目６番地',
        industry='情報・通信業',
        sec_code='44940',
        corporate_number='6010001170604',
    ),
    'E35551': EdinetCodeEntry(
        edinet_code='E35551',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉村\u3000泰助',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000タイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35553': EdinetCodeEntry(
        edinet_code='E35553',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾﨑\u3000保秀',
        submitter_name_en=None,
        submitter_name_yomi='オザキ\u3000ヤスヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35554': EdinetCodeEntry(
        edinet_code='E35554',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=401,
        fiscal_year_end='2月末日',
        submitter_name='株式会社コパ・コーポレーション',
        submitter_name_en='Copa Corpotation Inc.',
        submitter_name_yomi='カブシキガイシャコパコーポレーション',
        address='東京都渋谷区恵比寿南二丁目２３番７号',
        industry='卸売業',
        sec_code='76890',
        corporate_number='9011001050405',
    ),
    'E35555': EdinetCodeEntry(
        edinet_code='E35555',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=143,
        fiscal_year_end='3月31日',
        submitter_name='エブレン株式会社',
        submitter_name_en='EBRAINS,INC.',
        submitter_name_yomi='エブレンカブシキガイシャ',
        address='八王子市石川町２９７０番地６',
        industry='電気機器',
        sec_code='65990',
        corporate_number='4010101000605',
    ),
    'E35560': EdinetCodeEntry(
        edinet_code='E35560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=295,
        fiscal_year_end='3月31日',
        submitter_name='株式会社松屋アールアンドディ',
        submitter_name_en='Matsuya R&D Co.,Ltd',
        submitter_name_yomi='カブシキガイシャマツヤアールアンドディ',
        address='大野市鍬掛第２０号１番地２',
        industry='機械',
        sec_code='73170',
        corporate_number='3210001009917',
    ),
    'E35562': EdinetCodeEntry(
        edinet_code='E35562',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1198,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＮｅｘＴｏｎｅ',
        submitter_name_en='NexTone Inc.',
        submitter_name_yomi='カブシキガイシャネクストーン',
        address='渋谷区恵比寿四丁目２０番３号恵比寿ガーデンプレイスタワー１０階',
        industry='サービス業',
        sec_code='70940',
        corporate_number='5011001072766',
    ),
    'E35563': EdinetCodeEntry(
        edinet_code='E35563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=704,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ステムセル研究所',
        submitter_name_en='StemCell Institute Inc.',
        submitter_name_yomi='カブシキガイシャステムセルケンキュウジョ',
        address='港区虎ノ門一丁目２１番１９号',
        industry='医薬品',
        sec_code='70960',
        corporate_number='8010401038548',
    ),
    'E35564': EdinetCodeEntry(
        edinet_code='E35564',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志水\u3000雄一郎',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ユウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35567': EdinetCodeEntry(
        edinet_code='E35567',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2708,
        fiscal_year_end=None,
        submitter_name='ジュピター・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジュピターアセットマネジメントリミテッド',
        address='英国\u3000ＳＷ１Ｅ\u3000６ＳＱ、ロンドン、ヴィクトリアストリート\u3000７０、ザ・ジグザグビルディング',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35568': EdinetCodeEntry(
        edinet_code='E35568',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=110,
        fiscal_year_end='3月末日',
        submitter_name='株式会社アルマード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルマード',
        address='中央区日本橋室町４－６－２\u3000菱華ビルディング７階',
        industry='化学',
        sec_code='49320',
        corporate_number='4011201014503',
    ),
    'E35569': EdinetCodeEntry(
        edinet_code='E35569',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社オーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャオーク',
        address='草加市住吉一丁目７番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4030001111459',
    ),
    'E35573': EdinetCodeEntry(
        edinet_code='E35573',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ウプシロン投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='ウプシロントウシジギョウユウゲンセキニンクミアイ',
        address='港区赤坂九丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35574': EdinetCodeEntry(
        edinet_code='E35574',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社トリムメディカルホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='トリムメディカルホールディングス',
        address='大阪市北区大淀中１－８－３４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001109055',
    ),
    'E35578': EdinetCodeEntry(
        edinet_code='E35578',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=414,
        fiscal_year_end='6月末日',
        submitter_name='株式会社アイキューブドシステムズ',
        submitter_name_en='i3 Systems, Inc.',
        submitter_name_yomi='カブシキガイシャアイキューブドシステムズ',
        address='福岡市中央区天神四丁目１番３７号',
        industry='情報・通信業',
        sec_code='44950',
        corporate_number='6290001042164',
    ),
    'E35580': EdinetCodeEntry(
        edinet_code='E35580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='増本\u3000岳',
        submitter_name_en=None,
        submitter_name_yomi='マスモト\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35582': EdinetCodeEntry(
        edinet_code='E35582',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='公益財団法人Ｇ‐７奨学財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンジーセブンショウガクザイダン',
        address='神戸市須磨区弥栄台五丁目１９番地の２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140005024675',
    ),
    'E35584': EdinetCodeEntry(
        edinet_code='E35584',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='辻本\u3000晃利',
        submitter_name_en=None,
        submitter_name_yomi='ツジモト\u3000アキトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35587': EdinetCodeEntry(
        edinet_code='E35587',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=432,
        fiscal_year_end='3月末日',
        submitter_name='ＳＡＮＥＩ株式会社',
        submitter_name_en='SANEI LTD.',
        submitter_name_yomi='サンエイカブシキガイシャ',
        address='大阪市東成区玉津一丁目１２番２９号',
        industry='機械',
        sec_code='62300',
        corporate_number='1120001012428',
    ),
    'E35589': EdinetCodeEntry(
        edinet_code='E35589',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=210,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コマースＯｎｅホールディングス',
        submitter_name_en='Commerce One Holdings Inc.',
        submitter_name_yomi='カブシキガイシャコマースワンホールディングス',
        address='千代田区九段北４丁目２番１号市ヶ谷スクエアビル',
        industry='情報・通信業',
        sec_code='44960',
        corporate_number='7010001101896',
    ),
    'E35591': EdinetCodeEntry(
        edinet_code='E35591',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大橋\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='オオハシ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35592': EdinetCodeEntry(
        edinet_code='E35592',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川瀨\u3000紀彦',
        submitter_name_en=None,
        submitter_name_yomi='カワセ\u3000ノリヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35597': EdinetCodeEntry(
        edinet_code='E35597',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1426,
        fiscal_year_end='3月31日',
        submitter_name='ヤマイチエステート株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマイチエステートカブシキガイシャ',
        address='和歌山市中之島１５１８番地中之島８０１ビル５階',
        industry='不動産業',
        sec_code='29840',
        corporate_number='6170001003368',
    ),
    'E35600': EdinetCodeEntry(
        edinet_code='E35600',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤原\u3000俊也',
        submitter_name_en=None,
        submitter_name_yomi='フジワラ\u3000トシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35604': EdinetCodeEntry(
        edinet_code='E35604',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小倉\u3000秀司',
        submitter_name_en=None,
        submitter_name_yomi='オグラ\u3000シュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35610': EdinetCodeEntry(
        edinet_code='E35610',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=116,
        fiscal_year_end='3月末日',
        submitter_name='株式会社セルム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセルム',
        address='渋谷区恵比寿一丁目１９番１９号',
        industry='サービス業',
        sec_code='73670',
        corporate_number='8011001112552',
    ),
    'E35611': EdinetCodeEntry(
        edinet_code='E35611',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='7月31日',
        submitter_name='株式会社さくらさくプラス',
        submitter_name_en='SAKURASAKU PLUS,Co.,Ltd',
        submitter_name_yomi='カブシキカイシャサクラサクプラス',
        address='千代田区有楽町１丁目２番２号\u3000東宝日比谷ビル',
        industry='サービス業',
        sec_code='70970',
        corporate_number='6010001185437',
    ),
    'E35612': EdinetCodeEntry(
        edinet_code='E35612',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃａｙｍａｎ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＩＩＩ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイマン\u3000キャピタル\u3000マネジメント\u3000スリー\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35614': EdinetCodeEntry(
        edinet_code='E35614',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=710,
        fiscal_year_end='7月末日',
        submitter_name='株式会社ランドネット',
        submitter_name_en='LANDNET Inc.',
        submitter_name_yomi='カブシキガイシャランドネット',
        address='豊島区南池袋１－１６－１５\u3000ダイヤゲート池袋７階',
        industry='不動産業',
        sec_code='29910',
        corporate_number='9013301017315',
    ),
    'E35615': EdinetCodeEntry(
        edinet_code='E35615',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000勇人',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35617': EdinetCodeEntry(
        edinet_code='E35617',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='荒木\u3000喜貴',
        submitter_name_en=None,
        submitter_name_yomi='アラキ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35622': EdinetCodeEntry(
        edinet_code='E35622',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＰ\u3000Ｖ\u3000ＧＰ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャ\u3000エイピー\u3000ファイブ\u3000ジーピー',
        address='港区虎ノ門４－１－２８\u3000虎ノ門タワーズオフィス１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401117266',
    ),
    'E35623': EdinetCodeEntry(
        edinet_code='E35623',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='辻本\u3000康則',
        submitter_name_en=None,
        submitter_name_yomi='ツジモト\u3000ヤスノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35624': EdinetCodeEntry(
        edinet_code='E35624',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='三和澱粉工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンワデンプンコウギヨウカブシキガイシヤ',
        address='橿原市雲梯町５９４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3150001010501',
    ),
    'E35627': EdinetCodeEntry(
        edinet_code='E35627',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='島田\u3000良介',
        submitter_name_en=None,
        submitter_name_yomi='シマダ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35628': EdinetCodeEntry(
        edinet_code='E35628',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＩＷ．ＤＸパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイダブリューディーエックスカブシキガイシャ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401149082',
    ),
    'E35629': EdinetCodeEntry(
        edinet_code='E35629',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=101,
        fiscal_year_end=None,
        submitter_name='株式会社ＵＨ\u3000Ｐａｒｔｎｅｒｓ\u3000２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーエイチ\u3000パートナーズ\u3000ツー',
        address='豊島区南池袋二丁目９番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2013301045082',
    ),
    'E35631': EdinetCodeEntry(
        edinet_code='E35631',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＬＡホールディングス',
        submitter_name_en='LA Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエルエーホールディングス',
        address='港区海岸一丁目９番１８号',
        industry='不動産業',
        sec_code='29860',
        corporate_number='1010401153766',
    ),
    'E35632': EdinetCodeEntry(
        edinet_code='E35632',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1371,
        fiscal_year_end='9月30日',
        submitter_name='株式会社Ｓｐｅｅｅ',
        submitter_name_en='Speee, Inc.',
        submitter_name_yomi='カブシキカイシャスピー',
        address='港区六本木四丁目１番４号',
        industry='情報・通信業',
        sec_code='44990',
        corporate_number='5010401084611',
    ),
    'E35633': EdinetCodeEntry(
        edinet_code='E35633',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大塚\u3000一男',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000イチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35634': EdinetCodeEntry(
        edinet_code='E35634',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=52,
        fiscal_year_end=None,
        submitter_name='株式会社ラテールホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャラテールホールディングス',
        address='千代田区神田鍛冶町三丁目２番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001080847',
    ),
    'E35637': EdinetCodeEntry(
        edinet_code='E35637',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大久保\u3000泉',
        submitter_name_en=None,
        submitter_name_yomi='オオクボ\u3000イズミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35640': EdinetCodeEntry(
        edinet_code='E35640',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='達城\u3000久裕',
        submitter_name_en=None,
        submitter_name_yomi='タツシロ\u3000ヒサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35642': EdinetCodeEntry(
        edinet_code='E35642',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1605,
        fiscal_year_end='9月30日',
        submitter_name='ＧＭＯフィナンシャルゲート株式会社',
        submitter_name_en='GMO Financial Gate, Inc.',
        submitter_name_yomi='ジーエムオーフィナンシャルゲートカブシキカイシャ',
        address='渋谷区道玄坂一丁目１４番６号',
        industry='情報・通信業',
        sec_code='40510',
        corporate_number='5011001064508',
    ),
    'E35643': EdinetCodeEntry(
        edinet_code='E35643',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1458,
        fiscal_year_end=None,
        submitter_name='株式会社堀内カラー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャホリウチカラー',
        address='大阪市北区万歳町３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001070402',
    ),
    'E35645': EdinetCodeEntry(
        edinet_code='E35645',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大野\u3000暉',
        submitter_name_en=None,
        submitter_name_yomi='オオノ\u3000ヒカル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35647': EdinetCodeEntry(
        edinet_code='E35647',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＧ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エムジーゴウドウカイシャ',
        address='品川区上大崎２丁目５番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011003003001',
    ),
    'E35649': EdinetCodeEntry(
        edinet_code='E35649',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＲＭ\u3000Ｊａｐａｎ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='アールエムジャパンエルエルシー',
        address='１１１\u3000Ｗｅｉｒ\u3000Ｄｒｉｖｅ，\u3000Ｗｏｏｄｂｕｒｙ，\u3000Ｍｉｎｎｅｓｏｔａ\u3000５５１２５，\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35651': EdinetCodeEntry(
        edinet_code='E35651',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=110,
        fiscal_year_end=None,
        submitter_name='大王海運株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイオウカイウンカブシキガイシャ',
        address='四国中央市三島紙屋町７番３５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5500001014357',
    ),
    'E35656': EdinetCodeEntry(
        edinet_code='E35656',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上野\u3000憲二',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35660': EdinetCodeEntry(
        edinet_code='E35660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青木\u3000勇',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000イサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35661': EdinetCodeEntry(
        edinet_code='E35661',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小嶋\u3000雄介',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35667': EdinetCodeEntry(
        edinet_code='E35667',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35673': EdinetCodeEntry(
        edinet_code='E35673',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社シー・エム・ケー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャシーエムケー',
        address='大阪市西区江戸堀一丁目４番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9370002007618',
    ),
    'E35675': EdinetCodeEntry(
        edinet_code='E35675',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＤＡＬＭＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダルマ',
        address='横浜市中区本町四丁目４１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010801026217',
    ),
    'E35676': EdinetCodeEntry(
        edinet_code='E35676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＲＣホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイアールシーホールディングス',
        address='渋谷区神宮前六丁目３３番５号マンション原宿５０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001049359',
    ),
    'E35678': EdinetCodeEntry(
        edinet_code='E35678',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上野\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35679': EdinetCodeEntry(
        edinet_code='E35679',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26,
        fiscal_year_end=None,
        submitter_name='ヴァイタルプラス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヴァイタルプラスカブシキガイシャ',
        address='世田谷区等々力四丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010901026222',
    ),
    'E35680': EdinetCodeEntry(
        edinet_code='E35680',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='アイ・シグマ・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイシグマパートナーズカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001154237',
    ),
    'E35681': EdinetCodeEntry(
        edinet_code='E35681',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='北海道電力ネットワーク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホッカイドウデンリョクネットワークカブシキガイシャ',
        address='札幌市中央区大通東１丁目２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7430001078663',
    ),
    'E35691': EdinetCodeEntry(
        edinet_code='E35691',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='韓保維',
        submitter_name_en=None,
        submitter_name_yomi='ハンポールウェル',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35692': EdinetCodeEntry(
        edinet_code='E35692',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑中洋亮',
        submitter_name_en=None,
        submitter_name_yomi='ハタナカ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35693': EdinetCodeEntry(
        edinet_code='E35693',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=156172,
        fiscal_year_end=None,
        submitter_name='アムンディ・アセット・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='アムンディアセットマネジメント',
        address='フランス共和国パリ市７５０１５、パストゥール通り９１－９３番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35695': EdinetCodeEntry(
        edinet_code='E35695',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ウィル・アセット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウィルアセットカブシキガイシャ',
        address='和歌山市西浜一丁目２番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1170001015104',
    ),
    'E35696': EdinetCodeEntry(
        edinet_code='E35696',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｙｓ’\u3000Ａｓｓｏｒｔｍｅｎｔ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイズアソートメントカブシキガイシャ',
        address='和歌山市西浜一丁目３番３６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1170003001218',
    ),
    'E35703': EdinetCodeEntry(
        edinet_code='E35703',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97738,
        fiscal_year_end=None,
        submitter_name='クレディ\u3000アンドスリエル\u3000エ\u3000コメルシアル',
        submitter_name_en=None,
        submitter_name_yomi='クレディ\u3000アンドスリエル\u3000エ\u3000コメルシアル',
        address='６，\u3000Ａｖｅｎｕｅ\u3000ｄｅ\u3000Ｐｒｏｖｅｎｃｅ\u3000ｉｎ\u3000ｔｈｅ\u3000９ｔｈ\u3000Ａｒｒｏｎｄｉｓｅｍｅｎｔ\u3000ｏｆ\u3000Ｐａｒｉｓ，\u3000Ｆｒａｎｃｅ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35704': EdinetCodeEntry(
        edinet_code='E35704',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=173,
        fiscal_year_end=None,
        submitter_name='Ｖｅｃｔｏｒ\u3000Ｇｒｏｕｐ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ベクトルグループインターナショナルリミテッド',
        address='香港、カオルーン、ミンデン・アベニュー、２２～２６番地、ゴールズランド・ビルディング９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35706': EdinetCodeEntry(
        edinet_code='E35706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村勇斗',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35707': EdinetCodeEntry(
        edinet_code='E35707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒須\u3000綾希子',
        submitter_name_en=None,
        submitter_name_yomi='クロス\u3000アキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35712': EdinetCodeEntry(
        edinet_code='E35712',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社フラクタル・ビジネス',
        submitter_name_en=None,
        submitter_name_yomi='ガブシキガイシャフラクタルビジネス',
        address='小諸市田町２丁目６－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010801025697',
    ),
    'E35719': EdinetCodeEntry(
        edinet_code='E35719',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＳＭＫ協力業者持株会\u3000理事長\u3000金森\u3000米男',
        submitter_name_en=None,
        submitter_name_yomi='エスエムケイキョウリョクギョウシャモチカブカイ\u3000リジチョウ\u3000カナモリヨネオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35720': EdinetCodeEntry(
        edinet_code='E35720',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65,
        fiscal_year_end=None,
        submitter_name='トライヴィスタ・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トライヴィスタキャピタルカブシキカイシャ',
        address='中央区日本橋兜町６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401144284',
    ),
    'E35721': EdinetCodeEntry(
        edinet_code='E35721',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉川\u3000正弘',
        submitter_name_en=None,
        submitter_name_yomi='ヨシカワ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35722': EdinetCodeEntry(
        edinet_code='E35722',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西岡\u3000利明',
        submitter_name_en=None,
        submitter_name_yomi='ニシオカ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35724': EdinetCodeEntry(
        edinet_code='E35724',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アレッツ・シーオーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アレッツシーオーイーリミテッド',
        address='英国ブロムスグローブＢ６０\u3000４ＤＪ、ストーク・プライヤー、ハンブリー・ロード、ハリス・ビジネス・パーク、ザ・コートヤード３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35725': EdinetCodeEntry(
        edinet_code='E35725',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社ふぉー優',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000フォーユウ',
        address='西宮市馬場町２番３２号シンヨコビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001137869',
    ),
    'E35731': EdinetCodeEntry(
        edinet_code='E35731',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=365498,
        fiscal_year_end='1月31日',
        submitter_name='スプランク・インク',
        submitter_name_en=None,
        submitter_name_yomi='スプランクインク',
        address='アメリカ合衆国、カリフォルニア州、９４１０７\u3000サンフランシスコ、ブランナン・ストリート２７０',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E35733': EdinetCodeEntry(
        edinet_code='E35733',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='後藤\u3000秀隆',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000ヒデタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35737': EdinetCodeEntry(
        edinet_code='E35737',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9900,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＳＣホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌエスシーホールディングス',
        address='千代田区三番町１－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001094301',
    ),
    'E35741': EdinetCodeEntry(
        edinet_code='E35741',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5021,
        fiscal_year_end=None,
        submitter_name='オムロンヘルスケア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オムロンヘルスケアカブシキガイシャ',
        address='向日市寺戸町九ノ坪５３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7130001024920',
    ),
    'E35742': EdinetCodeEntry(
        edinet_code='E35742',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ユニテックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユニテックス',
        address='大阪市浪速区桜川４丁目１番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001048242',
    ),
    'E35749': EdinetCodeEntry(
        edinet_code='E35749',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=97,
        fiscal_year_end=None,
        submitter_name='ＯＫ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｃｏ．，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='オーケー\u3000ホールディングス\u3000カンパニー\u3000リミテッド',
        address='１０Ｆ，\u3000\u3000３９，\u3000Ｓｅｊｏｎｇ－ｄａｅｒｏ，\u3000Ｊｕｎｇ－ｇｕ，\u3000Ｓｅｏｕｌ，\u3000Ｒｅｐｕｂｌｉｃ\u3000ｏｆ\u3000Ｋｏｒｅａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35751': EdinetCodeEntry(
        edinet_code='E35751',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＮＡＶＥＲ\u3000Ｊ．Ｈｕｂ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ネイバージェイハブカブシキガイシャ',
        address='品川区上大崎二丁目１０番４４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101084807',
    ),
    'E35752': EdinetCodeEntry(
        edinet_code='E35752',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='アルジェブリスＵＣＩＴＳファンズ\u3000ｐｌｃ',
        submitter_name_en=None,
        submitter_name_yomi='アルジェブリスユーシッツファンズピーエルシー',
        address='アイルランド、ダブリン２、サー・ジョン・ロジャーソンズ・キー３３番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35753': EdinetCodeEntry(
        edinet_code='E35753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西尾\u3000義隆',
        submitter_name_en=None,
        submitter_name_yomi='ニシオ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35755': EdinetCodeEntry(
        edinet_code='E35755',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000隆志',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35758': EdinetCodeEntry(
        edinet_code='E35758',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=213,
        fiscal_year_end='6月30日',
        submitter_name='フィーチャ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フィーチャカブシキガイシャ',
        address='豊島区東池袋三丁目１番１号',
        industry='情報・通信業',
        sec_code='40520',
        corporate_number='6030001049697',
    ),
    'E35759': EdinetCodeEntry(
        edinet_code='E35759',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｐｒｏｌｉｇｈｔ\u3000Ｃｏｒｐｏｒａｔｉｏｎ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='プロライトコーポレーションリミテッド',
        address='Ｒｏｏｍ３０３\u3000３／Ｆ\u3000Ｇｏｌｄｅｎ\u3000Ｇａｔｅ\u3000Ｃｏｍｍｅｒｃｉａｌ\u3000ＢＬｄｇ．\u3000１３６－１３８\u3000Ａｕｓｔｉｎ\u3000Ｒｏａｄ\u3000Ｔｓｉｍ\u3000Ｓｈａ\u3000Ｔｓｕｉ，ＫＬ，ＨｏｎｇＫｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35761': EdinetCodeEntry(
        edinet_code='E35761',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社アースマテリアル',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャアースマテリアル',
        address='柏市柏１００４番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8040002096554',
    ),
    'E35763': EdinetCodeEntry(
        edinet_code='E35763',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松永\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='マツナガ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35765': EdinetCodeEntry(
        edinet_code='E35765',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=116,
        fiscal_year_end='5月31日',
        submitter_name='株式会社インターファクトリー',
        submitter_name_en='Interfactory,Inc.',
        submitter_name_yomi='カブシキガイシャインターファクトリー',
        address='千代田区富士見二丁目１０番２号',
        industry='情報・通信業',
        sec_code='40570',
        corporate_number='9011601012325',
    ),
    'E35766': EdinetCodeEntry(
        edinet_code='E35766',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=261,
        fiscal_year_end='3月31日',
        submitter_name='株式会社交換できるくん',
        submitter_name_en='koukandekirukun, Inc.',
        submitter_name_yomi='カブシキガイシャコウカンデキルクン',
        address='渋谷区東一丁目２６番２０号',
        industry='サービス業',
        sec_code='76950',
        corporate_number='2011001073362',
    ),
    'E35767': EdinetCodeEntry(
        edinet_code='E35767',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=144,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ＴＷＯＳＴＯＮＥ＆Ｓｏｎｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツーストーンアンドサンズ',
        address='渋谷区渋谷２－２２－３渋谷東口ビル６Ｆ',
        industry='サービス業',
        sec_code='73520',
        corporate_number='2011001096974',
    ),
    'E35772': EdinetCodeEntry(
        edinet_code='E35772',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11955,
        fiscal_year_end=None,
        submitter_name='ウェイストーン・マネジメント・カンパニー（ＩＥ）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウェイストーンマネジメントカンパニーアイイーリミテッド',
        address='アイルランド、ダブリン２、ローワー・バゴット・ストリート７６番３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35773': EdinetCodeEntry(
        edinet_code='E35773',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1235,
        fiscal_year_end='8月31日',
        submitter_name='株式会社グッドパッチ',
        submitter_name_en='Goodpatch Inc.',
        submitter_name_yomi='カブシキガイシャグッドパッチ',
        address='渋谷区鶯谷町３番３号',
        industry='情報・通信業',
        sec_code='73510',
        corporate_number='6010501033839',
    ),
    'E35785': EdinetCodeEntry(
        edinet_code='E35785',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='原\u3000伊都子',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000イツコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35786': EdinetCodeEntry(
        edinet_code='E35786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='カレント自動車株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カレントジドウシャカブシキガイシャ',
        address='横浜市港北区新横浜二丁目５番地１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001043253',
    ),
    'E35790': EdinetCodeEntry(
        edinet_code='E35790',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=803,
        fiscal_year_end='12月31日',
        submitter_name='ＫＩＹＯラーニング株式会社',
        submitter_name_en='KIYO Learning Co.,Ltd',
        submitter_name_yomi='キヨラーニングカブシキガイシャ',
        address='千代田区永田町２－１０－１',
        industry='サービス業',
        sec_code='73530',
        corporate_number='2011001066077',
    ),
    'E35791': EdinetCodeEntry(
        edinet_code='E35791',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1197,
        fiscal_year_end='3月末日',
        submitter_name='あすか製薬ホールディングス株式会社',
        submitter_name_en='ASKA Pharmaceutical Holdings CO., Ltd.',
        submitter_name_yomi='アスカセイヤクホールディングスカブシキガイシャ',
        address='港区芝浦二丁目５番１号',
        industry='医薬品',
        sec_code='48860',
        corporate_number='8010401159328',
    ),
    'E35792': EdinetCodeEntry(
        edinet_code='E35792',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='イメージ・フレイム・インベストメント（香港）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='イメージフレイムインベストメントホンコンリミテッド',
        address='香港ワンチャイ、クイーンズロード・イースト１、スリー・パシフィック・プレイス、２９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35797': EdinetCodeEntry(
        edinet_code='E35797',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=247,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＡＳＮＯＶＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアスノバ',
        address='名古屋市中村区平池町四丁目６０番地の１２\u3000グローバルゲート２６階',
        industry='サービス業',
        sec_code='92230',
        corporate_number='6210001015400',
    ),
    'E35798': EdinetCodeEntry(
        edinet_code='E35798',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上田\u3000桂司',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35804': EdinetCodeEntry(
        edinet_code='E35804',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='市原\u3000正樹',
        submitter_name_en=None,
        submitter_name_yomi='イチハラ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35810': EdinetCodeEntry(
        edinet_code='E35810',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=60000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ひろぎんホールディングス',
        submitter_name_en='Hirogin Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャヒロギンホールディングス',
        address='広島市中区紙屋町一丁目３番８号',
        industry='銀行業',
        sec_code='73370',
        corporate_number='6240001056714',
    ),
    'E35813': EdinetCodeEntry(
        edinet_code='E35813',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='エンデバー・ユナイテッド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンデバーユナイテッドカブシキガイシャ',
        address='千代田区丸の内二丁目５番１号丸の内二丁目ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001153111',
    ),
    'E35815': EdinetCodeEntry(
        edinet_code='E35815',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社武雄嬉野国際カントリークラブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタケオウレシノカントリークラブ',
        address='武雄市西川登町大字小田志１８３５６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8300001004623',
    ),
    'E35816': EdinetCodeEntry(
        edinet_code='E35816',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='日本成長投資アライアンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイチョウトウシアライアンスカブシキカイシャ',
        address='港区虎ノ門５丁目１３番１号\u3000虎ノ門４０ＭＴビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001176548',
    ),
    'E35818': EdinetCodeEntry(
        edinet_code='E35818',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤岡\u3000淳一',
        submitter_name_en=None,
        submitter_name_yomi='フジオカ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35821': EdinetCodeEntry(
        edinet_code='E35821',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=729,
        fiscal_year_end='6月30日',
        submitter_name='日本情報クリエイト株式会社',
        submitter_name_en='Japan PropTech Co.,Ltd.',
        submitter_name_yomi='ニホンジョウホウクリエイトカブシキカイシャ',
        address='都城市上町１３街区１８号',
        industry='情報・通信業',
        sec_code='40540',
        corporate_number='8350001008198',
    ),
    'E35822': EdinetCodeEntry(
        edinet_code='E35822',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=500,
        fiscal_year_end='3月31日',
        submitter_name='インヴァスト株式会社',
        submitter_name_en='INV Inc.',
        submitter_name_yomi='インヴァストカブシキガイシャ',
        address='中央区東日本橋一丁目５番６号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='8010001212692',
    ),
    'E35824': EdinetCodeEntry(
        edinet_code='E35824',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40,
        fiscal_year_end='11月30日',
        submitter_name='ティアンドエスグループ株式会社',
        submitter_name_en='T&S Group Inc.',
        submitter_name_yomi='ティアンドエスグループカブシキガイシャ',
        address='横浜市西区みなとみらい三丁目６番３号',
        industry='情報・通信業',
        sec_code='40550',
        corporate_number='6020001118494',
    ),
    'E35826': EdinetCodeEntry(
        edinet_code='E35826',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=110,
        fiscal_year_end='3月31日',
        submitter_name='アイペットホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイペットホールディングスカブシキカイシャ',
        address='江東区豊洲五丁目６番１５号',
        industry='保険業',
        sec_code=None,
        corporate_number='2010401155621',
    ),
    'E35827': EdinetCodeEntry(
        edinet_code='E35827',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1717,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｓｕｎ\u3000Ａｓｔｅｒｉｓｋ',
        submitter_name_en='Sun* Inc.',
        submitter_name_yomi='カブシキガイシャサンアスタリスク',
        address='千代田区大手町１－６－１',
        industry='情報・通信業',
        sec_code='40530',
        corporate_number='4010601044077',
    ),
    'E35828': EdinetCodeEntry(
        edinet_code='E35828',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社ぽると',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャポルト',
        address='福生市北田園二丁目１番地３エトワールＢ２０１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013101007246',
    ),
    'E35841': EdinetCodeEntry(
        edinet_code='E35841',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='ニューラルグループ株式会社',
        submitter_name_en='Neural Group Inc.',
        submitter_name_yomi='ニューラルグループカブシキガイシャ',
        address='千代田区有楽町一丁目１番２号',
        industry='情報・通信業',
        sec_code='40560',
        corporate_number='5010001189158',
    ),
    'E35843': EdinetCodeEntry(
        edinet_code='E35843',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='脇\u3000健一郎',
        submitter_name_en=None,
        submitter_name_yomi='ワキ\u3000ケンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35844': EdinetCodeEntry(
        edinet_code='E35844',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='曹\u3000暉',
        submitter_name_en=None,
        submitter_name_yomi='ソウ\u3000キ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35847': EdinetCodeEntry(
        edinet_code='E35847',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大丸\u3000孝之',
        submitter_name_en=None,
        submitter_name_yomi='ダイマル\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35848': EdinetCodeEntry(
        edinet_code='E35848',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＴＣＴＳ０５',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャティーシーティーエスゼロゴ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010003019653',
    ),
    'E35849': EdinetCodeEntry(
        edinet_code='E35849',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊勢\u3000幸治',
        submitter_name_en=None,
        submitter_name_yomi='イセ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35850': EdinetCodeEntry(
        edinet_code='E35850',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=69600,
        fiscal_year_end=None,
        submitter_name='ＳＢＩ地銀ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイチギンホールディングスカブシキガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401120172',
    ),
    'E35851': EdinetCodeEntry(
        edinet_code='E35851',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='乾\u3000伸行',
        submitter_name_en=None,
        submitter_name_yomi='イヌイ\u3000ノブユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35853': EdinetCodeEntry(
        edinet_code='E35853',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大鳥居\u3000清和',
        submitter_name_en=None,
        submitter_name_yomi='オオトリイ\u3000キヨカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35856': EdinetCodeEntry(
        edinet_code='E35856',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社フューチャースピリッツ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフューチャースピリッツ',
        address='京都市下京区中堂寺粟田町９１番地\u3000京都リサーチパーク９号館７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3130001023678',
    ),
    'E35860': EdinetCodeEntry(
        edinet_code='E35860',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＣＩＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシーアイエス',
        address='鳥羽市堅子町字前山２４４番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3190001007378',
    ),
    'E35862': EdinetCodeEntry(
        edinet_code='E35862',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='米津\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='ヨネツ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35866': EdinetCodeEntry(
        edinet_code='E35866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='糟谷\u3000誠一',
        submitter_name_en=None,
        submitter_name_yomi='カスタニ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35867': EdinetCodeEntry(
        edinet_code='E35867',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久田\u3000哲史',
        submitter_name_en=None,
        submitter_name_yomi='ヒサタ\u3000テツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35868': EdinetCodeEntry(
        edinet_code='E35868',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大塚\u3000英樹',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35869': EdinetCodeEntry(
        edinet_code='E35869',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000昌司',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35872': EdinetCodeEntry(
        edinet_code='E35872',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000暁',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35873': EdinetCodeEntry(
        edinet_code='E35873',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ヴァレックス・パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヴァレックスパートナーズ',
        address='中央区日本橋茅場町一丁目６番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001099586',
    ),
    'E35874': EdinetCodeEntry(
        edinet_code='E35874',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='綾部\u3000貴淑',
        submitter_name_en=None,
        submitter_name_yomi='アヤベ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35877': EdinetCodeEntry(
        edinet_code='E35877',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柳川\u3000十糸久',
        submitter_name_en=None,
        submitter_name_yomi='ヤナガワ\u3000トシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35878': EdinetCodeEntry(
        edinet_code='E35878',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='重松\u3000路威',
        submitter_name_en=None,
        submitter_name_yomi='シゲマツ\u3000ロイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35880': EdinetCodeEntry(
        edinet_code='E35880',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＢキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌビーキャピタル',
        address='港区虎ノ門三丁目２２番１０－２０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401149870',
    ),
    'E35881': EdinetCodeEntry(
        edinet_code='E35881',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河端\u3000保志',
        submitter_name_en=None,
        submitter_name_yomi='カワバタ\u3000ヤスユキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35882': EdinetCodeEntry(
        edinet_code='E35882',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙原\u3000克弥',
        submitter_name_en=None,
        submitter_name_yomi='タカハラ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35885': EdinetCodeEntry(
        edinet_code='E35885',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土屋\u3000尚史',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤ\u3000ナオフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35886': EdinetCodeEntry(
        edinet_code='E35886',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='服部\u3000裕輔',
        submitter_name_en=None,
        submitter_name_yomi='ハットリ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35887': EdinetCodeEntry(
        edinet_code='E35887',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平井\u3000誠人',
        submitter_name_en=None,
        submitter_name_yomi='ヒライ\u3000マコト',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35889': EdinetCodeEntry(
        edinet_code='E35889',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='タイガー\u3000ホールディングス\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='タイガー\u3000ホールディングス\u3000リミテッド',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシズ（ケイマン）リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35890': EdinetCodeEntry(
        edinet_code='E35890',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エボリューション\u3000ジャパン\u3000グループ\u3000ホールディング\u3000インク',
        submitter_name_en=None,
        submitter_name_yomi='エボリューション\u3000ジャパン\u3000グループ\u3000ホールディング\u3000インク',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ、インタートラスト・コーポレート・サービシズ（ケイマン）リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35895': EdinetCodeEntry(
        edinet_code='E35895',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橋本\u3000征道',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000マサミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35897': EdinetCodeEntry(
        edinet_code='E35897',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000泰平',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000タイヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35898': EdinetCodeEntry(
        edinet_code='E35898',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｓｉａｎ\u3000Ａｓｓｅｔ\u3000Ａｃｑｕｉｓｉｔｉｏｎ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='アジアン\u3000アセット\u3000アクイジション\u3000プライベート\u3000リミテッド',
        address='９\u3000Ｓｔｒａｉｔｓ\u3000Ｖｉｅｗ\u3000＃０６－０７\u3000Ｍａｒｉｎａ\u3000Ｏｎｅ\u3000Ｗｅｓｔ\u3000Ｔｏｗｅｒ\u3000Ｓｉｎｇａｐｏｒｅ\u3000０１８９３７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35900': EdinetCodeEntry(
        edinet_code='E35900',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＫコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティーケーコーポレーション',
        address='港区元赤坂１丁目－２－７赤坂Ｋタワー４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011601018686',
    ),
    'E35901': EdinetCodeEntry(
        edinet_code='E35901',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4928,
        fiscal_year_end=None,
        submitter_name='株式会社カカオ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカカオ',
        address='大韓民国済州特別自治道済州市先端路２４２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35904': EdinetCodeEntry(
        edinet_code='E35904',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀江\u3000聡寧',
        submitter_name_en=None,
        submitter_name_yomi='ホリエ\u3000トシヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35905': EdinetCodeEntry(
        edinet_code='E35905',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浅沼\u3000潔',
        submitter_name_en=None,
        submitter_name_yomi='アサヌマ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35907': EdinetCodeEntry(
        edinet_code='E35907',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小田\u3000喜代春',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000キヨハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35908': EdinetCodeEntry(
        edinet_code='E35908',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2095,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ポピンズ',
        submitter_name_en=None,
        submitter_name_yomi='ポピンズ',
        address='渋谷区広尾５－６ー６\u3000広尾プラザ',
        industry='サービス業',
        sec_code='73580',
        corporate_number='7011001113089',
    ),
    'E35911': EdinetCodeEntry(
        edinet_code='E35911',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=394,
        fiscal_year_end='12月末日',
        submitter_name='トヨクモ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨクモカブシキガイシャ',
        address='品川区上大崎三丁目１番１号\u3000ＪＲ東急目黒ビル\u3000１４階',
        industry='情報・通信業',
        sec_code='40580',
        corporate_number='1010001134431',
    ),
    'E35912': EdinetCodeEntry(
        edinet_code='E35912',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤本\u3000一成',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000カズナリ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35914': EdinetCodeEntry(
        edinet_code='E35914',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＴＬリゾーツ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーティーエルリゾーツ',
        address='港区六本木六丁目１番２０号７Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401150061',
    ),
    'E35915': EdinetCodeEntry(
        edinet_code='E35915',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森田\u3000晴彦',
        submitter_name_en=None,
        submitter_name_yomi='モリタ\u3000ハルヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35917': EdinetCodeEntry(
        edinet_code='E35917',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1533,
        fiscal_year_end=None,
        submitter_name='キャピタル・アールイー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='キャピタルアールイーエルエルシー',
        address='アメリカ合衆国、デラウェア州１９８０１、ウィルミントン、オレンジ・ストリート１２０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35920': EdinetCodeEntry(
        edinet_code='E35920',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='Ａｓｌｅａｄ\u3000Ｃａｐｉｔａｌ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='アスリード\u3000キャピタル\u3000ピーティーイー\u3000エルティーディー',
        address='５１\u3000ＢＲＡＳ\u3000ＢＡＳＡＨ\u3000ＲＤ，\u3000０５\u3000０１，\u3000ＳＩＮＧＡＰＯＲＥ\u3000１８９５５４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35921': EdinetCodeEntry(
        edinet_code='E35921',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平野\u3000俊博',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35922': EdinetCodeEntry(
        edinet_code='E35922',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000照男',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000テルオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35923': EdinetCodeEntry(
        edinet_code='E35923',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日下\u3000寛之',
        submitter_name_en=None,
        submitter_name_yomi='クサカ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35924': EdinetCodeEntry(
        edinet_code='E35924',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日下\u3000理',
        submitter_name_en=None,
        submitter_name_yomi='クサカ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35926': EdinetCodeEntry(
        edinet_code='E35926',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000玲',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35928': EdinetCodeEntry(
        edinet_code='E35928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3291,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｉ－ｎｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイエヌイー',
        address='大阪市北区中之島六丁目１番２１号',
        industry='化学',
        sec_code='49330',
        corporate_number='6140001082869',
    ),
    'E35930': EdinetCodeEntry(
        edinet_code='E35930',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=399,
        fiscal_year_end='12月末日',
        submitter_name='ｒａｋｕｍｏ株式会社',
        submitter_name_en='rakumo Inc.',
        submitter_name_yomi='ラクモカブシキガイシャ',
        address='千代田区麹町３－２',
        industry='情報・通信業',
        sec_code='40600',
        corporate_number='2011001069625',
    ),
    'E35931': EdinetCodeEntry(
        edinet_code='E35931',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2185,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ダイレクトマーケティングミックス',
        submitter_name_en='Direct Marketing MiX Inc.',
        submitter_name_yomi='カブシキガイシャダイレクトマーケティングミックス',
        address='大阪市北区曽根崎一丁目２番９号',
        industry='サービス業',
        sec_code='73540',
        corporate_number='7010001185502',
    ),
    'E35932': EdinetCodeEntry(
        edinet_code='E35932',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=144,
        fiscal_year_end='7月末日',
        submitter_name='株式会社アースインフィニティ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアースインフィニティ',
        address='大阪市北区中之島ニ丁目３番１８号',
        industry='小売業',
        sec_code='76920',
        corporate_number='4120001102102',
    ),
    'E35933': EdinetCodeEntry(
        edinet_code='E35933',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2500,
        fiscal_year_end=None,
        submitter_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グローバルエックスジャパンカブシキガイシャ',
        address='千代田区永田町二丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001203678',
    ),
    'E35934': EdinetCodeEntry(
        edinet_code='E35934',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹村\u3000淳',
        submitter_name_en=None,
        submitter_name_yomi='タケムラ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35935': EdinetCodeEntry(
        edinet_code='E35935',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='武川\u3000義浩',
        submitter_name_en=None,
        submitter_name_yomi='タケカワ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35937': EdinetCodeEntry(
        edinet_code='E35937',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='北井\u3000秀樹',
        submitter_name_en=None,
        submitter_name_yomi='キタイ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35941': EdinetCodeEntry(
        edinet_code='E35941',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=389,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ヘッドウォータース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヘッドウォータース',
        address='新宿区西新宿六丁目５番１号新宿アイランドタワー４階',
        industry='情報・通信業',
        sec_code='40110',
        corporate_number='4011101040211',
    ),
    'E35942': EdinetCodeEntry(
        edinet_code='E35942',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濡木\u3000理',
        submitter_name_en=None,
        submitter_name_yomi='ヌレキ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35943': EdinetCodeEntry(
        edinet_code='E35943',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3282,
        fiscal_year_end=None,
        submitter_name='グランサム、マヨ、ヴァン\u3000オッテルロー\u3000アンド\u3000カンパニー\u3000エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='グランサム\u3000マヨ\u3000ヴァン\u3000オッテルロー\u3000アンド\u3000カンパニー\u3000エルエルシー',
        address='５３\u3000Ｓｔａｔｅ\u3000Ｓｔｒｅｅｔ，\u3000Ｓｕｉｔｅ\u3000３３００，\u3000Ｂｏｓｔｏｎ，\u3000Ｍａｓｓａｃｈｕｓｅｔｔｓ\u3000０２１０９，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35945': EdinetCodeEntry(
        edinet_code='E35945',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=319,
        fiscal_year_end='9月30日',
        submitter_name='株式会社まぐまぐ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマグマグ',
        address='東京都品川区西五反田３－１２－１４\u3000西五反田プレイス８階',
        industry='情報・通信業',
        sec_code='40590',
        corporate_number='7011001055793',
    ),
    'E35946': EdinetCodeEntry(
        edinet_code='E35946',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1049,
        fiscal_year_end='9月末日',
        submitter_name='株式会社タスキ',
        submitter_name_en='TASUKI Corporation',
        submitter_name_yomi='カブシキガイシャタスキ',
        address='港区北青山二丁目７番９号',
        industry='不動産業',
        sec_code=None,
        corporate_number='5011101067559',
    ),
    'E35947': EdinetCodeEntry(
        edinet_code='E35947',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1020,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＳＴＩフードホールディングス',
        submitter_name_en='STI Foods Holdings,Inc.',
        submitter_name_yomi='エスティーアイフードホールディングス',
        address='東京都港区南青山１－１５－１４新乃木坂ビル４階',
        industry='食料品',
        sec_code='29320',
        corporate_number='8010401135262',
    ),
    'E35948': EdinetCodeEntry(
        edinet_code='E35948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=25239,
        fiscal_year_end='3月末日',
        submitter_name='キオクシアホールディングス株式会社',
        submitter_name_en='Kioxia Holdings Corporation',
        submitter_name_yomi='キオクシアホールディングスカブシキガイシャ',
        address='港区芝浦三丁目１番２１号',
        industry='電気機器',
        sec_code='285A0',
        corporate_number='8010401144206',
    ),
    'E35949': EdinetCodeEntry(
        edinet_code='E35949',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6963,
        fiscal_year_end=None,
        submitter_name='Ｋｉｂ\u3000ｐｌｕｇ\u3000ｅｎｅｒｇｙ\u3000Ｃｏ．，Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイアイビープラグエナジー',
        address='韓国蔚山廣域市南區處容路２６０－３７（夫谷洞１２５－２）（石油化学団地内）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35950': EdinetCodeEntry(
        edinet_code='E35950',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栗林\u3000宏吉',
        submitter_name_en=None,
        submitter_name_yomi='クリバヤシ\u3000ヒロヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35957': EdinetCodeEntry(
        edinet_code='E35957',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22,
        fiscal_year_end=None,
        submitter_name='ジャナス・ヘンダーソン・インベスターズ・ヨーロッパ・エスエー',
        submitter_name_en=None,
        submitter_name_yomi='ジャナスヘンダーソンインベスターズヨーロッパエスエー',
        address='ルクセンブルク大公国、ルクセンブルク市Ｌ－１９３０、リベルテ通り７８番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35958': EdinetCodeEntry(
        edinet_code='E35958',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｋａｉｓｅｒ\u3000Ｃａｐｉｔａｌ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='カイザーキャピタルホールディングスリミテッド',
        address='英国領ヴァージン諸島、ＶＧ１１１０、トルトラ島、ロードタウン、ウィックハムズケイ２、ビストラコーポレイトサービシズセンター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35959': EdinetCodeEntry(
        edinet_code='E35959',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=64,
        fiscal_year_end='12月末日',
        submitter_name='株式会社アクシス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアクシス',
        address='港区西新橋２丁目３番１号\u3000マークライト虎ノ門８Ｆ',
        industry='情報・通信業',
        sec_code='40120',
        corporate_number='6010401035266',
    ),
    'E35962': EdinetCodeEntry(
        edinet_code='E35962',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='阿部\u3000圭司',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35963': EdinetCodeEntry(
        edinet_code='E35963',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蕪木\u3000登',
        submitter_name_en=None,
        submitter_name_yomi='カブラキ\u3000ノボル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35964': EdinetCodeEntry(
        edinet_code='E35964',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蕪木\u3000有紀',
        submitter_name_en=None,
        submitter_name_yomi='カブラキ\u3000ユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35965': EdinetCodeEntry(
        edinet_code='E35965',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='酒井\u3000宏修',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000ヒロナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35966': EdinetCodeEntry(
        edinet_code='E35966',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=315,
        fiscal_year_end=None,
        submitter_name='ニホン\u3000グローバル\u3000グロウス\u3000パートナーズ\u3000エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ニホン\u3000グローバル\u3000グロウス\u3000パートナーズ\u3000エルエルシー',
        address='ケイマン諸島ＫＹ１－９００８、グランドケイマン、ジョージタウン、ホスピタル・ロード２７、ケイマン・コーポレート・センター、ウォーカーズ・コーポレート・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35967': EdinetCodeEntry(
        edinet_code='E35967',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4099,
        fiscal_year_end='12月末日',
        submitter_name='勤次郎株式会社',
        submitter_name_en='KInjiro Co.,Ltd.',
        submitter_name_yomi='キンジロウカブシキガイシャ',
        address='千代田区外神田四丁目１４番１号',
        industry='情報・通信業',
        sec_code='40130',
        corporate_number='5180001039651',
    ),
    'E35971': EdinetCodeEntry(
        edinet_code='E35971',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＡＳ\u3000Ｂｕｄｄｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムエイエスバディ',
        address='名古屋市南区道全町四丁目９番地の２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001140516',
    ),
    'E35972': EdinetCodeEntry(
        edinet_code='E35972',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丹羽\u3000耕太郎',
        submitter_name_en=None,
        submitter_name_yomi='ニワ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35977': EdinetCodeEntry(
        edinet_code='E35977',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='合同会社小栗達弘オフィス',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャオグリミチヒロオフィス',
        address='岐阜市茜部菱野４丁目７９番１号\u3000岐阜造園ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8200003004755',
    ),
    'E35979': EdinetCodeEntry(
        edinet_code='E35979',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=588,
        fiscal_year_end=None,
        submitter_name='Ｎａｔｉｏｎａｌ\u3000Ｉｎｄｅｍｎｉｔｙ\u3000Ｃｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='ナショナル\u3000インデムニティー\u3000カンパニー',
        address='１３１４\u3000Ｄｏｕｇｌａｓ\u3000Ｓｔｒｅｅｔ，\u3000Ｓｕｉｔｅ\u3000１４００，Ｏｍａｈａ，\u3000Ｎｅｂｒａｓｋａ，\u3000Ｕｎｉｔｅｄ\u3000Ｓｔａｔｅｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35980': EdinetCodeEntry(
        edinet_code='E35980',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=888,
        fiscal_year_end=None,
        submitter_name='日本生命第５回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイゴカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001211487',
    ),
    'E35982': EdinetCodeEntry(
        edinet_code='E35982',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＦＦＩＣＥ\u3000Ｍ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャオフィスエム',
        address='港区麻布台一丁目３番２―５７０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401136662',
    ),
    'E35984': EdinetCodeEntry(
        edinet_code='E35984',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｌｕｘｏｒ\u3000Ｃａｐｉｔａｌ\u3000Ｇｒｏｕｐ，\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='ルクソール\u3000キャピタル\u3000グループ\u3000エルピー',
        address='米国、ニューヨーク州、ニューヨーク、タイムズ・スクエア７、４３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35986': EdinetCodeEntry(
        edinet_code='E35986',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000洋平',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000ヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35988': EdinetCodeEntry(
        edinet_code='E35988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渋谷\u3000守浩',
        submitter_name_en=None,
        submitter_name_yomi='シブタニ\u3000モリヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35989': EdinetCodeEntry(
        edinet_code='E35989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=62,
        fiscal_year_end='7月末日',
        submitter_name='株式会社カラダノート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカラダノート',
        address='港区芝浦三丁目８番１０号',
        industry='サービス業',
        sec_code='40140',
        corporate_number='7010401079733',
    ),
    'E35991': EdinetCodeEntry(
        edinet_code='E35991',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＨＩＢＵＴＡＮＩホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシブタニホールディングス',
        address='生駒市菜畑町２３１３番地４５１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8150003001064',
    ),
    'E35993': EdinetCodeEntry(
        edinet_code='E35993',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=95,
        fiscal_year_end='9月末日',
        submitter_name='Ｒｅｔｔｙ株式会社',
        submitter_name_en='Retty Inc.',
        submitter_name_yomi='レッティカブシキガイシャ',
        address='港区三田１丁目４番１号\u3000住友不動産麻布十番ビル３階',
        industry='サービス業',
        sec_code='73560',
        corporate_number='7010401090888',
    ),
    'E35994': EdinetCodeEntry(
        edinet_code='E35994',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上山\u3000哲正',
        submitter_name_en=None,
        submitter_name_yomi='カミヤマ\u3000テツマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E35997': EdinetCodeEntry(
        edinet_code='E35997',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88,
        fiscal_year_end=None,
        submitter_name='株式会社テラスホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテラスホールディングス',
        address='港区赤坂４－１３－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4013201012817',
    ),
    'E36001': EdinetCodeEntry(
        edinet_code='E36001',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社富士ロジテック東日本',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジロジテックヒガシニホン',
        address='千代田区丸の内三丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001212069',
    ),
    'E36002': EdinetCodeEntry(
        edinet_code='E36002',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=343,
        fiscal_year_end='9月30日',
        submitter_name='Ｈｉクラテス株式会社',
        submitter_name_en='Hi-CRATES CO.,LTD.',
        submitter_name_yomi='ハイクラテスカブシキガイシャ',
        address='岡山市北区野田三丁目１２番３３号',
        industry='情報・通信業',
        sec_code='41720',
        corporate_number='2260001004724',
    ),
    'E36003': EdinetCodeEntry(
        edinet_code='E36003',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='濵田\u3000幸一',
        submitter_name_en=None,
        submitter_name_yomi='ハマダ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36005': EdinetCodeEntry(
        edinet_code='E36005',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森田\u3000周平',
        submitter_name_en=None,
        submitter_name_yomi='モリタ\u3000シュウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36006': EdinetCodeEntry(
        edinet_code='E36006',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=360,
        fiscal_year_end=None,
        submitter_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサステンキャピタルマネジメント',
        address='港区虎ノ門一丁目３番１号\u3000東京虎ノ門グローバルスクエア',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010901044494',
    ),
    'E36012': EdinetCodeEntry(
        edinet_code='E36012',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=24332,
        fiscal_year_end=None,
        submitter_name='マニュライフ・インベストメント・マネジメント（ＨＫ）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='マニュライフインベストメントマネジメントホンコンリミテッド',
        address='香港、銅鑼灣、希慎道３３號、リー・ガーデン・ワン、１６階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36016': EdinetCodeEntry(
        edinet_code='E36016',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='御手洗\u3000大祐',
        submitter_name_en=None,
        submitter_name_yomi='ミタライ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36018': EdinetCodeEntry(
        edinet_code='E36018',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日向\u3000宏',
        submitter_name_en=None,
        submitter_name_yomi='ヒナタ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36019': EdinetCodeEntry(
        edinet_code='E36019',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小倉\u3000博文',
        submitter_name_en=None,
        submitter_name_yomi='オグラ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36020': EdinetCodeEntry(
        edinet_code='E36020',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='住友生命第２回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイダイニカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001212034',
    ),
    'E36021': EdinetCodeEntry(
        edinet_code='E36021',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社ナノバンク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナノバンク',
        address='世田谷区等々力五丁目２０番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010901033339',
    ),
    'E36022': EdinetCodeEntry(
        edinet_code='E36022',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000裕次',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36023': EdinetCodeEntry(
        edinet_code='E36023',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田里\u3000友彦',
        submitter_name_en=None,
        submitter_name_yomi='タサト\u3000トモヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36024': EdinetCodeEntry(
        edinet_code='E36024',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='落合\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='オチアイ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36026': EdinetCodeEntry(
        edinet_code='E36026',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='星野\u3000和也',
        submitter_name_en=None,
        submitter_name_yomi='ホシノ\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36031': EdinetCodeEntry(
        edinet_code='E36031',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='12月31日',
        submitter_name='株式会社バルコス',
        submitter_name_en='BARCOS Co., Ltd.',
        submitter_name_yomi='カブシキガイシャバルコス',
        address='倉吉市河北町１番地',
        industry='その他製品',
        sec_code='77900',
        corporate_number='8270001005096',
    ),
    'E36046': EdinetCodeEntry(
        edinet_code='E36046',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1351,
        fiscal_year_end='7月31日',
        submitter_name='プレミアアンチエイジング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プレミアンチエイジングカブシキガイシャ',
        address='港区虎ノ門二丁目６番１号虎ノ門ヒルズステーションタワー',
        industry='化学',
        sec_code='49340',
        corporate_number='2010401085273',
    ),
    'E36047': EdinetCodeEntry(
        edinet_code='E36047',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='篠田\u3000庸介',
        submitter_name_en=None,
        submitter_name_yomi='シノダ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36051': EdinetCodeEntry(
        edinet_code='E36051',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='シバニェ・ユーケー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シバニェユーケーリミテッド',
        address='英国ＷＣ１Ｖ６ＢＸロンドン、ハイ・ホルボーン１６、ブレイチャー・ローリンズ・エル・エル・ピー気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36052': EdinetCodeEntry(
        edinet_code='E36052',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10375,
        fiscal_year_end=None,
        submitter_name='エムエム建材株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエムケンザイカブシキカイシャ',
        address='港区東新橋一丁目５番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001073087',
    ),
    'E36056': EdinetCodeEntry(
        edinet_code='E36056',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ワイエムエム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイエムエム',
        address='横浜市中区相生町四丁目６９番地関内Ｈビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401142805',
    ),
    'E36057': EdinetCodeEntry(
        edinet_code='E36057',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000敬',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36058': EdinetCodeEntry(
        edinet_code='E36058',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松浦\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='マツウラ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36059': EdinetCodeEntry(
        edinet_code='E36059',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='アイ・マーキュリーキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイマーキュリーキャピタルカブシキカイシャ',
        address='渋谷区渋谷二丁目２４番１２号\u3000渋谷スクランブルスクエア',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001095671',
    ),
    'E36061': EdinetCodeEntry(
        edinet_code='E36061',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='十見\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='ジュウミ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36063': EdinetCodeEntry(
        edinet_code='E36063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='辛\u3000澤',
        submitter_name_en=None,
        submitter_name_yomi='シン\u3000ゼ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36067': EdinetCodeEntry(
        edinet_code='E36067',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社グリーン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグリーン',
        address='東伯郡北栄町江北４５１番地６９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9270001007901',
    ),
    'E36069': EdinetCodeEntry(
        edinet_code='E36069',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=116,
        fiscal_year_end=None,
        submitter_name='Ｌｏｎｇ\u3000Ｃｏｒｒｉｄｏｒ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ロング\u3000コリドー\u3000アセット\u3000マネジメント\u3000リミテッド',
        address='２６／ｆ，\u3000Ｔｈｒｅｅ\u3000Ｅｘｃｈａｎｇｅ\u3000Ｓｑｕａｒｅ，\u3000８\u3000Ｃｏｎｎａｕｇｈｔ\u3000Ｐｌａｃｅ，\u3000Ｃｅｎｔｒａｌ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36070': EdinetCodeEntry(
        edinet_code='E36070',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1020,
        fiscal_year_end='8月31日',
        submitter_name='ペイクラウドホールディングス株式会社',
        submitter_name_en='Paycloud Holdings Inc.',
        submitter_name_yomi='ペイクラウドホールディングスカブシキガイシャ',
        address='港区南青山二丁目２４番１５号',
        industry='情報・通信業',
        sec_code='40150',
        corporate_number='7010401068488',
    ),
    'E36071': EdinetCodeEntry(
        edinet_code='E36071',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='京東株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウトウカブシキカイシャ',
        address='中央区銀座七丁目１５番１１号６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101072593',
    ),
    'E36077': EdinetCodeEntry(
        edinet_code='E36077',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=200,
        fiscal_year_end='11月末日',
        submitter_name='ＭＩＴホールディングス株式会社',
        submitter_name_en='MIT Holdings CO.,LTD.',
        submitter_name_yomi='ミットホールディングスカブシキガイシャ',
        address='千葉市美浜区中瀬二丁目６番地１',
        industry='情報・通信業',
        sec_code='40160',
        corporate_number='8040001042344',
    ),
    'E36078': EdinetCodeEntry(
        edinet_code='E36078',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=363,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ジオコード',
        submitter_name_en='GEOCODE CO., Ltd.',
        submitter_name_yomi='カブシキガイシャジオコード',
        address='新宿区新宿四丁目１番６号',
        industry='サービス業',
        sec_code='73570',
        corporate_number='4010401094677',
    ),
    'E36080': EdinetCodeEntry(
        edinet_code='E36080',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社アリスタゴラ・アドバイザーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアリスタゴラアドバイザーズ',
        address='港区愛宕二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401075960',
    ),
    'E36081': EdinetCodeEntry(
        edinet_code='E36081',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐郷\u3000充啓',
        submitter_name_en=None,
        submitter_name_yomi='サゴウ\u3000ミツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36082': EdinetCodeEntry(
        edinet_code='E36082',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='千鳥合同会社',
        submitter_name_en=None,
        submitter_name_yomi='チドリゴウドウガイシャ',
        address='港区西新橋一丁目１番１号ＥＰコンサルティングサービス内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010403023721',
    ),
    'E36086': EdinetCodeEntry(
        edinet_code='E36086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=812,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ココペリ',
        submitter_name_en='Kokopelli Inc.',
        submitter_name_yomi='カブシキカイシャココペリ',
        address='千代田区紀尾井町３番１２号',
        industry='情報・通信業',
        sec_code='41670',
        corporate_number='8010401088972',
    ),
    'E36087': EdinetCodeEntry(
        edinet_code='E36087',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平川\u3000大',
        submitter_name_en=None,
        submitter_name_yomi='ヒラカワ\u3000ダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36088': EdinetCodeEntry(
        edinet_code='E36088',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社シーラテクノロジーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシーラテクノロジーズ',
        address='渋谷区広尾１－１－３９\u3000恵比寿プライムスクエア７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001059862',
    ),
    'E36089': EdinetCodeEntry(
        edinet_code='E36089',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='エスエスケイフーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエスケイフーズカブシキカイシャ',
        address='静岡市清水区入船町１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080001008256',
    ),
    'E36090': EdinetCodeEntry(
        edinet_code='E36090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平川\u3000裕司',
        submitter_name_en=None,
        submitter_name_yomi='ヒラカワ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36091': EdinetCodeEntry(
        edinet_code='E36091',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1414,
        fiscal_year_end='12月31日',
        submitter_name='バルミューダ株式会社',
        submitter_name_en='BALMUDA Inc.',
        submitter_name_yomi='バルミューダカブシキガイシャ',
        address='武蔵野市境南町五丁目１番２１号',
        industry='電気機器',
        sec_code='66120',
        corporate_number='1012701010928',
    ),
    'E36098': EdinetCodeEntry(
        edinet_code='E36098',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1186,
        fiscal_year_end='3月末日',
        submitter_name='株式会社オーケーエム',
        submitter_name_en='OKUMURA ENGINEERING CORP.',
        submitter_name_yomi='カブシキガイシャオーケーエム',
        address='蒲生郡日野町大字大谷４４６番地の１',
        industry='機械',
        sec_code='62290',
        corporate_number='5160001009813',
    ),
    'E36100': EdinetCodeEntry(
        edinet_code='E36100',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=532,
        fiscal_year_end='2月末日',
        submitter_name='株式会社クリーマ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクリーマ',
        address='港区北青山２ー１２ー５\u3000ＫＲＴビル２Ｆ',
        industry='情報・通信業',
        sec_code='40170',
        corporate_number='6011001059861',
    ),
    'E36101': EdinetCodeEntry(
        edinet_code='E36101',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000竜也',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36102': EdinetCodeEntry(
        edinet_code='E36102',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='3月31日',
        submitter_name='オリエンタル白石株式会社',
        submitter_name_en='Oriental Shiraishi Corporation',
        submitter_name_yomi='オリエンタルシライシカブシキガイシャ',
        address='江東区豊洲五丁目６番５２号\u3000ＮＢＦ豊洲キャナルフロント\u3000５Ｆ',
        industry='建設業',
        sec_code='17860',
        corporate_number='7010601040057',
    ),
    'E36104': EdinetCodeEntry(
        edinet_code='E36104',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=140,
        fiscal_year_end=None,
        submitter_name='ＮＩＰＰＯＮ\u3000ＡＣＴＩＶＥ\u3000ＶＡＬＵＥ\u3000ＦＵＮＤ\u3000ＰＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ニッポン\u3000アクティブ\u3000バリュー\u3000ファンド',
        address='イギリス連合王国ロンドン市ロンドンウォール１２５番地６階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36105': EdinetCodeEntry(
        edinet_code='E36105',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='武田\u3000和也',
        submitter_name_en=None,
        submitter_name_yomi='タケダ\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36107': EdinetCodeEntry(
        edinet_code='E36107',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2563,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ヤプリ',
        submitter_name_en='Yappli, Inc.',
        submitter_name_yomi='カブシキガイシャヤプリ',
        address='港区六本木三丁目２番１号住友不動産六本木グランドタワー４１階',
        industry='情報・通信業',
        sec_code='41680',
        corporate_number='6010401104203',
    ),
    'E36108': EdinetCodeEntry(
        edinet_code='E36108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=311,
        fiscal_year_end='12月31日',
        submitter_name='ビートレンド株式会社',
        submitter_name_en='BETREND CORPORATION',
        submitter_name_yomi='ビートレンドカブシキカイシャ',
        address='品川区北品川５丁目５番１５号\u3000大崎ブライトコア６Ｆ',
        industry='サービス業',
        sec_code='40200',
        corporate_number='7010401054521',
    ),
    'E36109': EdinetCodeEntry(
        edinet_code='E36109',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社麻生東水ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアソウトウスイホールディングス',
        address='千代田区丸の内三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003032787',
    ),
    'E36111': EdinetCodeEntry(
        edinet_code='E36111',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='庵原\u3000保文',
        submitter_name_en=None,
        submitter_name_yomi='イハラ\u3000ヤスブミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36113': EdinetCodeEntry(
        edinet_code='E36113',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐野\u3000将史',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000マサフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36115': EdinetCodeEntry(
        edinet_code='E36115',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000真澄',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000マスミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36117': EdinetCodeEntry(
        edinet_code='E36117',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社エメラルド',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャエメラルド',
        address='千代田区丸の内三丁目１番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003026448',
    ),
    'E36122': EdinetCodeEntry(
        edinet_code='E36122',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=693,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｋａｉｚｅｎ\u3000Ｐｌａｔｆｏｒｍ',
        submitter_name_en='Kaizen Platform, Inc.',
        submitter_name_yomi='カブシキガイシャカイゼンプラットフォーム',
        address='港区白金１丁目２７番６号',
        industry='情報・通信業',
        sec_code='41700',
        corporate_number='2010401130731',
    ),
    'E36123': EdinetCodeEntry(
        edinet_code='E36123',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=748,
        fiscal_year_end='3月31日',
        submitter_name='株式会社いつも',
        submitter_name_en='itsumo.inc.',
        submitter_name_yomi='カブシキカイシャイツモ',
        address='千代田区有楽町１－１３－２\u3000第一生命日比谷ファースト',
        industry='サービス業',
        sec_code='76940',
        corporate_number='4010401074282',
    ),
    'E36124': EdinetCodeEntry(
        edinet_code='E36124',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='サンズ・キャピタル・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='サンズ\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='アメリカ合衆国、１９８０８、デラウェア州、ウィルミントン、２５１リトル・フォールズ・ドライブ、コーポレーション・サービス・カンパニー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36126': EdinetCodeEntry(
        edinet_code='E36126',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クールトラスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャクールトラスト',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001134970',
    ),
    'E36127': EdinetCodeEntry(
        edinet_code='E36127',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人中山視覚福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンナカヤマシカクフクシザイダン',
        address='神戸市兵庫区水木通２丁目１番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140005005276',
    ),
    'E36129': EdinetCodeEntry(
        edinet_code='E36129',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=117,
        fiscal_year_end='9月末日',
        submitter_name='クリングルファーマ株式会社',
        submitter_name_en='Kringle Pharma,Inc.',
        submitter_name_yomi='クリングルファーマカブシキガイシャ',
        address='大阪市北区中之島四丁目３番５１号',
        industry='医薬品',
        sec_code='48840',
        corporate_number='7120901027189',
    ),
    'E36130': EdinetCodeEntry(
        edinet_code='E36130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16,
        fiscal_year_end='3月31日',
        submitter_name='ＥＮＥＣＨＡＮＧＥ株式会社',
        submitter_name_en='ENECHANGE Ltd.',
        submitter_name_yomi='エネチェンジカブシキカイシャ',
        address='港区虎ノ門三丁目２番２号',
        industry='サービス業',
        sec_code='41690',
        corporate_number='6010601047805',
    ),
    'E36132': EdinetCodeEntry(
        edinet_code='E36132',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=372,
        fiscal_year_end='11月末日',
        submitter_name='株式会社オンデック',
        submitter_name_en='ONDECK Co., Ltd.',
        submitter_name_yomi='カブシキガイシャオンデック',
        address='大阪市中央区備後町三丁目４番１号',
        industry='サービス業',
        sec_code='73600',
        corporate_number='3120001128528',
    ),
    'E36133': EdinetCodeEntry(
        edinet_code='E36133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=18,
        fiscal_year_end='12月31日',
        submitter_name='株式会社リベルタ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリベルタ',
        address='渋谷区桜丘町２６－１セルリアンタワー５Ｆ',
        industry='化学',
        sec_code='49350',
        corporate_number='4011001034965',
    ),
    'E36134': EdinetCodeEntry(
        edinet_code='E36134',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=456,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＬＩＴＡＬＩＣＯ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリタリコ',
        address='目黒区上目黒二丁目１番１号',
        industry='サービス業',
        sec_code='73660',
        corporate_number='4011001133197',
    ),
    'E36136': EdinetCodeEntry(
        edinet_code='E36136',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石田\u3000一',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36137': EdinetCodeEntry(
        edinet_code='E36137',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濵田\u3000雄史',
        submitter_name_en=None,
        submitter_name_yomi='ハマダ\u3000ユウシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36138': EdinetCodeEntry(
        edinet_code='E36138',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴＴアド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌティティアド',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701013722',
    ),
    'E36140': EdinetCodeEntry(
        edinet_code='E36140',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=639,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ビーイングホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ガブシキカイシャビーイングホールディングス',
        address='金沢市専光寺町レ３番地１８',
        industry='陸運業',
        sec_code='91450',
        corporate_number='8220001007865',
    ),
    'E36141': EdinetCodeEntry(
        edinet_code='E36141',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=12055,
        fiscal_year_end='12月31日',
        submitter_name='ウェルスナビ株式会社',
        submitter_name_en='WealthNavi Inc.',
        submitter_name_yomi='ウェルスナビカブシキカイシャ',
        address='品川区西五反田八丁目４番１３号五反田ＪＰビルディング９Ｆ',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='3010001167611',
    ),
    'E36142': EdinetCodeEntry(
        edinet_code='E36142',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='須藤\u3000憲司',
        submitter_name_en=None,
        submitter_name_yomi='スドウ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36143': EdinetCodeEntry(
        edinet_code='E36143',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石橋\u3000利真',
        submitter_name_en=None,
        submitter_name_yomi='イシバシ\u3000トシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36144': EdinetCodeEntry(
        edinet_code='E36144',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＭＦＬみらいパートナーズインベストメント２号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエムエフエルミライパートナージンベストメントニゴウカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001211363',
    ),
    'E36145': EdinetCodeEntry(
        edinet_code='E36145',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エタニティ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エタニティカブシキカイシャ',
        address='いわき市常磐湯本町辰ノ口１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4380001031291',
    ),
    'E36150': EdinetCodeEntry(
        edinet_code='E36150',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社エスティエンジニアリング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスティエンジニアリング',
        address='大阪市中央区船越町１－５－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001133083',
    ),
    'E36152': EdinetCodeEntry(
        edinet_code='E36152',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺尾\u3000玄',
        submitter_name_en=None,
        submitter_name_yomi='テラオ\u3000ゲン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36153': EdinetCodeEntry(
        edinet_code='E36153',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2299,
        fiscal_year_end=None,
        submitter_name='エスジー\u3000クラインオート\u3000ハンブロス\u3000トラスト\u3000カンパニー（シーアイ）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エスジークラインオートハンブロストラストカンパニーシーアイリミテッド',
        address='エスジー\u3000ハンブロス\u3000ハウス、エスピラナーデ１８、セントヘリア、ジャージー、ＪＥ４\u3000８ＲＴ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36154': EdinetCodeEntry(
        edinet_code='E36154',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田畑\u3000正吾',
        submitter_name_en=None,
        submitter_name_yomi='タバタ\u3000ショウゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36155': EdinetCodeEntry(
        edinet_code='E36155',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=607,
        fiscal_year_end='12月末日',
        submitter_name='株式会社スタメン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスタメン',
        address='名古屋市中村区下広井町一丁目１４－８',
        industry='情報・通信業',
        sec_code='40190',
        corporate_number='7180001121985',
    ),
    'E36156': EdinetCodeEntry(
        edinet_code='E36156',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='株式会社デンソーウェーブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデンソーウェーブ',
        address='知多郡阿久比町大字草木字芳池１番',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8180001100311',
    ),
    'E36157': EdinetCodeEntry(
        edinet_code='E36157',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小川\u3000武重',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000タケシゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36161': EdinetCodeEntry(
        edinet_code='E36161',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='近藤\u3000繁',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36162': EdinetCodeEntry(
        edinet_code='E36162',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000哲哉',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36166': EdinetCodeEntry(
        edinet_code='E36166',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙島\u3000健二',
        submitter_name_en=None,
        submitter_name_yomi='タカシマ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36167': EdinetCodeEntry(
        edinet_code='E36167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山田\u3000美代子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ミヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36171': EdinetCodeEntry(
        edinet_code='E36171',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＪＳＬホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイエスエルホールディングスゴウドウカイシャ',
        address='千代田区麹町一丁目１２番地１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003032634',
    ),
    'E36172': EdinetCodeEntry(
        edinet_code='E36172',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=137,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グローバルインフォメーション',
        submitter_name_en='Global Information, Inc.',
        submitter_name_yomi='カブシキガイシャグローバルインフォメーション',
        address='川崎市麻生区万福寺一丁目２番３号アーシスビル７階',
        industry='情報・通信業',
        sec_code='41710',
        corporate_number='4020001065144',
    ),
    'E36173': EdinetCodeEntry(
        edinet_code='E36173',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=613,
        fiscal_year_end='12月31日',
        submitter_name='株式会社東京通信グループ',
        submitter_name_en='Tokyo Communications Group,Inc.',
        submitter_name_yomi='カブシキカイシャトウキョウツウシングループ',
        address='港区六本木三丁目２番１号',
        industry='情報・通信業',
        sec_code='73590',
        corporate_number='6011001105525',
    ),
    'E36174': EdinetCodeEntry(
        edinet_code='E36174',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=374,
        fiscal_year_end='12月31日',
        submitter_name='かっこ株式会社',
        submitter_name_en='Cacco Inc.',
        submitter_name_yomi='カッコカブシキガイシャ',
        address='港区元赤坂一丁目５番３１号',
        industry='情報・通信業',
        sec_code='41660',
        corporate_number='9010001137889',
    ),
    'E36175': EdinetCodeEntry(
        edinet_code='E36175',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000寿彦',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36179': EdinetCodeEntry(
        edinet_code='E36179',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＨＯＡＮＧ\u3000ＬＡＮ',
        submitter_name_en=None,
        submitter_name_yomi='ホアン\u3000ラン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36181': EdinetCodeEntry(
        edinet_code='E36181',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神谷\u3000アントニオ',
        submitter_name_en=None,
        submitter_name_yomi='カミヤ\u3000アントニオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36182': EdinetCodeEntry(
        edinet_code='E36182',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森垣\u3000昭',
        submitter_name_en=None,
        submitter_name_yomi='モリガキ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36183': EdinetCodeEntry(
        edinet_code='E36183',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1858,
        fiscal_year_end=None,
        submitter_name='マスト・アセット・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='マストアセットマネジメントインク',
        address='大韓民国ソウル特別市江南区彦州路３０街３９、３階（道谷洞、リンスクエア）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36187': EdinetCodeEntry(
        edinet_code='E36187',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='倉田将志',
        submitter_name_en=None,
        submitter_name_yomi='クラタマサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36188': EdinetCodeEntry(
        edinet_code='E36188',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='コラ・マネジメント・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='コラ\u3000マネジメント\u3000エルピー',
        address='アメリカ合衆国、１９８０８デラウェア州、ウィルミントン、スイート４００、センターヴィル・ロード２７１１、コーポレーション・サービス・カンパニー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36189': EdinetCodeEntry(
        edinet_code='E36189',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36190': EdinetCodeEntry(
        edinet_code='E36190',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10020,
        fiscal_year_end='3月末日',
        submitter_name='サワイグループホールディングス株式会社',
        submitter_name_en='SAWAI GROUP HOLDINGS Co., Ltd.',
        submitter_name_yomi='サワイグループホールディングスカブシキガイシャ',
        address='大阪市淀川区宮原５丁目２－３０',
        industry='医薬品',
        sec_code='48870',
        corporate_number='8120001236516',
    ),
    'E36192': EdinetCodeEntry(
        edinet_code='E36192',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小野\u3000悟',
        submitter_name_en=None,
        submitter_name_yomi='オノ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36195': EdinetCodeEntry(
        edinet_code='E36195',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000敬介',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36196': EdinetCodeEntry(
        edinet_code='E36196',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000厚史',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36198': EdinetCodeEntry(
        edinet_code='E36198',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='クァン・ミン・インベストメント・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='クァン\u3000ミン\u3000インベストメント\u3000ピーティーイー\u3000リミテッド',
        address='シンガポール、ファー・イースト・プラザ、＃０６－０１、１４\u3000スコットロード',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36199': EdinetCodeEntry(
        edinet_code='E36199',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000透',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36201': EdinetCodeEntry(
        edinet_code='E36201',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丸林\u3000耕太郎',
        submitter_name_en=None,
        submitter_name_yomi='マルバヤシ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36202': EdinetCodeEntry(
        edinet_code='E36202',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大橋\u3000優輝',
        submitter_name_en=None,
        submitter_name_yomi='オオハシ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36205': EdinetCodeEntry(
        edinet_code='E36205',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000泰博',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36212': EdinetCodeEntry(
        edinet_code='E36212',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社つづく',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツヅク',
        address='中央区銀座一丁目２２番１１号銀座大竹ビジデンス２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001197079',
    ),
    'E36213': EdinetCodeEntry(
        edinet_code='E36213',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=638,
        fiscal_year_end='1月31日',
        submitter_name='株式会社アピリッツ',
        submitter_name_en='Appirits Inc.',
        submitter_name_yomi='カブシキカイシャアピリッツ',
        address='渋谷区桜丘町１番１号',
        industry='情報・通信業',
        sec_code='41740',
        corporate_number='4011001065192',
    ),
    'E36214': EdinetCodeEntry(
        edinet_code='E36214',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トラ・トレーディング・サービシズ・リミテッド（Ｔｏｒａ\u3000Ｔｒａｄｉｎｇ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｌｉｍｉｔｅｄ）',
        submitter_name_en=None,
        submitter_name_yomi='トラトレーディングサービシズリミテッド',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００５、カマナ・ベイ、ワン・ネクサス・ウェイ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36215': EdinetCodeEntry(
        edinet_code='E36215',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='きらぼしキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キラボシキャピタルカブシキガイシャ',
        address='港区南青山三丁目１０番４３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401140638',
    ),
    'E36216': EdinetCodeEntry(
        edinet_code='E36216',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='外川\u3000穣',
        submitter_name_en=None,
        submitter_name_yomi='ソトカワ\u3000ユズル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36217': EdinetCodeEntry(
        edinet_code='E36217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古屋\u3000佑樹',
        submitter_name_en=None,
        submitter_name_yomi='フルヤ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36223': EdinetCodeEntry(
        edinet_code='E36223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3107,
        fiscal_year_end='9月30日',
        submitter_name='人・夢・技術グループ株式会社',
        submitter_name_en='People, Dreams & Technologies Group Co., Ltd.',
        submitter_name_yomi='ヒトユメギジュツグループカブシキガイシャ',
        address='中央区日本橋蛎殻町一丁目２０番４号',
        industry='サービス業',
        sec_code='92480',
        corporate_number='7010001221554',
    ),
    'E36224': EdinetCodeEntry(
        edinet_code='E36224',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='萩尾\u3000陽平',
        submitter_name_en=None,
        submitter_name_yomi='ハギオ\u3000ヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36228': EdinetCodeEntry(
        edinet_code='E36228',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='樋口\u3000荘祐',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチ\u3000ソウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36234': EdinetCodeEntry(
        edinet_code='E36234',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='パブリック・インベストメント・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='パブリックインベストメントファンド',
        address='サウジアラビア王国、１３５１９\u3000リヤド市、アルアキーク地区、キング・アブドラ金融地区、ザ・パブリック・インベストメント・ファンド・タワー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36236': EdinetCodeEntry(
        edinet_code='E36236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上英昭',
        submitter_name_en=None,
        submitter_name_yomi='イノウエヒデアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36237': EdinetCodeEntry(
        edinet_code='E36237',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社フォーカスキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフォーカスキャピタル',
        address='世田谷区上用賀三丁目１４番１７－３０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010903002078',
    ),
    'E36238': EdinetCodeEntry(
        edinet_code='E36238',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='村井資本株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ムライシホンカブシキカイシャ',
        address='渋谷区東四丁目４番１２－３０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003033293',
    ),
    'E36239': EdinetCodeEntry(
        edinet_code='E36239',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000政人',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000マサヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36240': EdinetCodeEntry(
        edinet_code='E36240',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥岡\u3000征彦',
        submitter_name_en=None,
        submitter_name_yomi='オクオカ\u3000ユキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36242': EdinetCodeEntry(
        edinet_code='E36242',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奥村\u3000晋一',
        submitter_name_en=None,
        submitter_name_yomi='オクムラ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36243': EdinetCodeEntry(
        edinet_code='E36243',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｃｈｅｕｎｇ\u3000Ｙｕｋ\u3000Ｓｈａｎ\u3000Ｓｈｉｒｌｅｙ',
        submitter_name_en=None,
        submitter_name_yomi='チャン\u3000ユク\u3000シャン\u3000シャーリー',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36247': EdinetCodeEntry(
        edinet_code='E36247',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='喜多甚一',
        submitter_name_en=None,
        submitter_name_yomi='キタシゲカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36249': EdinetCodeEntry(
        edinet_code='E36249',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＴＣＳカンパニーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テイシイエスカンパニーズカブシキガイシャ',
        address='中央区日本橋本町四丁目８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5140001006481',
    ),
    'E36250': EdinetCodeEntry(
        edinet_code='E36250',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中沢\u3000雄太',
        submitter_name_en=None,
        submitter_name_yomi='ナカザワ\u3000ユウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36251': EdinetCodeEntry(
        edinet_code='E36251',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩井\u3000裕之',
        submitter_name_en=None,
        submitter_name_yomi='イワイ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36252': EdinetCodeEntry(
        edinet_code='E36252',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関根\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='セキネ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36258': EdinetCodeEntry(
        edinet_code='E36258',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='テックス・テクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テックステクノロジーカブシキガイシャ',
        address='千代田区神田和泉町１番１－１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010501023858',
    ),
    'E36259': EdinetCodeEntry(
        edinet_code='E36259',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='倉橋\u3000健太',
        submitter_name_en=None,
        submitter_name_yomi='クラハシ\u3000ケンタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36261': EdinetCodeEntry(
        edinet_code='E36261',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=655,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ファブリカホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャファブリカホールディングス',
        address='港区赤坂一丁目１１番３０号',
        industry='情報・通信業',
        sec_code='41930',
        corporate_number='7180001049855',
    ),
    'E36262': EdinetCodeEntry(
        edinet_code='E36262',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='近藤\u3000智司',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36263': EdinetCodeEntry(
        edinet_code='E36263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＴＲＩＶＥ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ストライブカブシキカイシャ',
        address='港区虎ノ門五丁目１１番１号\u3000オランダヒルズ森タワーＲｏＰ１２０３号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401096762',
    ),
    'E36267': EdinetCodeEntry(
        edinet_code='E36267',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永山\u3000隆昭',
        submitter_name_en=None,
        submitter_name_yomi='ナガヤマ\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36268': EdinetCodeEntry(
        edinet_code='E36268',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月30日',
        submitter_name='株式会社シック・ホールディングス',
        submitter_name_en='CHIC Holdings INC.',
        submitter_name_yomi='カブシキガイシャシックホールディングス',
        address='新宿区新小川町４番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='1011101094672',
    ),
    'E36269': EdinetCodeEntry(
        edinet_code='E36269',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='ＤＢＪキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディービージェイキャピタルカブシキカイシャ',
        address='千代田区大手町一丁目９番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001124108',
    ),
    'E36271': EdinetCodeEntry(
        edinet_code='E36271',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='亀山\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='カメヤマ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36277': EdinetCodeEntry(
        edinet_code='E36277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大西\u3000泰平',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000タイヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36278': EdinetCodeEntry(
        edinet_code='E36278',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田野\u3000聡美',
        submitter_name_en=None,
        submitter_name_yomi='タノ\u3000サトミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36279': EdinetCodeEntry(
        edinet_code='E36279',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｎｇｅｌ\u3000Ｂｒｉｄｇｅ\u3000Ｄｅａｌ－ｂｙ－Ｄｅａｌ\u3000Ｆｕｎｄ９号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンジェルブリッジディールバイディールファンドキュウゴウカブシキガイシャ',
        address='千代田区永田町２－１７－４笠松千代田ビル１０１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001191470',
    ),
    'E36280': EdinetCodeEntry(
        edinet_code='E36280',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='Ｍ＆Ａグローバル・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムアンドエーグローバルパートナーズ',
        address='中央区日本橋室町四丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401094467',
    ),
    'E36282': EdinetCodeEntry(
        edinet_code='E36282',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植野\u3000泰幸',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36283': EdinetCodeEntry(
        edinet_code='E36283',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社慶應イノベーション・イニシアティブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイオウイノベーションイニシアティブ',
        address='港区虎ノ門五丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401122249',
    ),
    'E36284': EdinetCodeEntry(
        edinet_code='E36284',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＢ戦略投資事業合同会社',
        submitter_name_en=None,
        submitter_name_yomi='シービーセンリャクトウシジギョウゴウドウガイシャ',
        address='渋谷区初台一丁目５２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011103008262',
    ),
    'E36293': EdinetCodeEntry(
        edinet_code='E36293',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=672,
        fiscal_year_end=None,
        submitter_name='Ｄａｌａｌ\u3000Ｓｔｒｅｅｔ，\u3000ＬＬＣ．',
        submitter_name_en=None,
        submitter_name_yomi='ダラルストリートエルエルシー',
        address='アメリカ合衆国カリフォルニア州９２６２０、アーバイン、ルーズベルト１２２０、スイート２００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36294': EdinetCodeEntry(
        edinet_code='E36294',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＫ\u3000Ｂｅｉｄａ\u3000Ｊａｄｅ\u3000Ｂｉｒｄ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ホンコンベイダージェードバードインベストメンツリミテッド',
        address='１７ｔｈ\u3000Ｆｌｏｏｒ，\u3000Ｖ\u3000Ｈｅｕｎ\u3000Ｂｕｉｌｄｉｎｇ，\u3000１３８\u3000Ｑｕｅｅｎ’ｓ\u3000Ｒｏａｄ\u3000Ｃｅｎｔｒａｌ，\u3000Ｃｅｎｔｒａｌ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36295': EdinetCodeEntry(
        edinet_code='E36295',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='城口\u3000洋平',
        submitter_name_en=None,
        submitter_name_yomi='キグチ\u3000ヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36296': EdinetCodeEntry(
        edinet_code='E36296',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有田\u3000一平',
        submitter_name_en=None,
        submitter_name_yomi='アリタ\u3000イッペイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36297': EdinetCodeEntry(
        edinet_code='E36297',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢作\u3000和幸',
        submitter_name_en=None,
        submitter_name_yomi='ヤハギ\u3000カズユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36298': EdinetCodeEntry(
        edinet_code='E36298',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='アークホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アークホールディングスカブシキガイシャ',
        address='渋谷区南平台町１５－１３帝都渋谷ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001105169',
    ),
    'E36299': EdinetCodeEntry(
        edinet_code='E36299',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='ＳＭＦＬみらいパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエムエフエルミライパートナーズカブシキカイシャ',
        address='千代田区丸の内一丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001195354',
    ),
    'E36300': EdinetCodeEntry(
        edinet_code='E36300',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='東北大学ベンチャーパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウホクダイガクベンチャーパートナーズカブシキガイシャ',
        address='仙台市青葉区荒巻字青葉４６８番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4370001025360',
    ),
    'E36301': EdinetCodeEntry(
        edinet_code='E36301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000滋久',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000シゲヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36304': EdinetCodeEntry(
        edinet_code='E36304',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ホライズン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホライズン',
        address='大阪市西区南堀江二丁目７番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001231376',
    ),
    'E36305': EdinetCodeEntry(
        edinet_code='E36305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柴山\u3000和久',
        submitter_name_en=None,
        submitter_name_yomi='シバヤマ\u3000カズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36306': EdinetCodeEntry(
        edinet_code='E36306',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=107,
        fiscal_year_end=None,
        submitter_name='Ｅｎｅｒｇｙ\u3000Ｓｔａｔｉｏｎ\u3000Ｃｏｍｐａｎｙ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エナジーステーションカンパニーリミテッド',
        address='ＦＬＡＴ\u3000Ｅ，２９／Ｆ．，ＡＬＡＳＳＩＯ，１００\u3000ＣＡＩＮＥ\u3000ＲＯＡＤ，Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36307': EdinetCodeEntry(
        edinet_code='E36307',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栗原\u3000将',
        submitter_name_en=None,
        submitter_name_yomi='クリハラ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36308': EdinetCodeEntry(
        edinet_code='E36308',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栗原\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='クリハラ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36310': EdinetCodeEntry(
        edinet_code='E36310',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='原田\u3000智法',
        submitter_name_en=None,
        submitter_name_yomi='ハラダ\u3000トモノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36312': EdinetCodeEntry(
        edinet_code='E36312',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=102,
        fiscal_year_end='6月30日',
        submitter_name='株式会社Ｇｅｏｌｏｃａｔｉｏｎ\u3000Ｔｅｃｈｎｏｌｏｇｙ',
        submitter_name_en='Geolocation Technology, Inc.',
        submitter_name_yomi='カブシキカイシャジオロケーションテクノロジー',
        address='三島市一番町１８－２２',
        industry='情報・通信業',
        sec_code='40180',
        corporate_number='4080101006447',
    ),
    'E36314': EdinetCodeEntry(
        edinet_code='E36314',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久保\u3000良介',
        submitter_name_en=None,
        submitter_name_yomi='クボ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36315': EdinetCodeEntry(
        edinet_code='E36315',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舩戸\u3000雅夫',
        submitter_name_en=None,
        submitter_name_yomi='フナト\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36317': EdinetCodeEntry(
        edinet_code='E36317',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社スターフロンツ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスターフロンツ',
        address='愛知県名古屋市西区名駅１丁目１－１７ダイヤメイテツビル１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001116567',
    ),
    'E36318': EdinetCodeEntry(
        edinet_code='E36318',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='泉\u3000信彦',
        submitter_name_en=None,
        submitter_name_yomi='イズミ\u3000ノブヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36319': EdinetCodeEntry(
        edinet_code='E36319',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='ＲアンドＬホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アールアンドエールホールディングスカブシキガイシャ',
        address='港区東麻布二丁目１５－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401148783',
    ),
    'E36321': EdinetCodeEntry(
        edinet_code='E36321',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2109,
        fiscal_year_end='7月31日',
        submitter_name='株式会社アクシージア',
        submitter_name_en='AXXZIA Inc.',
        submitter_name_yomi='カブシキカイシャアクシージア',
        address='新宿区西新宿６－３－１新宿アイランド・ウィング２階',
        industry='化学',
        sec_code='49360',
        corporate_number='6011101061957',
    ),
    'E36322': EdinetCodeEntry(
        edinet_code='E36322',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1910,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ｃｏｌｙ',
        submitter_name_en='coly Inc.',
        submitter_name_yomi='カブシキガイシャコリー',
        address='港区三田一丁目４番１号',
        industry='情報・通信業',
        sec_code='41750',
        corporate_number='7010401110126',
    ),
    'E36323': EdinetCodeEntry(
        edinet_code='E36323',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=553,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＷＡＣＵＬ',
        submitter_name_en='WACUL.INC',
        submitter_name_yomi='カブシキガイシャワカル',
        address='千代田区神田小川町３－２６－８\u3000２Ｆ',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010001135511',
    ),
    'E36324': EdinetCodeEntry(
        edinet_code='E36324',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='合同会社ＦＩＮＯ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャフィノ',
        address='中央区日本橋蛎殻町二丁目１１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010403016699',
    ),
    'E36327': EdinetCodeEntry(
        edinet_code='E36327',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='セオ運輸株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セオウンユカブシキカイシャ',
        address='尼崎市神田北通６丁目１７１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001049432',
    ),
    'E36328': EdinetCodeEntry(
        edinet_code='E36328',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='タイヨウ・ジュピター・ホールディングス・ジーピー・エルティディー',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウジュピターホールディングスジーピーエルティディー',
        address='ケイマン諸島、ＫＹ１－００２、グランドケイマン、ジョージタウン、サウス・チャーチ・ストリート１０３、ハーバー・プレイス４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36336': EdinetCodeEntry(
        edinet_code='E36336',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000陣屋コネクト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ジンヤコネクト',
        address='秦野市鶴巻北２丁目８番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9021001047920',
    ),
    'E36337': EdinetCodeEntry(
        edinet_code='E36337',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ｚホールディングス中間株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼットホールディングスチュウカンカブシキカイシャ',
        address='千代田区紀尾井町１番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001199704',
    ),
    'E36338': EdinetCodeEntry(
        edinet_code='E36338',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=45000,
        fiscal_year_end='3月31日',
        submitter_name='オリックス銀行株式会社',
        submitter_name_en='ORIX Bank Corporation',
        submitter_name_yomi='オリックスギンコウカブシキガイシャ',
        address='港区芝三丁目２２番８号',
        industry='銀行業',
        sec_code=None,
        corporate_number='1010401084739',
    ),
    'E36340': EdinetCodeEntry(
        edinet_code='E36340',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小菅\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='コスゲ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36341': EdinetCodeEntry(
        edinet_code='E36341',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高野\u3000茂久',
        submitter_name_en=None,
        submitter_name_yomi='タカノ\u3000シゲヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36343': EdinetCodeEntry(
        edinet_code='E36343',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=664,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ｉ－ｐｌｕｇ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイプラグ',
        address='大阪市淀川区西中島５－１１－８',
        industry='情報・通信業',
        sec_code='41770',
        corporate_number='2140001087145',
    ),
    'E36346': EdinetCodeEntry(
        edinet_code='E36346',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月末日',
        submitter_name='ＮＴＴ・ＴＣリース株式会社',
        submitter_name_en='NTT TC Leasing Co.,Ltd.',
        submitter_name_yomi='エヌティティティーシーリースカブシキカイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス１３階',
        industry='その他金融業',
        sec_code=None,
        corporate_number='3010401151289',
    ),
    'E36348': EdinetCodeEntry(
        edinet_code='E36348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐渡市',
        submitter_name_en=None,
        submitter_name_yomi='サドシ',
        address='佐渡市千種２３２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9000020152242',
    ),
    'E36350': EdinetCodeEntry(
        edinet_code='E36350',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=143,
        fiscal_year_end='5月末日',
        submitter_name='室町ケミカル株式会社',
        submitter_name_en='MUROMACHI CHEMICALS INC.',
        submitter_name_yomi='ムロマチケミカルカブシキガイシャ',
        address='大牟田市新勝立町一丁目３８番５',
        industry='医薬品',
        sec_code='48850',
        corporate_number='3290001054096',
    ),
    'E36351': EdinetCodeEntry(
        edinet_code='E36351',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ココナラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャココナラ',
        address='渋谷区桜丘町２０番１号',
        industry='サービス業',
        sec_code='41760',
        corporate_number='9010701026061',
    ),
    'E36353': EdinetCodeEntry(
        edinet_code='E36353',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=374,
        fiscal_year_end='12月末日',
        submitter_name='株式会社Ｔ．Ｓ．Ｉ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーエスアイ',
        address='京都市西京区桂南巽町７５番地４',
        industry='サービス業',
        sec_code='73620',
        corporate_number='6130001044812',
    ),
    'E36354': EdinetCodeEntry(
        edinet_code='E36354',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ジョン・ハートレー・ティッド・キンバル（Ｊｏｈｎ\u3000Ｈａｒｔｌｅｙ\u3000Ｔｉｄｄ\u3000Ｋｉｍｂａｌｌ）',
        submitter_name_en=None,
        submitter_name_yomi='ジョンハートレーティッドキンバル',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36360': EdinetCodeEntry(
        edinet_code='E36360',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='スパイラルキャピタルパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スパイラルキャピタルパートナーズ',
        address='千代田区岩本町二丁目２番１０号日鉄岩本町ビルディング３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001208158',
    ),
    'E36362': EdinetCodeEntry(
        edinet_code='E36362',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武\u3000君',
        submitter_name_en=None,
        submitter_name_yomi='タケ\u3000クン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36363': EdinetCodeEntry(
        edinet_code='E36363',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='伊達アセットマネ－ジメント合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ダテアセットマネージメントゴウドウガイシャ',
        address='札幌市厚別区もみじ台南３丁目３番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8430003004278',
    ),
    'E36365': EdinetCodeEntry(
        edinet_code='E36365',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='２３．７株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トゥエンティスリーセブンカブシキガイシャ',
        address='大阪市北区曾根崎２丁目２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001187428',
    ),
    'E36366': EdinetCodeEntry(
        edinet_code='E36366',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=436,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｓｈａｒｉｎｇ\u3000Ｉｎｎｏｖａｔｉｏｎｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシェアリングイノベーションズ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='情報・通信業',
        sec_code='41780',
        corporate_number='5010601039720',
    ),
    'E36367': EdinetCodeEntry(
        edinet_code='E36367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=508,
        fiscal_year_end='3月31日',
        submitter_name='株式会社コンフィデンス・インターワークス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコンフィデンスインターワークス',
        address='新宿区新宿２丁目１９番１号',
        industry='サービス業',
        sec_code='73740',
        corporate_number='6010001162295',
    ),
    'E36368': EdinetCodeEntry(
        edinet_code='E36368',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=421,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シキノハイテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシキノハイテック',
        address='魚津市吉島８２９番地',
        industry='電気機器',
        sec_code='66140',
        corporate_number='3230001007092',
    ),
    'E36369': EdinetCodeEntry(
        edinet_code='E36369',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000富士夫',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000フジオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36370': EdinetCodeEntry(
        edinet_code='E36370',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田口\u3000知志',
        submitter_name_en=None,
        submitter_name_yomi='タグチ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36372': EdinetCodeEntry(
        edinet_code='E36372',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=7555,
        fiscal_year_end='12月31日',
        submitter_name='Ａｐｐｉｅｒ\u3000Ｇｒｏｕｐ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイピアグループカブシキガイシャ',
        address='港区愛宕二丁目５番１号\u3000愛宕グリーンヒルズＭＯＲＩタワー４０階',
        industry='情報・通信業',
        sec_code='41800',
        corporate_number='4010403018510',
    ),
    'E36373': EdinetCodeEntry(
        edinet_code='E36373',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社Ｎホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌホールディングス',
        address='名古屋市中川区山王二丁目６番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001144329',
    ),
    'E36374': EdinetCodeEntry(
        edinet_code='E36374',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10012,
        fiscal_year_end=None,
        submitter_name='ＳＩＮＯ\u3000ＢＩＯＰＨＡＲＭＡＣＥＵＴＩＣＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シノ\u3000バイオファーマシューティカル\u3000リミテッド',
        address='ケイマン諸島\u3000グランド・ケイマン\u3000ジョージ・タウン\u3000ハッチンスドライブ\u3000クリケットスクウェア\u3000センチュリーヤード\u3000私書箱２６８１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36376': EdinetCodeEntry(
        edinet_code='E36376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＣＨＣＰ－ＨＮ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシーエイチシーピーエイチエヌ',
        address='中央区八重洲二丁目５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001214780',
    ),
    'E36377': EdinetCodeEntry(
        edinet_code='E36377',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社イーグルファイナンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーグルファイナンス',
        address='新宿区西新宿３ー１８ー２－１０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010601046306',
    ),
    'E36382': EdinetCodeEntry(
        edinet_code='E36382',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＥＮ＆パートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケンアンドパートナーズ',
        address='大和市中央林間３－２６－２６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6021001071213',
    ),
    'E36384': EdinetCodeEntry(
        edinet_code='E36384',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12514,
        fiscal_year_end=None,
        submitter_name='ＥＣＭ\u3000マスター\u3000ファンド\u3000ＳＰＶ\u3000２',
        submitter_name_en=None,
        submitter_name_yomi='イーシーエム\u3000マスター\u3000ファンド\u3000エスピーブイ\u3000ツー',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－１１１１、クリケット・スクエア、ハッチンズ・ドライブ、私書箱２６８１、コンヤーズ・トラスト・カンパニー（ケイマン）リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36386': EdinetCodeEntry(
        edinet_code='E36386',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社秀和システムホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシュウワシステムホールディングス',
        address='江東区東陽二丁目４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010601058062',
    ),
    'E36387': EdinetCodeEntry(
        edinet_code='E36387',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＲＥＸＴ株式会社',
        submitter_name_en='REXT, INC.',
        submitter_name_yomi='レクストカブシキガイシャ',
        address='新宿区北新宿二丁目２１番１号',
        industry='小売業',
        sec_code=None,
        corporate_number='5011101094660',
    ),
    'E36388': EdinetCodeEntry(
        edinet_code='E36388',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=77,
        fiscal_year_end=None,
        submitter_name='株式会社アイ・ケイ・ケイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイケイケイ',
        address='名古屋市中区栄三丁目３１番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001033612',
    ),
    'E36390': EdinetCodeEntry(
        edinet_code='E36390',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社ツクイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャツクイ',
        address='横浜市港南区上大岡西１丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010003032209',
    ),
    'E36393': EdinetCodeEntry(
        edinet_code='E36393',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=183,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ココルポート',
        submitter_name_en='Cocorport Inc.',
        submitter_name_yomi='カブシキガイシャココルポート',
        address='川崎市川崎区砂子２－５－１１りそな川崎ビル４階',
        industry='サービス業',
        sec_code='93460',
        corporate_number='9020001094849',
    ),
    'E36394': EdinetCodeEntry(
        edinet_code='E36394',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='サカイ繊維株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サカイセンイカブシキカイシャ',
        address='福井市花堂中二丁目１５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6210001018295',
    ),
    'E36396': EdinetCodeEntry(
        edinet_code='E36396',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｄｉｎｇ\u3000Ｌｕ',
        submitter_name_en=None,
        submitter_name_yomi='ディン\u3000ルー',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36397': EdinetCodeEntry(
        edinet_code='E36397',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=310,
        fiscal_year_end=None,
        submitter_name='株式会社ベストライフホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャベストライフホールディングス',
        address='新宿区西新宿二丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101046861',
    ),
    'E36398': EdinetCodeEntry(
        edinet_code='E36398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=752,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジーネクスト',
        submitter_name_en='G-NEXT Inc.',
        submitter_name_yomi='カブシキガイシャジーネクスト',
        address='千代田区平河町２丁目８－９\u3000ＨＢ河町ビル３Ｆ',
        industry='情報・通信業',
        sec_code='41790',
        corporate_number='6010001146785',
    ),
    'E36399': EdinetCodeEntry(
        edinet_code='E36399',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='グローバル・イノベーション・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グローバルイノベーションパートナーズカブシキガイシャ',
        address='港区東新橋一丁目５番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401060060',
    ),
    'E36401': EdinetCodeEntry(
        edinet_code='E36401',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='島\u3000啓介',
        submitter_name_en=None,
        submitter_name_yomi='シマ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36402': EdinetCodeEntry(
        edinet_code='E36402',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＢ１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティービーワンカブシキガイシャ',
        address='中央区銀座四丁目９番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001213290',
    ),
    'E36403': EdinetCodeEntry(
        edinet_code='E36403',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=226,
        fiscal_year_end=None,
        submitter_name='Ｍｉｔｓｕｉ＆Ｃｏ．Ｇｌｏｂａｌ\u3000Ｉｎｖｅｓｔｍｅｎｔ，Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ミツイ\u3000アンド\u3000コ\u3000グローバルインベストメント\u3000インク',
        address='５３５\u3000Ｍｉｄｄｌｅｆｉｅｌｄ\u3000Ｒｏａｄ，Ｓｕｉｔｅ\u3000１００\u3000Ｍｅｎｌｏ\u3000Ｐａｒｋ，ＣＡ９４０２５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36405': EdinetCodeEntry(
        edinet_code='E36405',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1652,
        fiscal_year_end='3月31日',
        submitter_name='株式会社イー・ロジット',
        submitter_name_en='e LogiT co.,ltd.',
        submitter_name_yomi='カブシキガイシャイーロジット',
        address='千代田区外神田３丁目１１番１１号',
        industry='倉庫・運輸関連',
        sec_code='93270',
        corporate_number='7010001126191',
    ),
    'E36406': EdinetCodeEntry(
        edinet_code='E36406',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=655,
        fiscal_year_end='3月31日',
        submitter_name='ブロードマインド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブロードマインドカブシキガイシャ',
        address='渋谷区桜丘町１番１号',
        industry='その他金融業',
        sec_code='73430',
        corporate_number='6011001066916',
    ),
    'E36408': EdinetCodeEntry(
        edinet_code='E36408',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ａｓｌｅａｄ\u3000Ｓｔｒａｔｅｇｉｃ\u3000Ｖａｌｕｅ\u3000Ｆｕｎｄ',
        submitter_name_en=None,
        submitter_name_yomi='アスリード\u3000ストラテジック\u3000バリュー\u3000ファンド',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，ＫＹ１－９００８，Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36410': EdinetCodeEntry(
        edinet_code='E36410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2381,
        fiscal_year_end='12月31日',
        submitter_name='スパイダープラス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スパイダープラスカブシキガイシャ',
        address='港区虎ノ門２－２－１\u3000住友不動産虎ノ門タワー２７階',
        industry='情報・通信業',
        sec_code='41920',
        corporate_number='5013301026121',
    ),
    'E36412': EdinetCodeEntry(
        edinet_code='E36412',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6754,
        fiscal_year_end='6月末日',
        submitter_name='テスホールディングス株式会社',
        submitter_name_en='TESS Holdings Co., Ltd.',
        submitter_name_yomi='テスホールディングスカブシキガイシャ',
        address='大阪市淀川区西中島６丁目１番１号',
        industry='建設業',
        sec_code='50740',
        corporate_number='7120001138936',
    ),
    'E36414': EdinetCodeEntry(
        edinet_code='E36414',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=34201,
        fiscal_year_end=None,
        submitter_name='ＬＩＮＥ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ラインカブシキカイシャ',
        address='新宿区新宿四丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101089911',
    ),
    'E36415': EdinetCodeEntry(
        edinet_code='E36415',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人フェリシモ財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンフェリシモザイダン',
        address='神戸市中央区新港町７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140005025469',
    ),
    'E36416': EdinetCodeEntry(
        edinet_code='E36416',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＫ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイケイ',
        address='中央区銀座１－２２－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001215266',
    ),
    'E36419': EdinetCodeEntry(
        edinet_code='E36419',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人大成温調奨学財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンタイセイオンチョウショウガクザイダン',
        address='大田区山王二丁目１番８－９１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010805002077',
    ),
    'E36420': EdinetCodeEntry(
        edinet_code='E36420',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=193,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ヒューマンクリエイションホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒューマンクリエイションホールディングス',
        address='千代田区霞が関三丁目２番１号',
        industry='サービス業',
        sec_code='73610',
        corporate_number='8010001178760',
    ),
    'E36421': EdinetCodeEntry(
        edinet_code='E36421',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=459,
        fiscal_year_end='7月末日',
        submitter_name='売れるネット広告社グループ株式会社',
        submitter_name_en='Ureru Net Advertising Group Co.,Ltd.',
        submitter_name_yomi='ウレルネットコウコクシャグループカブシキガイシャ',
        address='福岡市早良区百道浜二丁目３番８号',
        industry='情報・通信業',
        sec_code='92350',
        corporate_number='7290001037832',
    ),
    'E36422': EdinetCodeEntry(
        edinet_code='E36422',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000公一レオ',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000コウイチレオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36424': EdinetCodeEntry(
        edinet_code='E36424',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='村山\u3000哲朗',
        submitter_name_en=None,
        submitter_name_yomi='ムラヤマ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36425': EdinetCodeEntry(
        edinet_code='E36425',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='垣内\u3000勇威',
        submitter_name_en=None,
        submitter_name_yomi='カキウチ\u3000ユウイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36426': EdinetCodeEntry(
        edinet_code='E36426',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中道謙',
        submitter_name_en=None,
        submitter_name_yomi='ナカミチケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36429': EdinetCodeEntry(
        edinet_code='E36429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大淵\u3000亮平',
        submitter_name_en=None,
        submitter_name_yomi='オオブチ\u3000リョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36430': EdinetCodeEntry(
        edinet_code='E36430',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石原章太郎',
        submitter_name_en=None,
        submitter_name_yomi='イシハラショウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36431': EdinetCodeEntry(
        edinet_code='E36431',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=282,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ベビーカレンダー',
        submitter_name_en='baby calendar Inc.',
        submitter_name_yomi='カブシキカイシャベビーカレンダー',
        address='渋谷区代々木一丁目３８番２号',
        industry='サービス業',
        sec_code='73630',
        corporate_number='5010401065685',
    ),
    'E36432': EdinetCodeEntry(
        edinet_code='E36432',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1000,
        fiscal_year_end='3月31日',
        submitter_name='東京電力リニューアブルパワー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウデンリョクリニューアブルパワーカブシキガイシャ',
        address='千代田区内幸町１丁目１番３号',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='3010001204364',
    ),
    'E36433': EdinetCodeEntry(
        edinet_code='E36433',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3303,
        fiscal_year_end='2月末日',
        submitter_name='株式会社オキサイド',
        submitter_name_en='OXIDE Corporation',
        submitter_name_yomi='カブシキガイシャオキサイド',
        address='北杜市武川町牧原１７４７番地１',
        industry='その他製品',
        sec_code='65210',
        corporate_number='9090001011376',
    ),
    'E36435': EdinetCodeEntry(
        edinet_code='E36435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=348,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アイスコ',
        submitter_name_en='Iceco Inc.',
        submitter_name_yomi='カブシキガイシャアイスコ',
        address='横浜市泉区新橋町１２１２番地',
        industry='卸売業',
        sec_code='76980',
        corporate_number='5020001000471',
    ),
    'E36437': EdinetCodeEntry(
        edinet_code='E36437',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮﨑\u3000恵子',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36438': EdinetCodeEntry(
        edinet_code='E36438',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000裕昭',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36439': EdinetCodeEntry(
        edinet_code='E36439',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柳澤\u3000謙介',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギサワ\u3000ケンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36441': EdinetCodeEntry(
        edinet_code='E36441',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=155,
        fiscal_year_end=None,
        submitter_name='ＩＴＯＣＨＵ\u3000ＰＬＡＳＴＩＣＳ\u3000ＰＴＥ．，\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='イトウチュウプラスチックスプライベートリミテッド',
        address='６\u3000ＳＨＥＮＴＯＮ\u3000ＷＡＹ\u3000＃２１－０８Ａ\u3000ＯＵＥ\u3000ＤＯＷＮＴＯＷＮ\u3000ＳＩＮＧＡＰＯＲＥ\u3000０６８８０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36442': EdinetCodeEntry(
        edinet_code='E36442',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=92,
        fiscal_year_end=None,
        submitter_name='株式会社雅コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャミヤビコーポレーション',
        address='杉並区善福寺二丁目３６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011301018413',
    ),
    'E36443': EdinetCodeEntry(
        edinet_code='E36443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000淳也',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ジュンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36445': EdinetCodeEntry(
        edinet_code='E36445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='二田\u3000泰久',
        submitter_name_en=None,
        submitter_name_yomi='ニタ\u3000ヤスヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36446': EdinetCodeEntry(
        edinet_code='E36446',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000大地',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ダイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36447': EdinetCodeEntry(
        edinet_code='E36447',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000瑞木',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000ミズキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36448': EdinetCodeEntry(
        edinet_code='E36448',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000杏奈',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000アンナ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36449': EdinetCodeEntry(
        edinet_code='E36449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＫＴホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスケーティーホールディングスカブシキカイシャ',
        address='千代田区大手町１丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001213163',
    ),
    'E36454': EdinetCodeEntry(
        edinet_code='E36454',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古川\u3000保典',
        submitter_name_en=None,
        submitter_name_yomi='フルカワ\u3000ヤスノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36455': EdinetCodeEntry(
        edinet_code='E36455',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='相原\u3000貴久',
        submitter_name_en=None,
        submitter_name_yomi='アイハラ\u3000タカヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36457': EdinetCodeEntry(
        edinet_code='E36457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='相原\u3000敏貴',
        submitter_name_en=None,
        submitter_name_yomi='アイハラ\u3000トシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36460': EdinetCodeEntry(
        edinet_code='E36460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2538,
        fiscal_year_end='12月31日',
        submitter_name='株式会社電算システムホールディングス',
        submitter_name_en='Densan System Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャデンサンシステムホールディングス',
        address='岐阜市日置江１丁目５８番地',
        industry='情報・通信業',
        sec_code='40720',
        corporate_number='9200001038853',
    ),
    'E36464': EdinetCodeEntry(
        edinet_code='E36464',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=923,
        fiscal_year_end='3月31日',
        submitter_name='表示灯株式会社',
        submitter_name_en='HYOJITO Co.. Ltd',
        submitter_name_yomi='ヒョウジトウカブシキカイシャ',
        address='名古屋市中村区名駅４丁目２－１１',
        industry='サービス業',
        sec_code='73680',
        corporate_number='7180001040070',
    ),
    'E36465': EdinetCodeEntry(
        edinet_code='E36465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='早坂\u3000貴幸',
        submitter_name_en=None,
        submitter_name_yomi='ハヤサカ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36466': EdinetCodeEntry(
        edinet_code='E36466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4425,
        fiscal_year_end='3月末日',
        submitter_name='株式会社紀文食品',
        submitter_name_en='KIBUN FOODS INC.',
        submitter_name_yomi='カブシキガイシャキブンショクヒン',
        address='中央区銀座５－１５－１',
        industry='食料品',
        sec_code='29330',
        corporate_number='4010001041880',
    ),
    'E36467': EdinetCodeEntry(
        edinet_code='E36467',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＳＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーエスエイチ',
        address='港区港南二丁目１５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36469': EdinetCodeEntry(
        edinet_code='E36469',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＲＭブラザーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーアールエムブラザーズ',
        address='渋谷区道玄坂１－１６－６\u3000二葉ビル８ｂ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7020001110491',
    ),
    'E36470': EdinetCodeEntry(
        edinet_code='E36470',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＡＧＳ\u3000Ｉｎｖｅｓｔｍｅｎｔ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='エーエージーエス\u3000インベストメント\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36471': EdinetCodeEntry(
        edinet_code='E36471',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中野\u3000智哉',
        submitter_name_en=None,
        submitter_name_yomi='ナカノ\u3000トモヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36473': EdinetCodeEntry(
        edinet_code='E36473',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='株式会社エイ・ティー・ジー・シー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイティージーシー',
        address='さいたま市南区文蔵三丁目１１番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001001027',
    ),
    'E36474': EdinetCodeEntry(
        edinet_code='E36474',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='株式会社赤城',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアカギ',
        address='前橋市大手町二丁目９番１４－２０２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8070001037639',
    ),
    'E36475': EdinetCodeEntry(
        edinet_code='E36475',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青木\u3000淳一',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36477': EdinetCodeEntry(
        edinet_code='E36477',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000正洋',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36478': EdinetCodeEntry(
        edinet_code='E36478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=149,
        fiscal_year_end='6月30日',
        submitter_name='株式会社リファインバースグループ',
        submitter_name_en='REFINVERSE Group, Inc.',
        submitter_name_yomi='カブシキガイシャリファインバースグループ',
        address='中央区日本橋人形町３－１０－１',
        industry='サービス業',
        sec_code='73750',
        corporate_number='8010001219556',
    ),
    'E36479': EdinetCodeEntry(
        edinet_code='E36479',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='Ｈｉｋａｒｉ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000ＢＶＩ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ヒカリ\u3000インベストメント\u3000ビーブイアイ\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000ＩＩ，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ，\u3000ＶＧ１１１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36480': EdinetCodeEntry(
        edinet_code='E36480',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='クリプトメリア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クリプトメリアカブシキカイシャ',
        address='渋谷区富ヶ谷２－４０－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001045934',
    ),
    'E36482': EdinetCodeEntry(
        edinet_code='E36482',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＮＮアドバイザーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティーエヌエヌアドバイザーズ',
        address='東京都港区麻布十番２丁目５－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001205148',
    ),
    'E36483': EdinetCodeEntry(
        edinet_code='E36483',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＰＩＭＣＯファンズ：グローバル・インベスターズ・シリーズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ピムコファンズグローバルインベスターズシリーズピーエルシー',
        address='アイルランド、Ｄ０２\u3000ＨＤ３２、ダブリン２、サー・ジョン・ロジャーソンズ・キー７８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36484': EdinetCodeEntry(
        edinet_code='E36484',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=6254,
        fiscal_year_end='7月31日',
        submitter_name='ビジョナル株式会社',
        submitter_name_en='Visional',
        submitter_name_yomi='ビジョナルカブシキガイシャ',
        address='渋谷区渋谷二丁目１５－１',
        industry='情報・通信業',
        sec_code='41940',
        corporate_number='6011001132222',
    ),
    'E36485': EdinetCodeEntry(
        edinet_code='E36485',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南\u3000壮一郎',
        submitter_name_en=None,
        submitter_name_yomi='ミナミ\u3000ソウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36486': EdinetCodeEntry(
        edinet_code='E36486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社イグニス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイグニス',
        address='渋谷区恵比寿一丁目１９番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001216152',
    ),
    'E36489': EdinetCodeEntry(
        edinet_code='E36489',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='みよし建設株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミヨシケンセツカブシキカイシャ',
        address='新宿区四谷３丁目１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2030001058033',
    ),
    'E36493': EdinetCodeEntry(
        edinet_code='E36493',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉橋\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='ヨシハシ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36494': EdinetCodeEntry(
        edinet_code='E36494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北山\u3000忠雄',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000タダオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36495': EdinetCodeEntry(
        edinet_code='E36495',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000新吾',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36497': EdinetCodeEntry(
        edinet_code='E36497',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平岡\u3000卓',
        submitter_name_en=None,
        submitter_name_yomi='ヒラオカ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36498': EdinetCodeEntry(
        edinet_code='E36498',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4057,
        fiscal_year_end='12月31日',
        submitter_name='株式会社マーキュリアホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマーキュリアホールディングス',
        address='千代田区内幸町三丁目３番３号内幸町ダイビル',
        industry='証券、商品先物取引業',
        sec_code='73470',
        corporate_number='8010001219432',
    ),
    'E36499': EdinetCodeEntry(
        edinet_code='E36499',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北山\u3000裕美',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000ユウミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36500': EdinetCodeEntry(
        edinet_code='E36500',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北山\u3000優吾',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000ユウゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36501': EdinetCodeEntry(
        edinet_code='E36501',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000俊一郎',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000シュンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36502': EdinetCodeEntry(
        edinet_code='E36502',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='パーインベスト（ルクセンブルグ）ＳＩＣＡＶ',
        submitter_name_en=None,
        submitter_name_yomi='パーインベストルクセンブルグシキャブ',
        address='ルクセンブルグ大公国、ルクセンブルグＬ－２４５３、ユージン・リュペール通り１２番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36503': EdinetCodeEntry(
        edinet_code='E36503',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人木下記念事業団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンキノシタキネンジギョウダン',
        address='神戸市中央区元町通６丁目２番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140005015740',
    ),
    'E36504': EdinetCodeEntry(
        edinet_code='E36504',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36505': EdinetCodeEntry(
        edinet_code='E36505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='笹川\u3000治信',
        submitter_name_en=None,
        submitter_name_yomi='ササカワ\u3000ハルノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36508': EdinetCodeEntry(
        edinet_code='E36508',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000謙自',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36509': EdinetCodeEntry(
        edinet_code='E36509',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='高谷コンサルティング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タカタニコンサルティングカブシキガイシャ',
        address='吹田市垂水町一丁目２１番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120901042294',
    ),
    'E36510': EdinetCodeEntry(
        edinet_code='E36510',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='シージェイピー・ダブリューエー・ホールディングス・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='シージェイピーダブリューエーホールディングスエルピー',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００８、ジョージ・タウン、エルギン・アベニュー１９０、ウォーカース・コーポレート・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36511': EdinetCodeEntry(
        edinet_code='E36511',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='塚田\u3000隆',
        submitter_name_en=None,
        submitter_name_yomi='ツカダ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36512': EdinetCodeEntry(
        edinet_code='E36512',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社オータス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオータス',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001138751',
    ),
    'E36515': EdinetCodeEntry(
        edinet_code='E36515',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='１０１合同会社',
        submitter_name_en=None,
        submitter_name_yomi='イチマルイチゴウドウカイシャ',
        address='港区六本木六丁目１５番１号六本木ヒルズけやき坂テラス４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403024433',
    ),
    'E36522': EdinetCodeEntry(
        edinet_code='E36522',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='角井\u3000亮一',
        submitter_name_en=None,
        submitter_name_yomi='カクイ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36523': EdinetCodeEntry(
        edinet_code='E36523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新明\u3000智',
        submitter_name_en=None,
        submitter_name_yomi='シンミョウ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36524': EdinetCodeEntry(
        edinet_code='E36524',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南\u3000章行',
        submitter_name_en=None,
        submitter_name_yomi='ミナミ\u3000アキユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36525': EdinetCodeEntry(
        edinet_code='E36525',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社オートニクス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオートニクス',
        address='志木市下宗岡４－１４－２６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8030001045240',
    ),
    'E36528': EdinetCodeEntry(
        edinet_code='E36528',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北山\u3000雄三',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000ユウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36529': EdinetCodeEntry(
        edinet_code='E36529',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26,
        fiscal_year_end=None,
        submitter_name='ＭＩＲＩ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ミリ\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='アメリカ合衆国マサチューセッツ州０２１１６ボストン、ボイルトン・ストリート７４５、スイート３０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36532': EdinetCodeEntry(
        edinet_code='E36532',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=83,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ネオマーケティング',
        submitter_name_en='NEO MARKETING INC.',
        submitter_name_yomi='カブシキガイシャネオマーケティング',
        address='渋谷区南平台町１６番２５号',
        industry='情報・通信業',
        sec_code='41960',
        corporate_number='4011001046358',
    ),
    'E36533': EdinetCodeEntry(
        edinet_code='E36533',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=493,
        fiscal_year_end=None,
        submitter_name='ＺＥＵＳ\u3000ＣＯ．，ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ゼウス',
        address='１３２，Ａｎｎｙｅｏｎｇｎａｍ－ｒｏ，Ｈｗａｓｅｏｎｇ－ｓｉ，Ｇｙｅｏｎｇｇｉ－ｄｏ，Ｋｏｒｅａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36534': EdinetCodeEntry(
        edinet_code='E36534',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='ＦＨＬホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフエイチエルホールディングスカブシキカイシャ',
        address='文京区後楽二丁目２３番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101085245',
    ),
    'E36538': EdinetCodeEntry(
        edinet_code='E36538',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保芦\u3000將人',
        submitter_name_en=None,
        submitter_name_yomi='ホアシ\u3000マサヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36539': EdinetCodeEntry(
        edinet_code='E36539',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='6月30日',
        submitter_name='ＤＮホールディングス株式会社',
        submitter_name_en='DN HOLDINGS CO., LTD.',
        submitter_name_yomi='ディーエヌホールディングスカブシキガイシャ',
        address='千代田区神田練塀町３００番地',
        industry='サービス業',
        sec_code='73770',
        corporate_number='8010001219795',
    ),
    'E36540': EdinetCodeEntry(
        edinet_code='E36540',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='１０１投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='イチマルイチトウシジギョウユウゲンセキニンクミアイ',
        address='港区六本木六丁目１５番１号六本木ヒルズけやき坂テラス４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36541': EdinetCodeEntry(
        edinet_code='E36541',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アサヒ・リファイニング・ユーエスエー・インク',
        submitter_name_en=None,
        submitter_name_yomi='アサヒ\u3000リファイニング\u3000ユーエスエー\u3000インク',
        address='アメリカ合衆国、デラウェア州１９８０８、ニューキャッスル、ウィルミントン、センタービルロード２７１１、スイート４００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36542': EdinetCodeEntry(
        edinet_code='E36542',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='行川\u3000久代',
        submitter_name_en=None,
        submitter_name_yomi='ナメカワ\u3000ヒサヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36545': EdinetCodeEntry(
        edinet_code='E36545',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1848,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ジェイ・イー・ティ',
        submitter_name_en='J.E.T.Co.,LTD.',
        submitter_name_yomi='カブシキガイシャジェイイーティー',
        address='浅口郡里庄町大字新庄字金山６０７８番',
        industry='機械',
        sec_code='62280',
        corporate_number='1260001018766',
    ),
    'E36546': EdinetCodeEntry(
        edinet_code='E36546',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='橋本\u3000光伸',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000ミツノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36547': EdinetCodeEntry(
        edinet_code='E36547',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＲＡ\u3000Ｒｅａｌ\u3000Ｅｓｔａｔｅ\u3000Ｉｎｖｅｓｔｏｒｓ\u3000３０\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エーアールエー\u3000リアル\u3000エステート\u3000インベスターズ\u3000サーティー\u3000リミテッド',
        address='香港特別行政区カオルーン、ホンハム、メトロポリス・ドライブ６、フォーチュン・メトロポリス、レベル９、ショップＮｏ．９０１－９０６、９４８－９５０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36548': EdinetCodeEntry(
        edinet_code='E36548',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65552,
        fiscal_year_end=None,
        submitter_name='ＣＡＮＴＯＲ\u3000ＦＩＴＺＧＥＲＡＬＤ\u3000＆\u3000ＣＯ．',
        submitter_name_en=None,
        submitter_name_yomi='キャンター\u3000フィッツジェラルド\u3000アンド\u3000コー',
        address='１１０\u3000Ｅａｓｔ\u3000５９ｔｈ\u3000Ｓｔｒｅｅｔ，\u3000Ｎｅｗ\u3000Ｙｏｒｋ\u3000１００２２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36549': EdinetCodeEntry(
        edinet_code='E36549',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10780,
        fiscal_year_end=None,
        submitter_name='ＣＡＮＴＯＲ\u3000ＦＩＴＺＧＥＲＡＬＤ\u3000ＥＵＲＯＰＥ',
        submitter_name_en=None,
        submitter_name_yomi='キャンター\u3000フィッツジェラルド\u3000ヨーロッパ',
        address='５\u3000ＣＨＵＲＣＨＩＬＬ\u3000ＰＬＡＣＥ，\u3000ＣＡＮＡＲＹ\u3000ＷＨＡＲＦ，\u3000ＬＯＮＤＯＮ，\u3000ＵＮＩＴＥＤ\u3000ＫＩＮＧＤＯＭ\u3000Ｅ１４\u3000５ＨＵ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36555': EdinetCodeEntry(
        edinet_code='E36555',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＳＭ・Ｍ３合同会社',
        submitter_name_en=None,
        submitter_name_yomi='シーエスエム\u3000エムスリーゴウドウガイシャ',
        address='中野区鷺宮２－７－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010403016651',
    ),
    'E36556': EdinetCodeEntry(
        edinet_code='E36556',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加島禎二',
        submitter_name_en=None,
        submitter_name_yomi='カシマ\u3000テイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36557': EdinetCodeEntry(
        edinet_code='E36557',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若鍋\u3000孝司',
        submitter_name_en=None,
        submitter_name_yomi='ワカナベ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36558': EdinetCodeEntry(
        edinet_code='E36558',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000友希',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36559': EdinetCodeEntry(
        edinet_code='E36559',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＰＩＮＥＲＩＶＥＲ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャパインリバー',
        address='小金井市東町四丁目２８番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8012401021896',
    ),
    'E36560': EdinetCodeEntry(
        edinet_code='E36560',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社アイズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイズ',
        address='横浜市戸塚区品濃町５３７－２０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001117249',
    ),
    'E36562': EdinetCodeEntry(
        edinet_code='E36562',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='三神興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンシンコウギョウカブシキガイシャ',
        address='中央区八丁堀１丁目１３番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001058009',
    ),
    'E36563': EdinetCodeEntry(
        edinet_code='E36563',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有田\u3000佳史',
        submitter_name_en=None,
        submitter_name_yomi='アリタ\u3000ヨシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36566': EdinetCodeEntry(
        edinet_code='E36566',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='蘇\u3000乾聞',
        submitter_name_en=None,
        submitter_name_yomi='ソ\u3000ケンブン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36567': EdinetCodeEntry(
        edinet_code='E36567',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安田\u3000啓司',
        submitter_name_en=None,
        submitter_name_yomi='ヤスダ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36568': EdinetCodeEntry(
        edinet_code='E36568',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='信濃\u3000孝喜',
        submitter_name_en=None,
        submitter_name_yomi='シナノ\u3000コウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36571': EdinetCodeEntry(
        edinet_code='E36571',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='米澤\u3000量登',
        submitter_name_en=None,
        submitter_name_yomi='ヨネザワ\u3000カズト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36572': EdinetCodeEntry(
        edinet_code='E36572',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田口\u3000佳子',
        submitter_name_en=None,
        submitter_name_yomi='タグチ\u3000ヨシコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36573': EdinetCodeEntry(
        edinet_code='E36573',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000義典',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36575': EdinetCodeEntry(
        edinet_code='E36575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000育代',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000イクヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36576': EdinetCodeEntry(
        edinet_code='E36576',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｚ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼットカブシキガイシャ',
        address='千代田区九段南３－８－２ライオンズマンション九段第二４０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011501025334',
    ),
    'E36577': EdinetCodeEntry(
        edinet_code='E36577',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='早川\u3000周作',
        submitter_name_en=None,
        submitter_name_yomi='ハヤカワ\u3000シュウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36578': EdinetCodeEntry(
        edinet_code='E36578',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横治\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='ヨコジ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36580': EdinetCodeEntry(
        edinet_code='E36580',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳\u3000先',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギ\u3000セン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36581': EdinetCodeEntry(
        edinet_code='E36581',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='山形兄弟株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマガタキョウダイカブシキガイシャ',
        address='渋谷区西原３－４５－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001091890',
    ),
    'E36582': EdinetCodeEntry(
        edinet_code='E36582',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社ネクスタ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャネクスタ',
        address='小平市小川町２丁目１１５７番地の８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001212461',
    ),
    'E36583': EdinetCodeEntry(
        edinet_code='E36583',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1204,
        fiscal_year_end=None,
        submitter_name='日本生命第６回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイロクカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001216645',
    ),
    'E36587': EdinetCodeEntry(
        edinet_code='E36587',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社デベロップ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデベロップ',
        address='市川市市川一丁目４－１０市川ビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8040001032114',
    ),
    'E36588': EdinetCodeEntry(
        edinet_code='E36588',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高田\u3000揚子',
        submitter_name_en=None,
        submitter_name_yomi='タカタ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36590': EdinetCodeEntry(
        edinet_code='E36590',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=111408,
        fiscal_year_end=None,
        submitter_name='Ｐｅａｋ\u3000ＸＶ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ\u3000ＩＶ',
        submitter_name_en=None,
        submitter_name_yomi='ピークフィフティーンパートナーズインベストメンツフォー',
        address='Ｆｉｆｔｈ\u3000Ｆｌｏｏｒ，\u3000Ｅｂｅｎｅ\u3000Ｅｓｐｌａｎａｄｅ，\u3000２４\u3000Ｂａｎｋ\u3000Ｓｔｒｅｅｔ，\u3000Ｃｙｂｅｒｃｉｔｙ，\u3000Ｅｂｅｎｅ，\u3000Ｍａｕｒｉｔｉｕｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36591': EdinetCodeEntry(
        edinet_code='E36591',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='レインボー・ライト・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='レインボーライトリミテッド',
        address='英領バージン諸島ＶＧ１１１０トルトラ島ロード・タウン、ウィッカムズ・ケイⅡ、ヴィストラ・コーポレート・サービシズ・センター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36592': EdinetCodeEntry(
        edinet_code='E36592',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=420,
        fiscal_year_end=None,
        submitter_name='ウットラム・ホールディングス・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウットラムホールディングスリミテッド',
        address='香港、ニューテリトリーズ、セン湾区、Ｕｋロード\u3000ヤン\u3000８、ニナタワー、第２タワー、３２階、３２０３及び３２０４室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36593': EdinetCodeEntry(
        edinet_code='E36593',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=193,
        fiscal_year_end=None,
        submitter_name='ニプシー・ホールディングス・インターナショナル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ニプシーホールディングスインターナショナルリミテッド',
        address='香港、ニューテリトリーズ、セン湾区、Ｕｋロード\u3000ヤン\u3000８、ニナタワー、第２タワー、３２階、３２０３及び３２０４室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36595': EdinetCodeEntry(
        edinet_code='E36595',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='プラクシー・インク',
        submitter_name_en=None,
        submitter_name_yomi='プラクシーインク',
        address='ビストラ・コーポレート・サービシーズ・センター、ウィッカムズ\u3000ケイ\u3000２、ロード\u3000タウン、トルトラ、ＶＧ１１１０、イギリス領バージン諸島',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36596': EdinetCodeEntry(
        edinet_code='E36596',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='グローバル・プレミア・グループ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='グローバルプレミアグループリミテッド',
        address='ビストラ・コーポレート・サービシーズ・センター、ウィッカムズ\u3000ケイ\u3000２、ロード\u3000タウン、トルトラ、ＶＧ１１１０、イギリス領バージン諸島',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36597': EdinetCodeEntry(
        edinet_code='E36597',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社紀鳳産業',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキホウサンギョウ',
        address='港区虎ノ門三丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401070977',
    ),
    'E36603': EdinetCodeEntry(
        edinet_code='E36603',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エムスリードリームインベスター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムスリードリームインベスター',
        address='渋谷区神宮前６－２３－４\u3000桑野ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001110490',
    ),
    'E36605': EdinetCodeEntry(
        edinet_code='E36605',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社福留興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフクトメコウサン',
        address='広島市西区草津港２丁目６－７５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9240002014346',
    ),
    'E36606': EdinetCodeEntry(
        edinet_code='E36606',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＥＶ\u3000Ｏ\u3000ＦＵＮＤ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='イーブイオーファンドエルエルシー',
        address='アメリカ合衆国、デラウェア州１９８０１、ニューキャッスル郡、ウィルミントン、オレンジ・ストリート１２０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36607': EdinetCodeEntry(
        edinet_code='E36607',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉田\u3000大士',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000モトヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36611': EdinetCodeEntry(
        edinet_code='E36611',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＹＫＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイケイティカブシキカイシャ',
        address='豊中市中桜塚３丁目２番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120901039347',
    ),
    'E36618': EdinetCodeEntry(
        edinet_code='E36618',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河合\u3000清明',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36619': EdinetCodeEntry(
        edinet_code='E36619',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='尾松\u3000豪紀',
        submitter_name_en=None,
        submitter_name_yomi='オマツ\u3000ヒデトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36620': EdinetCodeEntry(
        edinet_code='E36620',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28424,
        fiscal_year_end=None,
        submitter_name='東海道リート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='トウカイドウリートトウシホウジン',
        address='千代田大手町二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010005032892',
    ),
    'E36621': EdinetCodeEntry(
        edinet_code='E36621',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=446,
        fiscal_year_end='6月末日',
        submitter_name='株式会社メイホーホールディングス',
        submitter_name_en='Meiho Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャメイホーホールディングス',
        address='岐阜市吹上町６丁目２１番',
        industry='サービス業',
        sec_code='73690',
        corporate_number='6200001033709',
    ),
    'E36625': EdinetCodeEntry(
        edinet_code='E36625',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＰＩＰ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='エーピーアイピー\u3000インク',
        address='ｃ／ｏ\u3000Ｗａｌｋｅｒｓ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｌｉｍｉｔｅｄ，\u3000１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36626': EdinetCodeEntry(
        edinet_code='E36626',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=66274,
        fiscal_year_end=None,
        submitter_name='ＫＬＡテンコール（シンガポール）ピーティーイー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='ケーエルエーテンコールシンガポールピーティーイーエルティーディー',
        address='５５４５３２\u3000シンガポール、ノース・アヴェニュー５、セラングーン４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36627': EdinetCodeEntry(
        edinet_code='E36627',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=785,
        fiscal_year_end='3月31日',
        submitter_name='ドリームベッド株式会社',
        submitter_name_en='DREAMBED CO.,LTD.',
        submitter_name_yomi='ドリームベッドカブシキガイシャ',
        address='広島市西区己斐本町三丁目１２番３９号',
        industry='その他製品',
        sec_code='77910',
        corporate_number='7240001007740',
    ),
    'E36629': EdinetCodeEntry(
        edinet_code='E36629',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=155,
        fiscal_year_end='9月30日',
        submitter_name='株式会社デコルテ・ホールディングス',
        submitter_name_en='Decollte Holdings Corporation',
        submitter_name_yomi='カブシキガイシャデコルテホールディングス',
        address='神戸市中央区加納町４丁目４番１７号\u3000ニッセイ三宮ビル１２階',
        industry='サービス業',
        sec_code='73720',
        corporate_number='2010001180292',
    ),
    'E36630': EdinetCodeEntry(
        edinet_code='E36630',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10544,
        fiscal_year_end=None,
        submitter_name='ＷＣＭインベストメント・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ダブルシーエムインベストメントマネジメントエルエルシー',
        address='米国、９２６５１－２９７４、カリフォルニア州、ラグナ・ビーチ、ブルックス・ストリート２８１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36633': EdinetCodeEntry(
        edinet_code='E36633',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ＳＰＣトラスト',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエスピーシートラスト',
        address='港区赤坂四丁目２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010402025296',
    ),
    'E36634': EdinetCodeEntry(
        edinet_code='E36634',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植島\u3000幹九郎',
        submitter_name_en=None,
        submitter_name_yomi='ウエシマ\u3000カンクロウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36635': EdinetCodeEntry(
        edinet_code='E36635',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=312,
        fiscal_year_end='9月30日',
        submitter_name='株式会社プラスアルファ・コンサルティング',
        submitter_name_en='Plus Alpha Consulting Co., Ltd.',
        submitter_name_yomi='カブシキカイシャプラスアルファコンサルティング',
        address='港区東新橋一丁目９番２号汐留住友ビル２５階',
        industry='サービス業',
        sec_code='40710',
        corporate_number='9010401068115',
    ),
    'E36636': EdinetCodeEntry(
        edinet_code='E36636',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=24,
        fiscal_year_end=None,
        submitter_name='株式会社みらい知的財産技術研究所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミライチテキザイサンギジュツケンキュウショ',
        address='新宿区四谷本塩町４番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101055823',
    ),
    'E36637': EdinetCodeEntry(
        edinet_code='E36637',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=306,
        fiscal_year_end='5月31日',
        submitter_name='株式会社テンダ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテンダ',
        address='豊島区西池袋一丁目１１番１号',
        industry='情報・通信業',
        sec_code='41980',
        corporate_number='3013301014169',
    ),
    'E36638': EdinetCodeEntry(
        edinet_code='E36638',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=902,
        fiscal_year_end='5月31日',
        submitter_name='株式会社Ｅｎｊｉｎ',
        submitter_name_en='Enjin Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエンジン',
        address='中央区銀座５－１３－１６',
        industry='サービス業',
        sec_code='73700',
        corporate_number='4120001145497',
    ),
    'E36639': EdinetCodeEntry(
        edinet_code='E36639',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石脇\u3000秀夫',
        submitter_name_en=None,
        submitter_name_yomi='イシワキ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36641': EdinetCodeEntry(
        edinet_code='E36641',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙崎\u3000敏宏',
        submitter_name_en=None,
        submitter_name_yomi='タカサキ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36642': EdinetCodeEntry(
        edinet_code='E36642',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000克重',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000カツシゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36645': EdinetCodeEntry(
        edinet_code='E36645',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000一樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000カズキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36648': EdinetCodeEntry(
        edinet_code='E36648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1075,
        fiscal_year_end='8月31日',
        submitter_name='株式会社アイドマ・ホールディングス',
        submitter_name_en='Aidma Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャアイドマホールディングス',
        address='品川区上大崎二丁目１３番３０号',
        industry='サービス業',
        sec_code='73730',
        corporate_number='6013301031269',
    ),
    'E36650': EdinetCodeEntry(
        edinet_code='E36650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松岡\u3000真功',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36652': EdinetCodeEntry(
        edinet_code='E36652',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＳホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーエスホールディングス',
        address='千葉市中央区東千葉二丁目８番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001117018',
    ),
    'E36653': EdinetCodeEntry(
        edinet_code='E36653',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=961,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＢｌｕｅＭｅｍｅ',
        submitter_name_en='BlueMeme Inc.',
        submitter_name_yomi='カブシキガイシャブルーミーム',
        address='千代田区神田錦町三丁目２０番地',
        industry='情報・通信業',
        sec_code='40690',
        corporate_number='3010001132912',
    ),
    'E36654': EdinetCodeEntry(
        edinet_code='E36654',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='稲村\u3000政彦',
        submitter_name_en=None,
        submitter_name_yomi='イナムラ\u3000マサヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36655': EdinetCodeEntry(
        edinet_code='E36655',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=468,
        fiscal_year_end='9月末日',
        submitter_name='ＢＣＣ株式会社',
        submitter_name_en='BCC Co.,Ltd.',
        submitter_name_yomi='ビーシーシーカブシキガイシャ',
        address='大阪市中央区今橋二丁目５番８号',
        industry='サービス業',
        sec_code='73760',
        corporate_number='4120001181633',
    ),
    'E36657': EdinetCodeEntry(
        edinet_code='E36657',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1114,
        fiscal_year_end='3月31日',
        submitter_name='セレンディップ・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セレンディップホールディングスカブシキガイシャ',
        address='名古屋市中区錦一丁目５番１１号',
        industry='サービス業',
        sec_code='73180',
        corporate_number='8180001058335',
    ),
    'E36658': EdinetCodeEntry(
        edinet_code='E36658',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=80,
        fiscal_year_end='7月末日',
        submitter_name='グローバルスタイル株式会社',
        submitter_name_en='Global Style Co.,Ltd.',
        submitter_name_yomi='グローバルスタイルカブシキガイシャ',
        address='大阪市中央区淡路町三丁目５番１号',
        industry='小売業',
        sec_code='71260',
        corporate_number='8120001084238',
    ),
    'E36659': EdinetCodeEntry(
        edinet_code='E36659',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=333,
        fiscal_year_end='6月30日',
        submitter_name='ベイシス株式会社',
        submitter_name_en='Basis Corporation',
        submitter_name_yomi='ベイシスカブシキカイシャ',
        address='港区芝公園ニ丁目４番１号',
        industry='情報・通信業',
        sec_code='40680',
        corporate_number='7010701017054',
    ),
    'E36660': EdinetCodeEntry(
        edinet_code='E36660',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日比谷コンピュータシステム',
        submitter_name_en='HIBIYA COMPUTER SYSTEM CO.,LTD.',
        submitter_name_yomi='カブシキガイシャヒビヤコンピュータシステム',
        address='江東区東陽二丁目４番３８号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5010601050033',
    ),
    'E36661': EdinetCodeEntry(
        edinet_code='E36661',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=574,
        fiscal_year_end='8月31日',
        submitter_name='ワンダープラネット株式会社',
        submitter_name_en='WonderPlanet Inc.',
        submitter_name_yomi='ワンダープラネットカブシキガイシャ',
        address='名古屋市中区錦三丁目２３番１８号',
        industry='情報・通信業',
        sec_code='41990',
        corporate_number='3180001106874',
    ),
    'E36665': EdinetCodeEntry(
        edinet_code='E36665',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｃａｉａ\u3000Ｐｒｏｊｅｃｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカイヤプロジェクト',
        address='京都市上京区下立売通千本東入田中町４４４番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101055780',
    ),
    'E36666': EdinetCodeEntry(
        edinet_code='E36666',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=433,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ジィ・シィ企画',
        submitter_name_en='Global Communication Planning Co., Ltd.',
        submitter_name_yomi='カブシキガイシャジイシイキカク',
        address='佐倉市王子台一丁目２８番８号',
        industry='情報・通信業',
        sec_code='40730',
        corporate_number='5040001046876',
    ),
    'E36667': EdinetCodeEntry(
        edinet_code='E36667',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='8月31日',
        submitter_name='株式会社エータイ',
        submitter_name_en='A-tie Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエータイ',
        address='千代田区神田錦町三丁目２１番地',
        industry='サービス業',
        sec_code='369A0',
        corporate_number='3011101038066',
    ),
    'E36668': EdinetCodeEntry(
        edinet_code='E36668',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='株式会社ジャパンシルバーフリース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジャパンシルバーフリース',
        address='大阪市西区南堀江１丁目２１番４号ＪＳビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001043821',
    ),
    'E36669': EdinetCodeEntry(
        edinet_code='E36669',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ニューエネルギーマネジメント合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ニューエネルギーマネジメントゴウドウガイシャ',
        address='千代田区神田神保町１ー１８ー１千石屋ビル２０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011803004014',
    ),
    'E36670': EdinetCodeEntry(
        edinet_code='E36670',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=488,
        fiscal_year_end='9月30日',
        submitter_name='株式会社コラントッテ',
        submitter_name_en='Colan Totte.Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコラントッテ',
        address='大阪市中央区南船場二丁目１０番２６号',
        industry='その他製品',
        sec_code='77920',
        corporate_number='8120001073372',
    ),
    'E36671': EdinetCodeEntry(
        edinet_code='E36671',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='冨塚\u3000優',
        submitter_name_en=None,
        submitter_name_yomi='トミヅカ\u3000スグル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36673': EdinetCodeEntry(
        edinet_code='E36673',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｐａｎｔｈｅｕｍ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='パンテウムパートナーズリミテッド',
        address='香港セントラル、安蘭街１８号１９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36675': EdinetCodeEntry(
        edinet_code='E36675',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5000,
        fiscal_year_end=None,
        submitter_name='ＫＡＮＡＭＥＬ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カナメル\u3000カブシキガイシャ',
        address='品川区東品川二丁目２番２４号\u3000天王洲セントラルタワー\u3000１３Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001217607',
    ),
    'E36676': EdinetCodeEntry(
        edinet_code='E36676',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹内\u3000猛',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36682': EdinetCodeEntry(
        edinet_code='E36682',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000謙',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36683': EdinetCodeEntry(
        edinet_code='E36683',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='海信日本オートモーティブエアコンシステムズ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ハイセンスニホンオートモーティブエアコンシステムズゴウドウカイシャ',
        address='川崎市幸区堀川町６６－２興和川崎西口ビル１９Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020003019398',
    ),
    'E36684': EdinetCodeEntry(
        edinet_code='E36684',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー',
        submitter_name_en=None,
        submitter_name_yomi='フェデレーテッドハーミーズインベストメントファンズピーエルシー',
        address='アイルランド、ダブリン２、アッパーマウント・ストリート\u3000７／８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36687': EdinetCodeEntry(
        edinet_code='E36687',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11717,
        fiscal_year_end=None,
        submitter_name='インベスコ・インベストメンツ（バミューダ）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='インベスコインベストメンツバミューダリミテッド',
        address='英領バミューダハミルトン市ビクトリアストリート３１番ビクトリアプレイス５階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36690': EdinetCodeEntry(
        edinet_code='E36690',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三浦\u3000陽平',
        submitter_name_en=None,
        submitter_name_yomi='ミウラ\u3000ヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36692': EdinetCodeEntry(
        edinet_code='E36692',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000裕基',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36697': EdinetCodeEntry(
        edinet_code='E36697',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=570,
        fiscal_year_end='9月末日',
        submitter_name='株式会社Ｗａｑｏｏ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワクー',
        address='世田谷区上馬２－１４－１',
        industry='化学',
        sec_code='49370',
        corporate_number='9010901023800',
    ),
    'E36698': EdinetCodeEntry(
        edinet_code='E36698',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2358,
        fiscal_year_end='3月末日',
        submitter_name='日本電解株式会社',
        submitter_name_en='Nippon Denkai, LTD.',
        submitter_name_yomi='ニッポンデンカイカブシキガイシャ',
        address='筑西市下江連１２２６',
        industry='金属製品',
        sec_code=None,
        corporate_number='3010001176546',
    ),
    'E36699': EdinetCodeEntry(
        edinet_code='E36699',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ブラックロック・フィクスド・インカム・ダブリン・ファンズ\u3000ｐｌｃ',
        submitter_name_en=None,
        submitter_name_yomi='ブラックロックフィクスドインカムダブリンファンズピーエルシー',
        address='アイルランド、Ｄ０２\u3000ＲＫ５７、ダブリン２、サー・ジョン・ロジャーソンズ・キー７９番、キャピタル・ドック２００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36700': EdinetCodeEntry(
        edinet_code='E36700',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＣＣＩグループ',
        submitter_name_en='CCI Group, Inc.',
        submitter_name_yomi='カブシキカイシャシーシーアイグループ',
        address='金沢市広岡二丁目１２番６号',
        industry='銀行業',
        sec_code='73810',
        corporate_number='5220001024450',
    ),
    'E36701': EdinetCodeEntry(
        edinet_code='E36701',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＦアセット株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエフアセットカブシキガイシャ',
        address='文京区湯島二丁目２３番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001187795',
    ),
    'E36703': EdinetCodeEntry(
        edinet_code='E36703',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=36000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社十六フィナンシャルグループ',
        submitter_name_en='Juroku Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャジュウロクフィナンシャルグループ',
        address='岐阜市神田町八丁目２６番地',
        industry='銀行業',
        sec_code='73800',
        corporate_number='7200001039259',
    ),
    'E36705': EdinetCodeEntry(
        edinet_code='E36705',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='野村キャピタル・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラキャピタルパートナーズカブシキカイシャ',
        address='千代田区大手町二丁目２番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001188961',
    ),
    'E36706': EdinetCodeEntry(
        edinet_code='E36706',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=70175,
        fiscal_year_end='12月31日',
        submitter_name='ＮＩＰＰＯＮ\u3000ＥＸＰＲＥＳＳホールディングス株式会社',
        submitter_name_en='NIPPON EXPRESS HOLDINGS, INC.',
        submitter_name_yomi='ニッポンエクスプレスホールディングスカブシキカイシャ',
        address='千代田区神田和泉町２番地',
        industry='陸運業',
        sec_code='91470',
        corporate_number='5010001223668',
    ),
    'E36707': EdinetCodeEntry(
        edinet_code='E36707',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5000,
        fiscal_year_end='12月31日',
        submitter_name='フルサト・マルカホールディングス株式会社',
        submitter_name_en='MARUKA FURUSATO Corporation',
        submitter_name_yomi='フルサトマルカホールディングスカブシキカイシャ',
        address='大阪市中央区南新町一丁目２番１０号',
        industry='卸売業',
        sec_code='71280',
        corporate_number='9120001240871',
    ),
    'E36708': EdinetCodeEntry(
        edinet_code='E36708',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=341,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ラキール',
        submitter_name_en='LaKeel, Inc.',
        submitter_name_yomi='カブシキガイシャラキール',
        address='港区愛宕二丁目５番１号',
        industry='情報・通信業',
        sec_code='40740',
        corporate_number='4010401134301',
    ),
    'E36709': EdinetCodeEntry(
        edinet_code='E36709',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下村\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='シモムラ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36710': EdinetCodeEntry(
        edinet_code='E36710',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菊谷\u3000茂吉',
        submitter_name_en=None,
        submitter_name_yomi='キクタニ\u3000モキチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36711': EdinetCodeEntry(
        edinet_code='E36711',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=157,
        fiscal_year_end='7月31日',
        submitter_name='株式会社デリバリーコンサルティング',
        submitter_name_en='Delivery Consulting Inc.',
        submitter_name_yomi='カブシキガイシャデリバリーコンサルティング',
        address='港区赤坂９丁目７番１号\u3000ミッドタウン・タワー',
        industry='情報・通信業',
        sec_code='92400',
        corporate_number='4010401054152',
    ),
    'E36713': EdinetCodeEntry(
        edinet_code='E36713',
        submitter_type='外国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2026,
        fiscal_year_end='3月31日',
        submitter_name='オムニ・プラス・システム・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='オムニプラスシステムリミテッド',
        address='９９４\u3000Ｂｅｎｄｅｍｅｅｒ\u3000Ｒｏａｄ\u3000Ｂ－Ｃｅｎｔｒａｌ\u3000＃０１－０３\u3000Ｓｉｎｇａｐｏｒｅ\u3000３３９９４３',
        industry='外国法人・組合',
        sec_code='76990',
        corporate_number=None,
    ),
    'E36714': EdinetCodeEntry(
        edinet_code='E36714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='ミアヘルサホールディングス株式会社',
        submitter_name_en='Miahelsa Holdings Corporation',
        submitter_name_yomi='ミアヘルサホールディングスカブシキガイシャ',
        address='新宿区市谷仲之町３番１９号',
        industry='小売業',
        sec_code='71290',
        corporate_number='3011101096519',
    ),
    'E36716': EdinetCodeEntry(
        edinet_code='E36716',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ヤマダデンキ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマダデンキ',
        address='高崎市栄町１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2070001036729',
    ),
    'E36718': EdinetCodeEntry(
        edinet_code='E36718',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＥＰＳホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イーピーエスホールディングスカブシキガイシャ',
        address='新宿区津久戸町１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101095073',
    ),
    'E36720': EdinetCodeEntry(
        edinet_code='E36720',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阿部\u3000英司',
        submitter_name_en=None,
        submitter_name_yomi='アベ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36721': EdinetCodeEntry(
        edinet_code='E36721',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三室\u3000克哉',
        submitter_name_en=None,
        submitter_name_yomi='ミムロ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36722': EdinetCodeEntry(
        edinet_code='E36722',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=580,
        fiscal_year_end='7月末日',
        submitter_name='ブレインズテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブレインズテクノロジーカブシキガイシャ',
        address='港区高輪三丁目２３番１７号',
        industry='情報・通信業',
        sec_code='40750',
        corporate_number='3010601036265',
    ),
    'E36723': EdinetCodeEntry(
        edinet_code='E36723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='インフロニア・ホールディングス株式会社',
        submitter_name_en='INFRONEER Holdings Inc.',
        submitter_name_yomi='インフロニアホールディングスカブシキカイシャ',
        address='千代田区',
        industry='サービス業',
        sec_code='50760',
        corporate_number='3010001221541',
    ),
    'E36728': EdinetCodeEntry(
        edinet_code='E36728',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=682,
        fiscal_year_end=None,
        submitter_name='公益財団法人三谷研究開発支援財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンミタニケンキュウカイハツシエンザイダン',
        address='金沢市昭和町１６番１号\u3000ヴィサージュ１７階\u3000有限会社北都代行社内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4220005007394',
    ),
    'E36730': EdinetCodeEntry(
        edinet_code='E36730',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社おきなわフィナンシャルグループ',
        submitter_name_en='Okinawa Financial Group,Inc.',
        submitter_name_yomi='カブシキガイシャオキナワフィナンシャルグループ',
        address='那覇市久茂地三丁目１０番１号',
        industry='銀行業',
        sec_code='73500',
        corporate_number='2360001029471',
    ),
    'E36731': EdinetCodeEntry(
        edinet_code='E36731',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=870,
        fiscal_year_end='7月末日',
        submitter_name='株式会社サーキュレーション',
        submitter_name_en='CIRCULATION Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサーキュレーション',
        address='渋谷区神宮前三丁目２１番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4011001098218',
    ),
    'E36733': EdinetCodeEntry(
        edinet_code='E36733',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=13,
        fiscal_year_end='9月30日',
        submitter_name='株式会社くふうカンパニーホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクフウカンパニーホールディングス',
        address='東京都港区三田１－４－２８',
        industry='情報・通信業',
        sec_code='43760',
        corporate_number='5010401163051',
    ),
    'E36734': EdinetCodeEntry(
        edinet_code='E36734',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17,
        fiscal_year_end=None,
        submitter_name='ノルデア・インベストメント・マネジメント・アーベー',
        submitter_name_en=None,
        submitter_name_yomi='ノルデアインベストメントマネジメントアーベー',
        address='スウェーデン、ストックホルム１０５\u3000７１、Ｍ５４０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36737': EdinetCodeEntry(
        edinet_code='E36737',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黄\u3000聖博',
        submitter_name_en=None,
        submitter_name_yomi='コウ\u3000セイハク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36739': EdinetCodeEntry(
        edinet_code='E36739',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮本\u3000公',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36742': EdinetCodeEntry(
        edinet_code='E36742',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000善久',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヨシヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36743': EdinetCodeEntry(
        edinet_code='E36743',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川篤',
        submitter_name_en=None,
        submitter_name_yomi='イシカワアツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36747': EdinetCodeEntry(
        edinet_code='E36747',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='常川友樹',
        submitter_name_en=None,
        submitter_name_yomi='ツネカワトモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36750': EdinetCodeEntry(
        edinet_code='E36750',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='6月30日',
        submitter_name='ＡＩメカテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイメカテックカブシキガイシャ',
        address='龍ヶ崎市向陽台五丁目２番地',
        industry='電気機器',
        sec_code='62270',
        corporate_number='6050001041264',
    ),
    'E36751': EdinetCodeEntry(
        edinet_code='E36751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='ＴＲＥホールディングス株式会社',
        submitter_name_en='TRE HOLDINGS CORPORATION',
        submitter_name_yomi='ティーアールイーホールディングスカブシキカイシャ',
        address='千代田区大手町一丁目７番２号東京サンケイビル１５階',
        industry='サービス業',
        sec_code='92470',
        corporate_number='2010001221609',
    ),
    'E36752': EdinetCodeEntry(
        edinet_code='E36752',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000佐和子',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000サワコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36753': EdinetCodeEntry(
        edinet_code='E36753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中澤\u3000宣貴',
        submitter_name_en=None,
        submitter_name_yomi='ナカザワ\u3000ノブタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36754': EdinetCodeEntry(
        edinet_code='E36754',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴村\u3000賢治',
        submitter_name_en=None,
        submitter_name_yomi='スズムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36755': EdinetCodeEntry(
        edinet_code='E36755',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉村\u3000公孝',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000キミタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36756': EdinetCodeEntry(
        edinet_code='E36756',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9175,
        fiscal_year_end='3月31日',
        submitter_name='ヤマエグループホールディングス株式会社',
        submitter_name_en='YAMAE GROUP HOLDINGS CO.,LTD.',
        submitter_name_yomi='ヤマエグループホールディングスカブシキカイシャ',
        address='福岡市博多区博多駅東２丁目１３番３４号',
        industry='卸売業',
        sec_code='71300',
        corporate_number='9290001094921',
    ),
    'E36757': EdinetCodeEntry(
        edinet_code='E36757',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=35,
        fiscal_year_end='3月31日',
        submitter_name='株式会社一家ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイッカホールディングス',
        address='市川市東大和田二丁目４番１０号',
        industry='小売業',
        sec_code='71270',
        corporate_number='4040001120442',
    ),
    'E36758': EdinetCodeEntry(
        edinet_code='E36758',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舩橋\u3000茂行',
        submitter_name_en=None,
        submitter_name_yomi='フナバシ\u3000シゲユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36761': EdinetCodeEntry(
        edinet_code='E36761',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本田\u3000幸大',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000コウダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36762': EdinetCodeEntry(
        edinet_code='E36762',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｓ＆Ｓホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスアンドエスホールディングス',
        address='港区六本木４丁目２番２０ー３０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401145556',
    ),
    'E36764': EdinetCodeEntry(
        edinet_code='E36764',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10423,
        fiscal_year_end=None,
        submitter_name='学校法人国際総合学園',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジンコクサイソウゴウガクエン',
        address='新潟市中央区古町通二番町５４１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6110005000788',
    ),
    'E36767': EdinetCodeEntry(
        edinet_code='E36767',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='ＣＣＰ６株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーシーピーシックスカブシキガイシャ',
        address='千代田区一番町２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001134763',
    ),
    'E36768': EdinetCodeEntry(
        edinet_code='E36768',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アイダ設計',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイダセッケイ',
        address='上尾市今泉三丁目１０番地１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9030001000566',
    ),
    'E36769': EdinetCodeEntry(
        edinet_code='E36769',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='株式会社マナック・ケミカル・パートナーズ',
        submitter_name_en='MANAC Chemical Partners Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャマナックケミカルパートナーズ',
        address='中央区日本橋３丁目８番４号日本橋さくら通りビル６階',
        industry='化学',
        sec_code='43600',
        corporate_number='9010001221577',
    ),
    'E36770': EdinetCodeEntry(
        edinet_code='E36770',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='景祥針織有限公司',
        submitter_name_en=None,
        submitter_name_yomi='キングチョーニットウェアカンパニーリミテッド',
        address='中華人民共和国香港特別行政区新界將軍澳寶琳新都城一期地下Ｇ６Ａ舖',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36772': EdinetCodeEntry(
        edinet_code='E36772',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4000,
        fiscal_year_end=None,
        submitter_name='エプソン販売株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エプソンハンバイカブシキガイシャ',
        address='新宿区新宿四丁目１番６号ＪＲ新宿ミライナタワー２９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101003378',
    ),
    'E36773': EdinetCodeEntry(
        edinet_code='E36773',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000一彦',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36775': EdinetCodeEntry(
        edinet_code='E36775',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1288,
        fiscal_year_end=None,
        submitter_name='明治安田生命第１回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001218559',
    ),
    'E36776': EdinetCodeEntry(
        edinet_code='E36776',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＥＸＴ－О',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャネクストオー',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001217933',
    ),
    'E36778': EdinetCodeEntry(
        edinet_code='E36778',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＡＲ\u3000ＩＯＪ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエーアール\u3000アイオージェーゴウドウガイシャ',
        address='中央区銀座一丁目６番１１号\u3000アースタックス税理士法人内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010403025406',
    ),
    'E36779': EdinetCodeEntry(
        edinet_code='E36779',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＩＲＥ\u3000ＩＯＪ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アイアールイー\u3000アイオージェーゴウドウガイシャ',
        address='港区六本木六丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403025407',
    ),
    'E36780': EdinetCodeEntry(
        edinet_code='E36780',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='會田\u3000貞光',
        submitter_name_en=None,
        submitter_name_yomi='アイダ\u3000サダミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36782': EdinetCodeEntry(
        edinet_code='E36782',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社光大史',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャコウタイシ',
        address='さいたま市大宮区宮町三丁目４８番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6030001011070',
    ),
    'E36783': EdinetCodeEntry(
        edinet_code='E36783',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三宅\u3000尚子',
        submitter_name_en=None,
        submitter_name_yomi='ミヤケ\u3000ナオコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36785': EdinetCodeEntry(
        edinet_code='E36785',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＯＮＥ\u3000ＧＲＯＵＰ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワングループカブシキガイシャ',
        address='東大阪市川俣一丁目１番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9122001008530',
    ),
    'E36786': EdinetCodeEntry(
        edinet_code='E36786',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中山\u3000博登',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000ヒロト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36787': EdinetCodeEntry(
        edinet_code='E36787',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社スモールＢ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスモールビー',
        address='稲沢市小池三丁目１８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001145778',
    ),
    'E36788': EdinetCodeEntry(
        edinet_code='E36788',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000靖子',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36789': EdinetCodeEntry(
        edinet_code='E36789',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000文彦',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000フミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36792': EdinetCodeEntry(
        edinet_code='E36792',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クロスロード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクロスロード',
        address='羽曳野市恵我之荘五丁目２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120101063518',
    ),
    'E36793': EdinetCodeEntry(
        edinet_code='E36793',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='湯浅\u3000哲哉',
        submitter_name_en=None,
        submitter_name_yomi='ユアサ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36794': EdinetCodeEntry(
        edinet_code='E36794',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='株式会社クックイノベンチャー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクックイノベンチャー',
        address='名古屋市北区黒川本通二丁目４６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3140001089693',
    ),
    'E36795': EdinetCodeEntry(
        edinet_code='E36795',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=449,
        fiscal_year_end='8月末日',
        submitter_name='モビルス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モビルスカブシキガイシャ',
        address='品川区東五反田２丁目２２番９号住友不動産大崎ツインビル西館９階',
        industry='情報・通信業',
        sec_code='43700',
        corporate_number='6010401095847',
    ),
    'E36796': EdinetCodeEntry(
        edinet_code='E36796',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社コミューン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコミューン',
        address='佐倉市田町４３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001096682',
    ),
    'E36797': EdinetCodeEntry(
        edinet_code='E36797',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金子\u3000哲司',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36799': EdinetCodeEntry(
        edinet_code='E36799',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='矢ヶ部\u3000啓一',
        submitter_name_en=None,
        submitter_name_yomi='ヤカベ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36800': EdinetCodeEntry(
        edinet_code='E36800',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='犬養\u3000岬太',
        submitter_name_en=None,
        submitter_name_yomi='イヌカイ\u3000コウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36801': EdinetCodeEntry(
        edinet_code='E36801',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=266,
        fiscal_year_end='8月31日',
        submitter_name='株式会社フューチャーリンクネットワーク',
        submitter_name_en='Future Link Network Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフューチャーリンクネットワーク',
        address='船橋市西船四丁目１９番３号',
        industry='サービス業',
        sec_code='92410',
        corporate_number='7040001019632',
    ),
    'E36802': EdinetCodeEntry(
        edinet_code='E36802',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社アーク・クエスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアーククエスト',
        address='大阪市中央区南船場２－１０－２６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001137029',
    ),
    'E36804': EdinetCodeEntry(
        edinet_code='E36804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='スターリング証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スターリングショウケンカブシキガイシャ',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001088396',
    ),
    'E36805': EdinetCodeEntry(
        edinet_code='E36805',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000和博',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36808': EdinetCodeEntry(
        edinet_code='E36808',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=830,
        fiscal_year_end=None,
        submitter_name='アジアインベストメントファンド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アジアインベストメントファンドカブシキカイシャ',
        address='中央区勝どき一丁目１３番１号イヌイビル・カチドキ４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401134750',
    ),
    'E36809': EdinetCodeEntry(
        edinet_code='E36809',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='クレアシオン・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クレアシオンキャピタルカブシキカイシャ',
        address='港区赤坂九丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001123557',
    ),
    'E36811': EdinetCodeEntry(
        edinet_code='E36811',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='諸戸グループマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モロトグループマネジメントカブシキガイシャ',
        address='桑名市太一丸１８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4190001027276',
    ),
    'E36812': EdinetCodeEntry(
        edinet_code='E36812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙村\u3000徳康',
        submitter_name_en=None,
        submitter_name_yomi='タカムラ\u3000ノリヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36813': EdinetCodeEntry(
        edinet_code='E36813',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='一徳合同会社',
        submitter_name_en=None,
        submitter_name_yomi='イットクゴウドウガイシャ',
        address='名古屋市中区大須一丁目７番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180003017135',
    ),
    'E36814': EdinetCodeEntry(
        edinet_code='E36814',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49,
        fiscal_year_end=None,
        submitter_name='ＭＳＤ企業投資株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエスディキギョウトウシカブシキカイシャ',
        address='千代田区大手町一丁目９番２号\u3000大手町フィナンシャルシティグランキューブ１９Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001170243',
    ),
    'E36815': EdinetCodeEntry(
        edinet_code='E36815',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='竹内\u3000在',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000アリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36816': EdinetCodeEntry(
        edinet_code='E36816',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ネクストシークエンス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ネクストシークエンスゴウドウガイシャ',
        address='横浜市中区扇町ニ丁目５番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180003017134',
    ),
    'E36819': EdinetCodeEntry(
        edinet_code='E36819',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社キシモト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャ\u3000キシモト',
        address='大阪市天王寺区北河堀町７番２２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001023005',
    ),
    'E36820': EdinetCodeEntry(
        edinet_code='E36820',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='アング・ワイ・フーン',
        submitter_name_en=None,
        submitter_name_yomi='アングワイフーン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36821': EdinetCodeEntry(
        edinet_code='E36821',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ネオ・プアイ・ケオン',
        submitter_name_en=None,
        submitter_name_yomi='ネオプアイケオン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36824': EdinetCodeEntry(
        edinet_code='E36824',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山口\u3000貴弘',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36825': EdinetCodeEntry(
        edinet_code='E36825',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1492,
        fiscal_year_end='3月31日',
        submitter_name='株式会社レナサイエンス',
        submitter_name_en='Renascience Inc.',
        submitter_name_yomi='カブシキガイシャレナサイエンス',
        address='仙台市青葉区星陵町２－１',
        industry='医薬品',
        sec_code='48890',
        corporate_number='1012301007259',
    ),
    'E36827': EdinetCodeEntry(
        edinet_code='E36827',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=130,
        fiscal_year_end=None,
        submitter_name='日本生命２０２１基金流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイニセンニジュウイチキキンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001219000',
    ),
    'E36829': EdinetCodeEntry(
        edinet_code='E36829',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山瀬\u3000倫生',
        submitter_name_en=None,
        submitter_name_yomi='ヤマセ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36830': EdinetCodeEntry(
        edinet_code='E36830',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹下\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='タケシタ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36832': EdinetCodeEntry(
        edinet_code='E36832',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9920,
        fiscal_year_end=None,
        submitter_name='学校法人ティビィシィ学院',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジンティビィシィガクイン',
        address='宇都宮市大通り一丁目２番５～６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8060005000825',
    ),
    'E36836': EdinetCodeEntry(
        edinet_code='E36836',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='國部\u3000克彦',
        submitter_name_en=None,
        submitter_name_yomi='コクブ\u3000カツヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36837': EdinetCodeEntry(
        edinet_code='E36837',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉野\u3000悟',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36838': EdinetCodeEntry(
        edinet_code='E36838',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川田\u3000悟',
        submitter_name_en=None,
        submitter_name_yomi='カワタ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36840': EdinetCodeEntry(
        edinet_code='E36840',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=409,
        fiscal_year_end='5月末日',
        submitter_name='株式会社シイエヌエス',
        submitter_name_en='CNS Co.,Ltd',
        submitter_name_yomi='カブシキカイシャシイエヌエス',
        address='渋谷区恵比寿南１丁目５番５号ＪＲ恵比寿ビル９階',
        industry='情報・通信業',
        sec_code='40760',
        corporate_number='9011001034011',
    ),
    'E36842': EdinetCodeEntry(
        edinet_code='E36842',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社シングル・マインド',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシングルマインド',
        address='新宿区西早稲田一丁目８番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013303004504',
    ),
    'E36843': EdinetCodeEntry(
        edinet_code='E36843',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久保\u3000努',
        submitter_name_en=None,
        submitter_name_yomi='クボ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36844': EdinetCodeEntry(
        edinet_code='E36844',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=195,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＳＴＧ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000エスティージー',
        address='八尾市山賀町六丁目８２番地２',
        industry='非鉄金属',
        sec_code='58580',
        corporate_number='2122001021985',
    ),
    'E36845': EdinetCodeEntry(
        edinet_code='E36845',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='アジア電子工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アジアデンシコウギョウカブシキガイシャ',
        address='飯田市中村８０－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2100001022205',
    ),
    'E36846': EdinetCodeEntry(
        edinet_code='E36846',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大戸\u3000綾加',
        submitter_name_en=None,
        submitter_name_yomi='オオト\u3000アヤカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36854': EdinetCodeEntry(
        edinet_code='E36854',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平間\u3000恒浩',
        submitter_name_en=None,
        submitter_name_yomi='ヒラマ\u3000ツネヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36855': EdinetCodeEntry(
        edinet_code='E36855',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='角田\u3000博志',
        submitter_name_en=None,
        submitter_name_yomi='ツノダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36858': EdinetCodeEntry(
        edinet_code='E36858',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='有限会社おおとり',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャオオトリ',
        address='横浜市中区豆口台１３５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020002041679',
    ),
    'E36859': EdinetCodeEntry(
        edinet_code='E36859',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1282,
        fiscal_year_end='12月31日',
        submitter_name='株式会社セキュア',
        submitter_name_en='SECURE,INC.',
        submitter_name_yomi='カブシキガイシャセキュア',
        address='新宿区西新宿２丁目６番１号\u3000新宿住友ビル２０階',
        industry='情報・通信業',
        sec_code='42640',
        corporate_number='5011101040334',
    ),
    'E36860': EdinetCodeEntry(
        edinet_code='E36860',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=789,
        fiscal_year_end='8月末日',
        submitter_name='株式会社アスタリスク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアスタリスク',
        address='大阪市淀川区西中島五丁目６番１６号',
        industry='電気機器',
        sec_code='65220',
        corporate_number='3120001164267',
    ),
    'E36861': EdinetCodeEntry(
        edinet_code='E36861',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='エーピージーアセットマネジメントエヌヴィー',
        submitter_name_en=None,
        submitter_name_yomi='エーピージーアセットマネジメントエヌヴィー',
        address='オランダ王国アムステルダム、バーシス通り１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36862': EdinetCodeEntry(
        edinet_code='E36862',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=101,
        fiscal_year_end='1月31日',
        submitter_name='アップコン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アップコンカブシキカイシャ',
        address='川崎市高津区坂戸３－２－１ＫＳＰ東棟６１１',
        industry='建設業',
        sec_code='50750',
        corporate_number='4020001076372',
    ),
    'E36863': EdinetCodeEntry(
        edinet_code='E36863',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社マルハン太平洋クラブインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマルハンタイヘイヨウクラブインベストメント',
        address='千代田区丸の内一丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001219117',
    ),
    'E36864': EdinetCodeEntry(
        edinet_code='E36864',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=82,
        fiscal_year_end=None,
        submitter_name='ＡＭＩＲＡＬ\u3000ＧＥＳＴＩＯＮ',
        submitter_name_en=None,
        submitter_name_yomi='アミラル\u3000ジェスチョン',
        address='１０３\u3000ＲＵＥ\u3000ＤＥ\u3000ＧＲＥＮＥＬＬＥ\u3000７５００７\u3000ＰＡＲＩＳ\u3000ＦＲＡＮＣＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36865': EdinetCodeEntry(
        edinet_code='E36865',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='グリーンプロジェクト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グリーンクロジェクトカブシキカイシャ',
        address='千代田区丸の内二丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001159456',
    ),
    'E36873': EdinetCodeEntry(
        edinet_code='E36873',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久保田\u3000雅俊',
        submitter_name_en=None,
        submitter_name_yomi='クボタ\u3000マサトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36874': EdinetCodeEntry(
        edinet_code='E36874',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='有限会社ケイアンドアイ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャケイアンドアイ',
        address='船橋市本町２－７－１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7040002021851',
    ),
    'E36875': EdinetCodeEntry(
        edinet_code='E36875',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社レッドポイント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガシャレッドポイント',
        address='世田谷区中町１丁目１８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001092876',
    ),
    'E36876': EdinetCodeEntry(
        edinet_code='E36876',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社アイ・アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアイアセットマネジメント',
        address='港区六本木４丁目９番２号\u3000俳優座ビル８１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403010343',
    ),
    'E36877': EdinetCodeEntry(
        edinet_code='E36877',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=480,
        fiscal_year_end=None,
        submitter_name='大丸\u3000株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイマル\u3000カブシキカイシャ',
        address='札幌市白石区菊水３条１丁目８番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5430001009629',
    ),
    'E36881': EdinetCodeEntry(
        edinet_code='E36881',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榮\u3000章博',
        submitter_name_en=None,
        submitter_name_yomi='サカエ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36883': EdinetCodeEntry(
        edinet_code='E36883',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=435,
        fiscal_year_end='12月31日',
        submitter_name='株式会社リベロ',
        submitter_name_en='Livero Inc.',
        submitter_name_yomi='カブシキガイシャリベロ',
        address='港区虎ノ門三丁目８番８号ＮＴＴ虎ノ門ビル３Ｆ',
        industry='サービス業',
        sec_code='92450',
        corporate_number='1010901024558',
    ),
    'E36884': EdinetCodeEntry(
        edinet_code='E36884',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ニューアイデンティティクリエイション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニューアイデンティティクリエイション',
        address='港区南青山３ー１ー３６青山丸竹ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401139961',
    ),
    'E36886': EdinetCodeEntry(
        edinet_code='E36886',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=64,
        fiscal_year_end='7月31日',
        submitter_name='メディア総研株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メディアソウケンカブシキガイシャ',
        address='福岡市中央区大名２－８－１',
        industry='サービス業',
        sec_code='92420',
        corporate_number='2290001005793',
    ),
    'E36889': EdinetCodeEntry(
        edinet_code='E36889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='アヴィ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アヴィカブシキカイシャ',
        address='大阪市中央区大手通２－３－１６シエリア大手前１１０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001216587',
    ),
    'E36890': EdinetCodeEntry(
        edinet_code='E36890',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山川\u3000景子',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36891': EdinetCodeEntry(
        edinet_code='E36891',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='關根\u3000政英',
        submitter_name_en=None,
        submitter_name_yomi='セキネ\u3000マサヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36892': EdinetCodeEntry(
        edinet_code='E36892',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='富山\u3000広己',
        submitter_name_en=None,
        submitter_name_yomi='トミヤマ\u3000ヒロミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36895': EdinetCodeEntry(
        edinet_code='E36895',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＤＳＧ１',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディーエスジーワン',
        address='名古屋市中村区名駅五丁目３８番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180001102707',
    ),
    'E36896': EdinetCodeEntry(
        edinet_code='E36896',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月末日',
        submitter_name='株式会社プロジェクトホールディングス',
        submitter_name_en='ProjectHoldings,Inc.',
        submitter_name_yomi='カブシキガイシャプロジェクトホールディングス',
        address='港区麻布台一丁目３番１号',
        industry='サービス業',
        sec_code='92460',
        corporate_number='8010401122459',
    ),
    'E36897': EdinetCodeEntry(
        edinet_code='E36897',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=554,
        fiscal_year_end='12月末日',
        submitter_name='株式会社コアコンセプト・テクノロジー',
        submitter_name_en='Core Concept Technologies Inc.',
        submitter_name_yomi='カブシキガイシャコアコンセプトテクノロジー',
        address='豊島区南池袋１丁目１６番１５号',
        industry='情報・通信業',
        sec_code='43710',
        corporate_number='4010001127738',
    ),
    'E36899': EdinetCodeEntry(
        edinet_code='E36899',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='山田マーケティング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダマーケティングカブシキガイシャ',
        address='大阪市城東区今福西二丁目１１番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001237242',
    ),
    'E36901': EdinetCodeEntry(
        edinet_code='E36901',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＲＯＢＯＴ\u3000ＰＡＹＭＥＮＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャロボットペイメント',
        address='渋谷区神宮前６丁目１９番２０号',
        industry='情報・通信業',
        sec_code='43740',
        corporate_number='7011001051017',
    ),
    'E36902': EdinetCodeEntry(
        edinet_code='E36902',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＫコーポレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイケイコーポレーションカブシキカイシャ',
        address='小田原市西大友２０５番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1021001073395',
    ),
    'E36903': EdinetCodeEntry(
        edinet_code='E36903',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石原\u3000紀彦',
        submitter_name_en=None,
        submitter_name_yomi='イシハラ\u3000ノリヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36905': EdinetCodeEntry(
        edinet_code='E36905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=118,
        fiscal_year_end='12月31日',
        submitter_name='ユミルリンク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユミルリンクカブシキガイシャ',
        address='渋谷区代々木二丁目２番１号',
        industry='情報・通信業',
        sec_code='43720',
        corporate_number='3011001034545',
    ),
    'E36906': EdinetCodeEntry(
        edinet_code='E36906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='税所\u3000篤',
        submitter_name_en=None,
        submitter_name_yomi='サイショ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36907': EdinetCodeEntry(
        edinet_code='E36907',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='ＭＥＴＡ\u3000Ｃａｐｉｔａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メタキャピタルカブシキガイシャ',
        address='港区赤坂９丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401078062',
    ),
    'E36909': EdinetCodeEntry(
        edinet_code='E36909',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='シダー取引先持株会理事長\u3000浅井\u3000孝',
        submitter_name_en=None,
        submitter_name_yomi='シダートリヒキサキモチカブカイリジチョウ\u3000アサイ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36911': EdinetCodeEntry(
        edinet_code='E36911',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松藤\u3000展和',
        submitter_name_en=None,
        submitter_name_yomi='マツドウ\u3000ノブカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36913': EdinetCodeEntry(
        edinet_code='E36913',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アクアプレコン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アクアプレコンカブシキカイシャ',
        address='川崎市高津区溝口１－１５－３－１２０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001105597',
    ),
    'E36914': EdinetCodeEntry(
        edinet_code='E36914',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=88826,
        fiscal_year_end=None,
        submitter_name='フーリハン・ローキー・インク',
        submitter_name_en=None,
        submitter_name_yomi='フーリハンローキーインク',
        address='アメリカ合衆国デラウェア州ニューキャッスル・カウンティ、ウィルミントン、リトル・フォールス・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36918': EdinetCodeEntry(
        edinet_code='E36918',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='若菜\u3000秀之',
        submitter_name_en=None,
        submitter_name_yomi='ワカナ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36919': EdinetCodeEntry(
        edinet_code='E36919',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土井\u3000悠之介',
        submitter_name_en=None,
        submitter_name_yomi='ドイ\u3000ユウノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36920': EdinetCodeEntry(
        edinet_code='E36920',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000翔太',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ショウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36921': EdinetCodeEntry(
        edinet_code='E36921',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社バードアイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャバードアイ',
        address='品川区上大崎４－１－１－２７０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001109881',
    ),
    'E36922': EdinetCodeEntry(
        edinet_code='E36922',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ユニヴァ・アセット・マネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユニヴァアセットマネジメント',
        address='港区六本木１－６－１\u3000泉ガーデンタワー３５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401109966',
    ),
    'E36924': EdinetCodeEntry(
        edinet_code='E36924',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='室町機械株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ムロマチキカイカブシキガイシャ',
        address='中央区日本橋室町四丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001058580',
    ),
    'E36925': EdinetCodeEntry(
        edinet_code='E36925',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社トミコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトミコーポレーション',
        address='目黒区平町１－１０－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001140551',
    ),
    'E36928': EdinetCodeEntry(
        edinet_code='E36928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=304,
        fiscal_year_end='3月31日',
        submitter_name='シンプレクス・ホールディングス株式会社',
        submitter_name_en='Simplex Holdings, Inc.',
        submitter_name_yomi='シンプレクスホールディングスカブシキガイシャ',
        address='港区虎ノ門一丁目２３番１号',
        industry='情報・通信業',
        sec_code='43730',
        corporate_number='5010401128558',
    ),
    'E36929': EdinetCodeEntry(
        edinet_code='E36929',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='アイテック阪急阪神株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイテックハンキュウハンシンカブシキガイシャ',
        address='大阪市福島区海老江１丁目１番３１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001034119',
    ),
    'E36931': EdinetCodeEntry(
        edinet_code='E36931',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社紳士服中西',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシンシフクナカニシ',
        address='京都市下京区松原通烏丸西入ル玉津島町３０３番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4130001069811',
    ),
    'E36932': EdinetCodeEntry(
        edinet_code='E36932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000篤弘',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000アツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36934': EdinetCodeEntry(
        edinet_code='E36934',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹尾\u3000昌大',
        submitter_name_en=None,
        submitter_name_yomi='タケオ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36935': EdinetCodeEntry(
        edinet_code='E36935',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6000,
        fiscal_year_end=None,
        submitter_name='東芝ライテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウシバライテックカブシキカイシャ',
        address='横須賀市船越町一丁目２０１番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5021001044112',
    ),
    'E36936': EdinetCodeEntry(
        edinet_code='E36936',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋川\u3000正',
        submitter_name_en=None,
        submitter_name_yomi='アキカワ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36937': EdinetCodeEntry(
        edinet_code='E36937',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=109,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＢｅｅＸ',
        submitter_name_en='BeeX inc.',
        submitter_name_yomi='カブシキガイシャビーエックス',
        address='中央区銀座七丁目１４番１３号',
        industry='情報・通信業',
        sec_code='42700',
        corporate_number='4010001173996',
    ),
    'E36938': EdinetCodeEntry(
        edinet_code='E36938',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｇｅｎｅｓｉｓ１',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェネシスワン',
        address='京都市中京区烏丸通御池下る虎屋町５６６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3130001067312',
    ),
    'E36939': EdinetCodeEntry(
        edinet_code='E36939',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮下\u3000尚之',
        submitter_name_en=None,
        submitter_name_yomi='ミヤシタ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36940': EdinetCodeEntry(
        edinet_code='E36940',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1356,
        fiscal_year_end=None,
        submitter_name='全共連第１回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼンキョウレンダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001219944',
    ),
    'E36942': EdinetCodeEntry(
        edinet_code='E36942',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='5月31日',
        submitter_name='エイ・シイ工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイシイコウギョウカブシキガイシャ',
        address='寝屋川市石津元町１０－１２',
        industry='その他製品',
        sec_code=None,
        corporate_number='6120001147467',
    ),
    'E36943': EdinetCodeEntry(
        edinet_code='E36943',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7413,
        fiscal_year_end=None,
        submitter_name='マラソン・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='マラソン\u3000アセット\u3000マネジメント\u3000リミテッド',
        address='英国ＷＣ２Ｅ\u3000９ＤＰロンドン、フローラル・ストリート２７ｂ、ザ・フローラル・ビルディング',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36944': EdinetCodeEntry(
        edinet_code='E36944',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ワンキャリア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワンキャリア',
        address='渋谷区桜丘町２０番１号',
        industry='情報・通信業',
        sec_code='43770',
        corporate_number='8011001106991',
    ),
    'E36945': EdinetCodeEntry(
        edinet_code='E36945',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='３１ＶＥＮＴＵＲＥＳ－グローバル・ブレイン－グロースＩ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='サンイチベンチャーズグローバルブレイングロースワンゴウドウガイシャ',
        address='中央区日本橋一丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003027470',
    ),
    'E36946': EdinetCodeEntry(
        edinet_code='E36946',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5557,
        fiscal_year_end='12月31日',
        submitter_name='セーフィー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セーフィーカブシキカイシャ',
        address='品川区西品川一丁目１番１号\u3000住友不動産大崎ガーデンタワー',
        industry='情報・通信業',
        sec_code='43750',
        corporate_number='7010701030065',
    ),
    'E36949': EdinetCodeEntry(
        edinet_code='E36949',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神林\u3000秀康',
        submitter_name_en=None,
        submitter_name_yomi='カンバヤシ\u3000ヒデヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36954': EdinetCodeEntry(
        edinet_code='E36954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横尾\u3000禎司',
        submitter_name_en=None,
        submitter_name_yomi='ヨコオ\u3000テイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36956': EdinetCodeEntry(
        edinet_code='E36956',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=818,
        fiscal_year_end='3月末日',
        submitter_name='株式会社坪田ラボ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャツボタラボ',
        address='新宿区信濃町３５\u3000慶應義塾大学信濃町キャンパス２号館９階ＣＲＩＫ信濃町Ｅ７',
        industry='サービス業',
        sec_code='48900',
        corporate_number='5010401099989',
    ),
    'E36957': EdinetCodeEntry(
        edinet_code='E36957',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐渡島\u3000隆平',
        submitter_name_en=None,
        submitter_name_yomi='サドシマ\u3000リュウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36958': EdinetCodeEntry(
        edinet_code='E36958',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下崎\u3000守朗',
        submitter_name_en=None,
        submitter_name_yomi='シモザキ\u3000モリアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36959': EdinetCodeEntry(
        edinet_code='E36959',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森本\u3000数馬',
        submitter_name_en=None,
        submitter_name_yomi='モリモト\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36960': EdinetCodeEntry(
        edinet_code='E36960',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人穴見保雄財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンアナミヤスオザイダン',
        address='大分市西鶴崎１丁目７番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5320005009685',
    ),
    'E36961': EdinetCodeEntry(
        edinet_code='E36961',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=139,
        fiscal_year_end='9月30日',
        submitter_name='株式会社デジタリフト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデジタリフト',
        address='渋谷区神宮前六丁目１７番１１号',
        industry='サービス業',
        sec_code='92440',
        corporate_number='8011301019084',
    ),
    'E36962': EdinetCodeEntry(
        edinet_code='E36962',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡田\u3000直俊',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ナオトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36963': EdinetCodeEntry(
        edinet_code='E36963',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000丈晴',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000タケハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36964': EdinetCodeEntry(
        edinet_code='E36964',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡田\u3000亮介',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36968': EdinetCodeEntry(
        edinet_code='E36968',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1004,
        fiscal_year_end='9月30日',
        submitter_name='日本エコシステム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンエコシステムカブシキガイシャ',
        address='一宮市本町二丁目２番２号\u3000ＪＥＳ一宮ビル',
        industry='サービス業',
        sec_code='92490',
        corporate_number='8180001084777',
    ),
    'E36969': EdinetCodeEntry(
        edinet_code='E36969',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=582,
        fiscal_year_end='6月30日',
        submitter_name='ジャパンクラフトホールディングス株式会社',
        submitter_name_en='JAPAN CRAFT HOLDINGS CO., LTD.',
        submitter_name_yomi='ジャパンクラフトホールディングスカブシキカイシャ',
        address='名古屋市名東区高社一丁目２１０番地',
        industry='小売業',
        sec_code='71350',
        corporate_number='4180001149377',
    ),
    'E36970': EdinetCodeEntry(
        edinet_code='E36970',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=53,
        fiscal_year_end=None,
        submitter_name='ＪＯＨＣＭ\u3000（Ｓｉｎｇａｐｏｒｅ）\u3000Ｐｔｅ．\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ジェイオーエイチシーエムシンガポールピーティーイーリミテッド',
        address='シンガポール０４８９４６、キャピタグリーン１５－０４、マーケット・ストリート１３８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36973': EdinetCodeEntry(
        edinet_code='E36973',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田城\u3000弘志',
        submitter_name_en=None,
        submitter_name_yomi='タシロ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36974': EdinetCodeEntry(
        edinet_code='E36974',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松島\u3000穣',
        submitter_name_en=None,
        submitter_name_yomi='マツシマ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36976': EdinetCodeEntry(
        edinet_code='E36976',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=48781,
        fiscal_year_end='3月末日',
        submitter_name='ＰＨＣホールディングス株式会社',
        submitter_name_en='PHC Holdings Corporation',
        submitter_name_yomi='ピーエイチシーホールディングスカブシキカイシャ',
        address='東京都千代田区有楽町一丁目１３番２号\u3000第一生命日比谷ファースト１５階',
        industry='電気機器',
        sec_code='65230',
        corporate_number='6010001155349',
    ),
    'E36978': EdinetCodeEntry(
        edinet_code='E36978',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ケイアイホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイアイホールディングス',
        address='岡山市北区中仙道二丁目３３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6260001007715',
    ),
    'E36979': EdinetCodeEntry(
        edinet_code='E36979',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000友彦',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000トモヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36980': EdinetCodeEntry(
        edinet_code='E36980',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000慈和',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36981': EdinetCodeEntry(
        edinet_code='E36981',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梶本\u3000修身',
        submitter_name_en=None,
        submitter_name_yomi='カジモト\u3000オサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36985': EdinetCodeEntry(
        edinet_code='E36985',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＳＩＡ\u3000ＰＬＡＳＴＩＣ\u3000ＶＩＣＴＯＲＹ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='アジア\u3000プラスチック\u3000ビクトリー\u3000プライベート\u3000リミテッド',
        address='５６\u3000ＫＡＬＬＡＮＧ\u3000ＰＵＤＤＩＮＧ\u3000ＲＯＡＤ\u3000＃０７－０２\u3000ＨＨ\u3000＠\u3000ＫＡＬＬＡＮＧ\u3000ＳＩＮＧＡＰＯＲＥ\u3000（３４９３２８）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36987': EdinetCodeEntry(
        edinet_code='E36987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鹿島\u3000秀俊',
        submitter_name_en=None,
        submitter_name_yomi='カシマ\u3000ヒデトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36988': EdinetCodeEntry(
        edinet_code='E36988',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=302,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ＧＲＣＳ',
        submitter_name_en='GRCS Inc.',
        submitter_name_yomi='カブシキガイシャジーアールシーエス',
        address='千代田区丸の内一丁目１番１号\u3000パレスビル５階',
        industry='サービス業',
        sec_code='92500',
        corporate_number='3010001097899',
    ),
    'E36989': EdinetCodeEntry(
        edinet_code='E36989',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='10月末日',
        submitter_name='株式会社ＣＩＮＣ',
        submitter_name_en='CINC Corp.',
        submitter_name_yomi='カブシキガイシャシンク',
        address='港区虎ノ門一丁目２１－１９',
        industry='情報・通信業',
        sec_code='43780',
        corporate_number='9011101069568',
    ),
    'E36990': EdinetCodeEntry(
        edinet_code='E36990',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='阮明徳',
        submitter_name_en=None,
        submitter_name_yomi='グエンミンドゥック',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36991': EdinetCodeEntry(
        edinet_code='E36991',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=799,
        fiscal_year_end='9月30日',
        submitter_name='日本調理機株式会社',
        submitter_name_en='NITCHO CORPORATION',
        submitter_name_yomi='ニホンチョウリキカブシキカイシャ',
        address='大田区東六郷三丁目１５番８号',
        industry='機械',
        sec_code='29610',
        corporate_number='8010801009041',
    ),
    'E36992': EdinetCodeEntry(
        edinet_code='E36992',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=212,
        fiscal_year_end=None,
        submitter_name='ＨＣアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチシーアセットマネジメントカブシキカイシャ',
        address='千代田区神田神保町二丁目１１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001081038',
    ),
    'E36995': EdinetCodeEntry(
        edinet_code='E36995',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清水\u3000亘',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ワタル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E36997': EdinetCodeEntry(
        edinet_code='E36997',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='那須マテリアル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナスマテリアルカブシキカイシャ',
        address='大田原市北金丸２１２２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4060001012893',
    ),
    'E36999': EdinetCodeEntry(
        edinet_code='E36999',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横川\u3000尚佳',
        submitter_name_en=None,
        submitter_name_yomi='ヨコガワ\u3000ナオヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37002': EdinetCodeEntry(
        edinet_code='E37002',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29,
        fiscal_year_end=None,
        submitter_name='ハゼルビューセキュリティーズインク',
        submitter_name_en=None,
        submitter_name_yomi='ハゼルビューセキュリティーズインク',
        address='カナダ国オンタリオ州トロント\u3000ヤングストリート１１３３\u3000４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37003': EdinetCodeEntry(
        edinet_code='E37003',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩間\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='イワマ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37004': EdinetCodeEntry(
        edinet_code='E37004',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＣＡＲＰＥ\u3000ＤＩＥＭ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカーペディエム',
        address='港区虎ノ門三丁目８番２１号虎ノ門３３森ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010101010903',
    ),
    'E37006': EdinetCodeEntry(
        edinet_code='E37006',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=227,
        fiscal_year_end='2月末日',
        submitter_name='スローガン株式会社',
        submitter_name_en='Slogan Inc.',
        submitter_name_yomi='スローガンカブシキガイシャ',
        address='港区南青山二丁目１１番１７号',
        industry='サービス業',
        sec_code='92530',
        corporate_number='1010001096077',
    ),
    'E37009': EdinetCodeEntry(
        edinet_code='E37009',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000浩二',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37013': EdinetCodeEntry(
        edinet_code='E37013',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000明郎',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37014': EdinetCodeEntry(
        edinet_code='E37014',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000徳子',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000ノリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37016': EdinetCodeEntry(
        edinet_code='E37016',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000幸子',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000サチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37017': EdinetCodeEntry(
        edinet_code='E37017',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='有限会社第一エア工業',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャダイイチエアコウギョウ',
        address='大田区中央六丁目２番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010802008286',
    ),
    'E37019': EdinetCodeEntry(
        edinet_code='E37019',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小坂\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='コサカ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37023': EdinetCodeEntry(
        edinet_code='E37023',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=391,
        fiscal_year_end=None,
        submitter_name='リーテイルブランディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リーテイルブランディングカブシキガイシャ',
        address='港区北青山二丁目１２番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401042202',
    ),
    'E37024': EdinetCodeEntry(
        edinet_code='E37024',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='秋元\u3000之浩',
        submitter_name_en=None,
        submitter_name_yomi='アキモト\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37026': EdinetCodeEntry(
        edinet_code='E37026',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長澤\u3000有紘',
        submitter_name_en=None,
        submitter_name_yomi='ナガサワ\u3000アリヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37037': EdinetCodeEntry(
        edinet_code='E37037',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清久\u3000健也',
        submitter_name_en=None,
        submitter_name_yomi='キヨク\u3000ケンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37038': EdinetCodeEntry(
        edinet_code='E37038',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='10月末日',
        submitter_name='株式会社ＡＢ＆Ｃｏｍｐａｎｙ',
        submitter_name_en='AB&Company Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエービーアンドカンパニー',
        address='新宿区新宿二丁目１６番６号',
        industry='サービス業',
        sec_code='92510',
        corporate_number='8010401136855',
    ),
    'E37039': EdinetCodeEntry(
        edinet_code='E37039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河原\u3000聡',
        submitter_name_en=None,
        submitter_name_yomi='カワハラ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37040': EdinetCodeEntry(
        edinet_code='E37040',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮田\u3000萌美',
        submitter_name_en=None,
        submitter_name_yomi='ミヤタ\u3000メグミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37041': EdinetCodeEntry(
        edinet_code='E37041',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮田\u3000あや',
        submitter_name_en=None,
        submitter_name_yomi='ミヤタ\u3000アヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37042': EdinetCodeEntry(
        edinet_code='E37042',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊勢\u3000彦信',
        submitter_name_en=None,
        submitter_name_yomi='イセ\u3000ヒコノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37043': EdinetCodeEntry(
        edinet_code='E37043',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ミライサイテキグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミライサイテキグループ',
        address='港区虎ノ門四丁目１番２８号虎ノ門タワーズオフィス１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401162324',
    ),
    'E37044': EdinetCodeEntry(
        edinet_code='E37044',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=106,
        fiscal_year_end=None,
        submitter_name='三田キャピタル・プライベート・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ミタキャピタルプライベートリミテッド',
        address='シンガポール０６９５３４\u3000セシル・ストリート１０５\u3000ジ・オクタゴン＃２４－２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37045': EdinetCodeEntry(
        edinet_code='E37045',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000武史',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37046': EdinetCodeEntry(
        edinet_code='E37046',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='下村\u3000克則',
        submitter_name_en=None,
        submitter_name_yomi='シモムラ\u3000カツノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37047': EdinetCodeEntry(
        edinet_code='E37047',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田口\u3000紀成',
        submitter_name_en=None,
        submitter_name_yomi='タグチ\u3000タダアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37048': EdinetCodeEntry(
        edinet_code='E37048',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津野尾\u3000肇',
        submitter_name_en=None,
        submitter_name_yomi='ツノオ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37049': EdinetCodeEntry(
        edinet_code='E37049',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000浩和',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37052': EdinetCodeEntry(
        edinet_code='E37052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000規之',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37054': EdinetCodeEntry(
        edinet_code='E37054',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＬＩＮＥ\u3000Ｄｉｇｉｔａｌ\u3000Ｆｒｏｎｔｉｅｒ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ライン\u3000デジタル\u3000フロンティアカブシキカイシャ',
        address='港区赤坂九丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101084679',
    ),
    'E37055': EdinetCodeEntry(
        edinet_code='E37055',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙盛\u3000豊文',
        submitter_name_en=None,
        submitter_name_yomi='タカモリ\u3000トヨフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37060': EdinetCodeEntry(
        edinet_code='E37060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1039,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｐｈｏｔｏｓｙｎｔｈ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフォトシンス',
        address='東京都港区芝五丁目２９番１１号',
        industry='情報・通信業',
        sec_code='43790',
        corporate_number='4010701029878',
    ),
    'E37061': EdinetCodeEntry(
        edinet_code='E37061',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社東京ユナイテッド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトウキョウユナイテッド',
        address='文京区後楽一丁目４番１４号後楽森ビル１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101050994',
    ),
    'E37065': EdinetCodeEntry(
        edinet_code='E37065',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='神山\u3000隆志',
        submitter_name_en=None,
        submitter_name_yomi='カミヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37066': EdinetCodeEntry(
        edinet_code='E37066',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='百本\u3000正博',
        submitter_name_en=None,
        submitter_name_yomi='ヒャクモト\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37067': EdinetCodeEntry(
        edinet_code='E37067',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=277,
        fiscal_year_end=None,
        submitter_name='ピルグリム・パートナーズ・アジア・ピーティーイー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='ピルグリムパートナーズアジアピーティーイーエルティーディー',
        address='シンガポール０６８６０２、テロックアヤーストリート１３７、＃０４－０７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37068': EdinetCodeEntry(
        edinet_code='E37068',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野村\u3000和伸',
        submitter_name_en=None,
        submitter_name_yomi='ノムラ\u3000カズノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37069': EdinetCodeEntry(
        edinet_code='E37069',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='㈱ティムス',
        submitter_name_en='TMS Co., Ltd',
        submitter_name_yomi='カブシキカイシャティムス',
        address='府中市府中町一丁目９番地京王府中１丁目ビル１１階',
        industry='医薬品',
        sec_code='48910',
        corporate_number='5013401006469',
    ),
    'E37070': EdinetCodeEntry(
        edinet_code='E37070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金\u3000武偉',
        submitter_name_en=None,
        submitter_name_yomi='キム\u3000ムイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37072': EdinetCodeEntry(
        edinet_code='E37072',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮田\u3000敏男',
        submitter_name_en=None,
        submitter_name_yomi='ミヤタ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37076': EdinetCodeEntry(
        edinet_code='E37076',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=51,
        fiscal_year_end=None,
        submitter_name='株式会社ネットアイアールディー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャネットアイアールディー',
        address='京都市下京区中堂寺粟田町９３番地\u3000京都リサーチパークサイエンスセンタービル４号館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7130001018427',
    ),
    'E37077': EdinetCodeEntry(
        edinet_code='E37077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='釣谷\u3000宏行',
        submitter_name_en=None,
        submitter_name_yomi='ツリヤ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37078': EdinetCodeEntry(
        edinet_code='E37078',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1100,
        fiscal_year_end=None,
        submitter_name='伊藤忠紙パルプ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イトウチュウカミパルプカブシキカイシャ',
        address='中央区日本橋本町２－７－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001037338',
    ),
    'E37082': EdinetCodeEntry(
        edinet_code='E37082',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=80,
        fiscal_year_end='10月末日',
        submitter_name='のむら産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラサンギョウカブシキガイシャ',
        address='東久留米市前沢５－３２－２３',
        industry='機械',
        sec_code='71310',
        corporate_number='2012701007849',
    ),
    'E37083': EdinetCodeEntry(
        edinet_code='E37083',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1054,
        fiscal_year_end=None,
        submitter_name='光が丘興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒカリガオカコウサンカブシキガイシャ',
        address='練馬区高松５丁目８番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011601012260',
    ),
    'E37084': EdinetCodeEntry(
        edinet_code='E37084',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀越\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='ホリコシ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37091': EdinetCodeEntry(
        edinet_code='E37091',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='塚本\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='ツカモト\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37095': EdinetCodeEntry(
        edinet_code='E37095',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='8月31日',
        submitter_name='株式会社サイエンスアーツ',
        submitter_name_en='Science Arts, Inc.',
        submitter_name_yomi='カブシキガイシャサイエンスアーツ',
        address='新宿区神楽坂四丁目１番地１オザワビル７階',
        industry='情報・通信業',
        sec_code='44120',
        corporate_number='3010001129272',
    ),
    'E37097': EdinetCodeEntry(
        edinet_code='E37097',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='蓮尾\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='ハスオ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37098': EdinetCodeEntry(
        edinet_code='E37098',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=340,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ラストワンマイル',
        submitter_name_en='Last One Mile Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャラストワンマイル',
        address='豊島区東池袋四丁目２１番１号アウルタワー３階',
        industry='情報・通信業',
        sec_code='92520',
        corporate_number='2010001147267',
    ),
    'E37099': EdinetCodeEntry(
        edinet_code='E37099',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社生命科学インスティテュート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセイメイカガクインスティテュート',
        address='千代田区丸の内１－１－１\u3000パレスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003018167',
    ),
    'E37105': EdinetCodeEntry(
        edinet_code='E37105',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='12月31日',
        submitter_name='ＴＨＥＣＯＯ株式会社',
        submitter_name_en='THECOO Inc.',
        submitter_name_yomi='ザクーカブシキガイシャ',
        address='渋谷区神宮前３丁目２５－１５神宮前テラス５階',
        industry='情報・通信業',
        sec_code='42550',
        corporate_number='4010701028921',
    ),
    'E37106': EdinetCodeEntry(
        edinet_code='E37106',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=49,
        fiscal_year_end=None,
        submitter_name='ジャパンメディアシステム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンメディアシステムカブシキガイシャ',
        address='千代田区外神田二丁目１４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401162954',
    ),
    'E37107': EdinetCodeEntry(
        edinet_code='E37107',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｐａｒｓｉｆａｌ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='パーシファル\u3000キャピタル\u3000マネジメント\u3000エルピー',
        address='アメリカ合衆国、１９８０８デラウェア州、ウィルミントン、リトル・フォールズ・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37108': EdinetCodeEntry(
        edinet_code='E37108',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='堂山\u3000遼',
        submitter_name_en=None,
        submitter_name_yomi='ドウヤマ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37111': EdinetCodeEntry(
        edinet_code='E37111',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保木\u3000博子',
        submitter_name_en=None,
        submitter_name_yomi='ホキ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37112': EdinetCodeEntry(
        edinet_code='E37112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山﨑\u3000文義',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000フミヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37114': EdinetCodeEntry(
        edinet_code='E37114',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トークン合同会社',
        submitter_name_en=None,
        submitter_name_yomi='トークンゴウドウガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010003033911',
    ),
    'E37115': EdinetCodeEntry(
        edinet_code='E37115',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ブロードエンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブロードエンタープライズ',
        address='大阪市北区太融寺町５番１５号',
        industry='情報・通信業',
        sec_code='44150',
        corporate_number='5120001103719',
    ),
    'E37116': EdinetCodeEntry(
        edinet_code='E37116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=98,
        fiscal_year_end=None,
        submitter_name='株式会社ランニング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャランニング',
        address='大阪市西区西本町２－３－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001194591',
    ),
    'E37118': EdinetCodeEntry(
        edinet_code='E37118',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＫＫＲ\u3000ＰＨＣ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ケーケーアール\u3000ピーエイチシー\u3000インベストメント\u3000エルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランド・ハウス、私書箱第３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37119': EdinetCodeEntry(
        edinet_code='E37119',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='尾方\u3000久美子',
        submitter_name_en=None,
        submitter_name_yomi='オガタ\u3000クミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37120': EdinetCodeEntry(
        edinet_code='E37120',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社エム・クレド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエムクレド',
        address='千代田区紀尾井町４－１ニユーオータニガーデンコート２２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401055228',
    ),
    'E37121': EdinetCodeEntry(
        edinet_code='E37121',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3352,
        fiscal_year_end=None,
        submitter_name='インターステラテクノロジズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インターステラテクノロジズカブシキガイシャ',
        address='広尾郡大樹町字芽武６９０番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401080445',
    ),
    'E37123': EdinetCodeEntry(
        edinet_code='E37123',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='樋口\u3000正信',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチ\u3000マサノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37124': EdinetCodeEntry(
        edinet_code='E37124',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石松\u3000友典',
        submitter_name_en=None,
        submitter_name_yomi='イシマツ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37126': EdinetCodeEntry(
        edinet_code='E37126',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平\u3000大志朗',
        submitter_name_en=None,
        submitter_name_yomi='タイラ\u3000ダイシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37128': EdinetCodeEntry(
        edinet_code='E37128',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='朝日印刷持株会\u3000理事長\u3000小森善治',
        submitter_name_en=None,
        submitter_name_yomi='アサヒインサツモチカブカイ\u3000リジチョウ\u3000コモリヨシハル',
        address='富山市１番１号\u3000一番町スクエアビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4700150070586',
    ),
    'E37130': EdinetCodeEntry(
        edinet_code='E37130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=698,
        fiscal_year_end='3月末日',
        submitter_name='株式会社フレクト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフレクト',
        address='港区芝浦１丁目１番１号浜松町ビルディング１１階',
        industry='情報・通信業',
        sec_code='44140',
        corporate_number='6011001045498',
    ),
    'E37131': EdinetCodeEntry(
        edinet_code='E37131',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=412,
        fiscal_year_end='12月31日',
        submitter_name='アジアクエスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アジアクエストカブシキガイシャ',
        address='文京区後楽二丁目６番１号',
        industry='情報・通信業',
        sec_code='42610',
        corporate_number='2010901030183',
    ),
    'E37132': EdinetCodeEntry(
        edinet_code='E37132',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井村俊哉',
        submitter_name_en=None,
        submitter_name_yomi='イムラトシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37133': EdinetCodeEntry(
        edinet_code='E37133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=592,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ボードルア',
        submitter_name_en='baudroie,inc.',
        submitter_name_yomi='カブシキガイシャボードルア',
        address='港区赤坂九丁目７番地１号ミッドタウン・タワー３７階',
        industry='情報・通信業',
        sec_code='44130',
        corporate_number='4010401098975',
    ),
    'E37134': EdinetCodeEntry(
        edinet_code='E37134',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000望',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ノゾム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37135': EdinetCodeEntry(
        edinet_code='E37135',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋月\u3000帥謙',
        submitter_name_en=None,
        submitter_name_yomi='アキヅキ\u3000ミチカネ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37137': EdinetCodeEntry(
        edinet_code='E37137',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社将コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャショウコーポレーション',
        address='福岡市東区香椎照葉二丁目３番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1290001090804',
    ),
    'E37138': EdinetCodeEntry(
        edinet_code='E37138',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩井\u3000健治',
        submitter_name_en=None,
        submitter_name_yomi='シオイ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37139': EdinetCodeEntry(
        edinet_code='E37139',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社Ｅ＆Ｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーアンドイー',
        address='横浜市青葉区市ケ尾町４８４番地８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001103975',
    ),
    'E37140': EdinetCodeEntry(
        edinet_code='E37140',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社かたくら',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカタクラ',
        address='中央区明石町６番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001221253',
    ),
    'E37141': EdinetCodeEntry(
        edinet_code='E37141',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=714,
        fiscal_year_end='3月31日',
        submitter_name='株式会社長栄',
        submitter_name_en='Choei Inc.',
        submitter_name_yomi='カブシキガイシャチョウエイ',
        address='京都市伏見区深草西浦町三丁目７０番地第５長栄アストロビル',
        industry='不動産業',
        sec_code='29930',
        corporate_number='9130001015067',
    ),
    'E37142': EdinetCodeEntry(
        edinet_code='E37142',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000良太',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000リョウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37143': EdinetCodeEntry(
        edinet_code='E37143',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=519,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アップガレージグループ',
        submitter_name_en='UP GARAGE GROUP Co., Ltd.',
        submitter_name_yomi='カブシキガイシャアップガレージグループ',
        address='神奈川県横浜市青葉区榎が丘７番地２２',
        industry='サービス業',
        sec_code='71340',
        corporate_number='7020001105153',
    ),
    'E37145': EdinetCodeEntry(
        edinet_code='E37145',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=176,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｆｉｎａｔｅｘｔホールディングス',
        submitter_name_en='Finatext Holdings Ltd.',
        submitter_name_yomi='カブシキカイシャフィナテキストホールディングス',
        address='千代田区九段北三丁目２番１１号\u3000住友不動産九段北ビル４階',
        industry='サービス業',
        sec_code='44190',
        corporate_number='8010001157847',
    ),
    'E37146': EdinetCodeEntry(
        edinet_code='E37146',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1351,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｔｒｕｅ\u3000Ｄａｔａ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトゥルーデータ',
        address='港区芝大門１丁目１０番１１号',
        industry='情報・通信業',
        sec_code='44160',
        corporate_number='6010401042601',
    ),
    'E37147': EdinetCodeEntry(
        edinet_code='E37147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=544,
        fiscal_year_end='3月末日',
        submitter_name='グローバルセキュリティエキスパート株式会社',
        submitter_name_en='Global Security Experts Inc.',
        submitter_name_yomi='グローバルセキュリティエキスパートカブシキガイシャ',
        address='港区海岸一丁目１６番１号',
        industry='情報・通信業',
        sec_code='44170',
        corporate_number='2010401086255',
    ),
    'E37148': EdinetCodeEntry(
        edinet_code='E37148',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='株式会社エビス商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエビスショウジ',
        address='都城市豊満町９８０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5350001007871',
    ),
    'E37149': EdinetCodeEntry(
        edinet_code='E37149',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37151': EdinetCodeEntry(
        edinet_code='E37151',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='桃井純',
        submitter_name_en=None,
        submitter_name_yomi='モモイジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37153': EdinetCodeEntry(
        edinet_code='E37153',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1582,
        fiscal_year_end='9月30日',
        submitter_name='Ｇｒｅｅｎ\u3000Ｅａｒｔｈ\u3000Ｉｎｓｔｉｔｕｔｅ株式会社',
        submitter_name_en='Green Earth Institute Co., Ltd.',
        submitter_name_yomi='グリーンアースインスティテュートカブシキガイシャ',
        address='新宿区新宿三丁目５番６号',
        industry='サービス業',
        sec_code='92120',
        corporate_number='4010001142142',
    ),
    'E37154': EdinetCodeEntry(
        edinet_code='E37154',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='シックスジョイ・ホンコン・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シックスジョイホンコンリミテッド',
        address='香港ワンチャイ、クイーンズロード・イースト１、スリー・パシフィック・プレイス、２９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37156': EdinetCodeEntry(
        edinet_code='E37156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='12月31日',
        submitter_name='湖北工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コホクコウギョウカブシキガイシャ',
        address='長浜市高月町高月１６２３番地',
        industry='電気機器',
        sec_code='65240',
        corporate_number='9160001007235',
    ),
    'E37157': EdinetCodeEntry(
        edinet_code='E37157',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1588,
        fiscal_year_end='3月31日',
        submitter_name='三和油化工業株式会社',
        submitter_name_en='SANWAYUKA INDUSTRY CORPORATION',
        submitter_name_yomi='サンワユカコウギョウカブシキガイシャ',
        address='刈谷市一里山町深田１５番地',
        industry='化学',
        sec_code='41250',
        corporate_number='4180301014009',
    ),
    'E37158': EdinetCodeEntry(
        edinet_code='E37158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社エクサウィザーズ',
        submitter_name_en='ExaWizards Inc.',
        submitter_name_yomi='カブシキガイシャエクサウィザーズ',
        address='港区芝浦４丁目２－８住友不動産三田ファーストビル５階',
        industry='情報・通信業',
        sec_code='42590',
        corporate_number='2010001173536',
    ),
    'E37159': EdinetCodeEntry(
        edinet_code='E37159',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=287,
        fiscal_year_end='10月末日',
        submitter_name='株式会社ラバブルマーケティンググループ',
        submitter_name_en='Lovable Marketing Group, Inc.',
        submitter_name_yomi='カブシキカイシャラバブルマーケティンググループ',
        address='港区虎ノ門４－１－１３',
        industry='情報・通信業',
        sec_code='92540',
        corporate_number='3010401113149',
    ),
    'E37160': EdinetCodeEntry(
        edinet_code='E37160',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=54,
        fiscal_year_end='12月31日',
        submitter_name='株式会社網屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアミヤ',
        address='中央区日本橋浜町三丁目３番２号',
        industry='情報・通信業',
        sec_code='42580',
        corporate_number='8010001036654',
    ),
    'E37162': EdinetCodeEntry(
        edinet_code='E37162',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＴＣＳアライアンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティシィエスアライアンスカブシキカイシャ',
        address='中央区日本橋本町四丁目８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001221246',
    ),
    'E37163': EdinetCodeEntry(
        edinet_code='E37163',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='ロードマップ・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ロードマップホールディングスカブシキガイシャ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010403025900',
    ),
    'E37164': EdinetCodeEntry(
        edinet_code='E37164',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000将雄',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37165': EdinetCodeEntry(
        edinet_code='E37165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ライフドリンク\u3000カンパニー',
        submitter_name_en='LIFEDRINK COMPANY, INC.',
        submitter_name_yomi='ライフドリンク\u3000カンパニー',
        address='大阪市北区梅田三丁目３番１０号',
        industry='食料品',
        sec_code='25850',
        corporate_number='7120901008940',
    ),
    'E37166': EdinetCodeEntry(
        edinet_code='E37166',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｋ＆Ｃホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイアンドシーホールディングスカブシキガイシャ',
        address='港区虎ノ門五丁目１１番１号オランダヒルズ森タワーＲｏＰ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401069452',
    ),
    'E37169': EdinetCodeEntry(
        edinet_code='E37169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サインド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサインド',
        address='品川区西五反田八丁目４番１３号',
        industry='サービス業',
        sec_code='42560',
        corporate_number='9010701025765',
    ),
    'E37170': EdinetCodeEntry(
        edinet_code='E37170',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='後藤\u3000展幸',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000ノブユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37171': EdinetCodeEntry(
        edinet_code='E37171',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30000,
        fiscal_year_end=None,
        submitter_name='今治造船株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イマバリゾウセンカブシキガイシャ',
        address='今治市小浦町一丁目４番５２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7500001011179',
    ),
    'E37172': EdinetCodeEntry(
        edinet_code='E37172',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='飯田\u3000邦彦',
        submitter_name_en=None,
        submitter_name_yomi='イイダ\u3000クニヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37175': EdinetCodeEntry(
        edinet_code='E37175',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ＪＤＳＣ',
        submitter_name_en='Japan Data Science Consortium Co. Ltd.',
        submitter_name_yomi='カブシキガイシャジェーディーエスシー',
        address='文京区小石川１－４－１住友不動産後楽園ビル１６階',
        industry='情報・通信業',
        sec_code='44180',
        corporate_number='6010001193638',
    ),
    'E37176': EdinetCodeEntry(
        edinet_code='E37176',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1266,
        fiscal_year_end='12月末日',
        submitter_name='株式会社エフ・コード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエフコード',
        address='新宿区神楽坂一丁目１番地',
        industry='サービス業',
        sec_code='92110',
        corporate_number='7011101050802',
    ),
    'E37177': EdinetCodeEntry(
        edinet_code='E37177',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＰＴＣＪ－２ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピーティーシージェイツーホールディングスカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001221860',
    ),
    'E37179': EdinetCodeEntry(
        edinet_code='E37179',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='政木\u3000喜仁',
        submitter_name_en=None,
        submitter_name_yomi='マサキ\u3000ヨシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37180': EdinetCodeEntry(
        edinet_code='E37180',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社おがの',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオガノ',
        address='港区三田５丁目７番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401162732',
    ),
    'E37183': EdinetCodeEntry(
        edinet_code='E37183',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＯＬＡＢＬＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャソラブル',
        address='千代田区丸の内二丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001221460',
    ),
    'E37184': EdinetCodeEntry(
        edinet_code='E37184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000歩',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000アユム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37185': EdinetCodeEntry(
        edinet_code='E37185',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＭＢＫ\u3000Ｗｅｌｌｎｅｓｓ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムビーケー\u3000ウェルネス\u3000ホールディングスカブシキカイシャ',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001221934',
    ),
    'E37187': EdinetCodeEntry(
        edinet_code='E37187',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000繁',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37190': EdinetCodeEntry(
        edinet_code='E37190',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＲ東日本情報システム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイアールヒガシニホンジョウホウシステム',
        address='新宿区大久保三丁目８番２号\u3000新宿ガーデンタワー７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001009773',
    ),
    'E37192': EdinetCodeEntry(
        edinet_code='E37192',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=247,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ハイブリッドテクノロジーズ',
        submitter_name_en='Hybrid Technologies Co., Ltd.',
        submitter_name_yomi='カブシキガイシャハイブリッドテクノロジーズ',
        address='中央区新川２－２２－１いちご新川ビル５Ｆ',
        industry='情報・通信業',
        sec_code='42600',
        corporate_number='4012401031387',
    ),
    'E37193': EdinetCodeEntry(
        edinet_code='E37193',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15108,
        fiscal_year_end=None,
        submitter_name='Ｇａｌｌａｔｏｗｎ\u3000Ｄｅｖｅｌｏｐｍｅｎｔｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ギャラタウンデベロップメントリミテッド',
        address='ＰＯＢｏｘ\u3000３１１１９，\u3000Ｇｒａｎｄ\u3000Ｐａｖｉｌｉｏｎ，\u3000Ｈｉｂｉｓｃｕｓ\u3000Ｗａｙ，\u3000８０２\u3000Ｗｅｓｔ\u3000Ｂａｙ\u3000Ｒｏａｄ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１―１２０５，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37194': EdinetCodeEntry(
        edinet_code='E37194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=4134,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ネットプロテクションズホールディングス',
        submitter_name_en='Net Protections Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャネットプロテクションズホールディングス',
        address='千代田区麹町四丁目２番地６',
        industry='情報・通信業',
        sec_code='73830',
        corporate_number='1010001193056',
    ),
    'E37195': EdinetCodeEntry(
        edinet_code='E37195',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津川\u3000晃弘',
        submitter_name_en=None,
        submitter_name_yomi='ツガワ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37196': EdinetCodeEntry(
        edinet_code='E37196',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='タドラナ・マネジメント・ウンド・アセット・ゲーエムベーハー',
        submitter_name_en=None,
        submitter_name_yomi='タドラナマネジメントウンドアセットゲーエムベーハー',
        address='オーストリア共和国、ウィーン１０１０、ヴィップリンガーシュトラーセ２５／３０ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37197': EdinetCodeEntry(
        edinet_code='E37197',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=696,
        fiscal_year_end='9月30日',
        submitter_name='株式会社タカヨシホールディングス',
        submitter_name_en='TAKAYOSHI Holdings, INC.',
        submitter_name_yomi='カブシキガイシャタカヨシホールディングス',
        address='千葉市美浜区中瀬一丁目３番地',
        industry='サービス業',
        sec_code='92590',
        corporate_number='3040001004316',
    ),
    'E37198': EdinetCodeEntry(
        edinet_code='E37198',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=185,
        fiscal_year_end='3月末日',
        submitter_name='ＨＹＵＧＡ\u3000ＰＲＩＭＡＲＹ\u3000ＣＡＲＥ株式会社',
        submitter_name_en='HYUGA PRIMARY CARE Co.,Ltd.',
        submitter_name_yomi='ヒュウガプライマリーケアカブシキガイシャ',
        address='春日市春日原北町二丁目２番１号',
        industry='小売業',
        sec_code='71330',
        corporate_number='4290001042983',
    ),
    'E37199': EdinetCodeEntry(
        edinet_code='E37199',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='9月末日',
        submitter_name='株式会社ＣＳ－Ｃ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシーエスシー',
        address='港区芝浦四丁目１３番２３号',
        industry='情報・通信業',
        sec_code='92580',
        corporate_number='6011501017170',
    ),
    'E37200': EdinetCodeEntry(
        edinet_code='E37200',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='ＴＥＳ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テスカブシキカイシャ',
        address='品川区西五反田二丁目６番３号\u3000東洋ビル１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010701037733',
    ),
    'E37201': EdinetCodeEntry(
        edinet_code='E37201',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000雅之',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000マサユキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37202': EdinetCodeEntry(
        edinet_code='E37202',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人地球環境産業技術研究機構',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンチキュウカンキョウサンギョウギジュツケンキュウキコウ',
        address='木津川市木津川台九丁目２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130005012678',
    ),
    'E37203': EdinetCodeEntry(
        edinet_code='E37203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丹内\u3000悠佑',
        submitter_name_en=None,
        submitter_name_yomi='タンナイ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37204': EdinetCodeEntry(
        edinet_code='E37204',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山崎\u3000均',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37205': EdinetCodeEntry(
        edinet_code='E37205',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4616,
        fiscal_year_end='12月末日',
        submitter_name='リニューアブル・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リニューアブルジャパンカブシキガイシャ',
        address='港区虎ノ門一丁目２番８号',
        industry='電気・ガス業',
        sec_code=None,
        corporate_number='6010401097868',
    ),
    'E37206': EdinetCodeEntry(
        edinet_code='E37206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1250,
        fiscal_year_end='3月31日',
        submitter_name='ニフティライフスタイル株式会社',
        submitter_name_en='NIFTY Lifestyle Co.,Ltd',
        submitter_name_yomi='ニフティライフスタイルカブシキガイシャ',
        address='新宿区北新宿２－２１－１\u3000新宿フロントタワー',
        industry='情報・通信業',
        sec_code='42620',
        corporate_number='5011101083341',
    ),
    'E37207': EdinetCodeEntry(
        edinet_code='E37207',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='サスメド株式会社',
        submitter_name_en='SUSMED, Inc.',
        submitter_name_yomi='サスメドカブシキガイシャ',
        address='中央区日本橋本町三丁目７番２号',
        industry='情報・通信業',
        sec_code='42630',
        corporate_number='7010003022232',
    ),
    'E37208': EdinetCodeEntry(
        edinet_code='E37208',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－５２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイフィフティートゥー',
        address='千代田区丸の内一丁目１番１号\u3000パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001217798',
    ),
    'E37209': EdinetCodeEntry(
        edinet_code='E37209',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='清川\u3000悦男',
        submitter_name_en=None,
        submitter_name_yomi='キヨカワ\u3000エツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37210': EdinetCodeEntry(
        edinet_code='E37210',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='市瀬\u3000一浩',
        submitter_name_en=None,
        submitter_name_yomi='イチノセ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37211': EdinetCodeEntry(
        edinet_code='E37211',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='織田\u3000一彰',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000カズアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37212': EdinetCodeEntry(
        edinet_code='E37212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='茂木\u3000孝之',
        submitter_name_en=None,
        submitter_name_yomi='モギ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37214': EdinetCodeEntry(
        edinet_code='E37214',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1063,
        fiscal_year_end='3月31日',
        submitter_name='株式会社シーユーシー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシーユーシー',
        address='港区芝浦三丁目１番１号',
        industry='サービス業',
        sec_code='91580',
        corporate_number='9010401113614',
    ),
    'E37215': EdinetCodeEntry(
        edinet_code='E37215',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社グリット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグリット',
        address='港区赤坂三丁目２番１２号赤坂ノアビル７Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401160740',
    ),
    'E37216': EdinetCodeEntry(
        edinet_code='E37216',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社グリットパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグリットパートナーズ',
        address='港区赤坂三丁目２番１２号赤坂ノアビル７Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401136506',
    ),
    'E37218': EdinetCodeEntry(
        edinet_code='E37218',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河瀬\u3000航大',
        submitter_name_en=None,
        submitter_name_yomi='カワセ\u3000コウダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37220': EdinetCodeEntry(
        edinet_code='E37220',
        submitter_type='外国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='ＹＣＰホールディングス（グローバル）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ワイシーピーホールディングスグローバルリミテッド',
        address='シンガポール共和国、コーリヤー・キー２０、コーリヤ・キー２０＃１２－６',
        industry='外国法人・組合',
        sec_code='92570',
        corporate_number=None,
    ),
    'E37221': EdinetCodeEntry(
        edinet_code='E37221',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=64,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サクシード',
        submitter_name_en='Succeed co.,ltd.',
        submitter_name_yomi='カブシキガイシャサクシード',
        address='新宿区高田馬場一丁目４番１５号',
        industry='サービス業',
        sec_code='92560',
        corporate_number='7011101037139',
    ),
    'E37222': EdinetCodeEntry(
        edinet_code='E37222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=388,
        fiscal_year_end='3月31日',
        submitter_name='Ｉｎｓｔｉｔｕｔｉｏｎ\u3000ｆｏｒ\u3000ａ\u3000Ｇｌｏｂａｌ\u3000Ｓｏｃｉｅｔｙ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インスティテューションフォーアグローバルソサエティカブシキガイシャ',
        address='渋谷区恵比寿南一丁目１１番２号',
        industry='情報・通信業',
        sec_code='42650',
        corporate_number='8011001065180',
    ),
    'E37223': EdinetCodeEntry(
        edinet_code='E37223',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平岡\u3000秀一',
        submitter_name_en=None,
        submitter_name_yomi='ヒラオカ\u3000ヒデカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37224': EdinetCodeEntry(
        edinet_code='E37224',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='日本グローバル・グロース・パートナーズ・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='ニホングローバルグロースパートナーズマネジメントインク',
        address='１９８０１、デラウェア、ニューカッスルカウンティ、ウィルミントン、オレンジストリート１２０９、コーポレーショントラストセンター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37225': EdinetCodeEntry(
        edinet_code='E37225',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1977,
        fiscal_year_end=None,
        submitter_name='Ｒｅａｐｒａ\u3000Ｖｅｎｔｕｒｅｓ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='リープラベンチャーズピーティーイーリミテッド',
        address='３２８\u3000Ｎｏｔｒｈ\u3000Ｂｒｉｄｇｅ\u3000Ｒｏａｄ，＃０２－２０，Ｒａｆｆｌｅｓ\u3000Ｓｈｏｐｐｉｎｇ\u3000Ａｒｃａｄｅ\u3000Ｓｉｎｇａｐｏｒｅ\u3000１８８７１９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37226': EdinetCodeEntry(
        edinet_code='E37226',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鳥海\u3000裕二',
        submitter_name_en=None,
        submitter_name_yomi='トリウミ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37252': EdinetCodeEntry(
        edinet_code='E37252',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社サスティナ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサスティナ',
        address='渋谷区神南一丁目２３番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6210001000419',
    ),
    'E37262': EdinetCodeEntry(
        edinet_code='E37262',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000豊',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37264': EdinetCodeEntry(
        edinet_code='E37264',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社二村',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフタムラ',
        address='厚木市戸室三丁目１７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021001052539',
    ),
    'E37265': EdinetCodeEntry(
        edinet_code='E37265',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000和也',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37266': EdinetCodeEntry(
        edinet_code='E37266',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='冨永\u3000重寛',
        submitter_name_en=None,
        submitter_name_yomi='トミナガ\u3000シゲヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37267': EdinetCodeEntry(
        edinet_code='E37267',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='井上不動産有限会社',
        submitter_name_en=None,
        submitter_name_yomi='イノウエフドウサンユウゲンガイシャ',
        address='姫路市五軒邸二丁目１２８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5140002047500',
    ),
    'E37268': EdinetCodeEntry(
        edinet_code='E37268',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='早馬\u3000義光',
        submitter_name_en=None,
        submitter_name_yomi='ハヤマ\u3000ヨシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37269': EdinetCodeEntry(
        edinet_code='E37269',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='上野\u3000太郎',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37270': EdinetCodeEntry(
        edinet_code='E37270',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='株式会社でらゲー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャデラゲー',
        address='渋谷区渋谷三丁目６番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5013201018516',
    ),
    'E37272': EdinetCodeEntry(
        edinet_code='E37272',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='一般社団法人ラテールネクスト',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンラテールネクスト',
        address='港区虎ノ門４ー３ー１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405020173',
    ),
    'E37273': EdinetCodeEntry(
        edinet_code='E37273',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='一般社団法人コーセーマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンコーセーマネジメント',
        address='中央区銀座三丁目５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005033978',
    ),
    'E37274': EdinetCodeEntry(
        edinet_code='E37274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='一般社団法人ウッド',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンウッド',
        address='文京区白山二丁目２３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010005033979',
    ),
    'E37275': EdinetCodeEntry(
        edinet_code='E37275',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='一般社団法人ＭＹＭラボラトリーズ',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンエムワイエムラボラトリーズ',
        address='中央区銀座三丁目５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010005033980',
    ),
    'E37276': EdinetCodeEntry(
        edinet_code='E37276',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='フローバル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フローバルカブシキカイシャ',
        address='大阪市西区西本町１－１５－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001034550',
    ),
    'E37277': EdinetCodeEntry(
        edinet_code='E37277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大橋\u3000正興',
        submitter_name_en=None,
        submitter_name_yomi='オオハシ\u3000マサオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37278': EdinetCodeEntry(
        edinet_code='E37278',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社クロ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャクロ',
        address='渋谷区恵比寿三丁目３０番６号グレース恵比寿２０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011003007567',
    ),
    'E37279': EdinetCodeEntry(
        edinet_code='E37279',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000聡志',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37280': EdinetCodeEntry(
        edinet_code='E37280',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ｆｒｏｍ\u3000Ｂ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフロムビー',
        address='世田谷区尾山台二丁目１２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010901049207',
    ),
    'E37281': EdinetCodeEntry(
        edinet_code='E37281',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＡＭＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌエーエムシー',
        address='世田谷区尾山台二丁目１２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010901049206',
    ),
    'E37283': EdinetCodeEntry(
        edinet_code='E37283',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片貝\u3000哲太',
        submitter_name_en=None,
        submitter_name_yomi='カタカイ\u3000テツタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37285': EdinetCodeEntry(
        edinet_code='E37285',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡\u3000隆宏',
        submitter_name_en=None,
        submitter_name_yomi='オカタカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37287': EdinetCodeEntry(
        edinet_code='E37287',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='淵\u3000高晴',
        submitter_name_en=None,
        submitter_name_yomi='フチ\u3000タカハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37288': EdinetCodeEntry(
        edinet_code='E37288',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平良\u3000真人',
        submitter_name_en=None,
        submitter_name_yomi='タイラ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37290': EdinetCodeEntry(
        edinet_code='E37290',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6567,
        fiscal_year_end=None,
        submitter_name='グレニッチ・インベストメント・ホールディングズ・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='グレニッチインベストメントホールディングズピーティーイーリミテッド',
        address='シンガポール０６８８０８、シェントンウェイ５、ＵＩＣビルディング１３－０３号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37291': EdinetCodeEntry(
        edinet_code='E37291',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='吉岡\u3000裕之',
        submitter_name_en=None,
        submitter_name_yomi='ヨシオカ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37292': EdinetCodeEntry(
        edinet_code='E37292',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=203,
        fiscal_year_end='12月末日',
        submitter_name='Ｒｅｃｏｖｅｒｙ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ株式会社',
        submitter_name_en='Recovery International Co.,Ltd.',
        submitter_name_yomi='リカバリーインターナショナルカブシキガイシャ',
        address='東京都新宿区西新宿\u3000６－１６－１２\u3000第一丸善ビル６階',
        industry='サービス業',
        sec_code='92140',
        corporate_number='3011101068278',
    ),
    'E37294': EdinetCodeEntry(
        edinet_code='E37294',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='ＭＣＤ４株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムシーディーフォーカブシキカイシャ',
        address='千代田区丸の内一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001147005',
    ),
    'E37295': EdinetCodeEntry(
        edinet_code='E37295',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松岡\u3000馨',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37296': EdinetCodeEntry(
        edinet_code='E37296',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡田\u3000吉高',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37298': EdinetCodeEntry(
        edinet_code='E37298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高木\u3000毅',
        submitter_name_en=None,
        submitter_name_yomi='タカギ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37300': EdinetCodeEntry(
        edinet_code='E37300',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='春田\u3000真',
        submitter_name_en=None,
        submitter_name_yomi='ハルタ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37301': EdinetCodeEntry(
        edinet_code='E37301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='立川\u3000弘幸',
        submitter_name_en=None,
        submitter_name_yomi='タチカワ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37302': EdinetCodeEntry(
        edinet_code='E37302',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='Ｓｕｎｒｉｓｅ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ\u3000ＩＩＩ',
        submitter_name_en=None,
        submitter_name_yomi='サンライズマネージメントリミテッドスリー',
        address='ケイマン諸島\u3000ＫＹ１－１１０４\u3000グランドケイマン\u3000ジョージタウン、サウスチャーチストリート\u3000アグランドハウス\u3000私書箱３０９\u3000メイプルズ・コーポレート・サービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37303': EdinetCodeEntry(
        edinet_code='E37303',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='Ｓｕｎｒｉｓｅ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000（Ｎｏｎ－Ｕ．Ｓ．）\u3000Ｌｉｍｉｔｅｄ\u3000ＩＩＩ',
        submitter_name_en=None,
        submitter_name_yomi='サンライズマネージメントノンユーエスリミテッドスリー',
        address='ケイマン諸島\u3000ＫＹ１－１１０４\u3000グランドケイマン\u3000ジョージタウン、サウスチャーチストリート\u3000アグランドハウス\u3000私書箱３０９\u3000メイプルズ・コーポレート・サービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37304': EdinetCodeEntry(
        edinet_code='E37304',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=266,
        fiscal_year_end='12月末日',
        submitter_name='株式会社セイファート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセイファート',
        address='渋谷区渋谷三丁目２７番１１号',
        industry='サービス業',
        sec_code='92130',
        corporate_number='6011001043048',
    ),
    'E37309': EdinetCodeEntry(
        edinet_code='E37309',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='筒井\u3000幹治',
        submitter_name_en=None,
        submitter_name_yomi='ツツイ\u3000カンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37316': EdinetCodeEntry(
        edinet_code='E37316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='賀島義成',
        submitter_name_en=None,
        submitter_name_yomi='カシマヨシナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37318': EdinetCodeEntry(
        edinet_code='E37318',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='合同会社みやびマネージメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャミヤビマネージメント',
        address='港区赤坂２丁目１０番２号吉川ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010603006679',
    ),
    'E37319': EdinetCodeEntry(
        edinet_code='E37319',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ニフティ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニフティカブシキガイシャ',
        address='新宿区北新宿二丁目２１番１号\u3000新宿フロントタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101079619',
    ),
    'E37323': EdinetCodeEntry(
        edinet_code='E37323',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000智之',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37324': EdinetCodeEntry(
        edinet_code='E37324',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='Ｅｌｅｃｔｒｏｎｉｃ\u3000Ｇａｍｉｎｇ\u3000Ｄｅｖｅｌｏｐｍｅｎｔ\u3000Ｃｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='エレクトロニックゲーミングディベロップメントカンパニー',
        address='サウジアラビア王国、リヤド市、アサファラート地区、３０４４、アブドラ・アル・セハミーストリート、７６０５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37325': EdinetCodeEntry(
        edinet_code='E37325',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥脇\u3000隆司',
        submitter_name_en=None,
        submitter_name_yomi='オクワキ\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37326': EdinetCodeEntry(
        edinet_code='E37326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='亀井\u3000信吾',
        submitter_name_en=None,
        submitter_name_yomi='カメイ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37327': EdinetCodeEntry(
        edinet_code='E37327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000直也',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ナオヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37330': EdinetCodeEntry(
        edinet_code='E37330',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＳＳＫ－Ｖ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌエスエスケーブイ',
        address='港区愛宕２丁目５番１号愛宕グリーンヒルズＭＯＲＩタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401161085',
    ),
    'E37331': EdinetCodeEntry(
        edinet_code='E37331',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=280,
        fiscal_year_end=None,
        submitter_name='株式会社サタケ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサタケ',
        address='千代田区外神田４丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001017304',
    ),
    'E37332': EdinetCodeEntry(
        edinet_code='E37332',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中西\u3000良祐',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37333': EdinetCodeEntry(
        edinet_code='E37333',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='1月末日',
        submitter_name='モイ株式会社',
        submitter_name_en='Moi Corporation',
        submitter_name_yomi='モイカブシキガイシャ',
        address='文京区本郷一丁目３３番１３号',
        industry='情報・通信業',
        sec_code='50310',
        corporate_number='5010001145409',
    ),
    'E37344': EdinetCodeEntry(
        edinet_code='E37344',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＯＳＡフィールド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーエスーエフィールドカブシキガイシャ',
        address='京都市伏見区向島中島町５２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130001050005',
    ),
    'E37345': EdinetCodeEntry(
        edinet_code='E37345',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='黒木\u3000哲史',
        submitter_name_en=None,
        submitter_name_yomi='クロギ\u3000テツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37348': EdinetCodeEntry(
        edinet_code='E37348',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000整一',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37349': EdinetCodeEntry(
        edinet_code='E37349',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石田\u3000晃太',
        submitter_name_en=None,
        submitter_name_yomi='イシダ\u3000コウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37351': EdinetCodeEntry(
        edinet_code='E37351',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='長島\u3000宏',
        submitter_name_en=None,
        submitter_name_yomi='ナガシマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37352': EdinetCodeEntry(
        edinet_code='E37352',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社エヌズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌズ',
        address='世田谷区代沢１－３６－２７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010901048936',
    ),
    'E37353': EdinetCodeEntry(
        edinet_code='E37353',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社Ｃａｔａｌｙｓｔ・Ｄａｔａ・Ｐａｒｔｎｅｒｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカタリストデータパートナーズ',
        address='横浜市西区みなとみらい三丁目３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001109438',
    ),
    'E37356': EdinetCodeEntry(
        edinet_code='E37356',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000太',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000フトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37358': EdinetCodeEntry(
        edinet_code='E37358',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=142,
        fiscal_year_end='1月末日',
        submitter_name='株式会社ライトワークス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャライトワークス',
        address='千代田区麹町五丁目３番３号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010001084197',
    ),
    'E37359': EdinetCodeEntry(
        edinet_code='E37359',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='Ｂｅｙｏｎｄ\u3000Ｎｅｘｔ\u3000Ｖｅｎｔｕｒｅｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビヨンドネクストベンチャーズカブシキガイシャ',
        address='中央区日本橋本町三丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001162465',
    ),
    'E37365': EdinetCodeEntry(
        edinet_code='E37365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000健史',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37366': EdinetCodeEntry(
        edinet_code='E37366',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙品\u3000政明',
        submitter_name_en=None,
        submitter_name_yomi='タカシナ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37369': EdinetCodeEntry(
        edinet_code='E37369',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福原\u3000正大',
        submitter_name_en=None,
        submitter_name_yomi='フクハラ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37371': EdinetCodeEntry(
        edinet_code='E37371',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡田\u3000令奈',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000レイナ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37372': EdinetCodeEntry(
        edinet_code='E37372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000喆成',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000タカナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37373': EdinetCodeEntry(
        edinet_code='E37373',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000才成',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000トシナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37374': EdinetCodeEntry(
        edinet_code='E37374',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木\u3000佑也',
        submitter_name_en=None,
        submitter_name_yomi='ミキ\u3000ユウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37375': EdinetCodeEntry(
        edinet_code='E37375',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ｉＳＧＳインベストメントワークス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイエスジーエスインベストメントワークス',
        address='港区赤坂一丁目１２番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401125203',
    ),
    'E37376': EdinetCodeEntry(
        edinet_code='E37376',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='Ａｓｏ\u3000Ｇｒｏｕｐ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='アソグループリミテッド',
        address='３ｒｄ\u3000Ｆｌｏｏｒ\u3000Ｊ＆Ｃ\u3000Ｂｕｉｌｄｉｎｇ\u3000Ｒｏａｄ\u3000Ｔｏｗｎ\u3000Ｔｏｒｔｏｌａ\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37377': EdinetCodeEntry(
        edinet_code='E37377',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小泉始',
        submitter_name_en=None,
        submitter_name_yomi='コイズミハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37378': EdinetCodeEntry(
        edinet_code='E37378',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｈ＆Ｔコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチアンドティーコーポレーション',
        address='東京都港区虎ノ門四丁目３番２０号神谷町ＭＴビル１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401116306',
    ),
    'E37380': EdinetCodeEntry(
        edinet_code='E37380',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＴＲＡＮ\u3000ＶＡＮ\u3000ＭＩＮＨ',
        submitter_name_en=None,
        submitter_name_yomi='チャン\u3000バン\u3000ミン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37381': EdinetCodeEntry(
        edinet_code='E37381',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＩＮＯ\u3000ＰＲＩＤＥ\u3000ＶＥＮＴＵＲＥＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シノ\u3000プライド\u3000ベンチャーズ\u3000リミテッド',
        address='イギリス領ヴァージン諸島、トルトラ島、ロードタウン、クレイグミュア・チェンバース、ＶＧ１１１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37382': EdinetCodeEntry(
        edinet_code='E37382',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='粕本\u3000晋吾',
        submitter_name_en=None,
        submitter_name_yomi='カスモト\u3000シンゴ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37383': EdinetCodeEntry(
        edinet_code='E37383',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=987,
        fiscal_year_end=None,
        submitter_name='Ｙ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ワイアセットマネジメントリミテッド',
        address='香港、コーズウェイベイ、ハイサンアベニュー３３、リーガーデンワン４６階、１３３号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37384': EdinetCodeEntry(
        edinet_code='E37384',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=101,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＣＭＡアルファ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチシーエムエーアルファ',
        address='豊島区西池袋一丁目４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5013301046920',
    ),
    'E37385': EdinetCodeEntry(
        edinet_code='E37385',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳\u3000忍',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギ\u3000シノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37386': EdinetCodeEntry(
        edinet_code='E37386',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柳\u3000均',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37387': EdinetCodeEntry(
        edinet_code='E37387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳\u3000至',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギ\u3000イタル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37389': EdinetCodeEntry(
        edinet_code='E37389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅澤\u3000康二',
        submitter_name_en=None,
        submitter_name_yomi='ウメザワ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37390': EdinetCodeEntry(
        edinet_code='E37390',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='工藤\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='クドウ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37391': EdinetCodeEntry(
        edinet_code='E37391',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小迫\u3000宏行',
        submitter_name_en=None,
        submitter_name_yomi='コサコ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37392': EdinetCodeEntry(
        edinet_code='E37392',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='谷口\u3000辰成',
        submitter_name_en=None,
        submitter_name_yomi='タニグチ\u3000タツナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37394': EdinetCodeEntry(
        edinet_code='E37394',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='丸尾\u3000治男',
        submitter_name_en=None,
        submitter_name_yomi='マルオ\u3000ハルオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37397': EdinetCodeEntry(
        edinet_code='E37397',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=243,
        fiscal_year_end='2月末日',
        submitter_name='株式会社マーキュリー',
        submitter_name_en='MERCURY Inc.',
        submitter_name_yomi='カブシキガイシャマーキュリー',
        address='新宿区西新宿二丁目６番１号',
        industry='情報・通信業',
        sec_code='50250',
        corporate_number='7011101040753',
    ),
    'E37398': EdinetCodeEntry(
        edinet_code='E37398',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=95,
        fiscal_year_end='4月末日',
        submitter_name='エッジテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エッジテクノロジーカブシキカイシャ',
        address='千代田区神田須田町一丁目３２番地７\u3000クレス不動産神田ビル５階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='9010401111881',
    ),
    'E37399': EdinetCodeEntry(
        edinet_code='E37399',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=692,
        fiscal_year_end='5月末日',
        submitter_name='ビーウィズ株式会社',
        submitter_name_en='Bewith, Inc.',
        submitter_name_yomi='ビーウィズカブシキガイシャ',
        address='東京都新宿区西新宿３－７－１\u3000新宿パークタワーＮ棟３２Ｆ',
        industry='サービス業',
        sec_code='92160',
        corporate_number='6011101029715',
    ),
    'E37401': EdinetCodeEntry(
        edinet_code='E37401',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=178,
        fiscal_year_end=None,
        submitter_name='シャンハイ・アライアンス・ファイナンシャル・サービシズ・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='シャンハイアライアンスファイナンシャルサービシズカンパニーリミテッド',
        address='中華人民共和国２００２４１上海市閔行区東川路５５５号乙楼２０４２室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37402': EdinetCodeEntry(
        edinet_code='E37402',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ミネルバ・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='ミネルバマネジメントインク',
        address='アメリカ合衆国ハワイ州ホノルル、プコロア・ストリート２８５０、＃３００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37404': EdinetCodeEntry(
        edinet_code='E37404',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福井\u3000英治',
        submitter_name_en=None,
        submitter_name_yomi='フクイ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37405': EdinetCodeEntry(
        edinet_code='E37405',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤原\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='フジワラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37406': EdinetCodeEntry(
        edinet_code='E37406',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｓｈｏｗｃａｓｅ\u3000Ｃａｐｉｔａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャショーケースキャピタル',
        address='港区六本木一丁目９番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401133223',
    ),
    'E37407': EdinetCodeEntry(
        edinet_code='E37407',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＳＯＬＴＥＣ\u3000ＩＮＶＥＳＴＭＥＮＴＳ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ソルテックインベストメンツユウゲンセキニンカイシャ',
        address='１０\u3000ＡＮＳＯＮ\u3000ＲＯＡＤ，\u3000＃１４－０６\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＰＬＡＺＡ\u3000ＳＩＮＧＡＰＯＲＥ\u3000（０７９９０３）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37408': EdinetCodeEntry(
        edinet_code='E37408',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松倉\u3000喜一',
        submitter_name_en=None,
        submitter_name_yomi='マツクラ\u3000キイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37410': EdinetCodeEntry(
        edinet_code='E37410',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='タイヨウ・パシフィック・パートナーズ・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウパシフィックパートナーズエルピー',
        address='アメリカ合衆国、ワシントン州９８０３３、カークランド、キャリロンポイント５３００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37412': EdinetCodeEntry(
        edinet_code='E37412',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社プロクレアホールディングス',
        submitter_name_en='Procrea Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャプロクレアホールディングス',
        address='青森市勝田一丁目３番１号',
        industry='銀行業',
        sec_code='73840',
        corporate_number='3420001017799',
    ),
    'E37413': EdinetCodeEntry(
        edinet_code='E37413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='椙原\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='スギノハラ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37415': EdinetCodeEntry(
        edinet_code='E37415',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000有希子',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ユキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37416': EdinetCodeEntry(
        edinet_code='E37416',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金井\u3000正義',
        submitter_name_en=None,
        submitter_name_yomi='カナイ\u3000マサヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37419': EdinetCodeEntry(
        edinet_code='E37419',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=302,
        fiscal_year_end='12月末日',
        submitter_name='株式会社イメージ・マジック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイメージマジック',
        address='文京区小石川一丁目３番１１号',
        industry='その他製品',
        sec_code='77930',
        corporate_number='4030001059302',
    ),
    'E37420': EdinetCodeEntry(
        edinet_code='E37420',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='江口\u3000夏郎',
        submitter_name_en=None,
        submitter_name_yomi='エグチ\u3000ナツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37421': EdinetCodeEntry(
        edinet_code='E37421',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='税理士法人ＮＹ\u3000Ａｃｃｏｕｎｔｉｎｇ\u3000Ｐａｒｔｎｅｒｓ',
        submitter_name_en=None,
        submitter_name_yomi='ゼイリシホウジンエヌワイアカウンティングパートナーズ',
        address='千代田区九段北４丁目３番２６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011205001970',
    ),
    'E37425': EdinetCodeEntry(
        edinet_code='E37425',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000保',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000タモツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37426': EdinetCodeEntry(
        edinet_code='E37426',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩永\u3000泰典',
        submitter_name_en=None,
        submitter_name_yomi='イワナガ\u3000ヤスノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37428': EdinetCodeEntry(
        edinet_code='E37428',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='船野\u3000智輝',
        submitter_name_en=None,
        submitter_name_yomi='フナノ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37429': EdinetCodeEntry(
        edinet_code='E37429',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=74,
        fiscal_year_end=None,
        submitter_name='株式会社スケブベンチャーズ',
        submitter_name_en=None,
        submitter_name_yomi='スケブベンチャーズ',
        address='港区南青山五丁目１１番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120101046302',
    ),
    'E37431': EdinetCodeEntry(
        edinet_code='E37431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＷＣＰ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダブルシーピー',
        address='東京都港区虎ノ門五丁目１１番２号オランダヒルズ森タワー１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401143381',
    ),
    'E37432': EdinetCodeEntry(
        edinet_code='E37432',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=158,
        fiscal_year_end='11月30日',
        submitter_name='株式会社ＣａＳｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカジー',
        address='品川区上大崎三丁目５番１１号',
        industry='サービス業',
        sec_code='92150',
        corporate_number='6010001158418',
    ),
    'E37434': EdinetCodeEntry(
        edinet_code='E37434',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='橋本\u3000正徳',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37435': EdinetCodeEntry(
        edinet_code='E37435',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ヌーラボ',
        submitter_name_en='Nulab Inc.',
        submitter_name_yomi='カブシキガイシャヌーラボ',
        address='福岡市中央区大名一丁目８番６号',
        industry='サービス業',
        sec_code='50330',
        corporate_number='7290001026389',
    ),
    'E37437': EdinetCodeEntry(
        edinet_code='E37437',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＣＪＩホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチシージェイアイホールディングスカブシキカイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003036629',
    ),
    'E37439': EdinetCodeEntry(
        edinet_code='E37439',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000助三郎',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000スケサブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37440': EdinetCodeEntry(
        edinet_code='E37440',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木村\u3000友彦',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000トモヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37443': EdinetCodeEntry(
        edinet_code='E37443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安江\u3000由奈',
        submitter_name_en=None,
        submitter_name_yomi='ヤスエ\u3000ユナ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37445': EdinetCodeEntry(
        edinet_code='E37445',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='ＦＣＪ\u3000１\u3000ＣＯ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='エフシージェイワンカンパニーリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、アグランド・ハウス、私書箱３０９、メイプルズ・コーポレートサービシズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37449': EdinetCodeEntry(
        edinet_code='E37449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社多喜川カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタキガワカンパニー',
        address='豊島区上池袋一丁目３７番２２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3013301045726',
    ),
    'E37450': EdinetCodeEntry(
        edinet_code='E37450',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ビューティープロスペリティ―',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビューティープロスペリティー',
        address='世田谷区駒沢一丁目７番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001043047',
    ),
    'E37454': EdinetCodeEntry(
        edinet_code='E37454',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社名南経営ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャメイナンケイエイホールディングス',
        address='名古屋市中村区名駅一丁目１番１号ＪＰタワー名古屋',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001108606',
    ),
    'E37455': EdinetCodeEntry(
        edinet_code='E37455',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=895,
        fiscal_year_end=None,
        submitter_name='ジェイレックス・コーポレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイレックスコーポレーションカブシキカイシャ',
        address='新宿区西新宿一丁目２３番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101036202',
    ),
    'E37456': EdinetCodeEntry(
        edinet_code='E37456',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=447,
        fiscal_year_end='2月末日',
        submitter_name='株式会社セレコーポレーション',
        submitter_name_en='CEL Corporation',
        submitter_name_yomi='カブシキガイシャセレコーポレーション',
        address='中央区京橋三丁目７番１号\u3000相互館１１０タワー５階',
        industry='不動産業',
        sec_code='50780',
        corporate_number='5010401048987',
    ),
    'E37457': EdinetCodeEntry(
        edinet_code='E37457',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=188,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＴＯＲＩＣＯ',
        submitter_name_en='TORICO Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャトリコ',
        address='千代田区九段南二丁目１番３０号',
        industry='小売業',
        sec_code='71380',
        corporate_number='5011201010526',
    ),
    'E37458': EdinetCodeEntry(
        edinet_code='E37458',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=671,
        fiscal_year_end='8月末日',
        submitter_name='株式会社トリプルアイズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトリプルアイズ',
        address='港区芝浦三丁目４番１号グランパークタワー３２階',
        industry='情報・通信業',
        sec_code='50260',
        corporate_number='3011001072652',
    ),
    'E37459': EdinetCodeEntry(
        edinet_code='E37459',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＩＣグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオイシーグループ',
        address='川崎市幸区南幸町２丁目９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9021001002330',
    ),
    'E37462': EdinetCodeEntry(
        edinet_code='E37462',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊住\u3000満',
        submitter_name_en=None,
        submitter_name_yomi='トヨズミ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37463': EdinetCodeEntry(
        edinet_code='E37463',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山科\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシナ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37464': EdinetCodeEntry(
        edinet_code='E37464',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社日の出',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒノデ',
        address='名古屋市昭和区高辻町６番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001149311',
    ),
    'E37465': EdinetCodeEntry(
        edinet_code='E37465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中前\u3000真理子',
        submitter_name_en=None,
        submitter_name_yomi='ナカマエ\u3000マリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37466': EdinetCodeEntry(
        edinet_code='E37466',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=600,
        fiscal_year_end='12月31日',
        submitter_name='ＡｎｙＭｉｎｄ\u3000Ｇｒｏｕｐ株式会社',
        submitter_name_en='AnyMind Group Inc.',
        submitter_name_yomi='エニーマインドグループカブシキカイシャ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー３１階',
        industry='情報・通信業',
        sec_code='50270',
        corporate_number='7010401150205',
    ),
    'E37467': EdinetCodeEntry(
        edinet_code='E37467',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='立花\u3000充',
        submitter_name_en=None,
        submitter_name_yomi='タチバナ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37468': EdinetCodeEntry(
        edinet_code='E37468',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1227,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ノバック',
        submitter_name_en='NOVAC CO., LTD.',
        submitter_name_yomi='カブシキガイシャノバック',
        address='姫路市北条１丁目９２番地',
        industry='建設業',
        sec_code='50790',
        corporate_number='4140001058111',
    ),
    'E37470': EdinetCodeEntry(
        edinet_code='E37470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000伸也',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37471': EdinetCodeEntry(
        edinet_code='E37471',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社玉光堂',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャギョッコウドウ',
        address='港区虎ノ門四丁目１番４０号江戸見坂森ビル４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401076220',
    ),
    'E37472': EdinetCodeEntry(
        edinet_code='E37472',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='株式会社鈴木商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスズキショウテン',
        address='港区南麻布五丁目２番５号ザ・ハウス南麻布１０１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020002078578',
    ),
    'E37476': EdinetCodeEntry(
        edinet_code='E37476',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社クロノス・インターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクロノスインターナショナル',
        address='港区新橋五丁目２７番１号新橋パークプレイスビル２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401008809',
    ),
    'E37482': EdinetCodeEntry(
        edinet_code='E37482',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=231,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ファインズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャファインズ',
        address='港区芝浦一丁目２番１号\u3000シーバンスＮ館１９階',
        industry='情報・通信業',
        sec_code='51250',
        corporate_number='2011001127135',
    ),
    'E37484': EdinetCodeEntry(
        edinet_code='E37484',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ウェブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウェブ',
        address='市川市南行徳１－１６－２２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1040001028424',
    ),
    'E37485': EdinetCodeEntry(
        edinet_code='E37485',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＧＣホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーシーホールディングスカブシキカイシャ',
        address='千代田区丸の内一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001223972',
    ),
    'E37486': EdinetCodeEntry(
        edinet_code='E37486',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アルテジェネシス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルテジェネシス',
        address='横浜市中区翁町一丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001144790',
    ),
    'E37487': EdinetCodeEntry(
        edinet_code='E37487',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＪフューチャーホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスジェイフューチャーホールディングスカブシキガイシャ',
        address='品川区東品川二丁目４番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001221585',
    ),
    'E37488': EdinetCodeEntry(
        edinet_code='E37488',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=14138,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＯＫＵＳＡＩ\u3000ＥＬＥＣＴＲＩＣ',
        submitter_name_en='KOKUSAI ELECTRIC CORPORATION',
        submitter_name_yomi='カブシキガイシャコクサイエレクトリック',
        address='東京都千代田区神田鍛冶町三丁目４番地ｏａｋ神田鍛冶町ビル５階',
        industry='電気機器',
        sec_code='65250',
        corporate_number='4010003024801',
    ),
    'E37489': EdinetCodeEntry(
        edinet_code='E37489',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='柴田\u3000旬也',
        submitter_name_en=None,
        submitter_name_yomi='シバタ\u3000ジュンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37490': EdinetCodeEntry(
        edinet_code='E37490',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大河原\u3000峻',
        submitter_name_en=None,
        submitter_name_yomi='オオカワラ\u3000シュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37491': EdinetCodeEntry(
        edinet_code='E37491',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='町田\u3000正一',
        submitter_name_en=None,
        submitter_name_yomi='マチダ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37493': EdinetCodeEntry(
        edinet_code='E37493',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社南條商店',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャナンジョウショウテン',
        address='須賀川市狸森字下竹ノ内９番地８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9050002006585',
    ),
    'E37494': EdinetCodeEntry(
        edinet_code='E37494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='南條\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='ナンジョウ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37496': EdinetCodeEntry(
        edinet_code='E37496',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社デベロップ・ナビゲーター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデベロップナビゲーター',
        address='川口市末広３ー１ー１４ー２０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011101061139',
    ),
    'E37498': EdinetCodeEntry(
        edinet_code='E37498',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57,
        fiscal_year_end=None,
        submitter_name='ウィッシュボーンマネジメント\u3000リミテッド・パートナーシップ',
        submitter_name_en=None,
        submitter_name_yomi='ウィッシュボーンマネジメント\u3000リミテッド\u3000パートナーシップ',
        address='４４４\u3000ウェストレイクストリート\u3000４９階\u3000シカゴ\u3000イリノイ州\u3000６０６０６\u3000ユーエスエー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37499': EdinetCodeEntry(
        edinet_code='E37499',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1079,
        fiscal_year_end='3月31日',
        submitter_name='守谷輸送機工業株式会社',
        submitter_name_en='Moriya Transportation Engineering and Manufacturing Co.,Ltd',
        submitter_name_yomi='モリヤユソウキコウギョウカブシキカイシャ',
        address='横浜市金沢区福浦一丁目１４番地９',
        industry='機械',
        sec_code='62260',
        corporate_number='8020001010674',
    ),
    'E37501': EdinetCodeEntry(
        edinet_code='E37501',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＨＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエーエイチシー',
        address='金沢市上堤町１番３５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4220001024666',
    ),
    'E37502': EdinetCodeEntry(
        edinet_code='E37502',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='11月末日',
        submitter_name='株式会社アスマーク',
        submitter_name_en='ASMARQ Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャアスマーク',
        address='渋谷区東１－３２－１２渋谷プロパティータワー４Ｆ',
        industry='情報・通信業',
        sec_code='41970',
        corporate_number='2010901015886',
    ),
    'E37504': EdinetCodeEntry(
        edinet_code='E37504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1298,
        fiscal_year_end='3月31日',
        submitter_name='クリアル株式会社',
        submitter_name_en='CREAL Inc.',
        submitter_name_yomi='クリアルカブシキカイシャ',
        address='港区新橋二丁目１２番１１号',
        industry='不動産業',
        sec_code='29980',
        corporate_number='3010401093663',
    ),
    'E37505': EdinetCodeEntry(
        edinet_code='E37505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='胡桃沢\u3000精一',
        submitter_name_en=None,
        submitter_name_yomi='クルミザワ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37506': EdinetCodeEntry(
        edinet_code='E37506',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=340,
        fiscal_year_end='12月末日',
        submitter_name='セカンドサイトアナリティカ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セカンドサイトアナリティカカブシキガイシャ',
        address='千代田区神田西福田町３番地',
        industry='情報・通信業',
        sec_code='50280',
        corporate_number='1010001176151',
    ),
    'E37508': EdinetCodeEntry(
        edinet_code='E37508',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=459,
        fiscal_year_end='12月31日',
        submitter_name='株式会社メンタルヘルステクノロジーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメンタルヘルステクノロジーズ',
        address='赤坂３－１６－１１東海赤坂ビル４階',
        industry='情報・通信業',
        sec_code='92180',
        corporate_number='2010701026514',
    ),
    'E37512': EdinetCodeEntry(
        edinet_code='E37512',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=19230,
        fiscal_year_end=None,
        submitter_name='ピーエー・エース・フォー（エイチケー）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ピーエー\u3000エース\u3000フォー\u3000エイチケー\u3000リミテッド',
        address='香港、セントラル、８コノート・プレイス、スリー・エクスチェンジ・スクエア、２６階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37515': EdinetCodeEntry(
        edinet_code='E37515',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小倉クラッチ取引先持株会\u3000理事長\u3000五十嵐\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='オグラクラッチトリヒキサキモチカブカイ\u3000リジチョウ\u3000イガラシ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37518': EdinetCodeEntry(
        edinet_code='E37518',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=834,
        fiscal_year_end=None,
        submitter_name='ライオントラスト・インベストメント・パートナーズ・エル・エル・ピー',
        submitter_name_en=None,
        submitter_name_yomi='ライオントラスト\u3000インベストメント\u3000パートナーズ\u3000エル\u3000エル\u3000ピー',
        address='ロンドン、ＷＣ２Ｒ０ＥＺサボイ\u3000コート２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37519': EdinetCodeEntry(
        edinet_code='E37519',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000昌子',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000マサコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37520': EdinetCodeEntry(
        edinet_code='E37520',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000賢治',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37523': EdinetCodeEntry(
        edinet_code='E37523',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=496,
        fiscal_year_end='3月31日',
        submitter_name='エフビー介護サービス株式会社',
        submitter_name_en='FB CARE SERVICE  CO.,LTD.',
        submitter_name_yomi='エフビーカイゴサービスカブシキカイシャ',
        address='佐久市長土呂１５９番地２',
        industry='サービス業',
        sec_code='92200',
        corporate_number='2100001007791',
    ),
    'E37529': EdinetCodeEntry(
        edinet_code='E37529',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大村\u3000日出雄',
        submitter_name_en=None,
        submitter_name_yomi='オオムラ\u3000ヒデオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37533': EdinetCodeEntry(
        edinet_code='E37533',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福原\u3000聖子',
        submitter_name_en=None,
        submitter_name_yomi='フクハラ\u3000セイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37534': EdinetCodeEntry(
        edinet_code='E37534',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000裕樹',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37536': EdinetCodeEntry(
        edinet_code='E37536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加茂\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='カモ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37537': EdinetCodeEntry(
        edinet_code='E37537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='住本\u3000幸士',
        submitter_name_en=None,
        submitter_name_yomi='スミモト\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37538': EdinetCodeEntry(
        edinet_code='E37538',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田端\u3000辰輔',
        submitter_name_en=None,
        submitter_name_yomi='タバタ\u3000シンスケ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37540': EdinetCodeEntry(
        edinet_code='E37540',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='ワタキューセイモア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワタキューセイモアカブシキガイシャ',
        address='綴喜郡井手町大字多賀小字茶臼塚１２－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7130001037872',
    ),
    'E37542': EdinetCodeEntry(
        edinet_code='E37542',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='広木\u3000太',
        submitter_name_en=None,
        submitter_name_yomi='ヒロキ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37543': EdinetCodeEntry(
        edinet_code='E37543',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='株式会社コスモウエア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコスモウエア',
        address='墨田区錦糸一丁目２番１号\u3000アルカセントラル１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011801031475',
    ),
    'E37544': EdinetCodeEntry(
        edinet_code='E37544',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=106,
        fiscal_year_end=None,
        submitter_name='株式会社ダイコーホールディングスグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャダイコーホールディングスグループ',
        address='中央区日本橋茅場町１－１３－２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001135083',
    ),
    'E37545': EdinetCodeEntry(
        edinet_code='E37545',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菅原\u3000智美',
        submitter_name_en=None,
        submitter_name_yomi='スガワラ\u3000トモミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37546': EdinetCodeEntry(
        edinet_code='E37546',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=286,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ギックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャギックス',
        address='港区三田一丁目４－２８三田国際ビル２階',
        industry='サービス業',
        sec_code='92190',
        corporate_number='8011001092828',
    ),
    'E37547': EdinetCodeEntry(
        edinet_code='E37547',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山内\u3000正隆',
        submitter_name_en=None,
        submitter_name_yomi='ヤマウチ\u3000マサタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37548': EdinetCodeEntry(
        edinet_code='E37548',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='袴田\u3000武史',
        submitter_name_en=None,
        submitter_name_yomi='ハカマダ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37549': EdinetCodeEntry(
        edinet_code='E37549',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='陣\u3000隆浩',
        submitter_name_en=None,
        submitter_name_yomi='ジン\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37550': EdinetCodeEntry(
        edinet_code='E37550',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='板倉公洋',
        submitter_name_en=None,
        submitter_name_yomi='イタクラ\u3000タダヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37551': EdinetCodeEntry(
        edinet_code='E37551',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='玉置\u3000義議',
        submitter_name_en=None,
        submitter_name_yomi='タマキ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37554': EdinetCodeEntry(
        edinet_code='E37554',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社山西',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマニシ',
        address='名古屋市中区千代田２－１－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001041630',
    ),
    'E37558': EdinetCodeEntry(
        edinet_code='E37558',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＩＮＸ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジンクス',
        address='新宿区西新宿６丁目１５番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001104354',
    ),
    'E37559': EdinetCodeEntry(
        edinet_code='E37559',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ハマダグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハマダグループ',
        address='姫路市網干区新在家１２６１－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140001124181',
    ),
    'E37560': EdinetCodeEntry(
        edinet_code='E37560',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1497,
        fiscal_year_end='3月31日',
        submitter_name='フルハシＥＰＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フルハシイーピーオーカブシキガイシャ',
        address='名古屋市中区金山一丁目１３番１３号',
        industry='サービス業',
        sec_code='92210',
        corporate_number='3180001022733',
    ),
    'E37563': EdinetCodeEntry(
        edinet_code='E37563',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='インフォメティス株式会社',
        submitter_name_en='Informetis Co., Ltd.',
        submitter_name_yomi='インフォメティスカブシキガイシャ',
        address='港区芝公園一丁目８番２０号',
        industry='情報・通信業',
        sec_code='281A0',
        corporate_number='2010401105122',
    ),
    'E37567': EdinetCodeEntry(
        edinet_code='E37567',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=941712,
        fiscal_year_end='12月31日',
        submitter_name='ダウ・インク',
        submitter_name_en=None,
        submitter_name_yomi='ダウインク',
        address='アメリカ合衆国\u3000４８６７４\u3000ミシガン州、ミッドランド、Ｈ．Ｈ．ダウ・ウェイ２２１１',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E37568': EdinetCodeEntry(
        edinet_code='E37568',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='ＵＢＥ三菱セメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユービーイーミツビシセメントカブシキガイシャ',
        address='千代田区内幸町二丁目１番１号（飯野ビルディング）',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001217516',
    ),
    'E37569': EdinetCodeEntry(
        edinet_code='E37569',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='巽\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='タツミ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37571': EdinetCodeEntry(
        edinet_code='E37571',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000智康',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000トモヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37572': EdinetCodeEntry(
        edinet_code='E37572',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=701142,
        fiscal_year_end='12月31日',
        submitter_name='アルナイラム・ファーマシューティカルズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='アルナイラムファーマシューティカルズインク',
        address='アメリカ合衆国０２１４２マサチューセッツ州ケンブリッジ、ヘンリーＡ．ターミアースクエア、ウェストケンダルストリート６７５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E37573': EdinetCodeEntry(
        edinet_code='E37573',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=104,
        fiscal_year_end='4月30日',
        submitter_name='ＡＮＹＣＯＬＯＲ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エニーカラーカブシキガイシャ',
        address='港区赤坂９丁目７番２号ミッドタウン・イースト１１階',
        industry='サービス業',
        sec_code='50320',
        corporate_number='7011101080460',
    ),
    'E37574': EdinetCodeEntry(
        edinet_code='E37574',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='京田\u3000諭',
        submitter_name_en=None,
        submitter_name_yomi='キョウダ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37575': EdinetCodeEntry(
        edinet_code='E37575',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社三津原興産',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャミツハラコウサン',
        address='港区西麻布四丁目１９番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401154201',
    ),
    'E37576': EdinetCodeEntry(
        edinet_code='E37576',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000譲治',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ジョウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37577': EdinetCodeEntry(
        edinet_code='E37577',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='12月31日',
        submitter_name='ウェルビングループ株式会社',
        submitter_name_en='WELLBIN GROUP CO.,Ltd.',
        submitter_name_yomi='ウェルビングループカブシキガイシャ',
        address='所沢市坂之下１７－１',
        industry='小売業',
        sec_code='71360',
        corporate_number='4030001135706',
    ),
    'E37579': EdinetCodeEntry(
        edinet_code='E37579',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18,
        fiscal_year_end=None,
        submitter_name='有限会社濱重興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャハマジュウコウサン',
        address='姫路市白浜町甲７７０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6140002050206',
    ),
    'E37581': EdinetCodeEntry(
        edinet_code='E37581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='刀禰\u3000真之介',
        submitter_name_en=None,
        submitter_name_yomi='トネ\u3000シンノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37582': EdinetCodeEntry(
        edinet_code='E37582',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山川\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37584': EdinetCodeEntry(
        edinet_code='E37584',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3191,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ｉｓｐａｃｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイスペース',
        address='中央区日本橋浜町３－４２－３\u3000住友不動産浜町ビル３階',
        industry='輸送用機器',
        sec_code='93480',
        corporate_number='3030003001527',
    ),
    'E37587': EdinetCodeEntry(
        edinet_code='E37587',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ネプチューンキャピタルインベスターエルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ネプチューンキャピタルインベスターエルエルシー',
        address='アメリカ合衆国デラウェア州、ニューキャッスル郡、ウィルミントン、リトル・フォールス・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37589': EdinetCodeEntry(
        edinet_code='E37589',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=279,
        fiscal_year_end='3月31日',
        submitter_name='ペットゴー株式会社',
        submitter_name_en='Petgo Corporation',
        submitter_name_yomi='ペットゴーカブシキカイシャ',
        address='中野区本町一丁目３２番２号',
        industry='小売業',
        sec_code='71400',
        corporate_number='4011101038288',
    ),
    'E37590': EdinetCodeEntry(
        edinet_code='E37590',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＡＩＣサステナブル合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ナイクサステナブルゴウドウガイシャ',
        address='いわき市泉町滝尻字前坪４２－１\u3000ＯＳプラザ２階２０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010003032464',
    ),
    'E37591': EdinetCodeEntry(
        edinet_code='E37591',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小林\u3000保一',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ヤスカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37594': EdinetCodeEntry(
        edinet_code='E37594',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ドウメキエンタープライズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャドウメキエンタープライズ',
        address='日立市弁天町一丁目２１番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9050001023441',
    ),
    'E37595': EdinetCodeEntry(
        edinet_code='E37595',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=261,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ストレージ王',
        submitter_name_en='STORAGE-OH Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャストレージオウ',
        address='市川市市川南１丁目９－２３',
        industry='不動産業',
        sec_code='29970',
        corporate_number='3260001012107',
    ),
    'E37598': EdinetCodeEntry(
        edinet_code='E37598',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='アトミクス持株会\u3000理事長\u3000大井明朗',
        submitter_name_en=None,
        submitter_name_yomi='アトミクスモチカブカイ\u3000リジチョウ\u3000オオイアキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37602': EdinetCodeEntry(
        edinet_code='E37602',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='グレイハウンド・キャピタル・マネジメント・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='グレイハウンド\u3000キャピタル\u3000マネジメント\u3000エルエルピー',
        address='２５\u3000セント・ジェームズ・ストリート、ロンドン、イングランド、ＳＷ１Ａ\u3000１ＨＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37603': EdinetCodeEntry(
        edinet_code='E37603',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=408,
        fiscal_year_end='3月31日',
        submitter_name='サークレイス株式会社',
        submitter_name_en='circlace Inc',
        submitter_name_yomi='サークレイスカブシキガイシャ',
        address='中央区日本橋二丁目１番３号',
        industry='情報・通信業',
        sec_code='50290',
        corporate_number='5010001150061',
    ),
    'E37604': EdinetCodeEntry(
        edinet_code='E37604',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='菅原\u3000源一郎',
        submitter_name_en=None,
        submitter_name_yomi='スガワラ\u3000ゲンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37605': EdinetCodeEntry(
        edinet_code='E37605',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='濵\u3000芽久実',
        submitter_name_en=None,
        submitter_name_yomi='ハマ\u3000メグミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37606': EdinetCodeEntry(
        edinet_code='E37606',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='守谷\u3000貞夫',
        submitter_name_en=None,
        submitter_name_yomi='モリヤ\u3000サダオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37612': EdinetCodeEntry(
        edinet_code='E37612',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橋本\u3000欣典',
        submitter_name_en=None,
        submitter_name_yomi='ハシモト\u3000ヨシノリ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37613': EdinetCodeEntry(
        edinet_code='E37613',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社シンシア工務店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンシアコウムテン',
        address='千葉市若葉区中野町１６５０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001177334',
    ),
    'E37614': EdinetCodeEntry(
        edinet_code='E37614',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='網野\u3000知博',
        submitter_name_en=None,
        submitter_name_yomi='アミノ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37615': EdinetCodeEntry(
        edinet_code='E37615',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='花谷\u3000慎太郎',
        submitter_name_en=None,
        submitter_name_yomi='ハナタニ\u3000シンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37618': EdinetCodeEntry(
        edinet_code='E37618',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ジェイコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイコーポレーション',
        address='京都市下京区東洞院通綾小路下ル扇酒屋町２８９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3130001006641',
    ),
    'E37620': EdinetCodeEntry(
        edinet_code='E37620',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山口\u3000直彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000ナオヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37621': EdinetCodeEntry(
        edinet_code='E37621',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山口\u3000昭彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37623': EdinetCodeEntry(
        edinet_code='E37623',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＳＨＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーエスエイチディー',
        address='港区東新橋一丁目１番１９号ヤクルト本社ビル１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101073899',
    ),
    'E37624': EdinetCodeEntry(
        edinet_code='E37624',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＪＣインター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケージェーシーインター',
        address='港区赤坂六丁目１５番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401110136',
    ),
    'E37626': EdinetCodeEntry(
        edinet_code='E37626',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='三甲株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンコウカブシキガイシャ',
        address='瑞穂市本田４７４番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4200001009933',
    ),
    'E37627': EdinetCodeEntry(
        edinet_code='E37627',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=214,
        fiscal_year_end='5月31日',
        submitter_name='インテグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インテグループカブシキガイシャ',
        address='千代田区丸の内１－６－５\u3000丸の内北口ビル２６Ｆ',
        industry='サービス業',
        sec_code='192A0',
        corporate_number='4010001110066',
    ),
    'E37628': EdinetCodeEntry(
        edinet_code='E37628',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000耕比古',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000タガヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37629': EdinetCodeEntry(
        edinet_code='E37629',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='戸塚\u3000昌代',
        submitter_name_en=None,
        submitter_name_yomi='トツカ\u3000マサヨ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37630': EdinetCodeEntry(
        edinet_code='E37630',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='公益財団法人ホース未来福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンホースミライフクシザイダン',
        address='大田区南雪谷２－１７－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010805002836',
    ),
    'E37631': EdinetCodeEntry(
        edinet_code='E37631',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='安藤\u3000拓郎',
        submitter_name_en=None,
        submitter_name_yomi='アンドウ\u3000タクロウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37632': EdinetCodeEntry(
        edinet_code='E37632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鯉沼\u3000充',
        submitter_name_en=None,
        submitter_name_yomi='コイヌマ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37633': EdinetCodeEntry(
        edinet_code='E37633',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000昭',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37634': EdinetCodeEntry(
        edinet_code='E37634',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=847,
        fiscal_year_end=None,
        submitter_name='日本生命第７回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイナナカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001225129',
    ),
    'E37635': EdinetCodeEntry(
        edinet_code='E37635',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='髙山\u3000博和',
        submitter_name_en=None,
        submitter_name_yomi='タカヤマ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37636': EdinetCodeEntry(
        edinet_code='E37636',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上東\u3000宏一郎',
        submitter_name_en=None,
        submitter_name_yomi='カミヒガシ\u3000コウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37641': EdinetCodeEntry(
        edinet_code='E37641',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22999,
        fiscal_year_end=None,
        submitter_name='ＫＳＰ\u3000Ｋｏｋｕｓａｉ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ，ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ケイエスピーコクサイインベストメンツエルエルシー',
        address='４１１１\u3000Ｅａｓｔ３７ｔｈ\u3000Ｓｔｒｅｅｔ\u3000Ｎｏｒｔｈ，Ｗｉｃｈｉｔａ，\u3000Ｋａｎｓａｓ\u3000６７２２０\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37643': EdinetCodeEntry(
        edinet_code='E37643',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='ＫＢＩ\u3000Ｇｌｏｂａｌ\u3000Ｉｎｖｅｓｔｏｒｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ケービーアイグローバルインベスターズリミテッド',
        address='３階、ハーバーマスター・プレイス２、Ｉｆｓｃダブリン１、ダブリン１、ダブリン、アイルランド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37649': EdinetCodeEntry(
        edinet_code='E37649',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＬＰＨＡ\u3000Ｃａｐｉｔａｌ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アルファキャピタルゴウドウガイシャ',
        address='中央区日本橋兜町５番１号兜町第１平和ビル７階レコルテ内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010003030987',
    ),
    'E37650': EdinetCodeEntry(
        edinet_code='E37650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='深谷\u3000直紀',
        submitter_name_en=None,
        submitter_name_yomi='フカヤ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37651': EdinetCodeEntry(
        edinet_code='E37651',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000良太郎',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000リョウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37653': EdinetCodeEntry(
        edinet_code='E37653',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=79,
        fiscal_year_end=None,
        submitter_name='株式会社マキテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマキテック',
        address='名古屋市熱田区旗屋一丁目９番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001022765',
    ),
    'E37656': EdinetCodeEntry(
        edinet_code='E37656',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＷＫ\u3000１\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ダブリューケイワンエルエルシー',
        address='ケイマン諸島グランドケイマンＫＹ１－１１０８、カマナ・ベイ、９４ソラリス・アヴェニュー、ピーオーボックス１３４８、ムーラン・ガバナンス・サービシズ（ケイマン）リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37661': EdinetCodeEntry(
        edinet_code='E37661',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='城戸\u3000善浩',
        submitter_name_en=None,
        submitter_name_yomi='キド\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37662': EdinetCodeEntry(
        edinet_code='E37662',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉川\u3000元宏',
        submitter_name_en=None,
        submitter_name_yomi='ヨシカワ\u3000モトヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37665': EdinetCodeEntry(
        edinet_code='E37665',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀\u3000隆',
        submitter_name_en=None,
        submitter_name_yomi='ホリ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37667': EdinetCodeEntry(
        edinet_code='E37667',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ゴーゴーカレーグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゴーゴーカレーグループ',
        address='金沢市沖町イ８１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101059452',
    ),
    'E37672': EdinetCodeEntry(
        edinet_code='E37672',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='前田\u3000浩正',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000ヒロマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37673': EdinetCodeEntry(
        edinet_code='E37673',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=301,
        fiscal_year_end=None,
        submitter_name='株式会社みちのりホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャミチノリホールディングス',
        address='千代田区丸の内一丁目９番２号グラントウキョウサウスタワー８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001123665',
    ),
    'E37674': EdinetCodeEntry(
        edinet_code='E37674',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒澤\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='クロサワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37675': EdinetCodeEntry(
        edinet_code='E37675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中谷\u3000将史',
        submitter_name_en=None,
        submitter_name_yomi='ナカタニ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37678': EdinetCodeEntry(
        edinet_code='E37678',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='Ｓｅａｃａｓｔｌｅ\u3000Ｓｉｎｇａｐｏｒｅ\u3000Ｐｔｅ．Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='シーキャッスル\u3000シンガポール',
        address='６０\u3000Ｐａｙａ\u3000Ｌｅｂａｒ\u3000Ｒｏａｄ，\u3000＃０８－０６\u3000Ｐａｙａ\u3000Ｌｅｂａｒ\u3000Ｓｑｕａｒｅ，\u3000Ｓｉｎｇａｐｏｒｅ\u3000４０９０５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37680': EdinetCodeEntry(
        edinet_code='E37680',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪー６０',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイシックスティー',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001225493',
    ),
    'E37682': EdinetCodeEntry(
        edinet_code='E37682',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栁澤\u3000秀樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギサワ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37684': EdinetCodeEntry(
        edinet_code='E37684',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栁澤\u3000美穂',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギサワ\u3000ミホ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37685': EdinetCodeEntry(
        edinet_code='E37685',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栁澤\u3000考輝',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギサワ\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37686': EdinetCodeEntry(
        edinet_code='E37686',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='テキーラ\u3000リミテッド（ＴＱＵＩＬＡ\u3000ＬＩＭＩＴＥＤ）',
        submitter_name_en=None,
        submitter_name_yomi='テキーラ\u3000リミテッド',
        address='アイルランド\u3000ゴールウェイ\u3000ゴールウェイ県\u3000ドミニク通り３５－３７\u3000ラックストンコート２１（２１\u3000ＲＵＸＴＯＮ\u3000ＣＯＵＲＴ\u3000３５－３７\u3000ＤＯＭＩＮＩＣＫ\u3000ＳＴＲＥＥＴ\u3000ＣＯ．\u3000ＧＡＬＷＡＹ\u3000ＧＡＬＷＡＹ\u3000ＩＲＥＬＡＮＤ）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37687': EdinetCodeEntry(
        edinet_code='E37687',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金子\u3000好宏',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37688': EdinetCodeEntry(
        edinet_code='E37688',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='横田\u3000大造',
        submitter_name_en=None,
        submitter_name_yomi='ヨコタ\u3000ダイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37689': EdinetCodeEntry(
        edinet_code='E37689',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='イーストベンチャーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イーストベンチャーズカブシキガイシャ',
        address='港区六本木四丁目２番４５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401097559',
    ),
    'E37692': EdinetCodeEntry(
        edinet_code='E37692',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＣＰ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエスシーピー',
        address='松原市天美東８－４－２９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001216425',
    ),
    'E37693': EdinetCodeEntry(
        edinet_code='E37693',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＧＬＯＢＡＬ\u3000ＭＡＮＡＧＥＭＥＮＴ\u3000ＰＡＲＴＮＥＲＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='グローバルマネージメントパートナーズリミテッド',
        address='Ｕｎｉｔ\u3000１１１２，\u3000Ｗｉｎｇ\u3000Ｏｎ\u3000Ｐｌａｚａ，\u3000６２\u3000Ｍｏｄｙ\u3000Ｒｏａｄ，\u3000Ｔｓ\u3000ｉｍ\u3000Ｓｈａ\u3000Ｔｓｕｉ，\u3000Ｋｏｗｌｏｏｎ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37700': EdinetCodeEntry(
        edinet_code='E37700',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='布山\u3000高士',
        submitter_name_en=None,
        submitter_name_yomi='フヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37701': EdinetCodeEntry(
        edinet_code='E37701',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河合\u3000きよ子',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000キヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37702': EdinetCodeEntry(
        edinet_code='E37702',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='河合\u3000宏美',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000ヒロミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37703': EdinetCodeEntry(
        edinet_code='E37703',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1500,
        fiscal_year_end=None,
        submitter_name='大陽日酸株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイヨウニッサンカブシキガイシャ',
        address='品川区小山１丁目３番２６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010701038856',
    ),
    'E37705': EdinetCodeEntry(
        edinet_code='E37705',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=55,
        fiscal_year_end='12月末日',
        submitter_name='エマージング・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エマージングアセットマネジメントリミテッド',
        address='バミューダ、ハミルトンＨＭ１１、パー・ラ・ヴィル・ロード５８番、ヴァリス・ビルディング４階',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E37706': EdinetCodeEntry(
        edinet_code='E37706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='赤松\u3000洋介',
        submitter_name_en=None,
        submitter_name_yomi='アカマツ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37707': EdinetCodeEntry(
        edinet_code='E37707',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='リ・ジェネレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リジェネレーションカブシキカイシャ',
        address='港区芝五丁目１３－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401096623',
    ),
    'E37708': EdinetCodeEntry(
        edinet_code='E37708',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='櫻井\u3000聖仁',
        submitter_name_en=None,
        submitter_name_yomi='サクライ\u3000マサヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37709': EdinetCodeEntry(
        edinet_code='E37709',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=495,
        fiscal_year_end='3月末日',
        submitter_name='株式会社イーディーピー',
        submitter_name_en='EDP Corporation',
        submitter_name_yomi='カブシキガイシャイーディーピー',
        address='豊中市上新田四丁目６番３号',
        industry='その他製品',
        sec_code='77940',
        corporate_number='3120901029247',
    ),
    'E37710': EdinetCodeEntry(
        edinet_code='E37710',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂｅ\u3000Ｂｒａｖｅ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーブレイブカブシキガイシャ',
        address='港区芝５－３２－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401158229',
    ),
    'E37711': EdinetCodeEntry(
        edinet_code='E37711',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＧＯＬＯＮＧ\u3000ＨＯＬＤＩＮＧ\u3000ＣＯ．，ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ゴロング\u3000ホールディング\u3000カンパニー\u3000リミテッド',
        address='ＦＬＡＴ／ＲＭ\u3000１９１１\u3000ＬＥＥ\u3000ＧＡＲＤＥＮ\u3000ＯＮＥ\u3000３３\u3000ＨＹＳＡＮ\u3000ＡＶＥＮＵＥ\u3000ＣＡＵＳＥＷＡＹ\u3000ＢＡＹ，\u3000ＨＯＮＧ\u3000ＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37712': EdinetCodeEntry(
        edinet_code='E37712',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000雄策',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ユウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37713': EdinetCodeEntry(
        edinet_code='E37713',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石塚\u3000智士',
        submitter_name_en=None,
        submitter_name_yomi='イシヅカ\u3000モトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37714': EdinetCodeEntry(
        edinet_code='E37714',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='徳山\u3000明成',
        submitter_name_en=None,
        submitter_name_yomi='トクヤマ\u3000アキナリ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37718': EdinetCodeEntry(
        edinet_code='E37718',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=310761,
        fiscal_year_end='12月31日',
        submitter_name='シュナイダー・エレクトリック・エス・イー',
        submitter_name_en=None,
        submitter_name_yomi='シュナイダーエレクトリックエスイー',
        address='フランス\u3000９２５００\u3000リュエイユ・マルメゾン\u3000リュ・ジョゼフ・モニエ\u3000３５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E37719': EdinetCodeEntry(
        edinet_code='E37719',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=35,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンウェルズ',
        submitter_name_en='SUNWELS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャサンウェルズ',
        address='金沢市二宮町１５番１３号',
        industry='サービス業',
        sec_code='92290',
        corporate_number='9220001010117',
    ),
    'E37720': EdinetCodeEntry(
        edinet_code='E37720',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='德永\u3000明彦',
        submitter_name_en=None,
        submitter_name_yomi='トクナガ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37721': EdinetCodeEntry(
        edinet_code='E37721',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27,
        fiscal_year_end=None,
        submitter_name='株式会社コンセプト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコンセプト',
        address='京都市下京区河原町通松原上る二丁目富永町３６８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130001023547',
    ),
    'E37724': EdinetCodeEntry(
        edinet_code='E37724',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＲ西日本イノベーションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジェイアールニシニホンイノベーションズ',
        address='大阪市北区大深町１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001202256',
    ),
    'E37725': EdinetCodeEntry(
        edinet_code='E37725',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社いよぎんホールディングス',
        submitter_name_en='Iyogin Holdings,Inc.',
        submitter_name_yomi='カブシキガイシャイヨギンホールディングス',
        address='松山市南堀端町１番地',
        industry='銀行業',
        sec_code='58300',
        corporate_number='3500001024507',
    ),
    'E37726': EdinetCodeEntry(
        edinet_code='E37726',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000英一郎',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000エイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37727': EdinetCodeEntry(
        edinet_code='E37727',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='不二製油株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジセイユカブシキカイシャ',
        address='泉佐野市住吉町１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120101053709',
    ),
    'E37728': EdinetCodeEntry(
        edinet_code='E37728',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宮崎\u3000良一',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザキ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37729': EdinetCodeEntry(
        edinet_code='E37729',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡﨑衛',
        submitter_name_en=None,
        submitter_name_yomi='オカザキマモル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37730': EdinetCodeEntry(
        edinet_code='E37730',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='ハンマックス・インベストメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ハンマックス\u3000インベストメント\u3000リミテッド',
        address='英領バージン諸島、トルトラ島、ロード・タウン、パセアエステート',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37733': EdinetCodeEntry(
        edinet_code='E37733',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月30日',
        submitter_name='株式会社クオンツ総研ホールディングス',
        submitter_name_en='Quants Research Institute Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャクオンツソウケンホールディングス',
        address='千代田区一丁目８番１号\u3000丸の内トラストタワーＮ館１８階',
        industry='サービス業',
        sec_code='95520',
        corporate_number='3011001124759',
    ),
    'E37735': EdinetCodeEntry(
        edinet_code='E37735',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=901,
        fiscal_year_end=None,
        submitter_name='株式会社としすみ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトシスミ',
        address='渋谷区渋谷３－１０－５ＴＯＨＴＡＭビル２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001139359',
    ),
    'E37739': EdinetCodeEntry(
        edinet_code='E37739',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ユニマック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユニマックカブシキカイシャ',
        address='神戸市中央区八幡通３ー１ー１９\u3000日精ビル６Ｆ\u3000Ａ号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001083299',
    ),
    'E37740': EdinetCodeEntry(
        edinet_code='E37740',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2298,
        fiscal_year_end='3月31日',
        submitter_name='マイクロ波化学株式会社',
        submitter_name_en='Microwave Chemical Co., Ltd.',
        submitter_name_yomi='マイクロハカガクカブシキガイシャ',
        address='大阪市住之江区平林南一丁目６番１号',
        industry='サービス業',
        sec_code='92270',
        corporate_number='2120901017335',
    ),
    'E37741': EdinetCodeEntry(
        edinet_code='E37741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ピックルスホールディングス',
        submitter_name_en='PICKLES HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャピックルスホールディングス',
        address='所沢市東住吉７番８号',
        industry='食料品',
        sec_code='29350',
        corporate_number='8030001149933',
    ),
    'E37742': EdinetCodeEntry(
        edinet_code='E37742',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=482,
        fiscal_year_end='9月30日',
        submitter_name='株式会社マイクロアド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマイクロアド',
        address='渋谷区桜丘町２０－１\u3000渋谷インフォスタワー１３階',
        industry='サービス業',
        sec_code='95530',
        corporate_number='5011001052933',
    ),
    'E37743': EdinetCodeEntry(
        edinet_code='E37743',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=400,
        fiscal_year_end='3月31日',
        submitter_name='ウェルネス・コミュニケーションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウェルネスコミュニケーションズカブシキカイシャ',
        address='港区赤坂１－１２－３２\u3000アーク森ビル１４階',
        industry='サービス業',
        sec_code='366A0',
        corporate_number='2010601032208',
    ),
    'E37744': EdinetCodeEntry(
        edinet_code='E37744',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=98,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＡＶｉＣ',
        submitter_name_en='AViC Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエイビック',
        address='港区赤坂１－１２－３２\u3000アーク森ビル４階',
        industry='サービス業',
        sec_code='95540',
        corporate_number='5012401024308',
    ),
    'E37745': EdinetCodeEntry(
        edinet_code='E37745',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社バリスター',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャバリスター',
        address='港区南青山五丁目１番２５号青山フェイスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001225430',
    ),
    'E37746': EdinetCodeEntry(
        edinet_code='E37746',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エムズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムズ',
        address='千代田区内幸町一丁目３番３号内幸町ダイビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001225787',
    ),
    'E37749': EdinetCodeEntry(
        edinet_code='E37749',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社アールジェイ７号',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアールジェイナナゴウ',
        address='港区虎ノ門一丁目２番８号リニューアブル・ジャパン株式会社内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403025218',
    ),
    'E37751': EdinetCodeEntry(
        edinet_code='E37751',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社Ｚｕｉｔｔ\u3000ＪＰ',
        submitter_name_en=None,
        submitter_name_yomi='ズィットジェーピー',
        address='川崎市中原区上小田中３丁目２９番２ー１５２号クレストシティ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010901035141',
    ),
    'E37752': EdinetCodeEntry(
        edinet_code='E37752',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺尾\u3000文孝',
        submitter_name_en=None,
        submitter_name_yomi='テラオ\u3000フミタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37753': EdinetCodeEntry(
        edinet_code='E37753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐上\u3000峻作',
        submitter_name_en=None,
        submitter_name_yomi='サガミ\u3000シュンサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37754': EdinetCodeEntry(
        edinet_code='E37754',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='苗代\u3000亮達',
        submitter_name_en=None,
        submitter_name_yomi='ナワシロ\u3000リョウタツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37755': EdinetCodeEntry(
        edinet_code='E37755',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='津﨑\u3000宏一',
        submitter_name_en=None,
        submitter_name_yomi='ツザキ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37757': EdinetCodeEntry(
        edinet_code='E37757',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大橋\u3000健司',
        submitter_name_en=None,
        submitter_name_yomi='オオハシ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37761': EdinetCodeEntry(
        edinet_code='E37761',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本多\u3000敏行',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37764': EdinetCodeEntry(
        edinet_code='E37764',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=13510,
        fiscal_year_end='12月31日',
        submitter_name='株式会社トライト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトライト',
        address='大阪市北区曾根崎二丁目１２番７号',
        industry='サービス業',
        sec_code=None,
        corporate_number='2010401143717',
    ),
    'E37765': EdinetCodeEntry(
        edinet_code='E37765',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＬＵＣＫＹ\u3000ＴＡＲＧＥＴ\u3000ＨＯＬＤＩＮＧＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ラッキーターゲットホールディングスリミテッド',
        address='英領バージン諸島\u3000トルトラ島\u3000ロードタウン\u3000ウィッカムズケイ\u3000１\u3000デ\u3000カストロストリート\u3000２４\u3000アカラビルディング',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37766': EdinetCodeEntry(
        edinet_code='E37766',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＤＯＳＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ドウソカブシキガイシャ',
        address='千代田区霞ヶ関３－２－１霞ヶ関コモンゲート西館３６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011101071742',
    ),
    'E37773': EdinetCodeEntry(
        edinet_code='E37773',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=117,
        fiscal_year_end='9月30日',
        submitter_name='ジャパンワランティサポート株式会社',
        submitter_name_en='Japan Warranty Support  Co.,Ltd.',
        submitter_name_yomi='ジャパンワランティサポートカブシキカイシャ',
        address='千代田区大手町２－１－１大手町野村ビル７Ｆ',
        industry='その他金融業',
        sec_code=None,
        corporate_number='8010001131604',
    ),
    'E37774': EdinetCodeEntry(
        edinet_code='E37774',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ダイヤモンド機工株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイヤモンドキコウカブシキカイシャ',
        address='福岡市城南区南片江２丁目３０番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290001004663',
    ),
    'E37777': EdinetCodeEntry(
        edinet_code='E37777',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社しずおかフィナンシャルグループ',
        submitter_name_en='Shizuoka Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャシズオカフィナンシャルグループ',
        address='静岡市葵区呉服町１丁目１０番地',
        industry='銀行業',
        sec_code='58310',
        corporate_number='9080001025220',
    ),
    'E37778': EdinetCodeEntry(
        edinet_code='E37778',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='澤田\u3000大樹',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000タイジュ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37779': EdinetCodeEntry(
        edinet_code='E37779',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=60,
        fiscal_year_end='7月末日',
        submitter_name='ＩＮＴＬＯＯＰ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イントループカブシキガイシャ',
        address='港区赤坂二丁目４番６号',
        industry='サービス業',
        sec_code='95560',
        corporate_number='6010401064612',
    ),
    'E37780': EdinetCodeEntry(
        edinet_code='E37780',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋\u3000忠郎',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000タダロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37781': EdinetCodeEntry(
        edinet_code='E37781',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社あいちフィナンシャルグループ',
        submitter_name_en='Aichi Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャアイチフィナンシャルグループ',
        address='名古屋市中区栄三丁目１４番１２号',
        industry='銀行業',
        sec_code='73890',
        corporate_number='1180001153290',
    ),
    'E37782': EdinetCodeEntry(
        edinet_code='E37782',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000首藤奨学財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンシュトウショウガクザイダン',
        address='横浜市港北区箕輪町二丁目１７番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020005015252',
    ),
    'E37783': EdinetCodeEntry(
        edinet_code='E37783',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｂｅｙｏｎｄ\u3000Ｉｎｖｅｓｔｍｅｎｔ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビヨンドインベストメントカブシキカイシャ',
        address='中央区日本橋横山町１－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001204023',
    ),
    'E37784': EdinetCodeEntry(
        edinet_code='E37784',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｖａｌｅｎｃｉａ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バレンシアカブシキガイシャ',
        address='中央区八丁堀２ー１２ー７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001226260',
    ),
    'E37785': EdinetCodeEntry(
        edinet_code='E37785',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=16000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ちゅうぎんフィナンシャルグループ',
        submitter_name_en='Chugin Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャチュウギンフィナンシャルグループ',
        address='岡山市北区丸の内一丁目１５番２０号',
        industry='銀行業',
        sec_code='58320',
        corporate_number='1260001037279',
    ),
    'E37786': EdinetCodeEntry(
        edinet_code='E37786',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000和良',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000カズヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37788': EdinetCodeEntry(
        edinet_code='E37788',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='3月31日',
        submitter_name='日本管財ホールディングス株式会社',
        submitter_name_en='NIPPON KANZAI Holdings Co.,Ltd.',
        submitter_name_yomi='ニホンカンザイホールディングスカブシキガイシャ',
        address='西宮市六湛寺町９番１６号',
        industry='サービス業',
        sec_code='93470',
        corporate_number='6140001129629',
    ),
    'E37790': EdinetCodeEntry(
        edinet_code='E37790',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=581,
        fiscal_year_end='12月末日',
        submitter_name='ＨＯＵＳＥＩ株式会社',
        submitter_name_en='HOUSEI Inc.',
        submitter_name_yomi='ホウセイカブシキガイシャ',
        address='新宿区津久戸町１番８号神楽坂ＡＫビル９階',
        industry='情報・通信業',
        sec_code='50350',
        corporate_number='7010701008994',
    ),
    'E37791': EdinetCodeEntry(
        edinet_code='E37791',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社サンワ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサンワ',
        address='関市千疋７０５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9200001032823',
    ),
    'E37792': EdinetCodeEntry(
        edinet_code='E37792',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伴野\u3000博之',
        submitter_name_en=None,
        submitter_name_yomi='トモノ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37793': EdinetCodeEntry(
        edinet_code='E37793',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='アトミクス取引先持株会\u3000理事長\u3000楠本慶太',
        submitter_name_en=None,
        submitter_name_yomi='アトミクストリヒキサキモチカブカイ\u3000リジチョウ\u3000クスモトケイタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37795': EdinetCodeEntry(
        edinet_code='E37795',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=322,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＷＯＷ\u3000ＷＯＲＬＤ\u3000ＧＲＯＵＰ',
        submitter_name_en='WOW WORLD GROUP Inc.',
        submitter_name_yomi='カブシキガイシャワオワールドグループ',
        address='品川区西五反田七丁目２０番９号\u3000ＫＤＸ西五反田ビル４階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010701043287',
    ),
    'E37796': EdinetCodeEntry(
        edinet_code='E37796',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1116,
        fiscal_year_end='6月末日',
        submitter_name='株式会社エアークローゼット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエアークローゼット',
        address='港区南青山３－１－３１',
        industry='サービス業',
        sec_code='95570',
        corporate_number='6040001086707',
    ),
    'E37798': EdinetCodeEntry(
        edinet_code='E37798',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='リーディング・ガイド・ホンコン・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='リーディングガイドホンコンリミテッド',
        address='香港、九龍、九龍灣、常悅道１８號、周大福保險中心７樓、０７－０８室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37801': EdinetCodeEntry(
        edinet_code='E37801',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='坪田\u3000一男',
        submitter_name_en=None,
        submitter_name_yomi='ツボタ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37802': EdinetCodeEntry(
        edinet_code='E37802',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社トワ・スール',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトワスール',
        address='世田谷区羽根木１丁目２９番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010901047782',
    ),
    'E37804': EdinetCodeEntry(
        edinet_code='E37804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＰＥ第１号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイピーイーダイイチゴウカブシキガイシャ',
        address='千代田区霞が関三丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001166832',
    ),
    'E37806': EdinetCodeEntry(
        edinet_code='E37806',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＧＷ＆Ｋ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＭＡＮＡＧＥＭＥＮＴ，ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ジーダブルアンドケーインベストメントマネジメントエルエルシー',
        address='アメリカ合衆国マサチューセッツ州０２１１６、ボストン、バークレー・ストリート２２２、１５階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37807': EdinetCodeEntry(
        edinet_code='E37807',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='鈴木興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スズキコウサンカブシキガイシャ',
        address='京都市右京区龍安寺玉津芝町４番地７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3130001004942',
    ),
    'E37810': EdinetCodeEntry(
        edinet_code='E37810',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=121,
        fiscal_year_end='9月末日',
        submitter_name='ブリッジコンサルティンググループ株式会社',
        submitter_name_en='Bridge Consulting Group Inc.',
        submitter_name_yomi='ブリッジコンサルティンググループカブシキガイシャ',
        address='港区虎ノ門四丁目１番４０号',
        industry='サービス業',
        sec_code='92250',
        corporate_number='9010401096413',
    ),
    'E37811': EdinetCodeEntry(
        edinet_code='E37811',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=818,
        fiscal_year_end=None,
        submitter_name='サウスイースタン・アセット・マネジメント・インク',
        submitter_name_en=None,
        submitter_name_yomi='サウスイースタンアセットマネジメントインク',
        address='アメリカ合衆国３８１１９テネシ－州メンフィス市ポプラ通り６４１０番地９００号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37812': EdinetCodeEntry(
        edinet_code='E37812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='足立\u3000年彦',
        submitter_name_en=None,
        submitter_name_yomi='アダチ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37814': EdinetCodeEntry(
        edinet_code='E37814',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3374,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＫＹＯＲＩＴＳＵ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキョウリツ',
        address='板橋区清水町３６番１号',
        industry='その他製品',
        sec_code='77950',
        corporate_number='5010902023530',
    ),
    'E37815': EdinetCodeEntry(
        edinet_code='E37815',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ｕｎｅｒｒｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウネリー',
        address='港区虎ノ門４丁目１番１号神谷町トラストタワー２３階',
        industry='情報・通信業',
        sec_code='50340',
        corporate_number='7010001169991',
    ),
    'E37816': EdinetCodeEntry(
        edinet_code='E37816',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='木下\u3000慶彦',
        submitter_name_en=None,
        submitter_name_yomi='キノシタ\u3000ヨシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37817': EdinetCodeEntry(
        edinet_code='E37817',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='國分\u3000晃',
        submitter_name_en=None,
        submitter_name_yomi='コクブ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37819': EdinetCodeEntry(
        edinet_code='E37819',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉野\u3000巌',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノ\u3000イワオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37820': EdinetCodeEntry(
        edinet_code='E37820',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塚原\u3000保徳',
        submitter_name_en=None,
        submitter_name_yomi='ツカハラ\u3000ヤスノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37821': EdinetCodeEntry(
        edinet_code='E37821',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ソニー・ミュージックエンタテインメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソニーミュージックエンタテインメント',
        address='千代田区六番町４番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001082437',
    ),
    'E37822': EdinetCodeEntry(
        edinet_code='E37822',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=43,
        fiscal_year_end=None,
        submitter_name='竹内工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タケウチコウギョウカブシキガイシャ',
        address='名古屋市中川区清川町一丁目一番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001020002',
    ),
    'E37825': EdinetCodeEntry(
        edinet_code='E37825',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='石井\u3000智宏',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37826': EdinetCodeEntry(
        edinet_code='E37826',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田角\u3000陸',
        submitter_name_en=None,
        submitter_name_yomi='タズミ\u3000リク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37827': EdinetCodeEntry(
        edinet_code='E37827',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=603,
        fiscal_year_end=None,
        submitter_name='明治安田生命第２回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メイジヤスダセイメイダイニカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001226974',
    ),
    'E37828': EdinetCodeEntry(
        edinet_code='E37828',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ジュピター・ディープ・バリュー・パートナーズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ジュピターディープバリューパートナーズエルエルシー',
        address='アメリカ合衆国デラウェア州、ニューキャッスル郡、ウィルミントン、リトル・フォールス・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37829': EdinetCodeEntry(
        edinet_code='E37829',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社リージョナルプラスウイングス',
        submitter_name_en='RegionalPlus Wings Corp.',
        submitter_name_yomi='カブシキカイシャリージョナルプラスウイングス',
        address='大田区',
        industry='空運業',
        sec_code=None,
        corporate_number='3010801033310',
    ),
    'E37830': EdinetCodeEntry(
        edinet_code='E37830',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='天沼\u3000聰',
        submitter_name_en=None,
        submitter_name_yomi='アマヌマ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37831': EdinetCodeEntry(
        edinet_code='E37831',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ＩＮＥＳＴ株式会社',
        submitter_name_en='INEST,Inc.',
        submitter_name_yomi='アイネストカブシキガイシャ',
        address='豊島区東池袋一丁目２５番９号',
        industry='卸売業',
        sec_code='71110',
        corporate_number='6013301049765',
    ),
    'E37832': EdinetCodeEntry(
        edinet_code='E37832',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='朝日\u3000重紀',
        submitter_name_en=None,
        submitter_name_yomi='アサヒ\u3000シゲノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37833': EdinetCodeEntry(
        edinet_code='E37833',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=539,
        fiscal_year_end='9月末日',
        submitter_name='日本ビジネスシステムズ株式会社',
        submitter_name_en='Japan Business Systems, Inc.',
        submitter_name_yomi='ニホンビジネスシステムズカブシキガイシャ',
        address='港区虎ノ門二丁目６番１号虎ノ門ヒルズステーションタワー',
        industry='情報・通信業',
        sec_code='50360',
        corporate_number='4010401041588',
    ),
    'E37835': EdinetCodeEntry(
        edinet_code='E37835',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大髙\u3000功',
        submitter_name_en=None,
        submitter_name_yomi='オオタカ\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37836': EdinetCodeEntry(
        edinet_code='E37836',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木田\u3000裕士',
        submitter_name_en=None,
        submitter_name_yomi='キダ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37837': EdinetCodeEntry(
        edinet_code='E37837',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000博文',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ヒロフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37838': EdinetCodeEntry(
        edinet_code='E37838',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ノヴァックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャノヴァックス',
        address='港区南麻布一丁目７番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401064885',
    ),
    'E37839': EdinetCodeEntry(
        edinet_code='E37839',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='エルシー・ファンド・エイト・エルピー',
        submitter_name_en=None,
        submitter_name_yomi='エルシーファンドエイトエルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、アグランドハウス、私書箱３０９、メイプルズ・コーポレート・サービシーズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37841': EdinetCodeEntry(
        edinet_code='E37841',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉浦\u3000元',
        submitter_name_en=None,
        submitter_name_yomi='スギウラ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37844': EdinetCodeEntry(
        edinet_code='E37844',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37845': EdinetCodeEntry(
        edinet_code='E37845',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='相川\u3000佳之',
        submitter_name_en=None,
        submitter_name_yomi='アイカワ\u3000ヨシユキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37847': EdinetCodeEntry(
        edinet_code='E37847',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=275,
        fiscal_year_end=None,
        submitter_name='株式会社ハウスホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハウスホールディングス',
        address='京都市東山区新宮川町通松原下る西御門町４５６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5040001042891',
    ),
    'E37848': EdinetCodeEntry(
        edinet_code='E37848',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='7月末日',
        submitter_name='株式会社クラシコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクラシコム',
        address='国立市中１丁目１番地５２',
        industry='小売業',
        sec_code='71100',
        corporate_number='6012401017913',
    ),
    'E37850': EdinetCodeEntry(
        edinet_code='E37850',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＰＥＣ\u3000（ＣＨＩＮＡ）\u3000ＤＥＶＥＬＯＰＭＥＮＴ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='エイペック\u3000チャイナ\u3000デベロップメント\u3000リミテッド',
        address='ＦＬＡＴ／ＲＭ\u3000７０１－２\u3000０７／Ｆ\u3000Ｅｖｅｒｂｒｉｇｈｔ\u3000Ｃｅｎｔｒｅ，\u3000１０８\u3000Ｇｌｏｕｃｅｓｔｅｒ\u3000Ｒｏａｄ，\u3000Ｗａｎ\u3000Ｃｈａｉ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37851': EdinetCodeEntry(
        edinet_code='E37851',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='成成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セイセイカブシキガイシャ',
        address='江戸川区東葛西六丁目２３番４－３０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011701023432',
    ),
    'E37860': EdinetCodeEntry(
        edinet_code='E37860',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社Ｓｏｕｔｈ\u3000ａｉｒ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサウスエアー',
        address='港区赤坂４－１０－３１－３０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401156636',
    ),
    'E37861': EdinetCodeEntry(
        edinet_code='E37861',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社市原ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャイチハラホールディングス',
        address='千代田区九段南一丁目５番６号\u3000りそな九段ビル５階ＫＳフロア',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001195196',
    ),
    'E37862': EdinetCodeEntry(
        edinet_code='E37862',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社フォワード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフォワード',
        address='生駒郡平群町緑ヶ丘六丁目１番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9150001025543',
    ),
    'E37863': EdinetCodeEntry(
        edinet_code='E37863',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社三原色',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンゲンショク',
        address='有田郡湯浅町大字湯浅１７８０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7170001007450',
    ),
    'E37869': EdinetCodeEntry(
        edinet_code='E37869',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000俊範',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000トシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37870': EdinetCodeEntry(
        edinet_code='E37870',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤森\u3000直治',
        submitter_name_en=None,
        submitter_name_yomi='フジモリ\u3000ナオジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37871': EdinetCodeEntry(
        edinet_code='E37871',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='瀨戸\u3000信昭',
        submitter_name_en=None,
        submitter_name_yomi='セト\u3000ノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37872': EdinetCodeEntry(
        edinet_code='E37872',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内山\u3000英俊',
        submitter_name_en=None,
        submitter_name_yomi='ウチヤマ\u3000ヒデトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37875': EdinetCodeEntry(
        edinet_code='E37875',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000耕平',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37876': EdinetCodeEntry(
        edinet_code='E37876',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000友子',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トモコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37877': EdinetCodeEntry(
        edinet_code='E37877',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＤＣＭ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディーシーエムカブシキカイシャ',
        address='品川区南大井６丁目２２番７号\u3000大森ベルポートＥ館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010701039115',
    ),
    'E37878': EdinetCodeEntry(
        edinet_code='E37878',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2682,
        fiscal_year_end=None,
        submitter_name='ＣＯＲＮＥＳ\u3000＆\u3000ＣＯＭＰＡＮＹ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='コーンズアンドカンパニーリミテッド',
        address='１０／Ｆ，\u3000Ｆａｉｒｍｏｎｔ\u3000Ｈｏｕｓｅ，\u3000８\u3000Ｃｏｔｔｏｎ\u3000Ｔｒｅｅ\u3000Ｄｒｉｖｅ，\u3000Ｃｅｎｔｒａｌ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37880': EdinetCodeEntry(
        edinet_code='E37880',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=326,
        fiscal_year_end=None,
        submitter_name='Ａｎｔｏｎ\u3000Ｐａａｒ\u3000ＧｍｂＨ',
        submitter_name_en=None,
        submitter_name_yomi='アントンパールゲーエムベーハー',
        address='アントン・パール・シュトラーセ\u3000２０\u3000８０５４\u3000グラーツ・シュトラスガング',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37881': EdinetCodeEntry(
        edinet_code='E37881',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田賀\u3000健太郎',
        submitter_name_en=None,
        submitter_name_yomi='タガ\u3000ケンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37883': EdinetCodeEntry(
        edinet_code='E37883',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＨＡＲＰ\u3000ＥＤＧＥ\u3000ＶＥＮＴＵＲＥＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シャープ\u3000エッジ\u3000ベンチャーズ\u3000リミテッド',
        address='英領バージン諸島\u3000ＶＧ１１１０\u3000トルトラ島\u3000ロードタウン\u3000ウィッカムズケイ\u3000２\u3000ヴィストラコーポレートサービシズセンター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37884': EdinetCodeEntry(
        edinet_code='E37884',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小川\u3000穂波',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000ホナミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37885': EdinetCodeEntry(
        edinet_code='E37885',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3476,
        fiscal_year_end=None,
        submitter_name='ワールドプレイズリミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ワールドプレイズリミテッド',
        address='ヴィストラコーポレートサービスセンター、グラウンドフロア\u3000エヌピーエフ\u3000ビルディング、ビーチロード、アピア、サモア',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37886': EdinetCodeEntry(
        edinet_code='E37886',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='香港幻電有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ホンコンホウデンユウゲンカイシャ',
        address='ＦＬＡＴ／ＲＭ\u3000６０３，０６／Ｆ，ＬＡＷＳ\u3000ＣＯＭＭＥＲＣＩＡＬ\u3000ＰＬＡＺＡ，７８８\u3000ＣＨＥＵＮＧ\u3000ＳＨＡ\u3000ＷＡＮ\u3000ＲＯＡＤ，ＣＨＥＵＮＧ\u3000ＳＨＡ\u3000ＷＡＮ，ＨＯＮＧ\u3000ＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37887': EdinetCodeEntry(
        edinet_code='E37887',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社アン・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアンコーポレーション',
        address='中央区銀座一丁目１２番４号Ｎ＆ＥＢＬＤ．６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011103010441',
    ),
    'E37888': EdinetCodeEntry(
        edinet_code='E37888',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000茂二郎',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000シゲジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37889': EdinetCodeEntry(
        edinet_code='E37889',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000尚',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37891': EdinetCodeEntry(
        edinet_code='E37891',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日本電計取引先持株会\u3000理事長\u3000小林一夫',
        submitter_name_en=None,
        submitter_name_yomi='ニホンデンケイトリヒキサキモチカブカイ\u3000リジチョウ\u3000コバヤシカズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37894': EdinetCodeEntry(
        edinet_code='E37894',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＢＣＰＥ\u3000Ｂｒｏｎｚｅ\u3000Ｃａｙｍａｎ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーピーイー\u3000ブロンズ\u3000ケイマン\u3000エルピー',
        address='Ｍａｐｌｅｓ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｌｉｍｉｔｅｄ，\u3000ＰＯ\u3000Ｂｏｘ\u3000３０９，\u3000Ｕｇｌａｎｄ\u3000Ｈｏｕｓｅ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０４，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37901': EdinetCodeEntry(
        edinet_code='E37901',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000敏晴',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000トシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37902': EdinetCodeEntry(
        edinet_code='E37902',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=389,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ｅＷｅＬＬ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイーウェル',
        address='大阪市中央区久太郎町四丁目１番３号',
        industry='情報・通信業',
        sec_code='50380',
        corporate_number='1120001171257',
    ),
    'E37903': EdinetCodeEntry(
        edinet_code='E37903',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＡＮＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カノウカブシキカイシャ',
        address='小松市白江町ヨ２７８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1220001024917',
    ),
    'E37904': EdinetCodeEntry(
        edinet_code='E37904',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社チーム金子',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャチームカネコ',
        address='港区港南二丁目５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401138095',
    ),
    'E37906': EdinetCodeEntry(
        edinet_code='E37906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000貴多郎',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000キタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37907': EdinetCodeEntry(
        edinet_code='E37907',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='カナメ・キャピタル・エルピー（Ｋａｎａｍｅ\u3000Ｃａｐｉｔａｌ，Ｌ．Ｐ．）',
        submitter_name_en=None,
        submitter_name_yomi='カナメ\u3000キャピタル\u3000エルピー',
        address='コーポレーション・トラスト・カンパニー、１２０９\u3000オレンジストリート、ウィルミントン、カントリーオブニューキャッスル、デラウェア\u3000１９８０１、アメリカ合衆国',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37911': EdinetCodeEntry(
        edinet_code='E37911',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=23,
        fiscal_year_end='11月30日',
        submitter_name='ジャパニアス株式会社',
        submitter_name_en='Japaniace Co.,Ltd.',
        submitter_name_yomi='ジャパニアスカブシキカイシャ',
        address='横浜市西区みなとみらい二丁目２番１号横浜ランドマークタワー１８Ｆ',
        industry='サービス業',
        sec_code='95580',
        corporate_number='6020001036275',
    ),
    'E37912': EdinetCodeEntry(
        edinet_code='E37912',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=79,
        fiscal_year_end=None,
        submitter_name='キーウィテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キーウィテクノロジーカブシキカイシャ',
        address='中央区銀座１丁目１２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401134123',
    ),
    'E37913': EdinetCodeEntry(
        edinet_code='E37913',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1928,
        fiscal_year_end='11月末日',
        submitter_name='株式会社ＦＰパートナー',
        submitter_name_en='FP Partner Inc.',
        submitter_name_yomi='カブシキガイシャエフピーパートナー',
        address='文京区後楽一丁目５番３号',
        industry='保険業',
        sec_code='73880',
        corporate_number='8010001129227',
    ),
    'E37914': EdinetCodeEntry(
        edinet_code='E37914',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=450,
        fiscal_year_end='3月末日',
        submitter_name='株式会社テリロジーホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテリロジーホールディングス',
        address='千代田区九段北一丁目１３番５号',
        industry='卸売業',
        sec_code='51330',
        corporate_number='4010001230566',
    ),
    'E37915': EdinetCodeEntry(
        edinet_code='E37915',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='井上\u3000浩行',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37917': EdinetCodeEntry(
        edinet_code='E37917',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='エス・アイ・ジー・アジア・ファンド・フォー・エルエルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='エスアイジーアジアファンドフォーエルエルエルピー',
        address='米国１９８０８デラウェア州、ウィルミントン、リトル・フォールズ・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37918': EdinetCodeEntry(
        edinet_code='E37918',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社十文字チキンカンパニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジュウモンジチキンカンパニー',
        address='二戸市石切所字火行塚２５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2400001007720',
    ),
    'E37919': EdinetCodeEntry(
        edinet_code='E37919',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='合同会社尚創',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャショウソウ',
        address='横浜市中区尾上町五丁目７１番地－１８０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020003019874',
    ),
    'E37921': EdinetCodeEntry(
        edinet_code='E37921',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=143,
        fiscal_year_end=None,
        submitter_name='三東株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サントウカブシキカイシャ',
        address='中央区日本橋蛎殻町１丁目２９番６号水天宮前東急ビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001009182',
    ),
    'E37925': EdinetCodeEntry(
        edinet_code='E37925',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＷａｉｚＨｏｌｄｉｎｇｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワイズホールディングス',
        address='福岡市東区松田一丁目５番７号ミスターマックスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290001098103',
    ),
    'E37926': EdinetCodeEntry(
        edinet_code='E37926',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='ポーターズ株式会社',
        submitter_name_en='PORTERS CORPORATION',
        submitter_name_yomi='ポーターズカブシキガイシャ',
        address='港区赤坂８－５－３４',
        industry='情報・通信業',
        sec_code='51260',
        corporate_number='1010401046887',
    ),
    'E37929': EdinetCodeEntry(
        edinet_code='E37929',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='モノフル・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='モノフルピーティーイーリミテッド',
        address='シンガポール共和国マリーナビュー８番アジアスクエアタワー１＃０７－０４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37931': EdinetCodeEntry(
        edinet_code='E37931',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='黒木\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='クロキ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37932': EdinetCodeEntry(
        edinet_code='E37932',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長井\u3000一浩',
        submitter_name_en=None,
        submitter_name_yomi='ナガイ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37933': EdinetCodeEntry(
        edinet_code='E37933',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='牧田\u3000幸弘',
        submitter_name_en=None,
        submitter_name_yomi='マキタ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37934': EdinetCodeEntry(
        edinet_code='E37934',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7000,
        fiscal_year_end=None,
        submitter_name='株式会社シノケングループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシノケングループ',
        address='福岡市中央区天神１丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001228043',
    ),
    'E37936': EdinetCodeEntry(
        edinet_code='E37936',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=118,
        fiscal_year_end='8月31日',
        submitter_name='株式会社プログリット',
        submitter_name_en='PROGRIT Inc.',
        submitter_name_yomi='カブシキガイシャプログリット',
        address='千代田区有楽町２ー１０－１\u3000東京交通会館ビル５階',
        industry='サービス業',
        sec_code='95600',
        corporate_number='4010001178269',
    ),
    'E37937': EdinetCodeEntry(
        edinet_code='E37937',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＫＳＫ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイエスケイゴウドウガイシャ',
        address='文京区千石二丁目１１－９－４２１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010003026097',
    ),
    'E37939': EdinetCodeEntry(
        edinet_code='E37939',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='8月31日',
        submitter_name='株式会社グッピーズ',
        submitter_name_en="GUPPY's Inc.",
        submitter_name_yomi='カブシキガイシャグッピーズ',
        address='新宿区西新宿６丁目１４番１号\u3000新宿グリーンタワービル２４階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='5011101043683',
    ),
    'E37947': EdinetCodeEntry(
        edinet_code='E37947',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｌｉｆｔｉｎｇ\u3000Ｈｏｌｄｉｎｇｓ\u3000ＢｉｄＣｏ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リフティングホールディングスビッドコーカブシキカイシャ',
        address='千代田区丸の内一丁目１１番１号パシフィックセンチュリープレイス丸の内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001226390',
    ),
    'E37950': EdinetCodeEntry(
        edinet_code='E37950',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=125,
        fiscal_year_end='12月31日',
        submitter_name='株式会社キットアライブ',
        submitter_name_en='Kitalive Inc.',
        submitter_name_yomi='カブシキガイシャキットアライブ',
        address='札幌市北区北七条西一丁目１番地５',
        industry='情報・通信業',
        sec_code='50390',
        corporate_number='6430001072262',
    ),
    'E37951': EdinetCodeEntry(
        edinet_code='E37951',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='嘉屋\u3000雄大',
        submitter_name_en=None,
        submitter_name_yomi='カヤ\u3000ユウダイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37954': EdinetCodeEntry(
        edinet_code='E37954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中野\u3000剛人',
        submitter_name_en=None,
        submitter_name_yomi='ナカノ\u3000ノリト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37955': EdinetCodeEntry(
        edinet_code='E37955',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='北村\u3000亜沙子',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000アサコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37956': EdinetCodeEntry(
        edinet_code='E37956',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社エンジェル・トーチ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエンジェルトーチ',
        address='千代田区内幸町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001179201',
    ),
    'E37957': EdinetCodeEntry(
        edinet_code='E37957',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=78,
        fiscal_year_end='9月30日',
        submitter_name='ビジネスコーチ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビジネスコーチカブシキガイシャ',
        address='港区西新橋一丁目７番１４号',
        industry='サービス業',
        sec_code='95620',
        corporate_number='5010001092774',
    ),
    'E37958': EdinetCodeEntry(
        edinet_code='E37958',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=554,
        fiscal_year_end=None,
        submitter_name='日本生命第８回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイハチカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001228516',
    ),
    'E37959': EdinetCodeEntry(
        edinet_code='E37959',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1213,
        fiscal_year_end='8月31日',
        submitter_name='株式会社ＦＩＸＥＲ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフィクサー',
        address='芝浦１丁目２－３',
        industry='情報・通信業',
        sec_code='51290',
        corporate_number='1010401084788',
    ),
    'E37960': EdinetCodeEntry(
        edinet_code='E37960',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=822,
        fiscal_year_end='12月31日',
        submitter_name='株式会社キューブ',
        submitter_name_en='CUBE CO., LTD.',
        submitter_name_yomi='カブシキガイシャキューブ',
        address='港区赤坂二丁目１７番７号赤坂溜池タワー',
        industry='小売業',
        sec_code='71120',
        corporate_number='4011001045995',
    ),
    'E37961': EdinetCodeEntry(
        edinet_code='E37961',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＦＲＡＣＯＲＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフラコラ',
        address='福生市東町１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013101003286',
    ),
    'E37962': EdinetCodeEntry(
        edinet_code='E37962',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18673,
        fiscal_year_end=None,
        submitter_name='株式会社日本共創プラットフォーム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニホンキョウソウプラットフォーム',
        address='千代田区丸の内一丁目９番２号\u3000グラントウキョウサウスタワー８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001209679',
    ),
    'E37963': EdinetCodeEntry(
        edinet_code='E37963',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＫＥＮＳキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャケンズキャピタル',
        address='高松市観光通一丁目３番地４レアーレ瓦町２０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011103011888',
    ),
    'E37964': EdinetCodeEntry(
        edinet_code='E37964',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社イーグルファンド２号',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャイーグルファンドニゴウ',
        address='新宿区西新宿２－１－１\u3000新宿三井ビルディング４９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011103011889',
    ),
    'E37978': EdinetCodeEntry(
        edinet_code='E37978',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=32998,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソシオネクスト',
        submitter_name_en='Socionext Inc.',
        submitter_name_yomi='カブシキガイシャソシオネクスト',
        address='横浜市港北区新横浜二丁目１０番２３',
        industry='電気機器',
        sec_code='65260',
        corporate_number='7020001107604',
    ),
    'E37979': EdinetCodeEntry(
        edinet_code='E37979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=370,
        fiscal_year_end='12月31日',
        submitter_name='株式会社グラッドキューブ',
        submitter_name_en='GLAD CUBE Inc.',
        submitter_name_yomi='カブシキガイシャグラッドキューブ',
        address='大阪市中央区瓦町２丁目４－７新瓦町ビル８階',
        industry='サービス業',
        sec_code='95610',
        corporate_number='9120001129165',
    ),
    'E37981': EdinetCodeEntry(
        edinet_code='E37981',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松本\u3000將',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000ショウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37982': EdinetCodeEntry(
        edinet_code='E37982',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='株式会社ダイオーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイオーズ',
        address='千代田区丸の内一丁目７番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001228626',
    ),
    'E37985': EdinetCodeEntry(
        edinet_code='E37985',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=675,
        fiscal_year_end='12月31日',
        submitter_name='Ａｔｌａｓ\u3000Ｔｅｃｈｎｏｌｏｇｉｅｓ株式会社',
        submitter_name_en='Atlas Technologies Corporation',
        submitter_name_yomi='アトラステクノロジーズカブシキカイシャ',
        address='東京都千代田区霞が関三丁目２番５号',
        industry='サービス業',
        sec_code='95630',
        corporate_number='8012401033578',
    ),
    'E37986': EdinetCodeEntry(
        edinet_code='E37986',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1209,
        fiscal_year_end='3月末日',
        submitter_name='ＳＢＩリーシングサービス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイリーシングサービスカブシキガイシャ',
        address='港区六本木一丁目６番１号\u3000泉ガーデンタワー１４階',
        industry='その他金融業',
        sec_code='58340',
        corporate_number='4010401130688',
    ),
    'E37987': EdinetCodeEntry(
        edinet_code='E37987',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='7月31日',
        submitter_name='リンカーズ株式会社',
        submitter_name_en='Linkers Corporation',
        submitter_name_yomi='リンカーズカブシキカイシャ',
        address='文京区後楽二丁目３番２１号',
        industry='情報・通信業',
        sec_code='51310',
        corporate_number='1010901029020',
    ),
    'E37988': EdinetCodeEntry(
        edinet_code='E37988',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='肥田\u3000義光',
        submitter_name_en=None,
        submitter_name_yomi='ヒダ\u3000ヨシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37990': EdinetCodeEntry(
        edinet_code='E37990',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山内\u3000規之',
        submitter_name_en=None,
        submitter_name_yomi='ヤマノウチ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37991': EdinetCodeEntry(
        edinet_code='E37991',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社協栄情報',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキョウエイジョウホウ',
        address='中央区新川１丁目２８番２４号東京ダイヤビル４号館５Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401098601',
    ),
    'E37992': EdinetCodeEntry(
        edinet_code='E37992',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='株式会社Ｙ．Ｓ．Ｄ．',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイエスディー',
        address='台東区台東１－２４－９ブライト秋葉原５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8030001104104',
    ),
    'E37994': EdinetCodeEntry(
        edinet_code='E37994',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=539,
        fiscal_year_end=None,
        submitter_name='全共連第２回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼンキョウレンダイニカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001228820',
    ),
    'E37996': EdinetCodeEntry(
        edinet_code='E37996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田村\u3000稔郎',
        submitter_name_en=None,
        submitter_name_yomi='タムラ\u3000トシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37997': EdinetCodeEntry(
        edinet_code='E37997',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1052,
        fiscal_year_end=None,
        submitter_name='アプライド・マテリアルズ・ヨーロッパ・ビー・ヴィー',
        submitter_name_en=None,
        submitter_name_yomi='アプライドマテリアルズヨーロッパビーヴィー',
        address='オランダ王国２１３２ＪＧホーフトドルプ、スピカラーン５７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37998': EdinetCodeEntry(
        edinet_code='E37998',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7477081,
        fiscal_year_end=None,
        submitter_name='アマゾン・ドット・コム・インク',
        submitter_name_en=None,
        submitter_name_yomi='アマゾン\u3000ドット\u3000コム\u3000インク',
        address='アメリカ合衆国９８１０９、ワシントン州シアトル、テリー・アベニュー・ノース４１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E37999': EdinetCodeEntry(
        edinet_code='E37999',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='金島弘樹',
        submitter_name_en=None,
        submitter_name_yomi='カネシマヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38001': EdinetCodeEntry(
        edinet_code='E38001',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='山河企画有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワキカクユウゲンガイシャ',
        address='広島市西区観音町９番４号観音町ビル２０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9240002017150',
    ),
    'E38003': EdinetCodeEntry(
        edinet_code='E38003',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武内\u3000寿明',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000ヒサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38004': EdinetCodeEntry(
        edinet_code='E38004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='藤井\u3000太郎',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38007': EdinetCodeEntry(
        edinet_code='E38007',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=181,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＦＣＥ',
        submitter_name_en='FCE Inc.',
        submitter_name_yomi='カブシキガイシャエフシーイー',
        address='新宿区西新宿二丁目４番１号',
        industry='サービス業',
        sec_code='95640',
        corporate_number='5011101080339',
    ),
    'E38008': EdinetCodeEntry(
        edinet_code='E38008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ｐｌｕｓｚｅｒｏ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプラスゼロ',
        address='世田谷区北沢２－６－１０仙田ビル４階',
        industry='情報・通信業',
        sec_code='51320',
        corporate_number='7010901042439',
    ),
    'E38009': EdinetCodeEntry(
        edinet_code='E38009',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=110403,
        fiscal_year_end=None,
        submitter_name='ゲーブルー・クナウフ・カーゲー',
        submitter_name_en=None,
        submitter_name_yomi='ゲーブルークナウフカーゲー',
        address='ドイツ連邦共和国９７３４６イプホーフェン、アム・バンホフ７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38010': EdinetCodeEntry(
        edinet_code='E38010',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＢＩノンバンクホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイノンバンクホールディングスカブシキガイシャ',
        address='東京都港区六本木１－６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401141396',
    ),
    'E38011': EdinetCodeEntry(
        edinet_code='E38011',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社ＰａｎｏｐｔｉｃｏｎＩｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャパノプティコンインベストメント',
        address='新宿区西新宿三丁目３番１３号西新宿水間ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101090793',
    ),
    'E38013': EdinetCodeEntry(
        edinet_code='E38013',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='野澤\u3000俊通',
        submitter_name_en=None,
        submitter_name_yomi='ノザワ\u3000トシミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38014': EdinetCodeEntry(
        edinet_code='E38014',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下川\u3000弘樹',
        submitter_name_en=None,
        submitter_name_yomi='シモカワ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38015': EdinetCodeEntry(
        edinet_code='E38015',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西川\u3000三郎',
        submitter_name_en=None,
        submitter_name_yomi='ニシカワ\u3000サブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38016': EdinetCodeEntry(
        edinet_code='E38016',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ジャパネットホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジャパネットホールディングス',
        address='佐世保市日宇町２７８１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7310001007246',
    ),
    'E38017': EdinetCodeEntry(
        edinet_code='E38017',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=7500,
        fiscal_year_end='6月30日',
        submitter_name='ＩＤ＆Ｅホールディングス株式会社',
        submitter_name_en='Integrated Design  &  Engineering Holdings Co.,Ltd.',
        submitter_name_yomi='アイディーアンドイーホールディングスカブシキカイシャ',
        address='千代田区麹町５－４',
        industry='サービス業',
        sec_code=None,
        corporate_number='6010001236685',
    ),
    'E38021': EdinetCodeEntry(
        edinet_code='E38021',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ジェイ・エム・イー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジェイエムイー',
        address='港区南麻布５－５－９－５０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011101053428',
    ),
    'E38022': EdinetCodeEntry(
        edinet_code='E38022',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松村\u3000智明',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000トモアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38023': EdinetCodeEntry(
        edinet_code='E38023',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000繁貴',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38024': EdinetCodeEntry(
        edinet_code='E38024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='プリベントメディカル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プリベントメディカルカブシキガイシャ',
        address='中央区日本橋小舟町９－１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001171816',
    ),
    'E38025': EdinetCodeEntry(
        edinet_code='E38025',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｒａｙｓ\u3000Ｃｏｍｐａｎｙ（Ｈｏｎｇ\u3000Ｋｏｎｇ）Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='レイズ\u3000カンパニー\u3000ホンコン\u3000リミテッド',
        address='香港、セントラル、ワン・コンノート・プレイス、ジャーディン・ハウス、３０階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38028': EdinetCodeEntry(
        edinet_code='E38028',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='加藤\u3000貞顕',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000サダアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38030': EdinetCodeEntry(
        edinet_code='E38030',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='御子柴\u3000智美',
        submitter_name_en=None,
        submitter_name_yomi='ミコシバ\u3000トモミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38031': EdinetCodeEntry(
        edinet_code='E38031',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ロジスティード株式会社',
        submitter_name_en='LOGISTEED, Ltd.',
        submitter_name_yomi='ロジスティードカブシキガイシャ',
        address='中央区京橋二丁目９番２号',
        industry='陸運業',
        sec_code=None,
        corporate_number='4010001226242',
    ),
    'E38034': EdinetCodeEntry(
        edinet_code='E38034',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000直子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ナオコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38036': EdinetCodeEntry(
        edinet_code='E38036',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=279,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＰＯＰＥＲ',
        submitter_name_en='POPER Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャポパー',
        address='中央区日本橋茅場町一丁目１３番２１号',
        industry='情報・通信業',
        sec_code='51340',
        corporate_number='8011001103683',
    ),
    'E38037': EdinetCodeEntry(
        edinet_code='E38037',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日高早斗',
        submitter_name_en=None,
        submitter_name_yomi='ヒダカ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38038': EdinetCodeEntry(
        edinet_code='E38038',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社グリーンエネルギー',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャグリーンエネルギー',
        address='港区虎ノ門三丁目２２番１０－２０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010403028374',
    ),
    'E38042': EdinetCodeEntry(
        edinet_code='E38042',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='アクセンチュア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アクセンチュア\u3000カブシキ\u3000カイシャ',
        address='港区赤坂一丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401001556',
    ),
    'E38043': EdinetCodeEntry(
        edinet_code='E38043',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1100,
        fiscal_year_end='11月30日',
        submitter_name='ｎｏｔｅ株式会社',
        submitter_name_en='note inc.',
        submitter_name_yomi='ノートカブシキガイシャ',
        address='千代田区麹町６ー６ー２番町麹町ビルディング５階',
        industry='サービス業',
        sec_code='52430',
        corporate_number='3011001071811',
    ),
    'E38045': EdinetCodeEntry(
        edinet_code='E38045',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='矢澤\u3000俊一',
        submitter_name_en=None,
        submitter_name_yomi='ヤザワ\u3000トシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38048': EdinetCodeEntry(
        edinet_code='E38048',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社中西アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャナカニシアセットマネジメント',
        address='大阪市城東区今福西６丁目７番３３－１００１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001226050',
    ),
    'E38049': EdinetCodeEntry(
        edinet_code='E38049',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='西森\u3000康二',
        submitter_name_en=None,
        submitter_name_yomi='ニシモリ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38052': EdinetCodeEntry(
        edinet_code='E38052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='カンロ共栄会\u3000理事長\u3000小林\u3000正幸',
        submitter_name_en=None,
        submitter_name_yomi='カンロキョウエイカイ\u3000リジチョウ\u3000コバヤシ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38053': EdinetCodeEntry(
        edinet_code='E38053',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川実',
        submitter_name_en=None,
        submitter_name_yomi='オガワミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38054': EdinetCodeEntry(
        edinet_code='E38054',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='橋場\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='ハシバ\u3000ゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38055': EdinetCodeEntry(
        edinet_code='E38055',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='細川\u3000馨',
        submitter_name_en=None,
        submitter_name_yomi='ホソカワ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38056': EdinetCodeEntry(
        edinet_code='E38056',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平田\u3000実',
        submitter_name_en=None,
        submitter_name_yomi='ヒラタ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38057': EdinetCodeEntry(
        edinet_code='E38057',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=46,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＡＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアイエイテイ',
        address='岡崎市康生通南三丁目三番地マルワビル５Ｆ\u3000ＡＢ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2180302004092',
    ),
    'E38060': EdinetCodeEntry(
        edinet_code='E38060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松岡\u3000清一',
        submitter_name_en=None,
        submitter_name_yomi='マツオカ\u3000セイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38064': EdinetCodeEntry(
        edinet_code='E38064',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='合同会社田中',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャタナカ',
        address='目黒区三田２－６－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011003012876',
    ),
    'E38065': EdinetCodeEntry(
        edinet_code='E38065',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＮＪ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエヌケー',
        address='目黒区原町１丁目１１番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010603008963',
    ),
    'E38066': EdinetCodeEntry(
        edinet_code='E38066',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='合同会社ＮＨＳ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエヌエイチエス',
        address='世田谷区奥沢３－９－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010903006589',
    ),
    'E38067': EdinetCodeEntry(
        edinet_code='E38067',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＭＫ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエムケー',
        address='板橋区小茂根３－１７－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011403003353',
    ),
    'E38072': EdinetCodeEntry(
        edinet_code='E38072',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=688,
        fiscal_year_end='10月31日',
        submitter_name='ｔｒｉｐｌａ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トリプラカブシキカイシャ',
        address='新宿区西新宿４丁目１５番３号住友不動産西新宿ビル３号館３階',
        industry='情報・通信業',
        sec_code='51360',
        corporate_number='8012701013115',
    ),
    'E38073': EdinetCodeEntry(
        edinet_code='E38073',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='エヌエックスシー・ジャパン合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエックスシージャパンゴウドウガイシャ',
        address='千代田区大手町１－７－２\u3000東京サンケイビル２７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003023547',
    ),
    'E38074': EdinetCodeEntry(
        edinet_code='E38074',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西條\u3000晋一',
        submitter_name_en=None,
        submitter_name_yomi='サイジョウ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38075': EdinetCodeEntry(
        edinet_code='E38075',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='農林中金キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノウリンチュウキンキャピタルカブシキカイシャ',
        address='千代田区大手町一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001220393',
    ),
    'E38078': EdinetCodeEntry(
        edinet_code='E38078',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=567,
        fiscal_year_end='12月31日',
        submitter_name='株式会社エスネットワークス',
        submitter_name_en='ES NETWORKS CO., LTD.',
        submitter_name_yomi='カブシキカイシャエスネットワークス',
        address='千代田区丸の内２丁目７ー２ＪＰタワー２３階',
        industry='サービス業',
        sec_code='58670',
        corporate_number='7010401041874',
    ),
    'E38079': EdinetCodeEntry(
        edinet_code='E38079',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アールジェイピー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アールジェイピーカブシキガイシャ',
        address='港区六本木５丁目１２番７ー３０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401139873',
    ),
    'E38080': EdinetCodeEntry(
        edinet_code='E38080',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='湯浅健右',
        submitter_name_en=None,
        submitter_name_yomi='ユアサケンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38082': EdinetCodeEntry(
        edinet_code='E38082',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='スカイマーク株式会社',
        submitter_name_en='Skymark Airlines Inc.',
        submitter_name_yomi='スカイマークカブシキカイシャ',
        address='大田区羽田空港三丁目５番１０号',
        industry='空運業',
        sec_code='92040',
        corporate_number='7010801019529',
    ),
    'E38083': EdinetCodeEntry(
        edinet_code='E38083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植田\u3000千矢子',
        submitter_name_en=None,
        submitter_name_yomi='ウエダ\u3000チヤコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38084': EdinetCodeEntry(
        edinet_code='E38084',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='新原栄寿',
        submitter_name_en=None,
        submitter_name_yomi='ニイハラエイジュ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38085': EdinetCodeEntry(
        edinet_code='E38085',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三輪\u3000幸将',
        submitter_name_en=None,
        submitter_name_yomi='ミワ\u3000ユキマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38086': EdinetCodeEntry(
        edinet_code='E38086',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000甲子雄',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000カシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38089': EdinetCodeEntry(
        edinet_code='E38089',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='北村健',
        submitter_name_en=None,
        submitter_name_yomi='キタムラケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38090': EdinetCodeEntry(
        edinet_code='E38090',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='橋本舜',
        submitter_name_en=None,
        submitter_name_yomi='ハシモトシュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38091': EdinetCodeEntry(
        edinet_code='E38091',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岡田\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38092': EdinetCodeEntry(
        edinet_code='E38092',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑\u3000芳広',
        submitter_name_en=None,
        submitter_name_yomi='ハタ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38093': EdinetCodeEntry(
        edinet_code='E38093',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山碕\u3000峻太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000シュンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38094': EdinetCodeEntry(
        edinet_code='E38094',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡田\u3000祥吾',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ショウゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38103': EdinetCodeEntry(
        edinet_code='E38103',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='向山\u3000孝弘',
        submitter_name_en=None,
        submitter_name_yomi='ムカイヤマ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38104': EdinetCodeEntry(
        edinet_code='E38104',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='2月末日',
        submitter_name='ベースフード株式会社',
        submitter_name_en='BASE FOOD, Inc.',
        submitter_name_yomi='ベースフードカブシキカイシャ',
        address='目黒区中目黒五丁目２５番２号',
        industry='小売業',
        sec_code='29360',
        corporate_number='6010901037910',
    ),
    'E38105': EdinetCodeEntry(
        edinet_code='E38105',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松下\u3000智樹',
        submitter_name_en=None,
        submitter_name_yomi='マツシタ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38106': EdinetCodeEntry(
        edinet_code='E38106',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤陽彦',
        submitter_name_en=None,
        submitter_name_yomi='サトウキヨヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38107': EdinetCodeEntry(
        edinet_code='E38107',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='江川\u3000源',
        submitter_name_en=None,
        submitter_name_yomi='エガワ\u3000ゲン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38108': EdinetCodeEntry(
        edinet_code='E38108',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｈ設計工房',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチセッケイコウボウ',
        address='別府市大字南立石字北田位１７０３番地２',
        industry='不動産業',
        sec_code=None,
        corporate_number='2130001067949',
    ),
    'E38109': EdinetCodeEntry(
        edinet_code='E38109',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=832,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ＡＢＥＪＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアベジャ',
        address='港区港区三田一丁目１番１４号',
        industry='情報・通信業',
        sec_code='55740',
        corporate_number='5011001091576',
    ),
    'E38110': EdinetCodeEntry(
        edinet_code='E38110',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小代\u3000義行',
        submitter_name_en=None,
        submitter_name_yomi='オジロ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38111': EdinetCodeEntry(
        edinet_code='E38111',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='森\u3000遼太',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000リョウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38112': EdinetCodeEntry(
        edinet_code='E38112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='永田\u3000基樹',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000モトキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38113': EdinetCodeEntry(
        edinet_code='E38113',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='小代\u3000愛',
        submitter_name_en=None,
        submitter_name_yomi='オジロ\u3000メグム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38114': EdinetCodeEntry(
        edinet_code='E38114',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='夏原\u3000陽平',
        submitter_name_en=None,
        submitter_name_yomi='ナツハラ\u3000ヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38115': EdinetCodeEntry(
        edinet_code='E38115',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='夏原\u3000行平',
        submitter_name_en=None,
        submitter_name_yomi='ナツハラ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38116': EdinetCodeEntry(
        edinet_code='E38116',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='夏原\u3000美智子',
        submitter_name_en=None,
        submitter_name_yomi='ナツハラ\u3000ミチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38117': EdinetCodeEntry(
        edinet_code='E38117',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='宮越グループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミヤコシグループカブシキガイシャ',
        address='大田区大森北１－２３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010801033315',
    ),
    'E38118': EdinetCodeEntry(
        edinet_code='E38118',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=585,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アルファパーチェス',
        submitter_name_en='AlphaPurchase Corporation',
        submitter_name_yomi='カブシキガイシャアルファパーチェス',
        address='港区三田一丁目４番２８号\u3000三田国際ビル１５階',
        industry='卸売業',
        sec_code='71150',
        corporate_number='8010401090648',
    ),
    'E38122': EdinetCodeEntry(
        edinet_code='E38122',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桑畑夏美',
        submitter_name_en=None,
        submitter_name_yomi='クワハタナツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38123': EdinetCodeEntry(
        edinet_code='E38123',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加福\u3000秀亙',
        submitter_name_en=None,
        submitter_name_yomi='カフク\u3000ヒデノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38124': EdinetCodeEntry(
        edinet_code='E38124',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='創展環球有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ジェネシスユニバーサルリミテッド',
        address='香港長沙湾瓊林街８３号Ａ棟２１階２１１６号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38126': EdinetCodeEntry(
        edinet_code='E38126',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='大津\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='オオツ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38128': EdinetCodeEntry(
        edinet_code='E38128',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='株式会社アダチメディカルレンタルリース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアダチメディカルレンタルリース',
        address='大阪市中央区内平野町３－２－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120002057730',
    ),
    'E38129': EdinetCodeEntry(
        edinet_code='E38129',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='11月末日',
        submitter_name='株式会社ｐｒｏｐｅｒｔｙ\u3000ｔｅｃｈｎｏｌｏｇｉｅｓ',
        submitter_name_en='property technologies Inc.',
        submitter_name_yomi='カブシキカイシャプロパティテクノロジーズ',
        address='渋谷区本町三丁目１２番１号',
        industry='不動産業',
        sec_code='55270',
        corporate_number='5011001137024',
    ),
    'E38130': EdinetCodeEntry(
        edinet_code='E38130',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='土屋\u3000昌三',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤ\u3000ショウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38131': EdinetCodeEntry(
        edinet_code='E38131',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社コーチ・エフ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャコーチエフ',
        address='渋谷区元代々木町３９番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010902019851',
    ),
    'E38132': EdinetCodeEntry(
        edinet_code='E38132',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='Ｓｐｉｃａ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='スピカミテッド',
        address='ケイマン諸島、ＫＹ１ー１２０９、グランド・ケイマン、ガバナーズ・スクウェア、私書箱３２３１１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38133': EdinetCodeEntry(
        edinet_code='E38133',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社エルティー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエルティー',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001227538',
    ),
    'E38134': EdinetCodeEntry(
        edinet_code='E38134',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='岡野商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オカノショウジカブシキガイシャ',
        address='北九州市門司区港町１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5290801005156',
    ),
    'E38139': EdinetCodeEntry(
        edinet_code='E38139',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=350,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アソインターナショナル',
        submitter_name_en=None,
        submitter_name_yomi='アソインターナショナル',
        address='中央区銀座２丁目１１番８号\u3000第２２中央ビル３階',
        industry='その他製品',
        sec_code='93400',
        corporate_number='5010001035717',
    ),
    'E38140': EdinetCodeEntry(
        edinet_code='E38140',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='前田\u3000佳宏',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38142': EdinetCodeEntry(
        edinet_code='E38142',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='山本\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38144': EdinetCodeEntry(
        edinet_code='E38144',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社ヘーリオスエネルギー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヘーリオスエネルギー',
        address='渋谷区神南一丁目５番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001146715',
    ),
    'E38146': EdinetCodeEntry(
        edinet_code='E38146',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社デュケレ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャデュケレ',
        address='横浜市西区みなとみらい４－１０－２－Ｓ２３０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011103003917',
    ),
    'E38147': EdinetCodeEntry(
        edinet_code='E38147',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金田辰男',
        submitter_name_en=None,
        submitter_name_yomi='カネダタツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38148': EdinetCodeEntry(
        edinet_code='E38148',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5907,
        fiscal_year_end='3月末日',
        submitter_name='大栄環境株式会社',
        submitter_name_en='Daiei Kankyo Co., Ltd.',
        submitter_name_yomi='ダイエイカンキョウカブシキガイシャ',
        address='和泉市テクノステージ二丁目３番２８号',
        industry='サービス業',
        sec_code='93360',
        corporate_number='6120101041611',
    ),
    'E38152': EdinetCodeEntry(
        edinet_code='E38152',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38155': EdinetCodeEntry(
        edinet_code='E38155',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=152,
        fiscal_year_end='6月30日',
        submitter_name='ＧＬＯＥ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グローカブシキガイシャ',
        address='新宿区西新宿７－５－２５\u3000西新宿プライムスクエア１５階',
        industry='サービス業',
        sec_code='95650',
        corporate_number='3011001108349',
    ),
    'E38156': EdinetCodeEntry(
        edinet_code='E38156',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=157,
        fiscal_year_end='12月31日',
        submitter_name='株式会社サイフューズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサイフューズ',
        address='港区三田３－５－２７\u3000住友不動産三田ツインビル西館',
        industry='医薬品',
        sec_code='48920',
        corporate_number='1010001140223',
    ),
    'E38157': EdinetCodeEntry(
        edinet_code='E38157',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1057,
        fiscal_year_end='12月31日',
        submitter_name='ｍｏｎｏＡＩ\u3000ｔｅｃｈｎｏｌｏｇｙ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モノアイテクノロジーカブシキガイシャ',
        address='神戸市中央区三宮町一丁目８番１号\u3000さんプラザ３階３４号室',
        industry='情報・通信業',
        sec_code='52400',
        corporate_number='3011101065465',
    ),
    'E38160': EdinetCodeEntry(
        edinet_code='E38160',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＩＲ－Ｕ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエアーユー',
        address='港区北青山一丁目２番３号青山ビル１３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401129230',
    ),
    'E38161': EdinetCodeEntry(
        edinet_code='E38161',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊池\u3000淳司',
        submitter_name_en=None,
        submitter_name_yomi='キクチ\u3000ジュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38162': EdinetCodeEntry(
        edinet_code='E38162',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=89,
        fiscal_year_end='12月31日',
        submitter_name='株式会社トリドリ',
        submitter_name_en='toridori Inc.',
        submitter_name_yomi='カブシキガイシャトリドリ',
        address='渋谷区円山町２８番１号',
        industry='サービス業',
        sec_code='93370',
        corporate_number='6011001111250',
    ),
    'E38163': EdinetCodeEntry(
        edinet_code='E38163',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=218,
        fiscal_year_end='12月31日',
        submitter_name='株式会社アイズ',
        submitter_name_en='EYEZ,INC.',
        submitter_name_yomi='カブシキカイシャアイズ',
        address='渋谷区渋谷三丁目１２番２２号',
        industry='サービス業',
        sec_code='52420',
        corporate_number='3011001051128',
    ),
    'E38164': EdinetCodeEntry(
        edinet_code='E38164',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=336,
        fiscal_year_end='12月末日',
        submitter_name='株式会社エージェント・インシュアランス・グループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエージェントインシュアランスグループ',
        address='新宿区市谷本村町３ー２９',
        industry='保険業',
        sec_code=None,
        corporate_number='5010401054515',
    ),
    'E38166': EdinetCodeEntry(
        edinet_code='E38166',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武井\u3000泰士',
        submitter_name_en=None,
        submitter_name_yomi='タケイ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38167': EdinetCodeEntry(
        edinet_code='E38167',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社フーディソン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフーディソン',
        address='中央区勝どき３－３－７',
        industry='情報・通信業',
        sec_code='71140',
        corporate_number='8010401104993',
    ),
    'E38168': EdinetCodeEntry(
        edinet_code='E38168',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1135,
        fiscal_year_end='3月31日',
        submitter_name='株式会社サンクゼール',
        submitter_name_en='St.Cousair CO.,LTD.',
        submitter_name_yomi='カブシキカイシャサンクゼール',
        address='上水内郡飯綱町大字芋川１２６０番地',
        industry='食料品',
        sec_code='29370',
        corporate_number='4100001004085',
    ),
    'E38169': EdinetCodeEntry(
        edinet_code='E38169',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='11月末日',
        submitter_name='株式会社ＥＬＥＭＥＮＴＳ',
        submitter_name_en='ELEMENTS, Inc.',
        submitter_name_yomi='カブシキガイシャエレメンツ',
        address='中央区日本橋本町３－８－３日本橋ライフサイエンスビルディング３',
        industry='情報・通信業',
        sec_code='52460',
        corporate_number='4011001098069',
    ),
    'E38171': EdinetCodeEntry(
        edinet_code='E38171',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=167,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｒｅｂａｓｅ',
        submitter_name_en='Rebase, Inc.',
        submitter_name_yomi='カブシキガイシャリベース',
        address='渋谷区神宮前四丁目２６番１８号',
        industry='情報・通信業',
        sec_code='51380',
        corporate_number='1010901034004',
    ),
    'E38172': EdinetCodeEntry(
        edinet_code='E38172',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='栗原\u3000慎吾',
        submitter_name_en=None,
        submitter_name_yomi='クリハラ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38174': EdinetCodeEntry(
        edinet_code='E38174',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='原田\u3000恵吾',
        submitter_name_en=None,
        submitter_name_yomi='ハラダ\u3000ケイゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38176': EdinetCodeEntry(
        edinet_code='E38176',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='太田事務所株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオタジムショカブシキガイシャ',
        address='武蔵野市中町３－２５－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3012401039456',
    ),
    'E38177': EdinetCodeEntry(
        edinet_code='E38177',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000敦井奨学会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000ツルイショウガクカイ',
        address='新潟市中央区東大通一丁目２番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3110005014799',
    ),
    'E38178': EdinetCodeEntry(
        edinet_code='E38178',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=605,
        fiscal_year_end='12月末日',
        submitter_name='株式会社コーチ・エィ',
        submitter_name_en='COACH A Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャコーチエィ',
        address='千代田区九段南二丁目１番３０号',
        industry='サービス業',
        sec_code='93390',
        corporate_number='6010001075555',
    ),
    'E38179': EdinetCodeEntry(
        edinet_code='E38179',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6700,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＯＴＯＫＵ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトウトク',
        address='港区西新橋三丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001230223',
    ),
    'E38180': EdinetCodeEntry(
        edinet_code='E38180',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1610,
        fiscal_year_end='12月末日',
        submitter_name='オープンワーク株式会社',
        submitter_name_en='OpenWork Inc.',
        submitter_name_yomi='オープンワークカブシキガイシャ',
        address='渋谷区渋谷二丁目２４番１２号\u3000渋谷スクランブルスクエア',
        industry='情報・通信業',
        sec_code='51390',
        corporate_number='4011001063527',
    ),
    'E38181': EdinetCodeEntry(
        edinet_code='E38181',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社オーバービュー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーバービュー',
        address='大阪市中央区久宝寺町３－４－１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001126234',
    ),
    'E38182': EdinetCodeEntry(
        edinet_code='E38182',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000海',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000カイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38183': EdinetCodeEntry(
        edinet_code='E38183',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙畠\u3000裕二',
        submitter_name_en=None,
        submitter_name_yomi='タカバタケ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38184': EdinetCodeEntry(
        edinet_code='E38184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近藤\u3000隆',
        submitter_name_en=None,
        submitter_name_yomi='コンドウ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38185': EdinetCodeEntry(
        edinet_code='E38185',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=230,
        fiscal_year_end=None,
        submitter_name='ＷＩＬＬ\u3000ＦＩＥＬＤ\u3000ＣＡＰＩＴＡＬ\u3000ＰＴＥ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='ウィル\u3000フィールド\u3000キャピタル\u3000ピーティーイー\u3000エルティーディー',
        address='シンガポール',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38186': EdinetCodeEntry(
        edinet_code='E38186',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='セブンキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セブンキャピタルカブシキガイシャ',
        address='大阪市都島区高倉町３－１５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001224430',
    ),
    'E38187': EdinetCodeEntry(
        edinet_code='E38187',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27875,
        fiscal_year_end=None,
        submitter_name='株式会社ユーザベース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーザベース',
        address='千代田区丸の内二丁目５番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001230222',
    ),
    'E38190': EdinetCodeEntry(
        edinet_code='E38190',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=150,
        fiscal_year_end='8月31日',
        submitter_name='めぶくグラウンド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メブクグラウンドカブシキガイシャ',
        address='前橋市表町二丁目３０番８号ＡＱＥＲＵ６Ｆ',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='6070001039736',
    ),
    'E38191': EdinetCodeEntry(
        edinet_code='E38191',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=182,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＢＴＭ',
        submitter_name_en='BTM, Inc.',
        submitter_name_yomi='カブシキガイシャビーティーエム',
        address='渋谷区神泉町９－１\u3000Ｄａｉｗａ渋谷神泉ビル\u3000２階',
        industry='情報・通信業',
        sec_code='52470',
        corporate_number='4010701025456',
    ),
    'E38192': EdinetCodeEntry(
        edinet_code='E38192',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＩＮＦＯＲＩＣＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャインフォリッチ',
        address='渋谷区神宮前五丁目５２番２号',
        industry='サービス業',
        sec_code='93380',
        corporate_number='5011001107217',
    ),
    'E38193': EdinetCodeEntry(
        edinet_code='E38193',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鳥生格',
        submitter_name_en=None,
        submitter_name_yomi='トリウカク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38194': EdinetCodeEntry(
        edinet_code='E38194',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='高橋和久',
        submitter_name_en=None,
        submitter_name_yomi='タカハシカズヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38200': EdinetCodeEntry(
        edinet_code='E38200',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=213,
        fiscal_year_end='9月末日',
        submitter_name='株式会社スマサポ',
        submitter_name_en='Sumasapo Inc.',
        submitter_name_yomi='カブシキガイシャスマサポ',
        address='中央区日本橋３－６－２',
        industry='サービス業',
        sec_code='93420',
        corporate_number='1120001170275',
    ),
    'E38201': EdinetCodeEntry(
        edinet_code='E38201',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=877,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ｊｉｇ．ｊｐ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジグジェイピー',
        address='鯖江市横越町第１０号３４番地１',
        industry='情報・通信業',
        sec_code='52440',
        corporate_number='3011101042092',
    ),
    'E38202': EdinetCodeEntry(
        edinet_code='E38202',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='ダイワ通信株式会社',
        submitter_name_en='DAIWA TSUSHIN Co., Ltd',
        submitter_name_yomi='ダイワツウシンカブシキカイシャ',
        address='金沢市入江二丁目１８０番地',
        industry='情報・通信業',
        sec_code='71160',
        corporate_number='2220001020849',
    ),
    'E38203': EdinetCodeEntry(
        edinet_code='E38203',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='岩本\u3000秀成',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000ヒデナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38205': EdinetCodeEntry(
        edinet_code='E38205',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月30日',
        submitter_name='株式会社スマートドライブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスマートドライブ',
        address='千代田区有楽町一丁目１番２号',
        industry='情報・通信業',
        sec_code='51370',
        corporate_number='9010901033015',
    ),
    'E38206': EdinetCodeEntry(
        edinet_code='E38206',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='アリアケ・マスター・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='アリアケマスターファンド',
        address='ハーニーズ・フィディシャリー（ケイマン）リミテッド４階、ハーパープレイス、サウスチャーチストリート１０３、私書箱１０２４０、グランドケイマンＫＹ１ー１００２、ケイマン諸島',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38207': EdinetCodeEntry(
        edinet_code='E38207',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='平瀬\u3000智樹',
        submitter_name_en=None,
        submitter_name_yomi='ヒラセ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38209': EdinetCodeEntry(
        edinet_code='E38209',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社伊藤ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイトウホールディングス',
        address='千代田区三番町６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001185399',
    ),
    'E38210': EdinetCodeEntry(
        edinet_code='E38210',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=787,
        fiscal_year_end=None,
        submitter_name='株式会社カカオインベストメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカカオインベストメント',
        address='大韓民国京畿道城南市盆唐区板橋驛路１６６、Ｂ棟９階（ペッキョンドン、カカオ板橋アジト）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38211': EdinetCodeEntry(
        edinet_code='E38211',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='青柳\u3000和洋',
        submitter_name_en=None,
        submitter_name_yomi='アオヤギ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38212': EdinetCodeEntry(
        edinet_code='E38212',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='大東製糖株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイトウセイトウカブシキカイシャ',
        address='千葉市美浜区新港４４番',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3040001011205',
    ),
    'E38214': EdinetCodeEntry(
        edinet_code='E38214',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社フロンティアグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフロンティアグループ',
        address='千代田区外神田五丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001128861',
    ),
    'E38215': EdinetCodeEntry(
        edinet_code='E38215',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=115,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＧＥＮＯＶＡ',
        submitter_name_en='GENOVA,Inc.',
        submitter_name_yomi='カブシキカイシャジェノヴァ',
        address='渋谷区渋谷二丁目２１番１号渋谷ヒカリエ３４階',
        industry='サービス業',
        sec_code='93410',
        corporate_number='6011001046711',
    ),
    'E38216': EdinetCodeEntry(
        edinet_code='E38216',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺村\u3000久義',
        submitter_name_en=None,
        submitter_name_yomi='テラムラ\u3000ヒサヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38218': EdinetCodeEntry(
        edinet_code='E38218',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='片山チエン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カタヤマチエンカブシキガイシャ',
        address='東大阪市本庄西二丁目３番４３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001042282',
    ),
    'E38219': EdinetCodeEntry(
        edinet_code='E38219',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5130,
        fiscal_year_end=None,
        submitter_name='ツェナ・インベストメント・マネジメント・エルエルシー（Ｐｚｅｎａ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000ＬＬＣ）',
        submitter_name_en=None,
        submitter_name_yomi='ツェナ\u3000インベストメント\u3000マネジメント\u3000エルエルシー',
        address='３２０\u3000パークアベニュー\u3000８階\u3000ニューヨーク\u3000ニューヨーク州\u3000１００２２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38221': EdinetCodeEntry(
        edinet_code='E38221',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='ＪＡＩＣシードキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャイクシードキャピタルカブシキカイシャ',
        address='千代田区九段北３丁目２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001094871',
    ),
    'E38222': EdinetCodeEntry(
        edinet_code='E38222',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='虎ノ門パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トラノモンパートナーズカブシキガイシャ',
        address='港区虎ノ門四丁目１番３４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401169240',
    ),
    'E38223': EdinetCodeEntry(
        edinet_code='E38223',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='合同会社ＸＥホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャエックスイーホールディングス',
        address='港区高輪１丁目２３番３３号４０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010703002547',
    ),
    'E38229': EdinetCodeEntry(
        edinet_code='E38229',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ダイテックホールディング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイテックホールディング',
        address='品川区南大井６丁目１６番１９号\u3000大森ＭＨビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001107247',
    ),
    'E38230': EdinetCodeEntry(
        edinet_code='E38230',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1105,
        fiscal_year_end=None,
        submitter_name='ＬＥＥ\u3000ＷＯ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＧＲＯＵＰ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='リー\u3000ウォウ\u3000ヴェストメント\u3000グループ\u3000リミティド',
        address='ＦＬＡＴ\u3000Ｂ１６，Ｂ１Ｋ\u3000Ｂ，１Ｆ\u3000ＰＲＯＦＩＣＩＥＮＴ\u3000ＩＮＤＵＳＴＲＩＡＬ\u3000ＣＥＮＴＲＥ，ＮＯ．６\u3000ＷＡＮＧ\u3000ＫＷＵＮ\u3000ＲＯＡＤ，ＫＬ，ＨＯＮＧＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38231': EdinetCodeEntry(
        edinet_code='E38231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000貴之',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38232': EdinetCodeEntry(
        edinet_code='E38232',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='堀口\u3000英樹',
        submitter_name_en=None,
        submitter_name_yomi='ホリグチ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38233': EdinetCodeEntry(
        edinet_code='E38233',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='リード・キャピタル・マネージメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リードキャピタルマネージメントカブシキガイシャ',
        address='港区赤坂八丁目５番４０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001103759',
    ),
    'E38235': EdinetCodeEntry(
        edinet_code='E38235',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人村山財産管理',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンムラヤマザイサンカンリ',
        address='千代田区永田町二丁目１２番４号\u3000リオ・パートナーズ総合事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010005035153',
    ),
    'E38236': EdinetCodeEntry(
        edinet_code='E38236',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='国本\u3000貴志',
        submitter_name_en=None,
        submitter_name_yomi='クニモト\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38238': EdinetCodeEntry(
        edinet_code='E38238',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=51,
        fiscal_year_end=None,
        submitter_name='株式会社リープラジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャリープラジャパン',
        address='福岡県福岡市中央区天神四丁目３ー８ミーナ天神８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401125813',
    ),
    'E38240': EdinetCodeEntry(
        edinet_code='E38240',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='ＲＳ\u3000Ｃｏｍｐａｎｙ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='アールエス\u3000カンパニー\u3000リミテッド',
        address='ケイマン諸島\u3000ＫＹ１－１１０４\u3000グランド・ケイマン\u3000ウグランド・ハウス私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38241': EdinetCodeEntry(
        edinet_code='E38241',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社諸戸ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモロトホールディングス',
        address='桑名市太一丸１８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4190001013350',
    ),
    'E38242': EdinetCodeEntry(
        edinet_code='E38242',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＣインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェーシーインベストメントカブシキカイシャ',
        address='港区南青山２－２２－４－４０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401136556',
    ),
    'E38244': EdinetCodeEntry(
        edinet_code='E38244',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='ありあけキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アリアケキャピタルカブシキカイシャ',
        address='中央区日本橋兜町５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001207700',
    ),
    'E38245': EdinetCodeEntry(
        edinet_code='E38245',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000和弥',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000カズヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38247': EdinetCodeEntry(
        edinet_code='E38247',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=845,
        fiscal_year_end=None,
        submitter_name='住友生命第３回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイダイサンカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001230857',
    ),
    'E38248': EdinetCodeEntry(
        edinet_code='E38248',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人関奉仕財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンセキホウシザイダン',
        address='松山市湊町七丁目７番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4500005006839',
    ),
    'E38252': EdinetCodeEntry(
        edinet_code='E38252',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='増井\u3000慎二郎',
        submitter_name_en=None,
        submitter_name_yomi='マスイ\u3000シンジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38255': EdinetCodeEntry(
        edinet_code='E38255',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岸\u3000周平',
        submitter_name_en=None,
        submitter_name_yomi='キシ\u3000シュウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38256': EdinetCodeEntry(
        edinet_code='E38256',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=630,
        fiscal_year_end='1月末日',
        submitter_name='株式会社テクノロジーズ',
        submitter_name_en='TECHNOLOGIES, Inc.',
        submitter_name_yomi='カブシキガイシャテクノロジーズ',
        address='港区白金１丁目２７番６号',
        industry='情報・通信業',
        sec_code='52480',
        corporate_number='3010901034654',
    ),
    'E38257': EdinetCodeEntry(
        edinet_code='E38257',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='アルファソリッド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アルファソリッドカブシキガイシャ',
        address='大阪市都島区高倉町３丁目１５番１号５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001127665',
    ),
    'E38258': EdinetCodeEntry(
        edinet_code='E38258',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ザ・ファーストドア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャザファーストドア',
        address='港区芝４－５－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001109620',
    ),
    'E38262': EdinetCodeEntry(
        edinet_code='E38262',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='田中\u3000康之助',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000コウノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38263': EdinetCodeEntry(
        edinet_code='E38263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社綿屋半三郎',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワタヤハンザブロウ',
        address='新宿区中落合３丁目１４番地３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011101044452',
    ),
    'E38266': EdinetCodeEntry(
        edinet_code='E38266',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福野\u3000泰介',
        submitter_name_en=None,
        submitter_name_yomi='フクノ\u3000タイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38267': EdinetCodeEntry(
        edinet_code='E38267',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムホールディングス',
        address='高槻市美しが丘１－３－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120901036965',
    ),
    'E38271': EdinetCodeEntry(
        edinet_code='E38271',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アクセンチュア\u3000グローバル\u3000ホールディングス\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アクセンチュア\u3000グローバル\u3000ホールディングス\u3000リミテッド',
        address='アイルランド共和国\u3000ダブリン２、グランド\u3000キャナル\u3000ハーバー、グランド\u3000キャナル\u3000スクウェア１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38272': EdinetCodeEntry(
        edinet_code='E38272',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='アクセンチュア\u3000ホールディングス\u3000ビーブイ',
        submitter_name_en=None,
        submitter_name_yomi='アクセンチュア\u3000ホールディングス\u3000ビーブイ',
        address='オランダ王国１０８２ＭＡ\u3000アムステルダム、グスタヴマーラープレイン９０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38273': EdinetCodeEntry(
        edinet_code='E38273',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22013,
        fiscal_year_end=None,
        submitter_name='アクセンチュア\u3000インターナショナル\u3000ビーブイ',
        submitter_name_en=None,
        submitter_name_yomi='アクセンチュア\u3000インターナショナル\u3000ビーブイ',
        address='オランダ王国１０８２ＭＡ\u3000アムステルダム、グスタヴマーラープレイン９０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38274': EdinetCodeEntry(
        edinet_code='E38274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2100,
        fiscal_year_end=None,
        submitter_name='ＮＨＮ\u3000テコラス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエイチエヌテコラスカブシキガイシャ',
        address='港区西新橋三丁目１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101045256',
    ),
    'E38276': EdinetCodeEntry(
        edinet_code='E38276',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1113,
        fiscal_year_end=None,
        submitter_name='ＪＡＦＣＯ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000（Ａｓｉａ\u3000Ｐａｃｉｆｉｃ）\u3000Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='ジャフコ\u3000インベストメント\u3000アジア\u3000パシフィック\u3000リミテッド',
        address='１０\u3000Ｃｏｌｌｙｅｒ\u3000Ｑｕａｙ\u3000＃０５－０７，\u3000Ｏｃｅａｎ\u3000Ｆｉｎａｎｃｉａｌ\u3000Ｃｅｎｔｒｅ，\u3000Ｓｉｎｇａｐｏｒｅ\u3000０４９３１５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38277': EdinetCodeEntry(
        edinet_code='E38277',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='本城\u3000嘉太郎',
        submitter_name_en=None,
        submitter_name_yomi='ホンジョウ\u3000ヨシタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38279': EdinetCodeEntry(
        edinet_code='E38279',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社松濤',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャショウトウ',
        address='熊本市中央区神水一丁目３８番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3330001022453',
    ),
    'E38280': EdinetCodeEntry(
        edinet_code='E38280',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='神谷町パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カミヤチョウパートナーズカブシキガイシャ',
        address='港区虎ノ門四丁目１番３４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401169239',
    ),
    'E38281': EdinetCodeEntry(
        edinet_code='E38281',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='野村スパークス・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノムラスパークスインベストメントカブシキガイシャ',
        address='千代田区大手町二丁目２番２号アーバンネット大手町ビル１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001217133',
    ),
    'E38282': EdinetCodeEntry(
        edinet_code='E38282',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='溝部\u3000孝志',
        submitter_name_en=None,
        submitter_name_yomi='ミゾベ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38283': EdinetCodeEntry(
        edinet_code='E38283',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋山\u3000広宣',
        submitter_name_en=None,
        submitter_name_yomi='アキヤマ\u3000ヒロノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38285': EdinetCodeEntry(
        edinet_code='E38285',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='牧田\u3000伸一',
        submitter_name_en=None,
        submitter_name_yomi='マキタ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38286': EdinetCodeEntry(
        edinet_code='E38286',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社古知',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコチ',
        address='港区虎ノ門四丁目１番３４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010601011899',
    ),
    'E38287': EdinetCodeEntry(
        edinet_code='E38287',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='立川\u3000光昭',
        submitter_name_en=None,
        submitter_name_yomi='タチカワ\u3000ミツアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38288': EdinetCodeEntry(
        edinet_code='E38288',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=734,
        fiscal_year_end='9月30日',
        submitter_name='ＢＢＤイニシアティブ株式会社',
        submitter_name_en='BBD Initiative Inc.',
        submitter_name_yomi='ビービーディーイニシアティブカブシキカイシャ',
        address='港区愛宕二丁目５番１号',
        industry='情報・通信業',
        sec_code='52590',
        corporate_number='8010401173510',
    ),
    'E38289': EdinetCodeEntry(
        edinet_code='E38289',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７０',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイセブンティー',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001231021',
    ),
    'E38290': EdinetCodeEntry(
        edinet_code='E38290',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=96,
        fiscal_year_end=None,
        submitter_name='ウイングトワ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウイングトワカブシキガイシャ',
        address='神戸市東灘区御影中町三丁目２番４ー４７０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2140001026689',
    ),
    'E38291': EdinetCodeEntry(
        edinet_code='E38291',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩井\u3000スマ',
        submitter_name_en=None,
        submitter_name_yomi='シオイ\u3000スマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38293': EdinetCodeEntry(
        edinet_code='E38293',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=336,
        fiscal_year_end=None,
        submitter_name='コネクシオ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コネクシオカブシキガイシャ',
        address='港区虎ノ門４丁目１番１号\u3000神谷町トラストタワー７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001149130',
    ),
    'E38294': EdinetCodeEntry(
        edinet_code='E38294',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='真鍋\u3000英',
        submitter_name_en=None,
        submitter_name_yomi='マナベ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38295': EdinetCodeEntry(
        edinet_code='E38295',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='真鍋\u3000光',
        submitter_name_en=None,
        submitter_name_yomi='マナベ\u3000ヒカル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38296': EdinetCodeEntry(
        edinet_code='E38296',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='真鍋\u3000妙',
        submitter_name_en=None,
        submitter_name_yomi='マナベ\u3000タエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38297': EdinetCodeEntry(
        edinet_code='E38297',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='真鍋\u3000守利',
        submitter_name_en=None,
        submitter_name_yomi='マナベ\u3000モリトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38298': EdinetCodeEntry(
        edinet_code='E38298',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社梅田事務所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウメダジムショ',
        address='名古屋市熱田区横田一丁目１番５２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001153773',
    ),
    'E38299': EdinetCodeEntry(
        edinet_code='E38299',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='十河\u3000宏輔',
        submitter_name_en=None,
        submitter_name_yomi='ソゴウ\u3000コウスケ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38300': EdinetCodeEntry(
        edinet_code='E38300',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小堤\u3000音彦',
        submitter_name_en=None,
        submitter_name_yomi='コヅツミ\u3000オトヒコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38301': EdinetCodeEntry(
        edinet_code='E38301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='福島\u3000範幸',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000ノリユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38302': EdinetCodeEntry(
        edinet_code='E38302',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='フェムトパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フェムトパートナーズカブシキカイシャ',
        address='港区南青山一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001120643',
    ),
    'E38303': EdinetCodeEntry(
        edinet_code='E38303',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='濱中\u3000雄大',
        submitter_name_en=None,
        submitter_name_yomi='ハマナカ\u3000タケヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38305': EdinetCodeEntry(
        edinet_code='E38305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='東京大元持株会\u3000理事長\u3000宮﨑雅晴',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウダイゲンモチカブカイ\u3000リジチョウ\u3000ミヤザキマサハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38306': EdinetCodeEntry(
        edinet_code='E38306',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='阿曽\u3000敏正',
        submitter_name_en=None,
        submitter_name_yomi='アソ\u3000トシマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38309': EdinetCodeEntry(
        edinet_code='E38309',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥山\u3000宏昭',
        submitter_name_en=None,
        submitter_name_yomi='オクヤマ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38310': EdinetCodeEntry(
        edinet_code='E38310',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='奥山\u3000伸子',
        submitter_name_en=None,
        submitter_name_yomi='オクヤマ\u3000ノブコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38313': EdinetCodeEntry(
        edinet_code='E38313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='久田\u3000康弘',
        submitter_name_en=None,
        submitter_name_yomi='クダ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38316': EdinetCodeEntry(
        edinet_code='E38316',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋枝\u3000静香',
        submitter_name_en=None,
        submitter_name_yomi='アキエダ\u3000シズカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38318': EdinetCodeEntry(
        edinet_code='E38318',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3300,
        fiscal_year_end=None,
        submitter_name='株式会社アンプロモーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアンプロモーション',
        address='港区赤坂一丁目５番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401057335',
    ),
    'E38321': EdinetCodeEntry(
        edinet_code='E38321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=123,
        fiscal_year_end=None,
        submitter_name='中国総合信用株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チュウゴクソウゴウシンヨウカブシキカイシャ',
        address='広島市東区光町二丁目８番３７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001012785',
    ),
    'E38322': EdinetCodeEntry(
        edinet_code='E38322',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＴインベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムティーインベストメントカブシキガイシャ',
        address='東京都港区港南二丁目５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401137448',
    ),
    'E38324': EdinetCodeEntry(
        edinet_code='E38324',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＯＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーオーシー',
        address='新宿区西新宿３－２－９\u3000新宿ワシントンホテルビル本館２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401128244',
    ),
    'E38325': EdinetCodeEntry(
        edinet_code='E38325',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000勝彦',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000カツヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38326': EdinetCodeEntry(
        edinet_code='E38326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='不二ラテックス共栄会\u3000理事長\u3000田中\u3000眞介',
        submitter_name_en=None,
        submitter_name_yomi='フジラテックスキョウエイカイ\u3000リジチョウ\u3000タナカ\u3000シンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38327': EdinetCodeEntry(
        edinet_code='E38327',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='大東建託パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイトウケンタクパートナーズカブシキカイシャ',
        address='港区港南２丁目１６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401016618',
    ),
    'E38331': EdinetCodeEntry(
        edinet_code='E38331',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=38519,
        fiscal_year_end=None,
        submitter_name='ラクテン・キャピタル・エス・シー・エスピー',
        submitter_name_en=None,
        submitter_name_yomi='ラクテン\u3000キャピタル\u3000エス\u3000シー\u3000エスピー',
        address='ルクセンブルク大公国ルクセンブルク\u3000リュ\u3000ドゥ\u3000フォセ２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38332': EdinetCodeEntry(
        edinet_code='E38332',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷田\u3000優也',
        submitter_name_en=None,
        submitter_name_yomi='タニダ\u3000ユウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38333': EdinetCodeEntry(
        edinet_code='E38333',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙尾\u3000恭平',
        submitter_name_en=None,
        submitter_name_yomi='タカオ\u3000キョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38334': EdinetCodeEntry(
        edinet_code='E38334',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='副島\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='ソエジマ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38335': EdinetCodeEntry(
        edinet_code='E38335',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=257,
        fiscal_year_end='12月31日',
        submitter_name='ノバシステム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノバシステムカブシキガイシャ',
        address='大阪市西区江戸堀１丁目３番１５号',
        industry='情報・通信業',
        sec_code='52570',
        corporate_number='8120001046444',
    ),
    'E38336': EdinetCodeEntry(
        edinet_code='E38336',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社アーム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアーム',
        address='渋谷区神宮前六丁目２３番４号桑野ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001055227',
    ),
    'E38337': EdinetCodeEntry(
        edinet_code='E38337',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ルビィ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャルビィ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003038342',
    ),
    'E38339': EdinetCodeEntry(
        edinet_code='E38339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='太田\u3000卓利',
        submitter_name_en=None,
        submitter_name_yomi='オオタ\u3000タクトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38341': EdinetCodeEntry(
        edinet_code='E38341',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久世\u3000良太',
        submitter_name_en=None,
        submitter_name_yomi='クゼ\u3000リョウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38342': EdinetCodeEntry(
        edinet_code='E38342',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トークン・ツー合同会社',
        submitter_name_en=None,
        submitter_name_yomi='トークンツーゴウドウガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003039193',
    ),
    'E38343': EdinetCodeEntry(
        edinet_code='E38343',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＪ２０１５．ＦＵＮＤ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='ティージェーニゼロイチゴーファンド\u3000エルピー',
        address='ｃ／ｏ\u3000Ｉｎｔｅｒｔｒｕｓｔ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000（Ｃａｙｍａｎ）\u3000Ｌｉｍｉｔｅｄ，\u3000Ｏｎｅ\u3000Ｎｅｘｕｓ\u3000Ｗａｙ，\u3000Ｃａｍａｎａ\u3000Ｂａｙ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００５，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38344': EdinetCodeEntry(
        edinet_code='E38344',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｇｌｏｂａｌ\u3000Ｃａｔａｌｙｓｔ\u3000Ｖｅｎｔｕｒｅ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｊａｐａｎ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='グローバルカタリストベンチャーマネジメントジャパンゴウドウカイシャ',
        address='港区南青山１丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403015128',
    ),
    'E38345': EdinetCodeEntry(
        edinet_code='E38345',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1514,
        fiscal_year_end=None,
        submitter_name='ＧＭＣＭ\u3000ＶＥＮＴＵＲＥＳ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ジーエムシーエム\u3000ベンチャーズ\u3000プライベート\u3000リミテッド',
        address='８０\u3000ＲＯＢＩＮＳＯＮ\u3000ＲＯＡＤ，\u3000＃１３－０３\u3000ＳＩＮＧＡＰＯＲＥ\u3000（０６８８９８）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38346': EdinetCodeEntry(
        edinet_code='E38346',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='中村\u3000けん牛',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ケンギュウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38348': EdinetCodeEntry(
        edinet_code='E38348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＭＵ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーエムユー',
        address='港区南青山四丁目１７番３５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401162123',
    ),
    'E38349': EdinetCodeEntry(
        edinet_code='E38349',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='蜂屋\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='ハチヤ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38359': EdinetCodeEntry(
        edinet_code='E38359',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｈｉｋａｒｉ\u3000Ａｃｑｕｉｓｉｔｉｏｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒカリアクイジションカブシキガイシャ',
        address='港区西新橋二丁目１５番７号ＭＳＣ西新橋ビル３階税理士法人ＡＫＪパートナーズ内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401162779',
    ),
    'E38365': EdinetCodeEntry(
        edinet_code='E38365',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='豊住\u3000清',
        submitter_name_en=None,
        submitter_name_yomi='トヨズミ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38367': EdinetCodeEntry(
        edinet_code='E38367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=429,
        fiscal_year_end='11月30日',
        submitter_name='プライム・ストラテジー株式会社',
        submitter_name_en='Prime Strategy Co.,Ltd.',
        submitter_name_yomi='プライムストラテジーカブシキガイシャ',
        address='千代田区一番町８番地住友不動産一番町ビル１階',
        industry='情報・通信業',
        sec_code='52500',
        corporate_number='2010401081974',
    ),
    'E38368': EdinetCodeEntry(
        edinet_code='E38368',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ｙｏｓｈｉｄａ\u3000ｉｎｖｅｓｔｍｅｎｔ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダインベストメントカブシキガイシャ',
        address='小諸市丙３８０番地５リバーサイドヴィラＢ２０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401137446',
    ),
    'E38370': EdinetCodeEntry(
        edinet_code='E38370',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＷＩＳＥＬＹ\u3000ＨＡＲＶＥＳＴ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ワイズリー\u3000ハーベスト\u3000リミテッド',
        address='３１／ｆ，\u3000Ｆｕｎ\u3000Ｔｏｗｅｒ，\u3000Ｎｏ．３５\u3000Ｈｕｎｇ\u3000Ｔｏ\u3000Ｒｏａｄ，\u3000Ｋｗｕｎ\u3000Ｔｏｎｇ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38373': EdinetCodeEntry(
        edinet_code='E38373',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='12月31日',
        submitter_name='株式会社日本オーエー研究所',
        submitter_name_en='Nihon Office Automation Research Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャニホンオーエーケンキュウショ',
        address='千代田区西神田三丁目２番１号\u3000住友不動産千代田ファーストビル南館４階',
        industry='情報・通信業',
        sec_code='52410',
        corporate_number='7010001006022',
    ),
    'E38376': EdinetCodeEntry(
        edinet_code='E38376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='Ｈａｐｐｙ\u3000Ｅｌｅｍｅｎｔｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハッピーエレメンツカブシキガイシャ',
        address='京都市下京区東洞院通四条下ル元悪王子町５１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401087200',
    ),
    'E38377': EdinetCodeEntry(
        edinet_code='E38377',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='シグマシンカ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シグマシンカカブシキガイシャ',
        address='千代田区神田司町二丁目１０番４号\u3000Ｏｒｒｉｚｏｎｔｅ１００１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010701026558',
    ),
    'E38381': EdinetCodeEntry(
        edinet_code='E38381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000貴久子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000キクコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38382': EdinetCodeEntry(
        edinet_code='E38382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=52,
        fiscal_year_end='3月31日',
        submitter_name='株式会社伸和ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシンワホールディングス',
        address='札幌市西区二十四軒二条三丁目２番３６号',
        industry='小売業',
        sec_code='71180',
        corporate_number='8430001032173',
    ),
    'E38383': EdinetCodeEntry(
        edinet_code='E38383',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000稔之',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38384': EdinetCodeEntry(
        edinet_code='E38384',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000智範',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000トモノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38385': EdinetCodeEntry(
        edinet_code='E38385',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='和田\u3000順児',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000ジュンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38386': EdinetCodeEntry(
        edinet_code='E38386',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='魚谷\u3000幸一',
        submitter_name_en=None,
        submitter_name_yomi='ウオヤ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38387': EdinetCodeEntry(
        edinet_code='E38387',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='夏原商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナツハラショウジカブシキガイシャ',
        address='彦根市西今町４０番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5160003002444',
    ),
    'E38391': EdinetCodeEntry(
        edinet_code='E38391',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='船橋\u3000光和',
        submitter_name_en=None,
        submitter_name_yomi='フナハシ\u3000ミツカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38392': EdinetCodeEntry(
        edinet_code='E38392',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000宗敏',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ムネトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38395': EdinetCodeEntry(
        edinet_code='E38395',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='武士道アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブシドウアセットマネジメントカブシキカイシャ',
        address='中央区日本橋兜町６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001188199',
    ),
    'E38396': EdinetCodeEntry(
        edinet_code='E38396',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='安藤\u3000宏行',
        submitter_name_en=None,
        submitter_name_yomi='アンドウ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38397': EdinetCodeEntry(
        edinet_code='E38397',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇高\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='ウタカ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38398': EdinetCodeEntry(
        edinet_code='E38398',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='宇高\u3000和真',
        submitter_name_en=None,
        submitter_name_yomi='ウタカ\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38399': EdinetCodeEntry(
        edinet_code='E38399',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='畠山学',
        submitter_name_en=None,
        submitter_name_yomi='ハタケヤママナブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38400': EdinetCodeEntry(
        edinet_code='E38400',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社エコ革',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエコカク',
        address='佐野市高萩町１３２２番地９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9060001025404',
    ),
    'E38401': EdinetCodeEntry(
        edinet_code='E38401',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000繁三',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000シゲミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38402': EdinetCodeEntry(
        edinet_code='E38402',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='千賀\u3000恒宏',
        submitter_name_en=None,
        submitter_name_yomi='センガ\u3000ツネヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38404': EdinetCodeEntry(
        edinet_code='E38404',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000道夫',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38406': EdinetCodeEntry(
        edinet_code='E38406',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='松村\u3000豊人',
        submitter_name_en=None,
        submitter_name_yomi='マツムラ\u3000トヨヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38407': EdinetCodeEntry(
        edinet_code='E38407',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='三宅\u3000安幸',
        submitter_name_en=None,
        submitter_name_yomi='ミヤケ\u3000ヤスユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38408': EdinetCodeEntry(
        edinet_code='E38408',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='近和不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キンワフドウサンカブシキガイシャ',
        address='和歌山市築港５丁目４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5170001004367',
    ),
    'E38409': EdinetCodeEntry(
        edinet_code='E38409',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='あさかわルブテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサカワルブテックカブシキガイシャ',
        address='海南市下津町下津２７番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7170001005909',
    ),
    'E38410': EdinetCodeEntry(
        edinet_code='E38410',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=85,
        fiscal_year_end=None,
        submitter_name='浅川組運輸株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アサカワクミウンユカブシキガイシャ',
        address='海南市下津町下津３０６６番地の１３地先',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4170001005861',
    ),
    'E38411': EdinetCodeEntry(
        edinet_code='E38411',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社マネジメント・サーベイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマネジメントサーベイ',
        address='台東区浅草橋二丁目６番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001116253',
    ),
    'E38413': EdinetCodeEntry(
        edinet_code='E38413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='良原\u3000広樹',
        submitter_name_en=None,
        submitter_name_yomi='ヨシハラ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38414': EdinetCodeEntry(
        edinet_code='E38414',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='板倉\u3000正弘',
        submitter_name_en=None,
        submitter_name_yomi='イタクラ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38415': EdinetCodeEntry(
        edinet_code='E38415',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＶＩＮＴＡＧＥ\u3000ＣＡＶＥ\u3000ＴＯＫＹＯ\u3000株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヴィンテージケーブトーキョーカブシキカイシャ',
        address='港区元麻布１－３－２元麻布ヒルズフォレストテラスイースト',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401144916',
    ),
    'E38416': EdinetCodeEntry(
        edinet_code='E38416',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='九喜\u3000延之',
        submitter_name_en=None,
        submitter_name_yomi='クキ\u3000ノブユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38417': EdinetCodeEntry(
        edinet_code='E38417',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='アースエレメンツ・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アースエレメンツキャピタルカブシキガイシャ',
        address='港区赤坂九丁目６番２８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401118682',
    ),
    'E38419': EdinetCodeEntry(
        edinet_code='E38419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土屋\u3000淳一',
        submitter_name_en=None,
        submitter_name_yomi='ツチヤ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38421': EdinetCodeEntry(
        edinet_code='E38421',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6800,
        fiscal_year_end=None,
        submitter_name='岩崎電気株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イワサキデンキカブシキガイシャ',
        address='中央区東日本橋一丁目１番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001231953',
    ),
    'E38423': EdinetCodeEntry(
        edinet_code='E38423',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1500,
        fiscal_year_end=None,
        submitter_name='バーテックス・インベストメント・ソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バーテックスインベストメントソリューションズカブシキガイシャ',
        address='千代田区有楽町一丁目１３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001228527',
    ),
    'E38425': EdinetCodeEntry(
        edinet_code='E38425',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＩ２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムアイツー',
        address='渋谷区広尾一丁目１５ー６ヒーロービル６Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001091239',
    ),
    'E38427': EdinetCodeEntry(
        edinet_code='E38427',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハルメクホールディングス',
        submitter_name_en='halmek holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャハルメクホールディングス',
        address='新宿区神楽坂四丁目１番１号',
        industry='小売業',
        sec_code='71190',
        corporate_number='9011101091910',
    ),
    'E38428': EdinetCodeEntry(
        edinet_code='E38428',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='干場\u3000艶子',
        submitter_name_en=None,
        submitter_name_yomi='ホシバ\u3000ツヤコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38429': EdinetCodeEntry(
        edinet_code='E38429',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='尾田\u3000信夫',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38430': EdinetCodeEntry(
        edinet_code='E38430',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮澤\u3000孝夫',
        submitter_name_en=None,
        submitter_name_yomi='ミヤザワ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38435': EdinetCodeEntry(
        edinet_code='E38435',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1100,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＧ１６',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイジージュウロク',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401171489',
    ),
    'E38437': EdinetCodeEntry(
        edinet_code='E38437',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='有限会社エーケー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャエーケー',
        address='中央区銀座二丁目３番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010002017354',
    ),
    'E38438': EdinetCodeEntry(
        edinet_code='E38438',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=13,
        fiscal_year_end=None,
        submitter_name='株式会社精和',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセイワ',
        address='練馬区光が丘六丁目１番２号８０２号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001004624',
    ),
    'E38439': EdinetCodeEntry(
        edinet_code='E38439',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5070,
        fiscal_year_end=None,
        submitter_name='アグリビジネス投資育成株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アグリビジネストウシイクセイカブシキガイシャ',
        address='千代田区大手町一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001080633',
    ),
    'E38440': EdinetCodeEntry(
        edinet_code='E38440',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=390,
        fiscal_year_end='12月末日',
        submitter_name='株式会社アイビス',
        submitter_name_en='ibis inc.',
        submitter_name_yomi='カブシキガイシャアイビス',
        address='中央区八丁堀一丁目５番１号',
        industry='サービス業',
        sec_code='93430',
        corporate_number='7180001050326',
    ),
    'E38441': EdinetCodeEntry(
        edinet_code='E38441',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社薫風舎',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクンプウシャ',
        address='中央区日本橋小舟町６番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001223242',
    ),
    'E38442': EdinetCodeEntry(
        edinet_code='E38442',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='有限会社パックス・ケイ',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャパックスケイ',
        address='文京区湯島３－２８－２－６０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010002050166',
    ),
    'E38443': EdinetCodeEntry(
        edinet_code='E38443',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＳＨＩＮＫＯ',
        submitter_name_en='SHINKO Inc.',
        submitter_name_yomi='カブシキガイシャシンコー',
        address='台東区浅草橋五丁目２０番８号',
        industry='情報・通信業',
        sec_code='71200',
        corporate_number='7010501036634',
    ),
    'E38444': EdinetCodeEntry(
        edinet_code='E38444',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ジェイ・エス・ディー',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャジェイエスディー',
        address='新宿区下宮比町１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011103011749',
    ),
    'E38445': EdinetCodeEntry(
        edinet_code='E38445',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ティーエイティー・キャピタル・ファンド・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ティーエイティーキャピタルファンドエルエルシー',
        address='米国９６８１４ハワイ州、ホノルル、アラモアナ大通り１３８８\u3000＃８３００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38446': EdinetCodeEntry(
        edinet_code='E38446',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000保',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000タモツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38448': EdinetCodeEntry(
        edinet_code='E38448',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エン・アイ・ム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンアイムカブシキガイシャ',
        address='品川区東品川五丁目９番１５ー４１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010701043775',
    ),
    'E38450': EdinetCodeEntry(
        edinet_code='E38450',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=129,
        fiscal_year_end='12月31日',
        submitter_name='ビズメイツ株式会社',
        submitter_name_en='Bizmates, Inc.',
        submitter_name_yomi='ビズメイツカブシキガイシャ',
        address='千代田区神田須田町２ー１９ー２３',
        industry='サービス業',
        sec_code='93450',
        corporate_number='8010001147872',
    ),
    'E38452': EdinetCodeEntry(
        edinet_code='E38452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=754,
        fiscal_year_end='6月末日',
        submitter_name='アクシスコンサルティング株式会社',
        submitter_name_en='Axis Consulting Corporation',
        submitter_name_yomi='アクシスコンサルティングカブシキカイシャ',
        address='千代田区麹町４－８麹町クリスタルシティ',
        industry='サービス業',
        sec_code='93440',
        corporate_number='5010001078311',
    ),
    'E38453': EdinetCodeEntry(
        edinet_code='E38453',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=2787,
        fiscal_year_end='12月末日',
        submitter_name='ノイルイミューン・バイオテック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノイルイミューンバイオテックカブシキカイシャ',
        address='港区芝大門二丁目１２番１０号',
        industry='医薬品',
        sec_code='48930',
        corporate_number='1010001167340',
    ),
    'E38454': EdinetCodeEntry(
        edinet_code='E38454',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｏｄｅｓｓａ１２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオデッサトゥエルブ',
        address='世田谷区八幡山一丁目６番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010901052430',
    ),
    'E38455': EdinetCodeEntry(
        edinet_code='E38455',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='サイフ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイフカブシキガイシャ',
        address='中央区新川一丁目二十八番二十五号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001211791',
    ),
    'E38456': EdinetCodeEntry(
        edinet_code='E38456',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='ニュートン・インベストメント・マネジメント・ジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニュートンインベストメントマネジメントジャパンカブシキガイシャ',
        address='千代田区丸の内一丁目８番３号\u3000丸の内トラストタワー本館',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001228669',
    ),
    'E38457': EdinetCodeEntry(
        edinet_code='E38457',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔｈｅ\u3000ｃａｐｉｔａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャザキャピタル',
        address='千代田区丸の内１丁目１１番１号\u3000パシフィックセンチュリープレイス丸の内１３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001179397',
    ),
    'E38458': EdinetCodeEntry(
        edinet_code='E38458',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='公益財団法人重田教育財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンシゲタキョウイクザイダン',
        address='港区虎ノ門３－１８－６朝日虎ノ門マンション３１４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010405015750',
    ),
    'E38460': EdinetCodeEntry(
        edinet_code='E38460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='6月30日',
        submitter_name='株式会社Ｆｕｓｉｃ',
        submitter_name_en='Fusic Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャフュージック',
        address='福岡市中央区天神四丁目１番７号第３明星ビル６Ｆ',
        industry='情報・通信業',
        sec_code='52560',
        corporate_number='4290001023455',
    ),
    'E38461': EdinetCodeEntry(
        edinet_code='E38461',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='高速興産Ａ号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウソクコウサンエーゴウカブシキガイシャ',
        address='仙台市青葉区立町２３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4370001049509',
    ),
    'E38462': EdinetCodeEntry(
        edinet_code='E38462',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='高速興産Ｂ号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウソクコウサンビーゴウカブシキガイシャ',
        address='仙台市青葉区立町２３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2370001049510',
    ),
    'E38463': EdinetCodeEntry(
        edinet_code='E38463',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='高速興産Ｃ号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コウソクコウサンシーゴウカブシキガイシャ',
        address='仙台市青葉区立町２３番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1370001049511',
    ),
    'E38465': EdinetCodeEntry(
        edinet_code='E38465',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='江見\u3000由希子',
        submitter_name_en=None,
        submitter_name_yomi='エミ\u3000ユキコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38467': EdinetCodeEntry(
        edinet_code='E38467',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ヒューマンサービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒューマンサービス',
        address='船橋市海神町三丁目１１９番地５５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010501040425',
    ),
    'E38468': EdinetCodeEntry(
        edinet_code='E38468',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7907,
        fiscal_year_end=None,
        submitter_name='ＰＨＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピーエイチシーカブシキガイシャ',
        address='東温市南方２１３１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4500001007246',
    ),
    'E38469': EdinetCodeEntry(
        edinet_code='E38469',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='出井\u3000富男',
        submitter_name_en=None,
        submitter_name_yomi='デイ\u3000トミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38472': EdinetCodeEntry(
        edinet_code='E38472',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=544,
        fiscal_year_end='6月末日',
        submitter_name='株式会社Ａｒｅｎｔ',
        submitter_name_en='Arent Inc.',
        submitter_name_yomi='カブシキカイシャアレント',
        address='港区浜松町二丁目７番１９号',
        industry='情報・通信業',
        sec_code='52540',
        corporate_number='7080401018908',
    ),
    'E38473': EdinetCodeEntry(
        edinet_code='E38473',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山尾\u3000幸弘',
        submitter_name_en=None,
        submitter_name_yomi='ヤマオ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38474': EdinetCodeEntry(
        edinet_code='E38474',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=217,
        fiscal_year_end='3月31日',
        submitter_name='日本ナレッジ株式会社',
        submitter_name_en='Nihon Knowledge Co,Ltd.',
        submitter_name_yomi='ニホンナレッジカブシキカイシャ',
        address='東京都台東区寿三丁目１９番５号\u3000ＪＳビル９階',
        industry='情報・通信業',
        sec_code='52520',
        corporate_number='3010501010543',
    ),
    'E38477': EdinetCodeEntry(
        edinet_code='E38477',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2193,
        fiscal_year_end='12月31日',
        submitter_name='株式会社モンスターラボ',
        submitter_name_en='Monstarlab Inc.',
        submitter_name_yomi='カブシキガイシャモンスターラボ',
        address='渋谷区広尾１丁目１番３９号恵比寿プライムスクエアタワー４Ｆ',
        industry='情報・通信業',
        sec_code='52550',
        corporate_number='3013201019037',
    ),
    'E38478': EdinetCodeEntry(
        edinet_code='E38478',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=452,
        fiscal_year_end='3月31日',
        submitter_name='カバー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カバーカブシキガイシャ',
        address='港区三田３－５ー１９\u3000住友不動産東京三田ガーデンタワー１５階',
        industry='情報・通信業',
        sec_code='52530',
        corporate_number='4011001111450',
    ),
    'E38480': EdinetCodeEntry(
        edinet_code='E38480',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福留\u3000泰蔵',
        submitter_name_en=None,
        submitter_name_yomi='フクドメ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38481': EdinetCodeEntry(
        edinet_code='E38481',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＢＯＮＤ\u3000ＣＡＰＩＴＡＬ\u3000ＣＲＥＡＴＩＯＮ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ボンドキャピタル',
        address='１６\u3000ＲＡＦＦＬＥＳ\u3000ＱＵＡＹ\u3000＃１６－０５\u3000ＨＯＮＧ\u3000ＬＥＯＮＧ\u3000ＢＵＩＬＤＩＮＧ\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38483': EdinetCodeEntry(
        edinet_code='E38483',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=131,
        fiscal_year_end='7月末日',
        submitter_name='株式会社エコム',
        submitter_name_en='Ecology and Combustion Inc.',
        submitter_name_yomi='カブシキガイシャエコム',
        address='浜松市浜名区平口５２７７番地１',
        industry='機械',
        sec_code='62250',
        corporate_number='2080401002321',
    ),
    'E38484': EdinetCodeEntry(
        edinet_code='E38484',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙梨\u3000智志',
        submitter_name_en=None,
        submitter_name_yomi='タカナシ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38485': EdinetCodeEntry(
        edinet_code='E38485',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='ＣＤＫ戦略投資事業合同会社',
        submitter_name_en=None,
        submitter_name_yomi='シーディーケーセンリャクトウシジギョウゴウドウガイシャ',
        address='千代田区丸の内一丁目８番３号\u3000丸の内トラストタワー本館２０Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003025680',
    ),
    'E38487': EdinetCodeEntry(
        edinet_code='E38487',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濱﨑\u3000陽一郎',
        submitter_name_en=None,
        submitter_name_yomi='ハマサキ\u3000ヨウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38488': EdinetCodeEntry(
        edinet_code='E38488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='納富\u3000貞嘉',
        submitter_name_en=None,
        submitter_name_yomi='ノウトミ\u3000サダヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38491': EdinetCodeEntry(
        edinet_code='E38491',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=6146,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トランザクション・メディア・ネットワークス',
        submitter_name_en='Transaction Media Networks Inc.',
        submitter_name_yomi='トランザクションメディアネットワークス',
        address='中央区日本橋二丁目１１番２号',
        industry='情報・通信業',
        sec_code='52580',
        corporate_number='7010001115847',
    ),
    'E38502': EdinetCodeEntry(
        edinet_code='E38502',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＳＯＵＴＨ\u3000ＩＳＬＥ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='サウス\u3000アイル\u3000インターナショナル\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ２，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000ＶＧ１１１０，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38503': EdinetCodeEntry(
        edinet_code='E38503',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＤＯＲＭＯＮＴ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ドルモン\u3000インターナショナル\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000ＩＩ，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000ＶＧ１１１０，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38504': EdinetCodeEntry(
        edinet_code='E38504',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=454,
        fiscal_year_end='3月31日',
        submitter_name='南海化学株式会社',
        submitter_name_en='NANKAI CHEMICAL COMPANY, LIMITED',
        submitter_name_yomi='ナンカイカガクカブシキカイシャ',
        address='大阪市西区南堀江一丁目１２番１９号',
        industry='化学',
        sec_code='40400',
        corporate_number='1120001046120',
    ),
    'E38505': EdinetCodeEntry(
        edinet_code='E38505',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本田\u3000理',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38506': EdinetCodeEntry(
        edinet_code='E38506',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｃｈａｒｏｎ\u3000Ｆｉｎａｎｃｅ\u3000ＧｍｂＨ',
        submitter_name_en=None,
        submitter_name_yomi='シャロン\u3000ファイナンス\u3000ゲーエムベーハー',
        address='スイス連邦、６３６２スタンスタッド、アッハーエック\u3000１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38512': EdinetCodeEntry(
        edinet_code='E38512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=497,
        fiscal_year_end='6月30日',
        submitter_name='日本システムバンク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンシステムバンクカブシキガイシャ',
        address='福井市中央３－５－２１',
        industry='不動産業',
        sec_code='55300',
        corporate_number='8210001002628',
    ),
    'E38516': EdinetCodeEntry(
        edinet_code='E38516',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38517': EdinetCodeEntry(
        edinet_code='E38517',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小寺\u3000弘泰',
        submitter_name_en=None,
        submitter_name_yomi='コデラ\u3000ヒロヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38520': EdinetCodeEntry(
        edinet_code='E38520',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000均（相続人代表\u3000池田\u3000有希子）',
        submitter_name_en=None,
        submitter_name_yomi='イケダヒトシソウゾクニンダイヒョウイケダユキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38521': EdinetCodeEntry(
        edinet_code='E38521',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000秀行',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38522': EdinetCodeEntry(
        edinet_code='E38522',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='Ｂｌｏｓｓｏｍ\u3000Ｂｉｄｃｏ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブロッサムビッドコーカブシキカイシャ',
        address='港区白金台三丁目１０番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401171621',
    ),
    'E38523': EdinetCodeEntry(
        edinet_code='E38523',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=775,
        fiscal_year_end='6月30日',
        submitter_name='株式会社テクニスコ',
        submitter_name_en='TECNISCO, LTD.',
        submitter_name_yomi='カブシキカイシャテクニスコ',
        address='品川区南品川二丁目２番１５号',
        industry='金属製品',
        sec_code='29620',
        corporate_number='7010701006313',
    ),
    'E38525': EdinetCodeEntry(
        edinet_code='E38525',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19777,
        fiscal_year_end='6月30日',
        submitter_name='株式会社トライアルホールディングス',
        submitter_name_en='TRIAL Holdings, Inc.',
        submitter_name_yomi='カブシキガイシャトライアルホールディングス',
        address='福岡市東区多の津１ー１２ー２',
        industry='小売業',
        sec_code='141A0',
        corporate_number='9290001071458',
    ),
    'E38526': EdinetCodeEntry(
        edinet_code='E38526',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久世\u3000真也',
        submitter_name_en=None,
        submitter_name_yomi='クゼ\u3000シンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38527': EdinetCodeEntry(
        edinet_code='E38527',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯島\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='イイジマ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38530': EdinetCodeEntry(
        edinet_code='E38530',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1840,
        fiscal_year_end=None,
        submitter_name='ＩＱ\u3000ＥＱファンド・マネジメント（アイルランド）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アイキューイーキューファンドマネジメントアイルランドリミテッド',
        address='アイルランド、ダブリン２、サー・ジョン・ロジャーソンズ・キー７６番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38532': EdinetCodeEntry(
        edinet_code='E38532',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若山\u3000理子',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000ヨシコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38533': EdinetCodeEntry(
        edinet_code='E38533',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷郷\u3000元昭',
        submitter_name_en=None,
        submitter_name_yomi='タニゴウ\u3000モトアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38534': EdinetCodeEntry(
        edinet_code='E38534',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='アイザワ証券株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイザワショウケンカブシキカイシャ',
        address='港区東新橋一丁目９番１号\u3000東京汐留ビルディング',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001217122',
    ),
    'E38536': EdinetCodeEntry(
        edinet_code='E38536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000義人',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヨシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38537': EdinetCodeEntry(
        edinet_code='E38537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齊藤\u3000宏之',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38539': EdinetCodeEntry(
        edinet_code='E38539',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ネットプライス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャネットプライス',
        address='港区新橋二丁目１６番１号\u3000ニュー新橋ビル７０４Ｂ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010701020607',
    ),
    'E38540': EdinetCodeEntry(
        edinet_code='E38540',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='Ｊｏａｃｈｉｍ\u3000Ｓｔｏｃｋ\u3000Ｈｏｌｄｉｎｇ\u3000ＧｍｂＨ',
        submitter_name_en=None,
        submitter_name_yomi='ヨアヒム\u3000シュトック\u3000ホールディング',
        address='Ｐａｒｉｓｅｒ\u3000Ｓｔｒ．９，１０７１９\u3000Ｂｅｒｌｉｎ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38541': EdinetCodeEntry(
        edinet_code='E38541',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=487,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ジェノバ',
        submitter_name_en='JENOBA CO.,LTD.',
        submitter_name_yomi='カブシキガイシャジェノバ',
        address='千代田区神田須田町一丁目３４番地４',
        industry='情報・通信業',
        sec_code='55700',
        corporate_number='2010001077613',
    ),
    'E38544': EdinetCodeEntry(
        edinet_code='E38544',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=5889,
        fiscal_year_end='12月末日',
        submitter_name='株式会社スリーダムアライアンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャスリーダムアライアンス',
        address='港区赤坂１ー７ー１赤坂榎坂ビル８階',
        industry='サービス業',
        sec_code=None,
        corporate_number='8021001052921',
    ),
    'E38545': EdinetCodeEntry(
        edinet_code='E38545',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内山\u3000秀',
        submitter_name_en=None,
        submitter_name_yomi='ウチヤマ\u3000シュウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38546': EdinetCodeEntry(
        edinet_code='E38546',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38550': EdinetCodeEntry(
        edinet_code='E38550',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神谷\u3000栄治',
        submitter_name_en=None,
        submitter_name_yomi='カミヤ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38551': EdinetCodeEntry(
        edinet_code='E38551',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村上\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38561': EdinetCodeEntry(
        edinet_code='E38561',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柴田\u3000美知男',
        submitter_name_en=None,
        submitter_name_yomi='シバタ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38562': EdinetCodeEntry(
        edinet_code='E38562',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='工藤\u3000浩昭',
        submitter_name_en=None,
        submitter_name_yomi='クドウ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38563': EdinetCodeEntry(
        edinet_code='E38563',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井手\u3000浩太',
        submitter_name_en=None,
        submitter_name_yomi='イデ\u3000コウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38564': EdinetCodeEntry(
        edinet_code='E38564',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='五十嵐\u3000圭',
        submitter_name_en=None,
        submitter_name_yomi='イガラシ\u3000ケイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38565': EdinetCodeEntry(
        edinet_code='E38565',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='幸\u3000隆志',
        submitter_name_en=None,
        submitter_name_yomi='ユキ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38566': EdinetCodeEntry(
        edinet_code='E38566',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社鶴亀',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャツルカメ',
        address='渋谷区千駄ヶ谷４丁目２０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011201014664',
    ),
    'E38567': EdinetCodeEntry(
        edinet_code='E38567',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=365,
        fiscal_year_end='7月31日',
        submitter_name='株式会社Ｒｉｄｇｅ－ｉ',
        submitter_name_en='Ridge-i Inc.',
        submitter_name_yomi='カブシキガイシャリッジアイ',
        address='千代田区大手町１－６－１',
        industry='情報・通信業',
        sec_code='55720',
        corporate_number='9010001177423',
    ),
    'E38569': EdinetCodeEntry(
        edinet_code='E38569',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＲＡＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケーアールエーシー',
        address='川崎市川崎区駅前本町１１番地２川崎フロンティアビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020001127335',
    ),
    'E38570': EdinetCodeEntry(
        edinet_code='E38570',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社アレジアンス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアレジアンス',
        address='鎌倉市津西１－２４－２６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021001065301',
    ),
    'E38571': EdinetCodeEntry(
        edinet_code='E38571',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='いな川\u3000宏樹',
        submitter_name_en=None,
        submitter_name_yomi='イナガワ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38572': EdinetCodeEntry(
        edinet_code='E38572',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小松\u3000平佳',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000タカヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38573': EdinetCodeEntry(
        edinet_code='E38573',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柳原\u3000尚史',
        submitter_name_en=None,
        submitter_name_yomi='ヤナギハラ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38577': EdinetCodeEntry(
        edinet_code='E38577',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='芳山\u3000政安',
        submitter_name_en=None,
        submitter_name_yomi='ヨシヤマ\u3000マサヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38579': EdinetCodeEntry(
        edinet_code='E38579',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ａ＆Ｃコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエーアンドシーコーポレーション',
        address='武蔵野市吉祥寺本町２－８－４ｉ－ｏｆｆｉｃｅ吉祥寺',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7012401033686',
    ),
    'E38581': EdinetCodeEntry(
        edinet_code='E38581',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000耕一',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38585': EdinetCodeEntry(
        edinet_code='E38585',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梅林\u3000真如',
        submitter_name_en=None,
        submitter_name_yomi='ウメバヤシ\u3000マサナオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38586': EdinetCodeEntry(
        edinet_code='E38586',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中川\u3000高志',
        submitter_name_en=None,
        submitter_name_yomi='ナカガワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38587': EdinetCodeEntry(
        edinet_code='E38587',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐海\u3000文隆',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000フミタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38588': EdinetCodeEntry(
        edinet_code='E38588',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000篤史',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38589': EdinetCodeEntry(
        edinet_code='E38589',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000伸明',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38590': EdinetCodeEntry(
        edinet_code='E38590',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000日加',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ヒカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38593': EdinetCodeEntry(
        edinet_code='E38593',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山元\u3000雄太',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ユウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38594': EdinetCodeEntry(
        edinet_code='E38594',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000新悟',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38595': EdinetCodeEntry(
        edinet_code='E38595',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＧＲＩＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグリット',
        address='港区南麻布三丁目１１番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001211908',
    ),
    'E38596': EdinetCodeEntry(
        edinet_code='E38596',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ツナグ・インベストメンツ・ピーティーイー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='ツナグ\u3000インベストメンツ\u3000ピーティーイー\u3000エルティーディー',
        address='シンガポール、１８９３５２、＃１０－２３\u3000デュオタワー、３フレイザーストリート',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38597': EdinetCodeEntry(
        edinet_code='E38597',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｇｏｌｄ\u3000Ｐａｃｉｆｉｃ\u3000Ｇｌｏｂａｌ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ゴールド\u3000パシフィック\u3000グローバル\u3000リミテッド',
        address='Ｆｌａｔ\u3000Ｅ，\u3000１８／Ｆ．，\u3000Ｋａ\u3000Ｗｉｎｇ\u3000Ｂｕｉｌｄｉｎｇ，\u3000４－６\u3000Ｈｏｉ\u3000Ｗａｎ\u3000Ｓｔｒｅｅｔ，\u3000Ｑｕａｒｒｙ\u3000Ｂａｙ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38598': EdinetCodeEntry(
        edinet_code='E38598',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鴨林\u3000広軌',
        submitter_name_en=None,
        submitter_name_yomi='カモバヤシ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38599': EdinetCodeEntry(
        edinet_code='E38599',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＦＰＧ信託',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエフピージーシンタク',
        address='千代田区丸の内２丁目７番２号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010401089004',
    ),
    'E38600': EdinetCodeEntry(
        edinet_code='E38600',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ユニマットホールディング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユニマットホールディング',
        address='港区南青山二丁目１２番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401105321',
    ),
    'E38602': EdinetCodeEntry(
        edinet_code='E38602',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＰＹ\u3000ＯＰＵＬＥＮＣＥ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ピーワイ\u3000オプレンス\u3000インベストメント\u3000ピーティーイー\u3000リミテッド',
        address='１８\u3000ＳＩＮ\u3000ＭＩＮＧ\u3000ＬＡＮＥ\u3000＃０７－０３\u3000ＭＩＤＶＩＥＷ\u3000ＣＩＴＹ\u3000ＳＩＮＧＡＰＯＲＥ\u3000５７３９６０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38603': EdinetCodeEntry(
        edinet_code='E38603',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂｌｏｓｓｏｍｓ\u3000Ｈｏｌｄｉｎｇ\u3000ＨＫ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ブロッサムズ\u3000ホールディング\u3000エイチケー\u3000リミテッド',
        address='４／Ｆ．，\u3000ＶＣ\u3000Ｈｏｕｓｅ，\u3000４－６\u3000Ｏｎ\u3000Ｌａｎ\u3000Ｓｔｒｅｅｔ，\u3000Ｃｅｎｔｒａｌ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38606': EdinetCodeEntry(
        edinet_code='E38606',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1010,
        fiscal_year_end=None,
        submitter_name='陽インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンインベストメントカブシキカイシャ',
        address='大阪市中央区北浜２丁目１番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001186403',
    ),
    'E38607': EdinetCodeEntry(
        edinet_code='E38607',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='ＪＩＣベンチャー・グロース・インベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイアイシーベンチャーグロースインベストメンツカブシキカイシャ',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001210908',
    ),
    'E38610': EdinetCodeEntry(
        edinet_code='E38610',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社鎌田企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカマタキカク',
        address='渋谷区恵比寿南二丁目１７番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403013437',
    ),
    'E38618': EdinetCodeEntry(
        edinet_code='E38618',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｈｅｒｏｉｃ\u3000ｉｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヒーロイックインベストメント',
        address='福岡市博多区博多駅南二丁目１番９号博多筑紫通りセンタービル１Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5290001058161',
    ),
    'E38621': EdinetCodeEntry(
        edinet_code='E38621',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野坂\u3000信嘉',
        submitter_name_en=None,
        submitter_name_yomi='ノサカ\u3000ノブヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38623': EdinetCodeEntry(
        edinet_code='E38623',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺西\u3000孝一郎',
        submitter_name_en=None,
        submitter_name_yomi='テラニシ\u3000コウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38624': EdinetCodeEntry(
        edinet_code='E38624',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000裕昭',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヒロアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38625': EdinetCodeEntry(
        edinet_code='E38625',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='ＧＦＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーエフシーカブシキカイシャ',
        address='渋谷区恵比寿１－３４－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001114414',
    ),
    'E38626': EdinetCodeEntry(
        edinet_code='E38626',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小沼\u3000美和',
        submitter_name_en=None,
        submitter_name_yomi='コヌマ\u3000ミワ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38627': EdinetCodeEntry(
        edinet_code='E38627',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='磯川\u3000武志',
        submitter_name_en=None,
        submitter_name_yomi='イソカワ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38628': EdinetCodeEntry(
        edinet_code='E38628',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=36,
        fiscal_year_end=None,
        submitter_name='柏温泉リゾート株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カシワオンセンリゾートカブシキガイシャ',
        address='港区南青山７－８－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3040001089794',
    ),
    'E38629': EdinetCodeEntry(
        edinet_code='E38629',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='株式会社船カンショートコース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフナカンショートコース',
        address='白井市神々廻１９０４－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001043791',
    ),
    'E38630': EdinetCodeEntry(
        edinet_code='E38630',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社８１２８',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハチイチニハチ',
        address='世田谷区玉川田園調布二丁目１２番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010901039144',
    ),
    'E38632': EdinetCodeEntry(
        edinet_code='E38632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野坂俊彰',
        submitter_name_en=None,
        submitter_name_yomi='ノサカトシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38634': EdinetCodeEntry(
        edinet_code='E38634',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=323,
        fiscal_year_end='9月30日',
        submitter_name='株式会社エリッツホールディングス',
        submitter_name_en='Elitz Holdings Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャエリッツホールディングス',
        address='京都市中京区堀川通姉小路上る三坊堀川町５５番地１\u3000エリッツ御池ビル',
        industry='不動産業',
        sec_code='55330',
        corporate_number='2130001048932',
    ),
    'E38637': EdinetCodeEntry(
        edinet_code='E38637',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='デビッド・スペンサー',
        submitter_name_en=None,
        submitter_name_yomi='デビッドスペンサー',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38638': EdinetCodeEntry(
        edinet_code='E38638',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=135,
        fiscal_year_end=None,
        submitter_name='ＭＭＸＸベンチャーズ・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エムエムエックスエックスベンチャーズリミテッド',
        address='ＣＲＡＩＧＭＵＩＲ\u3000ＣＨＡＭＢＥＲＳ，\u3000ＲＯＡＤ\u3000ＴＯＷＮ，\u3000ＴＯＲＴＯＬＡ，\u3000ＶＧ１１１０，\u3000ＢＲＩＴＩＳＨ\u3000ＶＩＲＧＩＮ\u3000ＩＳＬＡＮＤＳ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38639': EdinetCodeEntry(
        edinet_code='E38639',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＭＳホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティエムエスホールディングス',
        address='大阪市中央区西心斎橋二丁目２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001238755',
    ),
    'E38640': EdinetCodeEntry(
        edinet_code='E38640',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ＳＴＰＲ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスティーピーアール',
        address='渋谷区渋谷２－２１－１渋谷ヒカリエ３４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401139143',
    ),
    'E38641': EdinetCodeEntry(
        edinet_code='E38641',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=255,
        fiscal_year_end='8月31日',
        submitter_name='株式会社プロディライト',
        submitter_name_en='Prodelight Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャプロディライト',
        address='大阪市中央区高麗橋三丁目３番１１号淀屋橋フレックスタワー２階',
        industry='情報・通信業',
        sec_code='55800',
        corporate_number='1120001146779',
    ),
    'E38642': EdinetCodeEntry(
        edinet_code='E38642',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡村\u3000吉光',
        submitter_name_en=None,
        submitter_name_yomi='オカムラ\u3000ヨシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38643': EdinetCodeEntry(
        edinet_code='E38643',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南\u3000尚子',
        submitter_name_en=None,
        submitter_name_yomi='ミナミ\u3000ナオコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38644': EdinetCodeEntry(
        edinet_code='E38644',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南\u3000安子',
        submitter_name_en=None,
        submitter_name_yomi='ミナミ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38645': EdinetCodeEntry(
        edinet_code='E38645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=190,
        fiscal_year_end='3月31日',
        submitter_name='株式会社オービーシステム',
        submitter_name_en='O.B.System Inc.',
        submitter_name_yomi='カブシキガイシャオービーシステム',
        address='大阪市中央区平野町二丁目３番７号',
        industry='情報・通信業',
        sec_code='55760',
        corporate_number='5120001030401',
    ),
    'E38648': EdinetCodeEntry(
        edinet_code='E38648',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12199,
        fiscal_year_end=None,
        submitter_name='ＳＯＭＰＯ\u3000Ｌｉｇｈｔ\u3000Ｖｏｒｔｅｘ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソンポライトボルテックス',
        address='新宿区西新宿一丁目２６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101095620',
    ),
    'E38649': EdinetCodeEntry(
        edinet_code='E38649',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=345,
        fiscal_year_end=None,
        submitter_name='Ｓｗｉｓｓ－Ａｓｉａ\u3000Ｆｉｎａｎｃｉａｌ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='スイス\u3000アジア\u3000フィナンシャル\u3000サービシズ\u3000ピーティーイー\u3000エルティーディー',
        address='９\u3000Ｒａｆｆｌｅｓ\u3000Ｐｌａｃｅ\u3000♯５３―０１／０４\u3000Ｒｅｐｕｂｌｉｃ\u3000Ｐｌａｚａ\u3000Ｓｉｎｇａｐｏｒｅ（０４８６１９）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38650': EdinetCodeEntry(
        edinet_code='E38650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='重松\u3000宣雄',
        submitter_name_en=None,
        submitter_name_yomi='シゲマツ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38651': EdinetCodeEntry(
        edinet_code='E38651',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=190,
        fiscal_year_end='8月末日',
        submitter_name='株式会社キャスター',
        submitter_name_en='Caster Co. Ltd.',
        submitter_name_yomi='カブシキガイシャキャスター',
        address='西都市鹿野田１１３６５番地１',
        industry='サービス業',
        sec_code='93310',
        corporate_number='7020001107769',
    ),
    'E38654': EdinetCodeEntry(
        edinet_code='E38654',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=133,
        fiscal_year_end='8月末日',
        submitter_name='ＡＲアドバンストテクノロジ株式会社',
        submitter_name_en='AR advanced technology, Inc.',
        submitter_name_yomi='エーアールアドバンストテクノロジカブシキカイシャ',
        address='渋谷区渋谷二丁目１７番１号',
        industry='情報・通信業',
        sec_code='55780',
        corporate_number='2010001130058',
    ),
    'E38655': EdinetCodeEntry(
        edinet_code='E38655',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000剛志',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38656': EdinetCodeEntry(
        edinet_code='E38656',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ブルーマンデイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブルーマンデイ',
        address='渋谷区渋谷２丁目１９番１５号\u3000宮益坂ビルディング６０９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001129852',
    ),
    'E38657': EdinetCodeEntry(
        edinet_code='E38657',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ダンシンダイナー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダンシンダイナー',
        address='大阪市淀川区西中島７－１０－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001056728',
    ),
    'E38659': EdinetCodeEntry(
        edinet_code='E38659',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='サイブリッジ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='サイブリッジゴウドウガイシャ',
        address='品川区南品川四丁目４番１７号\u3000品川サウスタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010703006631',
    ),
    'E38660': EdinetCodeEntry(
        edinet_code='E38660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池原\u3000諒平',
        submitter_name_en=None,
        submitter_name_yomi='イケハラ\u3000リョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38662': EdinetCodeEntry(
        edinet_code='E38662',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=32,
        fiscal_year_end='5月31日',
        submitter_name='株式会社Ｇｌｏｂｅｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグロービー',
        address='港区東麻布一丁目７番３号',
        industry='情報・通信業',
        sec_code='55750',
        corporate_number='9011001100548',
    ),
    'E38663': EdinetCodeEntry(
        edinet_code='E38663',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='ＴＮＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーエヌアイカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401169026',
    ),
    'E38664': EdinetCodeEntry(
        edinet_code='E38664',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='牟田\u3000成',
        submitter_name_en=None,
        submitter_name_yomi='ムタ\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38665': EdinetCodeEntry(
        edinet_code='E38665',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前田\u3000剛志',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38667': EdinetCodeEntry(
        edinet_code='E38667',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=680,
        fiscal_year_end='9月30日',
        submitter_name='株式会社リアルゲイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャリアルゲイト',
        address='渋谷区千駄ヶ谷三丁目５１番１０号',
        industry='不動産業',
        sec_code='55320',
        corporate_number='2010401098366',
    ),
    'E38670': EdinetCodeEntry(
        edinet_code='E38670',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡部\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='オカベ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38671': EdinetCodeEntry(
        edinet_code='E38671',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='ＭＡＳＡＮＯＢＵ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＣＡＰＩＴＡＬ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マサノブインベストメントキャピタルジャブシキカイシャ',
        address='港区三田１－１１－３８－２０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401173509',
    ),
    'E38672': EdinetCodeEntry(
        edinet_code='E38672',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社夢葉',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャユメハ',
        address='長野市大字南長野妻科４０９番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5100001030907',
    ),
    'E38673': EdinetCodeEntry(
        edinet_code='E38673',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＰＧＰ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エーピージーピー\u3000マネジメント\u3000リミテッド',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００８\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38676': EdinetCodeEntry(
        edinet_code='E38676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｏｔｅｍａｃｈｉ\u3000Ｈｏｌｄｉｎｇｓ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='オオテマチホールディングスゴウドウガイシャ',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003039551',
    ),
    'E38681': EdinetCodeEntry(
        edinet_code='E38681',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＣｈｒｏｎｏＳｏｕｒｃｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクロノソース',
        address='春日井市中央台七丁目１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001150701',
    ),
    'E38682': EdinetCodeEntry(
        edinet_code='E38682',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=35,
        fiscal_year_end='6月30日',
        submitter_name='株式会社クラダシ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクラダシ',
        address='品川区上大崎三丁目２番１号',
        industry='小売業',
        sec_code='58840',
        corporate_number='3011001100958',
    ),
    'E38683': EdinetCodeEntry(
        edinet_code='E38683',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社グリッド',
        submitter_name_en='GRID Inc.',
        submitter_name_yomi='カブシキガイシャグリッド',
        address='港区北青山三丁目１１番７号ＡＯビル６階',
        industry='情報・通信業',
        sec_code='55820',
        corporate_number='4010401084422',
    ),
    'E38684': EdinetCodeEntry(
        edinet_code='E38684',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=290,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ジーデップ・アドバンス',
        submitter_name_en='GDEP ADVANCE, Inc.',
        submitter_name_yomi='カブシキガイシャジーデップアドバンス',
        address='仙台市青葉区国分町三丁目４番３３',
        industry='卸売業',
        sec_code='58850',
        corporate_number='1010001173009',
    ),
    'E38685': EdinetCodeEntry(
        edinet_code='E38685',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=106,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＧＳＩ',
        submitter_name_en='GSI Co., Ltd.',
        submitter_name_yomi='カブシキガイシャジーエスアイ',
        address='札幌市北区北七条西一丁目１番地２',
        industry='情報・通信業',
        sec_code='55790',
        corporate_number='6430001032588',
    ),
    'E38686': EdinetCodeEntry(
        edinet_code='E38686',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人\u3000秀里会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジン\u3000ヒデサトカイ',
        address='広島市西区商工センター四丁目６番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6240005006707',
    ),
    'E38687': EdinetCodeEntry(
        edinet_code='E38687',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=45,
        fiscal_year_end='6月30日',
        submitter_name='株式会社Ｗ\u3000ＴＯＫＹＯ',
        submitter_name_en='W TOKYO Inc.',
        submitter_name_yomi='カブシキガイシャダブル\u3000トウキョウ',
        address='渋谷区神宮前五丁目２８番５号',
        industry='サービス業',
        sec_code='91590',
        corporate_number='1010001168883',
    ),
    'E38688': EdinetCodeEntry(
        edinet_code='E38688',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='クオリプス株式会社',
        submitter_name_en='Cuorips Inc.',
        submitter_name_yomi='クオリプスカブシキガイシャ',
        address='中央区日本橋本町三丁目１１番５号\u3000日本橋ライフサイエンスビルディング２、５０７',
        industry='医薬品',
        sec_code='48940',
        corporate_number='7020001120540',
    ),
    'E38689': EdinetCodeEntry(
        edinet_code='E38689',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=426,
        fiscal_year_end='3月末日',
        submitter_name='コージンバイオ株式会社',
        submitter_name_en='Kohjin Bio Co., Ltd.',
        submitter_name_yomi='コージンバイオカブシキカイシャ',
        address='坂戸市千代田５－１－３',
        industry='医薬品',
        sec_code='177A0',
        corporate_number='5030001068764',
    ),
    'E38690': EdinetCodeEntry(
        edinet_code='E38690',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=800,
        fiscal_year_end='5月末日',
        submitter_name='株式会社アイデミー',
        submitter_name_en='Aidemy Inc.',
        submitter_name_yomi='カブシキガイシャアイデミー',
        address='千代田区大手町一丁目２番１号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='7010001161164',
    ),
    'E38692': EdinetCodeEntry(
        edinet_code='E38692',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=37630,
        fiscal_year_end=None,
        submitter_name='社会福祉法人清水基金',
        submitter_name_en=None,
        submitter_name_yomi='シャカイフクシホウジンシミズキキン',
        address='中央区日本橋三丁目１２番２号朝日ビル内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005001037',
    ),
    'E38693': EdinetCodeEntry(
        edinet_code='E38693',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=392,
        fiscal_year_end='6月30日',
        submitter_name='株式会社クオルテック',
        submitter_name_en='Qualtec Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャクオルテック',
        address='堺市堺区三宝町四丁２３０番地',
        industry='サービス業',
        sec_code='91650',
        corporate_number='5120101021226',
    ),
    'E38695': EdinetCodeEntry(
        edinet_code='E38695',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月末日',
        submitter_name='ＡｅｒｏＥｄｇｅ株式会社',
        submitter_name_en='AeroEdge Co.,Ltd.',
        submitter_name_yomi='エアロエッジカブシキガイシャ',
        address='栃木県足利市寺岡町４８２－６',
        industry='金属製品',
        sec_code='74090',
        corporate_number='4060001027529',
    ),
    'E38697': EdinetCodeEntry(
        edinet_code='E38697',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大平\u3000啓介',
        submitter_name_en=None,
        submitter_name_yomi='オオダイラ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38698': EdinetCodeEntry(
        edinet_code='E38698',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ブリーチ',
        submitter_name_en='Bleach, Inc.',
        submitter_name_yomi='カブシキガイシャブリーチ',
        address='目黒区上目黒二丁目１番１号\u3000中目黒ＧＴタワー２１階',
        industry='サービス業',
        sec_code='91620',
        corporate_number='6040001070438',
    ),
    'E38699': EdinetCodeEntry(
        edinet_code='E38699',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濵口\u3000慶太',
        submitter_name_en=None,
        submitter_name_yomi='ハマグチ\u3000ケイタ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38700': EdinetCodeEntry(
        edinet_code='E38700',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='牧\u3000寛之',
        submitter_name_en=None,
        submitter_name_yomi='マキ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38701': EdinetCodeEntry(
        edinet_code='E38701',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松永\u3000茂生',
        submitter_name_en=None,
        submitter_name_yomi='マツナガ\u3000シゲオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38702': EdinetCodeEntry(
        edinet_code='E38702',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青木\u3000尚史',
        submitter_name_en=None,
        submitter_name_yomi='アオキ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38703': EdinetCodeEntry(
        edinet_code='E38703',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=6,
        fiscal_year_end='12月末日',
        submitter_name='モデルナ・インク',
        submitter_name_en=None,
        submitter_name_yomi='モデルナ\u3000インク',
        address='アメリカ合衆国、０２１４２、マサチューセッツ州ケンブリッジ、ビニーストリート３２５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E38706': EdinetCodeEntry(
        edinet_code='E38706',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38707': EdinetCodeEntry(
        edinet_code='E38707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='久世\u3000純子',
        submitter_name_en=None,
        submitter_name_yomi='クゼ\u3000スミコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38710': EdinetCodeEntry(
        edinet_code='E38710',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西島\u3000富久',
        submitter_name_en=None,
        submitter_name_yomi='ニシジマ\u3000トミヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38711': EdinetCodeEntry(
        edinet_code='E38711',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西島\u3000美和子',
        submitter_name_en=None,
        submitter_name_yomi='ニシジマ\u3000ミワコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38712': EdinetCodeEntry(
        edinet_code='E38712',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000義則',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38713': EdinetCodeEntry(
        edinet_code='E38713',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社アイビー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイビー',
        address='東京都豊島区南池袋二丁目９番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1013301050769',
    ),
    'E38714': EdinetCodeEntry(
        edinet_code='E38714',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=40000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社京都フィナンシャルグループ',
        submitter_name_en='Kyoto Financial Group, Inc.',
        submitter_name_yomi='カブシキガイシャキョウトフィナンシャルグループ',
        address='京都市下京区烏丸通松原上る薬師前町７００番地',
        industry='銀行業',
        sec_code='58440',
        corporate_number='3130001075397',
    ),
    'E38715': EdinetCodeEntry(
        edinet_code='E38715',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='出ッ古\u3000直美',
        submitter_name_en=None,
        submitter_name_yomi='デッコ\u3000ナオミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38716': EdinetCodeEntry(
        edinet_code='E38716',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=372,
        fiscal_year_end='9月末日',
        submitter_name='ニッポンインシュア株式会社',
        submitter_name_en='Nippon Insure Co., Ltd.',
        submitter_name_yomi='ニッポンインシュアカブシキガイシャ',
        address='福岡市中央区天神二丁目１４番２号福岡証券ビル６階',
        industry='その他金融業',
        sec_code='58430',
        corporate_number='7290001022124',
    ),
    'E38717': EdinetCodeEntry(
        edinet_code='E38717',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社渋谷神宮前ＩＯ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシブヤジングウマエアイオー',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003040513',
    ),
    'E38718': EdinetCodeEntry(
        edinet_code='E38718',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＧキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチジーキャピタル',
        address='大阪市中央区南船場二丁目１２番１６号ルグラン心斎橋５Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003022479',
    ),
    'E38722': EdinetCodeEntry(
        edinet_code='E38722',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=37,
        fiscal_year_end='6月30日',
        submitter_name='フラー株式会社',
        submitter_name_en='Fuller, Inc.',
        submitter_name_yomi='フラーカブシキガイシャ',
        address='新潟市中央区笹口一丁目２番地',
        industry='情報・通信業',
        sec_code='387A0',
        corporate_number='7050001033574',
    ),
    'E38723': EdinetCodeEntry(
        edinet_code='E38723',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2016,
        fiscal_year_end='3月31日',
        submitter_name='ＮＩＳＳＯホールディングス株式会社',
        submitter_name_en='NISSO HOLDINGS Co., Ltd.',
        submitter_name_yomi='ニッソーホールディングスカブシキガイシャ',
        address='横浜市港北区新横浜一丁目４番１号',
        industry='サービス業',
        sec_code='93320',
        corporate_number='1020001153802',
    ),
    'E38725': EdinetCodeEntry(
        edinet_code='E38725',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='寺島\u3000敬臣',
        submitter_name_en=None,
        submitter_name_yomi='テラシマ\u3000ケイシン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38728': EdinetCodeEntry(
        edinet_code='E38728',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=420,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ナレルグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナレルグループ',
        address='千代田区二番町３番地５',
        industry='サービス業',
        sec_code='91630',
        corporate_number='1010401145895',
    ),
    'E38730': EdinetCodeEntry(
        edinet_code='E38730',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社Ｗｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウィー',
        address='港区港南二丁目５番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401122548',
    ),
    'E38732': EdinetCodeEntry(
        edinet_code='E38732',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ムトウエンタープライズ２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャムトウエンタープライズツー',
        address='横浜市神奈川区六角橋６丁目２２番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001151408',
    ),
    'E38733': EdinetCodeEntry(
        edinet_code='E38733',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000のどか',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000ノドカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38734': EdinetCodeEntry(
        edinet_code='E38734',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹森\u3000征之',
        submitter_name_en=None,
        submitter_name_yomi='タケモリ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38735': EdinetCodeEntry(
        edinet_code='E38735',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=17000,
        fiscal_year_end=None,
        submitter_name='ボッシュ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ボッシュカブシキガイシャ',
        address='横浜市都筑区中川中央一丁目９番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001012340',
    ),
    'E38738': EdinetCodeEntry(
        edinet_code='E38738',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=556,
        fiscal_year_end='1月31日',
        submitter_name='ＤＡＩＷＡ\u3000ＣＹＣＬＥ株式会社',
        submitter_name_en='DAIWA CYCLE CO.,LTD.',
        submitter_name_yomi='ダイワサイクルカブシキガイシャ',
        address='吹田市江坂町一丁目１２番３８号',
        industry='小売業',
        sec_code='58880',
        corporate_number='4122001021471',
    ),
    'E38739': EdinetCodeEntry(
        edinet_code='E38739',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=95,
        fiscal_year_end='1月31日',
        submitter_name='株式会社ＧＥＮＤＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェンダ',
        address='港区東新橋１－９－１',
        industry='サービス業',
        sec_code='91660',
        corporate_number='4010001191817',
    ),
    'E38740': EdinetCodeEntry(
        edinet_code='E38740',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＰＭＩ‐ＬＬＨ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌピーエムアイエルエルエイチカブシキガイシャ',
        address='港区元赤坂一丁目７番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401167376',
    ),
    'E38741': EdinetCodeEntry(
        edinet_code='E38741',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渋谷\u3000修太',
        submitter_name_en=None,
        submitter_name_yomi='シブヤ\u3000シュウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38745': EdinetCodeEntry(
        edinet_code='E38745',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000綏子',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヤスコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38746': EdinetCodeEntry(
        edinet_code='E38746',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ｅｘｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエグジット',
        address='新潟市中央区米山４－１－３１紫竹綜合ビル５０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001166368',
    ),
    'E38747': EdinetCodeEntry(
        edinet_code='E38747',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人こどもの未来創造基金',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンコドモノミライソウゾウキキン',
        address='渋谷区広尾１－３－１８広尾オフィスビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011005007447',
    ),
    'E38750': EdinetCodeEntry(
        edinet_code='E38750',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯野\u3000匡道',
        submitter_name_en=None,
        submitter_name_yomi='イイノ\u3000タダミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38751': EdinetCodeEntry(
        edinet_code='E38751',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='幾嶋\u3000研三郎',
        submitter_name_en=None,
        submitter_name_yomi='イクシマ\u3000アキサブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38752': EdinetCodeEntry(
        edinet_code='E38752',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上赤\u3000一馬',
        submitter_name_en=None,
        submitter_name_yomi='カミアカ\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38753': EdinetCodeEntry(
        edinet_code='E38753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若林\u3000佳之助',
        submitter_name_en=None,
        submitter_name_yomi='ワカバヤシ\u3000ヨシノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38754': EdinetCodeEntry(
        edinet_code='E38754',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38755': EdinetCodeEntry(
        edinet_code='E38755',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1010,
        fiscal_year_end='9月30日',
        submitter_name='株式会社Ｌａｂｏｒｏ．ＡＩ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャラボロエーアイ',
        address='中央区銀座八丁目１１番１号',
        industry='情報・通信業',
        sec_code='55860',
        corporate_number='7010001174744',
    ),
    'E38760': EdinetCodeEntry(
        edinet_code='E38760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=70,
        fiscal_year_end='3月末日',
        submitter_name='ミガロホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミガロホールディングスカブシキガイシャ',
        address='新宿区西新宿６－５－１\u3000新宿アイランドタワー４１階',
        industry='不動産業',
        sec_code='55350',
        corporate_number='5011101104601',
    ),
    'E38761': EdinetCodeEntry(
        edinet_code='E38761',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5061,
        fiscal_year_end='3月31日',
        submitter_name='リケンＮＰＲ株式会社',
        submitter_name_en='NPR-RIKEN CORPORATION',
        submitter_name_yomi='リケンエヌピーアールカブシキガイシャ',
        address='千代田区三番町８番地１',
        industry='機械',
        sec_code='62090',
        corporate_number='9010001238935',
    ),
    'E38762': EdinetCodeEntry(
        edinet_code='E38762',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＨ\u3000Ｉｎｖｅｓｔｍｅｎｔ，\u3000Ｉｎｃ',
        submitter_name_en=None,
        submitter_name_yomi='エスエイチ\u3000インベストメント\u3000インク',
        address='Ｃｏｎｙｅｒｓ\u3000Ｔｒｕｓｔ\u3000Ｃｏｍｐａｎｙ\u3000（Ｃａｙｍａｎ）\u3000ＬＩＭＩＴＥＤ，\u3000Ｃｒｉｃｋｅｔ\u3000Ｓｑｕａｒｅ，\u3000Ｈｕｔｃｈｉｎｓ\u3000Ｄｒｉｖｅ，\u3000ＰＯ\u3000Ｂｏｘ\u3000２６８１，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１１１，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38763': EdinetCodeEntry(
        edinet_code='E38763',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='ケミコ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケミコカブシキガイシャ',
        address='大阪市西淀川区姫島３丁目１番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001049539',
    ),
    'E38765': EdinetCodeEntry(
        edinet_code='E38765',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=416,
        fiscal_year_end='10月31日',
        submitter_name='エコナビスタ株式会社',
        submitter_name_en='EcoNaviSta, Inc.',
        submitter_name_yomi='エコナビスタカブシキカイシャ',
        address='千代田区紀尾井町３番１号\u3000ＫＫＤビル６Ｆ',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='1010001128887',
    ),
    'E38766': EdinetCodeEntry(
        edinet_code='E38766',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平井\u3000康博',
        submitter_name_en=None,
        submitter_name_yomi='ヒライ\u3000ヤスヒロ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38768': EdinetCodeEntry(
        edinet_code='E38768',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000光夫',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ミツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38770': EdinetCodeEntry(
        edinet_code='E38770',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｋａｍ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカムインターナショナル',
        address='札幌市北区屯田９条３丁目２－１ー４０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011101060832',
    ),
    'E38771': EdinetCodeEntry(
        edinet_code='E38771',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=18499,
        fiscal_year_end='12月31日',
        submitter_name='韓国投資証券株式會社',
        submitter_name_en=None,
        submitter_name_yomi='カンコクトウシショウケンカブシキガイシャ',
        address='ソウル特別市永登浦区議事堂大路８８',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E38773': EdinetCodeEntry(
        edinet_code='E38773',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武内\u3000寿憲',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000トシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38775': EdinetCodeEntry(
        edinet_code='E38775',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩本\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38777': EdinetCodeEntry(
        edinet_code='E38777',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='互\u3000夕希子',
        submitter_name_en=None,
        submitter_name_yomi='タガイ\u3000ユキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38778': EdinetCodeEntry(
        edinet_code='E38778',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堤\u3000倭子',
        submitter_name_en=None,
        submitter_name_yomi='ツツミ\u3000シズコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38779': EdinetCodeEntry(
        edinet_code='E38779',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石花\u3000千花',
        submitter_name_en=None,
        submitter_name_yomi='イシハナ\u3000チカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38780': EdinetCodeEntry(
        edinet_code='E38780',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=131,
        fiscal_year_end='2月28日',
        submitter_name='株式会社ＪＲＣ',
        submitter_name_en='JRC CO.,LTD.',
        submitter_name_yomi='カブシキカイシャジェイアールシー',
        address='大阪市西区阿波座二丁目１番１号',
        industry='輸送用機器',
        sec_code='62240',
        corporate_number='2120001044197',
    ),
    'E38781': EdinetCodeEntry(
        edinet_code='E38781',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山田\u3000孝',
        submitter_name_en=None,
        submitter_name_yomi='ヤマダ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38783': EdinetCodeEntry(
        edinet_code='E38783',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市川\u3000康平',
        submitter_name_en=None,
        submitter_name_yomi='イチカワ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38784': EdinetCodeEntry(
        edinet_code='E38784',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000強',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38785': EdinetCodeEntry(
        edinet_code='E38785',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=28,
        fiscal_year_end='8月31日',
        submitter_name='株式会社カイテクノロジー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカイテクノロジー',
        address='新宿区内藤町８７',
        industry='情報・通信業',
        sec_code='55810',
        corporate_number='2010401122225',
    ),
    'E38786': EdinetCodeEntry(
        edinet_code='E38786',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩間公一\u3000相続人代表岩間要',
        submitter_name_en=None,
        submitter_name_yomi='イワマコウイチ\u3000ソウゾクニンダイヒョウイワマカナメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38787': EdinetCodeEntry(
        edinet_code='E38787',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川田\u3000友也',
        submitter_name_en=None,
        submitter_name_yomi='カワタ\u3000ユウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38788': EdinetCodeEntry(
        edinet_code='E38788',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小南\u3000秀光',
        submitter_name_en=None,
        submitter_name_yomi='コミナミ\u3000ヒデミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38789': EdinetCodeEntry(
        edinet_code='E38789',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=932,
        fiscal_year_end=None,
        submitter_name='株式会社バイジェン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャバイジェン',
        address='（Ｊａｎｇｈａｎｇ－ｄｏｎｇ，\u3000Ｍａｄｕｂｅｏｐｊｏ\u3000Ｂｕｉｌｄｉｎｇ）\u3000６８４－Ｈｏ，\u3000１１９３，\u3000Ｊｕｎｇａｎｇ－ｒｏ，\u3000Ｉｌｓａｎｄｏｎｇ－ｇｕ，\u3000Ｇｏｙａｎｇ－ｓｉ，\u3000Ｇｙｅｏｎｇｇｉ－ｄｏ，\u3000Ｒｅｐｕｂｌｉｃ\u3000ｏｆ\u3000Ｋｏｒｅａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38792': EdinetCodeEntry(
        edinet_code='E38792',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社ココアアセット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャココアアセット',
        address='大阪市北区豊崎３丁目１８－３－３６０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120001122492',
    ),
    'E38793': EdinetCodeEntry(
        edinet_code='E38793',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｋｉｎｇｗｏｒｌｄ\u3000Ｍｅｄｉｃｉｎｅｓ\u3000Ｈｅａｌｔｈ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='キングワールド\u3000メディスンズ\u3000ヘルス\u3000マネジメント\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000ＩＩ，Ｒｏａｄ\u3000Ｔｏｗｎ，Ｔｏｒｔｏｌａ，ＶＧ１１１０，Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38798': EdinetCodeEntry(
        edinet_code='E38798',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大壁\u3000勝洋',
        submitter_name_en=None,
        submitter_name_yomi='オオカベ\u3000カツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38799': EdinetCodeEntry(
        edinet_code='E38799',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊井\u3000敏幸',
        submitter_name_en=None,
        submitter_name_yomi='イイ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38801': EdinetCodeEntry(
        edinet_code='E38801',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永野\u3000謙一',
        submitter_name_en=None,
        submitter_name_yomi='ナガノ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38804': EdinetCodeEntry(
        edinet_code='E38804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=75,
        fiscal_year_end=None,
        submitter_name='ミツワ樹脂工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツワジュシコウギョウカブシキガイシャ',
        address='川口市本蓮一丁目２３番地３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7030001077383',
    ),
    'E38806': EdinetCodeEntry(
        edinet_code='E38806',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000聡彦',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000アキヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38807': EdinetCodeEntry(
        edinet_code='E38807',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白井\u3000元',
        submitter_name_en=None,
        submitter_name_yomi='シライ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38808': EdinetCodeEntry(
        edinet_code='E38808',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='住村\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='スミムラ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38809': EdinetCodeEntry(
        edinet_code='E38809',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤\u3000芳樹',
        submitter_name_en=None,
        submitter_name_yomi='サワ\u3000ヨシキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38811': EdinetCodeEntry(
        edinet_code='E38811',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松藤\u3000洋介',
        submitter_name_en=None,
        submitter_name_yomi='マツフジ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38812': EdinetCodeEntry(
        edinet_code='E38812',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='槙野\u3000常美',
        submitter_name_en=None,
        submitter_name_yomi='マキノ\u3000ツネミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38813': EdinetCodeEntry(
        edinet_code='E38813',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000茂喜',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38814': EdinetCodeEntry(
        edinet_code='E38814',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000富久子',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000フクコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38815': EdinetCodeEntry(
        edinet_code='E38815',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='龍池\u3000法子',
        submitter_name_en=None,
        submitter_name_yomi='タツイケ\u3000ノリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38816': EdinetCodeEntry(
        edinet_code='E38816',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平山\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='ヒラヤマ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38818': EdinetCodeEntry(
        edinet_code='E38818',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＹｏｕｒＴｕｒｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャユアターン',
        address='港区元麻布三丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001251767',
    ),
    'E38819': EdinetCodeEntry(
        edinet_code='E38819',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北電工取引先持株会\u3000理事長\u3000植野\u3000敏典',
        submitter_name_en=None,
        submitter_name_yomi='ホクデンコウトリヒキサキモチカブカイ\u3000リジチョウ\u3000ウエノ\u3000トシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38821': EdinetCodeEntry(
        edinet_code='E38821',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='勝屋\u3000嘉恭',
        submitter_name_en=None,
        submitter_name_yomi='カツヤ\u3000ヨシヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38825': EdinetCodeEntry(
        edinet_code='E38825',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='研創親和会\u3000理事長\u3000石丸朋文',
        submitter_name_en=None,
        submitter_name_yomi='ケンソウシンワカイ\u3000リジチョウ\u3000イシマルトモフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38827': EdinetCodeEntry(
        edinet_code='E38827',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大塚\u3000隆之',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38828': EdinetCodeEntry(
        edinet_code='E38828',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村上\u3000範義',
        submitter_name_en=None,
        submitter_name_yomi='ムラカミ\u3000ノリヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38829': EdinetCodeEntry(
        edinet_code='E38829',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=356,
        fiscal_year_end=None,
        submitter_name='株式会社福岡キャピタルパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフクオカキャピタルパートナーズ',
        address='福岡市博多区上川端町１２番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2290001026030',
    ),
    'E38830': EdinetCodeEntry(
        edinet_code='E38830',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=237,
        fiscal_year_end=None,
        submitter_name='住友生命２０２３基金流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイニセンニジュウサンキキンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001236256',
    ),
    'E38831': EdinetCodeEntry(
        edinet_code='E38831',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12591,
        fiscal_year_end=None,
        submitter_name='自然電力株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シゼンデンリョクカブシキカイシャ',
        address='福岡市中央区荒戸一丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001140434',
    ),
    'E38832': EdinetCodeEntry(
        edinet_code='E38832',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=253,
        fiscal_year_end=None,
        submitter_name='南海商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナンカイショウジカブシキカイシャ',
        address='大阪市西区西本町２丁目２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001046117',
    ),
    'E38840': EdinetCodeEntry(
        edinet_code='E38840',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社村松屋商店',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャムラマツヤショウテン',
        address='大田区南六郷二丁目５番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010801027077',
    ),
    'E38842': EdinetCodeEntry(
        edinet_code='E38842',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片岡\u3000尚',
        submitter_name_en=None,
        submitter_name_yomi='カタオカ\u3000ナオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38843': EdinetCodeEntry(
        edinet_code='E38843',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='申\u3000真衣',
        submitter_name_en=None,
        submitter_name_yomi='シン\u3000マイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38845': EdinetCodeEntry(
        edinet_code='E38845',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='湊\u3000剛宏',
        submitter_name_en=None,
        submitter_name_yomi='ミナト\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38846': EdinetCodeEntry(
        edinet_code='E38846',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森西\u3000淳',
        submitter_name_en=None,
        submitter_name_yomi='モリニシ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38849': EdinetCodeEntry(
        edinet_code='E38849',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='9月30日',
        submitter_name='株式会社揚羽',
        submitter_name_en='AGEHA Inc.',
        submitter_name_yomi='カブシキガイシャアゲハ',
        address='中央区八丁堀二丁目１２番７号',
        industry='サービス業',
        sec_code='93300',
        corporate_number='3010001133118',
    ),
    'E38850': EdinetCodeEntry(
        edinet_code='E38850',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='バズー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バズーカブシキガイシャ',
        address='浦添市城間３丁目３番１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401076874',
    ),
    'E38851': EdinetCodeEntry(
        edinet_code='E38851',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='グランディ・ストックメイト\u3000理事長\u3000臼井\u3000章浩',
        submitter_name_en=None,
        submitter_name_yomi='グランディ\u3000ストックメイト\u3000リジチョウ\u3000ウスイ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38853': EdinetCodeEntry(
        edinet_code='E38853',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＳｏｃｉａｌＧｏｏｄ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソーシャルグッド',
        address='港区白金２－７－２７ー１４０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010403023092',
    ),
    'E38858': EdinetCodeEntry(
        edinet_code='E38858',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35,
        fiscal_year_end=None,
        submitter_name='京都大学イノベーションキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウトダイガクイノベーションキャピタルカブシキカイシャ',
        address='京都市左京区吉田本町３６番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5130001054399',
    ),
    'E38859': EdinetCodeEntry(
        edinet_code='E38859',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=800,
        fiscal_year_end=None,
        submitter_name='ＡＣＴＷＥＬＬ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アクトウェルゴウドウガイシャ',
        address='渋谷区本町三丁目三十七番地九号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011003008298',
    ),
    'E38861': EdinetCodeEntry(
        edinet_code='E38861',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='合同会社アローエナジー',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャアローエナジー',
        address='東京都港区新橋２－１６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403029160',
    ),
    'E38863': EdinetCodeEntry(
        edinet_code='E38863',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石﨑\u3000秀信',
        submitter_name_en=None,
        submitter_name_yomi='イシザキ\u3000ヒデノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38864': EdinetCodeEntry(
        edinet_code='E38864',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=121,
        fiscal_year_end='9月30日',
        submitter_name='株式会社インバウンドプラットフォーム',
        submitter_name_en='Inbound Platform Corp.',
        submitter_name_yomi='カブシキガイシャインバウンドプラットフォーム',
        address='港区新橋六丁目１４番５号',
        industry='情報・通信業',
        sec_code='55870',
        corporate_number='2011001107558',
    ),
    'E38865': EdinetCodeEntry(
        edinet_code='E38865',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉田\u3000耕治',
        submitter_name_en=None,
        submitter_name_yomi='タマダ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38866': EdinetCodeEntry(
        edinet_code='E38866',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='菊地歯車株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キクチハグルマカブシキガイシャ',
        address='足利市福富新町７２６－３０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9060001018507',
    ),
    'E38867': EdinetCodeEntry(
        edinet_code='E38867',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='椎橋\u3000徹夫',
        submitter_name_en=None,
        submitter_name_yomi='シイハシ\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38868': EdinetCodeEntry(
        edinet_code='E38868',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤原\u3000弘将',
        submitter_name_en=None,
        submitter_name_yomi='フジハラ\u3000ヒロマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38869': EdinetCodeEntry(
        edinet_code='E38869',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福田\u3000道夫',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ミチオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38870': EdinetCodeEntry(
        edinet_code='E38870',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴＴデータ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌティティデータ',
        address='江東区豊洲三丁目３番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010601062093',
    ),
    'E38871': EdinetCodeEntry(
        edinet_code='E38871',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社コヒーレントシステムズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコヒーレントシステムズ',
        address='横浜市港北区新横浜２－６－１２・２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020001137004',
    ),
    'E38872': EdinetCodeEntry(
        edinet_code='E38872',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11846,
        fiscal_year_end=None,
        submitter_name='ＢＥＥＮＥＸＴ２\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーネクスト\u3000ツー\u3000ピーティーイー\u3000エルティーディー',
        address='９\u3000Ｒａｆｆｌｅｓ\u3000Ｐｌａｃｅ\u3000＃２６－０１\u3000Ｒｅｐｕｂｌｉｃ\u3000Ｐｌａｚａ\u3000Ｓｉｎｇａｐｏｒｅ\u3000０４８６１９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38874': EdinetCodeEntry(
        edinet_code='E38874',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000勉',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ツトム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38876': EdinetCodeEntry(
        edinet_code='E38876',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古屋\u3000雅章',
        submitter_name_en=None,
        submitter_name_yomi='フルヤ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38883': EdinetCodeEntry(
        edinet_code='E38883',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山中\u3000千佳',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナカ\u3000チカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38886': EdinetCodeEntry(
        edinet_code='E38886',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エイチアンドパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチアンドパートナーズ',
        address='港区六本木６－２－３１\u3000六本木ヒルズノースタワー１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401121640',
    ),
    'E38888': EdinetCodeEntry(
        edinet_code='E38888',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ガバナンス・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ガバナンスパートナーズカブシキガイシャ',
        address='港区虎ノ門３丁目４－１０虎ノ門３５森ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001106732',
    ),
    'E38889': EdinetCodeEntry(
        edinet_code='E38889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='辻商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツジショウジカブシキガイシャ',
        address='大阪市西淀川区姫島三丁目１番４７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001256182',
    ),
    'E38890': EdinetCodeEntry(
        edinet_code='E38890',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉君人',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベキミヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38892': EdinetCodeEntry(
        edinet_code='E38892',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社常陽キャピタルパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジョウヨウキャピタルパートナーズ',
        address='水戸市南町２丁目５番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7050001004914',
    ),
    'E38894': EdinetCodeEntry(
        edinet_code='E38894',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社中央商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャチュウオウショウジ',
        address='渋谷区上原二丁目２１番１８－２０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011301004424',
    ),
    'E38895': EdinetCodeEntry(
        edinet_code='E38895',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=163,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ライズ・コンサルティング・グループ',
        submitter_name_en='Rise Consulting Group, Inc.',
        submitter_name_yomi='カブシキガイシャライズコンサルティンググループ',
        address='港区六本木１－６－１\u3000泉ガーデンタワー３４階',
        industry='サービス業',
        sec_code='91680',
        corporate_number='5010401156815',
    ),
    'E38896': EdinetCodeEntry(
        edinet_code='E38896',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000泰亘',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38898': EdinetCodeEntry(
        edinet_code='E38898',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=309,
        fiscal_year_end='6月30日',
        submitter_name='笹徳印刷株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ササトクインサツカブシキガイシャ',
        address='豊明市栄町大脇７番地',
        industry='その他製品',
        sec_code='39580',
        corporate_number='1180001069322',
    ),
    'E38899': EdinetCodeEntry(
        edinet_code='E38899',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='葛石\u3000智',
        submitter_name_en=None,
        submitter_name_yomi='カッセキ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38900': EdinetCodeEntry(
        edinet_code='E38900',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='葛石\u3000真士',
        submitter_name_en=None,
        submitter_name_yomi='カッセキ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38901': EdinetCodeEntry(
        edinet_code='E38901',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='葛石\u3000晋三',
        submitter_name_en=None,
        submitter_name_yomi='カッセキ\u3000シンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38903': EdinetCodeEntry(
        edinet_code='E38903',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＲＥＶＩＣキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='レビックキャピタルカブシキカイシャ',
        address='千代田区大手町１丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001154405',
    ),
    'E38904': EdinetCodeEntry(
        edinet_code='E38904',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='デジタルバリューチェーンパートナーズ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='デジタルバリューチェーンパートナーズゴウドウカイシャ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010403030548',
    ),
    'E38905': EdinetCodeEntry(
        edinet_code='E38905',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='8月末日',
        submitter_name='Ｃｈｏｒｄｉａ\u3000Ｔｈｅｒａｐｅｕｔｉｃｓ株式会社',
        submitter_name_en='Chordia Therapeutics,Inc',
        submitter_name_yomi='コーディアセラピューティクスカブシキガイシャ',
        address='藤沢市村岡東２－２６－１',
        industry='医薬品',
        sec_code='190A0',
        corporate_number='1021001063330',
    ),
    'E38906': EdinetCodeEntry(
        edinet_code='E38906',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=293,
        fiscal_year_end='9月30日',
        submitter_name='成友興業株式会社',
        submitter_name_en='SEIYU KOGYO Co.,Ltd.',
        submitter_name_yomi='セイユウコウギョウカブシキガイシャ',
        address='あきる野市草花１１４１番地１',
        industry='サービス業',
        sec_code='91700',
        corporate_number='5013101000994',
    ),
    'E38910': EdinetCodeEntry(
        edinet_code='E38910',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=157,
        fiscal_year_end=None,
        submitter_name='Ｌｉｆｅ\u3000Ｓｃｉｅｎｃｅ\u3000＆\u3000Ｄｉｇｉｔａｌ\u3000Ｈｅａｌｔｈ\u3000Ｃｏ．\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ライフサイエンスアンドデジタルヘルスカンパニーリミテッド',
        address='アイルランド、ダブリン、ダブリン２、ジョージズ・キー・ダブリン２、ジョージズ・キー・プラザ、１階ブロックＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38911': EdinetCodeEntry(
        edinet_code='E38911',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=226,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ロジック・アンド・デザイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャロジックアンドデザイン',
        address='新宿区四谷３－２－１\u3000フロントプレイス四谷５階',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010001190366',
    ),
    'E38912': EdinetCodeEntry(
        edinet_code='E38912',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大島\u3000正人',
        submitter_name_en=None,
        submitter_name_yomi='オオシマ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38913': EdinetCodeEntry(
        edinet_code='E38913',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｆｓｌｕｉｔｄｉｊｋ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='アフスライトダイクビーヴィ',
        address='オランダ、アムステルダム、１１０１\u3000ＣＭ、ヘリカーベルクウェグ８８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38914': EdinetCodeEntry(
        edinet_code='E38914',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＹＪホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイジェイホールディングスカブシキガイシャ',
        address='千代田区丸の内三丁目４番１号新国際ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001236982',
    ),
    'E38915': EdinetCodeEntry(
        edinet_code='E38915',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｆｓｌｕｉｔｄｉｊｋ\u3000Ｈｏｌｄｉｎｇｓ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='アフスライトダイクホールディングスビーヴィ',
        address='オランダ、アムステルダム、１１０１\u3000ＣＭ、ヘリカーベルクウェグ８８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38916': EdinetCodeEntry(
        edinet_code='E38916',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濱口\u3000稔',
        submitter_name_en=None,
        submitter_name_yomi='ハマグチ\u3000ミノル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38917': EdinetCodeEntry(
        edinet_code='E38917',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='濱口\u3000佳宏',
        submitter_name_en=None,
        submitter_name_yomi='ハマグチ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38918': EdinetCodeEntry(
        edinet_code='E38918',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小出\u3000文彦',
        submitter_name_en=None,
        submitter_name_yomi='コイデ\u3000フミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38919': EdinetCodeEntry(
        edinet_code='E38919',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=667,
        fiscal_year_end='12月31日',
        submitter_name='株式会社オートサーバー',
        submitter_name_en='AUTO SERVER Co.,LTD.',
        submitter_name_yomi='カブシキガイシャオートサーバー',
        address='中央区日本橋室町四丁目６番２号',
        industry='情報・通信業',
        sec_code='55890',
        corporate_number='2010001171804',
    ),
    'E38920': EdinetCodeEntry(
        edinet_code='E38920',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000和信',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000カズノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38921': EdinetCodeEntry(
        edinet_code='E38921',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＳＫ\u3000ＣＡＰＩＴＡＬ\u3000ＰＡＲＴＮＥＲＳ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ティーエスケー\u3000キャピタル\u3000パートナーズ\u3000エルエルシー',
        address='２９７２\u3000ＣＯＬＵＭＢＩＡ\u3000ＳＴ\u3000ＴＯＲＲＡＮＣＥ\u3000ＣＡ\u3000９０５０３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38922': EdinetCodeEntry(
        edinet_code='E38922',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＢＰインベストメント合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーピーインベストメントゴウドウカイシャ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401172670',
    ),
    'E38923': EdinetCodeEntry(
        edinet_code='E38923',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔ′ｓ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ティーズインターナショナル',
        address='千代田区丸の内一丁目６番２号\u3000新丸の内センタービルディング１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001208736',
    ),
    'E38924': EdinetCodeEntry(
        edinet_code='E38924',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志方\u3000廣一',
        submitter_name_en=None,
        submitter_name_yomi='シカタ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38925': EdinetCodeEntry(
        edinet_code='E38925',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＰＴ\u3000ＡＳＩＡ\u3000ＰＬＡＳＴＩＫ\u3000ＶＩＫＴＯＲＩ',
        submitter_name_en=None,
        submitter_name_yomi='ピーティアジアプラスティックビクトリー',
        address='ＪＬ．ＨＡＮＧ\u3000ＫＥＳＴＵＲＩ\u3000ＫＡＶ．Ａ－０２．Ｄｅｓａ\u3000Ｋｅｌｕｒａｈａｎ\u3000Ｋａｂｉｌ．Ｋｅｃ．Ｎｏｎｇｓａ．Ｋｏｔａ\u3000Ｂａｔａｍ．Ｐｒｏｖｉｎｓｉ\u3000Ｋｅｐｕｌａｕａｎ\u3000Ｒｉａｕ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38926': EdinetCodeEntry(
        edinet_code='E38926',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=711,
        fiscal_year_end='12月31日',
        submitter_name='株式会社\u3000西部技研',
        submitter_name_en='Seibu Giken Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャセイブギケン',
        address='古賀市青柳３１０８番地３',
        industry='機械',
        sec_code='62230',
        corporate_number='5290001036357',
    ),
    'E38927': EdinetCodeEntry(
        edinet_code='E38927',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前嶋\u3000伸昭',
        submitter_name_en=None,
        submitter_name_yomi='マエジマ\u3000ノブアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38929': EdinetCodeEntry(
        edinet_code='E38929',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ｃａｐｉｔａｌ\u3000ｈａｒｂｏｒ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャキャピタルハーバー',
        address='港区元赤坂一丁目２番７号\u3000赤坂Ｋタワー４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010403029098',
    ),
    'E38931': EdinetCodeEntry(
        edinet_code='E38931',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社ドリームウェア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャドリームウェア',
        address='新宿区西新宿３ー１１－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101032037',
    ),
    'E38934': EdinetCodeEntry(
        edinet_code='E38934',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000高雄',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000タカオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38938': EdinetCodeEntry(
        edinet_code='E38938',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三木健嗣',
        submitter_name_en=None,
        submitter_name_yomi='ミキケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38940': EdinetCodeEntry(
        edinet_code='E38940',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='株式会社エンゼルグループ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエンゼルグループ',
        address='南魚沼郡湯沢町湯沢一丁目１番１５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='3110001035114',
    ),
    'E38941': EdinetCodeEntry(
        edinet_code='E38941',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000みさこ',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ミサコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38947': EdinetCodeEntry(
        edinet_code='E38947',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=40,
        fiscal_year_end='8月31日',
        submitter_name='小千谷産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オヂヤサンギョウカブシキガイシャ',
        address='新潟県小千谷市本町１丁目３－３',
        industry='不動産業',
        sec_code=None,
        corporate_number='1110001025323',
    ),
    'E38948': EdinetCodeEntry(
        edinet_code='E38948',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=60,
        fiscal_year_end='12月31日',
        submitter_name='ファーストアカウンティング株式会社',
        submitter_name_en='Fast Accounting Co.,Ltd.',
        submitter_name_yomi='ファーストアカウンティングカブシキカイシャ',
        address='港区浜松町１－６－１５',
        industry='情報・通信業',
        sec_code='55880',
        corporate_number='7010401125256',
    ),
    'E38949': EdinetCodeEntry(
        edinet_code='E38949',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=3,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＡＶＩＬＥＮ',
        submitter_name_en='AVILEN Inc.',
        submitter_name_yomi='カブシキガイシャアヴィレン',
        address='中央区日本橋馬喰町二丁目３－３\u3000秋葉原ファーストスクエア９階',
        industry='情報・通信業',
        sec_code='55910',
        corporate_number='1010501042976',
    ),
    'E38950': EdinetCodeEntry(
        edinet_code='E38950',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='ＴＢＪＨ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティービージェイエイチカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001230717',
    ),
    'E38953': EdinetCodeEntry(
        edinet_code='E38953',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=36,
        fiscal_year_end=None,
        submitter_name='Ｍａｖｅｎ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｐａｒｔｎｅｒｓ\u3000Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='メイヴン\u3000インベストメント\u3000パートナーズ\u3000リミテッド',
        address='Ｌｅｖｅｌ\u3000７，\u3000１５５\u3000Ｂｉｓｈｏｐｓｇａｔｅ，\u3000Ｌｏｎｄｏｎ\u3000ＥＣ２Ｍ\u3000３ＴＱ，\u3000Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38955': EdinetCodeEntry(
        edinet_code='E38955',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ミライニホン・アセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャミライニホンアセットマネジメント',
        address='港区赤坂１－１２－３２\u3000アーク森ビル２３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010403023685',
    ),
    'E38956': EdinetCodeEntry(
        edinet_code='E38956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北村\u3000裕三',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000ユウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38957': EdinetCodeEntry(
        edinet_code='E38957',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3984,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ネットスターズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャネットスターズ',
        address='中央区八丁堀三丁目３番５号',
        industry='情報・通信業',
        sec_code='55900',
        corporate_number='9010001141627',
    ),
    'E38958': EdinetCodeEntry(
        edinet_code='E38958',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＰＲＩＮＧ\u3000ＯＦ\u3000ＧＯＬＤ\u3000ＨＯＴＥＬ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＡＮＤ\u3000ＭＡＮＡＧＥＭＥＮＴ\u3000ＣＯＭＰＡＮＹ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='スプリング\u3000オブ\u3000ゴールド\u3000ホテル\u3000インベストメント\u3000アンド\u3000マネージメント\u3000カンパニー\u3000リミテッド',
        address='ＵＮＩＴ\u3000７０４，\u3000７／Ｆ．，\u3000ＣＯＮＣＯＲＤＩＡ\u3000ＰＬＡＺＡ，\u3000ＮＯ．\u3000１\u3000ＳＣＩＥＮＣＥ\u3000ＭＵＳＥＵＭ\u3000ＲＯＡＤ，\u3000ＴＳＩＭ\u3000ＳＨＡ\u3000ＴＳＵＩ\u3000ＥＡＳＴ，\u3000ＫＯＷＬＯＯＮ，\u3000ＨＯＮＧ\u3000ＫＯＮＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38959': EdinetCodeEntry(
        edinet_code='E38959',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＦＯ１',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエフオーワン',
        address='大阪市西区九条一丁２７番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120003024165',
    ),
    'E38964': EdinetCodeEntry(
        edinet_code='E38964',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上野\u3000世志史',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ヨシフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38965': EdinetCodeEntry(
        edinet_code='E38965',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社くすりの窓口',
        submitter_name_en='Kusurinomadoguchi, Inc.',
        submitter_name_yomi='カブシキガイシャクスリノマドグチ',
        address='豊島区池袋二丁目４３番１号',
        industry='情報・通信業',
        sec_code='55920',
        corporate_number='7420001005379',
    ),
    'E38967': EdinetCodeEntry(
        edinet_code='E38967',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='大韓民国',
        submitter_name_en=None,
        submitter_name_yomi='ダイカンミンコク',
        address='大韓民国',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E38968': EdinetCodeEntry(
        edinet_code='E38968',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＳＹマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエスワイマネジメント',
        address='港区赤坂１丁目１１番４０号１７０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010403030586',
    ),
    'E38969': EdinetCodeEntry(
        edinet_code='E38969',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=268,
        fiscal_year_end='10月末日',
        submitter_name='株式会社笑美面',
        submitter_name_en='Emimen Co., Ltd.',
        submitter_name_yomi='カブシキガイシャエミメン',
        address='大阪市西区京町堀一丁目８番３３号',
        industry='サービス業',
        sec_code='92370',
        corporate_number='9120001146301',
    ),
    'E38975': EdinetCodeEntry(
        edinet_code='E38975',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='インビジブルホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インビジブルホールディングスカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001237219',
    ),
    'E38977': EdinetCodeEntry(
        edinet_code='E38977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤\u3000一彦',
        submitter_name_en=None,
        submitter_name_yomi='フジ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38979': EdinetCodeEntry(
        edinet_code='E38979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='6月30日',
        submitter_name='株式会社オカムラ食品工業',
        submitter_name_en='Okamura Foods Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャオカムラショクヒンコウギョウ',
        address='青森市八重田一丁目６番１１号',
        industry='食料品',
        sec_code='29380',
        corporate_number='2420001000582',
    ),
    'E38981': EdinetCodeEntry(
        edinet_code='E38981',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社バベット',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャバベット',
        address='船橋市宮本２－９－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5040001018462',
    ),
    'E38985': EdinetCodeEntry(
        edinet_code='E38985',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ケイファーマ',
        submitter_name_en='K Pharma,Inc.',
        submitter_name_yomi='カブシキガイシャケイファーマ',
        address='港区六本木七丁目７番７号',
        industry='医薬品',
        sec_code='48960',
        corporate_number='9010401128001',
    ),
    'E38986': EdinetCodeEntry(
        edinet_code='E38986',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙田\u3000典明',
        submitter_name_en=None,
        submitter_name_yomi='タカダ\u3000ノリアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38987': EdinetCodeEntry(
        edinet_code='E38987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡村\u3000恒一',
        submitter_name_en=None,
        submitter_name_yomi='オカムラ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38989': EdinetCodeEntry(
        edinet_code='E38989',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='深山信次',
        submitter_name_en=None,
        submitter_name_yomi='ミヤマシンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38990': EdinetCodeEntry(
        edinet_code='E38990',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三橋\u3000透',
        submitter_name_en=None,
        submitter_name_yomi='ミツハシ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38991': EdinetCodeEntry(
        edinet_code='E38991',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福島\u3000弘明',
        submitter_name_en=None,
        submitter_name_yomi='フクシマ\u3000コウメイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38992': EdinetCodeEntry(
        edinet_code='E38992',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000卓繁',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000タカシゲ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38993': EdinetCodeEntry(
        edinet_code='E38993',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000昌樹',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E38996': EdinetCodeEntry(
        edinet_code='E38996',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ウエルネスジャパン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウエルネスジャパン',
        address='熊谷市三ヶ尻３７６３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1030001087198',
    ),
    'E39004': EdinetCodeEntry(
        edinet_code='E39004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='萩原\u3000外志仁',
        submitter_name_en=None,
        submitter_name_yomi='ハギワラ\u3000トシヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39005': EdinetCodeEntry(
        edinet_code='E39005',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ライズ・エイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャライズエイト',
        address='吹田市桃山台三丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120901032126',
    ),
    'E39006': EdinetCodeEntry(
        edinet_code='E39006',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水島\u3000冠',
        submitter_name_en=None,
        submitter_name_yomi='ミズシマ\u3000カン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39008': EdinetCodeEntry(
        edinet_code='E39008',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=262,
        fiscal_year_end='10月末日',
        submitter_name='ジャパンＭ＆Ａソリューション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンエムアンドエーソリューションカブシキカイシャ',
        address='千代田区麹町三丁目３番８号\u3000麹町センタープレイス７階',
        industry='サービス業',
        sec_code='92360',
        corporate_number='3010701038434',
    ),
    'E39009': EdinetCodeEntry(
        edinet_code='E39009',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ドリーム・アーツ',
        submitter_name_en='DreamArts Corporation',
        submitter_name_yomi='カブシキガイシャドリームアーツ',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='情報・通信業',
        sec_code='48110',
        corporate_number='9011001040835',
    ),
    'E39016': EdinetCodeEntry(
        edinet_code='E39016',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｔｉｎｇ\u3000Ｙａｎ\u3000Ｃｈｕｎ',
        submitter_name_en=None,
        submitter_name_yomi='ティン\u3000ヤン\u3000チュン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39018': EdinetCodeEntry(
        edinet_code='E39018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1729,
        fiscal_year_end='3月末日',
        submitter_name='全保連株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼンホレンカブシキガイシャ',
        address='那覇市字天久９０５番地',
        industry='その他金融業',
        sec_code='58450',
        corporate_number='9360001002793',
    ),
    'E39020': EdinetCodeEntry(
        edinet_code='E39020',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＤＯＥ５パーセント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャディーオーイーゴパーセント',
        address='渋谷区千駄ヶ谷３－２０－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001143471',
    ),
    'E39022': EdinetCodeEntry(
        edinet_code='E39022',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｈｏｒｕｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ホルスカブシキガイシャ',
        address='千代田区大手町一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001237715',
    ),
    'E39023': EdinetCodeEntry(
        edinet_code='E39023',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=48,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ＡｌｂａＬｉｎｋ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルバリンク',
        address='江東区木場二丁目１７番１６号\u3000ＢＥＳＩＤＥ\u3000ＫＩＢＡ３階',
        industry='不動産業',
        sec_code='55370',
        corporate_number='4010401091724',
    ),
    'E39024': EdinetCodeEntry(
        edinet_code='E39024',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森\u3000啓太郎',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000ケイタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39030': EdinetCodeEntry(
        edinet_code='E39030',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000陽祐',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39031': EdinetCodeEntry(
        edinet_code='E39031',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＢＳＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌビーエスイー',
        address='渋谷区渋谷２丁目２４番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001131734',
    ),
    'E39032': EdinetCodeEntry(
        edinet_code='E39032',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000喜容子',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000キヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39034': EdinetCodeEntry(
        edinet_code='E39034',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清原\u3000達郎',
        submitter_name_en=None,
        submitter_name_yomi='キヨハラ\u3000タツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39036': EdinetCodeEntry(
        edinet_code='E39036',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6861,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000キュロホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000キュロホールディングス',
        address='ソウル特別市江南区テヘラン７７ギル７\u3000４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39037': EdinetCodeEntry(
        edinet_code='E39037',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮脇\u3000邦人',
        submitter_name_en=None,
        submitter_name_yomi='ミヤワキ\u3000クニト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39038': EdinetCodeEntry(
        edinet_code='E39038',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社プリマベーラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプリマベーラ',
        address='港区赤坂８－２－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013301039790',
    ),
    'E39039': EdinetCodeEntry(
        edinet_code='E39039',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='スチールヘッド\u3000プライベート・リミテッド・ライアビリテイ・カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='スチールヘッド\u3000プライベートリミテッドライアビリティカンパニー',
        address='スプロゴーベ１７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39042': EdinetCodeEntry(
        edinet_code='E39042',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='邉見\u3000芳弘',
        submitter_name_en=None,
        submitter_name_yomi='ヘンミ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39043': EdinetCodeEntry(
        edinet_code='E39043',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水谷\u3000謙作',
        submitter_name_en=None,
        submitter_name_yomi='ミズタニ\u3000ケンサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39046': EdinetCodeEntry(
        edinet_code='E39046',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川上\u3000俊行',
        submitter_name_en=None,
        submitter_name_yomi='カワカミ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39047': EdinetCodeEntry(
        edinet_code='E39047',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社セコイア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャセコイア',
        address='港区赤坂一丁目１４番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010402032174',
    ),
    'E39048': EdinetCodeEntry(
        edinet_code='E39048',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='有限会社ビジネスレター',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャビジネスレター',
        address='生駒市東生駒１ー４３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120002007253',
    ),
    'E39049': EdinetCodeEntry(
        edinet_code='E39049',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上平\u3000豊久',
        submitter_name_en=None,
        submitter_name_yomi='ウエヒラ\u3000トヨヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39052': EdinetCodeEntry(
        edinet_code='E39052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000大樹',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000ダイキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39053': EdinetCodeEntry(
        edinet_code='E39053',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本間\u3000真彦',
        submitter_name_en=None,
        submitter_name_yomi='ホンマ\u3000マサヒコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39054': EdinetCodeEntry(
        edinet_code='E39054',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神谷\u3000紀彦',
        submitter_name_en=None,
        submitter_name_yomi='カミヤ\u3000ノリヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39055': EdinetCodeEntry(
        edinet_code='E39055',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='６８ｋ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ロクハチケイカブシキガイシャ',
        address='港区愛宕１－１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401164576',
    ),
    'E39058': EdinetCodeEntry(
        edinet_code='E39058',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=405,
        fiscal_year_end=None,
        submitter_name='全共連第３回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼンキョウレンダイサンカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001238471',
    ),
    'E39060': EdinetCodeEntry(
        edinet_code='E39060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='津川\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='ツガワ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39063': EdinetCodeEntry(
        edinet_code='E39063',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2862,
        fiscal_year_end=None,
        submitter_name='モラント・ライト・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='モラントライトマネジメントリミテッド',
        address='ＳＷ１Ａ\u3000１ＮＳ、英国、ロンドン、ジェームズプレイス通り４３番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39065': EdinetCodeEntry(
        edinet_code='E39065',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７６',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーシージェイセブンティシックス',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001238553',
    ),
    'E39066': EdinetCodeEntry(
        edinet_code='E39066',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='隈\u3000扶三郎',
        submitter_name_en=None,
        submitter_name_yomi='クマ\u3000フミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39067': EdinetCodeEntry(
        edinet_code='E39067',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人隈科学技術・文化振興会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンクマカガクギジュツブンカシンコウカイ',
        address='古賀市青柳３１０８番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7290005017434',
    ),
    'E39069': EdinetCodeEntry(
        edinet_code='E39069',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='トラストアップ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トラストアップカブシキカイシャ',
        address='千代田区丸の内二丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001200940',
    ),
    'E39070': EdinetCodeEntry(
        edinet_code='E39070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='李\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='リ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39072': EdinetCodeEntry(
        edinet_code='E39072',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＫＪＰ２\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイジェイピーツー\u3000エルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランド・ハウス、私書箱第３０９、メイプルス・コーポレート・サービシーズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39074': EdinetCodeEntry(
        edinet_code='E39074',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='1月31日',
        submitter_name='Ｊａｐａｎ\u3000Ｅｙｅｗｅａｒ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en='Japan Eyewear Holdings',
        submitter_name_yomi='ジャパンアイウェアホールディングスカブシキガイシャ',
        address='鯖江市吉江町７１２番地２',
        industry='小売業',
        sec_code='58890',
        corporate_number='6010001202919',
    ),
    'E39075': EdinetCodeEntry(
        edinet_code='E39075',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｃｈａｎ\u3000Ａｌｌｉｅ',
        submitter_name_en=None,
        submitter_name_yomi='チャン\u3000アリー',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39076': EdinetCodeEntry(
        edinet_code='E39076',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='株式会社旺司ライフワーク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオウジライフワーク',
        address='岐阜市北一色１丁目１０番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6200001037668',
    ),
    'E39079': EdinetCodeEntry(
        edinet_code='E39079',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='崔\u3000一鳴',
        submitter_name_en=None,
        submitter_name_yomi='サイ\u3000イミン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39083': EdinetCodeEntry(
        edinet_code='E39083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三好\u3000修',
        submitter_name_en=None,
        submitter_name_yomi='ミヨシオサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39089': EdinetCodeEntry(
        edinet_code='E39089',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=157,
        fiscal_year_end='2月末日',
        submitter_name='バリュークリエーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バリュークリエーションカブシキガイシャ',
        address='渋谷区恵比寿１ー１８ー１４\u3000恵比寿ファーストスクエア９階',
        industry='サービス業',
        sec_code='92380',
        corporate_number='8011001056031',
    ),
    'E39090': EdinetCodeEntry(
        edinet_code='E39090',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ＬＵＮ\u3000ＰＡＲＴＮＥＲＳ\u3000ＣＡＰＩＴＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ルンパートナーズキャピタルリミテッド',
        address='Ｈａｒｎｅｙｓ\u3000Ｓｅｒｖｉｃｅｓ\u3000（Ｃａｙｍａｎ）\u3000Ｌｉｍｉｔｅｄ，\u3000４ｔｈ\u3000Ｆｌｏｏｒ，\u3000Ｈａｒｂｏｕｒ\u3000Ｐｌａｃｅ，\u3000１０３\u3000Ｓｏｕｔｈ\u3000Ｃｈｕｒｃｈ\u3000Ｓｔｒｅｅｔ\u3000\u3000Ｐ．Ｏ．\u3000Ｂｏｘ\u3000１０２４０，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－１００２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39091': EdinetCodeEntry(
        edinet_code='E39091',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='ＴＯＰＰＡＮ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トッパンカブシキカイシャ',
        address='台東区台東一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010501050089',
    ),
    'E39092': EdinetCodeEntry(
        edinet_code='E39092',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='涌本\u3000宜央',
        submitter_name_en=None,
        submitter_name_yomi='ワクモト\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39094': EdinetCodeEntry(
        edinet_code='E39094',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＷＡＫＵＭＯＴＯ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワクモト',
        address='八尾市南本町一丁目２番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2122001033353',
    ),
    'E39095': EdinetCodeEntry(
        edinet_code='E39095',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='アイング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイングカブシキカイシャ',
        address='千代田区麹町二丁目１４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001023019',
    ),
    'E39096': EdinetCodeEntry(
        edinet_code='E39096',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=354490,
        fiscal_year_end=None,
        submitter_name='ＴＢＪホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティービージェイホールディングスカブシキガイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001230585',
    ),
    'E39098': EdinetCodeEntry(
        edinet_code='E39098',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='細沼\u3000順人',
        submitter_name_en=None,
        submitter_name_yomi='ホソヌマ\u3000マサヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39099': EdinetCodeEntry(
        edinet_code='E39099',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='インベストメントＺ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='インベストメントゼットカブシキカイシャ',
        address='港区虎ノ門三丁目２２番１０－２０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001206544',
    ),
    'E39104': EdinetCodeEntry(
        edinet_code='E39104',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1832,
        fiscal_year_end='12月31日',
        submitter_name='ＮＡＶＥＲ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ネイバーコーポレーション',
        address='大韓民国京畿道城南市盆唐区亭子一路９５',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E39106': EdinetCodeEntry(
        edinet_code='E39106',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡野\u3000栄之',
        submitter_name_en=None,
        submitter_name_yomi='オカノ\u3000ヒデユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39107': EdinetCodeEntry(
        edinet_code='E39107',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000雅也',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000マサヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39109': EdinetCodeEntry(
        edinet_code='E39109',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='朝日\u3000竜樹',
        submitter_name_en=None,
        submitter_name_yomi='アサヒ\u3000リュウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39110': EdinetCodeEntry(
        edinet_code='E39110',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='エー・アイ・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーアイキャピタルカブシキカイシャ',
        address='千代田区丸の内一丁目８番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001111065',
    ),
    'E39114': EdinetCodeEntry(
        edinet_code='E39114',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=695,
        fiscal_year_end='12月31日',
        submitter_name='ブルーイノベーション株式会社',
        submitter_name_en='Blue innovation Co., Ltd.',
        submitter_name_yomi='ブルーイノベーションカブシキガイシャ',
        address='文京区本郷五丁目３３番１０号',
        industry='情報・通信業',
        sec_code='55970',
        corporate_number='7010002053617',
    ),
    'E39116': EdinetCodeEntry(
        edinet_code='E39116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社キャピタルメディカ・ベンチャーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキャピタルメディカベンチャーズ',
        address='千代田区霞が関３－２－５霞が関ビルディング１９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401128239',
    ),
    'E39119': EdinetCodeEntry(
        edinet_code='E39119',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤本\u3000茂',
        submitter_name_en=None,
        submitter_name_yomi='フジモト\u3000シゲル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39122': EdinetCodeEntry(
        edinet_code='E39122',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=441,
        fiscal_year_end='3月31日',
        submitter_name='Ｓ＆Ｊ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスアンドジェイカブシキガイシャ',
        address='港区新橋一丁目１番１号日比谷ビルディング',
        industry='情報・通信業',
        sec_code='55990',
        corporate_number='9010401079013',
    ),
    'E39124': EdinetCodeEntry(
        edinet_code='E39124',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白井\u3000総',
        submitter_name_en=None,
        submitter_name_yomi='シライ\u3000オサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39126': EdinetCodeEntry(
        edinet_code='E39126',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=145,
        fiscal_year_end='3月末日',
        submitter_name='アウトルックコンサルティング株式会社',
        submitter_name_en='OutlookConsulting Co., Ltd.',
        submitter_name_yomi='アウトルックコンサルティングカブシキカイシャ',
        address='港区南青山三丁目１番３号スプライン青山東急ビル',
        industry='情報・通信業',
        sec_code='55960',
        corporate_number='1010001098759',
    ),
    'E39129': EdinetCodeEntry(
        edinet_code='E39129',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人ズームグループ学術振興財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンズームグループガクジュツシンコウザイダン',
        address='千代田区神田駿河台四丁目４番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010005035219',
    ),
    'E39133': EdinetCodeEntry(
        edinet_code='E39133',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=872,
        fiscal_year_end='12月31日',
        submitter_name='株式会社魁力屋',
        submitter_name_en='Kairikiya Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャカイリキヤ',
        address='京都市中京区烏丸通錦小路上る手洗水町６７０番地',
        industry='小売業',
        sec_code='58910',
        corporate_number='4130001026309',
    ),
    'E39135': EdinetCodeEntry(
        edinet_code='E39135',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榎並\u3000将志',
        submitter_name_en=None,
        submitter_name_yomi='エナミ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39136': EdinetCodeEntry(
        edinet_code='E39136',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=642,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ロココ',
        submitter_name_en='Rococo Co. Ltd.',
        submitter_name_yomi='カブシキカイシャロココ',
        address='大阪市中央区西心斎橋二丁目１番５号日本生命御堂筋八幡町ビル３階',
        industry='情報・通信業',
        sec_code='58680',
        corporate_number='5120001092383',
    ),
    'E39137': EdinetCodeEntry(
        edinet_code='E39137',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=6108,
        fiscal_year_end='5月末日',
        submitter_name='株式会社ＱＰＳ研究所',
        submitter_name_en='Institute for Q-shu Pioneers of Space, Inc.',
        submitter_name_yomi='カブシキガイシャキューピーエスケンキュウショ',
        address='福岡市中央区天神一丁目１５番３５号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2290002030634',
    ),
    'E39138': EdinetCodeEntry(
        edinet_code='E39138',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000孝昭',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タカアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39139': EdinetCodeEntry(
        edinet_code='E39139',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西谷\u3000明久',
        submitter_name_en=None,
        submitter_name_yomi='ニシタニ\u3000アキヒサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39140': EdinetCodeEntry(
        edinet_code='E39140',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｔｈａｎａｓｅ\u3000Ｉｎｄｕｓｔｒｉａｌ\u3000Ｐａｒｔｎｅｒ\u3000ＡＢ',
        submitter_name_en=None,
        submitter_name_yomi='アタナセインダストリアルパートナーエービー',
        address='Ｂｉｒｇｅｒ\u3000Ｊａｒｌｓｇａｔａｎ\u3000６\u3000４ｔｈ\u3000ｆｌｏｏｒ，\u3000１１４\u3000３４\u3000Ｓｔｏｃｋｈｏｌｍ，\u3000Ｓｗｅｄｅｎ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39142': EdinetCodeEntry(
        edinet_code='E39142',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='Ａｔｈａｎａｓｅ\u3000Ｉｎｄｕｓｔｒｉａｌ\u3000Ｐａｒｔｎｅｒ',
        submitter_name_en=None,
        submitter_name_yomi='アタナセインダストリアルパートナー',
        address='Ｌａｎｄｍａｒｋ\u3000Ｓｑｕａｒｅ，\u3000Ｗｅｓｔ\u3000Ｂａｙ\u3000Ｒｏａｄ，\u3000ＰＯ\u3000Ｂｏｘ\u3000７７５，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００６，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39143': EdinetCodeEntry(
        edinet_code='E39143',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人南海育英会',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンナンカイイクエイカイ',
        address='高松市常磐町二丁目１３番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2470005005268',
    ),
    'E39144': EdinetCodeEntry(
        edinet_code='E39144',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＭＭ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケーエムエム',
        address='千代田区紀尾井町４番１号ニューオータニガーデンコート８Ｆ税理士法人エクラコンサルティング内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001238926',
    ),
    'E39145': EdinetCodeEntry(
        edinet_code='E39145',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='迫\u3000幸治',
        submitter_name_en=None,
        submitter_name_yomi='サコ\u3000ユキハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39146': EdinetCodeEntry(
        edinet_code='E39146',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社北杜マネージメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャホクトマネージメント',
        address='渋谷区上原二丁目２５番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001157408',
    ),
    'E39147': EdinetCodeEntry(
        edinet_code='E39147',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2367,
        fiscal_year_end=None,
        submitter_name='ＢＰＥＡ\u3000ＶＩＩ\u3000Ｈｏｌｄｉｎｇ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーピーイーエーセブンホールディングビーヴィ',
        address='オランダ、アムステルダム、１１０１\u3000ＣＭ、ヘリカーベルクウェグ８８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39148': EdinetCodeEntry(
        edinet_code='E39148',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='茨木\u3000英彦',
        submitter_name_en=None,
        submitter_name_yomi='イバラキ\u3000ヒデヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39149': EdinetCodeEntry(
        edinet_code='E39149',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=359,
        fiscal_year_end=None,
        submitter_name='楽言海外国際（香港）有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ラクゲンカイガイコクサイホンコンユウゲンコウシ',
        address='中国香港金鍾金鍾道８９号力宝中心第一座１０楼１００３室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39151': EdinetCodeEntry(
        edinet_code='E39151',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＫＫＲ\u3000ＨＫＥ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイケイアール\u3000エイチケーイー\u3000インベストメント\u3000エルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランド・ハウス、私書箱第３０９、メイプルス・コーポレート・サービシーズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39152': EdinetCodeEntry(
        edinet_code='E39152',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福光\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='フクミツ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39153': EdinetCodeEntry(
        edinet_code='E39153',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='越川\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='コシカワ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39154': EdinetCodeEntry(
        edinet_code='E39154',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000行雄\u3000（金\u3000行雄）',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39158': EdinetCodeEntry(
        edinet_code='E39158',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=76,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ナルネットコミュニケーションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナルネットコミュニケーションズ',
        address='春日井市下市場町五丁目１番地１６',
        industry='サービス業',
        sec_code='58700',
        corporate_number='9010401147034',
    ),
    'E39159': EdinetCodeEntry(
        edinet_code='E39159',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今井\u3000利彦',
        submitter_name_en=None,
        submitter_name_yomi='イマイ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39160': EdinetCodeEntry(
        edinet_code='E39160',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000季愛（金\u3000季愛）',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000キエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39161': EdinetCodeEntry(
        edinet_code='E39161',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=99,
        fiscal_year_end='12月末日',
        submitter_name='株式会社シンカ',
        submitter_name_en='Thinca Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャシンカ',
        address='千代田区神田錦町三丁目１７番地\u3000廣瀬ビル１０階',
        industry='情報・通信業',
        sec_code='149A0',
        corporate_number='5010001158006',
    ),
    'E39162': EdinetCodeEntry(
        edinet_code='E39162',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=381,
        fiscal_year_end='12月末日',
        submitter_name='株式会社雨風太陽',
        submitter_name_en='Ame Kaze Taiyo, Inc.',
        submitter_name_yomi='カブシキガイシャアメカゼタイヨウ',
        address='花巻市大通一丁目１番４３ー２花巻駅構内',
        industry='情報・通信業',
        sec_code='56160',
        corporate_number='7400001010018',
    ),
    'E39163': EdinetCodeEntry(
        edinet_code='E39163',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西辻\u3000一真',
        submitter_name_en=None,
        submitter_name_yomi='ニシツジ\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39164': EdinetCodeEntry(
        edinet_code='E39164',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1103,
        fiscal_year_end=None,
        submitter_name='三瑩電子工業\u3000株式會社',
        submitter_name_en=None,
        submitter_name_yomi='サミョンデンシコウギョウ\u3000カブシキガイシャ',
        address='４７\u3000Ｓａｇｉｍａｋｇｏｌ－ｒｏ\u3000Ｊｕｎｇｗｏｎ－ｇｕ\u3000Ｓｅｏｎｇｎａｍ－ｓｉ\u3000Ｇｙｅｏｎｇｇｉ－ｄｏ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39165': EdinetCodeEntry(
        edinet_code='E39165',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=183,
        fiscal_year_end='5月31日',
        submitter_name='株式会社早稲田学習研究会',
        submitter_name_en='WASEDA GAKUSHUKENKYUKAI CO.,LTD.',
        submitter_name_yomi='カブシキカイシャワセダガクシュウケンキュウカイ',
        address='中央区京橋一丁目１番１号八重洲ダイビル９階',
        industry='サービス業',
        sec_code='58690',
        corporate_number='8070001020347',
    ),
    'E39166': EdinetCodeEntry(
        edinet_code='E39166',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='豊島不動産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トシマフドウサンカブシキカイシャ',
        address='豊島区北大塚二丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7013301033735',
    ),
    'E39167': EdinetCodeEntry(
        edinet_code='E39167',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社スカイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスカイ',
        address='墨田区亀沢二丁目４番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010601063990',
    ),
    'E39168': EdinetCodeEntry(
        edinet_code='E39168',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前川\u3000賢治',
        submitter_name_en=None,
        submitter_name_yomi='マエカワ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39170': EdinetCodeEntry(
        edinet_code='E39170',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=322,
        fiscal_year_end='3月31日',
        submitter_name='ＳＢＩレオスひふみ株式会社',
        submitter_name_en='SBI RHEOS HIFUMI Inc.',
        submitter_name_yomi='エスビーアイレオスヒフミカブシキガイシャ',
        address='千代田区丸の内一丁目１１番１号',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='8010001243663',
    ),
    'E39171': EdinetCodeEntry(
        edinet_code='E39171',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='マーソ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マーソカブシキガイシャ',
        address='港区虎ノ門四丁目３番１号\u3000城山トラストタワー１７階',
        industry='情報・通信業',
        sec_code='56190',
        corporate_number='9010401116526',
    ),
    'E39174': EdinetCodeEntry(
        edinet_code='E39174',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＲＴＳ－１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アーツワンカブシキガイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401173716',
    ),
    'E39175': EdinetCodeEntry(
        edinet_code='E39175',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ナベショー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャナベショー',
        address='大阪市中央区南船場４－１２－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001086273',
    ),
    'E39176': EdinetCodeEntry(
        edinet_code='E39176',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39177': EdinetCodeEntry(
        edinet_code='E39177',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉原\u3000俊夫',
        submitter_name_en=None,
        submitter_name_yomi='ヨシハラ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39180': EdinetCodeEntry(
        edinet_code='E39180',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000智司',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000トモジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39181': EdinetCodeEntry(
        edinet_code='E39181',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社\u3000新居浜ビジネスセンター',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンカイシャ\u3000ニイハマビジネスセンター',
        address='新居浜市\u3000久保田町\u3000１－２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8500002017001',
    ),
    'E39182': EdinetCodeEntry(
        edinet_code='E39182',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｋ．Ｉ．Ｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキット',
        address='西宮市神楽町５番５号ラ・ベルジュ夙川２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140001132052',
    ),
    'E39183': EdinetCodeEntry(
        edinet_code='E39183',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ポイント機構',
        submitter_name_en='POINT Organization Ltd.',
        submitter_name_yomi='カブシキカイシャポイントキコウ',
        address='渋谷区千駄ケ谷２丁目７番９号\u3000ＨＯＵＳＥ２７１７\u3000３０１号室',
        industry='サービス業',
        sec_code=None,
        corporate_number='1010401164714',
    ),
    'E39184': EdinetCodeEntry(
        edinet_code='E39184',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1202,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＳＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイエスエイチ',
        address='中央区京橋一丁目１番５号セントラルビル',
        industry='サービス業',
        sec_code='150A0',
        corporate_number='9010001174841',
    ),
    'E39185': EdinetCodeEntry(
        edinet_code='E39185',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000強夫',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000タケオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39186': EdinetCodeEntry(
        edinet_code='E39186',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高橋\u3000飛翔',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ヒショウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39187': EdinetCodeEntry(
        edinet_code='E39187',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='鹿児島ディベロップメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カゴシマディベロップメントカブシキガイシャ',
        address='鹿児島市山之口町１番１０号\u3000鹿児島中央ビル９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9340001000832',
    ),
    'E39188': EdinetCodeEntry(
        edinet_code='E39188',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000宗',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ツカサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39191': EdinetCodeEntry(
        edinet_code='E39191',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=210,
        fiscal_year_end=None,
        submitter_name='ＭＣＰ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｃｏｍｐａｎｙ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エムシーピーアセットマネジメントカンパニーリミテッド',
        address='Ｕｎｉｔ\u3000１８０３，\u3000Ｌｅｅ\u3000Ｇａｒｄｅｎ\u3000Ｔｈｒｅｅ，\u3000１\u3000Ｓｕｎｎｉｎｇ\u3000Ｒｏａｄ，\u3000Ｃａｕｓｅｗａｙ\u3000Ｂａｙ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39193': EdinetCodeEntry(
        edinet_code='E39193',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新谷\u3000晃人',
        submitter_name_en=None,
        submitter_name_yomi='シンヤ\u3000アキト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39194': EdinetCodeEntry(
        edinet_code='E39194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=19,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ヒューマンテクノロジーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャヒューマンテクノロジーズ',
        address='港区元赤坂一丁目６番６号',
        industry='情報・通信業',
        sec_code='56210',
        corporate_number='9010001144019',
    ),
    'E39195': EdinetCodeEntry(
        edinet_code='E39195',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＢＫＰ\u3000Ｖｅｇａ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムビーケーピーベガカブシキガイシャ',
        address='千代田区永田町二丁目１０番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001239584',
    ),
    'E39199': EdinetCodeEntry(
        edinet_code='E39199',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社第一ソフト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイイチソフト',
        address='練馬区豊玉北６－５－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011601003803',
    ),
    'E39200': EdinetCodeEntry(
        edinet_code='E39200',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小松\u3000一成',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000カズナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39201': EdinetCodeEntry(
        edinet_code='E39201',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='金子インベスト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カネコインベストカブシキガイシャ',
        address='鯖江市丸山町二丁目３番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3210001017663',
    ),
    'E39203': EdinetCodeEntry(
        edinet_code='E39203',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=325,
        fiscal_year_end='12月末日',
        submitter_name='ナイル株式会社',
        submitter_name_en='Nyle Inc.',
        submitter_name_yomi='ナイルカブシキカイシャ',
        address='品川区東五反田一丁目２４番２号',
        industry='情報・通信業',
        sec_code='56180',
        corporate_number='9013301023560',
    ),
    'E39205': EdinetCodeEntry(
        edinet_code='E39205',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=595,
        fiscal_year_end=None,
        submitter_name='Ｇｒｅｅｎｏａｋｓ\u3000Ｃａｐｉｔａｌ\u3000Ｐａｒｔｎｅｒｓ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='グリーンノークスキャピタルパートナーズエルエルシー',
        address='アメリカ合衆国９４５６３カリフォルニア州オリンダ、スイート２００シー、オリンダウェイ４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39207': EdinetCodeEntry(
        edinet_code='E39207',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='大手門株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オオテモンカブシキガイシャ',
        address='千代田区大手町一丁目５番１号\u3000大手町ファーストスクエアイーストタワー４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001237861',
    ),
    'E39208': EdinetCodeEntry(
        edinet_code='E39208',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='岡崎キャピタルＧＰ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='オカザキキャピタルジーピーゴウドウガイシャ',
        address='岡崎市菅生町元菅４１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180303004718',
    ),
    'E39209': EdinetCodeEntry(
        edinet_code='E39209',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='指田\u3000仁',
        submitter_name_en=None,
        submitter_name_yomi='サシダ\u3000ジン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39212': EdinetCodeEntry(
        edinet_code='E39212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新谷\u3000哲',
        submitter_name_en=None,
        submitter_name_yomi='シンタニ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39214': EdinetCodeEntry(
        edinet_code='E39214',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社東広',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトウコウ',
        address='渋谷区大山町２４番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001041838',
    ),
    'E39216': EdinetCodeEntry(
        edinet_code='E39216',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社カクカ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカクカ',
        address='渋谷区大山町２４番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001041562',
    ),
    'E39217': EdinetCodeEntry(
        edinet_code='E39217',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='Ｖａｎｔｅｒ\u3000Ｃｒｕｉｓｅ\u3000Ｈｅａｌｔｈ\u3000Ｓｅｒｖｉｃｅｓ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='バンータークルーズヘルスサービシーズインク',
        address='１ｓｔ\u3000Ｆｌｏｏｒ，\u3000Ｋｉｎｇｓ\u3000Ｃｏｕｒｔ，\u3000Ｂａｙ\u3000Ｓｔｒｅｅｔ，\u3000Ｐ．Ｏ．\u3000Ｂｏｘ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39218': EdinetCodeEntry(
        edinet_code='E39218',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=218740,
        fiscal_year_end='12月31日',
        submitter_name='フォルヴィア・エス・イー',
        submitter_name_en=None,
        submitter_name_yomi='フォルヴィアエスイー',
        address='フランス、ナンテール、９２０００、シャン・ピエルー通り２３－２７番地',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E39219': EdinetCodeEntry(
        edinet_code='E39219',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三輪\u3000信雄',
        submitter_name_en=None,
        submitter_name_yomi='ミワ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39221': EdinetCodeEntry(
        edinet_code='E39221',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＢＣＪ－７５',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャビーシージェイセブンティーファイブ',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003041689',
    ),
    'E39222': EdinetCodeEntry(
        edinet_code='E39222',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=198,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ｙｕｔｏｒｉ',
        submitter_name_en='yutori, Inc.',
        submitter_name_yomi='カブシキガイシャユトリ',
        address='世田谷区北沢２－５－２',
        industry='小売業',
        sec_code='58920',
        corporate_number='1020003014176',
    ),
    'E39223': EdinetCodeEntry(
        edinet_code='E39223',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人ＡＳＪ財団',
        submitter_name_en=None,
        submitter_name_yomi='エーエスジェイザイダン',
        address='川口市栄町三丁目２番１６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2030005020708',
    ),
    'E39230': EdinetCodeEntry(
        edinet_code='E39230',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西野\u3000恒五郎',
        submitter_name_en=None,
        submitter_name_yomi='ニシノ\u3000ツネゴロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39231': EdinetCodeEntry(
        edinet_code='E39231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神田\u3000有宏',
        submitter_name_en=None,
        submitter_name_yomi='カンダ\u3000アリヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39232': EdinetCodeEntry(
        edinet_code='E39232',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='三和システム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンワシステムカブシキガイシャ',
        address='ひたちなか市松戸町二丁目９番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6050001006779',
    ),
    'E39233': EdinetCodeEntry(
        edinet_code='E39233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='酒井\u3000憲一',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39234': EdinetCodeEntry(
        edinet_code='E39234',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='カメリア・ファンド・ワン・ケイマン・ジーピー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='カメリアファンドワンケイマンジーピーリミテッド',
        address='英領ケイマン諸島、ＫＹ１―９００８、グランド・ケイマン、ジョージ・タウン、エルジン・アベニュー１９０、ウォーカーズ・コーポレート・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39235': EdinetCodeEntry(
        edinet_code='E39235',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='ケラスス・ファンド・ワン・ケイマン・ジーピー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ケラススファンドワンケイマンジーピーリミテッド',
        address='英領ケイマン諸島、ＫＹ１―９００８、グランド・ケイマン、ジョージ・タウン、エルジン・アベニュー１９０、ウォーカーズ・コーポレート・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39236': EdinetCodeEntry(
        edinet_code='E39236',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='エヌアイシー・ファンド・ワン・ジャパン・ジーピー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エヌアイシーファンドワンジャパンジーピーリミテッド',
        address='英領ケイマン諸島、ＫＹ１―９００８、グランド・ケイマン、ジョージ・タウン、エルジン・アベニュー１９０、ウォーカーズ・コーポレート・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39237': EdinetCodeEntry(
        edinet_code='E39237',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ダルトン\u3000インベストメンツ\u3000インク',
        submitter_name_en=None,
        submitter_name_yomi='ダルトン\u3000インベストメンツ\u3000インク',
        address='米国ネヴァダ州\u3000８９１１７\u3000ラスベガス市\u3000ウエストサハラアベニュー９４４０\u3000スイート２１５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39238': EdinetCodeEntry(
        edinet_code='E39238',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下茂\u3000奉文',
        submitter_name_en=None,
        submitter_name_yomi='シモシゲ\u3000トモフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39239': EdinetCodeEntry(
        edinet_code='E39239',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下茂\u3000和子',
        submitter_name_en=None,
        submitter_name_yomi='シモシゲ\u3000カズコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39242': EdinetCodeEntry(
        edinet_code='E39242',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='日本ライフケアサイエンス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンライフケアサイエンスカブシキガイシャ',
        address='鹿児島市西千石町１１番２１号鹿児島ＭＳビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6340001025898',
    ),
    'E39245': EdinetCodeEntry(
        edinet_code='E39245',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000俊輔',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000シュンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39246': EdinetCodeEntry(
        edinet_code='E39246',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='市來\u3000敏光',
        submitter_name_en=None,
        submitter_name_yomi='イチキ\u3000トシミツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39247': EdinetCodeEntry(
        edinet_code='E39247',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='八坂\u3000哲雄',
        submitter_name_en=None,
        submitter_name_yomi='ヤサカ\u3000テツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39248': EdinetCodeEntry(
        edinet_code='E39248',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ケイ・ワイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイワイ',
        address='川崎市麻生区栗木台４ー１０ー１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1020001079989',
    ),
    'E39250': EdinetCodeEntry(
        edinet_code='E39250',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='徐\u3000志敏',
        submitter_name_en=None,
        submitter_name_yomi='ジョ\u3000シビン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39251': EdinetCodeEntry(
        edinet_code='E39251',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社イッシン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイッシン',
        address='高槻市美しが丘一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120901040638',
    ),
    'E39253': EdinetCodeEntry(
        edinet_code='E39253',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＲＲ・ＤＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアールアールディーディー',
        address='中央区日本橋兜町５－１兜町第１平和ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101061259',
    ),
    'E39254': EdinetCodeEntry(
        edinet_code='E39254',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=15000,
        fiscal_year_end='3月31日',
        submitter_name='リョーサン菱洋ホールディングス株式会社',
        submitter_name_en='Ryoyo Ryosan Holdings, Inc.',
        submitter_name_yomi='リョーサンリョーヨーホールディンクスカブシキガイシャ',
        address='千代田区東神田二丁目３番５号',
        industry='卸売業',
        sec_code='167A0',
        corporate_number='8010001243688',
    ),
    'E39257': EdinetCodeEntry(
        edinet_code='E39257',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＡＷＡＴＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカワタ',
        address='西白河郡矢吹町赤沢６６５番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9380001027921',
    ),
    'E39258': EdinetCodeEntry(
        edinet_code='E39258',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内木場\u3000隼',
        submitter_name_en=None,
        submitter_name_yomi='ウチキバ\u3000ハヤト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39259': EdinetCodeEntry(
        edinet_code='E39259',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=3000,
        fiscal_year_end='9月30日',
        submitter_name='株式会社タスキホールディングス',
        submitter_name_en='TASUKI Holdings Inc.',
        submitter_name_yomi='カブシキガイシャタスキホールディングス',
        address='港区北青山二丁目７番９号',
        industry='不動産業',
        sec_code='166A0',
        corporate_number='8010401181579',
    ),
    'E39260': EdinetCodeEntry(
        edinet_code='E39260',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河田\u3000憲二',
        submitter_name_en=None,
        submitter_name_yomi='カワタ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39261': EdinetCodeEntry(
        edinet_code='E39261',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='リアルテックホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リアルテックホールディングスカブシキガイシャ',
        address='墨田区横川１－１６－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010601062241',
    ),
    'E39263': EdinetCodeEntry(
        edinet_code='E39263',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮部\u3000賢一',
        submitter_name_en=None,
        submitter_name_yomi='ミヤベ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39266': EdinetCodeEntry(
        edinet_code='E39266',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000敏夫',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トシオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39267': EdinetCodeEntry(
        edinet_code='E39267',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ベインキャピタル・ジェイエムエム・ジェネラル・パートナー・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ベインキャピタルジェイエムエムジェネラルパートナーエルエルシー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、アグランドハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39268': EdinetCodeEntry(
        edinet_code='E39268',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=77,
        fiscal_year_end='12月31日',
        submitter_name='株式会社Ｖｅｒｉｔａｓ\u3000Ｉｎ\u3000Ｓｉｌｉｃｏ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ウェリタス\u3000イン\u3000シリコ',
        address='品川区西五反田一丁目１１番１号',
        industry='医薬品',
        sec_code='130A0',
        corporate_number='4011001113744',
    ),
    'E39269': EdinetCodeEntry(
        edinet_code='E39269',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊田\u3000貴之',
        submitter_name_en=None,
        submitter_name_yomi='クマダ\u3000タカユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39273': EdinetCodeEntry(
        edinet_code='E39273',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=459,
        fiscal_year_end='1月末日',
        submitter_name='株式会社イタミアート',
        submitter_name_en='itamiarts inc.',
        submitter_name_yomi='カブシキガイシャイタミアート',
        address='岡山市南区新保６６０－１５',
        industry='その他製品',
        sec_code='168A0',
        corporate_number='2260001008618',
    ),
    'E39274': EdinetCodeEntry(
        edinet_code='E39274',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1550,
        fiscal_year_end=None,
        submitter_name='Ｍｏｂｉｌｉｔｙ＆Ｍａｉｎｔｅｎａｎｃｅ\u3000Ｊａｐａｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モビリティアンドメンテナンス\u3000ジャパンカブシキカイシャ',
        address='港区北青山２－５－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401176393',
    ),
    'E39278': EdinetCodeEntry(
        edinet_code='E39278',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社エスポワール日本橋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエスポワールニホンバシ',
        address='大阪市中央区本町橋８－６さくら本町橋ビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001235259',
    ),
    'E39282': EdinetCodeEntry(
        edinet_code='E39282',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=61,
        fiscal_year_end=None,
        submitter_name='株式会社Ｄａｉｋｏ\u3000Ｃｏｍｍｕｎｉｃａｔｉｏｎｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダイコウコミュニケーションズ',
        address='板橋区三園二丁目４番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011401013035',
    ),
    'E39283': EdinetCodeEntry(
        edinet_code='E39283',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=16300,
        fiscal_year_end='3月31日',
        submitter_name='ＪＳＲ株式会社',
        submitter_name_en='JSR Corporation',
        submitter_name_yomi='ジェイエスアールカブシキガイシャ',
        address='港区東新橋一丁目９番２号',
        industry='化学',
        sec_code=None,
        corporate_number='1010401175166',
    ),
    'E39284': EdinetCodeEntry(
        edinet_code='E39284',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=67,
        fiscal_year_end=None,
        submitter_name='ワンビ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワンビカブシキガイシャ',
        address='新宿区新宿四丁目３番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001050745',
    ),
    'E39288': EdinetCodeEntry(
        edinet_code='E39288',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＢＲＩＡＲＷＯＯＤ\u3000ＣＡＰＩＴＡＬ\u3000ＰＡＲＴＮＥＲＳ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='ブライヤーウッド\u3000キャピタル\u3000パートナーズ\u3000エルピー',
        address='８５０\u3000Ｎｅｗ\u3000Ｂｕｒｔｏｎ\u3000Ｒｄ．\u3000Ｓｕｉｔｅ\u3000２０１，\u3000Ｄｏｖｅｒ，\u3000ＤＥ，１９９０４，\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39289': EdinetCodeEntry(
        edinet_code='E39289',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野崎\u3000浩司',
        submitter_name_en=None,
        submitter_name_yomi='ノザキ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39293': EdinetCodeEntry(
        edinet_code='E39293',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000崇',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39296': EdinetCodeEntry(
        edinet_code='E39296',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000涼一',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000リョウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39298': EdinetCodeEntry(
        edinet_code='E39298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤英樹',
        submitter_name_en=None,
        submitter_name_yomi='サイトウヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39300': EdinetCodeEntry(
        edinet_code='E39300',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='恵志\u3000章夫',
        submitter_name_en=None,
        submitter_name_yomi='エシ\u3000アキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39301': EdinetCodeEntry(
        edinet_code='E39301',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高畠\u3000義紀',
        submitter_name_en=None,
        submitter_name_yomi='タカバタケ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39303': EdinetCodeEntry(
        edinet_code='E39303',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エルエイチピー・ホールディングス・ジーピー・エルティーディー',
        submitter_name_en=None,
        submitter_name_yomi='エルエイチピーホールディングスジーピーエルティーディー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ユーグランドハウス、私書箱３０９、メープルズ・コーポレート・サービシズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39304': EdinetCodeEntry(
        edinet_code='E39304',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大塚\u3000泰造',
        submitter_name_en=None,
        submitter_name_yomi='オオツカ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39305': EdinetCodeEntry(
        edinet_code='E39305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙橋\u3000博之',
        submitter_name_en=None,
        submitter_name_yomi='タカハシ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39306': EdinetCodeEntry(
        edinet_code='E39306',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000貴',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39307': EdinetCodeEntry(
        edinet_code='E39307',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='板井\u3000清司',
        submitter_name_en=None,
        submitter_name_yomi='イタイ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39309': EdinetCodeEntry(
        edinet_code='E39309',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='小橋工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コバシコウギョウカブシキガイシャ',
        address='岡山市南区中畦６８４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6260001002526',
    ),
    'E39312': EdinetCodeEntry(
        edinet_code='E39312',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='株式会社カナモリコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカナモリコーポレーション',
        address='神戸市兵庫区荒田町４丁目８番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140001006941',
    ),
    'E39313': EdinetCodeEntry(
        edinet_code='E39313',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='國房\u3000啓一郎',
        submitter_name_en=None,
        submitter_name_yomi='クニフサ\u3000ケイイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39315': EdinetCodeEntry(
        edinet_code='E39315',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社須原屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャ\u3000スハラヤ',
        address='目黒区東山２－１４－２０－Ｃ１０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401125924',
    ),
    'E39317': EdinetCodeEntry(
        edinet_code='E39317',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='須原\u3000伸太郎',
        submitter_name_en=None,
        submitter_name_yomi='スハラ\u3000シンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39318': EdinetCodeEntry(
        edinet_code='E39318',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='筑地\u3000宏次',
        submitter_name_en=None,
        submitter_name_yomi='ツキジ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39325': EdinetCodeEntry(
        edinet_code='E39325',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社Ｓｈｅｌｔｅｒ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシェルター',
        address='豊島区南池袋一丁目１９番４号幸伸ビル４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011601020802',
    ),
    'E39326': EdinetCodeEntry(
        edinet_code='E39326',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｉｐ\u3000Ｋａｍ\u3000Ｈｏｉ',
        submitter_name_en=None,
        submitter_name_yomi='イップ\u3000カムホイ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39327': EdinetCodeEntry(
        edinet_code='E39327',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７４',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイセブンティーフォー',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001236200',
    ),
    'E39329': EdinetCodeEntry(
        edinet_code='E39329',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口\u3000聡',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39331': EdinetCodeEntry(
        edinet_code='E39331',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古河\u3000未由紀',
        submitter_name_en=None,
        submitter_name_yomi='フルカワ\u3000ミユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39333': EdinetCodeEntry(
        edinet_code='E39333',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='合同会社ドゥーイング',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャドゥーイング',
        address='横浜市港北区日吉本町三丁目３６番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020003023059',
    ),
    'E39334': EdinetCodeEntry(
        edinet_code='E39334',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤田\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39335': EdinetCodeEntry(
        edinet_code='E39335',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤田\u3000さくら',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000サクラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39336': EdinetCodeEntry(
        edinet_code='E39336',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤田\u3000昂太朗',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39337': EdinetCodeEntry(
        edinet_code='E39337',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｉｎｆｉｎｉｔｙｂｒａｎｄｃａｐｉｔａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャインフィニティブランドキャピタル',
        address='港区赤坂９－７－２\u3000ミッドタウン・イースト４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401177879',
    ),
    'E39338': EdinetCodeEntry(
        edinet_code='E39338',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='篠原\u3000敬一',
        submitter_name_en=None,
        submitter_name_yomi='シノハラ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39339': EdinetCodeEntry(
        edinet_code='E39339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浅井\u3000啓行',
        submitter_name_en=None,
        submitter_name_yomi='アサイ\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39340': EdinetCodeEntry(
        edinet_code='E39340',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浅井\u3000伸之輔',
        submitter_name_en=None,
        submitter_name_yomi='アサイ\u3000シンノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39342': EdinetCodeEntry(
        edinet_code='E39342',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社大石キャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオイシキャピタル',
        address='港区元麻布一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401162887',
    ),
    'E39343': EdinetCodeEntry(
        edinet_code='E39343',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｙｕ\u3000Ｃｈｅ\u3000Ｗａｈ',
        submitter_name_en=None,
        submitter_name_yomi='ヨ\u3000チェワウ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39344': EdinetCodeEntry(
        edinet_code='E39344',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=650,
        fiscal_year_end=None,
        submitter_name='Ｊ＆Ｔ環境株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイアンドティーカンキョウカブシキガイシャ',
        address='横浜市鶴見区弁天町３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8020001016738',
    ),
    'E39345': EdinetCodeEntry(
        edinet_code='E39345',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000宣也',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ノブヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39346': EdinetCodeEntry(
        edinet_code='E39346',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤英志',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39347': EdinetCodeEntry(
        edinet_code='E39347',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ベルインベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ベルインベストメンツカブシキガイシャ',
        address='中央区銀座１－１２－４\u3000エヌアンドイービルディング\u3000６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001237604',
    ),
    'E39349': EdinetCodeEntry(
        edinet_code='E39349',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=222,
        fiscal_year_end='5月31日',
        submitter_name='Ｃｏｃｏｌｉｖｅ株式会社',
        submitter_name_en='Cocolive, Inc.',
        submitter_name_yomi='ココリブカブシキガイシャ',
        address='千代田区神田神保町１ー２８ー１\u3000ｍｉｒｉｏ神保町\u3000７Ｆ',
        industry='情報・通信業',
        sec_code='137A0',
        corporate_number='4010401129383',
    ),
    'E39350': EdinetCodeEntry(
        edinet_code='E39350',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＵＣＣジャパン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユーシーシージャパンカブシキガイシャ',
        address='神戸市中央区多聞通五丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8120901010441',
    ),
    'E39354': EdinetCodeEntry(
        edinet_code='E39354',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有田\u3000泰志',
        submitter_name_en=None,
        submitter_name_yomi='アリタ\u3000タイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39367': EdinetCodeEntry(
        edinet_code='E39367',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=301,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ジンジブ',
        submitter_name_en='JINJIB Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャジンジブ',
        address='大阪市中央区南本町二丁目６番１２号',
        industry='サービス業',
        sec_code='142A0',
        corporate_number='8010401117310',
    ),
    'E39369': EdinetCodeEntry(
        edinet_code='E39369',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='片石\u3000貴展',
        submitter_name_en=None,
        submitter_name_yomi='カタイシ\u3000タカノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39373': EdinetCodeEntry(
        edinet_code='E39373',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＴＣＳホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テイシイエスホールディングスカブシキガイシャ',
        address='中央区日本橋本町四丁目８番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001234777',
    ),
    'E39375': EdinetCodeEntry(
        edinet_code='E39375',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三谷\u3000公男',
        submitter_name_en=None,
        submitter_name_yomi='ミタニ\u3000キミオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39376': EdinetCodeEntry(
        edinet_code='E39376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ミヤマ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミヤマ',
        address='上田市御嶽堂３２０番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3100001010935',
    ),
    'E39377': EdinetCodeEntry(
        edinet_code='E39377',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='11月30日',
        submitter_name='光フードサービス株式会社',
        submitter_name_en='Hikari Food Service Co., Ltd.',
        submitter_name_yomi='ヒカリフードサービスカブシキガイシャ',
        address='名古屋市中村区則武一丁目１０番６号\u3000ノリタケ第１ビル１０１',
        industry='小売業',
        sec_code='138A0',
        corporate_number='6180001072619',
    ),
    'E39378': EdinetCodeEntry(
        edinet_code='E39378',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大谷\u3000光徳',
        submitter_name_en=None,
        submitter_name_yomi='オオタニ\u3000ミツノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39379': EdinetCodeEntry(
        edinet_code='E39379',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島\u3000翔太',
        submitter_name_en=None,
        submitter_name_yomi='ナカシマ\u3000ショウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39382': EdinetCodeEntry(
        edinet_code='E39382',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=16,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ＶＲＡＩＮ\u3000Ｓｏｌｕｔｉｏｎ',
        submitter_name_en='VRAIN Solution, Inc.',
        submitter_name_yomi='カブシキガイシャヴレインソリューション',
        address='中央区晴海一丁目８番１０号',
        industry='情報・通信業',
        sec_code='135A0',
        corporate_number='3010001208381',
    ),
    'E39384': EdinetCodeEntry(
        edinet_code='E39384',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='マリンフード株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マリンフードカブシキガイシャ',
        address='豊中市豊南町東４丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120901025775',
    ),
    'E39385': EdinetCodeEntry(
        edinet_code='E39385',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='パーシング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パーシングカブシキカイシャ',
        address='港区高輪１ー６ー１０ー３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010801020054',
    ),
    'E39387': EdinetCodeEntry(
        edinet_code='E39387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神足\u3000尚孝',
        submitter_name_en=None,
        submitter_name_yomi='コウタリ\u3000ナオタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39388': EdinetCodeEntry(
        edinet_code='E39388',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ａｄｒｉａｎ\u3000Ｗｏｎｇ\u3000Ｊｕｎ\u3000Ｊｉｅ',
        submitter_name_en=None,
        submitter_name_yomi='エイドリアン\u3000ウォン\u3000ジュン\u3000ジエ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39389': EdinetCodeEntry(
        edinet_code='E39389',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北村\u3000勝博',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39390': EdinetCodeEntry(
        edinet_code='E39390',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＡアソシエイツジャパン１号',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティーエーアソシエイツジャパンイチゴウ',
        address='港区白金台三丁目１０番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401179719',
    ),
    'E39391': EdinetCodeEntry(
        edinet_code='E39391',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ブルーム１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブルームワンカブシキカイシャ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー３７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401176187',
    ),
    'E39392': EdinetCodeEntry(
        edinet_code='E39392',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='奈賀\u3000幾次郎',
        submitter_name_en=None,
        submitter_name_yomi='ナカ\u3000イクジロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39394': EdinetCodeEntry(
        edinet_code='E39394',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７８',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイセブンティーエイト',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001239026',
    ),
    'E39395': EdinetCodeEntry(
        edinet_code='E39395',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三條\u3000真弘',
        submitter_name_en=None,
        submitter_name_yomi='サンジョウ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39396': EdinetCodeEntry(
        edinet_code='E39396',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社綺麗創造ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキレイソウゾウホールディングス',
        address='江東区富岡二丁目１１番６号長谷萬ビル４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401134126',
    ),
    'E39397': EdinetCodeEntry(
        edinet_code='E39397',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=55,
        fiscal_year_end='12月末日',
        submitter_name='株式会社カウリス',
        submitter_name_en='Caulis Inc.',
        submitter_name_yomi='カブシキガイシャカウリス',
        address='千代田区大手町一丁目６番１号大手町ビル４階\u3000ＦＩＮＯＬＡＢ',
        industry='サービス業',
        sec_code='153A0',
        corporate_number='7011101075345',
    ),
    'E39398': EdinetCodeEntry(
        edinet_code='E39398',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人ＣＢＧＭこども財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンシービージーエムコドモザイダン',
        address='港区南青山二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010405020617',
    ),
    'E39401': EdinetCodeEntry(
        edinet_code='E39401',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩堀\u3000克英',
        submitter_name_en=None,
        submitter_name_yomi='イワホリ\u3000カツヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39402': EdinetCodeEntry(
        edinet_code='E39402',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＰＴＣＪ‐５ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピーティーシージェイファイブホールディングスカブシキカイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001241537',
    ),
    'E39403': EdinetCodeEntry(
        edinet_code='E39403',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福田\u3000裕子',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39405': EdinetCodeEntry(
        edinet_code='E39405',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=438,
        fiscal_year_end='12月31日',
        submitter_name='株式会社情報戦略テクノロジー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジョウホウセンリャクテクノロジー',
        address='渋谷区恵比寿四丁目２０番３号',
        industry='情報・通信業',
        sec_code='155A0',
        corporate_number='2011001059411',
    ),
    'E39406': EdinetCodeEntry(
        edinet_code='E39406',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=8,
        fiscal_year_end='3月31日',
        submitter_name='イシン株式会社',
        submitter_name_en='Ishin Co., Ltd.',
        submitter_name_yomi='イシンカブシキガイシャ',
        address='新宿区新宿六丁目２８番７号新宿イーストコート７階',
        industry='サービス業',
        sec_code='143A0',
        corporate_number='6011101062914',
    ),
    'E39407': EdinetCodeEntry(
        edinet_code='E39407',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='コロンビア・ワークス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コロンビアワークスカブシキガイシャ',
        address='渋谷区渋谷三丁目２８番１５号',
        industry='不動産業',
        sec_code='146A0',
        corporate_number='8011001094980',
    ),
    'E39408': EdinetCodeEntry(
        edinet_code='E39408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=34,
        fiscal_year_end='6月末日',
        submitter_name='グリーンモンスター株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グリーンモンスターカブシキガイシャ',
        address='渋谷区神南一丁目４番９号',
        industry='サービス業',
        sec_code='157A0',
        corporate_number='8011001096069',
    ),
    'E39409': EdinetCodeEntry(
        edinet_code='E39409',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=629,
        fiscal_year_end='12月末日',
        submitter_name='株式会社Ｌ\u3000ｉｓ\u3000Ｂ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエルイズビー',
        address='千代田区岩本町三丁目１１番１１号',
        industry='情報・通信業',
        sec_code='145A0',
        corporate_number='6010601042541',
    ),
    'E39410': EdinetCodeEntry(
        edinet_code='E39410',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=56,
        fiscal_year_end='12月末日',
        submitter_name='株式会社ハッチ・ワーク',
        submitter_name_en='HATCH WORK CO.,LTD.',
        submitter_name_yomi='カブシキガイシャハッチワーク',
        address='港区南青山二丁目２番８号ＤＦビル',
        industry='情報・通信業',
        sec_code='148A0',
        corporate_number='4010401098174',
    ),
    'E39411': EdinetCodeEntry(
        edinet_code='E39411',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＸＹＺ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エックスワイゼットカブシキガイシャ',
        address='港区六本木六丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401179936',
    ),
    'E39413': EdinetCodeEntry(
        edinet_code='E39413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新井\u3000亨',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39414': EdinetCodeEntry(
        edinet_code='E39414',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='明石\u3000智義',
        submitter_name_en=None,
        submitter_name_yomi='アカシ\u3000トモヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39418': EdinetCodeEntry(
        edinet_code='E39418',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊｕｍｐ\u3000Ｌｉｆｅ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャンプライフカブシキガイシャ',
        address='静岡市清水区由比北田１１４番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2080001026101',
    ),
    'E39420': EdinetCodeEntry(
        edinet_code='E39420',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000慎吾',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000シンゴ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39421': EdinetCodeEntry(
        edinet_code='E39421',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＳＨＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌエスエイチディ',
        address='渋谷区広尾二丁目３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010601064413',
    ),
    'E39422': EdinetCodeEntry(
        edinet_code='E39422',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='アールティーダブリュー・インベストメンツ・リミテッドパートナーシップ',
        submitter_name_en=None,
        submitter_name_yomi='アールティーダブリューインベストメンツリミテッドパートナーシップ',
        address='アメリカ合衆国、ニューヨーク州１００１４、ニューヨーク、４０・１０番街、７階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39423': EdinetCodeEntry(
        edinet_code='E39423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='島津\u3000敦好',
        submitter_name_en=None,
        submitter_name_yomi='シマヅ\u3000アツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39424': EdinetCodeEntry(
        edinet_code='E39424',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='リー・チャン・ユン・グループ・インターナショナル・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='リーチャンユングループインターナショナルピーティーイーリミテッド',
        address='シンガポール（０３８９８８）、テマセク・ブールバード８、サンテック・タワー・スリー\u3000＃３２－０４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39425': EdinetCodeEntry(
        edinet_code='E39425',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='弓削\u3000雅人',
        submitter_name_en=None,
        submitter_name_yomi='ユゲ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39426': EdinetCodeEntry(
        edinet_code='E39426',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=20725,
        fiscal_year_end='12月31日',
        submitter_name='サムティホールディングス株式会社',
        submitter_name_en='SAMTY HOLDINGS Co., Ltd.',
        submitter_name_yomi='サムティホールディングスカブシキガイシャ',
        address='大阪市淀川区西宮原一丁目８番３９号',
        industry='サービス業',
        sec_code=None,
        corporate_number='4120001265576',
    ),
    'E39427': EdinetCodeEntry(
        edinet_code='E39427',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29,
        fiscal_year_end=None,
        submitter_name='株式会社宮脇商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミヤワキショウジ',
        address='高松市朝日新町１６－１７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4470002002365',
    ),
    'E39429': EdinetCodeEntry(
        edinet_code='E39429',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='マルエヌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルエヌカブシキガイシャ',
        address='朝霞市栄町２丁目１番地４０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9030001045090',
    ),
    'E39430': EdinetCodeEntry(
        edinet_code='E39430',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社井上ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャイノウエホールディングス',
        address='新宿区若宮町２５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101096643',
    ),
    'E39432': EdinetCodeEntry(
        edinet_code='E39432',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=144,
        fiscal_year_end=None,
        submitter_name='株式会社文藝春秋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブンゲイシュンジュウ',
        address='千代田区紀尾井町３番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001027998',
    ),
    'E39433': EdinetCodeEntry(
        edinet_code='E39433',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000浩喜',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000コウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39434': EdinetCodeEntry(
        edinet_code='E39434',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='嶋尻\u3000行雅',
        submitter_name_en=None,
        submitter_name_yomi='シマジリ\u3000ユキマサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39435': EdinetCodeEntry(
        edinet_code='E39435',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森藤\u3000恵二',
        submitter_name_en=None,
        submitter_name_yomi='モリトウ\u3000ケイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39436': EdinetCodeEntry(
        edinet_code='E39436',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000利明',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39437': EdinetCodeEntry(
        edinet_code='E39437',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='富田\u3000祐司',
        submitter_name_en=None,
        submitter_name_yomi='トミタ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39438': EdinetCodeEntry(
        edinet_code='E39438',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000考伸',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000タカノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39445': EdinetCodeEntry(
        edinet_code='E39445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南塲\u3000勇佑',
        submitter_name_en=None,
        submitter_name_yomi='ナンバ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39446': EdinetCodeEntry(
        edinet_code='E39446',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川口\u3000佑',
        submitter_name_en=None,
        submitter_name_yomi='カワグチ\u3000ユウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39447': EdinetCodeEntry(
        edinet_code='E39447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社日本投資ファンド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャニホントウシファンド',
        address='千代田区丸の内１丁目８番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001189225',
    ),
    'E39448': EdinetCodeEntry(
        edinet_code='E39448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=593,
        fiscal_year_end='3月31日',
        submitter_name='株式会社アズパートナーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアズパートナーズ',
        address='千代田区神田駿河台２丁目２番地\u3000御茶ノ水杏雲ビル１１階',
        industry='サービス業',
        sec_code='160A0',
        corporate_number='3010001090458',
    ),
    'E39449': EdinetCodeEntry(
        edinet_code='E39449',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='12月31日',
        submitter_name='株式会社キッズスター',
        submitter_name_en='KIDS STAR Inc.',
        submitter_name_yomi='カブシキガイシャキッズスター',
        address='渋谷区神泉町９番５号',
        industry='情報・通信業',
        sec_code='248A0',
        corporate_number='6011001102514',
    ),
    'E39451': EdinetCodeEntry(
        edinet_code='E39451',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中内\u3000準',
        submitter_name_en=None,
        submitter_name_yomi='ナカウチ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39454': EdinetCodeEntry(
        edinet_code='E39454',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｋ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイ',
        address='北九州市小倉北区熊本三丁目２番１ー７０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7290801027652',
    ),
    'E39456': EdinetCodeEntry(
        edinet_code='E39456',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000将也',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ショウヤ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39457': EdinetCodeEntry(
        edinet_code='E39457',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社エス・ワイ・エス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスワイエス',
        address='台東区駒形二丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010501021542',
    ),
    'E39459': EdinetCodeEntry(
        edinet_code='E39459',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｈｏｎｙ\u3000Ｌｉｎｋ\u3000Ｃｏ－Ｉｎｖｅｓｔｍｅｎｔ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ホニー\u3000リンク\u3000コインベストメント\u3000エル\u3000ピー',
        address='英領ヴァージン諸島、トルトラ、ロードタウン、ピーオーボックス\u3000１７３、キングストン・チェンバーズ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39460': EdinetCodeEntry(
        edinet_code='E39460',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=36,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ハンモック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャハンモック',
        address='新宿区大久保一丁目３番２１号',
        industry='情報・通信業',
        sec_code='173A0',
        corporate_number='7013301029898',
    ),
    'E39462': EdinetCodeEntry(
        edinet_code='E39462',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－８０',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーシージェイエイティー',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001242018',
    ),
    'E39463': EdinetCodeEntry(
        edinet_code='E39463',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大須賀\u3000哲',
        submitter_name_en=None,
        submitter_name_yomi='オオスカ\u3000テツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39464': EdinetCodeEntry(
        edinet_code='E39464',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上村\u3000孝',
        submitter_name_en=None,
        submitter_name_yomi='カミムラ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39465': EdinetCodeEntry(
        edinet_code='E39465',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐野\u3000正憲',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39468': EdinetCodeEntry(
        edinet_code='E39468',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=472,
        fiscal_year_end=None,
        submitter_name='なかのアセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ナカノアセットマネジメントカブシキガイシャ',
        address='中央区日本橋兜町５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001238165',
    ),
    'E39470': EdinetCodeEntry(
        edinet_code='E39470',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3,
        fiscal_year_end='3月末日',
        submitter_name='株式会社テクノバンクサンケン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャテクノバンクサンケン',
        address='田川郡香春町大字香春字三角１０２１番３',
        industry='不動産業',
        sec_code=None,
        corporate_number='9290801016868',
    ),
    'E39472': EdinetCodeEntry(
        edinet_code='E39472',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='新生キャピタルパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンセイキャピタルパートナーズカブシキカイシャ',
        address='港区虎ノ門五丁目１３番１号虎ノ門４０МТビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001191299',
    ),
    'E39473': EdinetCodeEntry(
        edinet_code='E39473',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='8月31日',
        submitter_name='マテリアルグループ株式会社',
        submitter_name_en='Material Group inc.',
        submitter_name_yomi='マテリアルグループカブシキカイシャ',
        address='港区赤坂一丁目１２番３２号アーク森ビル３５階',
        industry='サービス業',
        sec_code='156A0',
        corporate_number='8010401113771',
    ),
    'E39474': EdinetCodeEntry(
        edinet_code='E39474',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='ＳＢＣメディカルグループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーシーメディカルグループカブシキカイシャ',
        address='横浜市戸塚区上倉田町９０８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2020001123317',
    ),
    'E39475': EdinetCodeEntry(
        edinet_code='E39475',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月末日',
        submitter_name='ルーマニア',
        submitter_name_en=None,
        submitter_name_yomi='ルーマニア',
        address='Ｍｉｎｉｓｔｒｙ\u3000ｏｆ\u3000Ｆｉｎａｎｃｅ，\u3000１６\u3000Ｌｉｂｅｒｔａｔｉｉ\u3000Ｂｏｕｌｅｖａｒｄ，\u3000Ｂｕｃｈａｒｅｓｔ\u3000５，\u3000Ｒｏｍａｎｉａ',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E39476': EdinetCodeEntry(
        edinet_code='E39476',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ダイブ',
        submitter_name_en='Dive inc.',
        submitter_name_yomi='カブシキガイシャダイブ',
        address='新宿区新宿２－８－１\u3000新宿セブンビル１０階',
        industry='サービス業',
        sec_code='151A0',
        corporate_number='6011101046603',
    ),
    'E39477': EdinetCodeEntry(
        edinet_code='E39477',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｔｉｎｇ\u3000Ｙａｎ\u3000Ｃｈｕｎ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ティン\u3000ヤン\u3000チュン\u3000リミテッド',
        address='ＦＬＡＴ／ＲＭ\u3000７０１－２\u3000０７／Ｆ\u3000Ｅｖｅｒｂｒｉｇｈｔ\u3000Ｃｅｎｔｒｅ，\u3000１０８\u3000Ｇｌｏｕｃｅｓｔｅｒ\u3000Ｒｏａｄ，\u3000Ｗａｎ\u3000Ｃｈａｉ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39478': EdinetCodeEntry(
        edinet_code='E39478',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=80,
        fiscal_year_end=None,
        submitter_name='株式会社リンクコーポレイトコミュニケーションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリンクコーポレイトコミュニケーションズ',
        address='中央区銀座四丁目１２番１５号歌舞伎座タワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001122841',
    ),
    'E39480': EdinetCodeEntry(
        edinet_code='E39480',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社エツミ光学',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエツミコウガク',
        address='鯖江市糺町２１－４－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3210001012706',
    ),
    'E39481': EdinetCodeEntry(
        edinet_code='E39481',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000俊介',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000シュンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39482': EdinetCodeEntry(
        edinet_code='E39482',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='櫻井\u3000透',
        submitter_name_en=None,
        submitter_name_yomi='サクライ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39483': EdinetCodeEntry(
        edinet_code='E39483',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ソラコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャソラコム',
        address='世田谷区玉川四丁目５番６号尾嶋ビル３階',
        industry='情報・通信業',
        sec_code='147A0',
        corporate_number='9011001102783',
    ),
    'E39484': EdinetCodeEntry(
        edinet_code='E39484',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三崎優太',
        submitter_name_en=None,
        submitter_name_yomi='ミサキユウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39485': EdinetCodeEntry(
        edinet_code='E39485',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高山\u3000泰三',
        submitter_name_en=None,
        submitter_name_yomi='タカヤマ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39487': EdinetCodeEntry(
        edinet_code='E39487',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=545,
        fiscal_year_end='3月31日',
        submitter_name='株式会社Ｗｉｌｌ\u3000Ｓｍａｒｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウィルスマート',
        address='江東区富岡２－１１－６\u3000ＨＡＳＥＭＡＮ\u3000ＢＬＤＧ５－１',
        industry='情報・通信業',
        sec_code='175A0',
        corporate_number='3010401103249',
    ),
    'E39488': EdinetCodeEntry(
        edinet_code='E39488',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='レジル株式会社',
        submitter_name_en='Rezil Inc.',
        submitter_name_yomi='レジルカブシキガイシャ',
        address='千代田区丸の内１－８－１丸の内トラストタワーＮ館１４階',
        industry='サービス業',
        sec_code=None,
        corporate_number='1122001007449',
    ),
    'E39489': EdinetCodeEntry(
        edinet_code='E39489',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀬之口\u3000和磨',
        submitter_name_en=None,
        submitter_name_yomi='セノクチ\u3000カズマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39490': EdinetCodeEntry(
        edinet_code='E39490',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=283,
        fiscal_year_end=None,
        submitter_name='Ａｔｈｏｓ\u3000Ｃａｐｉｔａｌ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='アトス\u3000キャピタル\u3000リミテッド',
        address='３１／Ｆ．，\u3000Ｔｏｗｅｒ\u3000Ｔｗｏ，\u3000Ｔｉｍｅｓ\u3000Ｓｑｕａｒｅ\u3000１\u3000Ｍａｔｈｅｓｏｎ\u3000Ｓｔｒｅｅｔ\u3000Ｃａｕｓｅｗａｙ\u3000Ｂａｙ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39491': EdinetCodeEntry(
        edinet_code='E39491',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒岩\u3000主信',
        submitter_name_en=None,
        submitter_name_yomi='クロイワ\u3000シゲノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39492': EdinetCodeEntry(
        edinet_code='E39492',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横野\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='ヨコノ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39501': EdinetCodeEntry(
        edinet_code='E39501',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤千寿夫',
        submitter_name_en=None,
        submitter_name_yomi='カトウチズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39502': EdinetCodeEntry(
        edinet_code='E39502',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='舩渡\u3000大地',
        submitter_name_en=None,
        submitter_name_yomi='フナト\u3000ダイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39503': EdinetCodeEntry(
        edinet_code='E39503',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉川\u3000憲',
        submitter_name_en=None,
        submitter_name_yomi='タマガワ\u3000ケン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39504': EdinetCodeEntry(
        edinet_code='E39504',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ライフイン２４ｇｒｏｕｐ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャライフインニジュウヨングループ',
        address='豊島区東池袋四丁目１４番２号ワークスタジオ０１ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013301047109',
    ),
    'E39505': EdinetCodeEntry(
        edinet_code='E39505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1010,
        fiscal_year_end='6月末日',
        submitter_name='株式会社構造計画研究所ホールディングス',
        submitter_name_en='KOZO KEIKAKU ENGINEERING HOLDINGS Inc.',
        submitter_name_yomi='カブシキガイシャコウゾウケイカクケンキュショホールディングス',
        address='中野区本町４ー３８－１３日本ホルスタイン会館内',
        industry='情報・通信業',
        sec_code='208A0',
        corporate_number='5011201025607',
    ),
    'E39506': EdinetCodeEntry(
        edinet_code='E39506',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='日本交通株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンコウツウカブシキガイシャ',
        address='千代田区紀尾井町３－１２\u3000紀尾井町ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011501015887',
    ),
    'E39508': EdinetCodeEntry(
        edinet_code='E39508',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保芦\u3000さち子',
        submitter_name_en=None,
        submitter_name_yomi='ホアシ\u3000サチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39509': EdinetCodeEntry(
        edinet_code='E39509',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保芦\u3000育子',
        submitter_name_en=None,
        submitter_name_yomi='ホアシ\u3000イクコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39510': EdinetCodeEntry(
        edinet_code='E39510',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三浦\u3000嚴嗣',
        submitter_name_en=None,
        submitter_name_yomi='ミウラ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39512': EdinetCodeEntry(
        edinet_code='E39512',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='株式会社ジャルコ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジャルコ',
        address='中央区日本橋二丁目１６番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001111395',
    ),
    'E39513': EdinetCodeEntry(
        edinet_code='E39513',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='保芦\u3000惠子',
        submitter_name_en=None,
        submitter_name_yomi='ホアシ\u3000ケイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39514': EdinetCodeEntry(
        edinet_code='E39514',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＡＲＳＵ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハース',
        address='北区赤羽１－５２－１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011501022115',
    ),
    'E39515': EdinetCodeEntry(
        edinet_code='E39515',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山中\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='ヤマナカ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39517': EdinetCodeEntry(
        edinet_code='E39517',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ブルーム２株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブルームツーカブシキカイシャ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー３７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401176188',
    ),
    'E39518': EdinetCodeEntry(
        edinet_code='E39518',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＰ６０',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーピーロクジュウ',
        address='港区虎ノ門４ー１－２８\u3000虎ノ門タワーズオフィス１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401138626',
    ),
    'E39519': EdinetCodeEntry(
        edinet_code='E39519',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000博一',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39520': EdinetCodeEntry(
        edinet_code='E39520',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中桐\u3000啓貴',
        submitter_name_en=None,
        submitter_name_yomi='ナカギリ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39522': EdinetCodeEntry(
        edinet_code='E39522',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若山\u3000大典',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39523': EdinetCodeEntry(
        edinet_code='E39523',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若山\u3000正美',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000マサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39524': EdinetCodeEntry(
        edinet_code='E39524',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='若山\u3000悠',
        submitter_name_en=None,
        submitter_name_yomi='ワカヤマ\u3000ユウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39526': EdinetCodeEntry(
        edinet_code='E39526',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高野\u3000紀子',
        submitter_name_en=None,
        submitter_name_yomi='タカノ\u3000ノリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39527': EdinetCodeEntry(
        edinet_code='E39527',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000靖朗',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39528': EdinetCodeEntry(
        edinet_code='E39528',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000統一',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ノリカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39529': EdinetCodeEntry(
        edinet_code='E39529',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩満\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='シオミツ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39533': EdinetCodeEntry(
        edinet_code='E39533',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='庄子\u3000潔',
        submitter_name_en=None,
        submitter_name_yomi='ショウジ\u3000キヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39534': EdinetCodeEntry(
        edinet_code='E39534',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='増田\u3000知平',
        submitter_name_en=None,
        submitter_name_yomi='マスダ\u3000トモヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39536': EdinetCodeEntry(
        edinet_code='E39536',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='サムライカーボンズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サムライカーボンズカブシキガイシャ',
        address='横浜市港北区新横浜二丁目１７番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001144898',
    ),
    'E39537': EdinetCodeEntry(
        edinet_code='E39537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='南\u3000志郎',
        submitter_name_en=None,
        submitter_name_yomi='ミナミ\u3000シロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39539': EdinetCodeEntry(
        edinet_code='E39539',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大竹\u3000弘',
        submitter_name_en=None,
        submitter_name_yomi='オオタケ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39540': EdinetCodeEntry(
        edinet_code='E39540',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村田\u3000美夏',
        submitter_name_en=None,
        submitter_name_yomi='ムラタ\u3000ミカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39541': EdinetCodeEntry(
        edinet_code='E39541',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='１０Ｘ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='テンエックス\u3000インベストメント\u3000エルティーディー',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39546': EdinetCodeEntry(
        edinet_code='E39546',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙井\u3000淳',
        submitter_name_en=None,
        submitter_name_yomi='タカイ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39547': EdinetCodeEntry(
        edinet_code='E39547',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000満秀',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000ミツヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39548': EdinetCodeEntry(
        edinet_code='E39548',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＢＣＰＥ\u3000Ｔａｎｋｅｒ\u3000ＧＰ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーピーイータンカージーピーエルエルシー',
        address='Ｓｕｉｔｅ\u3000３０２，\u3000４００１\u3000Ｋｅｎｎｅｔｔ\u3000Ｐｉｋｅ，\u3000Ｃｏｕｎｔｙ\u3000ｏｆ\u3000Ｎｅｗ\u3000Ｃａｓｔｌｅ，\u3000Ｗｉｌｍｉｎｇｔｏｎ，\u3000ＤＥ１９８０７\u3000ＵＳＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39549': EdinetCodeEntry(
        edinet_code='E39549',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ディライトワークス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディライトワークスカブシキガイシャ',
        address='港区六本木６－１０－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401109902',
    ),
    'E39550': EdinetCodeEntry(
        edinet_code='E39550',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000格彰',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ノリアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39551': EdinetCodeEntry(
        edinet_code='E39551',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='馬場沙紀',
        submitter_name_en=None,
        submitter_name_yomi='バンバサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39556': EdinetCodeEntry(
        edinet_code='E39556',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人紀文・保芦記念財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンキブンホアシキネンザイダン',
        address='港区海岸２－１－７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010405022005',
    ),
    'E39558': EdinetCodeEntry(
        edinet_code='E39558',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='猪野\u3000栄一',
        submitter_name_en=None,
        submitter_name_yomi='イノ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39560': EdinetCodeEntry(
        edinet_code='E39560',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='李顯駿',
        submitter_name_en=None,
        submitter_name_yomi='リーヒュンジュン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39561': EdinetCodeEntry(
        edinet_code='E39561',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=224,
        fiscal_year_end=None,
        submitter_name='ＤＳＮＴｅｃｈ．Ｉｎｋ',
        submitter_name_en=None,
        submitter_name_yomi='ディーエスエヌテックインク',
        address='韓国ソウル特別市江南区駅三路９道２８、４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39562': EdinetCodeEntry(
        edinet_code='E39562',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='植村\u3000健志',
        submitter_name_en=None,
        submitter_name_yomi='ウエムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39563': EdinetCodeEntry(
        edinet_code='E39563',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='共栄会\u3000理事長\u3000山俊彦',
        submitter_name_en=None,
        submitter_name_yomi='キョウエイカイリジチョウヤマトシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39565': EdinetCodeEntry(
        edinet_code='E39565',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='江尻\u3000高宏',
        submitter_name_en=None,
        submitter_name_yomi='エジリ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39566': EdinetCodeEntry(
        edinet_code='E39566',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮下修',
        submitter_name_en=None,
        submitter_name_yomi='ミヤシタオサム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39569': EdinetCodeEntry(
        edinet_code='E39569',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北川\u3000昌邦',
        submitter_name_en=None,
        submitter_name_yomi='キタガワ\u3000マサクニ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39570': EdinetCodeEntry(
        edinet_code='E39570',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='相良\u3000健志',
        submitter_name_en=None,
        submitter_name_yomi='サガラ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39575': EdinetCodeEntry(
        edinet_code='E39575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浅村\u3000裕二',
        submitter_name_en=None,
        submitter_name_yomi='アサムラ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39576': EdinetCodeEntry(
        edinet_code='E39576',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='クロダ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クロダカブシキガイシャ',
        address='士別市上士別町十六線北２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8450001012792',
    ),
    'E39577': EdinetCodeEntry(
        edinet_code='E39577',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='天塩倉庫株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テシオソウコカブシキガイシャ',
        address='士別市上士別町十六線北２番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8450001007941',
    ),
    'E39578': EdinetCodeEntry(
        edinet_code='E39578',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='三菱電機モビリティ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシデンキモビリティカブシキガイシャ',
        address='千代田区丸の内二丁目７－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001239816',
    ),
    'E39580': EdinetCodeEntry(
        edinet_code='E39580',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｗｅｌｌ\u3000Ｓｉｄｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウェルサイド',
        address='千葉市中央区祐光四丁目２５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001126852',
    ),
    'E39581': EdinetCodeEntry(
        edinet_code='E39581',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｂｌｕｅ\u3000ｌａｇｏｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャブルーラグーン',
        address='三浦市三崎町諸磯浜ノ原１８９５番地９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9021001075368',
    ),
    'E39582': EdinetCodeEntry(
        edinet_code='E39582',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃｈｕｒｃｈ\u3000＆\u3000Ｄｗｉｇｈｔ\u3000Ｊａｐａｎ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='チャーチアンドドワイトジャパンゴウドウガイシャ',
        address='千代田区霞が関三丁目２番６号東京倶楽部ビルディング１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003043211',
    ),
    'E39584': EdinetCodeEntry(
        edinet_code='E39584',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＥＮＥＯＳイノベーションパートナーズ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エネオスイノベーションパートナーズゴウドウカイシャ',
        address='千代田区大手町一丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010003030809',
    ),
    'E39585': EdinetCodeEntry(
        edinet_code='E39585',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='羽山\u3000尚',
        submitter_name_en=None,
        submitter_name_yomi='ハヤマ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39589': EdinetCodeEntry(
        edinet_code='E39589',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='進\u3000顕',
        submitter_name_en=None,
        submitter_name_yomi='シン\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39590': EdinetCodeEntry(
        edinet_code='E39590',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田邉\u3000勝宣',
        submitter_name_en=None,
        submitter_name_yomi='タナベ\u3000カツノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39591': EdinetCodeEntry(
        edinet_code='E39591',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='9月30日',
        submitter_name='合同会社田中企画',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャタナカキカク',
        address='熊本市南区上ノ郷２丁目３番３６号',
        industry='不動産業',
        sec_code=None,
        corporate_number='6330003008002',
    ),
    'E39592': EdinetCodeEntry(
        edinet_code='E39592',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=3576,
        fiscal_year_end='12月31日',
        submitter_name='肥銀ブリッジ投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='ヒギンブリッジトウシジギョウユウゲンセキニンクミアイ',
        address='熊本市中央区下通１丁目９番９号',
        industry='その他金融業',
        sec_code=None,
        corporate_number=None,
    ),
    'E39593': EdinetCodeEntry(
        edinet_code='E39593',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='カタリスト・インベストメント・グループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カタリストインベストメントグループカブシキガイシャ',
        address='千代田区永田町二丁目１１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401158322',
    ),
    'E39594': EdinetCodeEntry(
        edinet_code='E39594',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武田\u3000好修',
        submitter_name_en=None,
        submitter_name_yomi='タケダ\u3000ヨシノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39595': EdinetCodeEntry(
        edinet_code='E39595',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＫＭＫホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャケーエムケーホールディングス',
        address='港区南青山五丁目１４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001158710',
    ),
    'E39598': EdinetCodeEntry(
        edinet_code='E39598',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=650,
        fiscal_year_end=None,
        submitter_name='読売テレビ放送株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨミウリテレビホウソウカブシキガイシャ',
        address='大阪市中央区城見１－３－５０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001091917',
    ),
    'E39601': EdinetCodeEntry(
        edinet_code='E39601',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社プロシード',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプロシード',
        address='中野区中央５－３３－１２－５０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011201025260',
    ),
    'E39603': EdinetCodeEntry(
        edinet_code='E39603',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊丹\u3000一晃',
        submitter_name_en=None,
        submitter_name_yomi='イタミ\u3000カズアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39606': EdinetCodeEntry(
        edinet_code='E39606',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉村英毅',
        submitter_name_en=None,
        submitter_name_yomi='ヨシムラ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39607': EdinetCodeEntry(
        edinet_code='E39607',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川\u3000亮',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39608': EdinetCodeEntry(
        edinet_code='E39608',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ウィル\u3000マネジメント\u3000スリー\u3000エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ウィル\u3000マネジメント\u3000スリー\u3000エルエルシー',
        address='アメリカ合衆国\u3000１９８０１\u3000デラウェア州\u3000ウィルミントン\u3000オレンジ・ストリート１２０９\u3000コーポレーション・トラスト・カンパニー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39609': EdinetCodeEntry(
        edinet_code='E39609',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐野\u3000純也',
        submitter_name_en=None,
        submitter_name_yomi='サノ\u3000ジュンヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39610': EdinetCodeEntry(
        edinet_code='E39610',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＰＬＡＮＡ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプラナ',
        address='福岡市博多区博多駅前四丁目１７番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290001060557',
    ),
    'E39611': EdinetCodeEntry(
        edinet_code='E39611',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７７',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイセブンティーセブン',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001239025',
    ),
    'E39612': EdinetCodeEntry(
        edinet_code='E39612',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000健一',
        submitter_name_en=None,
        submitter_name_yomi='ハヤシ\u3000ケンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39614': EdinetCodeEntry(
        edinet_code='E39614',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松尾\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='マツオ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39615': EdinetCodeEntry(
        edinet_code='E39615',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高取\u3000美樹',
        submitter_name_en=None,
        submitter_name_yomi='タカトリ\u3000ミキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39617': EdinetCodeEntry(
        edinet_code='E39617',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂａｉｎ\u3000Ｃａｐｉｔａｌ\u3000Ａｓｉａ\u3000Ｖ\u3000Ｇｅｎｅｒａｌ\u3000Ｐａｒｔｎｅｒ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ベインキャピタルアジアファイブジェネラルパートナーエルエルシー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、アグランドハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39618': EdinetCodeEntry(
        edinet_code='E39618',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社宇佐美鉱油',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウサミコウユ',
        address='津島市埋田町一丁目８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001096360',
    ),
    'E39621': EdinetCodeEntry(
        edinet_code='E39621',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='エルアール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エルアールカブシキガイシャ',
        address='港区虎ノ門５－１２－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39623': EdinetCodeEntry(
        edinet_code='E39623',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='いなよしキャピタルパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イナヨシキャピタルパートナーズカブシキカイシャ',
        address='品川区東品川二丁目３番１２号シーフォートスクエアセンタービル９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001118646',
    ),
    'E39624': EdinetCodeEntry(
        edinet_code='E39624',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊田\u3000亜理沙',
        submitter_name_en=None,
        submitter_name_yomi='トヨタ\u3000アリサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39626': EdinetCodeEntry(
        edinet_code='E39626',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39628': EdinetCodeEntry(
        edinet_code='E39628',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000孝人',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000タカヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39629': EdinetCodeEntry(
        edinet_code='E39629',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='出口\u3000浩史',
        submitter_name_en=None,
        submitter_name_yomi='デグチ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39630': EdinetCodeEntry(
        edinet_code='E39630',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=35,
        fiscal_year_end=None,
        submitter_name='株式会社アガルート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアガルート',
        address='新宿区新小川町５番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011201017162',
    ),
    'E39631': EdinetCodeEntry(
        edinet_code='E39631',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='津村\u3000元英',
        submitter_name_en=None,
        submitter_name_yomi='ツムラ\u3000モトフサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39636': EdinetCodeEntry(
        edinet_code='E39636',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='籠谷\u3000智輝',
        submitter_name_en=None,
        submitter_name_yomi='カゴタニ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39637': EdinetCodeEntry(
        edinet_code='E39637',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌティー',
        address='白河市向新蔵１１１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101096431',
    ),
    'E39639': EdinetCodeEntry(
        edinet_code='E39639',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39640': EdinetCodeEntry(
        edinet_code='E39640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=107,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ＷＯＬＶＥＳ\u3000ＨＡＮＤ',
        submitter_name_en='WOLVES HAND Co., Ltd.',
        submitter_name_yomi='カブシキガイシャウルブズハンド',
        address='大阪市西区南堀江三丁目７番２２号',
        industry='サービス業',
        sec_code='194A0',
        corporate_number='7010001199948',
    ),
    'E39641': EdinetCodeEntry(
        edinet_code='E39641',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北井\u3000正志',
        submitter_name_en=None,
        submitter_name_yomi='キタイ\u3000タダシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39643': EdinetCodeEntry(
        edinet_code='E39643',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社北川本家',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャキタガワホンケ',
        address='京都市伏見区山崎町３６４番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8130001014193',
    ),
    'E39645': EdinetCodeEntry(
        edinet_code='E39645',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社タウンズ',
        submitter_name_en='TAUNS Laboratories, Inc.',
        submitter_name_yomi='カブシキガイシャタウンズ',
        address='伊豆の国市神島７６１番１',
        industry='医薬品',
        sec_code='197A0',
        corporate_number='4010001175101',
    ),
    'E39646': EdinetCodeEntry(
        edinet_code='E39646',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=471,
        fiscal_year_end='5月末日',
        submitter_name='株式会社Ｄ＆Ｍカンパニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャディーアンドエムカンパニー',
        address='大阪市北区梅田二丁目５番２５号',
        industry='その他金融業',
        sec_code='189A0',
        corporate_number='2120001194249',
    ),
    'E39647': EdinetCodeEntry(
        edinet_code='E39647',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=480,
        fiscal_year_end=None,
        submitter_name='株式会社サウンドハウス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサウンドハウス',
        address='成田市新泉１４－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040001046181',
    ),
    'E39648': EdinetCodeEntry(
        edinet_code='E39648',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金\u3000淙採',
        submitter_name_en=None,
        submitter_name_yomi='キム\u3000ジョンチエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39650': EdinetCodeEntry(
        edinet_code='E39650',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='廣政\u3000愁一',
        submitter_name_en=None,
        submitter_name_yomi='ヒロマサ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39653': EdinetCodeEntry(
        edinet_code='E39653',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=120,
        fiscal_year_end='4月30日',
        submitter_name='株式会社学びエイド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマナビエイド',
        address='東京都文京区本郷６丁目１７番９号',
        industry='情報・通信業',
        sec_code='184A0',
        corporate_number='4010001167800',
    ),
    'E39655': EdinetCodeEntry(
        edinet_code='E39655',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='マルシアンホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='マルシアンホールディングスゴウドウガイシャ',
        address='港区虎ノ門二丁目６番１号虎ノ門ヒルズステーションタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010403031970',
    ),
    'E39657': EdinetCodeEntry(
        edinet_code='E39657',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='アスミホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アスミホールディングスカブシキカイシャ',
        address='神戸市須磨区天神町４丁目４ー３５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140001128258',
    ),
    'E39659': EdinetCodeEntry(
        edinet_code='E39659',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000誠司',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39660': EdinetCodeEntry(
        edinet_code='E39660',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000敏行',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39661': EdinetCodeEntry(
        edinet_code='E39661',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=601,
        fiscal_year_end='4月30日',
        submitter_name='株式会社アストロスケールホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='ガブシキカイシャアストロスケールホールディングス',
        address='墨田区錦糸四丁目１７番１号',
        industry='サービス業',
        sec_code='186A0',
        corporate_number='6010603007550',
    ),
    'E39662': EdinetCodeEntry(
        edinet_code='E39662',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=249,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＭＵＳＣＡＴ\u3000ＧＲＯＵＰ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマスカットグループ',
        address='渋谷区道玄坂一丁目１２番１号渋谷マークシティウエスト２０階',
        industry='サービス業',
        sec_code='195A0',
        corporate_number='2011101076579',
    ),
    'E39664': EdinetCodeEntry(
        edinet_code='E39664',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='Ｔｅａｍ\u3000Ｅｎｅｒｇｙ\u3000ＧＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チームエナジージーアイカブシキガイシャ',
        address='大阪市中央区北浜二丁目６番１８号１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120001234325',
    ),
    'E39665': EdinetCodeEntry(
        edinet_code='E39665',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=133,
        fiscal_year_end=None,
        submitter_name='ゼナーアセットマネジメントエルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='ゼナーアセットマネジメントエルエルピー',
        address='英国、ロンドン、ＳＷ３\u3000４ＬＹ、８６デューク・オブ・ヨーク・スクエア',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39666': EdinetCodeEntry(
        edinet_code='E39666',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金子\u3000将幸',
        submitter_name_en=None,
        submitter_name_yomi='カネコ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39668': EdinetCodeEntry(
        edinet_code='E39668',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='6月末日',
        submitter_name='株式会社ＭＦＳ',
        submitter_name_en='MFS, Inc.',
        submitter_name_yomi='カブシキガイシャエムエフエス',
        address='東京都千代田区大手町一丁目６番１号',
        industry='その他金融業',
        sec_code='196A0',
        corporate_number='5010401082796',
    ),
    'E39669': EdinetCodeEntry(
        edinet_code='E39669',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2041,
        fiscal_year_end=None,
        submitter_name='ＵＢＳファンド・マネジメント（アイルランド）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスファンドマネジメントアイルランドリミテッド',
        address='アイルランド、ダブリン２、サウス・フレデリック通り、カレッジ・パーク・ハウス１階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39670': EdinetCodeEntry(
        edinet_code='E39670',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000康弘',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39671': EdinetCodeEntry(
        edinet_code='E39671',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=39,
        fiscal_year_end='5月末日',
        submitter_name='株式会社ロゴスホールディングス',
        submitter_name_en='LOGOS HOLDINGS INC.',
        submitter_name_yomi='カブシキガイシャロゴスホールディングス',
        address='帯広市東３条南１３丁目２番地１',
        industry='建設業',
        sec_code='205A0',
        corporate_number='4430001081892',
    ),
    'E39672': EdinetCodeEntry(
        edinet_code='E39672',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='間野\u3000賢治',
        submitter_name_en=None,
        submitter_name_yomi='マノ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39673': EdinetCodeEntry(
        edinet_code='E39673',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='星山\u3000和彦',
        submitter_name_en=None,
        submitter_name_yomi='ホシヤマ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39674': EdinetCodeEntry(
        edinet_code='E39674',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡辺\u3000敏行',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000トシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39675': EdinetCodeEntry(
        edinet_code='E39675',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社可成屋',
        submitter_name_en='Kanariya Co., Ltd.',
        submitter_name_yomi='カブシキカイシャカナリヤ',
        address='中央区月島三丁目２６番１１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5012401041765',
    ),
    'E39676': EdinetCodeEntry(
        edinet_code='E39676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔ．ＭＡＫＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーメイク',
        address='大阪市西区阿波座２－３ー２３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001239973',
    ),
    'E39677': EdinetCodeEntry(
        edinet_code='E39677',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＥＴＳグループ',
        submitter_name_en='ETS Group Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャイーティーエスグループ',
        address='豊島区南池袋１－１０－１３',
        industry='建設業',
        sec_code='253A0',
        corporate_number='4013301053182',
    ),
    'E39685': EdinetCodeEntry(
        edinet_code='E39685',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='グロースパートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グロースパートナーズカブシキカイシャ',
        address='目黒区自由が丘２－１６－１２ＲＪ３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001148909',
    ),
    'E39687': EdinetCodeEntry(
        edinet_code='E39687',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＡＦホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイエイエフホールディングスカブシキガイシャ',
        address='千代田区大手町一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001243691',
    ),
    'E39691': EdinetCodeEntry(
        edinet_code='E39691',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=130,
        fiscal_year_end='3月31日',
        submitter_name='株式会社豆蔵',
        submitter_name_en='MAMEZO CO.,LTD.',
        submitter_name_yomi='カブシキガイシャマメゾウ',
        address='新宿区西新宿二丁目１番１号',
        industry='情報・通信業',
        sec_code='202A0',
        corporate_number='6011101093174',
    ),
    'E39692': EdinetCodeEntry(
        edinet_code='E39692',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社クリスピー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャクリスピー',
        address='千代田区丸の内一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001244022',
    ),
    'E39693': EdinetCodeEntry(
        edinet_code='E39693',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=86,
        fiscal_year_end=None,
        submitter_name='アセンダー・キャピタル・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='アセンダー\u3000キャピタル\u3000リミテッド',
        address='香港、黄竹坑道５０、３００１、Ｗ５０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39694': EdinetCodeEntry(
        edinet_code='E39694',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ビー・エックス・ジェイ・ビー・ツー・ホールディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエックスジェイビーツーホールディングカブシキカイシャ',
        address='港区虎ノ門五丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401182081',
    ),
    'E39695': EdinetCodeEntry(
        edinet_code='E39695',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社ハルク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハルク',
        address='高岡市福岡町赤丸６５７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001154563',
    ),
    'E39696': EdinetCodeEntry(
        edinet_code='E39696',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社みみっく',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミミック',
        address='川辺郡猪名川町白金三丁目１１番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140001109835',
    ),
    'E39704': EdinetCodeEntry(
        edinet_code='E39704',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='麻布台１号有限責任事業組合',
        submitter_name_en=None,
        submitter_name_yomi='アザブダイイチゴウユウゲンセキニンジギョウクミアイ',
        address='港区赤坂四丁目５番２１号バルミー赤坂３１７号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39707': EdinetCodeEntry(
        edinet_code='E39707',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='駒田\u3000一央',
        submitter_name_en=None,
        submitter_name_yomi='コマダ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39708': EdinetCodeEntry(
        edinet_code='E39708',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=21,
        fiscal_year_end='5月31日',
        submitter_name='ＰｏｓｔＰｒｉｍｅ株式会社',
        submitter_name_en='PostPrime Inc.',
        submitter_name_yomi='ポストプライムカブシキカイシャ',
        address='港区虎ノ門一丁目１０番５号',
        industry='情報・通信業',
        sec_code='198A0',
        corporate_number='7010401155402',
    ),
    'E39709': EdinetCodeEntry(
        edinet_code='E39709',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=237,
        fiscal_year_end=None,
        submitter_name='株式会社エスコンアセットマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエスコンアセットマネジメント',
        address='港区虎ノ門二丁目１０番４号\u3000オークラプレステージタワー２０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001162142',
    ),
    'E39711': EdinetCodeEntry(
        edinet_code='E39711',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長野\u3000光幸',
        submitter_name_en=None,
        submitter_name_yomi='ナガノ\u3000ミツユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39714': EdinetCodeEntry(
        edinet_code='E39714',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000真人',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39715': EdinetCodeEntry(
        edinet_code='E39715',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='玉野\u3000玲子',
        submitter_name_en=None,
        submitter_name_yomi='タマノ\u3000レイコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39716': EdinetCodeEntry(
        edinet_code='E39716',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙田\u3000信子',
        submitter_name_en=None,
        submitter_name_yomi='タカダ\u3000ノブコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39721': EdinetCodeEntry(
        edinet_code='E39721',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トモエ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トモエカブシキガイシャ',
        address='岐阜市正木１５５２番地１８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3200001042489',
    ),
    'E39728': EdinetCodeEntry(
        edinet_code='E39728',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='八幡\u3000信孝',
        submitter_name_en=None,
        submitter_name_yomi='ヤハタ\u3000ノブタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39729': EdinetCodeEntry(
        edinet_code='E39729',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=119,
        fiscal_year_end='7月31日',
        submitter_name='株式会社カドス・コーポレーション',
        submitter_name_en='Cados Corporation',
        submitter_name_yomi='カブシキガイシャカドスコーポレーション',
        address='山口市小郡黄金町７番１７号',
        industry='建設業',
        sec_code='211A0',
        corporate_number='9250001001352',
    ),
    'E39731': EdinetCodeEntry(
        edinet_code='E39731',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=310,
        fiscal_year_end=None,
        submitter_name='株式会社ミンカブソリューションサービシーズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミンカブソリューションサービシーズ',
        address='港区東新橋一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001234228',
    ),
    'E39732': EdinetCodeEntry(
        edinet_code='E39732',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='10月31日',
        submitter_name='フィットイージー株式会社',
        submitter_name_en='FIT-EASY',
        submitter_name_yomi='フィットイージーカブシキガイシャ',
        address='岐阜市本町三丁目２番地１',
        industry='サービス業',
        sec_code='212A0',
        corporate_number='3200001035344',
    ),
    'E39733': EdinetCodeEntry(
        edinet_code='E39733',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＹＳＹ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワイエスワイ',
        address='堺市西区浜寺昭和町五丁６２７番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120101058171',
    ),
    'E39735': EdinetCodeEntry(
        edinet_code='E39735',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野中\u3000雅貴',
        submitter_name_en=None,
        submitter_name_yomi='ノナカ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39736': EdinetCodeEntry(
        edinet_code='E39736',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡田\u3000光信',
        submitter_name_en=None,
        submitter_name_yomi='オカダ\u3000ミツノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39737': EdinetCodeEntry(
        edinet_code='E39737',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=591,
        fiscal_year_end='3月31日',
        submitter_name='ＡＩフュージョンキャピタルグループ株式会社',
        submitter_name_en='AI FUSION CAPITAL GROUP CORP.',
        submitter_name_yomi='エーアイフュージョンキャピタルグループカブシキガイシャ',
        address='港区六本木一丁目９番９号',
        industry='その他金融業',
        sec_code='254A0',
        corporate_number='9010001248769',
    ),
    'E39738': EdinetCodeEntry(
        edinet_code='E39738',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｈｅｂａｒａ\u3000Ｈｏｌｄｃｏ\u3000ＩＩ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ヘバラ\u3000ホールドコ\u3000ツー\u3000エル\u3000ピー',
        address='アメリカ合衆国、デラウェア州、ニューカッスルカウンティ、ウィルミントン、１２０９オレンジストリート１９８０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39739': EdinetCodeEntry(
        edinet_code='E39739',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－７９',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイセブンティーナイン',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001242017',
    ),
    'E39740': EdinetCodeEntry(
        edinet_code='E39740',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エムキャップ十二号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムキャップジュウニゴウカブシキガイシャ',
        address='千代田区丸の内三丁目１番１号国際ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001244355',
    ),
    'E39741': EdinetCodeEntry(
        edinet_code='E39741',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='ジーエルテクノホールディングス株式会社',
        submitter_name_en='GLTECHNO HOLDINGS, INC.',
        submitter_name_yomi='ジーエルテクノホールディングスカブシキカイシャ',
        address='新宿区西新宿６丁目２２番地１号',
        industry='精密機器',
        sec_code='255A0',
        corporate_number='2011101109000',
    ),
    'E39742': EdinetCodeEntry(
        edinet_code='E39742',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='斎藤\u3000靜敬',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39743': EdinetCodeEntry(
        edinet_code='E39743',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='森山興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='モリヤマコウサンカブシキカイシャ',
        address='逗子市久木八丁目７番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021001057959',
    ),
    'E39747': EdinetCodeEntry(
        edinet_code='E39747',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4,
        fiscal_year_end=None,
        submitter_name='ＶＴＯＮＥ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヴェトンカブシキカイシャ',
        address='習志野市鷺沼台３－６－１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1040001015265',
    ),
    'E39748': EdinetCodeEntry(
        edinet_code='E39748',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北山\u3000聡明',
        submitter_name_en=None,
        submitter_name_yomi='キタヤマ\u3000トシアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39749': EdinetCodeEntry(
        edinet_code='E39749',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=825,
        fiscal_year_end=None,
        submitter_name='住友生命第４回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スミトモセイメイダイヨンカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001244829',
    ),
    'E39750': EdinetCodeEntry(
        edinet_code='E39750',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5000,
        fiscal_year_end=None,
        submitter_name='新生信託銀行株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンセイシンタクギンコウカブシキカイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001077463',
    ),
    'E39751': EdinetCodeEntry(
        edinet_code='E39751',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=1730,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＰＲＩＳＭ\u3000ＢｉｏＬａｂ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャプリズムバイオラボ',
        address='藤沢市村岡東二丁目２６番１号',
        industry='医薬品',
        sec_code='206A0',
        corporate_number='6020001095131',
    ),
    'E39752': EdinetCodeEntry(
        edinet_code='E39752',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大屋\u3000翼',
        submitter_name_en=None,
        submitter_name_yomi='オオヤ\u3000ツバサ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39756': EdinetCodeEntry(
        edinet_code='E39756',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社シーディーワン',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャシーディーワン',
        address='目黒区上目黒三丁目６番２４号碓井ビル三階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011103004371',
    ),
    'E39757': EdinetCodeEntry(
        edinet_code='E39757',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松井\u3000信博',
        submitter_name_en=None,
        submitter_name_yomi='マツイ\u3000ノブヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39758': EdinetCodeEntry(
        edinet_code='E39758',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ネイビー１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ネイビーワンカブシキカイシャ',
        address='千代田区有楽町一丁目１３番２号第一生命日比谷ファースト１２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001245195',
    ),
    'E39759': EdinetCodeEntry(
        edinet_code='E39759',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='10月31日',
        submitter_name='Ｈｅａｒｔｓｅｅｄ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ハートシードカブシキガイシャ',
        address='港区芝浦１丁目２番３号シーバンスＳ館５階',
        industry='医薬品',
        sec_code='219A0',
        corporate_number='4011001108455',
    ),
    'E39760': EdinetCodeEntry(
        edinet_code='E39760',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=107,
        fiscal_year_end='10月31日',
        submitter_name='株式会社タイミー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタイミー',
        address='東京都港区東新橋１丁目５ー２\u3000汐留シティセンター３５階',
        industry='情報・通信業',
        sec_code='215A0',
        corporate_number='1012801018219',
    ),
    'E39761': EdinetCodeEntry(
        edinet_code='E39761',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=606,
        fiscal_year_end=None,
        submitter_name='和德投資有限公司',
        submitter_name_en=None,
        submitter_name_yomi='ワトクトウシユウゲンコウシ',
        address='中華人民共和国、香港特別行政区、カウルーン、クントンロード３４８、マニュライフプレイス５階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39762': EdinetCodeEntry(
        edinet_code='E39762',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='公益財団法人マリオン財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンマリオンザイダン',
        address='新宿区富久町９－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011105010031',
    ),
    'E39765': EdinetCodeEntry(
        edinet_code='E39765',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='福山産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フクヤマサンギョウカブシキカイシャ',
        address='福山市本庄町中三丁目１９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2240001032710',
    ),
    'E39767': EdinetCodeEntry(
        edinet_code='E39767',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般財団法人アサヒペンひかり財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンアサヒペンヒカリザイダン',
        address='大阪市鶴見区鶴見四丁目１番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120005024194',
    ),
    'E39768': EdinetCodeEntry(
        edinet_code='E39768',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='倉谷\u3000知子',
        submitter_name_en=None,
        submitter_name_yomi='クラタニ\u3000トモコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39776': EdinetCodeEntry(
        edinet_code='E39776',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=84,
        fiscal_year_end=None,
        submitter_name='株式会社シティクリエイションホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシティクリエイションホールディングス',
        address='東京都板橋区中丸町１１番２号ワコーレ要町ビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011201012911',
    ),
    'E39777': EdinetCodeEntry(
        edinet_code='E39777',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='庄司\u3000武史',
        submitter_name_en=None,
        submitter_name_yomi='ショウジ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39778': EdinetCodeEntry(
        edinet_code='E39778',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='9月末日',
        submitter_name='株式会社Ｆａｂｅｒ\u3000Ｃｏｍｐａｎｙ',
        submitter_name_en='Faber Company Inc.',
        submitter_name_yomi='カブシキカイシャファベルカンパニー',
        address='港区虎ノ門四丁目１番１号',
        industry='情報・通信業',
        sec_code='220A0',
        corporate_number='5010401064118',
    ),
    'E39779': EdinetCodeEntry(
        edinet_code='E39779',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ビー・エックス・ジェイ・シー・ツー・ホールディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエックスジェイシーツーホールディングカブシキガイシャ',
        address='港区虎ノ門五丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401182469',
    ),
    'E39780': EdinetCodeEntry(
        edinet_code='E39780',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='稲井田\u3000勝',
        submitter_name_en=None,
        submitter_name_yomi='イナイダ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39781': EdinetCodeEntry(
        edinet_code='E39781',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='楠\u3000流維',
        submitter_name_en=None,
        submitter_name_yomi='クスノキ\u3000ルイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39782': EdinetCodeEntry(
        edinet_code='E39782',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='楠\u3000行博',
        submitter_name_en=None,
        submitter_name_yomi='クスノキ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39783': EdinetCodeEntry(
        edinet_code='E39783',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大久保\u3000遼',
        submitter_name_en=None,
        submitter_name_yomi='オオクボ\u3000リョウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39784': EdinetCodeEntry(
        edinet_code='E39784',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='Ｄａｎ\u3000Ｔａｋａｈａｓｈｉ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ダン\u3000タカハシ\u3000エルエルシー',
        address='１２０９\u3000Ｏｒａｎｇｅ\u3000Ｓｔｒｅｅｔ，\u3000Ｗｉｌｍｉｎｇｔｏｎ，\u3000Ｄｅｌａｗａｒｅ，\u3000１９８０１，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39785': EdinetCodeEntry(
        edinet_code='E39785',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5500,
        fiscal_year_end='3月31日',
        submitter_name='飛島ホールディングス株式会社',
        submitter_name_en='TOBISHIMA HOLDINGS Inc',
        submitter_name_yomi='トビシマホールディングスカブシキガイシャ',
        address='港区港南１－８－１５',
        industry='建設業',
        sec_code='256A0',
        corporate_number='3010401185502',
    ),
    'E39786': EdinetCodeEntry(
        edinet_code='E39786',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山﨑\u3000武夫',
        submitter_name_en=None,
        submitter_name_yomi='ヤマサキ\u3000タケオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39788': EdinetCodeEntry(
        edinet_code='E39788',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=220,
        fiscal_year_end='7月末日',
        submitter_name='株式会社Ｌｉｂｅｒａｗａｒｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリベラウェア',
        address='千葉市中央区中央三丁目３－１',
        industry='情報・通信業',
        sec_code='218A0',
        corporate_number='7040001096770',
    ),
    'E39790': EdinetCodeEntry(
        edinet_code='E39790',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三宅\u3000洋',
        submitter_name_en=None,
        submitter_name_yomi='ミヤケ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39792': EdinetCodeEntry(
        edinet_code='E39792',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二木\u3000信行',
        submitter_name_en=None,
        submitter_name_yomi='ニキ\u3000ノブユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39797': EdinetCodeEntry(
        edinet_code='E39797',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ａｄｏ\u3000Ｐｌｕｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアドプラス',
        address='大阪市中央区北浜三丁目２番２５号京阪淀屋橋ビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001231532',
    ),
    'E39798': EdinetCodeEntry(
        edinet_code='E39798',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='新聯利控股有限公司',
        submitter_name_en=None,
        submitter_name_yomi='シンリアンリーホールディングスリミテッド',
        address='ＲＭ\u3000Ａ０７，１７０１－０２\u3000ＮＥＷ\u3000ＴＲＥＮＤ\u3000ＣＥＮＴＲＥ，\u3000７０４\u3000ＰＲＩＮＣＥ\u3000ＥＤＷＡＲＤ\u3000ＲＯＡＤ\u3000ＥＡＳＴ，\u3000ＳＡＮ\u3000ＰＯ\u3000ＫＯＮＧ\u3000ＫＬＮ，\u3000ＨＯＮＧ\u3000ＫＯＮＧ，\u3000ＣＨＩＮＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39800': EdinetCodeEntry(
        edinet_code='E39800',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩澤\u3000崇',
        submitter_name_en=None,
        submitter_name_yomi='シオザワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39801': EdinetCodeEntry(
        edinet_code='E39801',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ライフサイエンスベンチャーキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ライフサイエンスベンチャーキャピタルカブシキカイシャ',
        address='千代田区神田三崎町３－１０－４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001048745',
    ),
    'E39805': EdinetCodeEntry(
        edinet_code='E39805',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='池田\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='イケダ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39807': EdinetCodeEntry(
        edinet_code='E39807',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山田\u3000明',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマダ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39808': EdinetCodeEntry(
        edinet_code='E39808',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍ＆Ｉ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムアンドアイ',
        address='千代田区丸の内２－１－１\u3000明治安田生命ビル１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001206691',
    ),
    'E39809': EdinetCodeEntry(
        edinet_code='E39809',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＯＲＣＨＩＤ\u3000ＰＬＵＳ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='オーキッドプラス\u3000プライベート\u3000リミテッド',
        address='４００\u3000ＯＲＣＨＡＲＤ\u3000ＲＯＡＤ\u3000＃０５－１７，\u3000ＯＲＣＨＡＲＤ\u3000ＴＯＷＥＲＳ\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39812': EdinetCodeEntry(
        edinet_code='E39812',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=697,
        fiscal_year_end='4月30日',
        submitter_name='株式会社グリーンクロスホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャグリーンクロスホールディングス',
        address='福岡市中央区笹丘一丁目１７番２９号',
        industry='卸売業',
        sec_code='272A0',
        corporate_number='9290001107872',
    ),
    'E39813': EdinetCodeEntry(
        edinet_code='E39813',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='株式会社エースタート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエースタート',
        address='港区三田三丁目５番２７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401115955',
    ),
    'E39814': EdinetCodeEntry(
        edinet_code='E39814',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='徳田\u3000博子',
        submitter_name_en=None,
        submitter_name_yomi='トクダ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39815': EdinetCodeEntry(
        edinet_code='E39815',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='赤羽\u3000斉子',
        submitter_name_en=None,
        submitter_name_yomi='アカハネ\u3000ナリコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39818': EdinetCodeEntry(
        edinet_code='E39818',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＧＭＯベンチャー通信スタートアップ支援株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーエムオーベンチャーツウシンスタートアップシエンカブシキガイシャ',
        address='東京都渋谷区桜丘町２６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001098552',
    ),
    'E39820': EdinetCodeEntry(
        edinet_code='E39820',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ライジングプロパティマネジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャライジングプロパティマネジメント',
        address='大阪市福島区福島４丁目３番２３－３７１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001234658',
    ),
    'E39827': EdinetCodeEntry(
        edinet_code='E39827',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29917,
        fiscal_year_end=None,
        submitter_name='ＣＩＴＩＣ\u3000ＣＡＰＩＴＡＬ\u3000ＪＡＰＡＮ\u3000ＰＡＲＴＮＥＲＳ\u3000ＩＩＩ、Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='シティック\u3000キャピタル\u3000ジャパン\u3000パートナーズ\u3000スリー\u3000エル\u3000ピー',
        address='ＷＡＬＫＥＲＳ\u3000ＣＯＲＰＯＲＡＴＥ\u3000ＬＩＭＩＴＥＤ，１９０\u3000ＥＬＧＩＮ\u3000ＡＶＥＮＵＥ、\u3000ＧＥＯＲＧＥ\u3000ＴＯＷＮ、\u3000ＧＲＡＮＤ\u3000ＣＡＹＭＡＮ、ＫＹ１－９００８\u3000ＣＡＹＭＡＮ\u3000ＩＳＬＡＮＤＳ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39828': EdinetCodeEntry(
        edinet_code='E39828',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊ－ＳＴＡＲ\u3000Ｎｏ．３\u3000ＧＦ\u3000ＧＰ，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ジェイスターナンバースリージーエフジーピーリミテッド',
        address='Ｐ．\u3000Ｏ．\u3000Ｂｏｘ\u3000１３５０，\u3000Ｗｉｎｄｗａｒｄ\u3000３，\u3000Ｒｅｇａｔｔａ\u3000Ｏｆｆｉｃｅ\u3000Ｐａｒｋ\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39829': EdinetCodeEntry(
        edinet_code='E39829',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊ－ＳＴＡＲ\u3000Ｎｏ．３\u3000ＪＣ\u3000ＧＰ，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ジェイスターナンバースリージェイシージーピーリミテッド',
        address='Ｐ．\u3000Ｏ．\u3000Ｂｏｘ\u3000１３５０，\u3000Ｗｉｎｄｗａｒｄ\u3000３，\u3000Ｒｅｇａｔｔａ\u3000Ｏｆｆｉｃｅ\u3000\u3000Ｐａｒｋ\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39830': EdinetCodeEntry(
        edinet_code='E39830',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊ－ＳＴＡＲ\u3000Ｎｏ．３\u3000ＪＦ\u3000ＧＰ，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ジェイスターナンバースリージェイエフジーピーリミテッド',
        address='Ｐ．\u3000Ｏ．\u3000Ｂｏｘ\u3000１３５０，\u3000Ｗｉｎｄｗａｒｄ\u3000３，\u3000Ｒｅｇａｔｔａ\u3000Ｏｆｆｉｃｅ\u3000\u3000Ｐａｒｋ\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39831': EdinetCodeEntry(
        edinet_code='E39831',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｊ－ＳＴＡＲ\u3000Ｎｏ．３\u3000ＳＳ\u3000ＧＰ，\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='ジェイスターナンバースリーエスエスジーピーリミテッド',
        address='Ｐ．\u3000Ｏ．\u3000Ｂｏｘ\u3000１３５０，\u3000Ｗｉｎｄｗａｒｄ\u3000３，\u3000Ｒｅｇａｔｔａ\u3000Ｏｆｆｉｃｅ\u3000\u3000Ｐａｒｋ\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39832': EdinetCodeEntry(
        edinet_code='E39832',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＬＮＳ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='エルエヌエスマネジメント',
        address='１２０\u3000Ｌｏｗｅｒ\u3000Ｄｅｌｔａ\u3000Ｒｄ，\u3000＃１０－０９，\u3000Ｃｅｎｄ\u3000ｅｘ\u3000Ｃｅｎｔｒｅ，\u3000Ｓｉｎｇａｐｏｒｅ\u3000１６９２０８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39838': EdinetCodeEntry(
        edinet_code='E39838',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙山\u3000眞司',
        submitter_name_en=None,
        submitter_name_yomi='タカヤマ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39840': EdinetCodeEntry(
        edinet_code='E39840',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=619,
        fiscal_year_end=None,
        submitter_name='日本生命第９回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンセイメイダイキュウカイレツゴローンリュウドウカカブシキカイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001245701',
    ),
    'E39844': EdinetCodeEntry(
        edinet_code='E39844',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＣＰＦフィルムファンド',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシーピーエフフィルムファンド',
        address='港区元赤坂一丁目１番７－１２０９号株式会社赤坂国際会計内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010403032843',
    ),
    'E39846': EdinetCodeEntry(
        edinet_code='E39846',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=98,
        fiscal_year_end='11月30日',
        submitter_name='株式会社オプロ',
        submitter_name_en='Opro Co., Ltd.',
        submitter_name_yomi='カブシキガイシャオプロ',
        address='中央区京橋二丁目１４番１号',
        industry='情報・通信業',
        sec_code='228A0',
        corporate_number='2010401054559',
    ),
    'E39848': EdinetCodeEntry(
        edinet_code='E39848',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000幹一',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000カンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39851': EdinetCodeEntry(
        edinet_code='E39851',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8120,
        fiscal_year_end=None,
        submitter_name='ＦＩＲＳＴ\u3000ＰＬＵＳ\u3000ＦＩＮＡＮＣＩＡＬ\u3000ＨＯＬＤＩＮＧＳ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ファースト\u3000プラス\u3000フィナンシャル\u3000ホールディングス\u3000プライベート\u3000リミテッド',
        address='８\u3000ＭＡＲＩＮＡ\u3000ＶＩＥＷ\u3000３６ー０２\u3000ＡＳＩＡ\u3000ＳＱＵＡＲＥ\u3000ＴＯＷＥＲ\u3000１\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39852': EdinetCodeEntry(
        edinet_code='E39852',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人北野美術館',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンキタノビジュツカン',
        address='長野市若穂綿内７９６３番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8100005010497',
    ),
    'E39854': EdinetCodeEntry(
        edinet_code='E39854',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000清文',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000キヨフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39856': EdinetCodeEntry(
        edinet_code='E39856',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=14100,
        fiscal_year_end=None,
        submitter_name='エシロールルックスオティカ',
        submitter_name_en=None,
        submitter_name_yomi='エシロールルックスオティカ',
        address='フランス\u3000９４２２０\u3000シャラントン＝ル＝ポン\u3000パリ通り１４７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39857': EdinetCodeEntry(
        edinet_code='E39857',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000敬起',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39858': EdinetCodeEntry(
        edinet_code='E39858',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中島喜一郎',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000キイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39860': EdinetCodeEntry(
        edinet_code='E39860',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西堀\u3000達也',
        submitter_name_en=None,
        submitter_name_yomi='ニシボリ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39864': EdinetCodeEntry(
        edinet_code='E39864',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=277,
        fiscal_year_end='9月30日',
        submitter_name='Ｃｒｏｓｓ\u3000Ｅホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クロスイーホールディングスカブシキガイシャ',
        address='佐世保市ハウステンボス町５番地３',
        industry='サービス業',
        sec_code='231A0',
        corporate_number='3310001018107',
    ),
    'E39868': EdinetCodeEntry(
        edinet_code='E39868',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=57,
        fiscal_year_end=None,
        submitter_name='株式会社ニューロマジック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニューロマジック',
        address='中央区築地六丁目１６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001053898',
    ),
    'E39871': EdinetCodeEntry(
        edinet_code='E39871',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=373,
        fiscal_year_end=None,
        submitter_name='ＭＹ．Ａｌｐｈａ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＨＫ\u3000Ａｄｖｉｓｏｒｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エムワイ\u3000アルファ\u3000マネジメント\u3000ホンコン\u3000アドバイザーズ\u3000リミテッド',
        address='Ｕｎｉｔ\u3000２０１，\u3000２／Ｆ，\u3000１００\u3000Ｑｕｅｅｎ’ｓ\u3000Ｒｏａｄ\u3000Ｃｅｎｔｒａｌ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39872': EdinetCodeEntry(
        edinet_code='E39872',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水野\u3000昭人',
        submitter_name_en=None,
        submitter_name_yomi='ミズノ\u3000アキヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39873': EdinetCodeEntry(
        edinet_code='E39873',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1629555,
        fiscal_year_end=None,
        submitter_name='Ｅｌｉ\u3000Ｌｉｌｌｙ\u3000ａｎｄ\u3000Ｃｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='イーライ\u3000リリー\u3000アンド\u3000カンパニー',
        address='アメリカ合衆国インディアナ州４６２８５、インディアナポリス、リリー・コーポレートセンター',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39874': EdinetCodeEntry(
        edinet_code='E39874',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堤\u3000洋一郎',
        submitter_name_en=None,
        submitter_name_yomi='ツツミ\u3000ヨウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39875': EdinetCodeEntry(
        edinet_code='E39875',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000敦司',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39876': EdinetCodeEntry(
        edinet_code='E39876',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='朝倉\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='アサクラ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39877': EdinetCodeEntry(
        edinet_code='E39877',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社オリーブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオリーブ',
        address='岐阜市一日市場一丁目１９６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9200001039190',
    ),
    'E39880': EdinetCodeEntry(
        edinet_code='E39880',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三村\u3000昌之',
        submitter_name_en=None,
        submitter_name_yomi='ミムラ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39881': EdinetCodeEntry(
        edinet_code='E39881',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三村\u3000健二',
        submitter_name_en=None,
        submitter_name_yomi='ミムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39885': EdinetCodeEntry(
        edinet_code='E39885',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔ’ｓ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000ティーズインターナショナル',
        address='千代田区丸の内１－６－２\u3000新丸の内センタービルディング１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001208736',
    ),
    'E39886': EdinetCodeEntry(
        edinet_code='E39886',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＳＮ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエイエスエヌ',
        address='港区赤坂四丁目７番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401183269',
    ),
    'E39888': EdinetCodeEntry(
        edinet_code='E39888',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='ＤＲＯＮＥ\u3000ＦＵＮＤ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ドローンファンドカブシキガイシャ',
        address='港区虎ノ門五丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2021001054667',
    ),
    'E39890': EdinetCodeEntry(
        edinet_code='E39890',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渋江\u3000透',
        submitter_name_en=None,
        submitter_name_yomi='シブエ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39891': EdinetCodeEntry(
        edinet_code='E39891',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='菊川\u3000厚',
        submitter_name_en=None,
        submitter_name_yomi='キクカワ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39892': EdinetCodeEntry(
        edinet_code='E39892',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=473,
        fiscal_year_end='12月31日',
        submitter_name='リガク・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リガクホールディングスカブシキカイシャ',
        address='昭島市松原町３丁目９－１２',
        industry='精密機器',
        sec_code='268A0',
        corporate_number='7010001214351',
    ),
    'E39898': EdinetCodeEntry(
        edinet_code='E39898',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小田\u3000則彦',
        submitter_name_en=None,
        submitter_name_yomi='オダ\u3000ノリヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39899': EdinetCodeEntry(
        edinet_code='E39899',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福田\u3000惠一',
        submitter_name_en=None,
        submitter_name_yomi='フクダ\u3000ケイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39900': EdinetCodeEntry(
        edinet_code='E39900',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古川\u3000俊治',
        submitter_name_en=None,
        submitter_name_yomi='フルカワ\u3000トシハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39901': EdinetCodeEntry(
        edinet_code='E39901',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川\u3000達哉',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39903': EdinetCodeEntry(
        edinet_code='E39903',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=627,
        fiscal_year_end='3月31日',
        submitter_name='Ａｉロボティクス株式会社',
        submitter_name_en='Ai ROBOTICS INC.',
        submitter_name_yomi='エーアイロボティクスカブシキガイシャ',
        address='港区六本木六丁目１０番１号',
        industry='化学',
        sec_code='247A0',
        corporate_number='8011001110465',
    ),
    'E39906': EdinetCodeEntry(
        edinet_code='E39906',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=328,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ＲＯＸＸ',
        submitter_name_en='ROXX, Inc.',
        submitter_name_yomi='カブシキガイシャロックス',
        address='東京都新宿区新宿６丁目２７番３０号',
        industry='情報・通信業',
        sec_code='241A0',
        corporate_number='4011001097376',
    ),
    'E39907': EdinetCodeEntry(
        edinet_code='E39907',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='龍川\u3000誠',
        submitter_name_en=None,
        submitter_name_yomi='タツカワ\u3000マコト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39908': EdinetCodeEntry(
        edinet_code='E39908',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋山\u3000琢己',
        submitter_name_en=None,
        submitter_name_yomi='アキヤマ\u3000タクミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39909': EdinetCodeEntry(
        edinet_code='E39909',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｌｉｂｅｒｔｙｈｉｌｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリバティヒル',
        address='江戸川区清新町１丁目１番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011701009964',
    ),
    'E39910': EdinetCodeEntry(
        edinet_code='E39910',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＡＰＩ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャエーピーアイ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010403032990',
    ),
    'E39911': EdinetCodeEntry(
        edinet_code='E39911',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｎｇｅｌ\u3000Ｂｒｉｄｇｅ\u3000Ｄｅａｌ―ｂｙ―Ｄｅａｌ\u3000Ｆｕｎｄ５号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エンジェル\u3000ブリッジ\u3000ディール\u3000バイ\u3000ディール\u3000ファンドゴゴウカブシキガイシャ',
        address='千代田区永田町２丁目１７番４号笠松千代田ビル１０１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001108352',
    ),
    'E39912': EdinetCodeEntry(
        edinet_code='E39912',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村本\u3000光彦',
        submitter_name_en=None,
        submitter_name_yomi='ムラモト\u3000ミツヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39913': EdinetCodeEntry(
        edinet_code='E39913',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='箱崎\u3000英次',
        submitter_name_en=None,
        submitter_name_yomi='ハコザキ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39914': EdinetCodeEntry(
        edinet_code='E39914',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社さくらキャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサクラキャピタル',
        address='港区赤坂五丁目２番１０号\u3000グリーンパーク赤坂２９０７',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401148352',
    ),
    'E39917': EdinetCodeEntry(
        edinet_code='E39917',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉田\u3000茂樹',
        submitter_name_en=None,
        submitter_name_yomi='スギタ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39920': EdinetCodeEntry(
        edinet_code='E39920',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='9月末日',
        submitter_name='株式会社リプライオリティ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリプライオリティ',
        address='福岡市博多区綱場町９番２０号',
        industry='サービス業',
        sec_code='242A0',
        corporate_number='9010001128178',
    ),
    'E39921': EdinetCodeEntry(
        edinet_code='E39921',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='Ｋｅｙｒｏｃｋ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='キーロック\u3000キャピタル\u3000マネジメント\u3000リミテッド',
        address='香港、ヘネシー・ロード２８、ファイブ・パシフィック・プレイス、２４０１号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39922': EdinetCodeEntry(
        edinet_code='E39922',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='閔\u3000弘圭',
        submitter_name_en=None,
        submitter_name_yomi='ミン\u3000ホンキュ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39923': EdinetCodeEntry(
        edinet_code='E39923',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=18243,
        fiscal_year_end=None,
        submitter_name='ＵＣＣ\u3000ＨＯＬＤＩＮＧＳ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ユーシーシーホールディングス',
        address='３６\u3000ＲＯＢＩＮＳＯＮ\u3000ＲＯＡＤ＃１６－０４\u3000ＣＩＴＹ\u3000ＨＯＵＳＥ\u3000ＳＩＮＧＡＰＯＲＥ\u3000０６８８７７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7700150124298',
    ),
    'E39924': EdinetCodeEntry(
        edinet_code='E39924',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='和田\u3000哲也',
        submitter_name_en=None,
        submitter_name_yomi='ワダ\u3000テツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39926': EdinetCodeEntry(
        edinet_code='E39926',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中嶋\u3000汰朗',
        submitter_name_en=None,
        submitter_name_yomi='ナカジマ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39927': EdinetCodeEntry(
        edinet_code='E39927',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='統合アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウゴウアセットマネジメントカブシキカイシャ',
        address='港区南青山５－１７－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401128430',
    ),
    'E39928': EdinetCodeEntry(
        edinet_code='E39928',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='8月末日',
        submitter_name='株式会社ＩＮＧＳ',
        submitter_name_en='INGS inc.',
        submitter_name_yomi='カブシキガイシャイングス',
        address='新宿区新宿６－２８－８\u3000ラ・ベルティ新宿３階',
        industry='小売業',
        sec_code='245A0',
        corporate_number='3011101052273',
    ),
    'E39929': EdinetCodeEntry(
        edinet_code='E39929',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＳＵＰＥＲ\u3000ＳＴＡＴＥ\u3000ＨＯＬＤＩＮＧＳ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スーパーステートホールディングスカブシキガイシャ',
        address='渋谷区渋谷２－２１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011001162534',
    ),
    'E39930': EdinetCodeEntry(
        edinet_code='E39930',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山根\u3000慎一郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマネ\u3000シンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39934': EdinetCodeEntry(
        edinet_code='E39934',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｒｅｃｏｌｌｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャレコレ',
        address='港区東新橋１－５－２汐留シティセンター３５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6013301046564',
    ),
    'E39935': EdinetCodeEntry(
        edinet_code='E39935',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='株式会社メディカルフロンティア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャメディカルフロンティア',
        address='郡山市駅前２丁目１０番１５号三共郡山ビル北館１階２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401110657',
    ),
    'E39936': EdinetCodeEntry(
        edinet_code='E39936',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=40,
        fiscal_year_end='6月30日',
        submitter_name='株式会社アスア',
        submitter_name_en='ASUA Inc.',
        submitter_name_yomi='カブシキガイシャアスア',
        address='名古屋市中村区黄金通一丁目１１番地',
        industry='サービス業',
        sec_code='246A0',
        corporate_number='7180001043783',
    ),
    'E39937': EdinetCodeEntry(
        edinet_code='E39937',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='間地\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='マジ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39944': EdinetCodeEntry(
        edinet_code='E39944',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＡＩＴＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エーアイティーアイカブシキカイシャ',
        address='中央区日本橋兜町６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001227956',
    ),
    'E39945': EdinetCodeEntry(
        edinet_code='E39945',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ケイ・ウノ',
        submitter_name_en='K-uno, CO., LTD.',
        submitter_name_yomi='カブシキガイシャケイウノ',
        address='名古屋市千種区猫洞通三丁目９番地',
        industry='小売業',
        sec_code='259A0',
        corporate_number='9180001005179',
    ),
    'E39947': EdinetCodeEntry(
        edinet_code='E39947',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中山\u3000伸之',
        submitter_name_en=None,
        submitter_name_yomi='ナカヤマ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39948': EdinetCodeEntry(
        edinet_code='E39948',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ソウハンホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャソウハンホールディングス',
        address='中央区日本橋蛎殻町一丁目３８番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001204481',
    ),
    'E39949': EdinetCodeEntry(
        edinet_code='E39949',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山崎裕康',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキヒロヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39950': EdinetCodeEntry(
        edinet_code='E39950',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山崎光紀',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキミツノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39951': EdinetCodeEntry(
        edinet_code='E39951',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古澤\u3000暢央',
        submitter_name_en=None,
        submitter_name_yomi='フルサワ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39953': EdinetCodeEntry(
        edinet_code='E39953',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社オートバックス・ディーラーグループ・ホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオートバックスディーラーグループホールディングス',
        address='練馬区高野台四丁目２２番２４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011601023235',
    ),
    'E39955': EdinetCodeEntry(
        edinet_code='E39955',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊久間\u3000哲',
        submitter_name_en=None,
        submitter_name_yomi='イクマ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39956': EdinetCodeEntry(
        edinet_code='E39956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='槇田\u3000幸夫',
        submitter_name_en=None,
        submitter_name_yomi='マキタ\u3000ユキオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39960': EdinetCodeEntry(
        edinet_code='E39960',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='Ｓａｕｄｉ\u3000Ａｒａｍｃｏ\u3000Ｅｎｔｒｅｐｒｅｎｅｕｒｓｈｉｐ\u3000Ｖｅｎｔｕｒｅｓ\u3000Ｃｏｍｐａｎｙ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='サウジアラムコアントレプレナーシップベンチャーズカンパニーリミテッド',
        address='サウジアラビア王国４７１９－３４４６４、ダーラン８７８３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39961': EdinetCodeEntry(
        edinet_code='E39961',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=105,
        fiscal_year_end='8月末日',
        submitter_name='グロースエクスパートナーズ株式会社',
        submitter_name_en='Growth  X Partners, Inc.',
        submitter_name_yomi='グロースエクスパートナーズカブシキガイシャ',
        address='新宿区西新宿一丁目２６番２号',
        industry='情報・通信業',
        sec_code='244A0',
        corporate_number='9010001118708',
    ),
    'E39962': EdinetCodeEntry(
        edinet_code='E39962',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ディービーピラミッドホールディングスエルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ディービーピラミッドホールディングスエルエルシー',
        address='アメリカ合衆国、フロリダ州、３３４８７、ボカラトン、パーク・オブ・コマース・ドライブ７５０、スイート２１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39963': EdinetCodeEntry(
        edinet_code='E39963',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｉｐ\u3000Ｓｈｉｕ\u3000Ｋｕｅｎ',
        submitter_name_en=None,
        submitter_name_yomi='イップ\u3000シウクエン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39964': EdinetCodeEntry(
        edinet_code='E39964',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社アルプス物流',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアルプスブツリュウ',
        address='横浜市港北区新羽町１７５６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001244552',
    ),
    'E39966': EdinetCodeEntry(
        edinet_code='E39966',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社大岳カンパニー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオオダケカンパニー',
        address='立川市柴崎町三丁目１３番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4012801006740',
    ),
    'E39967': EdinetCodeEntry(
        edinet_code='E39967',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='株式会社オルツ',
        submitter_name_en='alt Inc.',
        submitter_name_yomi='カブシキガイシャオルツ',
        address='港区六本木７－１５－７',
        industry='情報・通信業',
        sec_code=None,
        corporate_number='2010601047081',
    ),
    'E39968': EdinetCodeEntry(
        edinet_code='E39968',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=232,
        fiscal_year_end='9月30日',
        submitter_name='株式会社Ｓａｐｅｅｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサピート',
        address='港区芝五丁目１３番１８号',
        industry='情報・通信業',
        sec_code='269A0',
        corporate_number='5010001174267',
    ),
    'E39971': EdinetCodeEntry(
        edinet_code='E39971',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='有冨\u3000修',
        submitter_name_en=None,
        submitter_name_yomi='アリトミ\u3000シュウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39976': EdinetCodeEntry(
        edinet_code='E39976',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='マルヤス工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルヤスコウギョウカブシキガイシャ',
        address='岡崎市橋目町北山１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6180001009422',
    ),
    'E39978': EdinetCodeEntry(
        edinet_code='E39978',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠山功',
        submitter_name_en=None,
        submitter_name_yomi='トオヤマ\u3000イサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39979': EdinetCodeEntry(
        edinet_code='E39979',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000良彦',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ヨシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39980': EdinetCodeEntry(
        edinet_code='E39980',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='有限会社秀吉',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャヒデヨシ',
        address='名古屋市千種区鹿子町三丁目３５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5180002050021',
    ),
    'E39984': EdinetCodeEntry(
        edinet_code='E39984',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000智隆',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000トモタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39985': EdinetCodeEntry(
        edinet_code='E39985',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='日比野\u3000直人',
        submitter_name_en=None,
        submitter_name_yomi='ヒビノ\u3000ナオト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E39990': EdinetCodeEntry(
        edinet_code='E39990',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='シンプレクス・キャピタル・インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンプレクスキャピタルインベストメントカブシキカイシャ',
        address='千代田区丸の内１－５－１新丸の内ビルディング２７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001229179',
    ),
    'E39992': EdinetCodeEntry(
        edinet_code='E39992',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='有限会社ピーシー',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャピーシー',
        address='宇都宮市元今泉三丁目１８番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7060002007452',
    ),
    'E39993': EdinetCodeEntry(
        edinet_code='E39993',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end='12月31日',
        submitter_name='スロベニア共和国',
        submitter_name_en=None,
        submitter_name_yomi='スロベニアキョウワコク',
        address='スロベニア共和国、１０００リュブリャナ、ズパンチェバ・ウリカ３',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E39994': EdinetCodeEntry(
        edinet_code='E39994',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3131,
        fiscal_year_end=None,
        submitter_name='株式会社Ｗｉｚ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャワイズ',
        address='東京都豊島区南大塚二丁目２５番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2013301032080',
    ),
    'E39995': EdinetCodeEntry(
        edinet_code='E39995',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社たいかも',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタイカモ',
        address='三浦郡葉山町堀内１６０番１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5021001060679',
    ),
    'E39998': EdinetCodeEntry(
        edinet_code='E39998',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社キャプスタン・メディカル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャキャプスタンメディカル',
        address='港区南青山六丁目２番９号\u3000ＫＳビル１０Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011001071829',
    ),
    'E40001': EdinetCodeEntry(
        edinet_code='E40001',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=74,
        fiscal_year_end=None,
        submitter_name='エマージング・アセット・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='エマージングアセットマネジメントリミテッド',
        address='バミューダ、ハミルトンＨＭ１１、パー・ラ・ヴィル・ロード５８番、ヴァリス・ビルディング４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40002': EdinetCodeEntry(
        edinet_code='E40002',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='里見\u3000一典',
        submitter_name_en=None,
        submitter_name_yomi='サトミ\u3000カズノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40003': EdinetCodeEntry(
        edinet_code='E40003',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社舞花',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャマイカ',
        address='港区虎ノ門一丁目１７番１号虎ノ門ヒルズビジネスタワ－１４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4030001111723',
    ),
    'E40004': EdinetCodeEntry(
        edinet_code='E40004',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安川\u3000貴英',
        submitter_name_en=None,
        submitter_name_yomi='ヤスカワ\u3000タカヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40005': EdinetCodeEntry(
        edinet_code='E40005',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋田\u3000正人',
        submitter_name_en=None,
        submitter_name_yomi='アキタ\u3000マサヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40006': EdinetCodeEntry(
        edinet_code='E40006',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='秋田\u3000里加',
        submitter_name_en=None,
        submitter_name_yomi='アキタ\u3000リカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40007': EdinetCodeEntry(
        edinet_code='E40007',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='ウルトラテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウルトラテクノロジーカブシキカイシャ',
        address='横浜市都筑区新栄町１３番１８－３０３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6020001125796',
    ),
    'E40009': EdinetCodeEntry(
        edinet_code='E40009',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大本\u3000朋之',
        submitter_name_en=None,
        submitter_name_yomi='オオモトトモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40018': EdinetCodeEntry(
        edinet_code='E40018',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=706,
        fiscal_year_end='9月末日',
        submitter_name='株式会社Ｓｃｈｏｏ',
        submitter_name_en='Schoo,inc.',
        submitter_name_yomi='カブシキカイシャスクー',
        address='渋谷区鶯谷町２番７号',
        industry='サービス業',
        sec_code='264A0',
        corporate_number='3011001071002',
    ),
    'E40019': EdinetCodeEntry(
        edinet_code='E40019',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='株式会社日水コン',
        submitter_name_en='Nihon Suido Consultants Co., Ltd.',
        submitter_name_yomi='カブシキカイシャニッスイコン',
        address='新宿区西新宿六丁目２２番１号',
        industry='サービス業',
        sec_code='261A0',
        corporate_number='3011101015783',
    ),
    'E40021': EdinetCodeEntry(
        edinet_code='E40021',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷岡\u3000哲広',
        submitter_name_en=None,
        submitter_name_yomi='タニオカ\u3000テツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40024': EdinetCodeEntry(
        edinet_code='E40024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ‐８２‐１',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーシージェイエイティートゥーワン',
        address='東京都千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001247542',
    ),
    'E40025': EdinetCodeEntry(
        edinet_code='E40025',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1127,
        fiscal_year_end=None,
        submitter_name='パーソルキャリア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パーソルキャリアカブシキカイシャ',
        address='港区麻布台一丁目三番地一号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401089183',
    ),
    'E40026': EdinetCodeEntry(
        edinet_code='E40026',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桑山\u3000友美',
        submitter_name_en=None,
        submitter_name_yomi='クワヤマ\u3000トモミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40027': EdinetCodeEntry(
        edinet_code='E40027',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｏｎｔａｒｉｏ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='オンタリオゴウドウカイシャ',
        address='港区西新橋一丁目１番１号ＥＰコンサルティングサービス内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010403032885',
    ),
    'E40028': EdinetCodeEntry(
        edinet_code='E40028',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桑山好美',
        submitter_name_en=None,
        submitter_name_yomi='クワヤマヨシミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40029': EdinetCodeEntry(
        edinet_code='E40029',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ユータカラヤ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユータカラヤカブシキガイシャ',
        address='川崎市幸区南幸町２－９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4021001060795',
    ),
    'E40034': EdinetCodeEntry(
        edinet_code='E40034',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='3月31日',
        submitter_name='株式会社デジタルキューブ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャデジタルキューブ',
        address='神戸市中央区海岸通５番地',
        industry='情報・通信業',
        sec_code='263A0',
        corporate_number='7140001029282',
    ),
    'E40035': EdinetCodeEntry(
        edinet_code='E40035',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井口邦',
        submitter_name_en=None,
        submitter_name_yomi='イグチ\u3000クニ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40036': EdinetCodeEntry(
        edinet_code='E40036',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桂\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='カツラ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40037': EdinetCodeEntry(
        edinet_code='E40037',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='東京大学協創プラットフォーム開発株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウダイガクキョウソウプラットフォームカイハツカブシキカイシャ',
        address='文京区本郷七丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001173123',
    ),
    'E40038': EdinetCodeEntry(
        edinet_code='E40038',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社アイエフエム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイエフエム',
        address='福山市能島一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3240001033121',
    ),
    'E40039': EdinetCodeEntry(
        edinet_code='E40039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石井\u3000峯夫',
        submitter_name_en=None,
        submitter_name_yomi='イシイ\u3000ミネオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40040': EdinetCodeEntry(
        edinet_code='E40040',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='ＦＫ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフケーカブシキカイシャ',
        address='千代田区丸の内二丁目１番１号明治安田生命ビル１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001246985',
    ),
    'E40041': EdinetCodeEntry(
        edinet_code='E40041',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今井\u3000進太郎',
        submitter_name_en=None,
        submitter_name_yomi='シマイ\u3000シンタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40044': EdinetCodeEntry(
        edinet_code='E40044',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='松栄株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ショウエイカブシキカイシャ',
        address='松江市白潟本町７１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1280001000383',
    ),
    'E40047': EdinetCodeEntry(
        edinet_code='E40047',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='古桝屋株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コマスヤカブシキガイシャ',
        address='長岡市神田町３丁目１番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8110001037584',
    ),
    'E40052': EdinetCodeEntry(
        edinet_code='E40052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小賀浩通',
        submitter_name_en=None,
        submitter_name_yomi='コガヒロミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40053': EdinetCodeEntry(
        edinet_code='E40053',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65,
        fiscal_year_end=None,
        submitter_name='ＦＯＵＲ\u3000ＳＥＡＳＯＮＳ\u3000ＡＳＩＡ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＰＴＥ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='フォーシーズンズアジアインベストメントピーティーイィエルティディ',
        address='８０\u3000ＲＯＢＩＮＳＯＮ\u3000ＲＯＡＤ\u3000＃１３－０３\u3000ＳＩＮＧＡＰＯＲＥ\u3000０６８８９８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40054': EdinetCodeEntry(
        edinet_code='E40054',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000頑太',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000ゲンタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40057': EdinetCodeEntry(
        edinet_code='E40057',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社三輝',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサンキ',
        address='堺市北区中百舌鳥町二丁３１４番地１シャリエ中百舌鳥１２０４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4120101066981',
    ),
    'E40058': EdinetCodeEntry(
        edinet_code='E40058',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=221,
        fiscal_year_end='12月31日',
        submitter_name='Ｈｍｃｏｍｍ株式会社',
        submitter_name_en='Hmcomm Inc.',
        submitter_name_yomi='エイチエムコムカブシキカイシャ',
        address='港区芝大門２－１１－１',
        industry='情報・通信業',
        sec_code='265A0',
        corporate_number='9020001096754',
    ),
    'E40060': EdinetCodeEntry(
        edinet_code='E40060',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1656,
        fiscal_year_end='1月31日',
        submitter_name='Ｔｅｒｒａ\u3000Ｄｒｏｎｅ株式会社',
        submitter_name_en='Terra Drone Corporation',
        submitter_name_yomi='テラドローンカブシキガイシャ',
        address='渋谷区南平台町２番１７号',
        industry='情報・通信業',
        sec_code='278A0',
        corporate_number='5011001109543',
    ),
    'E40065': EdinetCodeEntry(
        edinet_code='E40065',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='リジェネラティブ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='リジェネラティブカブシキガイシャ',
        address='目黒区下目黒１丁目１番１４号コノトラビル７Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140001126807',
    ),
    'E40066': EdinetCodeEntry(
        edinet_code='E40066',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='2月末日',
        submitter_name='株式会社ガーデン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャガーデン',
        address='新宿区新宿二丁目８番８号',
        industry='小売業',
        sec_code='274A0',
        corporate_number='1011101075301',
    ),
    'E40067': EdinetCodeEntry(
        edinet_code='E40067',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒井\u3000基晴',
        submitter_name_en=None,
        submitter_name_yomi='クロイ\u3000モトハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40069': EdinetCodeEntry(
        edinet_code='E40069',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000隆二',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40070': EdinetCodeEntry(
        edinet_code='E40070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山崎\u3000里仁',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ノリヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40073': EdinetCodeEntry(
        edinet_code='E40073',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='山川株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワカブシキガイシャ',
        address='大阪市中央区淡路町一丁目３－２－８０３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001215562',
    ),
    'E40074': EdinetCodeEntry(
        edinet_code='E40074',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=25924,
        fiscal_year_end='12月31日',
        submitter_name='ＬＶＭＨモエ・ヘネシー・ルイ・ヴィトン',
        submitter_name_en=None,
        submitter_name_yomi='エルブイエムエイチモエヘネシールイヴィトン',
        address='フランス、パリ、７５００８、モンテーニュ通り２２番地',
        industry='その他製品',
        sec_code=None,
        corporate_number=None,
    ),
    'E40076': EdinetCodeEntry(
        edinet_code='E40076',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='立花\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='タチバナ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40077': EdinetCodeEntry(
        edinet_code='E40077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白井\u3000基治',
        submitter_name_en=None,
        submitter_name_yomi='シライ\u3000モトハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40082': EdinetCodeEntry(
        edinet_code='E40082',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='川島\u3000賢',
        submitter_name_en=None,
        submitter_name_yomi='カワシマ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40083': EdinetCodeEntry(
        edinet_code='E40083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='セーラー広告取引先持株会\u3000理事長\u3000小松義彦',
        submitter_name_en=None,
        submitter_name_yomi='セーラーコウコクトリヒキサキモチカブカイ\u3000リジチョウ\u3000コマツヨシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40084': EdinetCodeEntry(
        edinet_code='E40084',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小澤\u3000修三',
        submitter_name_en=None,
        submitter_name_yomi='オザワ\u3000シュウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40088': EdinetCodeEntry(
        edinet_code='E40088',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－８６',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイエイティーシックス',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001248190',
    ),
    'E40090': EdinetCodeEntry(
        edinet_code='E40090',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｇｌｏｂａｌ\u3000Ｓｅｍｉｃｏｎｄｕｃｔｏｒ\u3000Ｓｐｅｃｉａｌ\u3000Ｇａｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='グローバル\u3000セミコンダクター\u3000スペシャル\u3000ガス\u3000リミテッド',
        address='Ｓｕｉｔｅ２７０１－０８，２７／Ｆ．，Ｓｈｕｉ\u3000Ｏｎ\u3000Ｃｅｎｔｒｅ，Ｎｏｓ．６－８\u3000Ｈａｒｂｏｕｒ\u3000Ｒｏａｄ，Ｗａｎｃｈａｉ，Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40091': EdinetCodeEntry(
        edinet_code='E40091',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＦＯＵ\u3000ＪＯＨＮ\u3000ＣＨＩ\u3000ＣＨＯＮＧ',
        submitter_name_en=None,
        submitter_name_yomi='フー\u3000ジョン\u3000チー\u3000チョング',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40092': EdinetCodeEntry(
        edinet_code='E40092',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中根\u3000進',
        submitter_name_en=None,
        submitter_name_yomi='ナカネ\u3000ススム',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40093': EdinetCodeEntry(
        edinet_code='E40093',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='アパホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アパホールディングスカブシキガイシャ',
        address='港区赤坂三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401122291',
    ),
    'E40094': EdinetCodeEntry(
        edinet_code='E40094',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金内\u3000康人',
        submitter_name_en=None,
        submitter_name_yomi='カネウチ\u3000ヤスヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40095': EdinetCodeEntry(
        edinet_code='E40095',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='文智勇',
        submitter_name_en=None,
        submitter_name_yomi='ムンジヨン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40096': EdinetCodeEntry(
        edinet_code='E40096',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉原\u3000行洋',
        submitter_name_en=None,
        submitter_name_yomi='スギハラ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40097': EdinetCodeEntry(
        edinet_code='E40097',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='公益財団法人水・地域イノベーション財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンミズチイキイノベーションザイダン',
        address='新宿区西新宿六丁目１２番１号（パークウエスト）',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011105009432',
    ),
    'E40100': EdinetCodeEntry(
        edinet_code='E40100',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='児嶋\u3000一登',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000カズト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40104': EdinetCodeEntry(
        edinet_code='E40104',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=160,
        fiscal_year_end=None,
        submitter_name='豊田Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨダホールディングスカブシキカイシャ',
        address='港区新橋二丁目１９番４号ＳＮＴビル１１Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401141426',
    ),
    'E40107': EdinetCodeEntry(
        edinet_code='E40107',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='四谷\u3000秋水',
        submitter_name_en=None,
        submitter_name_yomi='ヨツヤ\u3000シュウスイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40108': EdinetCodeEntry(
        edinet_code='E40108',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=28,
        fiscal_year_end=None,
        submitter_name='株式会社ルイ・ボストン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャルイボストン',
        address='世田谷区代田６ー１１ー１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010902016481',
    ),
    'E40109': EdinetCodeEntry(
        edinet_code='E40109',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上野\u3000博史',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40110': EdinetCodeEntry(
        edinet_code='E40110',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='青柳\u3000誠希',
        submitter_name_en=None,
        submitter_name_yomi='アオヤギ\u3000マサキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40111': EdinetCodeEntry(
        edinet_code='E40111',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上野\u3000剛史',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40112': EdinetCodeEntry(
        edinet_code='E40112',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000伸一',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40113': EdinetCodeEntry(
        edinet_code='E40113',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='米倉\u3000千貴',
        submitter_name_en=None,
        submitter_name_yomi='ヨネクラ\u3000カズタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40115': EdinetCodeEntry(
        edinet_code='E40115',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ＭＭ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエムインベストメンツカブシキカイシャ',
        address='福岡市中央区大手門１－１－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010701039458',
    ),
    'E40116': EdinetCodeEntry(
        edinet_code='E40116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ネットプライス事業再生合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ネットプライスジギョウサイセイゴウドウガイシャ',
        address='港区新橋２丁目１６番１号ニュー新橋ビル９階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403033120',
    ),
    'E40117': EdinetCodeEntry(
        edinet_code='E40117',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=908464,
        fiscal_year_end=None,
        submitter_name='Ｅ\u3000ＩＮＫ\u3000ＨＯＬＤＩＮＧＳ\u3000ＩＮＣ．',
        submitter_name_en=None,
        submitter_name_yomi='イー\u3000インク\u3000ホールディングス\u3000インク',
        address='台湾３００新竹市新竹科学園区力行一路３号',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40118': EdinetCodeEntry(
        edinet_code='E40118',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='森\u3000健志郎',
        submitter_name_en=None,
        submitter_name_yomi='モリ\u3000ケンシロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40119': EdinetCodeEntry(
        edinet_code='E40119',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山下\u3000貴司',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40121': EdinetCodeEntry(
        edinet_code='E40121',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000知宏',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40123': EdinetCodeEntry(
        edinet_code='E40123',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉川\u3000健',
        submitter_name_en=None,
        submitter_name_yomi='ヨシカワ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40124': EdinetCodeEntry(
        edinet_code='E40124',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三本\u3000幸司',
        submitter_name_en=None,
        submitter_name_yomi='ミツモト\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40126': EdinetCodeEntry(
        edinet_code='E40126',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000かおる',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40127': EdinetCodeEntry(
        edinet_code='E40127',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000穣',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40128': EdinetCodeEntry(
        edinet_code='E40128',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000嵩大',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40130': EdinetCodeEntry(
        edinet_code='E40130',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=479,
        fiscal_year_end='8月31日',
        submitter_name='ククレブ・アドバイザーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ククレブアドバイザーズカブシキカイシャ',
        address='千代田区内神田一丁目１４番８号\u3000ＫＡＮＤＡＳＱＵＡＲＥＧＡＴＥ',
        industry='不動産業',
        sec_code='276A0',
        corporate_number='2010001202336',
    ),
    'E40131': EdinetCodeEntry(
        edinet_code='E40131',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｓｏｎｇ\u3000Ｂｉｄｃｏ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ソンビドコゴウドウカイシャ',
        address='中央区日本橋室町四丁目３番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010003044943',
    ),
    'E40132': EdinetCodeEntry(
        edinet_code='E40132',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='根岸\u3000靖',
        submitter_name_en=None,
        submitter_name_yomi='ネギシ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40133': EdinetCodeEntry(
        edinet_code='E40133',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='Ａｐｒｉｃｕｓ\u3000Ｐａｒｔｎｅｒｓ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='アプリカスパートナーズゴウドウカイシャ',
        address='港区北青山三丁目６番７号青山パラシオタワー１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010403033219',
    ),
    'E40134': EdinetCodeEntry(
        edinet_code='E40134',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=290,
        fiscal_year_end='12月31日',
        submitter_name='クイーンズゲート',
        submitter_name_en=None,
        submitter_name_yomi='クイーンズゲート',
        address='ケイマン諸島\u3000ＫＹ１ー１２０２\u3000グランド・ケイマン、ハーバー・プレイス、サウス・チャーチ・ストリート１０３\u3000私書箱３０４６４',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E40136': EdinetCodeEntry(
        edinet_code='E40136',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='1月31日',
        submitter_name='株式会社カブ＆ピース',
        submitter_name_en='KABU & PEACE Inc.',
        submitter_name_yomi='カブシキカイシャカブアンドピース',
        address='港区六本木一丁目４番５号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7010401180409',
    ),
    'E40137': EdinetCodeEntry(
        edinet_code='E40137',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='堂島汽船株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ドウジマキセンカブシキガイシャ',
        address='大阪市北区堂島二丁目３番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001268946',
    ),
    'E40139': EdinetCodeEntry(
        edinet_code='E40139',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小島\u3000直人',
        submitter_name_en=None,
        submitter_name_yomi='コジマ\u3000ナオト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40140': EdinetCodeEntry(
        edinet_code='E40140',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｇ\u3000Ｆｕｔｕｒｅ\u3000Ｆｕｎｄ１号投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='ジーフューチャーファンドイチゴウトウシジギョウユウゲンセキニンクミアイ',
        address='中央区八重洲一丁目４番１６号\u3000東京建物八重洲ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40141': EdinetCodeEntry(
        edinet_code='E40141',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志村\u3000晶',
        submitter_name_en=None,
        submitter_name_yomi='シムラ\u3000ヒカル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40142': EdinetCodeEntry(
        edinet_code='E40142',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='ＳＡＭＵＲＡＩ\u3000ＪＡＰＡＮ\u3000ＩＮＶＥＳＴＭＥＮＴＳ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='サムライ\u3000ジャパン\u3000インベストメンツ\u3000ピーティーイーリミテッド',
        address='１０ＡＮＳＯＮＲＯＡＤ＃１７－２０ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＰＬＡＺＡ\u3000ＳＩＮＧＡＰＯＲＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40143': EdinetCodeEntry(
        edinet_code='E40143',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松田\u3000航',
        submitter_name_en=None,
        submitter_name_yomi='マツダ\u3000ワタル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40144': EdinetCodeEntry(
        edinet_code='E40144',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='齋藤\u3000勝俊',
        submitter_name_en=None,
        submitter_name_yomi='サイトウ\u3000マサトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40145': EdinetCodeEntry(
        edinet_code='E40145',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=50,
        fiscal_year_end='3月末日',
        submitter_name='株式会社リスキル',
        submitter_name_en='Reskill Corp.',
        submitter_name_yomi='カブシキカイシャリスキル',
        address='新宿区四谷四丁目２８番地４ＹＫＢエンサインビル',
        industry='サービス業',
        sec_code='291A0',
        corporate_number='9011101098757',
    ),
    'E40146': EdinetCodeEntry(
        edinet_code='E40146',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮川\u3000洋',
        submitter_name_en=None,
        submitter_name_yomi='ミヤカワ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40147': EdinetCodeEntry(
        edinet_code='E40147',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1195,
        fiscal_year_end='5月31日',
        submitter_name='グロービング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='グロービングカブシキガイシャ',
        address='港区南青山３丁目１－３４',
        industry='サービス業',
        sec_code='277A0',
        corporate_number='5011101079356',
    ),
    'E40148': EdinetCodeEntry(
        edinet_code='E40148',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=898,
        fiscal_year_end=None,
        submitter_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='エスエムビーシーニッコウインベストメントファンドマネジメントカンパニーエスエイ',
        address='ルクセンブルグ大公国\u3000ルクセンブルグ\u3000Ｌ－１２８２\u3000ヒルデガルト・フォン・ビンゲン通り２番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40149': EdinetCodeEntry(
        edinet_code='E40149',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='築山\u3000英治',
        submitter_name_en=None,
        submitter_name_yomi='ツキヤマ\u3000エイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40150': EdinetCodeEntry(
        edinet_code='E40150',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='東京都',
        submitter_name_en=None,
        submitter_name_yomi='トウキョウト',
        address='新宿区西新宿２丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8000020130001',
    ),
    'E40151': EdinetCodeEntry(
        edinet_code='E40151',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社エクソソーム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエクソソーム',
        address='千代田区二番町５番地２５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001233052',
    ),
    'E40154': EdinetCodeEntry(
        edinet_code='E40154',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='ＭＩＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミックカブシキカイシャ',
        address='新宿区西新宿５－１４－３',
        industry='サービス業',
        sec_code='300A0',
        corporate_number='2011101020470',
    ),
    'E40155': EdinetCodeEntry(
        edinet_code='E40155',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=140,
        fiscal_year_end=None,
        submitter_name='ｆｕｎｄｎｏｔｅ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ファンドノートカブシキカイシャ',
        address='港区芝５－２９－２０\u3000クロスオフィス三田',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401162385',
    ),
    'E40156': EdinetCodeEntry(
        edinet_code='E40156',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3000,
        fiscal_year_end=None,
        submitter_name='ＧＣＭホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーシーエムホールディングスカブシキガイシャ',
        address='中央区日本橋蛎殻町２丁目１１番３号\u3000日本橋水天宮ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003026558',
    ),
    'E40157': EdinetCodeEntry(
        edinet_code='E40157',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='共通物産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キョウツウブッサンカブシキガイシャ',
        address='千代田区麹町５－５－１葵シャトー２０５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011501025410',
    ),
    'E40158': EdinetCodeEntry(
        edinet_code='E40158',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11296,
        fiscal_year_end=None,
        submitter_name='フランクリン・アドバイザーズ・インク',
        submitter_name_en=None,
        submitter_name_yomi='フランクリンアドバイザーズインク',
        address='アメリカ合衆国、９４４０３、カリフォルニア州、サン・マテオ市、フランクリン・パークウェイ１番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40159': EdinetCodeEntry(
        edinet_code='E40159',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平野\u3000泰啓',
        submitter_name_en=None,
        submitter_name_yomi='ヒラノ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40160': EdinetCodeEntry(
        edinet_code='E40160',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＷＡＮＧ\u3000ＣＨＩ',
        submitter_name_en=None,
        submitter_name_yomi='ワン\u3000チ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40161': EdinetCodeEntry(
        edinet_code='E40161',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=26610,
        fiscal_year_end=None,
        submitter_name='Ｖｅｒｔｅｘ\u3000Ｇｒｏｗｔｈ\u3000Ｆｕｎｄ\u3000Ⅱ\u3000Ｐｔｅ．\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='バーテックス\u3000グロースファンド\u3000ツー',
        address='２５０\u3000Ｎｏｒｔｈ\u3000Ｂｒｉｄｇｅ\u3000Ｒｏａｄ\u3000Ｒａｆｆｌｅｓ\u3000Ｃｉｔｙ\u3000Ｔｏｗｅｒ\u3000＃１１ー０１\u3000Ｓｉｎｇａｐｏｒｅ\u3000１７９１０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40163': EdinetCodeEntry(
        edinet_code='E40163',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6,
        fiscal_year_end=None,
        submitter_name='株式会社ケイ・エス・エス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイエスエス',
        address='練馬区石神井町六丁目２３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010701031346',
    ),
    'E40164': EdinetCodeEntry(
        edinet_code='E40164',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='令和アカウンティング・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='レイワアカウンティングホールディングスカブシキガイシャ',
        address='中央区日本橋一丁目４番１号\u3000日本橋一丁目ビルディング',
        industry='サービス業',
        sec_code='296A0',
        corporate_number='6010001128817',
    ),
    'E40165': EdinetCodeEntry(
        edinet_code='E40165',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柴田\u3000泰三',
        submitter_name_en=None,
        submitter_name_yomi='シバタ\u3000タイゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40166': EdinetCodeEntry(
        edinet_code='E40166',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16595,
        fiscal_year_end=None,
        submitter_name='ＩＦ\u3000Ｇｒｏｗｔｈ\u3000Ｏｐｐｏｒｔｕｎｉｔｙ\u3000Ｆｕｎｄ\u3000Ｉ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='アイエフグロースオポチュニティーファンドワンエルピー',
        address='コンヤーズ・トラスト・カンパニー（ケイマン）・リミテッド\u3000クリケットスクエア、ハッチンズドライブ私書箱２６８１\u3000グランドケイマン、ＫＹ１－１１１１\u3000ケイマン諸島',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40167': EdinetCodeEntry(
        edinet_code='E40167',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山口\u3000豊彦',
        submitter_name_en=None,
        submitter_name_yomi='ヤマグチ\u3000トヨヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40168': EdinetCodeEntry(
        edinet_code='E40168',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9,
        fiscal_year_end=None,
        submitter_name='株式会社コンステレーションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコンステレーションズ',
        address='港区東新橋二丁目９番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401093951',
    ),
    'E40175': EdinetCodeEntry(
        edinet_code='E40175',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=299,
        fiscal_year_end='11月末日',
        submitter_name='株式会社ＴＭＨ',
        submitter_name_en='TMH Inc.',
        submitter_name_yomi='カブシキガイシャティーエムエイチ',
        address='大分市下郡北三丁目１４番６号\u3000メゾンドールⅡ\u3000１号',
        industry='卸売業',
        sec_code='280A0',
        corporate_number='9320001011625',
    ),
    'E40181': EdinetCodeEntry(
        edinet_code='E40181',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｓｕｎｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャサニー',
        address='藤沢市湘南台一丁目１番地２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1021001083502',
    ),
    'E40185': EdinetCodeEntry(
        edinet_code='E40185',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ａｔｏｍ\u3000Ｉｎｖｅｓｔｍｅｎｔ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='アトム\u3000インベストメント\u3000エルピー',
        address='Ｗａｌｋｅｒｓ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｌｉｍｉｔｅｄ，\u3000１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40186': EdinetCodeEntry(
        edinet_code='E40186',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=900,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ファイントゥデイホールディングス',
        submitter_name_en='FineToday Holdings Co., Ltd.',
        submitter_name_yomi='カブシキガイシャファイントゥデイホールディングス',
        address='港区港南二丁目１６番３号',
        industry='化学',
        sec_code=None,
        corporate_number='3010001215304',
    ),
    'E40187': EdinetCodeEntry(
        edinet_code='E40187',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000幸一',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40188': EdinetCodeEntry(
        edinet_code='E40188',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ワイエス商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイエスショウジカブシキガイシャ',
        address='港区六本木六丁目１０番１号六本木ヒルズ森タワー２３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401185696',
    ),
    'E40189': EdinetCodeEntry(
        edinet_code='E40189',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=90,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ジグザグ',
        submitter_name_en='zig-zag,Inc.',
        submitter_name_yomi='カブシキガイシャジグザグ',
        address='渋谷区桜丘町１４番１号',
        industry='情報・通信業',
        sec_code='340A0',
        corporate_number='7011001106134',
    ),
    'E40190': EdinetCodeEntry(
        edinet_code='E40190',
        submitter_type='外国政府等',
        listing_status=None,
        consolidated=None,
        capital_million_yen=137747,
        fiscal_year_end='12月31日',
        submitter_name='アフリカ輸出入銀行',
        submitter_name_en=None,
        submitter_name_yomi='アフリカユシュツニュウギンコウ',
        address='該当なし',
        industry='外国政府等',
        sec_code=None,
        corporate_number=None,
    ),
    'E40191': EdinetCodeEntry(
        edinet_code='E40191',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティコーポレーション',
        address='呉市焼山本庄四丁目８番１８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1240001063913',
    ),
    'E40192': EdinetCodeEntry(
        edinet_code='E40192',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社Ｗ＆Ｄインベストメントデザイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャダブリューアンドディーインベストメントデザイン',
        address='港区北青山三丁目５番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401132200',
    ),
    'E40193': EdinetCodeEntry(
        edinet_code='E40193',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='千代田インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チヨダインベストメントカブシキガイシャ',
        address='千代田区西神田三丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001227657',
    ),
    'E40194': EdinetCodeEntry(
        edinet_code='E40194',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='2月20日',
        submitter_name='ハンワホームズ株式会社',
        submitter_name_en="Hanwa Home's Co., Ltd.",
        submitter_name_yomi='ハンワホームズカブシキガイシャ',
        address='泉南市幡代三丁目８３８番地の１',
        industry='建設業',
        sec_code='275A0',
        corporate_number='5120101044359',
    ),
    'E40196': EdinetCodeEntry(
        edinet_code='E40196',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀地\u3000かなえ',
        submitter_name_en=None,
        submitter_name_yomi='ホリチ\u3000カナエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40197': EdinetCodeEntry(
        edinet_code='E40197',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＵＤＯＮ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウドンカブシキガイシャ',
        address='京都市伏見区桃山町根来１２番地４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001249260',
    ),
    'E40198': EdinetCodeEntry(
        edinet_code='E40198',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＢＩＦＳ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイエフエスゴウドウガイシャ',
        address='港区六本木一丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010403029361',
    ),
    'E40199': EdinetCodeEntry(
        edinet_code='E40199',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＪ１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティージェーワンカブシキガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001247946',
    ),
    'E40203': EdinetCodeEntry(
        edinet_code='E40203',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=778,
        fiscal_year_end=None,
        submitter_name='株式会社外為どっとコム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャガイタメドットコム',
        address='港区東新橋二丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401052335',
    ),
    'E40206': EdinetCodeEntry(
        edinet_code='E40206',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=821,
        fiscal_year_end='3月31日',
        submitter_name='ラクサス・テクノロジーズ株式会社',
        submitter_name_en='Laxus Technologies Inc.',
        submitter_name_yomi='ラクサステクノロジーズカブシキカイシャ',
        address='広島市中区中町８－１８',
        industry='サービス業',
        sec_code='288A0',
        corporate_number='9240001017580',
    ),
    'E40207': EdinetCodeEntry(
        edinet_code='E40207',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='辻本\u3000久和',
        submitter_name_en=None,
        submitter_name_yomi='ツジモト\u3000ヒサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40208': EdinetCodeEntry(
        edinet_code='E40208',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＴＣＳ‐１投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='ティーシーエスワントウシジギョウユウゲンセキニンクミアイ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40212': EdinetCodeEntry(
        edinet_code='E40212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ゲロヴィッチ・サイモン',
        submitter_name_en=None,
        submitter_name_yomi='ゲロヴイツチサイモン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40213': EdinetCodeEntry(
        edinet_code='E40213',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=11642,
        fiscal_year_end='3月31日',
        submitter_name='黒田グループ株式会社',
        submitter_name_en='Kuroda Group Co., Ltd.',
        submitter_name_yomi='クロダグループカブシキカイシャ',
        address='品川区南大井五丁目１７番９号',
        industry='その他製品',
        sec_code='287A0',
        corporate_number='2010001186851',
    ),
    'E40215': EdinetCodeEntry(
        edinet_code='E40215',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=119,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ビースタイルホールディングス',
        submitter_name_en='b-style holdings,Inc.',
        submitter_name_yomi='カブシキガイシャビースタイルホールディングス',
        address='新宿区西新宿６－１８－１',
        industry='サービス業',
        sec_code='302A0',
        corporate_number='7011101090501',
    ),
    'E40216': EdinetCodeEntry(
        edinet_code='E40216',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2950,
        fiscal_year_end='12月末日',
        submitter_name='株式会社Ｓｙｎｓｐｅｃｔｉｖｅ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャシンスペクティブ',
        address='江東区三好三丁目１０番３号',
        industry='情報・通信業',
        sec_code='290A0',
        corporate_number='4010001189902',
    ),
    'E40217': EdinetCodeEntry(
        edinet_code='E40217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村松\u3000眞之',
        submitter_name_en=None,
        submitter_name_yomi='ムラマツ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40218': EdinetCodeEntry(
        edinet_code='E40218',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榎並\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='エナミ\u3000タイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40220': EdinetCodeEntry(
        edinet_code='E40220',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='輪島総介',
        submitter_name_en=None,
        submitter_name_yomi='ワジマ\u3000ソウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40222': EdinetCodeEntry(
        edinet_code='E40222',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=104858,
        fiscal_year_end=None,
        submitter_name='テクトロニック・インダストリーズ・カンパニー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='テクトロニックインダストリーズカンパニーリミテッド',
        address='香港、ニューテリトリース、クワァイチョン、クワァイチョンロード５１番、クーロンコマースセンタータワー２、２９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40223': EdinetCodeEntry(
        edinet_code='E40223',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=248,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ｖｉｓｕｍｏ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビジュモ',
        address='渋谷区神宮前六丁目１０番１１号原宿ソフィアビル４階',
        industry='その他製品',
        sec_code='303A0',
        corporate_number='2011001127358',
    ),
    'E40225': EdinetCodeEntry(
        edinet_code='E40225',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='シャヌワール株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シャヌワールカブシキガイシャ',
        address='千代田区九段南４－８－８\u3000プレミスト九段１５０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011601021874',
    ),
    'E40226': EdinetCodeEntry(
        edinet_code='E40226',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='牧野\u3000顕道',
        submitter_name_en=None,
        submitter_name_yomi='マキノ\u3000アキミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40229': EdinetCodeEntry(
        edinet_code='E40229',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='マネーフォワードコンサルティング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マネーフォワードコンサルティングカブシキガイシャ',
        address='港区芝浦３－１－２１ｍｓｂＴａｍａｃｈｉ田町ステーションタワーＳ２１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401183427',
    ),
    'E40230': EdinetCodeEntry(
        edinet_code='E40230',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=236,
        fiscal_year_end='2月末日',
        submitter_name='フォルシア株式会社',
        submitter_name_en='FORCIA, Inc.',
        submitter_name_yomi='フォルシアカブシキガイシャ',
        address='新宿区新宿四丁目１番６号',
        industry='情報・通信業',
        sec_code='304A0',
        corporate_number='8011101031454',
    ),
    'E40234': EdinetCodeEntry(
        edinet_code='E40234',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='下\u3000一彦',
        submitter_name_en=None,
        submitter_name_yomi='シモ\u3000カズヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40236': EdinetCodeEntry(
        edinet_code='E40236',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=142,
        fiscal_year_end='3月31日',
        submitter_name='クラシル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クラシルカブシキカイシャ',
        address='港区芝浦３丁目１ー１\u3000ｍｓｂＴａｍａｃｈｉ田町ステーションタワーＮ\u3000２３Ｆ',
        industry='情報・通信業',
        sec_code='299A0',
        corporate_number='2011001099829',
    ),
    'E40237': EdinetCodeEntry(
        edinet_code='E40237',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='門林\u3000雄基',
        submitter_name_en=None,
        submitter_name_yomi='カドバヤシ\u3000ユウキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40238': EdinetCodeEntry(
        edinet_code='E40238',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉野\u3000泰雄',
        submitter_name_en=None,
        submitter_name_yomi='ヨシノ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40239': EdinetCodeEntry(
        edinet_code='E40239',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田村\u3000正則',
        submitter_name_en=None,
        submitter_name_yomi='タムラ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40240': EdinetCodeEntry(
        edinet_code='E40240',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='山野美容商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマノビヨウショウジカブシキカイシャ',
        address='渋谷区代々木１－１３－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001044114',
    ),
    'E40241': EdinetCodeEntry(
        edinet_code='E40241',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀江\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='ホリエ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40242': EdinetCodeEntry(
        edinet_code='E40242',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社田村商事',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタムラショウジ',
        address='塩尻市広丘野村９３６－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7100001015682',
    ),
    'E40243': EdinetCodeEntry(
        edinet_code='E40243',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中井\u3000大志',
        submitter_name_en=None,
        submitter_name_yomi='ナカイ\u3000タイシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40244': EdinetCodeEntry(
        edinet_code='E40244',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='児玉\u3000昇司',
        submitter_name_en=None,
        submitter_name_yomi='コダマ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40245': EdinetCodeEntry(
        edinet_code='E40245',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鶴\u3000結介',
        submitter_name_en=None,
        submitter_name_yomi='ツル\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40246': EdinetCodeEntry(
        edinet_code='E40246',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鶴\u3000厚志',
        submitter_name_en=None,
        submitter_name_yomi='ツル\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40247': EdinetCodeEntry(
        edinet_code='E40247',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=336762,
        fiscal_year_end='12月31日',
        submitter_name='インテグリス・インク',
        submitter_name_en=None,
        submitter_name_yomi='インテグリスインク',
        address='米国\u3000０１８２１\u3000マサチューセッツ州、ビレリカ、コンコード・ロード１２９',
        industry='外国法人・組合',
        sec_code=None,
        corporate_number=None,
    ),
    'E40248': EdinetCodeEntry(
        edinet_code='E40248',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｂｌｕｅ\u3000Ｐｅａｋ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャブルーピーク',
        address='港区北青山二丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401177152',
    ),
    'E40249': EdinetCodeEntry(
        edinet_code='E40249',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000陽介',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ヨウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40252': EdinetCodeEntry(
        edinet_code='E40252',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社チェンバーマネイジメント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャチェンバーマネイジメント',
        address='佐渡市秋津１００６番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8110001035662',
    ),
    'E40253': EdinetCodeEntry(
        edinet_code='E40253',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=153,
        fiscal_year_end='12月末日',
        submitter_name='ＧＶＡ\u3000ＴＥＣＨ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジーヴァテックカブシキガイシャ',
        address='渋谷区代々木３ー３７ー５ー２階',
        industry='情報・通信業',
        sec_code='298A0',
        corporate_number='3011001114347',
    ),
    'E40254': EdinetCodeEntry(
        edinet_code='E40254',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新居\u3000英一',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000エイイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40256': EdinetCodeEntry(
        edinet_code='E40256',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='那須\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='ナス\u3000ゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40257': EdinetCodeEntry(
        edinet_code='E40257',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大澤\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='オオサワ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40258': EdinetCodeEntry(
        edinet_code='E40258',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='有限会社ニシナ興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャニシナコウサン',
        address='長野市若里七丁目１３番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3100002003913',
    ),
    'E40263': EdinetCodeEntry(
        edinet_code='E40263',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='德重\u3000徹',
        submitter_name_en=None,
        submitter_name_yomi='トクシゲ\u3000トオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40264': EdinetCodeEntry(
        edinet_code='E40264',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮寺\u3000之裕',
        submitter_name_en=None,
        submitter_name_yomi='ミヤデラ\u3000ユキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40266': EdinetCodeEntry(
        edinet_code='E40266',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｗｏｊｃｉｅｃｈ\u3000Ｊａｋｕｂ\u3000Ｐｏｄｏｂａｓ',
        submitter_name_en=None,
        submitter_name_yomi='ヴォイチェフ\u3000ヤクブ\u3000ポドバス',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40267': EdinetCodeEntry(
        edinet_code='E40267',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山内\u3000英靖',
        submitter_name_en=None,
        submitter_name_yomi='ヤマウチ\u3000ヒデハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40269': EdinetCodeEntry(
        edinet_code='E40269',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=55,
        fiscal_year_end='12月31日',
        submitter_name='株式会社技術承継機構',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャギジュツショウケイキコウ',
        address='渋谷区渋谷１ー３－１８ビラ・モデルナＡ４０２',
        industry='サービス業',
        sec_code='319A0',
        corporate_number='8010001193280',
    ),
    'E40270': EdinetCodeEntry(
        edinet_code='E40270',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='山内エンタープライズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤマウチエンタープライズカブシキガイシャ',
        address='塩釜市新浜町１丁目２６番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5370001044871',
    ),
    'E40271': EdinetCodeEntry(
        edinet_code='E40271',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙島\u3000雄太',
        submitter_name_en=None,
        submitter_name_yomi='タカシマ\u3000ユウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40275': EdinetCodeEntry(
        edinet_code='E40275',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='日光産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッコウサンギョウカブシキガイシャ',
        address='大阪市福島区福島７ー１５ー２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001036026',
    ),
    'E40276': EdinetCodeEntry(
        edinet_code='E40276',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＣＮホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエーシーエヌホールディングス',
        address='大阪市中央区城見二丁目１番６１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001262866',
    ),
    'E40283': EdinetCodeEntry(
        edinet_code='E40283',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水谷\u3000日出夫',
        submitter_name_en=None,
        submitter_name_yomi='ミズタニ\u3000ヒデオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40287': EdinetCodeEntry(
        edinet_code='E40287',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='エフホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフホールディングスカブシキガイシャ',
        address='高知市薊野西町３丁目２７番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2490001010575',
    ),
    'E40290': EdinetCodeEntry(
        edinet_code='E40290',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000耕平',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40294': EdinetCodeEntry(
        edinet_code='E40294',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社Ｈ＆Ｄ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチアンドディー',
        address='倉敷市加須山３３４－２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8260002020566',
    ),
    'E40295': EdinetCodeEntry(
        edinet_code='E40295',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＨＹホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エイチワイホールディングスカブシキガイシャ',
        address='松江市鹿島町手結５４６番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8280001008957',
    ),
    'E40297': EdinetCodeEntry(
        edinet_code='E40297',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1301,
        fiscal_year_end=None,
        submitter_name='学校法人君津あすなろ学園',
        submitter_name_en=None,
        submitter_name_yomi='ガッコウホウジンキミツアスナロガクエン',
        address='君津市上湯江字三角１０１９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040005008434',
    ),
    'E40298': EdinetCodeEntry(
        edinet_code='E40298',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12540746,
        fiscal_year_end=None,
        submitter_name='グーグル・インターナショナル・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='グーグルインターナショナルエルエルシー',
        address='米国\u3000１９８０８\u3000デラウェア州、ウィルミントン、リトル・フォールズ・ドライブ２５１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40299': EdinetCodeEntry(
        edinet_code='E40299',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=14375,
        fiscal_year_end='3月末日',
        submitter_name='いすゞリーシングサービス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イスズリーシングサービスカブシキガイシャ',
        address='横浜市西区高島１－２－５',
        industry='その他金融業',
        sec_code=None,
        corporate_number='7010701027334',
    ),
    'E40300': EdinetCodeEntry(
        edinet_code='E40300',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='親川\u3000智行',
        submitter_name_en=None,
        submitter_name_yomi='オヤカワ\u3000トモユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40303': EdinetCodeEntry(
        edinet_code='E40303',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｔｏｋｙｏ‐１ＧＰ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トーキョーワンジーピーカブシキガイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001234696',
    ),
    'E40305': EdinetCodeEntry(
        edinet_code='E40305',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=495,
        fiscal_year_end=None,
        submitter_name='パーソルクロステクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='パーソルクロステクノロジーカブシキガイシャ',
        address='新宿区西新宿２－１－１新宿三井ビルディング５１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3180001032055',
    ),
    'E40306': EdinetCodeEntry(
        edinet_code='E40306',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='時\u3000慧',
        submitter_name_en=None,
        submitter_name_yomi='トキ\u3000ケイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40307': EdinetCodeEntry(
        edinet_code='E40307',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='Ｃａｔａｌｙｓｔ\u3000Ａｒｔ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カタリストアートインベストメンツカブシキカイシャ',
        address='港区赤坂一丁目１４番５号アークヒルズ・エグゼクティブタワーＳ９０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001233890',
    ),
    'E40309': EdinetCodeEntry(
        edinet_code='E40309',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=55,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000松岡',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000マツオカ',
        address='下関市東大和町１－１０－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7250001006345',
    ),
    'E40310': EdinetCodeEntry(
        edinet_code='E40310',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平儀野\u3000由貴',
        submitter_name_en=None,
        submitter_name_yomi='ヒラギノ\u3000ユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40311': EdinetCodeEntry(
        edinet_code='E40311',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='増村\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='マスムラ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40313': EdinetCodeEntry(
        edinet_code='E40313',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48459,
        fiscal_year_end=None,
        submitter_name='ＫＭ２，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ケイエムツーエルピー',
        address='ＰＯ\u3000Ｂｏｘ\u3000３０９，\u3000Ｕｇｌａｎｄ\u3000Ｈｏｕｓｅ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０４，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40315': EdinetCodeEntry(
        edinet_code='E40315',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000香太郎',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000コウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40316': EdinetCodeEntry(
        edinet_code='E40316',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＤＩＭＥＮＳＩＯＮ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ディメンションカブシキガイシャ',
        address='港区虎ノ門五丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001202556',
    ),
    'E40317': EdinetCodeEntry(
        edinet_code='E40317',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='シトラスインベストメント合同会社',
        submitter_name_en=None,
        submitter_name_yomi='シトラスインベストメントゴウドウカイシャ',
        address='港区北青山二丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010403027152',
    ),
    'E40318': EdinetCodeEntry(
        edinet_code='E40318',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安達\u3000礼',
        submitter_name_en=None,
        submitter_name_yomi='アダチ\u3000アヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40319': EdinetCodeEntry(
        edinet_code='E40319',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='屋代\u3000浩子',
        submitter_name_en=None,
        submitter_name_yomi='ヤシロ\u3000ヒロコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40320': EdinetCodeEntry(
        edinet_code='E40320',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=15,
        fiscal_year_end=None,
        submitter_name='融和実業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユウワジツギョウカブシキガイシャ',
        address='東京都新宿区西新宿１－２６－２新宿野村ビル３２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011101080805',
    ),
    'E40321': EdinetCodeEntry(
        edinet_code='E40321',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安西\u3000弘道',
        submitter_name_en=None,
        submitter_name_yomi='アンザイ\u3000ヒロミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40322': EdinetCodeEntry(
        edinet_code='E40322',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社Ｏｒｉｇｉｎａｌ３',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャオリジナルスリー',
        address='世田谷区松原一丁目３７番２１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010903004330',
    ),
    'E40323': EdinetCodeEntry(
        edinet_code='E40323',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=24,
        fiscal_year_end=None,
        submitter_name='株式会社シンコーホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='シンコーホールディングス',
        address='杉並区桃井一丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011301022252',
    ),
    'E40325': EdinetCodeEntry(
        edinet_code='E40325',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉田\u3000広美',
        submitter_name_en=None,
        submitter_name_yomi='ヨシダ\u3000ヒロミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40326': EdinetCodeEntry(
        edinet_code='E40326',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩本\u3000達平',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000タッペイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40327': EdinetCodeEntry(
        edinet_code='E40327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='應矢\u3000満弦',
        submitter_name_en=None,
        submitter_name_yomi='オウヤ\u3000ミツル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40328': EdinetCodeEntry(
        edinet_code='E40328',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ガレリア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ガレリアカブシキガイシャ',
        address='渋谷区神宮前６－２３－４\u3000桑野ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001125612',
    ),
    'E40329': EdinetCodeEntry(
        edinet_code='E40329',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＰＭＨ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーピーエムエイチ',
        address='港区新橋２丁目１９番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401154636',
    ),
    'E40333': EdinetCodeEntry(
        edinet_code='E40333',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='越智ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オチホールディングスカブシキカイシャ',
        address='北葛城郡広陵町大字疋相３０９番地２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7150003001255',
    ),
    'E40334': EdinetCodeEntry(
        edinet_code='E40334',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ブッキングリゾート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャブッキングリゾート',
        address='大阪市北区梅田二丁目６番２０号１５階',
        industry='サービス業',
        sec_code='324A0',
        corporate_number='8140001090861',
    ),
    'E40336': EdinetCodeEntry(
        edinet_code='E40336',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='高沢産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タカサワサンギョウカブシキガイシャ',
        address='長野市南千歳一丁目１５番地３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2100001001852',
    ),
    'E40337': EdinetCodeEntry(
        edinet_code='E40337',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯野\u3000佐保里',
        submitter_name_en=None,
        submitter_name_yomi='イイノ\u3000サオリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40338': EdinetCodeEntry(
        edinet_code='E40338',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水上\u3000光啓',
        submitter_name_en=None,
        submitter_name_yomi='ミズカミ\u3000ミツヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40339': EdinetCodeEntry(
        edinet_code='E40339',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='須貝\u3000信',
        submitter_name_en=None,
        submitter_name_yomi='スガイ\u3000アキラ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40340': EdinetCodeEntry(
        edinet_code='E40340',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='須貝\u3000舞',
        submitter_name_en=None,
        submitter_name_yomi='スガイ\u3000マイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40342': EdinetCodeEntry(
        edinet_code='E40342',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金沢\u3000崇',
        submitter_name_en=None,
        submitter_name_yomi='カナザワ\u3000タカシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40345': EdinetCodeEntry(
        edinet_code='E40345',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河合\u3000克也',
        submitter_name_en=None,
        submitter_name_yomi='カワイ\u3000カツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40351': EdinetCodeEntry(
        edinet_code='E40351',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='ＯＬＰ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='オーエルピー\u3000キャピタル\u3000マネジメント\u3000リミテッド',
        address='Ｕｎｉｔ\u3000２４３０，\u3000２４／Ｆ，\u3000Ｌｅｅ\u3000Ｇａｒｄｅｎ\u3000Ｏｎｅ，\u3000３３\u3000Ｈｙｓａｎ\u3000Ａｖｅｎｕｅ，\u3000Ｃａｕｓｅｗａｙ\u3000Ｂａｙ，\u3000Ｈｏｎｇ\u3000Ｋｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40352': EdinetCodeEntry(
        edinet_code='E40352',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古谷\u3000昇',
        submitter_name_en=None,
        submitter_name_yomi='コタニ\u3000ノボル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40353': EdinetCodeEntry(
        edinet_code='E40353',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='津川\u3000佳代子',
        submitter_name_en=None,
        submitter_name_yomi='ツガワ\u3000カヨコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40354': EdinetCodeEntry(
        edinet_code='E40354',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=497,
        fiscal_year_end='2月末日',
        submitter_name='株式会社フライヤー',
        submitter_name_en='Flier Inc.',
        submitter_name_yomi='カブシキガイシャフライヤー',
        address='千代田区一ツ橋一丁目１番１号',
        industry='情報・通信業',
        sec_code='323A0',
        corporate_number='1011001095283',
    ),
    'E40356': EdinetCodeEntry(
        edinet_code='E40356',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平儀野\u3000好美',
        submitter_name_en=None,
        submitter_name_yomi='ヒラギノ\u3000ヨシミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40357': EdinetCodeEntry(
        edinet_code='E40357',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴村\u3000淳',
        submitter_name_en=None,
        submitter_name_yomi='スズムラ\u3000ジュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40359': EdinetCodeEntry(
        edinet_code='E40359',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社メイホク',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメイホク',
        address='稲沢市国府宮二丁目８番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180001158308',
    ),
    'E40360': EdinetCodeEntry(
        edinet_code='E40360',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上野\u3000公嗣',
        submitter_name_en=None,
        submitter_name_yomi='ウエノ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40361': EdinetCodeEntry(
        edinet_code='E40361',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃｏｒｄｉａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コーディアルカブシキガイシャ',
        address='淀川区西中島１丁目９番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001226969',
    ),
    'E40363': EdinetCodeEntry(
        edinet_code='E40363',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＢＣＰＥ\u3000Ｐａｎｇｅａ\u3000Ｃａｙｍａｎ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーピーイーパンゲアケイマンエルピー',
        address='ＰＯ\u3000Ｂｏｘ\u3000３０９，\u3000Ｕｇｌａｎｄ\u3000Ｈｏｕｓｅ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－１１０４，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40367': EdinetCodeEntry(
        edinet_code='E40367',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新井\u3000元行',
        submitter_name_en=None,
        submitter_name_yomi='アライ\u3000モトユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40368': EdinetCodeEntry(
        edinet_code='E40368',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=512,
        fiscal_year_end=None,
        submitter_name='ＣＯＴＴＯＮＦＡＩＲ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='コットンフェア\u3000リミテッド',
        address='２５\u3000Ｇｕｚｍａｎ\u3000Ｓｔｒｅｅｔ，\u3000Ｂｅｌａｍａ\u3000Ｐｈａｓｅ\u3000１，\u3000Ｂｅｌｉｚｅ\u3000Ｃｉｔｙ，\u3000Ｂｅｌｉｚｅ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40371': EdinetCodeEntry(
        edinet_code='E40371',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='根本\u3000武',
        submitter_name_en=None,
        submitter_name_yomi='ネモト\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40372': EdinetCodeEntry(
        edinet_code='E40372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='遠藤\u3000幸一',
        submitter_name_en=None,
        submitter_name_yomi='エンドウ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40373': EdinetCodeEntry(
        edinet_code='E40373',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=752550,
        fiscal_year_end=None,
        submitter_name='セールスフォース・ベンチャーズ・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='セールスフォースベンチャーズエルエルシー',
        address='アメリカ合衆国カリフォルニア州サンフランシスコ市４１５ミッション・ストリート、セールスフォース・タワー３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40375': EdinetCodeEntry(
        edinet_code='E40375',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='唐橋\u3000孝子',
        submitter_name_en=None,
        submitter_name_yomi='カラハシ\u3000タカコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40376': EdinetCodeEntry(
        edinet_code='E40376',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='唐橋\u3000和男',
        submitter_name_en=None,
        submitter_name_yomi='カラハシ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40377': EdinetCodeEntry(
        edinet_code='E40377',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000俊',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000シュン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40381': EdinetCodeEntry(
        edinet_code='E40381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤\u3000正幸',
        submitter_name_en=None,
        submitter_name_yomi='トウ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40383': EdinetCodeEntry(
        edinet_code='E40383',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7183,
        fiscal_year_end=None,
        submitter_name='ＬＥＯＭＯ，ｉｎｃ',
        submitter_name_en=None,
        submitter_name_yomi='レオモインク',
        address='３２００\u3000Ｃａｒｂｏｎ\u3000Ｐｌａｃｅ\u3000Ｓｕｉｔｅ\u3000１００，\u3000Ｂｏｕｌｄｅｒ，\u3000ＣＯ\u3000ＵＳＡ\u3000８０３０１',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40386': EdinetCodeEntry(
        edinet_code='E40386',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＹｕｉＭ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユイム',
        address='新宿区西新宿１－１４－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011101069450',
    ),
    'E40391': EdinetCodeEntry(
        edinet_code='E40391',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='野﨑\u3000雄一',
        submitter_name_en=None,
        submitter_name_yomi='ノザキ\u3000ユウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40392': EdinetCodeEntry(
        edinet_code='E40392',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ヒューマン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒューマンカブシキガイシャ',
        address='大阪市中央区安土町２丁目３番１３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1120001124033',
    ),
    'E40393': EdinetCodeEntry(
        edinet_code='E40393',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社クールトラスト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクールトラスト',
        address='千代田区丸の内一丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001134970',
    ),
    'E40396': EdinetCodeEntry(
        edinet_code='E40396',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｅｉｇｈｔ\u3000Ｒｏａｄｓ\u3000Ｖｅｎｔｕｒｅｓ\u3000Ｊａｐａｎ\u3000ＩＩ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='エイトローズ\u3000ヴェンチャーズ\u3000ジャパン\u3000ツー\u3000エルピー',
        address='ペンブローク・ホール、４２クロウレーン、ペンブローグ・エイチエム１９、バミューダ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40398': EdinetCodeEntry(
        edinet_code='E40398',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='1月末日',
        submitter_name='株式会社ＴＥＮＴＩＡＬ',
        submitter_name_en='TENTIAL Inc.',
        submitter_name_yomi='カブシキカイシャテンシャル',
        address='品川区北品川六丁目７番２９号',
        industry='小売業',
        sec_code='325A0',
        corporate_number='9011001120604',
    ),
    'E40399': EdinetCodeEntry(
        edinet_code='E40399',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＴａｌｅｎｔＸ',
        submitter_name_en='TalentX Inc.',
        submitter_name_yomi='カブシキカイシャタレントエックス',
        address='新宿区神楽坂４－８\u3000神楽坂プラザビルＧ階',
        industry='情報・通信業',
        sec_code='330A0',
        corporate_number='3010001192221',
    ),
    'E40400': EdinetCodeEntry(
        edinet_code='E40400',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月末日',
        submitter_name='ミーク株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミークカブシキカイシャ',
        address='渋谷区渋谷三丁目１０番１３号',
        industry='情報・通信業',
        sec_code='332A0',
        corporate_number='5010701037252',
    ),
    'E40401': EdinetCodeEntry(
        edinet_code='E40401',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='１２\u3000Ｗｅｓｔ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＰ',
        submitter_name_en=None,
        submitter_name_yomi='トゥエルブ\u3000ウエスト\u3000キャピタル\u3000マネジメント\u3000エルピー',
        address='アメリカ合衆国、１９８０８デラウェア州、ニューカッスル郡、ウィルミントン、センターヴィル・ロード２７１１、スイート４００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40402': EdinetCodeEntry(
        edinet_code='E40402',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='武田\u3000毅',
        submitter_name_en=None,
        submitter_name_yomi='タケダ\u3000ツヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40403': EdinetCodeEntry(
        edinet_code='E40403',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=54,
        fiscal_year_end=None,
        submitter_name='株式会社赤錆コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアカサビコーポレーション',
        address='姫路市夢前町杉之内２６８番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8140002054287',
    ),
    'E40407': EdinetCodeEntry(
        edinet_code='E40407',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='篠﨑\u3000晃一',
        submitter_name_en=None,
        submitter_name_yomi='シノザキ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40408': EdinetCodeEntry(
        edinet_code='E40408',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=524,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＩＡＣＥトラベル',
        submitter_name_en='IACE TRAVEL Corporation.',
        submitter_name_yomi='カブシキガイシャアイエーシーイートラベル',
        address='中央区日本橋馬喰町一丁目１４番５号',
        industry='サービス業',
        sec_code='343A0',
        corporate_number='7010001128717',
    ),
    'E40409': EdinetCodeEntry(
        edinet_code='E40409',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='灰田\u3000俊也',
        submitter_name_en=None,
        submitter_name_yomi='ハイダ\u3000トシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40410': EdinetCodeEntry(
        edinet_code='E40410',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='シー・シックス・エイト株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーシックスエイトカブシキガイシャ',
        address='千代田区丸の内二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001251216',
    ),
    'E40411': EdinetCodeEntry(
        edinet_code='E40411',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='湯沢株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユザワカブシキガイシャ',
        address='渋谷区渋谷二丁目１９番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010601060823',
    ),
    'E40412': EdinetCodeEntry(
        edinet_code='E40412',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社ＬＥＲＺ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエルイーアールゼット',
        address='渋谷区円山町３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401187276',
    ),
    'E40413': EdinetCodeEntry(
        edinet_code='E40413',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃ\u3000Ｈｏｌｄｉｎｇｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーホールディングスカブシキガイシャ',
        address='千代田区内幸町一丁目３番３号内幸町ダイビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001250823',
    ),
    'E40415': EdinetCodeEntry(
        edinet_code='E40415',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人山種美術財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンヤマタネビジュツザイダン',
        address='渋谷区広尾３－１２－３６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010005018691',
    ),
    'E40416': EdinetCodeEntry(
        edinet_code='E40416',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｋｈｏｏ\u3000Ｊｉｅ\u3000Ｘｉｏｎｇ',
        submitter_name_en=None,
        submitter_name_yomi='クー\u3000ジエ\u3000ション',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40417': EdinetCodeEntry(
        edinet_code='E40417',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｑｕａｒｔｚ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャクオーツ',
        address='岐阜市菅生２丁目６番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001251471',
    ),
    'E40419': EdinetCodeEntry(
        edinet_code='E40419',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西澤\u3000重治',
        submitter_name_en=None,
        submitter_name_yomi='ニシザワ\u3000シゲハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40420': EdinetCodeEntry(
        edinet_code='E40420',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=259,
        fiscal_year_end='3月末日',
        submitter_name='株式会社メディックス',
        submitter_name_en='Medix Inc.',
        submitter_name_yomi='カブシキガイシャメディックス',
        address='千代田区神田神保町１‐１０５',
        industry='サービス業',
        sec_code='331A0',
        corporate_number='7010001030732',
    ),
    'E40421': EdinetCodeEntry(
        edinet_code='E40421',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石坂\u3000裕',
        submitter_name_en=None,
        submitter_name_yomi='イシサカ\u3000ユタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40423': EdinetCodeEntry(
        edinet_code='E40423',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=20,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トヨコー',
        submitter_name_en='TOYOKOH Inc.',
        submitter_name_yomi='カブシキガイシャトヨコー',
        address='富士市青島町３９番地',
        industry='精密機器',
        sec_code='341A0',
        corporate_number='2080101010566',
    ),
    'E40424': EdinetCodeEntry(
        edinet_code='E40424',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='新沼\u3000吾史',
        submitter_name_en=None,
        submitter_name_yomi='ニイヌマ\u3000サトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40425': EdinetCodeEntry(
        edinet_code='E40425',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大内\u3000将伸',
        submitter_name_en=None,
        submitter_name_yomi='オオウチ\u3000マサノブ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40426': EdinetCodeEntry(
        edinet_code='E40426',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松本\u3000眞基子',
        submitter_name_en=None,
        submitter_name_yomi='マツモト\u3000マキコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40427': EdinetCodeEntry(
        edinet_code='E40427',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='Ｃｉｔｃｏ\u3000Ｔｒｕｓｔｅｅｓ（ＵＴ）ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='シトコ\u3000トラスティーズ\u3000ユーティー\u3000リミテッド',
        address='ケイマン諸島、ＫＹ１－１２０５、グランドケイマン、私書箱３１１０６、カマナベイ、ネクサスウェイ８９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40428': EdinetCodeEntry(
        edinet_code='E40428',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三谷\u3000俊介',
        submitter_name_en=None,
        submitter_name_yomi='ミタニ\u3000シュンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40429': EdinetCodeEntry(
        edinet_code='E40429',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=434,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ＺｅｎｍｕＴｅｃｈ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゼンムテック',
        address='東京都中央区新川二丁目２２番１号',
        industry='情報・通信業',
        sec_code='338A0',
        corporate_number='9011001099070',
    ),
    'E40430': EdinetCodeEntry(
        edinet_code='E40430',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=30,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＮＰスレッズオブライト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティエヌピースレッズオブライト',
        address='横浜市港北区新横浜二丁目３番地１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020001116954',
    ),
    'E40431': EdinetCodeEntry(
        edinet_code='E40431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社アベＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアベシー',
        address='鹿児島市下荒田三丁目１０番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6340001025782',
    ),
    'E40432': EdinetCodeEntry(
        edinet_code='E40432',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='ダイナミックマッププラットフォーム株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダイナミックマッププラットフォームカブシキガイシャ',
        address='渋谷区渋谷二丁目１２番４号',
        industry='情報・通信業',
        sec_code='336A0',
        corporate_number='4010401125416',
    ),
    'E40433': EdinetCodeEntry(
        edinet_code='E40433',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=12,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000ミロク興産',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミロクコウサン',
        address='高知市稲荷町１２０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2490001001228',
    ),
    'E40434': EdinetCodeEntry(
        edinet_code='E40434',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社フォーサイト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフォーサイト',
        address='名古屋市中区新栄二丁目２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001251087',
    ),
    'E40435': EdinetCodeEntry(
        edinet_code='E40435',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='桐渕\u3000真人',
        submitter_name_en=None,
        submitter_name_yomi='キリブチ\u3000マサト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40437': EdinetCodeEntry(
        edinet_code='E40437',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=6033,
        fiscal_year_end=None,
        submitter_name='ＳｉｌｖｅｒＣａｐｅ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='シルバーケイプインベストメンツリミテッド',
        address='ケイマン諸島ＫＹ１－１１０３，グランド・ケイマン，ジョージ・タウン，ワン・キャピタル・プレイス４階、ピーオーボックス８４７、トリデント・トラスト・カンパニー（ケイマン）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40440': EdinetCodeEntry(
        edinet_code='E40440',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='伊藤\u3000美由紀',
        submitter_name_en=None,
        submitter_name_yomi='イトウ\u3000ミユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40441': EdinetCodeEntry(
        edinet_code='E40441',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='高瀬\u3000真尚',
        submitter_name_en=None,
        submitter_name_yomi='タカセ\u3000マサナオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40443': EdinetCodeEntry(
        edinet_code='E40443',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000鉄郎',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40444': EdinetCodeEntry(
        edinet_code='E40444',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＫ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーケー',
        address='中央区銀座一丁目１２番４号\u3000Ｎ＆Ｅ\u3000ＢＬＤ．６Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001149641',
    ),
    'E40448': EdinetCodeEntry(
        edinet_code='E40448',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=644,
        fiscal_year_end='2月末日',
        submitter_name='プログレス・テクノロジーズ\u3000グループ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プログレステクノロジーズ\u3000グループカブシキガイシャ',
        address='江東区青海一丁目１番２０号',
        industry='サービス業',
        sec_code='339A0',
        corporate_number='4010401153730',
    ),
    'E40450': EdinetCodeEntry(
        edinet_code='E40450',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土井\u3000正太郎',
        submitter_name_en=None,
        submitter_name_yomi='ドイ\u3000マサタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40451': EdinetCodeEntry(
        edinet_code='E40451',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍｉｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミント',
        address='文京区向丘一丁目１４番２－２０６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1070001042513',
    ),
    'E40452': EdinetCodeEntry(
        edinet_code='E40452',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=35,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ビジュアル・プロセッシング・ジャパン',
        submitter_name_en='Visual Processing Japan Co., Ltd.',
        submitter_name_yomi='カブシキガイシャビジュアルプロセッシングジャパン',
        address='渋谷区恵比寿四丁目２０番７号\u3000恵比寿ガーデンプレイスセンタープラザＢ１',
        industry='情報・通信業',
        sec_code='334A0',
        corporate_number='9011001019532',
    ),
    'E40453': EdinetCodeEntry(
        edinet_code='E40453',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白井\u3000元',
        submitter_name_en=None,
        submitter_name_yomi='シライ\u3000ハジメ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40454': EdinetCodeEntry(
        edinet_code='E40454',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊澤\u3000一晃',
        submitter_name_en=None,
        submitter_name_yomi='トヨサワ\u3000カズアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40455': EdinetCodeEntry(
        edinet_code='E40455',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｋｅｙｓｔｏｎｅ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000Ｈｏｌｄｉｎｇｓ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='キーストーン\u3000インベストメント\u3000ホールディングス\u3000エル\u3000ピー',
        address='ケイマン諸島、グランド・ケイマンＫＹ１－９００８、ジョージ・タウン、エルギン・アべニュー１９０、ウォーカース・コーポレート・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40456': EdinetCodeEntry(
        edinet_code='E40456',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=109312,
        fiscal_year_end=None,
        submitter_name='三菱ＵＦＪニコス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミツビシユーエフジェイニコスカブシキカイシャ',
        address='文京区本郷三丁目３３番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001000016',
    ),
    'E40458': EdinetCodeEntry(
        edinet_code='E40458',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='谷\u3000憲三朗',
        submitter_name_en=None,
        submitter_name_yomi='タニ\u3000ケンザブロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40459': EdinetCodeEntry(
        edinet_code='E40459',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土方\u3000康基',
        submitter_name_en=None,
        submitter_name_yomi='ヒジカタ\u3000ヤスキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40460': EdinetCodeEntry(
        edinet_code='E40460',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='新光電気工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンコウデンキコウギョウカブシキガイシャ',
        address='長野市小島田町８０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401177555',
    ),
    'E40461': EdinetCodeEntry(
        edinet_code='E40461',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社シエルトコミュニケーションズ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシエルトコミュニケーションズ',
        address='世田谷区代沢二丁目４０番１号\u3000ディアナコート代沢４０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010901054277',
    ),
    'E40464': EdinetCodeEntry(
        edinet_code='E40464',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='エス・エヌ・ホールディングス有限会社',
        submitter_name_en=None,
        submitter_name_yomi='エスエヌホールディングスユウゲンカイシャ',
        address='京丹後市大宮町口大野８８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9130002034025',
    ),
    'E40466': EdinetCodeEntry(
        edinet_code='E40466',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中西\u3000裕太郎',
        submitter_name_en=None,
        submitter_name_yomi='ナカニシ\u3000ユウタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40467': EdinetCodeEntry(
        edinet_code='E40467',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社タイラコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタイラコーポレーション',
        address='昭島市中神町１１６０－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4012801022829',
    ),
    'E40470': EdinetCodeEntry(
        edinet_code='E40470',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='尹\u3000炯植',
        submitter_name_en=None,
        submitter_name_yomi='ユン\u3000ヒョンシク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40471': EdinetCodeEntry(
        edinet_code='E40471',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='クリムソン\u3000ホワイト\u3000インベストメント\u3000ピーティーイー\u3000リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='クリムソン\u3000ホワイト\u3000インベストメント\u3000ピーティーイー\u3000リミテッド',
        address='シンガポール共和国０６８９１２\u3000キャピタルタワー３７ー０１\u3000ロビンソンロード１６８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40472': EdinetCodeEntry(
        edinet_code='E40472',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鼓呂雲\u3000健造',
        submitter_name_en=None,
        submitter_name_yomi='コロン\u3000ケンゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40474': EdinetCodeEntry(
        edinet_code='E40474',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＲＴＳ－３株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アーツスリーカブシキガイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401187545',
    ),
    'E40475': EdinetCodeEntry(
        edinet_code='E40475',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＢＦアクセラレーション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムビーエフアクセラレーションカブシキガイシャ',
        address='千代田区丸の内一丁目１１番１号パシフィックセンチュリープレイス丸の内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001252063',
    ),
    'E40476': EdinetCodeEntry(
        edinet_code='E40476',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長澤\u3000信治',
        submitter_name_en=None,
        submitter_name_yomi='ナガサワ\u3000シンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40477': EdinetCodeEntry(
        edinet_code='E40477',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=267,
        fiscal_year_end='9月30日',
        submitter_name='株式会社ミライロ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミライロ',
        address='大阪市淀川区西中島３丁目８番１５号',
        industry='サービス業',
        sec_code='335A0',
        corporate_number='4120001144623',
    ),
    'E40478': EdinetCodeEntry(
        edinet_code='E40478',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－９２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャビーシージェイナインティーツー',
        address='千代田区丸の内一丁目１番１号\u3000パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001250742',
    ),
    'E40481': EdinetCodeEntry(
        edinet_code='E40481',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000祐輔',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40482': EdinetCodeEntry(
        edinet_code='E40482',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='垣内\u3000俊哉',
        submitter_name_en=None,
        submitter_name_yomi='カキウチ\u3000トシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40483': EdinetCodeEntry(
        edinet_code='E40483',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1000,
        fiscal_year_end=None,
        submitter_name='日揮株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッキカブシキカイシャ',
        address='横浜市西区みなとみらい２－３－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001036818',
    ),
    'E40485': EdinetCodeEntry(
        edinet_code='E40485',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＭＨ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエムエイチ',
        address='仙台市青葉区錦町二丁目４番６２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1370003006931',
    ),
    'E40487': EdinetCodeEntry(
        edinet_code='E40487',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=207,
        fiscal_year_end=None,
        submitter_name='インディペンデント\u3000フランチャイズ\u3000パートナーズ\u3000エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='インディペンデント\u3000フランチャイズ\u3000パートナーズ\u3000エルエルピー',
        address='Ｌｅｖｅｌ\u3000１，\u3000１０\u3000Ｐｏｒｔｍａｎ\u3000Ｓｑｕａｒｅ\u3000Ｌｏｎｄｏｎ，\u3000Ｕｎｉｔｅｄ\u3000Ｋｉｎｇｄｏｍ\u3000ｏｆ\u3000Ｇｒｅａｔ\u3000Ｂｒｉｔａｉｎ\u3000ａｎｄ\u3000Ｎｏｒｔｈｅｒｎ\u3000Ｉｒｅｌａｎｄ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40488': EdinetCodeEntry(
        edinet_code='E40488',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='楠田\u3000恵則',
        submitter_name_en=None,
        submitter_name_yomi='クスダ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40489': EdinetCodeEntry(
        edinet_code='E40489',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＧ２７',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェージーニジュウナナ',
        address='港区虎ノ門一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401187299',
    ),
    'E40490': EdinetCodeEntry(
        edinet_code='E40490',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三津原\u3000陽子',
        submitter_name_en=None,
        submitter_name_yomi='ミツハラ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40492': EdinetCodeEntry(
        edinet_code='E40492',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='合同会社ＣＹＧＮＵＳ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャシグナス',
        address='中央区日本橋蛎殻町二丁目１１番３号日本橋水天宮ビル３階ＧＣＭアセットマネジメント株式会社内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403025943',
    ),
    'E40494': EdinetCodeEntry(
        edinet_code='E40494',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ベーア・ディミトリー・フィリップ',
        submitter_name_en=None,
        submitter_name_yomi='ベーア\u3000ディミトリー\u3000フィリップ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40495': EdinetCodeEntry(
        edinet_code='E40495',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＷＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジェイダブルティカブシキガイシャ',
        address='千代田区大手町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001251423',
    ),
    'E40498': EdinetCodeEntry(
        edinet_code='E40498',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000貴史',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タカフミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40499': EdinetCodeEntry(
        edinet_code='E40499',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小谷中\u3000茂樹',
        submitter_name_en=None,
        submitter_name_yomi='コヤナカ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40500': EdinetCodeEntry(
        edinet_code='E40500',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='株式会社アクセルスペースホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアクセルスペースホールディングス',
        address='中央区日本橋本町三丁目３番３号',
        industry='情報・通信業',
        sec_code='402A0',
        corporate_number='1010001207963',
    ),
    'E40504': EdinetCodeEntry(
        edinet_code='E40504',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笠原\u3000浩',
        submitter_name_en=None,
        submitter_name_yomi='カサハラ\u3000ヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40505': EdinetCodeEntry(
        edinet_code='E40505',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=1139,
        fiscal_year_end='7月31日',
        submitter_name='デジタルグリッド株式会社',
        submitter_name_en=None,
        submitter_name_yomi='デジタルグリッドカブシキガイシャ',
        address='港区赤坂一丁目７番１号',
        industry='電気・ガス業',
        sec_code='350A0',
        corporate_number='4010001187063',
    ),
    'E40506': EdinetCodeEntry(
        edinet_code='E40506',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＵＮＲＩＳＥ\u3000ＯＲＩＥＮＴＡＬ\u3000ＣＡＰＩＴＡＬ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='サンライズオリエンタルキャピタル',
        address='２\u3000ＶＥＮＴＵＲＥ\u3000ＤＲＩＶＥ，＃１１－３１，ＶＩＳＩＯＮ\u3000ＥＸＣＨＡＮＧＥ，ＳＩＮＧＡＰＯＲＥ\u3000６０８５２６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40507': EdinetCodeEntry(
        edinet_code='E40507',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=400,
        fiscal_year_end=None,
        submitter_name='ソニーセミコンダクタソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソニーセミコンダクタソリューションズカブシキガイシャ',
        address='厚木市旭町四丁目１４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7021001057797',
    ),
    'E40508': EdinetCodeEntry(
        edinet_code='E40508',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人ヨコタ',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンヨコタ',
        address='広島市中区南吉島一丁目３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9240005015886',
    ),
    'E40510': EdinetCodeEntry(
        edinet_code='E40510',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='ＩＡＰＦ２株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイエーピーエフツーカブシキガイシャ',
        address='港区虎ノ門五丁目１３番１号\u3000虎ノ門４０ＭＴビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401188442',
    ),
    'E40512': EdinetCodeEntry(
        edinet_code='E40512',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=50,
        fiscal_year_end='12月末日',
        submitter_name='株式会社エージェントＩＧホールディングス',
        submitter_name_en='Agent IG Holdings Inc.',
        submitter_name_yomi='エージェントアイジーホールディングス',
        address='新宿区市谷本村町３番２９号',
        industry='保険業',
        sec_code='377A0',
        corporate_number='3011101112366',
    ),
    'E40513': EdinetCodeEntry(
        edinet_code='E40513',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='勝野\u3000仁視',
        submitter_name_en=None,
        submitter_name_yomi='カツノ\u3000ヒトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40514': EdinetCodeEntry(
        edinet_code='E40514',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='民野\u3000剛郎',
        submitter_name_en=None,
        submitter_name_yomi='タミノ\u3000タケロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40516': EdinetCodeEntry(
        edinet_code='E40516',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=67,
        fiscal_year_end='5月31日',
        submitter_name='エレベーターコミュニケーションズ株式会社',
        submitter_name_en='Elevator Communications Co.,Ltd.',
        submitter_name_yomi='エレベーターコミュニケーションズカブシキカイシャ',
        address='品川区南大井六丁目１６番１６号',
        industry='サービス業',
        sec_code='353A0',
        corporate_number='5010801017897',
    ),
    'E40518': EdinetCodeEntry(
        edinet_code='E40518',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大賀\u3000康史',
        submitter_name_en=None,
        submitter_name_yomi='オオガ\u3000ヤスシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40519': EdinetCodeEntry(
        edinet_code='E40519',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='奥村晋一商会株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オクムラシンイチショウカイカブシキガイシャ',
        address='東近江市八日市清水３丁目１番１９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2160001025730',
    ),
    'E40520': EdinetCodeEntry(
        edinet_code='E40520',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='峯村\u3000竜太',
        submitter_name_en=None,
        submitter_name_yomi='ミネムラ\u3000リュウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40522': EdinetCodeEntry(
        edinet_code='E40522',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=148,
        fiscal_year_end=None,
        submitter_name='ウィンボンド・エレクトロニクス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウィンボンドエレクトロニクスカブシキガイシャ',
        address='横浜市港北区新横浜２－３－１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7020001038007',
    ),
    'E40526': EdinetCodeEntry(
        edinet_code='E40526',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＰ\u3000Ｉｎｔｅｒｎａｔｉｏｎａｌ\u3000ＶＩＩ\u3000ＧＰ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='エーピー\u3000インターナショナル\u3000セブン\u3000ジーピー\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－９００８，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40527': EdinetCodeEntry(
        edinet_code='E40527',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＣＭ\u3000ＶＩＩ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='シーシーエム\u3000セブン\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００８\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40528': EdinetCodeEntry(
        edinet_code='E40528',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＪＩＰ\u3000（ＡＰ）\u3000ＶＩＩ，\u3000Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='シージェーアイピー\u3000エイピー\u3000セブン\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００８\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40529': EdinetCodeEntry(
        edinet_code='E40529',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＢＯ\u3000（ＡＰ）\u3000ＶＩＩ，Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='ジェービーオー\u3000エーピー\u3000セブン\u3000インク',
        address='１９０\u3000Ｅｌｇｉｎ\u3000Ａｖｅｎｕｅ，\u3000Ｇｅｏｒｇｅ\u3000Ｔｏｗｎ，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ，\u3000ＫＹ１－９００８\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40531': EdinetCodeEntry(
        edinet_code='E40531',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='株式会社フジトランスコーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャフジトランスコーポレーション',
        address='名古屋市港区入船一丁目７番４１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4180001007287',
    ),
    'E40532': EdinetCodeEntry(
        edinet_code='E40532',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='間山\u3000弘造',
        submitter_name_en=None,
        submitter_name_yomi='マヤマ\u3000コウゾウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40535': EdinetCodeEntry(
        edinet_code='E40535',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水野\u3000昌広',
        submitter_name_en=None,
        submitter_name_yomi='ミズノ\u3000マサヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40536': EdinetCodeEntry(
        edinet_code='E40536',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永門\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ナガト\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40537': EdinetCodeEntry(
        edinet_code='E40537',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小谷中\u3000一樹',
        submitter_name_en=None,
        submitter_name_yomi='コヤナカ\u3000カズキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40540': EdinetCodeEntry(
        edinet_code='E40540',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松原\u3000哲朗',
        submitter_name_en=None,
        submitter_name_yomi='マツバラ\u3000テツロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40541': EdinetCodeEntry(
        edinet_code='E40541',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=700000,
        fiscal_year_end=None,
        submitter_name='日本郵便株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンユウビンカブシキガイシャ',
        address='千代田区大手町二丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001112577',
    ),
    'E40542': EdinetCodeEntry(
        edinet_code='E40542',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=142323,
        fiscal_year_end=None,
        submitter_name='株式会社海外交通・都市開発事業支援機構',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャカイガイコウツウトシカイハツジギョウシエンキコウ',
        address='千代田区丸の内二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001163675',
    ),
    'E40543': EdinetCodeEntry(
        edinet_code='E40543',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＬＷＬホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エルダブリューエルホールディングスカブシキカイシャ',
        address='千代田区麹町一丁目１２番地１号住友不動産ふくおか半蔵門ビル３階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001252824',
    ),
    'E40546': EdinetCodeEntry(
        edinet_code='E40546',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＬＯＩＶＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャロイブ',
        address='札幌市北区北七条西四丁目５番地１',
        industry='サービス業',
        sec_code='352A0',
        corporate_number='7430001038015',
    ),
    'E40550': EdinetCodeEntry(
        edinet_code='E40550',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000正則',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40551': EdinetCodeEntry(
        edinet_code='E40551',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社Ｓバンク',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャエスバンク',
        address='千代田区大手町一丁目２番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003046668',
    ),
    'E40554': EdinetCodeEntry(
        edinet_code='E40554',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社パロマ・リームホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャパロマリームホールディングス',
        address='千代田区丸の内一丁目８番３号丸の内トラストタワー本館７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001239015',
    ),
    'E40555': EdinetCodeEntry(
        edinet_code='E40555',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山下\u3000文明',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000フミアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40556': EdinetCodeEntry(
        edinet_code='E40556',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=29600,
        fiscal_year_end=None,
        submitter_name='ニューホライズン４号投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='ニューホライズンヨンゴウトウシジギョウユウゲンセキニンクミアイ',
        address='港区西新橋二丁目８番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40557': EdinetCodeEntry(
        edinet_code='E40557',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='馬見塚\u3000讓',
        submitter_name_en=None,
        submitter_name_yomi='マミヅカ\u3000ユズル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40558': EdinetCodeEntry(
        edinet_code='E40558',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社あけぼの',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアケボノ',
        address='名古屋市名東区貴船二丁目１８０９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001135762',
    ),
    'E40559': EdinetCodeEntry(
        edinet_code='E40559',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=229,
        fiscal_year_end=None,
        submitter_name='株式会社テクノスマイル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャテクノスマイル',
        address='宮若市竹原２３６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6290801014940',
    ),
    'E40563': EdinetCodeEntry(
        edinet_code='E40563',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1464,
        fiscal_year_end=None,
        submitter_name='エイチ・ケー・イノエン・コーポレーション',
        submitter_name_en=None,
        submitter_name_yomi='エイチケーイノエンコーポレーション',
        address='忠清北道清州市興徳区五松邑五松生命二路２３９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40564': EdinetCodeEntry(
        edinet_code='E40564',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＺＵＵ\u3000Ｆｕｎｄｅｒｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ズーファンダーズカブシキガイシャ',
        address='港区麻布台１丁目３番１号麻布台ヒルズ森ＪＰタワー４６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3011001127588',
    ),
    'E40565': EdinetCodeEntry(
        edinet_code='E40565',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＢＲＯＯＫＬＡＮＤＳ\u3000ＦＵＮＤ\u3000ＭＡＮＡＧＥＭＥＮＴ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ブルックランズ\u3000ファンド\u3000マネジメント\u3000リミテッド',
        address='４\u3000Ｃａｖｅｎｄｉｓｈ\u3000Ｓｑｕａｒｅ\u3000Ｌｏｎｄｏｎ\u3000Ｗ１Ｇ\u3000０ＰＧ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40567': EdinetCodeEntry(
        edinet_code='E40567',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000アイエスシー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000アイエスシー',
        address='港区新橋３－４－１０\u3000新橋企画ビル２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001133096',
    ),
    'E40574': EdinetCodeEntry(
        edinet_code='E40574',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='薄田\u3000章博',
        submitter_name_en=None,
        submitter_name_yomi='ススキダ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40575': EdinetCodeEntry(
        edinet_code='E40575',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='村石\u3000誠司',
        submitter_name_en=None,
        submitter_name_yomi='ムライシ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40576': EdinetCodeEntry(
        edinet_code='E40576',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内田\u3000真帆子',
        submitter_name_en=None,
        submitter_name_yomi='ウチダ\u3000マホコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40577': EdinetCodeEntry(
        edinet_code='E40577',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='仲里\u3000一義',
        submitter_name_en=None,
        submitter_name_yomi='ナカザト\u3000カズヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40582': EdinetCodeEntry(
        edinet_code='E40582',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔ・Ｋホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーケイホールディングス',
        address='武蔵野市吉祥寺本町１－３１－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6012401014704',
    ),
    'E40583': EdinetCodeEntry(
        edinet_code='E40583',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='上原\u3000俊彦',
        submitter_name_en=None,
        submitter_name_yomi='ウエハラ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40584': EdinetCodeEntry(
        edinet_code='E40584',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＳＮＦホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エーエスエヌエフホールディングスゴウドウガイシャ',
        address='千代田区丸の内三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010003041811',
    ),
    'E40587': EdinetCodeEntry(
        edinet_code='E40587',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='西本興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニシモトコウサンカブシキカイシャ',
        address='和歌山市西高松一丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4170001010564',
    ),
    'E40588': EdinetCodeEntry(
        edinet_code='E40588',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＡＹ\u3000ＬＥＯ\u3000ＢＲＯＴＨＥＲＳ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='ケイ\u3000レオ\u3000ブラザーズ\u3000リミテッド',
        address='Ｓｕｉｔｅ\u3000３，\u3000Ｇｌｏｂａｌ\u3000Ｖｉｌｌａｇｅ，\u3000Ｊｉｖａｎ’ｓ\u3000Ｃｏｍｐｌｅｘ，\u3000Ｍｏｎｔ\u3000Ｆｌｅｕｒｉ，Ｍａｈｅ，Ｓｅｙｃｈｅｌｌｅｓ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40589': EdinetCodeEntry(
        edinet_code='E40589',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=850,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＲＩＤＧＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャブリッジ',
        address='千代田区神田和泉町一番地６番１６号\u3000ヤマトビル４０５号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001245227',
    ),
    'E40592': EdinetCodeEntry(
        edinet_code='E40592',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=56,
        fiscal_year_end=None,
        submitter_name='パーム・インベストメント・マネジメント・ピーティーイー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='パームインベストメントマネジメントピーティーイーリミテッド',
        address='シンガポール\u3000２３７９９４、キム・セング・プロムナード１、グレートワールドシティ＃１１－１３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40593': EdinetCodeEntry(
        edinet_code='E40593',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤井\u3000善英',
        submitter_name_en=None,
        submitter_name_yomi='フジイ\u3000ヨシヒデ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40594': EdinetCodeEntry(
        edinet_code='E40594',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='矢野\u3000拓也',
        submitter_name_en=None,
        submitter_name_yomi='ヤノ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40595': EdinetCodeEntry(
        edinet_code='E40595',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田坂\u3000大作',
        submitter_name_en=None,
        submitter_name_yomi='タサカ\u3000ダイサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40596': EdinetCodeEntry(
        edinet_code='E40596',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=310,
        fiscal_year_end=None,
        submitter_name='丸紅Ｉ－ＤＩＧＩＯホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マルベニアイデジオホールディングスカブシキカイシャ',
        address='文京区後楽二丁目６－１\u3000住友不動産飯田橋ファーストタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001234223',
    ),
    'E40597': EdinetCodeEntry(
        edinet_code='E40597',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今村\u3000邦之',
        submitter_name_en=None,
        submitter_name_yomi='イマムラ\u3000クニユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40598': EdinetCodeEntry(
        edinet_code='E40598',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大谷\u3000寛',
        submitter_name_en=None,
        submitter_name_yomi='オオタニヒロシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40599': EdinetCodeEntry(
        edinet_code='E40599',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='徳原\u3000玖哉',
        submitter_name_en=None,
        submitter_name_yomi='トクハラ\u3000キュウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40602': EdinetCodeEntry(
        edinet_code='E40602',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平田\u3000恭平',
        submitter_name_en=None,
        submitter_name_yomi='ヒラタ\u3000キョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40603': EdinetCodeEntry(
        edinet_code='E40603',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永門\u3000優作',
        submitter_name_en=None,
        submitter_name_yomi='ナガト\u3000ユウサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40604': EdinetCodeEntry(
        edinet_code='E40604',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='照井\u3000秀浩',
        submitter_name_en=None,
        submitter_name_yomi='テルイ\u3000ヒデヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40609': EdinetCodeEntry(
        edinet_code='E40609',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='結キャピタル・パートナーズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ユイキャピタルパートナーズカブシキガイシャ',
        address='中央区日本橋小舟町１１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001193931',
    ),
    'E40611': EdinetCodeEntry(
        edinet_code='E40611',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田口\u3000善一',
        submitter_name_en=None,
        submitter_name_yomi='タグチ\u3000ヨシカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40612': EdinetCodeEntry(
        edinet_code='E40612',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡積\u3000正夫',
        submitter_name_en=None,
        submitter_name_yomi='オカヅミ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40614': EdinetCodeEntry(
        edinet_code='E40614',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＴＴデータＳＭＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエヌティティデータエスエムエス',
        address='江東区豊洲３－３－９\u3000豊洲センタービルアネックス３Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010601032678',
    ),
    'E40615': EdinetCodeEntry(
        edinet_code='E40615',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='荻田\u3000剛大',
        submitter_name_en=None,
        submitter_name_yomi='オギタ\u3000タケヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40617': EdinetCodeEntry(
        edinet_code='E40617',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＪＨＹ\u3000ＨＫ\u3000Ｄｅｖｅｌｏｐｍｅｎｔ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ジェイエイチワイエイチケーデベロップメントリミテッド',
        address='香港、湾仔、ヘネシー・ロード２５３－２６１、イージー・コマーシャル・ビルディング１５０２号室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40624': EdinetCodeEntry(
        edinet_code='E40624',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='畑本\u3000裕之',
        submitter_name_en=None,
        submitter_name_yomi='ハタモト\u3000ヒロユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40627': EdinetCodeEntry(
        edinet_code='E40627',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムシー',
        address='港区西新橋３丁目２４番１０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401089605',
    ),
    'E40631': EdinetCodeEntry(
        edinet_code='E40631',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清板大亮',
        submitter_name_en=None,
        submitter_name_yomi='セイタダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40632': EdinetCodeEntry(
        edinet_code='E40632',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000和弘',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000カズヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40633': EdinetCodeEntry(
        edinet_code='E40633',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='豊田\u3000祐介',
        submitter_name_en=None,
        submitter_name_yomi='トヨダ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40634': EdinetCodeEntry(
        edinet_code='E40634',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='近清\u3000拓馬',
        submitter_name_en=None,
        submitter_name_yomi='チカキヨ\u3000タクマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40635': EdinetCodeEntry(
        edinet_code='E40635',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前川\u3000彩香',
        submitter_name_en=None,
        submitter_name_yomi='マエカワ\u3000アヤカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40638': EdinetCodeEntry(
        edinet_code='E40638',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='スターツ信託株式会社',
        submitter_name_en=None,
        submitter_name_yomi='スターツシンタクカブシキカイシャ',
        address='中央区日本橋三丁目１番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001127443',
    ),
    'E40639': EdinetCodeEntry(
        edinet_code='E40639',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小澤\u3000拓',
        submitter_name_en=None,
        submitter_name_yomi='オザワ\u3000タク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40640': EdinetCodeEntry(
        edinet_code='E40640',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='株式会社リップス',
        submitter_name_en='LIPPS CO,.LTD',
        submitter_name_yomi='カブシキカイシャリップス',
        address='渋谷区神宮前三丁目１番３０号',
        industry='化学',
        sec_code='373A0',
        corporate_number='1011001056203',
    ),
    'E40641': EdinetCodeEntry(
        edinet_code='E40641',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000健一郎',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000ケンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40642': EdinetCodeEntry(
        edinet_code='E40642',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=603,
        fiscal_year_end=None,
        submitter_name='Ｃｏｎｔｉｎｅｎｔａｌ\u3000Ｇｅｎｅｒａｌ\u3000Ｉｎｓｕｒａｎｃｅ\u3000Ｃｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='コンチネンタルゼネラルインシュアランスカンパニー',
        address='１１００１\u3000Ｌａｋｅｌｉｎｅ\u3000Ｂｏｕｌｅｖａｒｄ，\u3000Ｓｕｉｔｅ\u3000１２０，\u3000Ａｕｓｔｉｎ，\u3000Ｔｅｘａｓ\u3000７８７１７，\u3000ｔｈｅ\u3000Ｕｎｉｔｅｄ\u3000Ｓｔａｔｅｓ\u3000ｏｆ\u3000Ａｍｅｒｉｃａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40644': EdinetCodeEntry(
        edinet_code='E40644',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＹＡＧＥＯ\u3000Ｅｌｅｃｔｒｏｎｉｃｓ\u3000Ｊａｐａｎ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤゲオ\u3000エレクトロニクス\u3000ジャパンゴウドウガイシャ',
        address='千代田区西神田三丁目８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010003046392',
    ),
    'E40645': EdinetCodeEntry(
        edinet_code='E40645',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ウィル・マネジメント・ツー・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ウィルマネジメントツーリミテッド',
        address='ケイマン諸島ＫＹ１－１１０４グランド・ケイマン、アグランド・ハウス私書箱３０９メープルズ・コーポレート・サービシズ・リミテッド気付',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40648': EdinetCodeEntry(
        edinet_code='E40648',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='8月31日',
        submitter_name='プリモグローバルホールディングス株式会社',
        submitter_name_en='Primo Global Holdings Co., Ltd.',
        submitter_name_yomi='プリモグローバルホールディングスカブシキカイシャ',
        address='中央区銀座５ー１２ー５白鶴ビル４階',
        industry='小売業',
        sec_code='367A0',
        corporate_number='2010001214496',
    ),
    'E40649': EdinetCodeEntry(
        edinet_code='E40649',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ－９８',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイナインティーエイト',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001253823',
    ),
    'E40651': EdinetCodeEntry(
        edinet_code='E40651',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社グローバルエナジー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャグローバルエナジー',
        address='港区東新橋二丁目１番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401146434',
    ),
    'E40652': EdinetCodeEntry(
        edinet_code='E40652',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＡＭＡメディカルサービス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャハマメディカルサービス',
        address='渋谷区恵比寿４－７－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001187311',
    ),
    'E40653': EdinetCodeEntry(
        edinet_code='E40653',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='伊勢興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イセコウサンカブシキカイシャ',
        address='奥州市水沢上姉体一丁目１７番地１２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010801000873',
    ),
    'E40654': EdinetCodeEntry(
        edinet_code='E40654',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社渡辺冷食',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャワタナベレイショク',
        address='鴨川市大里２－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5040001074266',
    ),
    'E40655': EdinetCodeEntry(
        edinet_code='E40655',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=300,
        fiscal_year_end=None,
        submitter_name='横浜キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヨコハマキャピタルカブシキガイシャ',
        address='横浜市西区みなとみらい３－１－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3020001016263',
    ),
    'E40656': EdinetCodeEntry(
        edinet_code='E40656',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='みらい再生支援機構合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ミライサイセイシエンキコウゴウドウガイシャ',
        address='日本橋本町三丁目３番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4020003021087',
    ),
    'E40657': EdinetCodeEntry(
        edinet_code='E40657',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000孝典',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000タカノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40659': EdinetCodeEntry(
        edinet_code='E40659',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＧＴホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティージーティーホールディングス',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001254067',
    ),
    'E40661': EdinetCodeEntry(
        edinet_code='E40661',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒岩\u3000初美',
        submitter_name_en=None,
        submitter_name_yomi='クロイワ\u3000ハツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40662': EdinetCodeEntry(
        edinet_code='E40662',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=2649,
        fiscal_year_end='5月31日',
        submitter_name='株式会社レント',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャレント',
        address='静岡市駿河区国吉田一丁目６番１０号',
        industry='サービス業',
        sec_code='372A0',
        corporate_number='2080001005740',
    ),
    'E40663': EdinetCodeEntry(
        edinet_code='E40663',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊澤\u3000一郎',
        submitter_name_en=None,
        submitter_name_yomi='クマザワ\u3000イチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40668': EdinetCodeEntry(
        edinet_code='E40668',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='3月31日',
        submitter_name='株式会社北里コーポレーション',
        submitter_name_en='Kitazato Corporation',
        submitter_name_yomi='カブシキガイシャキタザトコーポレーション',
        address='富士市柳島１００番地１０',
        industry='精密機器',
        sec_code='368A0',
        corporate_number='9010001108188',
    ),
    'E40669': EdinetCodeEntry(
        edinet_code='E40669',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='井上\u3000太',
        submitter_name_en=None,
        submitter_name_yomi='イノウエ\u3000フトシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40670': EdinetCodeEntry(
        edinet_code='E40670',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='三日月株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ミカヅキカブシキカイシャ',
        address='港区西新橋一丁目２番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401189283',
    ),
    'E40672': EdinetCodeEntry(
        edinet_code='E40672',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='セレス・ファンド・マネジメント（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='セレスファンドマネジメントケイマンリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40674': EdinetCodeEntry(
        edinet_code='E40674',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='2月末日',
        submitter_name='伊澤タオル株式会社',
        submitter_name_en='IZAWA TOWEL CO.,LTD.',
        submitter_name_yomi='イザワタオルカブシキガイシャ',
        address='渋谷区恵比寿西一丁目２６番６号',
        industry='繊維製品',
        sec_code='365A0',
        corporate_number='9010401160598',
    ),
    'E40675': EdinetCodeEntry(
        edinet_code='E40675',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='坂本\u3000哲',
        submitter_name_en=None,
        submitter_name_yomi='サカモト\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40676': EdinetCodeEntry(
        edinet_code='E40676',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＰＣ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスピーシーカブシキガイシャ',
        address='鳥取市西町５丁目１０５番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6270001008142',
    ),
    'E40681': EdinetCodeEntry(
        edinet_code='E40681',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='北里商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キタザトショウジカブシキガイシャ',
        address='富士宮市野中１１４４番地の３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6080101019372',
    ),
    'E40682': EdinetCodeEntry(
        edinet_code='E40682',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｔａｒｉ\u3000Ｃａｐｉｔａｌ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='アタリ\u3000キャピタル\u3000リミテッド',
        address='英領ヴァージン諸島トルトラ、ロードタウン、シー・メドウ・ハウス私書箱１１６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40684': EdinetCodeEntry(
        edinet_code='E40684',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社サンワ電化阿久比',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャサンワデンカアグイ',
        address='知多郡阿久比町大字椋岡字唐松４３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1180001092308',
    ),
    'E40688': EdinetCodeEntry(
        edinet_code='E40688',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10000,
        fiscal_year_end=None,
        submitter_name='株式会社マルハン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマルハン',
        address='京都市上京区出町今出川上る青龍町２３１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3130001003894',
    ),
    'E40690': EdinetCodeEntry(
        edinet_code='E40690',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤川\u3000欣洋',
        submitter_name_en=None,
        submitter_name_yomi='フジカワ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40691': EdinetCodeEntry(
        edinet_code='E40691',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤川\u3000佳織',
        submitter_name_en=None,
        submitter_name_yomi='フジカワ\u3000カオリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40692': EdinetCodeEntry(
        edinet_code='E40692',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='半田\u3000めぐみ',
        submitter_name_en=None,
        submitter_name_yomi='ハンダ\u3000メグミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40693': EdinetCodeEntry(
        edinet_code='E40693',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＭＥＬ\u3000ＣＡＰＩＴＡＬ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='エムイーエルキャピタルリミテッド',
        address='Ｆｌａｔ\u3000Ｅ４，２０Ｆ\u3000Ｓｕｎｗａｙ\u3000Ｇａｒｄｅｎ９８９\u3000Ｋｉｎｇｓ\u3000Ｒｏａｄ\u3000ＱｕａｒｒｙＢａｙ\u3000ＨｏｎｇＫｏｎｇ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40695': EdinetCodeEntry(
        edinet_code='E40695',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=160,
        fiscal_year_end=None,
        submitter_name='霞ヶ関ホテルリート投資法人',
        submitter_name_en=None,
        submitter_name_yomi='カスミガセキホテルリートトウシホウジン',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010005039857',
    ),
    'E40697': EdinetCodeEntry(
        edinet_code='E40697',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＭＴ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエムティーカブシキガイシャ',
        address='千代田区永田町二丁目１１番１号山王パークタワー５階トラスティーズ・コンサルティングＬＬＰ内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401190221',
    ),
    'E40699': EdinetCodeEntry(
        edinet_code='E40699',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ソン\u3000ユウ\u3000ニン（Ｓｕｎ\u3000Ｙｏｕ\u3000Ｎｉｎｇ）',
        submitter_name_en=None,
        submitter_name_yomi='ソン\u3000ユウ\u3000ニン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40701': EdinetCodeEntry(
        edinet_code='E40701',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='樺山\u3000伸一',
        submitter_name_en=None,
        submitter_name_yomi='カバヤマ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40703': EdinetCodeEntry(
        edinet_code='E40703',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=79,
        fiscal_year_end=None,
        submitter_name='ＰＯＴＵＳ\u3000ＣＡＰＩＴＡＬ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ポータスキャピタルプライベートリミテッド',
        address='シンガポール、＃０９ー０６、ゴールドヒルプラザ５１、３０８９００',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40704': EdinetCodeEntry(
        edinet_code='E40704',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ａｋｅｒｕ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャアケル',
        address='世田谷区北沢三丁目２６番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010901050265',
    ),
    'E40706': EdinetCodeEntry(
        edinet_code='E40706',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=498,
        fiscal_year_end=None,
        submitter_name='株式会社写真化学',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャシャシンカガク',
        address='京都市中京区烏丸通二条下ル秋野々町５１８番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7130001003123',
    ),
    'E40708': EdinetCodeEntry(
        edinet_code='E40708',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小村\u3000直克',
        submitter_name_en=None,
        submitter_name_yomi='オムラ\u3000ナオカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40709': EdinetCodeEntry(
        edinet_code='E40709',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小村\u3000洋子',
        submitter_name_en=None,
        submitter_name_yomi='オムラ\u3000ヨウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40710': EdinetCodeEntry(
        edinet_code='E40710',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ライズネックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャライズネックス',
        address='宇治市木幡御蔵山３９番地の４７６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5120001154150',
    ),
    'E40713': EdinetCodeEntry(
        edinet_code='E40713',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＸＩＵＭ\u3000ＣＡＰＩＴＡＬ\u3000ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='アクシウム\u3000キャピタル\u3000ピーティーイー\u3000エルティーディー',
        address='９\u3000ＳＴＲＡＩＴＳ\u3000ＶＩＥＷ，\u3000♯０６－０７，\u3000ＭＡＲＩＮＡ\u3000ＯＮＥ\u3000ＷＥＳＴ\u3000ＴＯＷＥＲ，\u3000ＳＩＮＧＡＰＯＲＥ\u3000０１８９３７（９\u3000ストレイツ・ビュー、♯０６－０７、マリーナ・ワン・ウェスト・タワー、シンガポール\u3000０１８９３７）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40714': EdinetCodeEntry(
        edinet_code='E40714',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=95,
        fiscal_year_end=None,
        submitter_name='株式会社クローバー・ネットワーク・コム',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャクローバーネットワークコム',
        address='港区虎ノ門四丁目３番１号\u3000城山トラストタワー３４階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011001057559',
    ),
    'E40715': EdinetCodeEntry(
        edinet_code='E40715',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=29,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ヒット',
        submitter_name_en='Hit Co., Ltd.',
        submitter_name_yomi='カブシキカイシャヒット',
        address='中央区銀座六丁目１７番１号',
        industry='サービス業',
        sec_code='378A0',
        corporate_number='7010001055143',
    ),
    'E40717': EdinetCodeEntry(
        edinet_code='E40717',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='恒川\u3000裕康',
        submitter_name_en=None,
        submitter_name_yomi='ツネカワ\u3000ヒロヤス',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40718': EdinetCodeEntry(
        edinet_code='E40718',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='恒川\u3000晴美',
        submitter_name_en=None,
        submitter_name_yomi='ツネカワ\u3000ハルミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40719': EdinetCodeEntry(
        edinet_code='E40719',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩崎\u3000元治',
        submitter_name_en=None,
        submitter_name_yomi='イワサキ\u3000モトハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40720': EdinetCodeEntry(
        edinet_code='E40720',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000亘宏',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ノブヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40721': EdinetCodeEntry(
        edinet_code='E40721',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='ヒューリックプロパティソリューション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヒューリックプロパティソリューションカブシキカイシャ',
        address='中央区日本橋大伝馬町７－３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001185394',
    ),
    'E40723': EdinetCodeEntry(
        edinet_code='E40723',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='清水\u3000剛',
        submitter_name_en=None,
        submitter_name_yomi='シミズ\u3000ゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40724': EdinetCodeEntry(
        edinet_code='E40724',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='樺山\u3000玄基',
        submitter_name_en=None,
        submitter_name_yomi='カバヤマ\u3000ゲンキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40725': EdinetCodeEntry(
        edinet_code='E40725',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北村\u3000甲介',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000コウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40727': EdinetCodeEntry(
        edinet_code='E40727',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=5500,
        fiscal_year_end='3月末日',
        submitter_name='富士ユナイトホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フジユナイトホールディングスカブシキガイシャ',
        address='千代田区神田駿河台四丁目３番地（新お茶の水ビルディング１３階）',
        industry='卸売業',
        sec_code='416A0',
        corporate_number='2010001259038',
    ),
    'E40728': EdinetCodeEntry(
        edinet_code='E40728',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｔｈｅ\u3000Ｔｒｕｓｔｅｅｓ\u3000ｏｆ\u3000Ｃｏｌｕｍｂｉａ\u3000Ｕｎｉｖｅｒｓｉｔｙ\u3000ｉｎ\u3000ｔｈｅ\u3000Ｃｉｔｙ\u3000ｏｆ\u3000Ｎｅｗ\u3000Ｙｏｒｋ',
        submitter_name_en=None,
        submitter_name_yomi='ザ\u3000トラスティーズ\u3000オブ\u3000コロンビア\u3000ユニバーシティ\u3000イン\u3000ザ\u3000シティ\u3000オブ\u3000ニューヨーク',
        address='６１５\u3000Ｗｅｓｔ\u3000１３１ｓｔ\u3000Ｓｔｒｅｅｔ，\u3000Ｎｅｗ\u3000Ｙｏｒｋ，\u3000ＮＹ\u3000１００２７－７９２２，\u3000ＵＳＡ（６１５\u3000ウェスト\u3000１３１\u3000ストリート，\u3000ニューヨーク市，\u3000ニューヨーク州\u3000１００２７－７９２２，\u3000アメリカ合衆国）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40729': EdinetCodeEntry(
        edinet_code='E40729',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='ムニノバホールディングス株式会社',
        submitter_name_en='Muninova Holdings Inc.',
        submitter_name_yomi='ムニノバホールディングスカブシキガイシャ',
        address='京都市下京区烏丸通五条上る高砂町３８１－１',
        industry='その他金融業',
        sec_code=None,
        corporate_number=None,
    ),
    'E40730': EdinetCodeEntry(
        edinet_code='E40730',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＩＴ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ａｄｖｉｓｏｒｙ\u3000Ｓｅｒｖｉｃｅｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエムアイティーコーポレートアドバイザリーサビシーズ',
        address='港区虎ノ門１－３－１\u3000東京虎ノ門グローバルスクエア５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001054190',
    ),
    'E40731': EdinetCodeEntry(
        edinet_code='E40731',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安藤\u3000浩二',
        submitter_name_en=None,
        submitter_name_yomi='アンドウ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40732': EdinetCodeEntry(
        edinet_code='E40732',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社ＭＪ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000エムジェイ',
        address='市川市堀之内２－９－２２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1040001092239',
    ),
    'E40734': EdinetCodeEntry(
        edinet_code='E40734',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=86,
        fiscal_year_end=None,
        submitter_name='株式会社ＦＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエフディー',
        address='刈谷市今川町花池３番地１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9180301016438',
    ),
    'E40736': EdinetCodeEntry(
        edinet_code='E40736',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9846,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ブルーゾーンホールディングス',
        submitter_name_en='BLUE ZONES HOLDINGS CO.,LTD.',
        submitter_name_yomi='カブシキガイシャブルーゾーンホールディングス',
        address='川越市新宿町１丁目１０番地１',
        industry='小売業',
        sec_code='417A0',
        corporate_number=None,
    ),
    'E40740': EdinetCodeEntry(
        edinet_code='E40740',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＳＳＫ－Ｊ１',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエヌエスエスケージェーワン',
        address='港区愛宕二丁目５番１号愛宕グリーンヒルズＭＯＲＩタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401189383',
    ),
    'E40742': EdinetCodeEntry(
        edinet_code='E40742',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='イノー・アソシエイツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イノーアソシエイツカブシキガイシャ',
        address='港区赤坂五丁目４番９号赤坂五丁目ビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001229624',
    ),
    'E40743': EdinetCodeEntry(
        edinet_code='E40743',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='エムキャップ十五号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムキャップジュウゴゴウカブシキガイシャ',
        address='千代田区丸の内二丁目７番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001255168',
    ),
    'E40744': EdinetCodeEntry(
        edinet_code='E40744',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山川\u3000伯勇',
        submitter_name_en=None,
        submitter_name_yomi='ヤマカワ\u3000ハクユウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40746': EdinetCodeEntry(
        edinet_code='E40746',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社エンヴィー',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャエンヴィー',
        address='福岡市中央区大名一丁目９番５２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4290003016597',
    ),
    'E40747': EdinetCodeEntry(
        edinet_code='E40747',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮治\u3000友博',
        submitter_name_en=None,
        submitter_name_yomi='ミヤジ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40748': EdinetCodeEntry(
        edinet_code='E40748',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=99,
        fiscal_year_end='4月30日',
        submitter_name='株式会社山忠',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャヤマチュウ',
        address='海部郡大治町大字三本木字柳原１１２番地の３',
        industry='不動産業',
        sec_code='391A0',
        corporate_number='4180001098211',
    ),
    'E40749': EdinetCodeEntry(
        edinet_code='E40749',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北村\u3000常明',
        submitter_name_en=None,
        submitter_name_yomi='キタムラ\u3000ツネアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40750': EdinetCodeEntry(
        edinet_code='E40750',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山﨑\u3000恭裕',
        submitter_name_en=None,
        submitter_name_yomi='ヤマザキ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40751': EdinetCodeEntry(
        edinet_code='E40751',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='湯藤\u3000善行',
        submitter_name_en=None,
        submitter_name_yomi='ユトウ\u3000ヨシユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40753': EdinetCodeEntry(
        edinet_code='E40753',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木村\u3000かおる',
        submitter_name_en=None,
        submitter_name_yomi='キムラ\u3000カオル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40754': EdinetCodeEntry(
        edinet_code='E40754',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＣＧ２５０５株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーシージーニーゴーゼロゴーカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001254982',
    ),
    'E40756': EdinetCodeEntry(
        edinet_code='E40756',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='6月30日',
        submitter_name='株式会社みのや',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミノヤ',
        address='さいたま市中央区大字下落合１０５０番地２',
        industry='小売業',
        sec_code='386A0',
        corporate_number='5030001008183',
    ),
    'E40758': EdinetCodeEntry(
        edinet_code='E40758',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='尾形\u3000優',
        submitter_name_en=None,
        submitter_name_yomi='オガタ\u3000マサル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40759': EdinetCodeEntry(
        edinet_code='E40759',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水越\u3000聖',
        submitter_name_en=None,
        submitter_name_yomi='ミズコシ\u3000サトル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40760': EdinetCodeEntry(
        edinet_code='E40760',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＱＵＥＴＴＡ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='クエタゴウドウガイシャ',
        address='新宿区西新宿２－１－１\u3000新宿三井ビル３０階３００５号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011103015821',
    ),
    'E40761': EdinetCodeEntry(
        edinet_code='E40761',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＯＰＩ・１８株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーピーアイエイティーンカブシキガイシャ',
        address='港区浜松町二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401190011',
    ),
    'E40763': EdinetCodeEntry(
        edinet_code='E40763',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小松\u3000周平',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000シュウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40765': EdinetCodeEntry(
        edinet_code='E40765',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='樋口陽平',
        submitter_name_en=None,
        submitter_name_yomi='ヒグチヨウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40767': EdinetCodeEntry(
        edinet_code='E40767',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='水神\u3000怜良',
        submitter_name_en=None,
        submitter_name_yomi='ミズガミ\u3000サトヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40768': EdinetCodeEntry(
        edinet_code='E40768',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000正男',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000マサオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40769': EdinetCodeEntry(
        edinet_code='E40769',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＵＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーイーディー',
        address='東京都渋谷区道玄坂１丁目１０番８号渋谷道玄坂東急ビル２Ｆ－Ｃ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9011001166317',
    ),
    'E40772': EdinetCodeEntry(
        edinet_code='E40772',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐伯\u3000猛',
        submitter_name_en=None,
        submitter_name_yomi='サイキ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40773': EdinetCodeEntry(
        edinet_code='E40773',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='伊澤キャピタルパートナーズ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='イザワキャピタルパートナーズゴウドウガイシャ',
        address='大阪市住吉区長居東２丁目１３番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120003019980',
    ),
    'E40775': EdinetCodeEntry(
        edinet_code='E40775',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1200,
        fiscal_year_end=None,
        submitter_name='ＫＡＮＤＢ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ケーアンドビー\u3000インベストメント\u3000エルエルシー',
        address='１０３－１５７，ＡＬ\u3000ＭＡＲＡＲＡＬ，ＭＡＲＡＲＲ，ＤＵＢＡＩ，ＵＡＥ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40776': EdinetCodeEntry(
        edinet_code='E40776',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='後藤\u3000邦之',
        submitter_name_en=None,
        submitter_name_yomi='ゴトウ\u3000クニユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40777': EdinetCodeEntry(
        edinet_code='E40777',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=617,
        fiscal_year_end=None,
        submitter_name='サムソン・ロック・キャピタル・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='サムソンロックキャピタルエルエルピー',
        address='英国\u3000Ｗ１Ｆ\u3000７ＪＹ\u3000ロンドン、グレート・マールボロ・ストリート５８',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40778': EdinetCodeEntry(
        edinet_code='E40778',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本\u3000新九郎',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモト\u3000シンクロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40779': EdinetCodeEntry(
        edinet_code='E40779',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＡＥＧＩＳ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャイージス',
        address='千代田区一番町２２－３アデックス一番町ビル４０２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010003047063',
    ),
    'E40780': EdinetCodeEntry(
        edinet_code='E40780',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='安田\u3000周世',
        submitter_name_en=None,
        submitter_name_yomi='ヤスダ\u3000シュウセイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40782': EdinetCodeEntry(
        edinet_code='E40782',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='二木\u3000敦士',
        submitter_name_en=None,
        submitter_name_yomi='フタギ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40784': EdinetCodeEntry(
        edinet_code='E40784',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=332,
        fiscal_year_end='3月31日',
        submitter_name='オルタナ信託株式会社',
        submitter_name_en='ALTERNA TRUST, Ltd.',
        submitter_name_yomi='オルタナシンタクカブシキガイシャ',
        address='東京都中央区日本橋堀留町一丁目９番８号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010001253166',
    ),
    'E40786': EdinetCodeEntry(
        edinet_code='E40786',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社桃の木',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャモモノキ',
        address='千代田区紀尾井町１丁目３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401096548',
    ),
    'E40788': EdinetCodeEntry(
        edinet_code='E40788',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｐｅｎｔａｇｒａｍ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ペンタグラムキャピタルマネジメントカブシキカイシャ',
        address='東京都港区南青山３－１－３６青山丸竹ビル６Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401180278',
    ),
    'E40789': EdinetCodeEntry(
        edinet_code='E40789',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエム',
        address='千代田区有楽町一丁目１３番２号第一生命日比谷ファースト１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401187648',
    ),
    'E40792': EdinetCodeEntry(
        edinet_code='E40792',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='ＧＭＯ\u3000ＴＥＣＨホールディングス株式会社',
        submitter_name_en='GMO TECH Holdings, Inc.',
        submitter_name_yomi='ジーエムオーテックホールディングスカブシキガイシャ',
        address='渋谷区桜丘町２６－１',
        industry='サービス業',
        sec_code='415A0',
        corporate_number='1011001172925',
    ),
    'E40793': EdinetCodeEntry(
        edinet_code='E40793',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='プリモ・インテグラル１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プリモインテグラルワンカブシキカイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001214609',
    ),
    'E40794': EdinetCodeEntry(
        edinet_code='E40794',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='梶谷\u3000眞一郎',
        submitter_name_en=None,
        submitter_name_yomi='カジタニ\u3000シンイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40797': EdinetCodeEntry(
        edinet_code='E40797',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000吉之助',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000ヨシノスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40804': EdinetCodeEntry(
        edinet_code='E40804',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=82,
        fiscal_year_end=None,
        submitter_name='ジャパン・アクティベーション・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ジャパンアクティベーションキャピタルカブシキカイシャ',
        address='港区南青山二丁目５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401175772',
    ),
    'E40806': EdinetCodeEntry(
        edinet_code='E40806',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ケイ・エル・アイ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャケイエルアイ',
        address='福岡市博多区博多駅前三丁目４番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8290001019854',
    ),
    'E40808': EdinetCodeEntry(
        edinet_code='E40808',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='有限会社ユヴェントスホールディングス投資目的会社',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャユヴェントスホールディングストウシモクテキガイシャ',
        address='大韓民国ソウル特別市江南区奉恩寺路２９キル５－４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40809': EdinetCodeEntry(
        edinet_code='E40809',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='センカ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='センカカブシキカイシャ',
        address='大阪市鶴見区放出東１－１７－３４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2120001002023',
    ),
    'E40811': EdinetCodeEntry(
        edinet_code='E40811',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='櫻井金属工業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サクライキンゾクコウギョウカブシキカイシャ',
        address='荒川区荒川１－１４－１１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011501006631',
    ),
    'E40815': EdinetCodeEntry(
        edinet_code='E40815',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社ＩＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアイティ',
        address='大阪市淀川区西中島５丁目１３番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6120001264543',
    ),
    'E40818': EdinetCodeEntry(
        edinet_code='E40818',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='福田産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フクダサンギョウカブシキガイシャ',
        address='千代田区外神田四丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001254773',
    ),
    'E40819': EdinetCodeEntry(
        edinet_code='E40819',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=60,
        fiscal_year_end=None,
        submitter_name='株式会社福々',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフクフク',
        address='千代田区外神田四丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001027861',
    ),
    'E40820': EdinetCodeEntry(
        edinet_code='E40820',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田中\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='タナカ\u3000ヨウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40821': EdinetCodeEntry(
        edinet_code='E40821',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＸＩＡ\u3000ＺＵＩＴＩＮＧ',
        submitter_name_en=None,
        submitter_name_yomi='シア\u3000ズイティン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40822': EdinetCodeEntry(
        edinet_code='E40822',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＯＭＴホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーエムティーホールディングス',
        address='茂原市千沢１０９９－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4040001133568',
    ),
    'E40823': EdinetCodeEntry(
        edinet_code='E40823',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社友',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャユウ',
        address='新宿区西新宿６丁目２５番１３号\u3000フロイントビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001276668',
    ),
    'E40824': EdinetCodeEntry(
        edinet_code='E40824',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松丸\u3000敦之',
        submitter_name_en=None,
        submitter_name_yomi='マツマル\u3000ノブユキ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40828': EdinetCodeEntry(
        edinet_code='E40828',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小野\u3000和雄',
        submitter_name_en=None,
        submitter_name_yomi='オノ\u3000カズオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40829': EdinetCodeEntry(
        edinet_code='E40829',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小野\u3000拓雄',
        submitter_name_en=None,
        submitter_name_yomi='オノ\u3000タクオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40830': EdinetCodeEntry(
        edinet_code='E40830',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｓａｐｐｈｉｒｅｔｅｒｒａ\u3000Ｃａｐｉｔａｌ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='サファイアテラ\u3000キャピタル\u3000エルエルシー',
        address='２００\u3000Ｓ．\u3000Ｗａｃｋｅｒ\u3000Ｄｒ\u3000Ｓｕｉｔｅ．\u3000２６５０\u3000Ｃｈｉｃａｇｏ，\u3000ＩＬ\u3000６０６０６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40831': EdinetCodeEntry(
        edinet_code='E40831',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＰＣＧＶＩー１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ピーシージーシックスワンカブシキガイシャ',
        address='千代田区丸の内一丁目９番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001256034',
    ),
    'E40832': EdinetCodeEntry(
        edinet_code='E40832',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＭｉＹａ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミヤ',
        address='大田区中馬込一丁目８番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010801031488',
    ),
    'E40834': EdinetCodeEntry(
        edinet_code='E40834',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='Ｂｅｎｅｄｉｃｔ\u3000Ｂｅｈ\u3000Ｗｅｉ\u3000Ｈａｏ',
        submitter_name_en=None,
        submitter_name_yomi='ベネディクト\u3000ベイ\u3000ウェイ\u3000ハオ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40835': EdinetCodeEntry(
        edinet_code='E40835',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='五十畑\u3000輝夫',
        submitter_name_en=None,
        submitter_name_yomi='イカハタ\u3000テルオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40848': EdinetCodeEntry(
        edinet_code='E40848',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社キャピタルタイフーン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャキャピタルタイフーン',
        address='港区赤坂二丁目１４番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401138616',
    ),
    'E40849': EdinetCodeEntry(
        edinet_code='E40849',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小川\u3000義隆',
        submitter_name_en=None,
        submitter_name_yomi='オガワ\u3000ヨシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40850': EdinetCodeEntry(
        edinet_code='E40850',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福村\u3000康廣',
        submitter_name_en=None,
        submitter_name_yomi='フクムラ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40851': EdinetCodeEntry(
        edinet_code='E40851',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＣＯＲＥ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコア',
        address='大垣市久徳町１００番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401188724',
    ),
    'E40852': EdinetCodeEntry(
        edinet_code='E40852',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＴＭ\u3000Ｃａｐｉｔａｌ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムティーエムキャピタルカブシキガイシャ',
        address='港区南青山六丁目２番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401172256',
    ),
    'E40853': EdinetCodeEntry(
        edinet_code='E40853',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福村\u3000京子',
        submitter_name_en=None,
        submitter_name_yomi='フクムラ\u3000キョウコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40854': EdinetCodeEntry(
        edinet_code='E40854',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='5月31日',
        submitter_name='株式会社ＱＰＳホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャキューピーエスホールディングス',
        address='福岡市中央区天神１ー１５ー３５',
        industry='情報・通信業',
        sec_code='464A0',
        corporate_number='2290001112391',
    ),
    'E40860': EdinetCodeEntry(
        edinet_code='E40860',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='正木\u3000宏和',
        submitter_name_en=None,
        submitter_name_yomi='マサキ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40863': EdinetCodeEntry(
        edinet_code='E40863',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='金田\u3000卓也',
        submitter_name_en=None,
        submitter_name_yomi='カネダ\u3000タクヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40865': EdinetCodeEntry(
        edinet_code='E40865',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=172,
        fiscal_year_end='6月30日',
        submitter_name='株式会社ＵＮＩＣＯＮホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユニコンホールディングス',
        address='仙台市宮城野区榴岡二丁目５番３０号仙台イーストフロントビル５階',
        industry='建設業',
        sec_code='407A0',
        corporate_number='5010001200089',
    ),
    'E40866': EdinetCodeEntry(
        edinet_code='E40866',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='志村\u3000英樹',
        submitter_name_en=None,
        submitter_name_yomi='シムラ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40868': EdinetCodeEntry(
        edinet_code='E40868',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=250,
        fiscal_year_end=None,
        submitter_name='株式会社丸の内キャピタル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマルノウチキャピタル',
        address='千代田区丸の内２丁目７ー２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001172492',
    ),
    'E40869': EdinetCodeEntry(
        edinet_code='E40869',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＥＮＪＩＮ\u3000ＣＡＰＩＴＡＬ\u3000ＰＴＹ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='センジン\u3000キャピタル\u3000ピーティーワイ\u3000リミテッド',
        address='オーストラリア連邦ニューサウスウェールズ州２０００\u3000シドニー\u3000カッスルリー通り９－１３\u3000レベル１７',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40871': EdinetCodeEntry(
        edinet_code='E40871',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｓｍｏａｋ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='スモーク\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='６６５０\u3000Ｒｉｖｅｒｓ\u3000Ａｖｅ，\u3000Ｓｕｉｔｅ\u3000１００，\u3000Ｃｈａｒｌｅｓｔｏｎ，\u3000Ｓｏｕｔｈ\u3000Ｃａｒｏｌｉｎａ，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40872': EdinetCodeEntry(
        edinet_code='E40872',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＣＢ‐１４株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーシービージュウヨンカブシキカイシャ',
        address='千代田区大手町一丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001256651',
    ),
    'E40873': EdinetCodeEntry(
        edinet_code='E40873',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ウエムラ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャウエムラ',
        address='薩摩川内市西向田町５番１１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6340001008465',
    ),
    'E40874': EdinetCodeEntry(
        edinet_code='E40874',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='ポットラック株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ポットラックカブシキガイシャ',
        address='品川区上大崎二丁目１４番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011001070560',
    ),
    'E40875': EdinetCodeEntry(
        edinet_code='E40875',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社豊崎会計事務所',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャトヨサキカイケイジムショ',
        address='中央区銀座四丁目９番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001065642',
    ),
    'E40876': EdinetCodeEntry(
        edinet_code='E40876',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ａｋａｔｓｕｋｉ\u3000Ｃａｐｉｔａｌ\u3000Ｗｏｒｋｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アカツキキャピタルワークスカブシキガイシャ',
        address='大阪市北区梅田一丁目１番３号大阪駅前第３ビル２９階１－１ー１号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001266699',
    ),
    'E40877': EdinetCodeEntry(
        edinet_code='E40877',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＮＳＳＫ－Ｊ２',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャエヌエスエスケージェーツー',
        address='港区愛宕二丁目５番１号愛宕グリーンヒルズＭＯＲＩタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401189384',
    ),
    'E40878': EdinetCodeEntry(
        edinet_code='E40878',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='ヤンマー建機株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤンマーケンキカブシキカイシャ',
        address='筑後市大字熊野１７１７番地－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8290001047673',
    ),
    'E40879': EdinetCodeEntry(
        edinet_code='E40879',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=413,
        fiscal_year_end='5月31日',
        submitter_name='株式会社インテリックスホールディングス',
        submitter_name_en='INTELLEX HOLDINGS Co.,Ltd.',
        submitter_name_yomi='カブシキガイシャインテリックスホールディングス',
        address='渋谷区桜丘町３－２',
        industry='不動産業',
        sec_code='463A0',
        corporate_number='5011001174216',
    ),
    'E40882': EdinetCodeEntry(
        edinet_code='E40882',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉之原\u3000祥二',
        submitter_name_en=None,
        submitter_name_yomi='スギノハラ\u3000ショウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40883': EdinetCodeEntry(
        edinet_code='E40883',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='3月31日',
        submitter_name='株式会社ＪＰＥＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイペック',
        address='目黒区八雲四丁目８番１９号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='9010001256292',
    ),
    'E40884': EdinetCodeEntry(
        edinet_code='E40884',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='株式会社リアルクオリティ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリアルクオリティ',
        address='渋谷区神宮前６－３４－２３\u3000ＯＰ．Ｓｔ．Ｍ\u3000１Ｄ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401069322',
    ),
    'E40887': EdinetCodeEntry(
        edinet_code='E40887',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＰ７８',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーピーナナジュウハチ',
        address='港区虎ノ門四丁目１番２８号虎ノ門タワーズオフィス１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401180240',
    ),
    'E40888': EdinetCodeEntry(
        edinet_code='E40888',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＫ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーケーカブシキカイシャ',
        address='千代田区丸の内二丁目１番１号明治安田生命ビル１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001253605',
    ),
    'E40889': EdinetCodeEntry(
        edinet_code='E40889',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＡＰ８６',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエーピーハチジュウロク',
        address='港区虎ノ門四丁目１番２８号虎ノ門タワーズオフィス１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401191066',
    ),
    'E40890': EdinetCodeEntry(
        edinet_code='E40890',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=7,
        fiscal_year_end=None,
        submitter_name='ＲＩＨＵＡＸＩＮＧ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＬＩＭＩＴＥＤ',
        submitter_name_en=None,
        submitter_name_yomi='リファシン\u3000インベストメント\u3000リミテッド',
        address='Ｕｎｉｔ８，\u3000３／Ｆ．，\u3000Ｑｗｏｍａｒ\u3000Ｔｒａｄｉｎｇ\u3000Ｃｏｍｐｌｅｘ，\u3000Ｂｌａｃｋｂｕｒｎｅ\u3000Ｒｏａｄ，\u3000Ｐｏｒｔ\u3000Ｐｕｒｃｅｌｌ，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，\u3000Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ\u3000ＶＧ１１１０',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40892': EdinetCodeEntry(
        edinet_code='E40892',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ノヴァックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャノヴァックス',
        address='港区南麻布一丁目７番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401064885',
    ),
    'E40893': EdinetCodeEntry(
        edinet_code='E40893',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=287,
        fiscal_year_end=None,
        submitter_name='ＳＥＮＩＯＲ\u3000ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＨＯＬＤＩＮＧ（ＳＩＮＧＡＰＯＲＥ）ＰＴＥ．ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='シニアインターナショナルホールディング\u3000シンガポール\u3000ピーティーイーリミテッド',
        address='４６０\u3000ＡＬＥＸＡＮＤＲＡ\u3000ＲＯＡＤ，\u3000＃１１－０６，\u3000ＭＴＯＷＥＲ，\u3000ＳＩＮＧＡＰＯＲＥ\u3000１１９９６３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40894': EdinetCodeEntry(
        edinet_code='E40894',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｈｏｎｇ\u3000Ｋｏｎｇ\u3000Ｓｕｎｌｉｇｈｔ\u3000Ｈｏｕｓｅ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ホンコン\u3000サンライト\u3000ハウス\u3000リミテッド',
        address='ＳＨＯＰ\u3000Ｇ０６Ａ，\u3000Ｇ／Ｆ，\u3000ＭＥＴＲＯ\u3000ＣＩＴＹ\u3000ＰＨＡＳＥ\u3000１，\u3000ＰＯ\u3000ＬＡＭ，\u3000ＴＳＥＵＮＧ\u3000ＫＷＡＮ\u3000Ｏ，\u3000ＮＴ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40895': EdinetCodeEntry(
        edinet_code='E40895',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='能登\u3000伸一',
        submitter_name_en=None,
        submitter_name_yomi='ノト\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40896': EdinetCodeEntry(
        edinet_code='E40896',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ディメンショナル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャディメンショナル',
        address='品川区西五反田１丁目３０番２号ウィン五反田ビル６階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401177656',
    ),
    'E40897': EdinetCodeEntry(
        edinet_code='E40897',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＢＣＪ‐１００',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーシージェイワンハンドレッド',
        address='千代田区丸の内一丁目１番１号パレスビル５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001256983',
    ),
    'E40898': EdinetCodeEntry(
        edinet_code='E40898',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＳｐｉｃｙＣｏｍｐａｎｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャスパイシーカンパニー',
        address='渋谷区恵比寿４－７－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001191952',
    ),
    'E40899': EdinetCodeEntry(
        edinet_code='E40899',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='株式会社Ｌｅｍｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャレモン',
        address='福岡市東区香椎台一丁目８番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290001110601',
    ),
    'E40900': EdinetCodeEntry(
        edinet_code='E40900',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ビー・エックス・ジェイ・イー・ツー・ホールディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエックスジェイイーツーホールディングカブシキガイシャ',
        address='港区虎ノ門五丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401191720',
    ),
    'E40901': EdinetCodeEntry(
        edinet_code='E40901',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='堯アセットマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ギョウアセットマネジメントカブシキカイシャ',
        address='大阪市中央区谷町二丁目６番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9120001277914',
    ),
    'E40904': EdinetCodeEntry(
        edinet_code='E40904',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=10,
        fiscal_year_end='8月末日',
        submitter_name='株式会社オーバーラップホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオーバーラップホールディングス',
        address='品川区西五反田八丁目１番５号',
        industry='情報・通信業',
        sec_code='414A0',
        corporate_number='2010001226772',
    ),
    'E40905': EdinetCodeEntry(
        edinet_code='E40905',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ベータグリッド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャベータグリッド',
        address='港区西麻布３－２１－３－９０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401131652',
    ),
    'E40906': EdinetCodeEntry(
        edinet_code='E40906',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邉\u3000正礼',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000マサノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40908': EdinetCodeEntry(
        edinet_code='E40908',
        submitter_type='外国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='ＧＲＴキャピタル・マネジメント・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ジーアールティーキャピタルマネジメントリミテッド',
        address='香港、セントラル、ペダー・ストリート２０、ウィーロック・ハウス１６階、１６０４号室',
        industry='その他金融業',
        sec_code=None,
        corporate_number=None,
    ),
    'E40909': EdinetCodeEntry(
        edinet_code='E40909',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＬＩＵ\u3000ＹＡＮ',
        submitter_name_en=None,
        submitter_name_yomi='リュウ\u3000ヤン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40915': EdinetCodeEntry(
        edinet_code='E40915',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松下\u3000明義',
        submitter_name_en=None,
        submitter_name_yomi='マツシタ\u3000アキヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40916': EdinetCodeEntry(
        edinet_code='E40916',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='ＧＭＯコマース株式会社',
        submitter_name_en='GMO Commerce,Inc.',
        submitter_name_yomi='ジーエムオーコマースカブシキカイシャ',
        address='渋谷区道玄坂一丁目２番３号',
        industry='情報・通信業',
        sec_code='410A0',
        corporate_number='5011001092582',
    ),
    'E40917': EdinetCodeEntry(
        edinet_code='E40917',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=45,
        fiscal_year_end='8月31日',
        submitter_name='サイプレス・ホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイプレスホールディングスカブシキカイシャ',
        address='港区六本木一丁目９番１０号アークヒルズ仙石山森タワー４０階',
        industry='小売業',
        sec_code='428A0',
        corporate_number='2010001202872',
    ),
    'E40919': EdinetCodeEntry(
        edinet_code='E40919',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=61,
        fiscal_year_end='11月末日',
        submitter_name='ウリドキ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ウリドキカブシキガイシャ',
        address='新宿区新宿１－６－３\u3000新宿御苑フロント９階',
        industry='情報・通信業',
        sec_code='418A0',
        corporate_number='5010701030190',
    ),
    'E40920': EdinetCodeEntry(
        edinet_code='E40920',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＨＳＢＣグローバル・インベストメント・ファンド',
        submitter_name_en=None,
        submitter_name_yomi='エイチエスビーシーグローバルインベストメントファンド',
        address='ルクセンブルグ大公国、ホヴァルトＬ－２３７０、ペテルネルシェン通り４番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40921': EdinetCodeEntry(
        edinet_code='E40921',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＧＡＵＲＡＶ\u3000ＳＡＮＪＡＹ\u3000ＭＥＨＴＡ',
        submitter_name_en=None,
        submitter_name_yomi='ガウラヴ\u3000サンジェイ\u3000メタ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40923': EdinetCodeEntry(
        edinet_code='E40923',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=21,
        fiscal_year_end=None,
        submitter_name='株式会社橘屋',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャタチバナヤ',
        address='今治市旭町２丁目２番地５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5500001011916',
    ),
    'E40924': EdinetCodeEntry(
        edinet_code='E40924',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='木村商事株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キムラショウジカブシキガイシャ',
        address='今治市東鳥生町５丁目１９番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6500001011460',
    ),
    'E40925': EdinetCodeEntry(
        edinet_code='E40925',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ムービン・ストラテジック・キャリア',
        submitter_name_en="Movin' Strategic Career CO., LTD.",
        submitter_name_yomi='カブシキカイシャムービンストラテジックキャリア',
        address='港区赤坂九丁目７番１号\u3000ミッドタウン・タワー７Ｆ',
        industry='サービス業',
        sec_code='421A0',
        corporate_number='9010001123906',
    ),
    'E40926': EdinetCodeEntry(
        edinet_code='E40926',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=202424,
        fiscal_year_end=None,
        submitter_name='ノース・ピーク・キャピタル・マネジメント・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='ノースピークキャピタルマネジメントエルエルシー',
        address='アメリカ合衆国１０１７４、ニューヨーク州ニューヨーク市、レキシントン・アベニュー４０５番地',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40927': EdinetCodeEntry(
        edinet_code='E40927',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='昼田\u3000将司',
        submitter_name_en=None,
        submitter_name_yomi='ヒルタ\u3000マサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40930': EdinetCodeEntry(
        edinet_code='E40930',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8647,
        fiscal_year_end=None,
        submitter_name='バックト・オプコ・ホールディングス・エルエルシー',
        submitter_name_en=None,
        submitter_name_yomi='バックトオプコホールディングスエルエルシー',
        address='アメリカ合衆国、１０００６、ニューヨーク州、ニューヨーク、リバティ・ストリート１番地、ワン・リバティ・プラザ３階、スイート３０５ー３０６',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40931': EdinetCodeEntry(
        edinet_code='E40931',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=24363,
        fiscal_year_end=None,
        submitter_name='Ｒａｎｇｅｌｅｙ\u3000Ｃａｐｉｔａｌ，\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='レンジリー\u3000キャピタル\u3000エルエルシー',
        address='３\u3000Ｆｏｒｅｓｔ\u3000Ｓｔｒｅｅｔ，\u3000Ｎｅｗ\u3000Ｃａｎａａｎ，\u3000Ｃｏｎｎｅｃｔｉｃｕｔ，\u3000Ｕ．Ｓ．Ａ．',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40932': EdinetCodeEntry(
        edinet_code='E40932',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=22,
        fiscal_year_end=None,
        submitter_name='サントレード株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サントレードカブシキカイシャ',
        address='東大阪市長田西三丁目５番１７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2122001002878',
    ),
    'E40933': EdinetCodeEntry(
        edinet_code='E40933',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＧＣＱ\u3000ＦＵＮＤＳ\u3000ＭＡＮＡＧＥＭＥＮＴ\u3000ＰＴＹ\u3000Ｌｔｄ',
        submitter_name_en=None,
        submitter_name_yomi='ジーシーキュー\u3000ファンド\u3000マネジメント\u3000プロプライタリー\u3000リミテッド',
        address='Ｕｎｉｔ\u3000１４Ｌ，\u3000１６７\u3000Ｍａｃｑｕａｒｉｅ\u3000ＳＴＲＥＥＴ，\u3000ＳＹＤＮＥＹ\u3000ＮＳＷ\u3000２０００，\u3000ＡＵＳＴＲＡＬＩＡ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40934': EdinetCodeEntry(
        edinet_code='E40934',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=9916,
        fiscal_year_end='12月31日',
        submitter_name='株式会社パワーエックス',
        submitter_name_en='PowerX, Inc',
        submitter_name_yomi='カブシキカイシャパワーエックス',
        address='玉野市田井六丁目９番１号',
        industry='電気機器',
        sec_code='485A0',
        corporate_number='7010401159056',
    ),
    'E40935': EdinetCodeEntry(
        edinet_code='E40935',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鈴木\u3000幹子',
        submitter_name_en=None,
        submitter_name_yomi='スズキ\u3000ミキコ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40936': EdinetCodeEntry(
        edinet_code='E40936',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=16,
        fiscal_year_end=None,
        submitter_name='株式会社ガイアテック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャガイアテック',
        address='薩摩川内市小倉町５９６０番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5340001008581',
    ),
    'E40937': EdinetCodeEntry(
        edinet_code='E40937',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='12月31日',
        submitter_name='チンクエチェント株式会社',
        submitter_name_en='Cinquecento Corporation',
        submitter_name_yomi='チンクエチェントカブシキカイシャ',
        address='新宿区新宿二丁目１２番１３号新宿アントレサロンビル２階',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='8011101112601',
    ),
    'E40938': EdinetCodeEntry(
        edinet_code='E40938',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='明秀株式会社',
        submitter_name_en=None,
        submitter_name_yomi='メイシュウカブシキガイシャ',
        address='杉並区成田西２－１－１１\u3000Ｃ号棟',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011301029566',
    ),
    'E40939': EdinetCodeEntry(
        edinet_code='E40939',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=48,
        fiscal_year_end=None,
        submitter_name='有限会社新光企画',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャシンコウキカク',
        address='大阪市中央区北久宝寺町一丁目９番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120002036408',
    ),
    'E40941': EdinetCodeEntry(
        edinet_code='E40941',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃｕｒｉｅ１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='キュリーワンカブシキガイシャ',
        address='東京都港区麻布台１丁目３番１号麻布台ヒルズ森ＪＰタワー１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401191983',
    ),
    'E40943': EdinetCodeEntry(
        edinet_code='E40943',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社ニキティス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャニキティス',
        address='川口市上青木一丁目２３番３６－６０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001049082',
    ),
    'E40945': EdinetCodeEntry(
        edinet_code='E40945',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木暮\u3000康雄',
        submitter_name_en=None,
        submitter_name_yomi='コグレ\u3000ヤスオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40946': EdinetCodeEntry(
        edinet_code='E40946',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中村\u3000友哉',
        submitter_name_en=None,
        submitter_name_yomi='ナカムラ\u3000ユウヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40947': EdinetCodeEntry(
        edinet_code='E40947',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='全共連第４回劣後ローン流動化株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ゼンキョウレンダイヨンカイレツゴローンリュウドウカカブシキガイシャ',
        address='千代田区丸の内一丁目４番１号東京共同会計事務所内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001257402',
    ),
    'E40948': EdinetCodeEntry(
        edinet_code='E40948',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='末次\u3000栄作',
        submitter_name_en=None,
        submitter_name_yomi='スエツグ\u3000エイサク',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40950': EdinetCodeEntry(
        edinet_code='E40950',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒田\u3000直樹',
        submitter_name_en=None,
        submitter_name_yomi='クロダ\u3000ナオキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40951': EdinetCodeEntry(
        edinet_code='E40951',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='深井英樹',
        submitter_name_en=None,
        submitter_name_yomi='フカイ\u3000ヒデキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40954': EdinetCodeEntry(
        edinet_code='E40954',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小田切\u3000基浩',
        submitter_name_en=None,
        submitter_name_yomi='オダギリ\u3000モトヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40955': EdinetCodeEntry(
        edinet_code='E40955',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='扇栄会\u3000理事長\u3000山﨑\u3000俊隆',
        submitter_name_en=None,
        submitter_name_yomi='センエイカイ\u3000リジチョウ\u3000ヤマサキ\u3000トシタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40956': EdinetCodeEntry(
        edinet_code='E40956',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000豪',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000ゴウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40957': EdinetCodeEntry(
        edinet_code='E40957',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='塩満\u3000龍一',
        submitter_name_en=None,
        submitter_name_yomi='シオミツ\u3000リュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40958': EdinetCodeEntry(
        edinet_code='E40958',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社コンサバティヴホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャコンサバティヴホールディングス',
        address='目黒区目黒四丁目３番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1011001092660',
    ),
    'E40962': EdinetCodeEntry(
        edinet_code='E40962',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='双栄興業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソウエイコウギョウカブシキカイシャ',
        address='千代田区九段南三丁目９番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2011801014978',
    ),
    'E40964': EdinetCodeEntry(
        edinet_code='E40964',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='ユーソナー株式会社',
        submitter_name_en='uSonar Co., Ltd',
        submitter_name_yomi='ユーソナーカブシキカイシャ',
        address='新宿区西新宿三丁目２０番２号',
        industry='情報・通信業',
        sec_code='431A0',
        corporate_number='3011101023530',
    ),
    'E40971': EdinetCodeEntry(
        edinet_code='E40971',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｏｒｓａｙ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャオルセー',
        address='品川区東品川四丁目１３番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4012401043498',
    ),
    'E40973': EdinetCodeEntry(
        edinet_code='E40973',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=780,
        fiscal_year_end=None,
        submitter_name='一般財団法人三村学術福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='イッパンザイダンホウジンミムラガクジュツフクシザイダン',
        address='越前市家久町第５９号１番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7210005010215',
    ),
    'E40977': EdinetCodeEntry(
        edinet_code='E40977',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丹野\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='タンノ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40979': EdinetCodeEntry(
        edinet_code='E40979',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='4月30日',
        submitter_name='ＮＥ株式会社',
        submitter_name_en='NE Inc.',
        submitter_name_yomi='エヌイーカブシキガイシャ',
        address='横浜市港北区新横浜三丁目２番３号',
        industry='情報・通信業',
        sec_code='441A0',
        corporate_number='2021001075886',
    ),
    'E40982': EdinetCodeEntry(
        edinet_code='E40982',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='トリウム・キャピタル・エルエルピー',
        submitter_name_en=None,
        submitter_name_yomi='トリウムキャピタルエルエルピー',
        address='英国ＥＣ２Ｖ\u3000７ＢＢロンドン、グレシャム・ストリート６０、４階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40983': EdinetCodeEntry(
        edinet_code='E40983',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社マネジメントベース',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャマネジメントベース',
        address='千代田区飯田橋３－４－４第５田中ビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001102105',
    ),
    'E40984': EdinetCodeEntry(
        edinet_code='E40984',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＲＴＳ－４株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アーツフォーカブシキガイシャ',
        address='港区港南一丁目２番７０号品川シーズンテラス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401192499',
    ),
    'E40985': EdinetCodeEntry(
        edinet_code='E40985',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=400,
        fiscal_year_end='3月31日',
        submitter_name='テクセンドフォトマスク株式会社',
        submitter_name_en='Tekscend Photomask Corp.',
        submitter_name_yomi='テクセンドフォトマスクカブシキガイシャ',
        address='東京都港区東新橋一丁目５番２号',
        industry='精密機器',
        sec_code='429A0',
        corporate_number='1010401164466',
    ),
    'E40987': EdinetCodeEntry(
        edinet_code='E40987',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='中本有紀',
        submitter_name_en=None,
        submitter_name_yomi='ナカモトユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40991': EdinetCodeEntry(
        edinet_code='E40991',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='9月30日',
        submitter_name='辻・本郷ＩＴコンサルティング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ツジホンゴウアイティコンサルティングカブシキカイシャ',
        address='東京都渋谷区代々木一丁目３６番４号全理連ビル５階',
        industry='サービス業',
        sec_code='476A0',
        corporate_number='2011001073585',
    ),
    'E40992': EdinetCodeEntry(
        edinet_code='E40992',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＫＫ\u3000ＨＯＬＤＩＮＧＳ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチケイケイホールディングス',
        address='名古屋市東区葵三丁目１４番１２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010901012770',
    ),
    'E40993': EdinetCodeEntry(
        edinet_code='E40993',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='株式会社ファンドクラウド',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャファンドクラウド',
        address='新宿区西新宿五丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011201024473',
    ),
    'E40994': EdinetCodeEntry(
        edinet_code='E40994',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='土居\u3000信一',
        submitter_name_en=None,
        submitter_name_yomi='ドイ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40996': EdinetCodeEntry(
        edinet_code='E40996',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小山\u3000武',
        submitter_name_en=None,
        submitter_name_yomi='コヤマ\u3000タケシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E40997': EdinetCodeEntry(
        edinet_code='E40997',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='本多\u3000容和',
        submitter_name_en=None,
        submitter_name_yomi='ホンダ\u3000マサカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41002': EdinetCodeEntry(
        edinet_code='E41002',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ｒｅｎｇａ第１号合同会社',
        submitter_name_en=None,
        submitter_name_yomi='レンガダイイチゴウゴウドウガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010003048038',
    ),
    'E41010': EdinetCodeEntry(
        edinet_code='E41010',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='4月末日',
        submitter_name='サイバーソリューションズ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サイバーソリューションズカブシキガイシャ',
        address='港区芝浦三丁目４番１号\u3000グランパークタワー３４階',
        industry='情報・通信業',
        sec_code='436A0',
        corporate_number='7010001231677',
    ),
    'E41011': EdinetCodeEntry(
        edinet_code='E41011',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｐｅｒｓｈｉｎｇ\u3000Ａｓｉａ\u3000Ｐａｒｔｎｅｒｓ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='パーシング\u3000アジア\u3000パートナーズ\u3000エルエルシー',
        address='アメリカ合衆国デラウェア州ニューキャッスル郡ウィルミントン市リトルフォールズドライブ２５１コーポレーションサービスカンパニー方',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41013': EdinetCodeEntry(
        edinet_code='E41013',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=53,
        fiscal_year_end=None,
        submitter_name='株式会社Ａｓａｈｉｃｈｏ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアサヒチョウ',
        address='府中市府川町１１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6240001034109',
    ),
    'E41014': EdinetCodeEntry(
        edinet_code='E41014',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＢＩＮＭ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エスビーアイエヌエムゴウドウガイシャ',
        address='港区六本木１－６－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010403030698',
    ),
    'E41015': EdinetCodeEntry(
        edinet_code='E41015',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=27751,
        fiscal_year_end=None,
        submitter_name='ＥＣＭ\u3000Ｍａｓｔｅｒ\u3000Ｆｕｎｄ\u3000ＳＰＶ\u3000３',
        submitter_name_en=None,
        submitter_name_yomi='イーシーエム\u3000マスター\u3000ファンド\u3000エスピーブイ\u3000スリー',
        address='Ｃｏｎｙｅｒｓ\u3000Ｔｒｕｓｔ\u3000Ｃｏｍｐａｎｙ\u3000（Ｃａｙｍａｎ）\u3000Ｌｉｍｉｔｅｄ，\u3000Ｃｒｉｃｋｅｔ\u3000Ｓｑｕａｒｅ，\u3000Ｈｕｔｃｈｉｎｓ\u3000Ｄｒｉｖｅ，\u3000ＰＯ\u3000Ｂｏｘ\u3000２６８１，\u3000Ｇｒａｎｄ\u3000Ｃａｙｍａｎ\u3000ＫＹ１－１１１１，\u3000Ｃａｙｍａｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41017': EdinetCodeEntry(
        edinet_code='E41017',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=40,
        fiscal_year_end=None,
        submitter_name='ｍｕｓｉｃａ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ムジカカブシキカイシャ',
        address='大阪市北区梅田三丁目３番４５号マルイト西梅田ビル３Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001095665',
    ),
    'E41018': EdinetCodeEntry(
        edinet_code='E41018',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＨＡＹＡＫＡＷＡ',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャハヤカワ',
        address='印西市高花六丁目３６番１６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6040003026719',
    ),
    'E41019': EdinetCodeEntry(
        edinet_code='E41019',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＭＫＲ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーエムケイアール',
        address='中央区日本橋室町四丁目３番９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001258151',
    ),
    'E41021': EdinetCodeEntry(
        edinet_code='E41021',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='勝俣\u3000篤志',
        submitter_name_en=None,
        submitter_name_yomi='カツマタ\u3000アツシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41022': EdinetCodeEntry(
        edinet_code='E41022',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小林\u3000亜佐美',
        submitter_name_en=None,
        submitter_name_yomi='コバヤシ\u3000アサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41024': EdinetCodeEntry(
        edinet_code='E41024',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＯＦＩ・０１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='オーエフアイゼロイチカブシキガイシャ',
        address='港区浜松町二丁目４番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401192492',
    ),
    'E41025': EdinetCodeEntry(
        edinet_code='E41025',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人森田記念福祉財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンモリタキネンフクシザイダン',
        address='奈良市中登美ケ丘２丁目１９８４－４０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2150005002537',
    ),
    'E41027': EdinetCodeEntry(
        edinet_code='E41027',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=5,
        fiscal_year_end=None,
        submitter_name='株式会社センターロック',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャセンターロック',
        address='福津市中央六丁目８番地５ウィンドブレイク２Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8290001102908',
    ),
    'E41028': EdinetCodeEntry(
        edinet_code='E41028',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='3月31日',
        submitter_name='株式会社インフキュリオン',
        submitter_name_en='Infcurion, Inc.',
        submitter_name_yomi='カブシキガイシャインフキュリオン',
        address='千代田区麹町五丁目７番地２ＭＦＰＲ麹町ビル７Ｆ',
        industry='情報・通信業',
        sec_code='438A0',
        corporate_number='4010001117846',
    ),
    'E41029': EdinetCodeEntry(
        edinet_code='E41029',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｃａｍｂｒｉｄｇｅ\u3000Ａｓｉａ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ケンブリッジアジアエルエルシー',
        address='アメリカ合衆国デラウェア州ニューキャッスル郡ウィルミントン市リトルフォールズドライブ２５１番地コーポレーションサービスカンパニー',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41030': EdinetCodeEntry(
        edinet_code='E41030',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=836,
        fiscal_year_end='10月31日',
        submitter_name='クラシコ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='クラシコカブシキカイシャ',
        address='港区赤坂９－５－１２パークサイドシックス２０１',
        industry='繊維製品',
        sec_code='442A0',
        corporate_number='4011001062719',
    ),
    'E41032': EdinetCodeEntry(
        edinet_code='E41032',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永田\u3000勝治',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000カツハル',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41034': EdinetCodeEntry(
        edinet_code='E41034',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='カロンホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='カロンホールディングスカブシキガイシャ',
        address='千代田区霞が関三丁目２番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001257149',
    ),
    'E41037': EdinetCodeEntry(
        edinet_code='E41037',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=20,
        fiscal_year_end='3月31日',
        submitter_name='テラテクノロジー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='テラテクノロジーカブシキガイシャ',
        address='豊島区東池袋３－４－３池袋イースト',
        industry='情報・通信業',
        sec_code='483A0',
        corporate_number='8013301007853',
    ),
    'E41038': EdinetCodeEntry(
        edinet_code='E41038',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000將隆',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000マサタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41039': EdinetCodeEntry(
        edinet_code='E41039',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000美憲',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000ヨシノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41040': EdinetCodeEntry(
        edinet_code='E41040',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000清隆',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000キヨタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41042': EdinetCodeEntry(
        edinet_code='E41042',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='東\u3000稔哉',
        submitter_name_en=None,
        submitter_name_yomi='ヒガシ\u3000トシヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41045': EdinetCodeEntry(
        edinet_code='E41045',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=99,
        fiscal_year_end=None,
        submitter_name='日本継手株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニッポンツギテカブシキガイシャ',
        address='岸和田市田治米町１５３番地の１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120101037360',
    ),
    'E41047': EdinetCodeEntry(
        edinet_code='E41047',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長村\u3000耕志',
        submitter_name_en=None,
        submitter_name_yomi='オサムラ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41048': EdinetCodeEntry(
        edinet_code='E41048',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｓｕｍｏ\u3000Ｊａｐａｎ\u3000Ｖｅｎｔｕｒｅｓ\u3000Ｓｅｇｒｅｇａｔｅｄ\u3000Ｐｏｒｔｆｏｌｉｏ\u3000ｏｆ\u3000Ｆｕｎｄｖｉｅｗｓ\u3000ＳＰＣ\u3000Ｌｔｄ．',
        submitter_name_en=None,
        submitter_name_yomi='スモウ\u3000ジャパン\u3000ベンチャーズ\u3000セグリゲーテッド\u3000ポートフォリオ\u3000オブ\u3000ファンドビューズ\u3000エスピーシー\u3000リミテッド',
        address='ボルダー・コーポレート・サービス（ＢＶＩ）リミテッド、シー・メドウ・ハウス、ＰＯボックス１１６、ロード・タウン、トルトラ、英領バージン諸島',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41052': EdinetCodeEntry(
        edinet_code='E41052',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神川\u3000志悠',
        submitter_name_en=None,
        submitter_name_yomi='カミカワ\u3000シユウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41053': EdinetCodeEntry(
        edinet_code='E41053',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神川\u3000芽伊',
        submitter_name_en=None,
        submitter_name_yomi='カミカワ\u3000メイ',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41055': EdinetCodeEntry(
        edinet_code='E41055',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=48,
        fiscal_year_end='11月30日',
        submitter_name='株式会社フィットクルー',
        submitter_name_en='Fitcrew Inc.',
        submitter_name_yomi='カブシキカイシャフィットクルー',
        address='大阪市西区靭本町１－１３－９中央ビル１階',
        industry='サービス業',
        sec_code='469A0',
        corporate_number='6120901034938',
    ),
    'E41056': EdinetCodeEntry(
        edinet_code='E41056',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｄｉｓｈ合同会社',
        submitter_name_en=None,
        submitter_name_yomi='ディッシュゴウドウガイシャ',
        address='文京区本郷四丁目１６番６号天翔オフィス後楽園２１４号室',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010003042596',
    ),
    'E41059': EdinetCodeEntry(
        edinet_code='E41059',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000界宏',
        submitter_name_en=None,
        submitter_name_yomi='リン\u3000カイコウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41060': EdinetCodeEntry(
        edinet_code='E41060',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000盈穎',
        submitter_name_en=None,
        submitter_name_yomi='リン\u3000ミツエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41061': EdinetCodeEntry(
        edinet_code='E41061',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='林\u3000盈貝',
        submitter_name_en=None,
        submitter_name_yomi='リン\u3000ミツエ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41062': EdinetCodeEntry(
        edinet_code='E41062',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木田\u3000裕介',
        submitter_name_en=None,
        submitter_name_yomi='キダ\u3000ユウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41063': EdinetCodeEntry(
        edinet_code='E41063',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='戸田\u3000晃平',
        submitter_name_en=None,
        submitter_name_yomi='トダ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41065': EdinetCodeEntry(
        edinet_code='E41065',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＦＵＪＩＭＡＫＩアセットデザイン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフジマキアセットデザイン',
        address='京都市中京区高倉通錦小路上る貝屋町５６５番地１四条高倉スカイハイツ５０８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2130001066538',
    ),
    'E41066': EdinetCodeEntry(
        edinet_code='E41066',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長尾\u3000智明',
        submitter_name_en=None,
        submitter_name_yomi='ナガオ\u3000トモアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41067': EdinetCodeEntry(
        edinet_code='E41067',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神川\u3000貴実彦',
        submitter_name_en=None,
        submitter_name_yomi='カミカワ\u3000キミヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41069': EdinetCodeEntry(
        edinet_code='E41069',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤巻\u3000米隆',
        submitter_name_en=None,
        submitter_name_yomi='フジマキ\u3000ヨネタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41070': EdinetCodeEntry(
        edinet_code='E41070',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='飯田\u3000泰敬',
        submitter_name_en=None,
        submitter_name_yomi='イイダ\u3000ヤスタカ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41074': EdinetCodeEntry(
        edinet_code='E41074',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ビー・エックス・ジェイ・イー・ワン・ホールディング株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ビーエックスジェイイーワンホールディングカブシキガイシャ',
        address='港区虎ノ門五丁目１番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401191719',
    ),
    'E41075': EdinetCodeEntry(
        edinet_code='E41075',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=365,
        fiscal_year_end=None,
        submitter_name='株式会社ポケモン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャポケモン',
        address='港区六本木６－１０－１六本木ヒルズ森タワー８Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010401079276',
    ),
    'E41076': EdinetCodeEntry(
        edinet_code='E41076',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=87,
        fiscal_year_end='1月末日',
        submitter_name='ＨＵＭＡＮ\u3000ＭＡＤＥ株式会社',
        submitter_name_en='HUMAN MADE Inc.',
        submitter_name_yomi='ヒューマンメイドカブシキガイシャ',
        address='品川区上大崎２－２４－９',
        industry='小売業',
        sec_code='456A0',
        corporate_number='2011001109488',
    ),
    'E41077': EdinetCodeEntry(
        edinet_code='E41077',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大知\u3000昌幸',
        submitter_name_en=None,
        submitter_name_yomi='オオチ\u3000マサユキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41080': EdinetCodeEntry(
        edinet_code='E41080',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社あやめ家',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアヤメヤ',
        address='奈良市あやめ池北１丁目２７番２３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5150001019796',
    ),
    'E41081': EdinetCodeEntry(
        edinet_code='E41081',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=90,
        fiscal_year_end='10月31日',
        submitter_name='株式会社ＦＵＮＤＩＮＮＯ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャファンディーノ',
        address='港区芝５－２９－１１\u3000Ｇ－ＢＡＳＥ田町３Ｆ',
        industry='証券、商品先物取引業',
        sec_code='462A0',
        corporate_number='7010401121809',
    ),
    'E41082': EdinetCodeEntry(
        edinet_code='E41082',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=50,
        fiscal_year_end=None,
        submitter_name='豊田産業株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨタサンギョウカブシキガイシャ',
        address='吹田市芳野町１４ー３３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120901007624',
    ),
    'E41083': EdinetCodeEntry(
        edinet_code='E41083',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石村\u3000真一',
        submitter_name_en=None,
        submitter_name_yomi='イシムラ\u3000シンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41084': EdinetCodeEntry(
        edinet_code='E41084',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤原\u3000良輔',
        submitter_name_en=None,
        submitter_name_yomi='フジハラ\u3000リョウスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41085': EdinetCodeEntry(
        edinet_code='E41085',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=410,
        fiscal_year_end=None,
        submitter_name='有限会社ティーエム興産',
        submitter_name_en=None,
        submitter_name_yomi='ユウゲンガイシャティーエムコウサン',
        address='千代田区神田東松下町３７番地林道ビル７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010002012457',
    ),
    'E41086': EdinetCodeEntry(
        edinet_code='E41086',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=71,
        fiscal_year_end='10月末日',
        submitter_name='ＢＲＡＮＵ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブラニューカブシキカイシャ',
        address='港区六本木六丁目１番２４号ラピロス六本木４階',
        industry='情報・通信業',
        sec_code='460A0',
        corporate_number='6010401083620',
    ),
    'E41088': EdinetCodeEntry(
        edinet_code='E41088',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='株式会社麻布ビルディング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアザブビルディング',
        address='渋谷区神宮前六丁目３４番２０号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010402036478',
    ),
    'E41089': EdinetCodeEntry(
        edinet_code='E41089',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='浅野\u3000秀一',
        submitter_name_en=None,
        submitter_name_yomi='アサノ\u3000シュウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41091': EdinetCodeEntry(
        edinet_code='E41091',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='丸山\u3000弘毅',
        submitter_name_en=None,
        submitter_name_yomi='マルヤマ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41092': EdinetCodeEntry(
        edinet_code='E41092',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='来田\u3000武則',
        submitter_name_en=None,
        submitter_name_yomi='キタ\u3000タケノリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41093': EdinetCodeEntry(
        edinet_code='E41093',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='公益財団法人ＫＮＣ広瀬財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンケイエヌシーヒロセザイダン',
        address='神戸市中央区港島南町七丁目１番地の１９',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7140005027241',
    ),
    'E41096': EdinetCodeEntry(
        edinet_code='E41096',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='福富\u3000七海',
        submitter_name_en=None,
        submitter_name_yomi='フクトミ\u3000ナミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41099': EdinetCodeEntry(
        edinet_code='E41099',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長田\u3000敏彦',
        submitter_name_en=None,
        submitter_name_yomi='オサダ\u3000トシヒコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41100': EdinetCodeEntry(
        edinet_code='E41100',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大豆生田\u3000伸夫',
        submitter_name_en=None,
        submitter_name_yomi='オオマメウダ\u3000ノブオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41101': EdinetCodeEntry(
        edinet_code='E41101',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='8月31日',
        submitter_name='合同会社オーナーズブック・スリー',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャオーナーズブックスリー',
        address='千代田区霞が関三丁目２番５号',
        industry='不動産業',
        sec_code=None,
        corporate_number='4010003048643',
    ),
    'E41102': EdinetCodeEntry(
        edinet_code='E41102',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＷＨＤ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ダブリューエイチディーカブシキガイシャ',
        address='千代田区神田神保町３－１２－３神保町スリービル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001257120',
    ),
    'E41103': EdinetCodeEntry(
        edinet_code='E41103',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＹＡＨＯ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヤホカブシキガイシャ',
        address='府中市高木町１０７１番地',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401193466',
    ),
    'E41104': EdinetCodeEntry(
        edinet_code='E41104',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='1月末日',
        submitter_name='株式会社ノースサンド',
        submitter_name_en='Northsand, Inc.',
        submitter_name_yomi='カブシキガイシャノースサンド',
        address='中央区銀座四丁目１２番１５号\u3000歌舞伎座タワー７階',
        industry='サービス業',
        sec_code='446A0',
        corporate_number='6010601048200',
    ),
    'E41107': EdinetCodeEntry(
        edinet_code='E41107',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=2,
        fiscal_year_end=None,
        submitter_name='Ｉｃｅインテグラル１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アイスインテグラルワンカブシキガイシャ',
        address='千代田区丸の内一丁目９番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001217836',
    ),
    'E41108': EdinetCodeEntry(
        edinet_code='E41108',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=239,
        fiscal_year_end='12月末日',
        submitter_name='株式会社フツパー',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフツパー',
        address='大阪市淀川区西中島１ー１１ー１６\u3000新大阪ＣＳＰビル北館４階',
        industry='情報・通信業',
        sec_code='478A0',
        corporate_number='7120001228357',
    ),
    'E41115': EdinetCodeEntry(
        edinet_code='E41115',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ギミック',
        submitter_name_en='GIMIC Co., Ltd.',
        submitter_name_yomi='カブシキガイシャギミック',
        address='渋谷区南平台町２番１７号',
        industry='サービス業',
        sec_code='475A0',
        corporate_number='7011001073333',
    ),
    'E41116': EdinetCodeEntry(
        edinet_code='E41116',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＣインベストメンツ・マネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エスシーインベストメンツマネジメントカブシキガイシャ',
        address='千代田区大手町２丁目３番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001258629',
    ),
    'E41118': EdinetCodeEntry(
        edinet_code='E41118',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='晋文金属株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シンブンキンゾクカブシキカイシャ',
        address='江戸川区東葛西六丁目２３番４－３０１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011701017715',
    ),
    'E41119': EdinetCodeEntry(
        edinet_code='E41119',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3278,
        fiscal_year_end=None,
        submitter_name='ＵＮＩＶＥＲＳＡＬ\u3000ＤＩＧＩＴＡＬ\u3000ＩＮＣ．',
        submitter_name_en=None,
        submitter_name_yomi='ユニバーサル\u3000デジタル\u3000インク',
        address='１５ｔｈ\u3000Ｆｌｏｏｒ\u3000１１１１\u3000Ｗｅｓｔ\u3000Ｈａｓｔｉｎｇｓ\u3000Ｓｔｒｅｅｔ\u3000Ｖａｎｃｏｕｖｅｒ\u3000ＢＣ\u3000Ｖ６Ｅ\u3000２Ｊ３\u3000Ｃａｎａｄａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41123': EdinetCodeEntry(
        edinet_code='E41123',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＶＩＮＴＡＧＥＣＡＶＥＣＡＰＩＴＡＬ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ヴィンテージケーヴキャピタルカブシキガイシャ',
        address='港区元六本木３－１６－１３\u3000アンバサダー六本木６１０',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401191470',
    ),
    'E41125': EdinetCodeEntry(
        edinet_code='E41125',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭＭパワー合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエムパワーゴウドウガイシャ',
        address='港区虎ノ門一丁目２番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403036164',
    ),
    'E41126': EdinetCodeEntry(
        edinet_code='E41126',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=500,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＣＣ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジェイシーシー',
        address='港区芝四丁目７番６号芝ビルディング７０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010701042501',
    ),
    'E41127': EdinetCodeEntry(
        edinet_code='E41127',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大和\u3000新',
        submitter_name_en=None,
        submitter_name_yomi='オオワ\u3000アラタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41128': EdinetCodeEntry(
        edinet_code='E41128',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=152405,
        fiscal_year_end='3月31日',
        submitter_name='ＰａｙＰａｙ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ペイペイカブシキガイシャ',
        address='千代田区紀尾井町１番３号',
        industry='サービス業',
        sec_code=None,
        corporate_number='5010001192707',
    ),
    'E41130': EdinetCodeEntry(
        edinet_code='E41130',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=1,
        fiscal_year_end='3月31日',
        submitter_name='ＡＲＣＨＩＯＮ株式会社',
        submitter_name_en='ARCHION Corporation',
        submitter_name_yomi='アーチオンカブシキガイシャ',
        address='品川区西品川一丁目１番１号住友不動産大崎ガーデンタワー',
        industry='輸送用機器',
        sec_code=None,
        corporate_number='7012801024013',
    ),
    'E41131': EdinetCodeEntry(
        edinet_code='E41131',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榎\u3000崇斗',
        submitter_name_en=None,
        submitter_name_yomi='エノキ\u3000タカト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41134': EdinetCodeEntry(
        edinet_code='E41134',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ブルーブルームキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ブルーブルームキャピタルカブシキカイシャ',
        address='港区北青山１丁目３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401193626',
    ),
    'E41136': EdinetCodeEntry(
        edinet_code='E41136',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社ＹＮ企画',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウガイシャワイエヌキカク',
        address='港区六本木２－２－７クレール六本木３０４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010403011554',
    ),
    'E41139': EdinetCodeEntry(
        edinet_code='E41139',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀田\u3000麻美',
        submitter_name_en=None,
        submitter_name_yomi='ホッタアサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41141': EdinetCodeEntry(
        edinet_code='E41141',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＦＴＬキャピタルマネジメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エフティーエルキャピタルマネジメントカブシキガイシャ',
        address='港区芝３丁目８番２号ラトゥール芝公園３１０５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401185989',
    ),
    'E41142': EdinetCodeEntry(
        edinet_code='E41142',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ＡＮＲＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アンリカブシキガイシャ',
        address='港区六本木６丁目１０－１六本木ヒルズ森タワー１５Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001100170',
    ),
    'E41143': EdinetCodeEntry(
        edinet_code='E41143',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='株式会社ａ’ｇｉｌ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアジル',
        address='大阪市天王寺区堂ケ芝１－１１－３\u3000ＤＳｔ桃谷ビルディング４Ｆ',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3120001225928',
    ),
    'E41144': EdinetCodeEntry(
        edinet_code='E41144',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=565,
        fiscal_year_end='12月31日',
        submitter_name='株式会社ミラティブ',
        submitter_name_en='Mirrativ,Inc.',
        submitter_name_yomi='カブシキガイシャミラティブ',
        address='目黒区目黒２丁目１０ー１１目黒山手プレイス８階',
        industry='情報・通信業',
        sec_code='472A0',
        corporate_number='6010901041557',
    ),
    'E41145': EdinetCodeEntry(
        edinet_code='E41145',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='千代田プロパティホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='チヨダプロパティホールディングスカブシキガイシャ',
        address='千代田区大手町一丁目９番２号大手町フィナンシャルシティグランキューブ１８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5020001024198',
    ),
    'E41146': EdinetCodeEntry(
        edinet_code='E41146',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=90,
        fiscal_year_end=None,
        submitter_name='アストロンキャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アストロンキャピタルカブシキガイシャ',
        address='台東区台東一丁目２２番４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7011401018821',
    ),
    'E41147': EdinetCodeEntry(
        edinet_code='E41147',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ソルスティシア株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソルスティシアカブシキガイシャ',
        address='港区六本木六丁目１０番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401194003',
    ),
    'E41149': EdinetCodeEntry(
        edinet_code='E41149',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='有',
        capital_million_yen=100,
        fiscal_year_end='12月末日',
        submitter_name='ＮＳグループ株式会社',
        submitter_name_en='NS Group, Inc.',
        submitter_name_yomi='エヌエスグループカブシキカイシャ',
        address='大阪市北区中之島三丁目３番３号',
        industry='その他金融業',
        sec_code='471A0',
        corporate_number='3010001220782',
    ),
    'E41152': EdinetCodeEntry(
        edinet_code='E41152',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=657,
        fiscal_year_end='3月末日',
        submitter_name='株式会社スタートライン',
        submitter_name_en='Startline CO.,LTD.',
        submitter_name_yomi='カブシキガイシャスタートライン',
        address='三鷹市上連雀一丁目１２番１７号',
        industry='サービス業',
        sec_code='477A0',
        corporate_number='9010101009311',
    ),
    'E41153': EdinetCodeEntry(
        edinet_code='E41153',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='誠香インベストメント株式会社',
        submitter_name_en=None,
        submitter_name_yomi='セイカインベストメントカブシキガイシャ',
        address='世田谷区尾山台１丁目１６番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010901016165',
    ),
    'E41154': EdinetCodeEntry(
        edinet_code='E41154',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=30,
        fiscal_year_end='12月31日',
        submitter_name='株式会社リブ・コンサルティング',
        submitter_name_en='LiB Consulting Co.,Ltd.',
        submitter_name_yomi='カブシキカイシャリブコンサルティング',
        address='中央区日本橋二丁目７番１号\u3000東京日本橋タワー',
        industry='サービス業',
        sec_code='480A0',
        corporate_number='4010001148263',
    ),
    'E41156': EdinetCodeEntry(
        edinet_code='E41156',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂｏｓｐｏｌｄｅｒ\u3000１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ボスポルダーワンカブシキガイシャ',
        address='港区麻布台一丁目３番１号麻布台ヒルズ森ＪＰタワー１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401190459',
    ),
    'E41158': EdinetCodeEntry(
        edinet_code='E41158',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='鹿島\u3000紘樹',
        submitter_name_en=None,
        submitter_name_yomi='カシマ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41160': EdinetCodeEntry(
        edinet_code='E41160',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='国際自動車株式会社',
        submitter_name_en=None,
        submitter_name_yomi='コクサイジドウシャカブシキガイシャ',
        address='港区赤坂二丁目８番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401076302',
    ),
    'E41161': EdinetCodeEntry(
        edinet_code='E41161',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＫＪ００３株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ケイジェイゼロゼロスリーカブシキカイシャ',
        address='千代田区丸の内二丁目１番１号明治安田生命ビル１１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010001259732',
    ),
    'E41162': EdinetCodeEntry(
        edinet_code='E41162',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='ワイエス興産有限会社',
        submitter_name_en=None,
        submitter_name_yomi='ワイエスコウサンユウゲンカイシャ',
        address='府中市高木町４２４番地の５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2240002046874',
    ),
    'E41164': EdinetCodeEntry(
        edinet_code='E41164',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＷＯＷＯＯ\u3000ＰＴＥ．\u3000ＬＴＤ．',
        submitter_name_en=None,
        submitter_name_yomi='ワオー\u3000プライベート\u3000リミテッド',
        address='シンガポール\u3000シンガポール市\u3000フレーザー・ストリート３番地\u3000デュオ・タワー０４－２３Ａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41165': EdinetCodeEntry(
        edinet_code='E41165',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='3月末日',
        submitter_name='株式会社ＪＧ３５',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャジェイジーサンジュウゴ',
        address='港区虎ノ門一丁目３番１号',
        industry='その他金融業',
        sec_code=None,
        corporate_number='4010401194072',
    ),
    'E41167': EdinetCodeEntry(
        edinet_code='E41167',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社Ｃｏｌｏｒ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカラー',
        address='東京都中央区日本橋三丁目２番１４号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010001258966',
    ),
    'E41168': EdinetCodeEntry(
        edinet_code='E41168',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='内山\u3000彰博',
        submitter_name_en=None,
        submitter_name_yomi='ウチヤマ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41169': EdinetCodeEntry(
        edinet_code='E41169',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3157,
        fiscal_year_end=None,
        submitter_name='Ｄｒｉｅｈａｕｓ\u3000Ｃａｐｉｔａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='ドリーハウス\u3000キャピタル\u3000マネジメント\u3000エルエルシー',
        address='アメリカ合衆国イリノイ州シカゴ、イースト・エリー・ストリート２５',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41170': EdinetCodeEntry(
        edinet_code='E41170',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4500,
        fiscal_year_end=None,
        submitter_name='Ａｎｃｈｏｒ\u3000Ｃａｐｉｔａｌ\u3000Ｇｒｏｕｐ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アンカーキャピタルグループカブシキガイシャ',
        address='目黒区青葉台１丁目６番５９号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011001171856',
    ),
    'E41173': EdinetCodeEntry(
        edinet_code='E41173',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1238550,
        fiscal_year_end=None,
        submitter_name='Ｋｕｗａｉｔ\u3000Ｐｅｔｒｏｌｅｕｍ\u3000Ｃｏｒｐｏｒａｔｉｏｎ',
        submitter_name_en=None,
        submitter_name_yomi='クウェート\u3000ペトロリウム\u3000コーポレーション',
        address='Ｏｉｌ\u3000Ｓｅｃｔｏｒ\u3000Ｃｏｍｐｌｅｘ，\u3000Ｇｕｌｆ\u3000Ｓｔｒｅｅｔ，\u3000Ｂｕｉｌｄｉｎｇ\u3000Ｎｏ\u3000９０００４０，\u3000Ｓｈｕｗａｉｋｈ\u3000Ｉｎｄｕｓｔｒｉａｌ\u3000１，\u3000Ｂｌｏｃｋ\u3000１，\u3000Ｋｕｗａｉｔ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41174': EdinetCodeEntry(
        edinet_code='E41174',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＵＭＫ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーエムケー',
        address='墨田区緑二丁目１４番１５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010001259974',
    ),
    'E41175': EdinetCodeEntry(
        edinet_code='E41175',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='赤川\u3000隼一',
        submitter_name_en=None,
        submitter_name_yomi='アカガワ\u3000ジュンイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41176': EdinetCodeEntry(
        edinet_code='E41176',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡\u3000敬太郎',
        submitter_name_en=None,
        submitter_name_yomi='オカ\u3000ケイタロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41178': EdinetCodeEntry(
        edinet_code='E41178',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=274,
        fiscal_year_end=None,
        submitter_name='カーン・グローバル・ファンド・マネージャーズ（アイルランド）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='カーングローバルファンドマネージャーズアイルランドリミテッド',
        address='アイルランド、ダブリン２\u3000Ｄ０２Ｆ９８５、シャールモント・プレイス５５、３階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41180': EdinetCodeEntry(
        edinet_code='E41180',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＨＮホールディングス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャエイチエヌホールディングス',
        address='新宿区新宿一丁目３２番４号\u3000エヌエスビル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101105794',
    ),
    'E41181': EdinetCodeEntry(
        edinet_code='E41181',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=45,
        fiscal_year_end=None,
        submitter_name='ノアグループホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ノアグループホールディングスカブシキガイシャ',
        address='姫路市東山５２４',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4140001125134',
    ),
    'E41182': EdinetCodeEntry(
        edinet_code='E41182',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='ＰＨＡＲＲＥＬＬ\u3000ＷＩＬＬＩＡＭＳ',
        submitter_name_en=None,
        submitter_name_yomi='ファレル\u3000ウィリアムス',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41184': EdinetCodeEntry(
        edinet_code='E41184',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='名富\u3000達也',
        submitter_name_en=None,
        submitter_name_yomi='ナトミ\u3000タツヤ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41185': EdinetCodeEntry(
        edinet_code='E41185',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社カバロ企画',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャカバロキカク',
        address='大田区南雪谷二丁目１７番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010801021080',
    ),
    'E41188': EdinetCodeEntry(
        edinet_code='E41188',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='酒井\u3000雅美',
        submitter_name_en=None,
        submitter_name_yomi='サカイ\u3000マサミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41191': EdinetCodeEntry(
        edinet_code='E41191',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=100,
        fiscal_year_end='12月31日',
        submitter_name='ＰＲＯＮＩ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='プロニカブシキガイシャ',
        address='品川区東五反田３－２０－１４住友不動産高輪パークタワー１２Ｆ',
        industry='情報・通信業',
        sec_code='479A0',
        corporate_number='3011001091842',
    ),
    'E41192': EdinetCodeEntry(
        edinet_code='E41192',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=235,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍｉｎｔ\u3000Ｔｏｗｎ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャミントタウン',
        address='千代田区神田錦町２－２－１\u3000神田スクエア１１Ｆ\u3000ｗｅｗｏｒｋ内',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9020001100581',
    ),
    'E41193': EdinetCodeEntry(
        edinet_code='E41193',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ソフトバンクロボティクス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ソフトバンクロボティクスカブシキガイシャ',
        address='港区海岸一丁目７番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010401113318',
    ),
    'E41196': EdinetCodeEntry(
        edinet_code='E41196',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=279,
        fiscal_year_end=None,
        submitter_name='Ｂｒａｋｅｓ\u3000Ｉｎｄｉａ\u3000Ｐｒｉｖａｔｅ\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='ブレークスインディアプライベートリミテッド',
        address='ＮＯ\u3000２１\u3000ＰＡＴＵＬＡＳ\u3000ＲＯＡＤＭＡＤＲＡＳ－６００００２．\u3000Ｔａｍｉｌ\u3000Ｎａｄｕ，\u3000Ｉｎｄｉａ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41197': EdinetCodeEntry(
        edinet_code='E41197',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ワイズハブ・インターナショナル・コーポレーション・リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ワイズハブ\u3000インターナショナル\u3000コーポレーション\u3000リミテッド',
        address='香港新界葵青葵涌打磚坪街６８号和豊工業中心２６階２６０４Ｂ室',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41198': EdinetCodeEntry(
        edinet_code='E41198',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='粟津株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アワヅカブシキカイシャ',
        address='千代田区神田佐久間町三丁目３７番地クリダイマンション７０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001234524',
    ),
    'E41200': EdinetCodeEntry(
        edinet_code='E41200',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='杉山\u3000浩一',
        submitter_name_en=None,
        submitter_name_yomi='スギヤマ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41205': EdinetCodeEntry(
        edinet_code='E41205',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=109,
        fiscal_year_end=None,
        submitter_name='カーン・グローバル・ファンド・マネージャーズ（ルクセンブルグ）エス・エイ',
        submitter_name_en=None,
        submitter_name_yomi='カーングローバルファンドマネージャーズルクセンブルグエスエイ',
        address='ルクセンブルグ大公国、ルクセンブルグ\u3000Ｌ－２３５０、ジャン・ピレー通り\u3000３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41206': EdinetCodeEntry(
        edinet_code='E41206',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='徐宏沢',
        submitter_name_en=None,
        submitter_name_yomi='ジョコウタク',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41208': EdinetCodeEntry(
        edinet_code='E41208',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='瀬戸口\u3000正章',
        submitter_name_en=None,
        submitter_name_yomi='セトグチ\u3000マサアキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41209': EdinetCodeEntry(
        edinet_code='E41209',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｉｎｔｅｇｒａｔｅｄ\u3000Ａｓｓｅｔ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000（Ａｓｉａ）\u3000Ｌｉｍｉｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='インテグレイテド\u3000アセット\u3000マネジメント\u3000アジア\u3000リミテッド',
        address='Ｖｉｓｔｒａ\u3000Ｃｏｒｐｏｒａｔｅ\u3000Ｓｅｒｖｉｃｅｓ\u3000Ｃｅｎｔｒｅ，\u3000Ｗｉｃｋｈａｍｓ\u3000Ｃａｙ\u3000ＩＩ，\u3000Ｒｏａｄ\u3000Ｔｏｗｎ，\u3000Ｔｏｒｔｏｌａ，ＶＧ１１１０，Ｂｒｉｔｉｓｈ\u3000Ｖｉｒｇｉｎ\u3000Ｉｓｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41211': EdinetCodeEntry(
        edinet_code='E41211',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木田\u3000志郎',
        submitter_name_en=None,
        submitter_name_yomi='キダ\u3000シロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41212': EdinetCodeEntry(
        edinet_code='E41212',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='木田\u3000睦',
        submitter_name_en=None,
        submitter_name_yomi='キダ\u3000ムツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41217': EdinetCodeEntry(
        edinet_code='E41217',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='前田\u3000知紘',
        submitter_name_en=None,
        submitter_name_yomi='マエダ\u3000トモヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41218': EdinetCodeEntry(
        edinet_code='E41218',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐々木\u3000耕平',
        submitter_name_en=None,
        submitter_name_yomi='ササキ\u3000コウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41219': EdinetCodeEntry(
        edinet_code='E41219',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='加藤\u3000博己',
        submitter_name_en=None,
        submitter_name_yomi='カトウ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41220': EdinetCodeEntry(
        edinet_code='E41220',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小松\u3000亮太',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000リョウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41225': EdinetCodeEntry(
        edinet_code='E41225',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=150,
        fiscal_year_end=None,
        submitter_name='グリーンライト・再エネインフラ投資法人',
        submitter_name_en=None,
        submitter_name_yomi='グリーンライトサイエネインフラトウシホウジン',
        address='港区東新橋一丁目５番２号\u3000汐留シティセンター８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010405024525',
    ),
    'E41228': EdinetCodeEntry(
        edinet_code='E41228',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=4427,
        fiscal_year_end=None,
        submitter_name='ＭＮインターファッション株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エムエヌインターファッションカブシキガイシャ',
        address='港区元赤坂一丁目２番７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010401056967',
    ),
    'E41231': EdinetCodeEntry(
        edinet_code='E41231',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='笛木\u3000正司',
        submitter_name_en=None,
        submitter_name_yomi='フエキ\u3000マサツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41233': EdinetCodeEntry(
        edinet_code='E41233',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永田\u3000尚',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000ヒサシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41235': EdinetCodeEntry(
        edinet_code='E41235',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=10000,
        fiscal_year_end='3月31日',
        submitter_name='ＭＩＲＡＩＮＩホールディングス株式会社',
        submitter_name_en='MIRAINI HOLDINGS CO., LTD.',
        submitter_name_yomi='ミライニホールディングスカブシキガイシャ',
        address='港区芝一丁目１４番１０号',
        industry='電気機器',
        sec_code=None,
        corporate_number=None,
    ),
    'E41237': EdinetCodeEntry(
        edinet_code='E41237',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='天野\u3000太郎',
        submitter_name_en=None,
        submitter_name_yomi='アマノ\u3000タロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41238': EdinetCodeEntry(
        edinet_code='E41238',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山崎\u3000祐二',
        submitter_name_en=None,
        submitter_name_yomi='ヤマサキ\u3000ユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41240': EdinetCodeEntry(
        edinet_code='E41240',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='吉永\u3000安宏',
        submitter_name_en=None,
        submitter_name_yomi='ヨシナガ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41242': EdinetCodeEntry(
        edinet_code='E41242',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岡﨑\u3000太輔',
        submitter_name_en=None,
        submitter_name_yomi='オカザキ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41244': EdinetCodeEntry(
        edinet_code='E41244',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='宮本\u3000一成',
        submitter_name_en=None,
        submitter_name_yomi='ミヤモト\u3000カズナリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41246': EdinetCodeEntry(
        edinet_code='E41246',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='平石\u3000智紀',
        submitter_name_en=None,
        submitter_name_yomi='ヒライシ\u3000トモキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41247': EdinetCodeEntry(
        edinet_code='E41247',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=34,
        fiscal_year_end=None,
        submitter_name='株式会社プルータス・コンサルティング',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャプルータスコンサルティング',
        address='千代田区霞が関三丁目２番５号\u3000霞が関ビルディング３５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401070264',
    ),
    'E41248': EdinetCodeEntry(
        edinet_code='E41248',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=274,
        fiscal_year_end=None,
        submitter_name='ＡＶＩ\u3000ＪＡＰＡＮ\u3000ＯＰＰＯＲＴＵＮＩＴＹ\u3000ＴＲＵＳＴ\u3000ｐｌｃ',
        submitter_name_en=None,
        submitter_name_yomi='エーブイアイ\u3000ジャパン\u3000オポチュニティー\u3000トラスト\u3000ピーエルシー',
        address='英国ＥＣ３Ｍ７ＤＱ\u3000ロンドン、ライム・ストリート５１、１９階',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41251': EdinetCodeEntry(
        edinet_code='E41251',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=1,
        fiscal_year_end='7月31日',
        submitter_name='合同会社ＫＮサンク福岡',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャケーエヌサンクフクオカ',
        address='福岡市早良区昭代１－２１－２',
        industry='証券、商品先物取引業',
        sec_code=None,
        corporate_number='7290003012890',
    ),
    'E41252': EdinetCodeEntry(
        edinet_code='E41252',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='公益財団法人山口記念科学振興財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンヤマグチキネンカガクシンコウザイダン',
        address='千代田区岩本町二丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010005028029',
    ),
    'E41254': EdinetCodeEntry(
        edinet_code='E41254',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=200,
        fiscal_year_end=None,
        submitter_name='日本エイサー株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンエイサーカブシキガイシャ',
        address='新宿区西新宿６丁目２４－１',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011101049983',
    ),
    'E41257': EdinetCodeEntry(
        edinet_code='E41257',
        submitter_type='内国法人・組合',
        listing_status='上場',
        consolidated='無',
        capital_million_yen=9,
        fiscal_year_end='4月30日',
        submitter_name='株式会社ＴＯブックス',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャティーオーブックス',
        address='渋谷区桜丘町１番１号',
        industry='情報・通信業',
        sec_code='500A0',
        corporate_number='3011001100140',
    ),
    'E41258': EdinetCodeEntry(
        edinet_code='E41258',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社\u3000光輝ＥＮＥＲＧＹ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャ\u3000コウキエナジー',
        address='つくば市吾妻１丁目５番７号\u3000ダイワロイネットホテルつくばビル２階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3050001040649',
    ),
    'E41262': EdinetCodeEntry(
        edinet_code='E41262',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｒ１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アールワンカブシキガイシャ',
        address='港区虎ノ門二丁目６番１号\u3000虎ノ門ヒルズステーションタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010401194196',
    ),
    'E41263': EdinetCodeEntry(
        edinet_code='E41263',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社アトライ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャアトライ',
        address='港区台場一丁目１番２ー７０７号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401085650',
    ),
    'E41264': EdinetCodeEntry(
        edinet_code='E41264',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='廣瀨\u3000周栄',
        submitter_name_en=None,
        submitter_name_yomi='ヒロセ\u3000シュウエイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41271': EdinetCodeEntry(
        edinet_code='E41271',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大谷\u3000彰宏',
        submitter_name_en=None,
        submitter_name_yomi='オオタニ\u3000アキヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41272': EdinetCodeEntry(
        edinet_code='E41272',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000將道',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000マサミチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41273': EdinetCodeEntry(
        edinet_code='E41273',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000克栄',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000カツエイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41274': EdinetCodeEntry(
        edinet_code='E41274',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='横嶋\u3000大輔',
        submitter_name_en=None,
        submitter_name_yomi='ヨコシマ\u3000タイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41275': EdinetCodeEntry(
        edinet_code='E41275',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='ＴＰＭ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーピーエムカブシキガイシャ',
        address='中央区明石町８番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001087256',
    ),
    'E41276': EdinetCodeEntry(
        edinet_code='E41276',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＴＣＧ２５０９株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ティーシージーニーゴーゼロキュウカブシキガイシャ',
        address='千代田区丸の内一丁目５番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4010001260398',
    ),
    'E41279': EdinetCodeEntry(
        edinet_code='E41279',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='長谷川\u3000新里',
        submitter_name_en=None,
        submitter_name_yomi='ハセガワ\u3000シンリ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41280': EdinetCodeEntry(
        edinet_code='E41280',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='白木\u3000孝一',
        submitter_name_en=None,
        submitter_name_yomi='シラキ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41281': EdinetCodeEntry(
        edinet_code='E41281',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='西村\u3000賢治',
        submitter_name_en=None,
        submitter_name_yomi='ニシムラ\u3000ケンジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41282': EdinetCodeEntry(
        edinet_code='E41282',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=9000,
        fiscal_year_end=None,
        submitter_name='エピック・パートナーズ・インベストメンツ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エピックパートナーズインベストメンツカブシキガイシャ',
        address='港区虎ノ門四丁目１番１号神谷町トラストタワ－２５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001109271',
    ),
    'E41284': EdinetCodeEntry(
        edinet_code='E41284',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=120,
        fiscal_year_end=None,
        submitter_name='ＣＯＳＭＯ\u3000ＰＲＩＭＥ\u3000ＰＴＥ\u3000ＬＴＤ',
        submitter_name_en=None,
        submitter_name_yomi='コスモプライム\u3000プレイベートリミテッド',
        address='１０\u3000ＡＮＳＯＮ\u3000ＲＯＡＤ，＃０９ー０１，ＩＮＴＥＲＮＡＴＩＯＮＡＬ\u3000ＰＬＡＺＡ，\u3000ＳＩＮＧＡＰＯＲＥ\u3000０７９９０３',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41289': EdinetCodeEntry(
        edinet_code='E41289',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＣＳＲＩ５号株式会社',
        submitter_name_en=None,
        submitter_name_yomi='シーエスアールアイゴゴウカブシキカイシャ',
        address='千代田区大手町二丁目２番１号新大手町ビル８階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001256321',
    ),
    'E41290': EdinetCodeEntry(
        edinet_code='E41290',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='石川\u3000敬啓',
        submitter_name_en=None,
        submitter_name_yomi='イシカワ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41293': EdinetCodeEntry(
        edinet_code='E41293',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ビーシーピーイー\u3000セイ\u3000ケイマン\u3000エルピー',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーピーイー\u3000セイ\u3000ケイマン\u3000エルピー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランドケイマン、ジョージタウン、サウスチャーチストリート、アグランドハウス、私書箱３０９、メープルズ・コーポレート・サービシーズ・リミテッド',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41296': EdinetCodeEntry(
        edinet_code='E41296',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='株式会社Ｍｅｄｉｃａｌ\u3000Ｍａｎａｇｅｍｅｎｔ\u3000Ｃｏｎｓｕｌｔｉｎｇ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャメディカルマネジメントコンサルティング',
        address='大阪市淀川区西中島五丁目１４番５号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7120001227631',
    ),
    'E41297': EdinetCodeEntry(
        edinet_code='E41297',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=11,
        fiscal_year_end=None,
        submitter_name='サファイア・キャピタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サファイア\u3000キャピタルカブシキガイシャ',
        address='中央区日本橋一丁目１３番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010001174860',
    ),
    'E41298': EdinetCodeEntry(
        edinet_code='E41298',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='関\u3000厳',
        submitter_name_en=None,
        submitter_name_yomi='セキ\u3000イワオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41302': EdinetCodeEntry(
        edinet_code='E41302',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＬＶＪホールディングス２合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エルブイジェイホールディングスツーゴウドウガイシャ',
        address='千代田区丸の内二丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010003048897',
    ),
    'E41304': EdinetCodeEntry(
        edinet_code='E41304',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ＦＡＲＯＵＴ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャファーアウト',
        address='港区六本木１丁目６番１号泉ガーデンタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9010401155838',
    ),
    'E41305': EdinetCodeEntry(
        edinet_code='E41305',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='堀内\u3000康弘',
        submitter_name_en=None,
        submitter_name_yomi='ホリウチ\u3000ヤスヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41306': EdinetCodeEntry(
        edinet_code='E41306',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＭａａａａＲｕホールディングス株式会社',
        submitter_name_en=None,
        submitter_name_yomi='マールホールディングスカブシキガイシャ',
        address='中野区若宮三丁目１２番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5011201025425',
    ),
    'E41307': EdinetCodeEntry(
        edinet_code='E41307',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=350,
        fiscal_year_end=None,
        submitter_name='株式会社リクルート',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャリクルート',
        address='千代田区丸の内１ー９ー２\u3000グラントウキョウサウスタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001149426',
    ),
    'E41309': EdinetCodeEntry(
        edinet_code='E41309',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='無',
        capital_million_yen=30,
        fiscal_year_end='5月11日',
        submitter_name='株式会社ギークリー',
        submitter_name_en='Geekly , Inc.',
        submitter_name_yomi='カブシキカイシャギークリー',
        address='東京都渋谷区渋谷二丁目１７番１号',
        industry='サービス業',
        sec_code=None,
        corporate_number='7011001072459',
    ),
    'E41310': EdinetCodeEntry(
        edinet_code='E41310',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＳＢＣ\u3000Ｍｅｄｉｃａｌ\u3000Ｇｒｏｕｐ\u3000Ｉｎｃｏｒｐｏｒａｔｅｄ',
        submitter_name_en=None,
        submitter_name_yomi='エスビーシー\u3000メディカルグループ\u3000インコーポレイテッド',
        address='２００\u3000Ｓｐｅｃｔｒｕｍ\u3000ＣＥＮＴＥＲ\u3000Ｄｒｉｖｅ，\u3000Ｓｕｉｔｅ\u3000３００\u3000Ｉｒｖｉｎｅ，\u3000ＣＡ\u3000９２',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41311': EdinetCodeEntry(
        edinet_code='E41311',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='栗山\u3000規夫',
        submitter_name_en=None,
        submitter_name_yomi='クリヤマ\u3000ノリオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41312': EdinetCodeEntry(
        edinet_code='E41312',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='柴田\u3000大介',
        submitter_name_en=None,
        submitter_name_yomi='シバタ\u3000ダイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41315': EdinetCodeEntry(
        edinet_code='E41315',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='原\u3000茂樹',
        submitter_name_en=None,
        submitter_name_yomi='ハラ\u3000シゲキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41317': EdinetCodeEntry(
        edinet_code='E41317',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='冨岡\u3000市子',
        submitter_name_en=None,
        submitter_name_yomi='トミオカ\u3000イチコ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41318': EdinetCodeEntry(
        edinet_code='E41318',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=4131,
        fiscal_year_end='12月末日',
        submitter_name='イノバセル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='イノバセルカブシキガイシャ',
        address='品川区上大崎３－５－１１\u3000目黒ヴィラガーデン５階',
        industry='医薬品',
        sec_code=None,
        corporate_number='1011001137886',
    ),
    'E41319': EdinetCodeEntry(
        edinet_code='E41319',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='神谷\u3000陽一郎',
        submitter_name_en=None,
        submitter_name_yomi='カミタニ\u3000ヨウイチロウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41321': EdinetCodeEntry(
        edinet_code='E41321',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='タイヨー興産株式会社',
        submitter_name_en=None,
        submitter_name_yomi='タイヨーコウサンカブシキガイシャ',
        address='久留米市篠山町一丁目１２番３パークノヴァ５０１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3290001049088',
    ),
    'E41323': EdinetCodeEntry(
        edinet_code='E41323',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=2000,
        fiscal_year_end='3月31日',
        submitter_name='株式会社トランヴィア',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャトランヴィア',
        address='文京区小石川一丁目１２番１４号',
        industry='情報・通信業',
        sec_code=None,
        corporate_number=None,
    ),
    'E41324': EdinetCodeEntry(
        edinet_code='E41324',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩藤\u3000知義',
        submitter_name_en=None,
        submitter_name_yomi='イワドウ\u3000トモヨシ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41327': EdinetCodeEntry(
        edinet_code='E41327',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大西\u3000洋',
        submitter_name_en=None,
        submitter_name_yomi='オオニシ\u3000ヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41328': EdinetCodeEntry(
        edinet_code='E41328',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='榎園\u3000利浩',
        submitter_name_en=None,
        submitter_name_yomi='エノキゾノ\u3000トシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41329': EdinetCodeEntry(
        edinet_code='E41329',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='權田\u3000和士',
        submitter_name_en=None,
        submitter_name_yomi='ゴンダ\u3000カズヒト',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41330': EdinetCodeEntry(
        edinet_code='E41330',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山本裕治',
        submitter_name_en=None,
        submitter_name_yomi='ヤマモトユウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41333': EdinetCodeEntry(
        edinet_code='E41333',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='黒瀬\u3000康太',
        submitter_name_en=None,
        submitter_name_yomi='クロセ\u3000コウタ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41334': EdinetCodeEntry(
        edinet_code='E41334',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=113,
        fiscal_year_end=None,
        submitter_name='ＵＢＳマネジメント（ケイマン）リミテッド',
        submitter_name_en=None,
        submitter_name_yomi='ユービーエスマネジメントケイマンリミテッド',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン、ジョージ・タウン、ウグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41336': EdinetCodeEntry(
        edinet_code='E41336',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='一般社団法人ブルーツリー',
        submitter_name_en=None,
        submitter_name_yomi='イッパンシャダンホウジンブルーツリー',
        address='新宿区富久町５番６号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011105011563',
    ),
    'E41338': EdinetCodeEntry(
        edinet_code='E41338',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='三瓶悦男',
        submitter_name_en=None,
        submitter_name_yomi='サンペイ\u3000エツオ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41348': EdinetCodeEntry(
        edinet_code='E41348',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｔｉｇｅｒ投資事業有限責任組合',
        submitter_name_en=None,
        submitter_name_yomi='タイガートウシジギョウユウゲンセキニンクミアイ',
        address='渋谷区神宮前一丁目５番８号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41350': EdinetCodeEntry(
        edinet_code='E41350',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=701,
        fiscal_year_end=None,
        submitter_name='Ｏｐｅｎｆｉｎｄ\u3000Ｉｎｆｏｒｍａｔｉｏｎ\u3000Ｔｅｃｈｎｏｌｏｇｙ，Ｉｎｃ．',
        submitter_name_en=None,
        submitter_name_yomi='オープンファインドインフォメーションテクノロジー',
        address='台湾台北市北投區承徳路六段１２０號７樓',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41352': EdinetCodeEntry(
        edinet_code='E41352',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='合同会社つながる',
        submitter_name_en=None,
        submitter_name_yomi='ゴウドウカイシャツナガル',
        address='愛知県知多市にしの台四丁目１５－４－２０６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180003023445',
    ),
    'E41353': EdinetCodeEntry(
        edinet_code='E41353',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=65,
        fiscal_year_end=None,
        submitter_name='株式会社Ｔｉｇｅｒ\u3000Ｊａｐａｎ\u3000Ｉｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャタイガージャパンインベストメント',
        address='渋谷区千駄ヶ谷五丁目１５番６号マークス北参道５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8010001093992',
    ),
    'E41354': EdinetCodeEntry(
        edinet_code='E41354',
        submitter_type='内国法人・組合',
        listing_status='非上場',
        consolidated='有',
        capital_million_yen=300,
        fiscal_year_end='3月31日',
        submitter_name='ＧＭＳグループ株式会社',
        submitter_name_en='GMS Group Co,.Ltd.',
        submitter_name_yomi='ジーエムエスグループカブシキカイシャ',
        address='千代田区丸の内２－５－２三菱ビル８階',
        industry='機械',
        sec_code=None,
        corporate_number=None,
    ),
    'E41360': EdinetCodeEntry(
        edinet_code='E41360',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='名越\u3000美嗣',
        submitter_name_en=None,
        submitter_name_yomi='ナゴシ\u3000ヨシツグ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41366': EdinetCodeEntry(
        edinet_code='E41366',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='アキュメン株式会社',
        submitter_name_en=None,
        submitter_name_yomi='アキュメンカブシキガイシャ',
        address='武蔵野市吉祥寺本町一丁目２０番１号吉祥寺永谷シティプラザ１００２',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7290001058028',
    ),
    'E41367': EdinetCodeEntry(
        edinet_code='E41367',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今中\u3000康仁',
        submitter_name_en=None,
        submitter_name_yomi='イマナカ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41368': EdinetCodeEntry(
        edinet_code='E41368',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='澤田\u3000人輔',
        submitter_name_en=None,
        submitter_name_yomi='サワダ\u3000ジンスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41369': EdinetCodeEntry(
        edinet_code='E41369',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='小松\u3000圭介',
        submitter_name_en=None,
        submitter_name_yomi='コマツ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41372': EdinetCodeEntry(
        edinet_code='E41372',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今村\u3000誉一',
        submitter_name_en=None,
        submitter_name_yomi='イマムラ\u3000ヨイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41376': EdinetCodeEntry(
        edinet_code='E41376',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=416,
        fiscal_year_end=None,
        submitter_name='株式会社ＴＢＭ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャティービーエム',
        address='千代田区有楽町一丁目２番２号\u3000東宝日比谷ビル１５階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010401095495',
    ),
    'E41377': EdinetCodeEntry(
        edinet_code='E41377',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ｓａｎｔｅｃ\u3000Ｊａｐａｎ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='サンテックジャパンカブシキカイシャ',
        address='小牧市大草年上坂５８２３フォトニクスバレー大草キャンパス',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7180001151520',
    ),
    'E41378': EdinetCodeEntry(
        edinet_code='E41378',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｒｏｏｄｈａｌｓｇａｎｓ\u3000１株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ルードハルスガンスワンカブシキガイシャ',
        address='東京都港区麻布台一丁目３番１号麻布台ヒルズ森ＪＰタワー１７階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='7010401194904',
    ),
    'E41379': EdinetCodeEntry(
        edinet_code='E41379',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=19,
        fiscal_year_end=None,
        submitter_name='株式会社ＪＩＲＡＮ\u3000ＪＡＰＡＮ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャジランジャパン',
        address='港区海岸１ー７ー１ポートシティ竹芝１０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6011101060323',
    ),
    'E41381': EdinetCodeEntry(
        edinet_code='E41381',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='弓場\u3000一輝',
        submitter_name_en=None,
        submitter_name_yomi='ユミバ\u3000カズキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41382': EdinetCodeEntry(
        edinet_code='E41382',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社チェックマル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャチェックマル',
        address='京畿道龍仁市樹脂区新水路７６７、栄東１３０８号（東川洞、盆唐樹脂油塔',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41383': EdinetCodeEntry(
        edinet_code='E41383',
        submitter_type='個人（非居住者）（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='イ\u3000スジョン',
        submitter_name_en=None,
        submitter_name_yomi='イ\u3000スジョン',
        address=None,
        industry='個人（非居住者）（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41384': EdinetCodeEntry(
        edinet_code='E41384',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=100,
        fiscal_year_end=None,
        submitter_name='株式会社ＧＯＯＹＡ\u3000Ｈｏｌｄｉｎｇｓ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャゴーヤホールディングス',
        address='渋谷区渋谷１－１７－４－１０階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='4011001136175',
    ),
    'E41385': EdinetCodeEntry(
        edinet_code='E41385',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='北條\u3000麿',
        submitter_name_en=None,
        submitter_name_yomi='ホウジョウ\u3000タクマ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41386': EdinetCodeEntry(
        edinet_code='E41386',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='カン\u3000ミンジェ',
        submitter_name_en=None,
        submitter_name_yomi='カン\u3000ミンジェ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41387': EdinetCodeEntry(
        edinet_code='E41387',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='山下\u3000卓宏',
        submitter_name_en=None,
        submitter_name_yomi='ヤマシタ\u3000タカヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41388': EdinetCodeEntry(
        edinet_code='E41388',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='トヨタアセット準備株式会社',
        submitter_name_en=None,
        submitter_name_yomi='トヨタアセットジュンビカブシキカイシャ',
        address='千代田区有楽町一丁目１番２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001255894',
    ),
    'E41397': EdinetCodeEntry(
        edinet_code='E41397',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂｏｓｐｏｌｄｅｒ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ボスポルダー\u3000ビー\u3000ヴィ',
        address='オランダ\u3000アムステルダム\u3000１１０１ＣＭ\u3000ヘリカーベルクウェグ８４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41398': EdinetCodeEntry(
        edinet_code='E41398',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=499,
        fiscal_year_end=None,
        submitter_name='日本パレットレンタル株式会社',
        submitter_name_en=None,
        submitter_name_yomi='ニホンパレットレンタルカブシキガイシャ',
        address='千代田区大手町１－１－３\u3000大手センタービル',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001062380',
    ),
    'E41399': EdinetCodeEntry(
        edinet_code='E41399',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｂｏｓｐｏｌｄｅｒ\u3000Ｐａｒｅｎｔ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='ボスポルダー\u3000ペアレント\u3000ビー\u3000ヴィ',
        address='オランダ\u3000アムステルダム\u3000１１０１ＣＭ\u3000ヘリカーベルクウェグ８４',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41400': EdinetCodeEntry(
        edinet_code='E41400',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='松井\u3000隆二',
        submitter_name_en=None,
        submitter_name_yomi='マツイ\u3000リュウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41402': EdinetCodeEntry(
        edinet_code='E41402',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=8,
        fiscal_year_end=None,
        submitter_name='ひびき・パース・アドバイザーズ・エスピーシー',
        submitter_name_en=None,
        submitter_name_yomi='ヒビキパースアドバイザーズエスピーシー',
        address='ケイマン諸島、ＫＹ１－１１０４、グランド・ケイマン島、アグランド・ハウス、私書箱３０９番',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41406': EdinetCodeEntry(
        edinet_code='E41406',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='渡邊\u3000弘樹',
        submitter_name_en=None,
        submitter_name_yomi='ワタナベ\u3000ヒロキ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41407': EdinetCodeEntry(
        edinet_code='E41407',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｆｒａｎｃｉｓ\u3000Ｃａｐｉｔａｌ\u3000Ｉｎｃ',
        submitter_name_en=None,
        submitter_name_yomi='フランシスキャピタルカブシキガイシャ',
        address='２０４５Ｎ\u3000Ｄｏｂｓｏｎ\u3000Ｒｄ\u3000Ｓｔｅ\u3000＃１\u3000Ｃｈａｎｄｌｅｒ\u3000ＡＺ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41408': EdinetCodeEntry(
        edinet_code='E41408',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='田辺\u3000啓輔',
        submitter_name_en=None,
        submitter_name_yomi='タナベ\u3000ケイスケ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41410': EdinetCodeEntry(
        edinet_code='E41410',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＮＳＳＫ－ＧＡＭＭＡ２合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エヌエスエスケーガンマツーゴウドウカイシャ',
        address='港区愛宕二丁目５番１号愛宕グリーンヒルズＭＯＲＩタワー',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010403036916',
    ),
    'E41413': EdinetCodeEntry(
        edinet_code='E41413',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='竹内\u3000真',
        submitter_name_en=None,
        submitter_name_yomi='タケウチ\u3000シン',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41414': EdinetCodeEntry(
        edinet_code='E41414',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社バロン',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャバロン',
        address='千代田区丸の内二丁目３番２号郵船ビルディング１階',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3010001261975',
    ),
    'E41416': EdinetCodeEntry(
        edinet_code='E41416',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='Ｂｙ３株式会社',
        submitter_name_en=None,
        submitter_name_yomi='バイスリーカブシキガイシャ',
        address='中野区中野三丁目３４番３２号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='8011201026131',
    ),
    'E41417': EdinetCodeEntry(
        edinet_code='E41417',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='佐藤\u3000洋一',
        submitter_name_en=None,
        submitter_name_yomi='サトウ\u3000ヒロカズ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41418': EdinetCodeEntry(
        edinet_code='E41418',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=13,
        fiscal_year_end=None,
        submitter_name='ＵＬＴＩＭＡＴＥ\u3000ＣＬＡＳＳＩＣ\u3000ＩＮＶＥＳＴＭＥＮＴ\u3000ＬＬＣ',
        submitter_name_en=None,
        submitter_name_yomi='アルティメイトクラシックインベストメントエルエルシー',
        address='アラブ首長国連邦ドバイ首長国アル・バルシャ１地区ヘリテージ・ビルディングオフィス番号６０１－５８（アブドゥル・ラフマン・ハッサン・モハメド・アル・ロスタマニ所有）',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41423': EdinetCodeEntry(
        edinet_code='E41423',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='實吉\u3000政知',
        submitter_name_en=None,
        submitter_name_yomi='サネヨシ\u3000マサトモ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41426': EdinetCodeEntry(
        edinet_code='E41426',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='古川\u3000宏',
        submitter_name_en=None,
        submitter_name_yomi='フルカワ\u3000コウ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41427': EdinetCodeEntry(
        edinet_code='E41427',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='髙﨑\u3000誠司',
        submitter_name_en=None,
        submitter_name_yomi='タカサキ\u3000セイジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41431': EdinetCodeEntry(
        edinet_code='E41431',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='ＡＣＶＥホールディングス合同会社',
        submitter_name_en=None,
        submitter_name_yomi='エーシーブイイーホールディングスゴウドウガイシャ',
        address='千代田区丸の内三丁目２番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010003036642',
    ),
    'E41435': EdinetCodeEntry(
        edinet_code='E41435',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='河野\u3000広勝',
        submitter_name_en=None,
        submitter_name_yomi='カワノ\u3000ヒロカツ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41436': EdinetCodeEntry(
        edinet_code='E41436',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=20,
        fiscal_year_end=None,
        submitter_name='Ｌ＆Ｙ貿易株式会社',
        submitter_name_en=None,
        submitter_name_yomi='エルアンドワイボウエキカブシキガイシャ',
        address='前橋市問屋町２－１３－６',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='3070001032149',
    ),
    'E41442': EdinetCodeEntry(
        edinet_code='E41442',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='岩本\u3000恭平',
        submitter_name_en=None,
        submitter_name_yomi='イワモト\u3000キョウヘイ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41443': EdinetCodeEntry(
        edinet_code='E41443',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=10,
        fiscal_year_end=None,
        submitter_name='株式会社Ｕｃａｐｉ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャユーキャピ',
        address='港区白金台五丁目８番３号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='6010401194070',
    ),
    'E41445': EdinetCodeEntry(
        edinet_code='E41445',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='大森\u3000達司',
        submitter_name_en=None,
        submitter_name_yomi='オオモリ\u3000タツジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41447': EdinetCodeEntry(
        edinet_code='E41447',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=3,
        fiscal_year_end=None,
        submitter_name='公益財団法人アミファ・デザイン・アート振興財団',
        submitter_name_en=None,
        submitter_name_yomi='コウエキザイダンホウジンアミファデザインアートシンコウザイダン',
        address='港区北青山２－１３－５',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='1010405022934',
    ),
    'E41448': EdinetCodeEntry(
        edinet_code='E41448',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=0,
        fiscal_year_end=None,
        submitter_name='ＢＣＰＥ\u3000Ｍｅｔａ\u3000Ｃａｙｍａｎ，\u3000Ｌ．Ｐ．',
        submitter_name_en=None,
        submitter_name_yomi='ビーシーピーイー\u3000メタ\u3000ケイマン\u3000エルピー',
        address='ケイマン諸島、グランド・ケイマン、ＫＹ１－１１０４、アグランド・ハウス、私書箱３０９',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41449': EdinetCodeEntry(
        edinet_code='E41449',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｆｌｏｗｅｒｓ株式会社',
        submitter_name_en=None,
        submitter_name_yomi='フラワーズカブシキカイシャ',
        address='中央区日本橋室町２丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010001262311',
    ),
    'E41453': EdinetCodeEntry(
        edinet_code='E41453',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='熊谷\u3000浩二',
        submitter_name_en=None,
        submitter_name_yomi='クマガイ\u3000コウジ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41455': EdinetCodeEntry(
        edinet_code='E41455',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='藤田\u3000好邦',
        submitter_name_en=None,
        submitter_name_yomi='フジタ\u3000ヨシクニ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41456': EdinetCodeEntry(
        edinet_code='E41456',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='永田\u3000剛一',
        submitter_name_en=None,
        submitter_name_yomi='ナガタ\u3000コウイチ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41457': EdinetCodeEntry(
        edinet_code='E41457',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='各務\u3000勝己',
        submitter_name_en=None,
        submitter_name_yomi='カガミ\u3000カツミ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41458': EdinetCodeEntry(
        edinet_code='E41458',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社ビーブライト',
        submitter_name_en=None,
        submitter_name_yomi='カブシキカイシャビーブライト',
        address='西宮市丸橋町４－８',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='9140001134460',
    ),
    'E41462': EdinetCodeEntry(
        edinet_code='E41462',
        submitter_type='個人（組合発行者を除く）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=None,
        fiscal_year_end=None,
        submitter_name='今井\u3000芳博',
        submitter_name_en=None,
        submitter_name_yomi='イマイ\u3000ヨシヒロ',
        address=None,
        industry='個人（組合発行者を除く）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41463': EdinetCodeEntry(
        edinet_code='E41463',
        submitter_type='外国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='Ｍｏｔｈｅｒｓｏｎ\u3000Ｇｌｏｂａｌ\u3000Ｉｎｖｅｓｔｍｅｎｔｓ\u3000Ｂ．Ｖ．',
        submitter_name_en=None,
        submitter_name_yomi='マザーサン\u3000グローバル\u3000インベストメンツ\u3000ビーブイ',
        address='Ｒｉｊｎｓｂｕｒｇｓｔｒａａｔ\u3000９，\u3000１０５９ＡＴ\u3000Ａｍｓｔｅｒｄａｍ，\u3000Ｔｈｅ\u3000Ｎｅｔｈｅｒｌａｎｄｓ',
        industry='外国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number=None,
    ),
    'E41464': EdinetCodeEntry(
        edinet_code='E41464',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=1,
        fiscal_year_end=None,
        submitter_name='株式会社フエル',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフエル',
        address='品川区西五反田８丁目１－１３',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='2010001230353',
    ),
    'E41469': EdinetCodeEntry(
        edinet_code='E41469',
        submitter_type='内国法人・組合（有価証券報告書等の提出義務者以外）',
        listing_status=None,
        consolidated=None,
        capital_million_yen=25,
        fiscal_year_end=None,
        submitter_name='株式会社Ｆｉｘｓｔａｒｓ\u3000Ｉｎｖｅｓｔｍｅｎｔ',
        submitter_name_en=None,
        submitter_name_yomi='カブシキガイシャフィックスターズインベストメント',
        address='港区芝浦１丁目１番１号',
        industry='内国法人・組合（有価証券報告書等の提出義務者以外）',
        sec_code=None,
        corporate_number='5010401181549',
    ),
}

EDINET_CODE_RECORD_COUNT = len(_EDINET_CODE_TABLE)

_warned_unknown_edinet_codes: set[str] = set()


def get_edinet_code(code: str) -> EdinetCodeEntry | None:
    """EDINETコードから EdinetCodeEntry を返す。"""
    entry = _EDINET_CODE_TABLE.get(code)
    if entry is None and code not in _warned_unknown_edinet_codes:
        _warned_unknown_edinet_codes.add(code)
        warnings.warn(
            f"Unknown edinetCode: {code!r}.",
            category=EdinetWarning,
            stacklevel=2,
        )
    return entry


def all_edinet_codes() -> list[EdinetCodeEntry]:
    """全EDINETコードの一覧を返す。"""
    return list(_EDINET_CODE_TABLE.values())


def _normalize_sec_code(sec_code: str) -> str:
    """証券コードを5桁に正規化する。

    Args:
        sec_code: 証券コード（4桁または5桁）。

    Returns:
        5桁に正規化された証券コード。
    """
    sec_code = sec_code.strip()
    if len(sec_code) == 4:
        return sec_code + "0"
    return sec_code


def _normalize(text: str) -> str:
    """検索用にテキストを正規化する（NFKC + 小文字）。

    全角英数字を半角に統一し、大文字小文字を区別しない検索を可能にする。
    例: ``"三菱ＵＦＪ"`` → ``"三菱ufj"``
    """
    import unicodedata

    return unicodedata.normalize("NFKC", text).lower()


def _match_rank(entry: EdinetCodeEntry, query_normalized: str) -> int:
    """エントリと検索クエリのマッチ度を返す。

    クエリとエントリ名は NFKC 正規化 + 小文字化済みの前提。

    Returns:
        0: submitter_name が query で始まる（最優先）
        1: submitter_name_en が query で始まる
        2: submitter_name_yomi が query で始まる
        3: いずれかのフィールドに query を含む（部分一致）
        -1: マッチしない
    """
    name = _normalize(entry.submitter_name)
    if name.startswith(query_normalized):
        return 0
    name_en = _normalize(entry.submitter_name_en) if entry.submitter_name_en else None
    if name_en and name_en.startswith(query_normalized):
        return 1
    name_yomi = _normalize(entry.submitter_name_yomi) if entry.submitter_name_yomi else None
    if name_yomi and name_yomi.startswith(query_normalized):
        return 2
    if query_normalized in name:
        return 3
    if name_en and query_normalized in name_en:
        return 3
    if name_yomi and query_normalized in name_yomi:
        return 3
    return -1


def search_edinet_codes(
    query: str,
    *,
    limit: int = 20,
) -> list[EdinetCodeEntry]:
    """企業名でEdinetCodeEntryを部分一致検索する。

    ``submitter_name`` / ``submitter_name_en`` / ``submitter_name_yomi`` の
    いずれかに ``query`` が含まれるエントリを返す。
    全角半角を正規化（NFKC）し、大文字・小文字を区別しない。

    結果は関連度順にソートされる:
    - 名前が query で始まるもの（prefix match）が先頭
    - 名前に query を含むもの（contains match）が後続

    Args:
        query: 検索キーワード。空文字の場合は空リストを返す。
            全角・半角どちらでも検索可能（例: ``"三菱UFJ"`` と
            ``"三菱ＵＦＪ"`` は同一視される）。
        limit: 最大返却件数。0で無制限。

    Returns:
        マッチしたEdinetCodeEntryのリスト（関連度順）。
    """
    if not query:
        return []
    query_normalized = _normalize(query)
    ranked: list[tuple[int, EdinetCodeEntry]] = []
    for entry in all_edinet_codes():
        rank = _match_rank(entry, query_normalized)
        if rank >= 0:
            ranked.append((rank, entry))
    ranked.sort(key=lambda t: t[0])
    results = [entry for _, entry in ranked]
    if limit > 0:
        results = results[:limit]
    return results


def get_edinet_code_by_sec_code(sec_code: str) -> EdinetCodeEntry | None:
    """証券コードからEdinetCodeEntryを返す。

    4桁の場合は末尾に ``"0"`` を付与して5桁にしてから検索する。

    Args:
        sec_code: 証券コード（4桁または5桁）。

    Returns:
        マッチしたEdinetCodeEntry。見つからない場合はNone。
    """
    normalized = _normalize_sec_code(sec_code)
    for entry in all_edinet_codes():
        if entry.sec_code == normalized:
            return entry
    return None


def get_edinet_codes_by_industry(
    industry: str,
    *,
    limit: int = 100,
) -> list[EdinetCodeEntry]:
    """業種名でEdinetCodeEntryを検索する。

    完全一致を優先し、見つからなければ部分一致にフォールバックする。
    例: ``"銀行"`` → ``"銀行業"`` にマッチ。

    Args:
        industry: 業種名（例: ``"銀行業"``、``"銀行"``）。
        limit: 最大返却件数。0で無制限。

    Returns:
        マッチしたEdinetCodeEntryのリスト。
    """
    # 完全一致を先に試す
    results: list[EdinetCodeEntry] = []
    for entry in all_edinet_codes():
        if entry.industry == industry:
            results.append(entry)
            if limit > 0 and len(results) >= limit:
                break
    if results:
        return results

    # 完全一致なし → 部分一致にフォールバック
    for entry in all_edinet_codes():
        if entry.industry and industry in entry.industry:
            results.append(entry)
            if limit > 0 and len(results) >= limit:
                break
    return results


def get_listed_edinet_codes(*, limit: int = 0) -> list[EdinetCodeEntry]:
    """上場企業のEdinetCodeEntry一覧を返す。

    ``listing_status == "上場"`` のエントリを返す。

    Args:
        limit: 最大返却件数。0で無制限。

    Returns:
        上場企業のEdinetCodeEntryのリスト。
    """
    results: list[EdinetCodeEntry] = []
    for entry in all_edinet_codes():
        if entry.listing_status == "上場":
            results.append(entry)
            if limit > 0 and len(results) >= limit:
                break
    return results


def _reset_warning_state() -> None:
    """テスト用。"""
    _warned_unknown_edinet_codes.clear()
