"""ファンドコード (fundCode) のモデル定義。

AUTO-GENERATED by tools/generate_fund_codes.py. DO NOT EDIT.
Source: data/source/FundcodeDlInfo.csv
"""
from __future__ import annotations

import warnings

from pydantic import BaseModel, ConfigDict

from edinet.exceptions import EdinetWarning


class FundCodeEntry(BaseModel):
    """ファンドコードリストの1行。"""

    model_config = ConfigDict(frozen=True)

    fund_code: str
    sec_code: str | None
    fund_name: str
    fund_name_yomi: str
    security_type: str
    period_1: str | None
    period_2: str | None
    edinet_code: str
    issuer_name: str

    def __str__(self) -> str:
        return f"FundCodeEntry({self.fund_code} | {self.fund_name})"


_FUND_CODE_TABLE: dict[str, FundCodeEntry] = {
    'G01003': FundCodeEntry(
        fund_code='G01003',
        sec_code=None,
        fund_name='しんきんインデックスファンド２２５',
        fund_name_yomi='シンキンインデックスファンドニィニィゴ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G01034': FundCodeEntry(
        fund_code='G01034',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株オープン「３５」',
        fund_name_yomi='ミツビシユーエフジェイニホンカブオープンサンジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01045': FundCodeEntry(
        fund_code='G01045',
        sec_code=None,
        fund_name='グローイング・エンジェル',
        fund_name_yomi='グローイング\u3000エンジェル',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G01051': FundCodeEntry(
        fund_code='G01051',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本成長株オープン',
        fund_name_yomi='ミツビシユーエフジェイニホンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01060': FundCodeEntry(
        fund_code='G01060',
        sec_code=None,
        fund_name='損保ジャパン－ＴＣＷ外国株式ファンドＡコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ソンポジャパンティーシーダブリューガイコクカブシキファンド\u3000エーコース\u3000カワセヘッジアリ\u3000\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01074': FundCodeEntry(
        fund_code='G01074',
        sec_code=None,
        fund_name='シナプス（Ｓｙｎａｐｓｅ）',
        fund_name_yomi='シナプス',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01075': FundCodeEntry(
        fund_code='G01075',
        sec_code=None,
        fund_name='ピクテ・ニッポン・グロース・ファンド',
        fund_name_yomi='ピクテニッポングロースファンド',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2='11月27日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G01089': FundCodeEntry(
        fund_code='G01089',
        sec_code=None,
        fund_name='アバディーン・スタンダード・ジャパン・グロース・ファンド',
        fund_name_yomi='アバディーンスタンダードジャパングロースファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G01097': FundCodeEntry(
        fund_code='G01097',
        sec_code=None,
        fund_name='東海ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='トウカイエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01100': FundCodeEntry(
        fund_code='G01100',
        sec_code=None,
        fund_name='ジャパン・グロース・ファンド',
        fund_name_yomi='ジャパングロースファンド',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01105': FundCodeEntry(
        fund_code='G01105',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000クオンツ\u3000日本株オープン',
        fund_name_yomi='アラムコクオンツニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01107': FundCodeEntry(
        fund_code='G01107',
        sec_code=None,
        fund_name='大同リサーチ＆アクティブオープン',
        fund_name_yomi='ダイドーリサーチアンドアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G01117': FundCodeEntry(
        fund_code='G01117',
        sec_code=None,
        fund_name='ニッセイ日本株オープン',
        fund_name_yomi='ニッセイニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01125': FundCodeEntry(
        fund_code='G01125',
        sec_code=None,
        fund_name='りそな・日経２２５オープン',
        fund_name_yomi='リソナニッケイニイニイゴオープン',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G01126': FundCodeEntry(
        fund_code='G01126',
        sec_code=None,
        fund_name='三井住友・スーパーアクティブ・オープン',
        fund_name_yomi='ミツイスミトモスーパーアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01131': FundCodeEntry(
        fund_code='G01131',
        sec_code=None,
        fund_name='ドイチェ・ジャパン・グロース・オープン',
        fund_name_yomi='ドイチェジャパングロースオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G01146': FundCodeEntry(
        fund_code='G01146',
        sec_code=None,
        fund_name='日興エコファンド',
        fund_name_yomi='ニッコウエコファンド',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01156': FundCodeEntry(
        fund_code='G01156',
        sec_code=None,
        fund_name='さわかみファンド',
        fund_name_yomi='サワカミファンド',
        security_type='内国投資信託受益証券',
        period_1='8月23日',
        period_2=None,
        edinet_code='E12468',
        issuer_name='さわかみ投信株式会社',
    ),
    'G01157': FundCodeEntry(
        fund_code='G01157',
        sec_code=None,
        fund_name='デジタル情報通信革命',
        fund_name_yomi='デジタルジョウホウツウシンカクメイ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01158': FundCodeEntry(
        fund_code='G01158',
        sec_code=None,
        fund_name='損保ジャパン・グリーン・オープン',
        fund_name_yomi='ソンポジャパングリーンオープン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01164': FundCodeEntry(
        fund_code='G01164',
        sec_code=None,
        fund_name='三井住友・日本株・成長力ファンド',
        fund_name_yomi='ミツイスミトモニホンカブセイチョウリョクファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01170': FundCodeEntry(
        fund_code='G01170',
        sec_code=None,
        fund_name='ノムラ・ボンド＆ローン・ファンド',
        fund_name_yomi='ノムラ\u3000ボンドアンドローン\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G01179': FundCodeEntry(
        fund_code='G01179',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株グロースオープン',
        fund_name_yomi='ミツビシユーエフジェイニホンカブグロースオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01186': FundCodeEntry(
        fund_code='G01186',
        sec_code=None,
        fund_name='ＪＰＭ・Ｅ－フロンティア・オープン',
        fund_name_yomi='ジェイピーエムイーフロンティアオープン',
        security_type='内国投資信託受益証券',
        period_1='10月28日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01189': FundCodeEntry(
        fund_code='G01189',
        sec_code=None,
        fund_name='損保ジャパン日本株ファンド',
        fund_name_yomi='ソンポジャパンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01194': FundCodeEntry(
        fund_code='G01194',
        sec_code=None,
        fund_name='アセット・ナビゲーション・ファンド（株式８０）',
        fund_name_yomi='アセットナビゲーションファンドカブシキハチジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01202': FundCodeEntry(
        fund_code='G01202',
        sec_code=None,
        fund_name='フィデリティ・テクノロジー厳選株式ファンド',
        fund_name_yomi='フィデリティテクノロジーゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01204': FundCodeEntry(
        fund_code='G01204',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000リサーチ\u3000日本株オープン',
        fund_name_yomi='アラムコリサーチニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01205': FundCodeEntry(
        fund_code='G01205',
        sec_code=None,
        fund_name='ｎｅｔＷＩＮ\u3000ＧＳテクノロジー株式ファンドＡコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ネットウィン\u3000ジーエス\u3000テクノロジーカブシキファンド\u3000エーコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2='5月30日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G01207': FundCodeEntry(
        fund_code='G01207',
        sec_code=None,
        fund_name='次世代ファンド',
        fund_name_yomi='ジセダイファンド',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01208': FundCodeEntry(
        fund_code='G01208',
        sec_code=None,
        fund_name='ＣＢオープン',
        fund_name_yomi='シービーオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01213': FundCodeEntry(
        fund_code='G01213',
        sec_code=None,
        fund_name='ＤＬＩＢＪ公社債オープン（短期コース）',
        fund_name_yomi='ディエルアイビィジェイコウシャサイオープンタンキコース',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01214': FundCodeEntry(
        fund_code='G01214',
        sec_code=None,
        fund_name='ＤＬＩＢＪ公社債オープン（中期コース）',
        fund_name_yomi='ディエルアイビィジェイコウシャサイオープンチュウキコース',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01217': FundCodeEntry(
        fund_code='G01217',
        sec_code=None,
        fund_name='ＪＰＭザ・ジャパン',
        fund_name_yomi='ジェイピーエムザジャパン',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01221': FundCodeEntry(
        fund_code='G01221',
        sec_code=None,
        fund_name='新世代成長株ファンド',
        fund_name_yomi='シンセダイセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01231': FundCodeEntry(
        fund_code='G01231',
        sec_code=None,
        fund_name='エコ・パートナーズ',
        fund_name_yomi='エコパートナーズ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01237': FundCodeEntry(
        fund_code='G01237',
        sec_code=None,
        fund_name='三井住友・日本株グロース・オープン',
        fund_name_yomi='ミツイスミトモニホンカブグロースオープン',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01240': FundCodeEntry(
        fund_code='G01240',
        sec_code=None,
        fund_name='野村国内株式アクティブオープン',
        fund_name_yomi='ノムラコクナイカブシキアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G01241': FundCodeEntry(
        fund_code='G01241',
        sec_code=None,
        fund_name='ニッセイグローバルバランスオープン（債券重視型）／ニッセイグローバルバランスオープン（標\u3000準\u3000型）／ニッセイグローバルバランスオープン（株式重視型）',
        fund_name_yomi='ニッセイグローバルバランスオープンサイケンジュウシガタ\u3000ニッセイグローバルバランスオープンヒョウジュンガタ\u3000ニッセイグローバルバランスオープンカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01245': FundCodeEntry(
        fund_code='G01245',
        sec_code=None,
        fund_name='アバディーン・スタンダード日本小型株ファンド',
        fund_name_yomi='アバディーンスタンダードニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G01246': FundCodeEntry(
        fund_code='G01246',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ターゲット・イヤーファンド\u3000２０３０／２０４０',
        fund_name_yomi='ミツビシユーエフジェイターゲットイヤーファンドニイゼロサンゼロニイゼロヨンゼロ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01247': FundCodeEntry(
        fund_code='G01247',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ライフ・バランスファンド（安定型）／（安定成長型）／（成長型）／（積極型）',
        fund_name_yomi='ミツビシユーエフジェイライフバランスファンドアンテイガタアンテイセイチョウガタセイチョウガタセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01258': FundCodeEntry(
        fund_code='G01258',
        sec_code=None,
        fund_name='ニッセイ日本株グロースオープン',
        fund_name_yomi='ニッセイニホンカブグロースオープン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01259': FundCodeEntry(
        fund_code='G01259',
        sec_code=None,
        fund_name='新経済大国日本',
        fund_name_yomi='シンケイザイタイコクニッポン',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01260': FundCodeEntry(
        fund_code='G01260',
        sec_code=None,
        fund_name='ＤＩＡＭ成長株オープン',
        fund_name_yomi='ダイアムセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01265': FundCodeEntry(
        fund_code='G01265',
        sec_code=None,
        fund_name='日興クオンツ・アクティブ・ジャパン',
        fund_name_yomi='ニッコウクオンツアクティブジャパン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01269': FundCodeEntry(
        fund_code='G01269',
        sec_code=None,
        fund_name='ダイワ・バリュー株・オープン',
        fund_name_yomi='ダイワバリューカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01274': FundCodeEntry(
        fund_code='G01274',
        sec_code=None,
        fund_name='青のライフキャンバス・ファンド（標準型）赤のライフキャンバス・ファンド（積極型）',
        fund_name_yomi='アオノライフキャンパスファンドヒョウジュンガタアカノライフキャンパスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G01276': FundCodeEntry(
        fund_code='G01276',
        sec_code=None,
        fund_name='ルーミス\u3000グローバル\u3000ボンドファンド（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='ルーミスグローバルボンドファンドカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01283': FundCodeEntry(
        fund_code='G01283',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ミツビシユーエフジェイエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01291': FundCodeEntry(
        fund_code='G01291',
        sec_code=None,
        fund_name='ハリス\u3000グローバル\u3000バリュー株ファンド（年１回決算型）',
        fund_name_yomi='ハリスグローバルバリューカブファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01293': FundCodeEntry(
        fund_code='G01293',
        sec_code=None,
        fund_name='日本株バリュー・ファンド',
        fund_name_yomi='ニホンカブバリューファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01294': FundCodeEntry(
        fund_code='G01294',
        sec_code=None,
        fund_name='日本株グロース・ファンド',
        fund_name_yomi='ニホンカブグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01295': FundCodeEntry(
        fund_code='G01295',
        sec_code=None,
        fund_name='日本・小型株・ファンド',
        fund_name_yomi='ニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01296': FundCodeEntry(
        fund_code='G01296',
        sec_code=None,
        fund_name='日本株スタイル・ミックス・ファンド',
        fund_name_yomi='ニホンカブスタイルミックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01297': FundCodeEntry(
        fund_code='G01297',
        sec_code=None,
        fund_name='日本株インカム・ファンド',
        fund_name_yomi='ニホンカブインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01304': FundCodeEntry(
        fund_code='G01304',
        sec_code=None,
        fund_name='日興エボリューション',
        fund_name_yomi='ニッコウエボリューション',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01315': FundCodeEntry(
        fund_code='G01315',
        sec_code=None,
        fund_name='フィデリティ・日本優良株・ファンド',
        fund_name_yomi='フィデリティニホンユウリョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月31日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01316': FundCodeEntry(
        fund_code='G01316',
        sec_code=None,
        fund_name='フィデリティ・ジャパン・アグレッシブ・グロース',
        fund_name_yomi='フィデリティジャパンアグレッシブグロース',
        security_type='内国投資信託受益証券',
        period_1='10月31日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01318': FundCodeEntry(
        fund_code='G01318',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000スタイルセレクト・グロースファンド／バリューファンド／ブレンドファンド\u3000ＢＷマネープールファンド',
        fund_name_yomi='ミツビシユーエフジェイタイルセレクトグロースファンドバリューファンドブレンドファンドビーダブリューマネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01321': FundCodeEntry(
        fund_code='G01321',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000トピックスインデックスオープン',
        fund_name_yomi='ミツビシユーエフジェイ\u3000トピックスインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01330': FundCodeEntry(
        fund_code='G01330',
        sec_code=None,
        fund_name='ＧＳ\u3000日本小型株ファンド',
        fund_name_yomi='ジーエスニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G01331': FundCodeEntry(
        fund_code='G01331',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株式オープン',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ニホンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01332': FundCodeEntry(
        fund_code='G01332',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本バランスオープン\u3000株式２０型\u3000三菱ＵＦＪ\u3000日本バランスオープン\u3000株式４０型',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ニホンバランスオープン\u3000カブシキニジュウガタ\u3000\u3000ミツビシユーエフジェイ\u3000ニホンバランスオープン\u3000カブシキヨンジュウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01333': FundCodeEntry(
        fund_code='G01333',
        sec_code=None,
        fund_name='ピクテ・バイオ医薬品ファンド（１年決算型）円コース',
        fund_name_yomi='ピクテバイオイヤクヒンファンドイチネンケッサンガタエンコース',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G01338': FundCodeEntry(
        fund_code='G01338',
        sec_code=None,
        fund_name='ＪＰＭ中小型株・アクティブ・オープン',
        fund_name_yomi='ジェイピーエムチュウコガタカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01339': FundCodeEntry(
        fund_code='G01339',
        sec_code=None,
        fund_name='インベスコ\u3000ジャパン・エンタープライズ・オープン',
        fund_name_yomi='インベスコ\u3000ジャパンエンタープライズオープン',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G01347': FundCodeEntry(
        fund_code='G01347',
        sec_code=None,
        fund_name='ダイワ投信倶楽部日本債券インデックス',
        fund_name_yomi='ダイワトウシンクラブニホンサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01348': FundCodeEntry(
        fund_code='G01348',
        sec_code=None,
        fund_name='ダイワ投信倶楽部外国株式インデックス',
        fund_name_yomi='ダイワトウシンクラブガイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01349': FundCodeEntry(
        fund_code='G01349',
        sec_code=None,
        fund_name='ダイワライフスタイル２５',
        fund_name_yomi='ダイワライフスタイルニジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01354': FundCodeEntry(
        fund_code='G01354',
        sec_code=None,
        fund_name='三井住友・げんきシニアライフ・オープン',
        fund_name_yomi='ミツイスミトモゲンキシニアライフオープン',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01363': FundCodeEntry(
        fund_code='G01363',
        sec_code=None,
        fund_name='日本株式インデックス・オープン',
        fund_name_yomi='ニホンカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01364': FundCodeEntry(
        fund_code='G01364',
        sec_code=None,
        fund_name='外国株式インデックス・オープン',
        fund_name_yomi='ガイコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01378': FundCodeEntry(
        fund_code='G01378',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000グローバルイノベーション',
        fund_name_yomi='ミツビシユーエフジェイ\u3000グローバルイノベーション',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01379': FundCodeEntry(
        fund_code='G01379',
        sec_code=None,
        fund_name='三菱\u3000ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ミツビシエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01383': FundCodeEntry(
        fund_code='G01383',
        sec_code=None,
        fund_name='キャッシュフロー経営評価オープン',
        fund_name_yomi='キャッシュフローケイエイヒョウカオープン',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01384': FundCodeEntry(
        fund_code='G01384',
        sec_code=None,
        fund_name='中小型株式オープン',
        fund_name_yomi='チュウコガタカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G01389': FundCodeEntry(
        fund_code='G01389',
        sec_code=None,
        fund_name='ストラテジック・バリュー・オープン',
        fund_name_yomi='ストラテジック\u3000バリュー\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G01393': FundCodeEntry(
        fund_code='G01393',
        sec_code=None,
        fund_name='しんきんトピックスオープン',
        fund_name_yomi='シンキントピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='7月18日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G01396': FundCodeEntry(
        fund_code='G01396',
        sec_code=None,
        fund_name='ニッセイ日本株リサーチオープン',
        fund_name_yomi='ニッセイニホンカブリサーチオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01406': FundCodeEntry(
        fund_code='G01406',
        sec_code=None,
        fund_name='三井住友・日経２２５オープン',
        fund_name_yomi='ミツイスミトモニッケイニィニィゴオープン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01407': FundCodeEntry(
        fund_code='G01407',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ライフプラン\u3000２５\u3000三菱ＵＦＪ\u3000ライフプラン\u3000５０\u3000三菱ＵＦＪ\u3000ライフプラン\u3000７５',
        fund_name_yomi='ミツビシユーエフジェイライフプランニジュウゴミツビシユーエフジェイライフプランゴジュウミツビシユーエフジェイライフプランナナジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01408': FundCodeEntry(
        fund_code='G01408',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000海外株式オープン',
        fund_name_yomi='ミツビシユーエフジェイカイガイカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01409': FundCodeEntry(
        fund_code='G01409',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000海外債券オープン',
        fund_name_yomi='ミツビシユーエフジェイカイガイサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01411': FundCodeEntry(
        fund_code='G01411',
        sec_code=None,
        fund_name='三井住友・ＤＣ日本株式リサーチファンド',
        fund_name_yomi='ミツイスミトモディーシーニホンカブシキリサーチファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01413': FundCodeEntry(
        fund_code='G01413',
        sec_code=None,
        fund_name='三井住友・グローバル株式年金ファンド\u3000Ａコース\u3000（為替ヘッジあり）\u3000三井住友・グローバル株式年金ファンド\u3000Ｂコース\u3000（為替ヘッジなし）',
        fund_name_yomi='ミツイスミトモグローバルカブシキネンキンファンドエーコースカワセヘッジアリ\u3000ミツイスミトモグローバルカブシキネンキンファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01417': FundCodeEntry(
        fund_code='G01417',
        sec_code=None,
        fund_name='ハッピーエイジング・ファンド\u3000ハッピーエイジング２０\u3000３０\u3000４０\u3000５０\u3000６０',
        fund_name_yomi='ハッピーエイジングファンド\u3000ハッピーエイジング\u3000ニジュー\u3000サンジュー\u3000ヨンジュー\u3000ゴジュー\u3000ロクジュー',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01418': FundCodeEntry(
        fund_code='G01418',
        sec_code=None,
        fund_name='損保ジャパン日本債券ファンド',
        fund_name_yomi='ソンポジャパンニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01419': FundCodeEntry(
        fund_code='G01419',
        sec_code=None,
        fund_name='損保ジャパン外国債券ファンド',
        fund_name_yomi='ソンポジャパンガイコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01423': FundCodeEntry(
        fund_code='G01423',
        sec_code=None,
        fund_name='ＪＰＭ日本中小型株ファンド',
        fund_name_yomi='ジェイピーエムニホンチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01425': FundCodeEntry(
        fund_code='G01425',
        sec_code=None,
        fund_name='アムンディ・ターゲット・ジャパン・ファンド',
        fund_name_yomi='アムンディターゲットジャパンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G01428': FundCodeEntry(
        fund_code='G01428',
        sec_code=None,
        fund_name='Ｏｎｅ国内株オープン',
        fund_name_yomi='ワンコクナイカブオープン',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01433': FundCodeEntry(
        fund_code='G01433',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ライフセレクトファンド（安定型）\u3000三菱ＵＦＪ\u3000ライフセレクトファンド（安定成長型）\u3000三菱ＵＦＪ\u3000ライフセレクトファンド（成長型）',
        fund_name_yomi='ミツビシユーエフジェイライフセレクトファンドアンテイガタミツビシユーエフジェイライフセレクトファンドアンテイセイチョウガタミツビシユーエフジェイライフセレクトファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01434': FundCodeEntry(
        fund_code='G01434',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000外国債券オープン',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01435': FundCodeEntry(
        fund_code='G01435',
        sec_code=None,
        fund_name='三井住友・バリュー株式年金ファンド',
        fund_name_yomi='ミツイスミトモバリューカブシキネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01443': FundCodeEntry(
        fund_code='G01443',
        sec_code=None,
        fund_name='ファンド・オブ・オールスター・ファンズ',
        fund_name_yomi='ファンドオブオールスターファンズ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01445': FundCodeEntry(
        fund_code='G01445',
        sec_code=None,
        fund_name='ミュータント',
        fund_name_yomi='ミュータント',
        security_type='内国投資信託受益証券',
        period_1='9月27日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01449': FundCodeEntry(
        fund_code='G01449',
        sec_code=None,
        fund_name='ニッセイ日本ストラテジックオープン',
        fund_name_yomi='ニッセイニホンストラテジックオープン',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01451': FundCodeEntry(
        fund_code='G01451',
        sec_code=None,
        fund_name='フィデリティ・中小型株・オープン',
        fund_name_yomi='フィデリティチュウコガタカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01452': FundCodeEntry(
        fund_code='G01452',
        sec_code=None,
        fund_name='日本インデックスオープン２２５',
        fund_name_yomi='ニホンインデックスオープンニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G01454': FundCodeEntry(
        fund_code='G01454',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000ＳＲＩ\u3000社会貢献ファンド',
        fund_name_yomi='アラムコエスアールアイシャカイコウケンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01455': FundCodeEntry(
        fund_code='G01455',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000バリューオープン',
        fund_name_yomi='ミツビシユーエフジェイ\u3000バリューオープン',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01456': FundCodeEntry(
        fund_code='G01456',
        sec_code=None,
        fund_name='三井住友・年金プラン３０\u3000三井住友・年金プラン５０\u3000三井住友・年金プラン７０',
        fund_name_yomi='ミツイスミトモネンキンプランサンジュウ\u3000ミツイスミトモネンキンプランゴジュウ\u3000ミツイスミトモネンキンプランナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01461': FundCodeEntry(
        fund_code='G01461',
        sec_code=None,
        fund_name='スパークス・ジャパン・スモール・キャップ・ファンド',
        fund_name_yomi='スパークス\u3000ジャパン\u3000スモール\u3000キャップ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G01465': FundCodeEntry(
        fund_code='G01465',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株アクティブ・ファンド',
        fund_name_yomi='ミツビシユーエフジェイニホンカブアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月30日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01499': FundCodeEntry(
        fund_code='G01499',
        sec_code=None,
        fund_name='米国ＮＡＳＤＡＱオープン\u3000Ａコース、米国ＮＡＳＤＡＱオープン\u3000Ｂコース',
        fund_name_yomi='ベイコクナスダックオープン\u3000エーコース\u3000ベイコクナスダックオープン\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G01500': FundCodeEntry(
        fund_code='G01500',
        sec_code=None,
        fund_name='日興アクティブ・ダイナミクス',
        fund_name_yomi='ニッコウアクティブダイナミクス',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01514': FundCodeEntry(
        fund_code='G01514',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000日経平均ファンド',
        fund_name_yomi='アラムコニッケイヘイキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G01518': FundCodeEntry(
        fund_code='G01518',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＭＶ２０\u3000三菱ＵＦＪ\u3000ＭＶ４０\u3000三菱ＵＦＪ\u3000ＭＶ８０',
        fund_name_yomi='ミツビシユーエフジェイエムヴイニジュウミツビシユーエフジェイエムヴイヨンジュウミツビシユーエフジェイエムヴイハチジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01521': FundCodeEntry(
        fund_code='G01521',
        sec_code=None,
        fund_name='バランス物語３０（安定型）、バランス物語５０（安定・成長型）、バランス物語７０（成長型）',
        fund_name_yomi='バランスモノガタリサンジュウ\u3000アンテイガタ\u3000バランスモノガタリゴジュウ\u3000アンテイセイチョウガタ\u3000バランスモノガタリナナジュウ\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01525': FundCodeEntry(
        fund_code='G01525',
        sec_code=None,
        fund_name='アバディーン・スタンダード日本成長株ファンド',
        fund_name_yomi='アバディーンスタンダードニホンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G01537': FundCodeEntry(
        fund_code='G01537',
        sec_code=None,
        fund_name='［アバディーン・ファンド・セレクション］海外高格付け債ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='アバディーン\u3000ファンド\u3000セレクション\u3000カイガイコウカクヅケサイファンド\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G01542': FundCodeEntry(
        fund_code='G01542',
        sec_code=None,
        fund_name='アバディーン・ジャパン・オープン',
        fund_name_yomi='アバディーン\u3000ジャパン\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G01552': FundCodeEntry(
        fund_code='G01552',
        sec_code=None,
        fund_name='ＪＰＭアジア・成長株・ファンド',
        fund_name_yomi='ジェイピーエムアジアセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01557': FundCodeEntry(
        fund_code='G01557',
        sec_code=None,
        fund_name='ＪＰＭグローバル・ＣＢ・オープン’９５',
        fund_name_yomi='ジェイピーエムグローバルシービーオープンキュウジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01561': FundCodeEntry(
        fund_code='G01561',
        sec_code=None,
        fund_name='ＪＰＭ中小型株オープン',
        fund_name_yomi='ジェイピーエムチュウコガタカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01563': FundCodeEntry(
        fund_code='G01563',
        sec_code=None,
        fund_name='ＪＰＭグレーター・チャイナ・オープン',
        fund_name_yomi='ジェイピーエムグレーターチャイナオープン',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01565': FundCodeEntry(
        fund_code='G01565',
        sec_code=None,
        fund_name='ＪＰＭ日本株・アクティブ・オープン',
        fund_name_yomi='ジェイピーエムニホンカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01569': FundCodeEntry(
        fund_code='G01569',
        sec_code=None,
        fund_name='ＪＰＭアジア株・アクティブ・オープン',
        fund_name_yomi='ジェイピーエムアジアカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G01571': FundCodeEntry(
        fund_code='G01571',
        sec_code=None,
        fund_name='損保ジャパン日本株オープン',
        fund_name_yomi='ソンポジャパンニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G01613': FundCodeEntry(
        fund_code='G01613',
        sec_code=None,
        fund_name='ニッセイ／パトナム・インカムオープン',
        fund_name_yomi='ニッセイパトナムインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G01621': FundCodeEntry(
        fund_code='G01621',
        sec_code=None,
        fund_name='ハイブリッド・セレクション',
        fund_name_yomi='ハイブリッドセレクション',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01625': FundCodeEntry(
        fund_code='G01625',
        sec_code=None,
        fund_name='グローバル・ボンド・ポート（Ｃコース）',
        fund_name_yomi='グローバルボンドポート\u3000シーコース',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01626': FundCodeEntry(
        fund_code='G01626',
        sec_code=None,
        fund_name='グローバル・ボンド・ポート（Ｄコース）',
        fund_name_yomi='グローバルボンドポート\u3000ディーコース',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2='3月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01629': FundCodeEntry(
        fund_code='G01629',
        sec_code=None,
        fund_name='ドルマネーファンド',
        fund_name_yomi='ドルマネーファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2='3月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01630': FundCodeEntry(
        fund_code='G01630',
        sec_code=None,
        fund_name='日経２２５ノーロードオープン',
        fund_name_yomi='ニッケイニーニーゴノーロードオープン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01631': FundCodeEntry(
        fund_code='G01631',
        sec_code=None,
        fund_name='ＩＢＪＩＴＭジャパン・セレクション',
        fund_name_yomi='アイビージェイアイティーエムジャパンセレクション',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01633': FundCodeEntry(
        fund_code='G01633',
        sec_code=None,
        fund_name='ＤＬ日本株式オープン',
        fund_name_yomi='ディーエルニホンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G01648': FundCodeEntry(
        fund_code='G01648',
        sec_code=None,
        fund_name='インデックスファンド２２５',
        fund_name_yomi='インデックスファンドニーニーゴー',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01650': FundCodeEntry(
        fund_code='G01650',
        sec_code=None,
        fund_name='インデックスファンドＴＳＰ',
        fund_name_yomi='インデックスファンドティーエスピー',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01654': FundCodeEntry(
        fund_code='G01654',
        sec_code=None,
        fund_name='キャピタルオープン',
        fund_name_yomi='キャピタルオープン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01668': FundCodeEntry(
        fund_code='G01668',
        sec_code=None,
        fund_name='日興アクティブバリュー',
        fund_name_yomi='ニッコウアクティブバリュー',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01693': FundCodeEntry(
        fund_code='G01693',
        sec_code=None,
        fund_name='インデックスポートフォリオ',
        fund_name_yomi='インデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01698': FundCodeEntry(
        fund_code='G01698',
        sec_code=None,
        fund_name='財形株投（一般財形３０）（一般財形５０）（年金・住宅財形３０）',
        fund_name_yomi='ザイケイカブトウ\u3000イッパンザイケイサンジュウ\u3000イッパンザイケイゴジュウ\u3000ネンキン\u3000ジュウタクザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01704': FundCodeEntry(
        fund_code='G01704',
        sec_code=None,
        fund_name='低位株オープン',
        fund_name_yomi='テイイカブオープン',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01705': FundCodeEntry(
        fund_code='G01705',
        sec_code=None,
        fund_name='日本新興株オープン',
        fund_name_yomi='ニホンシンコウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01708': FundCodeEntry(
        fund_code='G01708',
        sec_code=None,
        fund_name='日興ジャパンオープン',
        fund_name_yomi='ニッコウジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01713': FundCodeEntry(
        fund_code='G01713',
        sec_code=None,
        fund_name='日本トレンド・セレクトハイパー・ウェイブリバース・トレンド・オープン日本トレンド・マネーポートフォリオ',
        fund_name_yomi='ニホントレンドセレクトハイパーウェイブリバーストレンドオープンニホントレンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01716': FundCodeEntry(
        fund_code='G01716',
        sec_code=None,
        fund_name='利益還元成長株オープン',
        fund_name_yomi='リエキカンゲンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01722': FundCodeEntry(
        fund_code='G01722',
        sec_code=None,
        fund_name='公社債投信１２月号',
        fund_name_yomi='コウシャサイトウシンジュウニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01725': FundCodeEntry(
        fund_code='G01725',
        sec_code=None,
        fund_name='日興ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ニッコウエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G01726': FundCodeEntry(
        fund_code='G01726',
        sec_code=None,
        fund_name='三井住友・日本株オープン',
        fund_name_yomi='ミツイスミトモニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='9月27日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01730': FundCodeEntry(
        fund_code='G01730',
        sec_code=None,
        fund_name='三井住友・株式アナライザー・オープン',
        fund_name_yomi='ミツイスミトモカブシキアナライザーオープン',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01731': FundCodeEntry(
        fund_code='G01731',
        sec_code=None,
        fund_name='三井住友・２２５オープン',
        fund_name_yomi='ミツイスミトモニィニィゴオープン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G01746': FundCodeEntry(
        fund_code='G01746',
        sec_code=None,
        fund_name='シュローダー日本ファンド',
        fund_name_yomi='シュローダーニホンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G01748': FundCodeEntry(
        fund_code='G01748',
        sec_code=None,
        fund_name='シュローダー日本株式オープン',
        fund_name_yomi='シュローダーニホンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G01754': FundCodeEntry(
        fund_code='G01754',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（１２月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクジュウニガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01761': FundCodeEntry(
        fund_code='G01761',
        sec_code=None,
        fund_name='夢楽章\u3000日経平均オープン',
        fund_name_yomi='ユメガクショウニッケイヘイキンオープン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01773': FundCodeEntry(
        fund_code='G01773',
        sec_code=None,
        fund_name='グローバル・エマージング・ボンド・オープン',
        fund_name_yomi='グローバルエマージングボンドオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01780': FundCodeEntry(
        fund_code='G01780',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＮＡＳＤＡＱオープン\u3000Ａコース／Ｂコース',
        fund_name_yomi='ミツビシユーエフジェイナスダックオープンエーコースビーコース',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01784': FundCodeEntry(
        fund_code='G01784',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000チャイナオープン',
        fund_name_yomi='ミツビシユーエフジェイチャイナオープン',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01799': FundCodeEntry(
        fund_code='G01799',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000積立ファンド（日本バランス型）',
        fund_name_yomi='ミツビシユーエフジェイツミタテファンドニホンバランスガタ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01800': FundCodeEntry(
        fund_code='G01800',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000グローバルバランス（安定型）／（積極型）',
        fund_name_yomi='ミツビシユーエフジェイグローバルバランスアンテイガタセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01807': FundCodeEntry(
        fund_code='G01807',
        sec_code=None,
        fund_name='インデックスファンド２２５',
        fund_name_yomi='インデックスファンドニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01809': FundCodeEntry(
        fund_code='G01809',
        sec_code=None,
        fund_name='トピックスオープン',
        fund_name_yomi='トピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01812': FundCodeEntry(
        fund_code='G01812',
        sec_code=None,
        fund_name='ＪＡＰＡＮスタンダードオープン',
        fund_name_yomi='ジャパンスタンダードオープン',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01819': FundCodeEntry(
        fund_code='G01819',
        sec_code=None,
        fund_name='Ｊオープン（小型株）',
        fund_name_yomi='ジェイオープンコガタカブ',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01822': FundCodeEntry(
        fund_code='G01822',
        sec_code=None,
        fund_name='フィデリティ・ジャパン・オープン',
        fund_name_yomi='フィデリティジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01823': FundCodeEntry(
        fund_code='G01823',
        sec_code=None,
        fund_name='フィデリティ・欧州中小型株・オープンＡコース（為替ヘッジ付き）\u3000フィデリティ・欧州中小型株・オープンＢコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティオウシュウチュウコガタカブオープンエイコースカワセヘッジツキ\u3000フィデリティオウシュウチュウコガタカブオープンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01824': FundCodeEntry(
        fund_code='G01824',
        sec_code=None,
        fund_name='フィデリティ・グローバル・エクイティ・オープンＡコース（限定為替ヘッジ）\u3000フィデリティ・グローバル・エクイティ・オープンＢコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティグローバルエクイティオープンエイコースゲンテイカワセヘッジ\u3000フィデリティグローバルエクイティオープンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01825': FundCodeEntry(
        fund_code='G01825',
        sec_code=None,
        fund_name='フィデリティ・ハイ・イールド・ボンド・オープンポートフォリオＡ（為替ヘッジなし）',
        fund_name_yomi='フィデリティハイイールドボンドオープンポートフォリオエイカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01826': FundCodeEntry(
        fund_code='G01826',
        sec_code=None,
        fund_name='フィデリティ・ストラテジック・インカム・ファンドＡコース（為替ヘッジ付き）\u3000フィデリティ・ストラテジック・インカム・ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティストラテジックインカムファンドエイコースカワセヘッジツキ\u3000フィデリティストラテジックインカムファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01827': FundCodeEntry(
        fund_code='G01827',
        sec_code=None,
        fund_name='フィデリティ・グローバル・ファンド',
        fund_name_yomi='フィデリティグローバルファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01828': FundCodeEntry(
        fund_code='G01828',
        sec_code=None,
        fund_name='フィデリティ・バランス・ファンド',
        fund_name_yomi='フィデリティバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01829': FundCodeEntry(
        fund_code='G01829',
        sec_code=None,
        fund_name='フィデリティ・日本成長株・ファンド',
        fund_name_yomi='フィデリティニホンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01830': FundCodeEntry(
        fund_code='G01830',
        sec_code=None,
        fund_name='フィデリティ・日本小型株・ファンド',
        fund_name_yomi='フィデリティニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01831': FundCodeEntry(
        fund_code='G01831',
        sec_code=None,
        fund_name='フィデリティ・欧州株・ファンド',
        fund_name_yomi='フィデリティオウシュウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01832': FundCodeEntry(
        fund_code='G01832',
        sec_code=None,
        fund_name='フィデリティ・米国優良株・ファンド',
        fund_name_yomi='フィデリティベイコクユウリョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01833': FundCodeEntry(
        fund_code='G01833',
        sec_code=None,
        fund_name='フィデリティ・ＵＳハイ・イールド・ファンド（毎月決算型）Ｂ（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスハイイールドファンドマイツキケッサンガタビーカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01835': FundCodeEntry(
        fund_code='G01835',
        sec_code=None,
        fund_name='フィデリティ・アジア株・ファンド',
        fund_name_yomi='フィデリティアジアカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G01838': FundCodeEntry(
        fund_code='G01838',
        sec_code=None,
        fund_name='２２５インデックスファンド',
        fund_name_yomi='ニーニーゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月29日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G01842': FundCodeEntry(
        fund_code='G01842',
        sec_code=None,
        fund_name='アクティブ\u3000バリュー\u3000オープン',
        fund_name_yomi='アクティブバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G01853': FundCodeEntry(
        fund_code='G01853',
        sec_code=None,
        fund_name='大型株ファンド',
        fund_name_yomi='オオガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01854': FundCodeEntry(
        fund_code='G01854',
        sec_code=None,
        fund_name='ストック\u3000インデックスファンド\u3000２２５',
        fund_name_yomi='ストックインデックスファンドニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01856': FundCodeEntry(
        fund_code='G01856',
        sec_code=None,
        fund_name='トピックス・インデックスファンド',
        fund_name_yomi='トピックスインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01862': FundCodeEntry(
        fund_code='G01862',
        sec_code=None,
        fund_name='財形給付金ファンド',
        fund_name_yomi='ザイケイキュウフキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01863': FundCodeEntry(
        fund_code='G01863',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）インデックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランインデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01864': FundCodeEntry(
        fund_code='G01864',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）ボンドミックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランボンドミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01865': FundCodeEntry(
        fund_code='G01865',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）フィナンシャルミックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランフィナンシャルミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01866': FundCodeEntry(
        fund_code='G01866',
        sec_code=None,
        fund_name='財形株投（一般財形５０）',
        fund_name_yomi='ザイケイカブトウイッパンザイケイゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01867': FundCodeEntry(
        fund_code='G01867',
        sec_code=None,
        fund_name='財形株投（一般財形３０）',
        fund_name_yomi='ザイケイカブトウイッパンザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01868': FundCodeEntry(
        fund_code='G01868',
        sec_code=None,
        fund_name='財形株投（年金・住宅財形３０）',
        fund_name_yomi='ザイケイカブトウネンキンジュウタクザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01872': FundCodeEntry(
        fund_code='G01872',
        sec_code=None,
        fund_name='公社債投信（１２月号）',
        fund_name_yomi='コウシャサイトウシンジュウニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01878': FundCodeEntry(
        fund_code='G01878',
        sec_code=None,
        fund_name='ダイワＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ダイワエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01889': FundCodeEntry(
        fund_code='G01889',
        sec_code=None,
        fund_name='大和ベストチョイス・オープン',
        fund_name_yomi='ダイワベストチョイスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01891': FundCodeEntry(
        fund_code='G01891',
        sec_code=None,
        fund_name='マネー・オープン',
        fund_name_yomi='マネーオープン',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01906': FundCodeEntry(
        fund_code='G01906',
        sec_code=None,
        fund_name='ダイワ・ジャパン・オープン',
        fund_name_yomi='ダイワジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01916': FundCodeEntry(
        fund_code='G01916',
        sec_code=None,
        fund_name='アクティブ・ニッポン',
        fund_name_yomi='アクティブニッポン',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01935': FundCodeEntry(
        fund_code='G01935',
        sec_code=None,
        fund_name='ダイワ投信倶楽部マネー',
        fund_name_yomi='ダイワトウシンクラブマネー',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G01988': FundCodeEntry(
        fund_code='G01988',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株アクティブオープン',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ニホンカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01989': FundCodeEntry(
        fund_code='G01989',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000インデックス２２５オープン',
        fund_name_yomi='ミツビシユーエフジェイインデックスニニゴオープン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G01998': FundCodeEntry(
        fund_code='G01998',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）インデックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランインデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月26日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G01999': FundCodeEntry(
        fund_code='G01999',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）ボンドミックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランボンドミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月26日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G02004': FundCodeEntry(
        fund_code='G02004',
        sec_code=None,
        fund_name='日本ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ニホンエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G02007': FundCodeEntry(
        fund_code='G02007',
        sec_code=None,
        fund_name='日本財形給付金ファンド',
        fund_name_yomi='ニホンザイケイキュウフキンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G02010': FundCodeEntry(
        fund_code='G02010',
        sec_code=None,
        fund_name='日本グロースオープン',
        fund_name_yomi='ニホングロースオープン',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G02037': FundCodeEntry(
        fund_code='G02037',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・ハイ・イールド・オープン',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000ハイ\u3000イールド\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2='5月20日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G02038': FundCodeEntry(
        fund_code='G02038',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・ハイ・インカム・オープンＡ（為替ヘッジなし）／Ｂ（為替ヘッジあり）',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000グローバル\u3000ハイ\u3000インカム\u3000オープンエー\u3000カワセヘッジナシ\u3000ビー\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G02039': FundCodeEntry(
        fund_code='G02039',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・インカム・ファンド',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000グローバル\u3000インカム\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G02041': FundCodeEntry(
        fund_code='G02041',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・グロース・オポチュニティーズ（年２回決算型）',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000グローバル\u3000グロース\u3000オポチュニティーズ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G02043': FundCodeEntry(
        fund_code='G02043',
        sec_code=None,
        fund_name='インベスコ\u3000ジャパン・ニューフロンティア・オープン',
        fund_name_yomi='インベスコ\u3000ジャパンニューフロンティアオープン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G02044': FundCodeEntry(
        fund_code='G02044',
        sec_code=None,
        fund_name='ＧＴグローバル\u3000インベストメント・オープン',
        fund_name_yomi='ジーティーグローバル\u3000インベストメントオープン',
        security_type='内国投資信託受益証券',
        period_1='2月28日',
        period_2='8月28日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G02048': FundCodeEntry(
        fund_code='G02048',
        sec_code=None,
        fund_name='インベスコ\u3000店頭・成長株オープン',
        fund_name_yomi='インベスコ\u3000テントウ\u3000セイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G02050': FundCodeEntry(
        fund_code='G02050',
        sec_code=None,
        fund_name='インベスコ\u3000インカムセレクトファンド',
        fund_name_yomi='インベスコ\u3000インカムセレクトファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G02067': FundCodeEntry(
        fund_code='G02067',
        sec_code=None,
        fund_name='パインブリッジ・ワールド株式・オープン',
        fund_name_yomi='パインブリッジワールドカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G02071': FundCodeEntry(
        fund_code='G02071',
        sec_code=None,
        fund_name='ドイチェ・ユーロスター・オープン',
        fund_name_yomi='ドイチェユーロスターオープン',
        security_type='内国投資信託受益証券',
        period_1='5月29日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G02079': FundCodeEntry(
        fund_code='G02079',
        sec_code=None,
        fund_name='ドイチェ・ライフ・プラン３０／５０／７０',
        fund_name_yomi='ドイチェライフプラン\u3000サンジュウ\u3000ゴジュウ\u3000ナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G02251': FundCodeEntry(
        fund_code='G02251',
        sec_code=None,
        fund_name='農中ＵＳ債券オープン',
        fund_name_yomi='ノウチュウユーエスサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02253': FundCodeEntry(
        fund_code='G02253',
        sec_code=None,
        fund_name='ＪＡ\u3000ＴＯＰＩＸオープン',
        fund_name_yomi='ジェイエイトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02255': FundCodeEntry(
        fund_code='G02255',
        sec_code=None,
        fund_name='農中日経２２５オープン',
        fund_name_yomi='ノウチュウニッケイニイニイゴオープン',
        security_type='内国投資信託受益証券',
        period_1='7月21日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02262': FundCodeEntry(
        fund_code='G02262',
        sec_code=None,
        fund_name='スーパーバランス（毎月分配型）',
        fund_name_yomi='スーパーバランスマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月9日',
        period_2='11月9日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G02263': FundCodeEntry(
        fund_code='G02263',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）インデックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランインデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G02264': FundCodeEntry(
        fund_code='G02264',
        sec_code=None,
        fund_name='ミリオン（従業員積立投資プラン）フィナンシャルミックスポートフォリオ',
        fund_name_yomi='ミリオンジュウギョウインツミタテトウシプランフィナンシャルミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G02269': FundCodeEntry(
        fund_code='G02269',
        sec_code=None,
        fund_name='リサーチ・アクティブ・オープン',
        fund_name_yomi='リサーチアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2='10月30日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02270': FundCodeEntry(
        fund_code='G02270',
        sec_code=None,
        fund_name='ノムラ・ジャパン・オープン',
        fund_name_yomi='ノムラ\u3000ジャパン\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02271': FundCodeEntry(
        fund_code='G02271',
        sec_code=None,
        fund_name='グローバル・バリュー・オープン',
        fund_name_yomi='グローバルバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02272': FundCodeEntry(
        fund_code='G02272',
        sec_code=None,
        fund_name='ノムラ・ジャパン・バリュー・オープン',
        fund_name_yomi='ノムラジャパンバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02275': FundCodeEntry(
        fund_code='G02275',
        sec_code=None,
        fund_name='小型ブルーチップオープン',
        fund_name_yomi='コガタブルーチップオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02276': FundCodeEntry(
        fund_code='G02276',
        sec_code=None,
        fund_name='ハイ・イールド\u3000ボンド\u3000オープン\u3000Ａコース、ハイ・イールド\u3000ボンド\u3000オープン\u3000Ｂコース',
        fund_name_yomi='ハイイールド\u3000ボンド\u3000オープン\u3000エーコース\u3000ハイイールド\u3000ボンド\u3000オープン\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2='9月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02285': FundCodeEntry(
        fund_code='G02285',
        sec_code=None,
        fund_name='アジア\u3000オープン',
        fund_name_yomi='アジア\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02286': FundCodeEntry(
        fund_code='G02286',
        sec_code=None,
        fund_name='チャイナ\u3000オープン',
        fund_name_yomi='チャイナ\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='10月13日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02290': FundCodeEntry(
        fund_code='G02290',
        sec_code=None,
        fund_name='スーパー\u3000トレンド\u3000オープン',
        fund_name_yomi='スーパー\u3000トレンド\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02291': FundCodeEntry(
        fund_code='G02291',
        sec_code=None,
        fund_name='野村ワールドスター\u3000オープン',
        fund_name_yomi='ノムラワールドスターオープン',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02293': FundCodeEntry(
        fund_code='G02293',
        sec_code=None,
        fund_name='米国優先証券オープン',
        fund_name_yomi='ベイコクユウセンショウケンオープン',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02294': FundCodeEntry(
        fund_code='G02294',
        sec_code=None,
        fund_name='ノムラ・ボンド・インカム・オープン',
        fund_name_yomi='ノムラ\u3000ボンド\u3000インカム\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02297': FundCodeEntry(
        fund_code='G02297',
        sec_code=None,
        fund_name='野村新興国債券投信Ａコース（毎月分配型）、野村新興国債券投信Ｂコース（毎月分配型）',
        fund_name_yomi='ノムラシンコウコクサイケントウシンエーコースマイツキブンパイガタ\u3000ノムラシンコウコクサイケントウシンビーコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02298': FundCodeEntry(
        fund_code='G02298',
        sec_code=None,
        fund_name='情報エレクトロニクスファンド',
        fund_name_yomi='ジョウホウエレクトロニクスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02325': FundCodeEntry(
        fund_code='G02325',
        sec_code=None,
        fund_name='積立て株式ファンド',
        fund_name_yomi='ツミタテカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02326': FundCodeEntry(
        fund_code='G02326',
        sec_code=None,
        fund_name='日本低位株ファンド',
        fund_name_yomi='ニホンテイイカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02333': FundCodeEntry(
        fund_code='G02333',
        sec_code=None,
        fund_name='株式インデックス\u3000２２５',
        fund_name_yomi='カブシキインデックス\u3000ニニゴ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02334': FundCodeEntry(
        fund_code='G02334',
        sec_code=None,
        fund_name='トピックス・インデックス・オープン',
        fund_name_yomi='トピックスインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02335': FundCodeEntry(
        fund_code='G02335',
        sec_code='13190',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経３００株価指数連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ニッケイサンビャク\u3000カブカシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02337': FundCodeEntry(
        fund_code='G02337',
        sec_code=None,
        fund_name='東欧投資ファンド',
        fund_name_yomi='トウオウトウシファンド',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02341': FundCodeEntry(
        fund_code='G02341',
        sec_code=None,
        fund_name='ミリオン（インデックスポートフォリオ）、ミリオン（バランスポートフォリオ）、ミリオン（ジャパン\u3000ドリーム\u3000ポートフォリオ）、ミリオン（リザーブ\u3000ポートフォリオ）',
        fund_name_yomi='ミリオン\u3000インデックスポートフォリオ\u3000ミリオン\u3000バランスポートフォリオ\u3000ミリオン\u3000ジャパン\u3000ドリーム\u3000ポートフォリオ\u3000ミリオン\u3000リザーブ\u3000ポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02342': FundCodeEntry(
        fund_code='G02342',
        sec_code=None,
        fund_name='財形株投（一般財形５０）、財形株投（一般財形３０）、財形株投（年金・住宅財形３０）',
        fund_name_yomi='ザイケイカブトウ\u3000イッパンザイケイゴジュウ\u3000ザイケイカブトウ\u3000イッパンザイケイサンジュウ\u3000ザイケイカブトウ\u3000ネンキン\u3000ジュウタクザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02349': FundCodeEntry(
        fund_code='G02349',
        sec_code=None,
        fund_name='野村ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='ノムラエムアールエフ\u3000マネー\u3000リザーブ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02350': FundCodeEntry(
        fund_code='G02350',
        sec_code=None,
        fund_name='財形給付金ファンド',
        fund_name_yomi='ザイケイキュウフキンファンド',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02351': FundCodeEntry(
        fund_code='G02351',
        sec_code=None,
        fund_name='第１２回\u3000公社債投資信託',
        fund_name_yomi='ダイジュウニカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02363': FundCodeEntry(
        fund_code='G02363',
        sec_code=None,
        fund_name='スーパー小型株ポートフォリオ',
        fund_name_yomi='スーパーコガタカブポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02382': FundCodeEntry(
        fund_code='G02382',
        sec_code=None,
        fund_name='ＢＡＭワールド・ボンド＆カレンシー・ファンド（毎月決算型）',
        fund_name_yomi='バムワールドボンドアンドカレンシーファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11348',
        issuer_name='ベアリングス・ジャパン株式会社',
    ),
    'G02386': FundCodeEntry(
        fund_code='G02386',
        sec_code=None,
        fund_name='アジア未来成長株式ファンド',
        fund_name_yomi='アジアミライセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E11348',
        issuer_name='ベアリングス・ジャパン株式会社',
    ),
    'G02405': FundCodeEntry(
        fund_code='G02405',
        sec_code=None,
        fund_name='ステート・ストリート外国株式インデックス・オープン',
        fund_name_yomi='ステートストリートガイコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2='5月30日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G02407': FundCodeEntry(
        fund_code='G02407',
        sec_code=None,
        fund_name='ピクテ欧州ファンドＡコース（限定為替ヘッジ）ピクテ欧州ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='ピクテオウシュウファンドエーコースゲンテイカワセヘッジピクテオウシュウファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G02408': FundCodeEntry(
        fund_code='G02408',
        sec_code=None,
        fund_name='ピクテ・グローバル・バランス・オープン',
        fund_name_yomi='ピクテグローバルバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G02409': FundCodeEntry(
        fund_code='G02409',
        sec_code=None,
        fund_name='ピクテ・ヨーロピアン・オープン',
        fund_name_yomi='ピクテヨーロピアンオープン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G02412': FundCodeEntry(
        fund_code='G02412',
        sec_code=None,
        fund_name='ゴールドマン・サックス・世界債券オープンＡコース限定為替ヘッジ／Ｂコース為替ヘッジなし／Ｃコース毎月分配限定為替ヘッジ／Ｄコース毎月分配為替ヘッジなし',
        fund_name_yomi='ゴールドマン\u3000サックス\u3000セカイサイケンオープンエーコースゲンテイカワセヘッジ\u3000ビーコースカワセヘッジナシ\u3000シーコースマイツキブンパイゲンテイカワセヘッジ\u3000ディーコースマイツキブンパイカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02414': FundCodeEntry(
        fund_code='G02414',
        sec_code=None,
        fund_name='ＧＳ・日本株ファンド（自動けいぞく）',
        fund_name_yomi='ジーエスニホンカブファンドジドウケイゾク',
        security_type='内国投資信託受益証券',
        period_1='12月27日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02415': FundCodeEntry(
        fund_code='G02415',
        sec_code=None,
        fund_name='ＧＳ・日本株ファンド',
        fund_name_yomi='ジーエスニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月27日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02417': FundCodeEntry(
        fund_code='G02417',
        sec_code=None,
        fund_name='モナリザ\u3000\u3000ゴールドマン・サックス世界債券ファンド',
        fund_name_yomi='モナリザゴールドマンサックスセカイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02419': FundCodeEntry(
        fund_code='G02419',
        sec_code=None,
        fund_name='ガリレオ',
        fund_name_yomi='ガリレオ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02420': FundCodeEntry(
        fund_code='G02420',
        sec_code=None,
        fund_name='ダ・ヴィンチ',
        fund_name_yomi='ダヴィンチ',
        security_type='内国投資信託受益証券',
        period_1='9月14日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02422': FundCodeEntry(
        fund_code='G02422',
        sec_code=None,
        fund_name='バラエティ・オープン',
        fund_name_yomi='バラエティ\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G02434': FundCodeEntry(
        fund_code='G02434',
        sec_code=None,
        fund_name='グローバル・ボンド・オープンＩＭ',
        fund_name_yomi='グローバルボンドオープンアイエム',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E08707',
        issuer_name='モルガン・スタンレー・インベストメント・マネジメント株式会社',
    ),
    'G02440': FundCodeEntry(
        fund_code='G02440',
        sec_code=None,
        fund_name='ＪＡ海外株式ファンド',
        fund_name_yomi='ジェイエイカイガイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02441': FundCodeEntry(
        fund_code='G02441',
        sec_code=None,
        fund_name='ＪＡ海外債券ファンド',
        fund_name_yomi='ジェイエイカイガイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='10月16日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02442': FundCodeEntry(
        fund_code='G02442',
        sec_code=None,
        fund_name='ＪＡ日本債券ファンド',
        fund_name_yomi='ジェイエイニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月16日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02443': FundCodeEntry(
        fund_code='G02443',
        sec_code=None,
        fund_name='ＪＡ日本株式ファンド',
        fund_name_yomi='ジェイエイニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月16日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02455': FundCodeEntry(
        fund_code='G02455',
        sec_code=None,
        fund_name='公社債投信１月号',
        fund_name_yomi='コウシャサイトウシンイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02456': FundCodeEntry(
        fund_code='G02456',
        sec_code=None,
        fund_name='公社債投信（１月号）',
        fund_name_yomi='コウシャサイトウシンイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02457': FundCodeEntry(
        fund_code='G02457',
        sec_code=None,
        fund_name='第１回\u3000公社債投資信託',
        fund_name_yomi='ダイイッカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02459': FundCodeEntry(
        fund_code='G02459',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（１月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクイチガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02482': FundCodeEntry(
        fund_code='G02482',
        sec_code=None,
        fund_name='公社債投信９月号',
        fund_name_yomi='コウシャサイトウシンクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02487': FundCodeEntry(
        fund_code='G02487',
        sec_code=None,
        fund_name='第９回\u3000公社債投資信託',
        fund_name_yomi='ダイキュウカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02490': FundCodeEntry(
        fund_code='G02490',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（９月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタククガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02493': FundCodeEntry(
        fund_code='G02493',
        sec_code=None,
        fund_name='公社債投信（９月号）',
        fund_name_yomi='コウシャサイトウシンクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02520': FundCodeEntry(
        fund_code='G02520',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（２月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクニガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02523': FundCodeEntry(
        fund_code='G02523',
        sec_code=None,
        fund_name='第２回\u3000公社債投資信託',
        fund_name_yomi='ダイニカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02527': FundCodeEntry(
        fund_code='G02527',
        sec_code=None,
        fund_name='公社債投信（２月号）',
        fund_name_yomi='コウシャサイトウシンニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02538': FundCodeEntry(
        fund_code='G02538',
        sec_code=None,
        fund_name='公社債投信２月号',
        fund_name_yomi='コウシャサイトウシンニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02551': FundCodeEntry(
        fund_code='G02551',
        sec_code=None,
        fund_name='公社債投信１０月号',
        fund_name_yomi='コウシャサイトウシンジュウガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02552': FundCodeEntry(
        fund_code='G02552',
        sec_code=None,
        fund_name='第１０回\u3000公社債投資信託',
        fund_name_yomi='ダイジュッカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02556': FundCodeEntry(
        fund_code='G02556',
        sec_code=None,
        fund_name='三井住友・ライフビュー・日本株式ファンド',
        fund_name_yomi='ミツイスミトモライフビューニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02557': FundCodeEntry(
        fund_code='G02557',
        sec_code=None,
        fund_name='三井住友・ライフビュー・日本債券ファンド',
        fund_name_yomi='ミツイスミトモライフビューニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02558': FundCodeEntry(
        fund_code='G02558',
        sec_code=None,
        fund_name='三井住友・ライフビュー・バランスファンド３０（安定型）',
        fund_name_yomi='ミツイスミトモライフビューバランスファンドサンジュウアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02559': FundCodeEntry(
        fund_code='G02559',
        sec_code=None,
        fund_name='三井住友・ライフビュー・バランスファンド５０（標準型）',
        fund_name_yomi='ミツイスミトモライフビューバランスファンドゴジュウヒョウジュンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02560': FundCodeEntry(
        fund_code='G02560',
        sec_code=None,
        fund_name='三井住友・ライフビュー・バランスファンド７０（積極型）',
        fund_name_yomi='ミツイスミトモライフビューバランスファンドナナジュウセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02562': FundCodeEntry(
        fund_code='G02562',
        sec_code=None,
        fund_name='公社債投信（１０月号）',
        fund_name_yomi='コウシャサイトウシンジュウガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02567': FundCodeEntry(
        fund_code='G02567',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000国内バランス２０',
        fund_name_yomi='ミツビシユーエフジェイコクナイバランスニジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02571': FundCodeEntry(
        fund_code='G02571',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（１０月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシンタクジュウガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02574': FundCodeEntry(
        fund_code='G02574',
        sec_code=None,
        fund_name='ＪＡ資産設計ファンド（安定型）\u3000ＪＡ資産設計ファンド（成長型）\u3000ＪＡ資産設計ファンド（積極型）',
        fund_name_yomi='ジェイエイシサンセッケイファンド\u3000アンテイガタ\u3000ジェイエイシサンセッケイファンド\u3000セイチョウガタ\u3000ジェイエイシサンセッケイファンド\u3000セッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G02595': FundCodeEntry(
        fund_code='G02595',
        sec_code=None,
        fund_name='公社債投信（３月号）',
        fund_name_yomi='コウシャサイトウシンサンガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02600': FundCodeEntry(
        fund_code='G02600',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（３月設定）',
        fund_name_yomi='ツイカカタコウシャサイショウケントウシシンタクサンガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02603': FundCodeEntry(
        fund_code='G02603',
        sec_code=None,
        fund_name='第３回\u3000公社債投資信託',
        fund_name_yomi='ダイサンカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02608': FundCodeEntry(
        fund_code='G02608',
        sec_code=None,
        fund_name='公社債投信３月号',
        fund_name_yomi='コウシャサイトウシンサンガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02612': FundCodeEntry(
        fund_code='G02612',
        sec_code=None,
        fund_name='第１１回\u3000公社債投資信託',
        fund_name_yomi='ダイジュウイッカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02633': FundCodeEntry(
        fund_code='G02633',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000システムバリューオープン',
        fund_name_yomi='ミツビシユーエフジェイシステムバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02634': FundCodeEntry(
        fund_code='G02634',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000トピックスオープン',
        fund_name_yomi='ミツビシユーエフジェイトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02635': FundCodeEntry(
        fund_code='G02635',
        sec_code=None,
        fund_name='ダイワライフスタイル５０',
        fund_name_yomi='ダイワライフスタイルゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02636': FundCodeEntry(
        fund_code='G02636',
        sec_code=None,
        fund_name='ダイワライフスタイル７５',
        fund_name_yomi='ダイワライフスタイルナナジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02637': FundCodeEntry(
        fund_code='G02637',
        sec_code=None,
        fund_name='ダイワ投信倶楽部外国債券インデックス',
        fund_name_yomi='ダイワトウシンクラブガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02646': FundCodeEntry(
        fund_code='G02646',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＴＯＰＩＸ・ファンド',
        fund_name_yomi='ミツビシユーエフジェイトピックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02655': FundCodeEntry(
        fund_code='G02655',
        sec_code=None,
        fund_name='公社債投信（１１月号）',
        fund_name_yomi='コウシャサイトウシンジュウイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02658': FundCodeEntry(
        fund_code='G02658',
        sec_code=None,
        fund_name='ＰＲＵ海外債券マーケット・パフォーマー',
        fund_name_yomi='プルカイガイサイケンマーケットパフォーマー',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12429',
        issuer_name='ＰＧＩＭジャパン株式会社',
    ),
    'G02659': FundCodeEntry(
        fund_code='G02659',
        sec_code=None,
        fund_name='公社債投信１１月号',
        fund_name_yomi='コウシャサイトウシンジュウイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02661': FundCodeEntry(
        fund_code='G02661',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（１１月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクジュウイチガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02670': FundCodeEntry(
        fund_code='G02670',
        sec_code=None,
        fund_name='三井住友・ＤＣ年金プラン・ファンド（ターゲット・イヤー型）２０２０\u3000三井住友・ＤＣ年金プラン・ファンド（ターゲット・イヤー型）２０３０\u3000三井住友・ＤＣ年金プラン・ファンド（ターゲット・イヤー型）２０４０',
        fund_name_yomi='ミツイスミトモディーシーネンキンプランファンドターゲットイヤーガタニィゼロニィゼロ\u3000ミツイスミトモディーシーネンキンプランファンドターゲットイヤーガタニィゼロサンゼロ\u3000ミツイスミトモディーシーネンキンプランファンドターゲットイヤーガタニィゼロヨンゼロ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02690': FundCodeEntry(
        fund_code='G02690',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（４月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクシガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02695': FundCodeEntry(
        fund_code='G02695',
        sec_code=None,
        fund_name='第４回\u3000公社債投資信託',
        fund_name_yomi='ダイヨンカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02696': FundCodeEntry(
        fund_code='G02696',
        sec_code=None,
        fund_name='公社債投信（４月号）',
        fund_name_yomi='コウシャサイトウシンシガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02697': FundCodeEntry(
        fund_code='G02697',
        sec_code=None,
        fund_name='公社債投信４月号',
        fund_name_yomi='コウシャサイトウシンシガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02730': FundCodeEntry(
        fund_code='G02730',
        sec_code=None,
        fund_name='公社債投信（６月号）',
        fund_name_yomi='コウシャサイトウシンロクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02733': FundCodeEntry(
        fund_code='G02733',
        sec_code=None,
        fund_name='公社債投信６月号',
        fund_name_yomi='コウシャサイトウシンロクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02738': FundCodeEntry(
        fund_code='G02738',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（６月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクロクガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02740': FundCodeEntry(
        fund_code='G02740',
        sec_code=None,
        fund_name='ニッセイＴＯＰＩＸオープン',
        fund_name_yomi='ニッセイトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G02750': FundCodeEntry(
        fund_code='G02750',
        sec_code=None,
        fund_name='明治安田日本債券オープン（毎月決算型）',
        fund_name_yomi='メイジヤスダニホンサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G02752': FundCodeEntry(
        fund_code='G02752',
        sec_code=None,
        fund_name='明治安田外国債券オープン',
        fund_name_yomi='メイジヤスダガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G02771': FundCodeEntry(
        fund_code='G02771',
        sec_code=None,
        fund_name='公社債投信５月号',
        fund_name_yomi='コウシャサイトウシンゴガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02775': FundCodeEntry(
        fund_code='G02775',
        sec_code=None,
        fund_name='公社債投信（５月号）',
        fund_name_yomi='コウシャサイトウシンゴガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02776': FundCodeEntry(
        fund_code='G02776',
        sec_code=None,
        fund_name='公社債投信（７月号）',
        fund_name_yomi='コウシャサイトウシンシチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02779': FundCodeEntry(
        fund_code='G02779',
        sec_code=None,
        fund_name='第５回\u3000公社債投資信託',
        fund_name_yomi='ダイゴカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02785': FundCodeEntry(
        fund_code='G02785',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（５月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクゴガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02796': FundCodeEntry(
        fund_code='G02796',
        sec_code=None,
        fund_name='バランスセレクト３０',
        fund_name_yomi='バランスセレクトサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02797': FundCodeEntry(
        fund_code='G02797',
        sec_code=None,
        fund_name='バランスセレクト５０',
        fund_name_yomi='バランスセレクトゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02798': FundCodeEntry(
        fund_code='G02798',
        sec_code=None,
        fund_name='バランスセレクト７０',
        fund_name_yomi='バランスセレクトナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02803': FundCodeEntry(
        fund_code='G02803',
        sec_code=None,
        fund_name='公社債投信７月号',
        fund_name_yomi='コウシャサイトウシンシチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02809': FundCodeEntry(
        fund_code='G02809',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（７月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクシチガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02825': FundCodeEntry(
        fund_code='G02825',
        sec_code=None,
        fund_name='公社債投信（８月号）',
        fund_name_yomi='コウシャサイトウシンハチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02839': FundCodeEntry(
        fund_code='G02839',
        sec_code=None,
        fund_name='第６回\u3000公社債投資信託',
        fund_name_yomi='ダイロッカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02847': FundCodeEntry(
        fund_code='G02847',
        sec_code=None,
        fund_name='公社債投信８月号',
        fund_name_yomi='コウシャサイトウシンハチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02855': FundCodeEntry(
        fund_code='G02855',
        sec_code=None,
        fund_name='アセット・ナビゲーション・ファンド（株式６０）',
        fund_name_yomi='アセットナビゲーションファンドカブシキロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02856': FundCodeEntry(
        fund_code='G02856',
        sec_code=None,
        fund_name='アセット・ナビゲーション・ファンド（株式４０）',
        fund_name_yomi='アセットナビゲーションファンドカブシキヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02857': FundCodeEntry(
        fund_code='G02857',
        sec_code=None,
        fund_name='アセット・ナビゲーション・ファンド（株式２０）',
        fund_name_yomi='アセットナビゲーションファンドカブシキニジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02861': FundCodeEntry(
        fund_code='G02861',
        sec_code=None,
        fund_name='第８回\u3000公社債投資信託',
        fund_name_yomi='ダイハチカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02863': FundCodeEntry(
        fund_code='G02863',
        sec_code=None,
        fund_name='追加型・公社債証券投資信託（８月設定）',
        fund_name_yomi='ツイカガタコウシャサイショウケントウシシンタクハチガツセッテイ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G02877': FundCodeEntry(
        fund_code='G02877',
        sec_code=None,
        fund_name='第７回\u3000公社債投資信託',
        fund_name_yomi='ダイナナカイ\u3000コウシャサイトウシシンタク',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02888': FundCodeEntry(
        fund_code='G02888',
        sec_code=None,
        fund_name='三井住友・ワールド・パッケージ・オープン',
        fund_name_yomi='ミツイスミトモワールドパッケージオープン',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G02918': FundCodeEntry(
        fund_code='G02918',
        sec_code='13210',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経２２５連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ニッケイニニゴレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02921': FundCodeEntry(
        fund_code='G02921',
        sec_code='13050',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸ（年１回決算型）',
        fund_name_yomi='アイフリーイーティーエフトピックスネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02922': FundCodeEntry(
        fund_code='G02922',
        sec_code='13200',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経２２５（年１回決算型）',
        fund_name_yomi='アイフリーイーティーエフニッケイニイニイゴネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02923': FundCodeEntry(
        fund_code='G02923',
        sec_code='13300',
        fund_name='上場インデックスファンド２２５',
        fund_name_yomi='ジョウジョウインデックスファンドニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02925': FundCodeEntry(
        fund_code='G02925',
        sec_code='13060',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＴＯＰＩＸ連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000トピックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02944': FundCodeEntry(
        fund_code='G02944',
        sec_code=None,
        fund_name='マイストーリー・株２５、マイストーリー・株５０、マイストーリー・株７５、マイストーリー・株１００、マイストーリー・日本株１００',
        fund_name_yomi='マイストーリーカブニジュウゴ\u3000マイストーリーカブゴジュウ\u3000マイストーリーカブナナジュウゴ\u3000マイストーリーカブヒャク\u3000マイストーリーニホンカブヒャク',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G02955': FundCodeEntry(
        fund_code='G02955',
        sec_code='89520',
        fund_name='ジャパンリアルエステイト投資法人',
        fund_name_yomi='ジャパンリアルエステイトトウシホウジン',
        security_type='内国投資証券',
        period_1='3月31日',
        period_2='9月30日',
        edinet_code='E13205',
        issuer_name='ジャパンリアルエステイト投資法人',
    ),
    'G02956': FundCodeEntry(
        fund_code='G02956',
        sec_code='89510',
        fund_name='日本ビルファンド投資法人',
        fund_name_yomi='ニホンビルファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='6月30日',
        period_2='12月31日',
        edinet_code='E13206',
        issuer_name='日本ビルファンド投資法人',
    ),
    'G02966': FundCodeEntry(
        fund_code='G02966',
        sec_code=None,
        fund_name='日興・ピムコ・グローバル短期債券ファンド',
        fund_name_yomi='ニッコウピムコグローバルタンキサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G02971': FundCodeEntry(
        fund_code='G02971',
        sec_code=None,
        fund_name='ドイチェ・グローバル・バランス〈安定型〉〈成長型〉〈積極型〉',
        fund_name_yomi='ドイチェ\u3000グローバル\u3000バランス\u3000アンテイガタ\u3000セイチョウガタ\u3000セッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G02981': FundCodeEntry(
        fund_code='G02981',
        sec_code='13290',
        fund_name='ｉシェアーズ・コア\u3000日経２２５\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズコアニッケイニニゴイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G02982': FundCodeEntry(
        fund_code='G02982',
        sec_code=None,
        fund_name='日本新生ファンド（愛称：ライジングパワー）',
        fund_name_yomi='ニホンシンセイファンドアイショウライジングパワー',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G02986': FundCodeEntry(
        fund_code='G02986',
        sec_code=None,
        fund_name='ＤＣ・ダイワ・トピックス・インデックス（確定拠出年金専用ファンド）',
        fund_name_yomi='ディーシーダイワトピックスインデックスカクテイキョシュツネンキンセンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G02988': FundCodeEntry(
        fund_code='G02988',
        sec_code=None,
        fund_name='ＪＰＭワールド・ＣＢ・オープン',
        fund_name_yomi='ジェイピーエムワールドシービーオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G02994': FundCodeEntry(
        fund_code='G02994',
        sec_code=None,
        fund_name='東京海上セレクション・日本株式',
        fund_name_yomi='トウキョウカイジョウセレクションニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G02995': FundCodeEntry(
        fund_code='G02995',
        sec_code=None,
        fund_name='東京海上セレクション・日本株ＴＯＰＩＸ',
        fund_name_yomi='トウキョウカイジョウセレクションニホンカブトピックス',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G02996': FundCodeEntry(
        fund_code='G02996',
        sec_code=None,
        fund_name='東京海上セレクション・外国株式',
        fund_name_yomi='トウキョウカイジョウセレクションガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G02997': FundCodeEntry(
        fund_code='G02997',
        sec_code=None,
        fund_name='東京海上セレクション・外国債券',
        fund_name_yomi='トウキョウカイジョウセレクションガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G02999': FundCodeEntry(
        fund_code='G02999',
        sec_code=None,
        fund_name='東京海上セレクション・バランス３０／東京海上セレクション・バランス５０／東京海上セレクション・バランス７０',
        fund_name_yomi='トウキョウカイジョウセレクションバランスサンジュウ\u3000トウキョウカイジョウセレクションバランスゴジュウ\u3000トウキョウカイジョウセレクションバランスナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G03006': FundCodeEntry(
        fund_code='G03006',
        sec_code=None,
        fund_name='ＰＲＵグッドライフ２０３０（年金）',
        fund_name_yomi='プルグッドライフ\u3000ニゼロサンゼロ\u3000ネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12429',
        issuer_name='ＰＧＩＭジャパン株式会社',
    ),
    'G03007': FundCodeEntry(
        fund_code='G03007',
        sec_code=None,
        fund_name='ＰＲＵグッドライフ２０４０（年金）',
        fund_name_yomi='プルグッドライフ\u3000ニゼロヨンゼロ\u3000ネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12429',
        issuer_name='ＰＧＩＭジャパン株式会社',
    ),
    'G03011': FundCodeEntry(
        fund_code='G03011',
        sec_code=None,
        fund_name='ＤＣマイセレクション２５',
        fund_name_yomi='ディーシーマイセレクションニジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03012': FundCodeEntry(
        fund_code='G03012',
        sec_code=None,
        fund_name='ＤＣマイセレクション５０',
        fund_name_yomi='ディーシーマイセレクションゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03013': FundCodeEntry(
        fund_code='G03013',
        sec_code=None,
        fund_name='ＤＣマイセレクション７５',
        fund_name_yomi='ディーシーマイセレクションナナジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03014': FundCodeEntry(
        fund_code='G03014',
        sec_code=None,
        fund_name='ＤＣ日本株式インデックス・オープン',
        fund_name_yomi='ディーシーニホンカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03015': FundCodeEntry(
        fund_code='G03015',
        sec_code=None,
        fund_name='ＤＣ日本債券インデックス・オープン',
        fund_name_yomi='ディーシーニホンサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03016': FundCodeEntry(
        fund_code='G03016',
        sec_code=None,
        fund_name='ＤＣ外国株式インデックス・オープン',
        fund_name_yomi='ディーシーガイコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03017': FundCodeEntry(
        fund_code='G03017',
        sec_code=None,
        fund_name='ＤＣ外国債券インデックス・オープン',
        fund_name_yomi='ディーシーガイコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03019': FundCodeEntry(
        fund_code='G03019',
        sec_code=None,
        fund_name='三井住友・ＤＣバランスファンド（安定型）\u3000三井住友・ＤＣバランスファンド（安定成長型）\u3000三井住友・ＤＣバランスファンド（成長型）',
        fund_name_yomi='ミツイスミトモディーシーバランスファンドアンテイガタ\u3000ミツイスミトモディーシーバランスファンドアンテイセイチョウガタ\u3000ミツイスミトモディーシーバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03020': FundCodeEntry(
        fund_code='G03020',
        sec_code=None,
        fund_name='三井住友・ＤＣ国内株式アクティブＳ',
        fund_name_yomi='ミツイスミトモディーシーコクナイカブシキアクティブエス',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03021': FundCodeEntry(
        fund_code='G03021',
        sec_code=None,
        fund_name='三井住友・ＤＣ国内債券アクティブ',
        fund_name_yomi='ミツイスミトモディーシーコクナイサイケンアクティブ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03022': FundCodeEntry(
        fund_code='G03022',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国株式アクティブ',
        fund_name_yomi='ミツイスミトモディーシーガイコクカブシキアクティブ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03023': FundCodeEntry(
        fund_code='G03023',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国債券アクティブ',
        fund_name_yomi='ミツイスミトモディーシーガイコクサイケンアクティブ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03024': FundCodeEntry(
        fund_code='G03024',
        sec_code=None,
        fund_name='ハイ・イールド\u3000ボンド\u3000オープン\u3000Ｃコース、ハイ・イールド\u3000ボンド\u3000オープン\u3000Ｄコース',
        fund_name_yomi='ハイ\u3000イールド\u3000ボンド\u3000オープン\u3000シーコース\u3000ハイ\u3000イールド\u3000ボンド\u3000オープン\u3000ディーコース',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2='9月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03026': FundCodeEntry(
        fund_code='G03026',
        sec_code=None,
        fund_name='三井住友・ニュー・チャイナ・ファンド',
        fund_name_yomi='ミツイスミトモニューチャイナファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03027': FundCodeEntry(
        fund_code='G03027',
        sec_code=None,
        fund_name='ＤＩＡＭ日本株式オープン＜ＤＣ年金＞',
        fund_name_yomi='ダイアムニホンカブシキオープンディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03028': FundCodeEntry(
        fund_code='G03028',
        sec_code=None,
        fund_name='ＤＩＡＭ外国株式オープン＜ＤＣ年金＞',
        fund_name_yomi='ダイアムガイコクカブシキオープンディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2='6月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03029': FundCodeEntry(
        fund_code='G03029',
        sec_code=None,
        fund_name='ＤＩＡＭライフサイクル・ファンド＜ＤＣ年金＞１安定型／２安定・成長型／３成長型',
        fund_name_yomi='ダイアムライフサイクルファンドディーシーネンキンイチアンテイガタニアンテイセイチョウガタサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03037': FundCodeEntry(
        fund_code='G03037',
        sec_code=None,
        fund_name='三井住友・ＤＣ年金日本債券ファンド',
        fund_name_yomi='ミツイスミトモディーシーネンキンニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03038': FundCodeEntry(
        fund_code='G03038',
        sec_code=None,
        fund_name='２２５ＩＤＸオープン',
        fund_name_yomi='ニーニーゴアイディエックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G03040': FundCodeEntry(
        fund_code='G03040',
        sec_code=None,
        fund_name='年金積立\u3000グローバル・ラップ・バランス（安定型）',
        fund_name_yomi='ネンキンツミタテグローバルラップバランスアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03041': FundCodeEntry(
        fund_code='G03041',
        sec_code=None,
        fund_name='年金積立\u3000グローバル・ラップ・バランス（安定成長型）',
        fund_name_yomi='ネンキンツミタテグローバルラップバランスアンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03042': FundCodeEntry(
        fund_code='G03042',
        sec_code=None,
        fund_name='年金積立\u3000グローバル・ラップ・バランス（成長型）',
        fund_name_yomi='ネンキンツミタテグローバルラップバランスセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03043': FundCodeEntry(
        fund_code='G03043',
        sec_code=None,
        fund_name='年金積立\u3000グローバル・ラップ・バランス（積極成長型）',
        fund_name_yomi='ネンキンツミタテグローバルラップバランスセッキョクセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03044': FundCodeEntry(
        fund_code='G03044',
        sec_code=None,
        fund_name='年金積立\u3000グローバル・ラップ・バランス（積極型）',
        fund_name_yomi='ネンキンツミタテグローバルラップバランスセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03045': FundCodeEntry(
        fund_code='G03045',
        sec_code=None,
        fund_name='年金積立\u3000アセット・ナビゲーション・ファンド（株式２０）',
        fund_name_yomi='ネンキンツミタテアセットナビゲーションファンドカブシキニジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03046': FundCodeEntry(
        fund_code='G03046',
        sec_code=None,
        fund_name='年金積立\u3000アセット・ナビゲーション・ファンド（株式４０）',
        fund_name_yomi='ネンキンツミタテアセットナビゲーションファンドカブシキヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03047': FundCodeEntry(
        fund_code='G03047',
        sec_code=None,
        fund_name='年金積立\u3000アセット・ナビゲーション・ファンド（株式６０）',
        fund_name_yomi='ネンキンツミタテアセットナビゲーションファンドカブシキロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03048': FundCodeEntry(
        fund_code='G03048',
        sec_code=None,
        fund_name='年金積立\u3000アセット・ナビゲーション・ファンド（株式８０）',
        fund_name_yomi='ネンキンツミタテアセットナビゲーションファンドカブシキハチジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03049': FundCodeEntry(
        fund_code='G03049',
        sec_code=None,
        fund_name='インデックスファンド日本債券（１年決算型）',
        fund_name_yomi='インデックスファンドニホンサイケン\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03050': FundCodeEntry(
        fund_code='G03050',
        sec_code=None,
        fund_name='インデックスファンド海外株式（ヘッジなし）',
        fund_name_yomi='インデックスファンドカイガイカブシキ\u3000ヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03051': FundCodeEntry(
        fund_code='G03051',
        sec_code=None,
        fund_name='インデックスファンド海外株式（ヘッジあり）',
        fund_name_yomi='インデックスファンドカイガイカブシキ\u3000ヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03052': FundCodeEntry(
        fund_code='G03052',
        sec_code=None,
        fund_name='インデックスファンド海外債券（ヘッジなし）１年決算型',
        fund_name_yomi='インデックスファンドカイガイサイケン\u3000ヘッジナシ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03053': FundCodeEntry(
        fund_code='G03053',
        sec_code=None,
        fund_name='インデックスファンド海外債券（ヘッジあり）１年決算型',
        fund_name_yomi='インデックスファンドカイガイサイケン\u3000ヘッジアリ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03054': FundCodeEntry(
        fund_code='G03054',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ライフ・バランスファンド（安定型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーライフバランスファンドアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='8月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03055': FundCodeEntry(
        fund_code='G03055',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ライフ・バランスファンド（安定成長型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーライフバランスファンドアンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03056': FundCodeEntry(
        fund_code='G03056',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ライフ・バランスファンド（成長型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーライフバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03057': FundCodeEntry(
        fund_code='G03057',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ライフ・バランスファンド（積極型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーライフバランスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='8月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03058': FundCodeEntry(
        fund_code='G03058',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞海外債券オープン',
        fund_name_yomi='ミツビシユーエフジェイディーシーカイガイサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03059': FundCodeEntry(
        fund_code='G03059',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ＴＯＰＩＸ・ファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシートピックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03062': FundCodeEntry(
        fund_code='G03062',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・グロース・オポチュニティーズ（年金つみたて向け）',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000グローバル\u3000グロース\u3000オポチュニティーズ\u3000ネンキンツミタテムケ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G03066': FundCodeEntry(
        fund_code='G03066',
        sec_code=None,
        fund_name='年金積立\u3000アクティブ・ダイナミクス',
        fund_name_yomi='ネンキンツミタテアクティブダイナミクス',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03067': FundCodeEntry(
        fund_code='G03067',
        sec_code=None,
        fund_name='年金積立\u3000日本短期債券オープン',
        fund_name_yomi='ネンキンツミタテニホンタンキサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='10月28日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03068': FundCodeEntry(
        fund_code='G03068',
        sec_code=None,
        fund_name='年金積立\u3000クオンツ・アクティブ・ジャパン',
        fund_name_yomi='ネンキンツミタテクオンツアクティブジャパン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03069': FundCodeEntry(
        fund_code='G03069',
        sec_code=None,
        fund_name='年金積立\u3000インターナショナル・ボンド・ファンド',
        fund_name_yomi='ネンキンツミタテインターナショナルボンドファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03070': FundCodeEntry(
        fund_code='G03070',
        sec_code=None,
        fund_name='年金積立\u3000インターナショナル・グロース・ファンド',
        fund_name_yomi='ネンキンツミタテインターナショナルグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03071': FundCodeEntry(
        fund_code='G03071',
        sec_code=None,
        fund_name='三井住友・ＤＣ年金日本株式２２５ファンド',
        fund_name_yomi='ミツイスミトモディーシーネンキンニホンカブシキニィニィゴファンド',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03074': FundCodeEntry(
        fund_code='G03074',
        sec_code=None,
        fund_name='年金積立\u3000エコファンド',
        fund_name_yomi='ネンキンツミタテエコファンド',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03075': FundCodeEntry(
        fund_code='G03075',
        sec_code=None,
        fund_name='インデックスファンドＴＯＰＩＸ（日本株式）',
        fund_name_yomi='インデックスファンドトピックス\u3000ニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03076': FundCodeEntry(
        fund_code='G03076',
        sec_code=None,
        fund_name='インデックスファンド２２５（日本株式）',
        fund_name_yomi='インデックスファンドニーニーゴ\u3000ニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03078': FundCodeEntry(
        fund_code='G03078',
        sec_code=None,
        fund_name='年金積立\u3000Ｊグロース',
        fund_name_yomi='ネンキンツミタテジェイグロース',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03079': FundCodeEntry(
        fund_code='G03079',
        sec_code=None,
        fund_name='年金積立\u3000ジャパンオープン',
        fund_name_yomi='ネンキンツミタテジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03080': FundCodeEntry(
        fund_code='G03080',
        sec_code=None,
        fund_name='ゴールドマン・サックス・世界債券オープンＡ限定為替ヘッジ（確定拠出年金向け）\u3000Ｂ為替ヘッジなし（確定拠出年金向け）',
        fund_name_yomi='ゴールドマンサックスセカイサイケンオープンエーゲンテイカワセヘッジカクテイキョシュツネンキンムケ\u3000ビーカワセヘッジナシカクテイキョウシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G03081': FundCodeEntry(
        fund_code='G03081',
        sec_code=None,
        fund_name='シュローダー日本ファンド（確定拠出年金向け）',
        fund_name_yomi='シュローダーニホンファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月24日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G03082': FundCodeEntry(
        fund_code='G03082',
        sec_code=None,
        fund_name='フィデリティ・グローバル・エクイティ・オープン\u3000Ａ（限定為替ヘッジ）（確定拠出年金向け）',
        fund_name_yomi='フィデリティグローバルエクイティオープン\u3000エイゲンテイカワセヘッジ\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03083': FundCodeEntry(
        fund_code='G03083',
        sec_code=None,
        fund_name='フィデリティ・ジャパン・オープン（確定拠出年金向け）',
        fund_name_yomi='フィデリティジャパンオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03084': FundCodeEntry(
        fund_code='G03084',
        sec_code=None,
        fund_name='マイストーリー・株２５（確定拠出年金向け）',
        fund_name_yomi='マイストーリ\u3000カブニイゴウ\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03085': FundCodeEntry(
        fund_code='G03085',
        sec_code=None,
        fund_name='マイストーリー・株５０（確定拠出年金向け）',
        fund_name_yomi='マイストーリー\u3000カブゴジュウ\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03086': FundCodeEntry(
        fund_code='G03086',
        sec_code=None,
        fund_name='マイストーリー・株７５（確定拠出年金向け）',
        fund_name_yomi='マイストーリー\u3000カブナナジュウゴ\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03087': FundCodeEntry(
        fund_code='G03087',
        sec_code=None,
        fund_name='マイストーリー・株１００（確定拠出年金向け）',
        fund_name_yomi='マイストリー\u3000カブヒャク\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03088': FundCodeEntry(
        fund_code='G03088',
        sec_code=None,
        fund_name='マイストーリー・日本株１００（確定拠出年金向け）',
        fund_name_yomi='マイストーリー\u3000ニホンカブヒャク\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03089': FundCodeEntry(
        fund_code='G03089',
        sec_code=None,
        fund_name='トピックス・インデックス・オープン（確定拠出年金向け）',
        fund_name_yomi='トピックスインデックスオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='9月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03090': FundCodeEntry(
        fund_code='G03090',
        sec_code=None,
        fund_name='リサーチ・アクティブ・オープン\u3000（確定拠出年金向け）',
        fund_name_yomi='リサーチアクティブオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月30日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03091': FundCodeEntry(
        fund_code='G03091',
        sec_code=None,
        fund_name='ノムラ・ジャパン・オープン（確定拠出年金向け）',
        fund_name_yomi='ノムラジャパンオープンカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03092': FundCodeEntry(
        fund_code='G03092',
        sec_code=None,
        fund_name='野村日本株アクティブ・コアファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラニホンカブアクティブコアファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03093': FundCodeEntry(
        fund_code='G03093',
        sec_code=None,
        fund_name='ノムラ日本債券オープン（確定拠出年金向け）',
        fund_name_yomi='ノムラニホンサイケンオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03095': FundCodeEntry(
        fund_code='G03095',
        sec_code=None,
        fund_name='大同ＤＣ２２５インデックスファンド',
        fund_name_yomi='ダイドウディシーニーニーゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G03098': FundCodeEntry(
        fund_code='G03098',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・米ドル毎月分配型ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ベイドルマイツキブンパイガタファンド',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G03101': FundCodeEntry(
        fund_code='G03101',
        sec_code=None,
        fund_name='シュローダーＤＣアクティブ日本株式',
        fund_name_yomi='シュローダーディーシーアクティブニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G03103': FundCodeEntry(
        fund_code='G03103',
        sec_code=None,
        fund_name='シュローダーＤＣアクティブ外国株式',
        fund_name_yomi='シュローダーディーシーアクティブガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G03105': FundCodeEntry(
        fund_code='G03105',
        sec_code=None,
        fund_name='シュローダー年金運用ファンド日本株式',
        fund_name_yomi='シュローダーネンキンウンヨウファンドニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G03106': FundCodeEntry(
        fund_code='G03106',
        sec_code=None,
        fund_name='シュローダー年金運用ファンド日本債券',
        fund_name_yomi='シュローダーネンキンウンヨウファンドニホンサイケン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G03107': FundCodeEntry(
        fund_code='G03107',
        sec_code=None,
        fund_name='ＤＩＡＭジャパン・セレクション＜ＤＣ年金＞',
        fund_name_yomi='ダイアムジャパンセレクションディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03110': FundCodeEntry(
        fund_code='G03110',
        sec_code=None,
        fund_name='損保ジャパン日本株オープン（ＤＣ年金）',
        fund_name_yomi='ソンポジャパンニホンカブオープン\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='10月31日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G03120': FundCodeEntry(
        fund_code='G03120',
        sec_code=None,
        fund_name='ＪＰＭ日本株・オープン',
        fund_name_yomi='ジェイピーエムニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G03123': FundCodeEntry(
        fund_code='G03123',
        sec_code=None,
        fund_name='バランスセレクト３０（確定拠出年金向け）',
        fund_name_yomi='バランスセレクトサンジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03124': FundCodeEntry(
        fund_code='G03124',
        sec_code=None,
        fund_name='バランスセレクト５０（確定拠出年金向け）',
        fund_name_yomi='バランスセレクトゴジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03125': FundCodeEntry(
        fund_code='G03125',
        sec_code=None,
        fund_name='バランスセレクト７０（確定拠出年金向け）',
        fund_name_yomi='バランスセレクトナナジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03126': FundCodeEntry(
        fund_code='G03126',
        sec_code=None,
        fund_name='フィデリティ・グローバル・エクイティ・オープン\u3000Ｂ（為替ヘッジなし）（確定拠出年金向け）',
        fund_name_yomi='フィデリティグローバルエクイティオープン\u3000ビーカワセヘッジナシ\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03128': FundCodeEntry(
        fund_code='G03128',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞ターゲット・イヤー\u3000ファンド\u3000２０３０／２０４０',
        fund_name_yomi='ミツビシユーエフジェイディーシーターゲットイヤーファンドニーゼロサンゼロニーゼロヨンゼロ',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03129': FundCodeEntry(
        fund_code='G03129',
        sec_code=None,
        fund_name='＜ＤＣ＞日本株スタイル・ミックス・ファンド',
        fund_name_yomi='ディーシーニホンカブスタイルミックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03130': FundCodeEntry(
        fund_code='G03130',
        sec_code=None,
        fund_name='＜ＤＣ＞インデックスファンド２２５',
        fund_name_yomi='ディーシーインデックスファンドニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03132': FundCodeEntry(
        fund_code='G03132',
        sec_code=None,
        fund_name='ＤＣニッセイグローバルアクティブ株式',
        fund_name_yomi='ディーシーニッセイグローバルアクティブカブシキ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03143': FundCodeEntry(
        fund_code='G03143',
        sec_code=None,
        fund_name='ＤＣ・ダイワ・バリュー株・オープン',
        fund_name_yomi='ディーシーダイワバリューカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03144': FundCodeEntry(
        fund_code='G03144',
        sec_code=None,
        fund_name='明治安田ＤＣ日本株式リサーチオープン',
        fund_name_yomi='メイジヤスダディーシーニホンカブシキリサーチオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03145': FundCodeEntry(
        fund_code='G03145',
        sec_code=None,
        fund_name='明治安田ＤＣ日本債券オープン',
        fund_name_yomi='メイジヤスダディーシーニホンサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03146': FundCodeEntry(
        fund_code='G03146',
        sec_code=None,
        fund_name='明治安田ＤＣグローバルバランスオープン',
        fund_name_yomi='メイジヤスダディーシーグローバルバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03147': FundCodeEntry(
        fund_code='G03147',
        sec_code=None,
        fund_name='明治安田ＤＣハートフルライフ（プラン３０）\u3000明治安田ＤＣハートフルライフ（プラン５０）\u3000明治安田ＤＣハートフルライフ（プラン７０）',
        fund_name_yomi='メイジヤスダディーシーハートフルライフプランサンジュウ\u3000メイジヤスダディーシーハートフルライフプランゴジュウ\u3000メイジヤスダディーシーハートフルライフプランナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03148': FundCodeEntry(
        fund_code='G03148',
        sec_code=None,
        fund_name='明治安田ＤＣ外国株式リサーチオープン',
        fund_name_yomi='メイジヤスダディーシーガイコクカブシキリサーチオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03149': FundCodeEntry(
        fund_code='G03149',
        sec_code=None,
        fund_name='明治安田ＤＣ外国債券オープン',
        fund_name_yomi='メイジヤスダディーシーガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03154': FundCodeEntry(
        fund_code='G03154',
        sec_code=None,
        fund_name='ＤＣニッセイバランスアクティブ',
        fund_name_yomi='ディーシーニッセイバランスアクティブ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03155': FundCodeEntry(
        fund_code='G03155',
        sec_code=None,
        fund_name='ＤＣニッセイ国内債券インデックス',
        fund_name_yomi='ディーシーニッセイコクナイサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03156': FundCodeEntry(
        fund_code='G03156',
        sec_code=None,
        fund_name='ＤＣニッセイグローバルバランス（債券重視型）／ＤＣニッセイグローバルバランス（標\u3000準\u3000型）／ＤＣニッセイグローバルバランス（株式重視型）',
        fund_name_yomi='ディーシーニッセイグローバルバランスサイケンジュウシガタ\u3000ディーシーニッセイグローバルバランスヒョウジュンガタ\u3000ディーシーニッセイグローバルバランスカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03159': FundCodeEntry(
        fund_code='G03159',
        sec_code=None,
        fund_name='ＤＣ・ダイワ・ジャパン・オープン（確定拠出年金専用ファンド）',
        fund_name_yomi='ディーシーダイワジャパンオープンカクテイキョシュツネンキンセンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03160': FundCodeEntry(
        fund_code='G03160',
        sec_code=None,
        fund_name='いちよしグロース１',
        fund_name_yomi='イチヨシグロースワン',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G03161': FundCodeEntry(
        fund_code='G03161',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞日本債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーニホンサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03162': FundCodeEntry(
        fund_code='G03162',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞外国株式インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03164': FundCodeEntry(
        fund_code='G03164',
        sec_code=None,
        fund_name='ダイワ・チャイナ・ファンド',
        fund_name_yomi='ダイワチャイナファンド',
        security_type='内国投資信託受益証券',
        period_1='12月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03172': FundCodeEntry(
        fund_code='G03172',
        sec_code=None,
        fund_name='日立国内株式インデックスファンド',
        fund_name_yomi='ヒタチコクナイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E13347',
        issuer_name='日立投資顧問株式会社',
    ),
    'G03173': FundCodeEntry(
        fund_code='G03173',
        sec_code=None,
        fund_name='日立国内債券インデックスファンド',
        fund_name_yomi='ヒタチコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E13347',
        issuer_name='日立投資顧問株式会社',
    ),
    'G03174': FundCodeEntry(
        fund_code='G03174',
        sec_code=None,
        fund_name='日立外国株式インデックスファンド',
        fund_name_yomi='ヒタチガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E13347',
        issuer_name='日立投資顧問株式会社',
    ),
    'G03175': FundCodeEntry(
        fund_code='G03175',
        sec_code=None,
        fund_name='日立外国債券インデックスファンド',
        fund_name_yomi='ヒタチガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E13347',
        issuer_name='日立投資顧問株式会社',
    ),
    'G03176': FundCodeEntry(
        fund_code='G03176',
        sec_code=None,
        fund_name='日立バランスファンド（株式７０）、日立バランスファンド（株式５０）、日立バランスファンド（株式３０）',
        fund_name_yomi='ヒタチバランスファンド\u3000カブシキナナジュウ\u3000ヒタチバランスファンド\u3000カブシキゴジュウ\u3000ヒタチバランスファンド\u3000カブシキサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E13347',
        issuer_name='日立投資顧問株式会社',
    ),
    'G03177': FundCodeEntry(
        fund_code='G03177',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ厳選日本成長株オープン',
        fund_name_yomi='ミツビシユーエフジェイディーシーゲンセンニホンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03178': FundCodeEntry(
        fund_code='G03178',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞海外株式オープン',
        fund_name_yomi='ミツビシユーエフジェイディーシーカイガイカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03179': FundCodeEntry(
        fund_code='G03179',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞日本債券ファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03181': FundCodeEntry(
        fund_code='G03181',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国債券インカムオープン',
        fund_name_yomi='ミツビシユーエフジェイベイコクサイケンインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03183': FundCodeEntry(
        fund_code='G03183',
        sec_code=None,
        fund_name='野村日本債券ファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラニホンサイケンファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03188': FundCodeEntry(
        fund_code='G03188',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞外国債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03189': FundCodeEntry(
        fund_code='G03189',
        sec_code=None,
        fund_name='ＤＣ\u3000\u3000ガリレオ',
        fund_name_yomi='ディーシー\u3000\u3000ガリレオ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G03192': FundCodeEntry(
        fund_code='G03192',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞インデックス・ライフ・バランス\u3000ファンド（安定型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーインデックスライフバランスファンドアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03193': FundCodeEntry(
        fund_code='G03193',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞インデックス・ライフ・バランス\u3000ファンド（安定成長型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーインデックスライフバランスファンドアンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03194': FundCodeEntry(
        fund_code='G03194',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞インデックス・ライフ・バランス\u3000ファンド（成長型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーインデックスライフバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03195': FundCodeEntry(
        fund_code='G03195',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞インデックス・ライフ・バランス\u3000ファンド（積極型）',
        fund_name_yomi='ミツビシユーエフジェイディーシーインデックスライフバランスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03196': FundCodeEntry(
        fund_code='G03196',
        sec_code='13080',
        fund_name='上場インデックスファンドＴＯＰＩＸ',
        fund_name_yomi='ジョウジョウインデックスファンドトピックス',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03197': FundCodeEntry(
        fund_code='G03197',
        sec_code=None,
        fund_name='ＴＯＰＩＸインデックスファンド（個人型年金向け）',
        fund_name_yomi='トピックスインデックスファンドコジンガタネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03198': FundCodeEntry(
        fund_code='G03198',
        sec_code=None,
        fund_name='海外債券インデックスファンド（個人型年金向け）',
        fund_name_yomi='カイガイサイケンインデックスファンドコジンガタネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03199': FundCodeEntry(
        fund_code='G03199',
        sec_code=None,
        fund_name='日本債券インデックスファンド（個人型年金向け）',
        fund_name_yomi='ニホンサイケンインデックスファンドコジンガタネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03200': FundCodeEntry(
        fund_code='G03200',
        sec_code=None,
        fund_name='ＤＣ・ダイワ・ストックインデックス２２５（確定拠出年金専用ファンド）',
        fund_name_yomi='ディーシーダイワストックインデックスニイニイゴカクテイキョシュツネンキンセンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03205': FundCodeEntry(
        fund_code='G03205',
        sec_code=None,
        fund_name='ニッセイ日本株ファンド',
        fund_name_yomi='ニッセイニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03206': FundCodeEntry(
        fund_code='G03206',
        sec_code=None,
        fund_name='ＤＣニッセイ／パトナム・グローバル債券',
        fund_name_yomi='ディーシーニッセイパトナムグローバルサイケン',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03207': FundCodeEntry(
        fund_code='G03207',
        sec_code=None,
        fund_name='ＤＣニッセイ国内株式アクティブ',
        fund_name_yomi='ディーシーニッセイコクナイカブシキアクティブ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03212': FundCodeEntry(
        fund_code='G03212',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000トピックスオープン（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000トピックスオープンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03214': FundCodeEntry(
        fund_code='G03214',
        sec_code=None,
        fund_name='三井住友・日本債券インデックス・ファンド',
        fund_name_yomi='ミツイスミトモニホンサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03216': FundCodeEntry(
        fund_code='G03216',
        sec_code=None,
        fund_name='ステート・ストリートＤＣ外国株式インデックス・オープン',
        fund_name_yomi='ステートストリートディーシーガイコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2='5月30日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G03220': FundCodeEntry(
        fund_code='G03220',
        sec_code=None,
        fund_name='日本インデックス２２５ＤＣファンド',
        fund_name_yomi='ニホンインデックスニーニーゴディーシーファンド',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G03222': FundCodeEntry(
        fund_code='G03222',
        sec_code=None,
        fund_name='野村日本国債インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラニホンコクサイインデックスファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03224': FundCodeEntry(
        fund_code='G03224',
        sec_code=None,
        fund_name='ＨＳＢＣチャイナオープン',
        fund_name_yomi='エイチエスビーシーチャイナオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G03231': FundCodeEntry(
        fund_code='G03231',
        sec_code=None,
        fund_name='東京海上セレクション・日本債券',
        fund_name_yomi='トウキョウカイジョウセレクションニホンサイケン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G03239': FundCodeEntry(
        fund_code='G03239',
        sec_code=None,
        fund_name='野村外国株式インデックスファンド・ＭＳＣＩ－ＫＯＫＵＳＡＩ（確定拠出年金向け）',
        fund_name_yomi='ノムラガイコクカブシキインデックスファンドエムエスシーアイコクサイカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03241': FundCodeEntry(
        fund_code='G03241',
        sec_code=None,
        fund_name='ＤＣファンダメンタル・バリュー\u3000ファンド',
        fund_name_yomi='ディーシーファンダメンタルバリュー\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03242': FundCodeEntry(
        fund_code='G03242',
        sec_code=None,
        fund_name='ＤＣリサーチ・グロース\u3000ファンド',
        fund_name_yomi='ディーシーリサーチ\u3000グロース\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03243': FundCodeEntry(
        fund_code='G03243',
        sec_code=None,
        fund_name='ＤＣニッセイ国内債券アクティブ',
        fund_name_yomi='ディーシーニッセイコクナイサイケンアクティブ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03244': FundCodeEntry(
        fund_code='G03244',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞グローバルバランス\u3000６０型／４０型／２０型',
        fund_name_yomi='ミツビシユーエフジェイディーシーグローバルバランスロクジュウガタヨンジュウガタニジュウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03247': FundCodeEntry(
        fund_code='G03247',
        sec_code=None,
        fund_name='野村外国債券パッシブファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラガイコクサイケンパッシブファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03248': FundCodeEntry(
        fund_code='G03248',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000海外債券オープン（３ヵ月決算型）',
        fund_name_yomi='ミツビシユーエフジェイカイガイサイケンオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03250': FundCodeEntry(
        fund_code='G03250',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ国内債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03251': FundCodeEntry(
        fund_code='G03251',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000外国債券オープン（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ガイコクサイケンオープンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03252': FundCodeEntry(
        fund_code='G03252',
        sec_code=None,
        fund_name='ＤＣ・ダイワ・アクティブ・ニッポン（確定拠出年金専用ファンド）',
        fund_name_yomi='ディーシーダイワアクティブニッポンカクテイキョシュツネンキンセンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03256': FundCodeEntry(
        fund_code='G03256',
        sec_code=None,
        fund_name='三井住友・日本債券年金ファンド',
        fund_name_yomi='ミツイスミトモニホンサイケンネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03266': FundCodeEntry(
        fund_code='G03266',
        sec_code=None,
        fund_name='フィデリティ・日本バリュー・ファンド',
        fund_name_yomi='フィデリティニホンバリューファンド',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03274': FundCodeEntry(
        fund_code='G03274',
        sec_code='89530',
        fund_name='日本都市ファンド投資法人',
        fund_name_yomi='ニホントシファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E13410',
        issuer_name='日本都市ファンド投資法人',
    ),
    'G03280': FundCodeEntry(
        fund_code='G03280',
        sec_code=None,
        fund_name='スパークス・日本株・ロング・ショート・ファンド',
        fund_name_yomi='スパークス\u3000ニホンカブ\u3000ロング\u3000ショート\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G03284': FundCodeEntry(
        fund_code='G03284',
        sec_code=None,
        fund_name='ワールド・ソブリンインカム（愛称\u3000十二単衣）',
        fund_name_yomi='ワールドソブリンインカムアイショウジュウニヒトエ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G03286': FundCodeEntry(
        fund_code='G03286',
        sec_code=None,
        fund_name='ステート・ストリートＤＣ外国債券インデックス・オープン',
        fund_name_yomi='ステートストリートディーシーガイコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G03302': FundCodeEntry(
        fund_code='G03302',
        sec_code='13110',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＴＯＰＩＸ\u3000Ｃｏｒｅ\u3000３０連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000トピックス\u3000コア\u3000サンジュウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03305': FundCodeEntry(
        fund_code='G03305',
        sec_code='16150',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000東証銀行業株価指数連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000トウショウギンコウギョウカブカシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03309': FundCodeEntry(
        fund_code='G03309',
        sec_code=None,
        fund_name='静岡ベンチマーク・ファンド',
        fund_name_yomi='シズオカベンチマークファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03312': FundCodeEntry(
        fund_code='G03312',
        sec_code=None,
        fund_name='国内債券・株式バランスファンド（確定拠出年金向け）',
        fund_name_yomi='コクナイサイケンカブシキバランスファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03322': FundCodeEntry(
        fund_code='G03322',
        sec_code=None,
        fund_name='ダイワ成長株オープン',
        fund_name_yomi='ダイワセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='5月9日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03328': FundCodeEntry(
        fund_code='G03328',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・ボンド・ファンド',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000グローバル\u3000ボンド\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月1日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G03335': FundCodeEntry(
        fund_code='G03335',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・ユーロ毎月分配型ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ユーロマイツキブンパイガタファンド',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G03338': FundCodeEntry(
        fund_code='G03338',
        sec_code='89540',
        fund_name='オリックス不動産投資法人',
        fund_name_yomi='オリックスフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='8月31日',
        period_2='2月28日',
        edinet_code='E13445',
        issuer_name='オリックス不動産投資法人',
    ),
    'G03340': FundCodeEntry(
        fund_code='G03340',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本株アクティブオープン（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイニホンカブアクティブオープンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03341': FundCodeEntry(
        fund_code='G03341',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000インデックス２２５オープン（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイインデックスニニゴオープンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03342': FundCodeEntry(
        fund_code='G03342',
        sec_code=None,
        fund_name='ゴールドマン・サックス毎月分配債券ファンド',
        fund_name_yomi='ゴールドマン\u3000サックスマイツキブンパイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G03344': FundCodeEntry(
        fund_code='G03344',
        sec_code=None,
        fund_name='ＳＢＩ\u3000ＴＯＰＩＸ１００・インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='エスビーアイ\u3000トピックスヒャク\u3000インデックスファンド\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G03345': FundCodeEntry(
        fund_code='G03345',
        sec_code='89550',
        fund_name='日本プライムリアルティ投資法人',
        fund_name_yomi='ニホンプライムリアルティトウシホウジン',
        security_type='内国投資証券',
        period_1='6月30日',
        period_2='12月31日',
        edinet_code='E13448',
        issuer_name='日本プライムリアルティ投資法人',
    ),
    'G03346': FundCodeEntry(
        fund_code='G03346',
        sec_code=None,
        fund_name='グローバル・バリュー・オープン（確定拠出年金向け）',
        fund_name_yomi='グローバルバリューオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03347': FundCodeEntry(
        fund_code='G03347',
        sec_code=None,
        fund_name='東海３県ファンド',
        fund_name_yomi='トウカイサンケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月1日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G03350': FundCodeEntry(
        fund_code='G03350',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000欧州債券オープン（３ヵ月決算型）',
        fund_name_yomi='ミツビシユーエフジェイオウシュウサイケンオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03362': FundCodeEntry(
        fund_code='G03362',
        sec_code=None,
        fund_name='ダイワ日本株オープン',
        fund_name_yomi='ダイワニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03365': FundCodeEntry(
        fund_code='G03365',
        sec_code=None,
        fund_name='グローバル・ボンド・ポート\u3000毎月決算コース（為替ヘッジなし）',
        fund_name_yomi='グローバルボンドポート\u3000マイツキケッサンコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03373': FundCodeEntry(
        fund_code='G03373',
        sec_code=None,
        fund_name='ニッセイ／パトナム・ユーロインカムオープン',
        fund_name_yomi='ニッセイパトナムユーロインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03375': FundCodeEntry(
        fund_code='G03375',
        sec_code=None,
        fund_name='マイバランス３０（確定拠出年金向け）',
        fund_name_yomi='マイバランスサンジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03376': FundCodeEntry(
        fund_code='G03376',
        sec_code=None,
        fund_name='マイバランス５０（確定拠出年金向け）',
        fund_name_yomi='マイバランスゴジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03377': FundCodeEntry(
        fund_code='G03377',
        sec_code=None,
        fund_name='マイバランス７０（確定拠出年金向け）',
        fund_name_yomi='マイバランスナナジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03379': FundCodeEntry(
        fund_code='G03379',
        sec_code=None,
        fund_name='茨城ファンド',
        fund_name_yomi='イバラギファンド',
        security_type='内国投資信託受益証券',
        period_1='7月29日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03384': FundCodeEntry(
        fund_code='G03384',
        sec_code=None,
        fund_name='しんきん国内債券ファンド',
        fund_name_yomi='シンキンコクナイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G03385': FundCodeEntry(
        fund_code='G03385',
        sec_code=None,
        fund_name='しんきん好配当利回り株ファンド',
        fund_name_yomi='シンキンコウハイトウリマワリカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月6日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G03387': FundCodeEntry(
        fund_code='G03387',
        sec_code=None,
        fund_name='野村国内債券インデックスファンド・ＮＯＭＵＲＡ－ＢＰＩ総合（確定拠出年金向け）',
        fund_name_yomi='ノムラコクナイサイケンインデックスファンドノムラビーピーアイソウゴウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03392': FundCodeEntry(
        fund_code='G03392',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000外国債券オープン（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイガイコクサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03393': FundCodeEntry(
        fund_code='G03393',
        sec_code=None,
        fund_name='ドイチェ・ヨーロッパ\u3000インカム\u3000オープン',
        fund_name_yomi='ドイチェ\u3000ヨーロッパ\u3000インカム\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G03394': FundCodeEntry(
        fund_code='G03394',
        sec_code=None,
        fund_name='第８回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイハチカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03400': FundCodeEntry(
        fund_code='G03400',
        sec_code=None,
        fund_name='ＤＣ静岡ベンチマーク・ファンド',
        fund_name_yomi='ディーシーシズオカベンチマークファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03404': FundCodeEntry(
        fund_code='G03404',
        sec_code=None,
        fund_name='第９回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイキュウカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03405': FundCodeEntry(
        fund_code='G03405',
        sec_code='89560',
        fund_name='ＮＴＴ都市開発リート投資法人',
        fund_name_yomi='エヌティティトシカイハツリートトウシホウジン',
        security_type='内国投資証券',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E13484',
        issuer_name='ＮＴＴ都市開発リート投資法人',
    ),
    'G03424': FundCodeEntry(
        fund_code='G03424',
        sec_code=None,
        fund_name='ＤＩＡＭ外国株式インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムガイコクカブシキインデックスファンド\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03425': FundCodeEntry(
        fund_code='G03425',
        sec_code=None,
        fund_name='ピクテ・ユーロ最高格付国債ファンド（毎月決算型）',
        fund_name_yomi='ピクテユーロサイコウカクヅケコクサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G03431': FundCodeEntry(
        fund_code='G03431',
        sec_code=None,
        fund_name='第１０回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイジュッカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03442': FundCodeEntry(
        fund_code='G03442',
        sec_code=None,
        fund_name='ダイワ高格付豪ドル債オープン（毎月分配型）',
        fund_name_yomi='ダイワコウカクツケゴウドルサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03445': FundCodeEntry(
        fund_code='G03445',
        sec_code=None,
        fund_name='野村国内株式インデックスファンド・ＴＯＰＩＸ（確定拠出年金向け）',
        fund_name_yomi='ノムラコクナイカブシキインデックスファンドトピックス\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03447': FundCodeEntry(
        fund_code='G03447',
        sec_code=None,
        fund_name='ピクテ・ユーロ最高格付国債ファンド（３ヵ月決算型）',
        fund_name_yomi='ピクテユーロサイコウカクヅケコクサイファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G03451': FundCodeEntry(
        fund_code='G03451',
        sec_code=None,
        fund_name='第１１回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイジュウイッカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03455': FundCodeEntry(
        fund_code='G03455',
        sec_code=None,
        fund_name='明治安田外国債券オープン（毎月分配型）',
        fund_name_yomi='メイジヤスダガイコクサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03456': FundCodeEntry(
        fund_code='G03456',
        sec_code=None,
        fund_name='野村外国債券インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03462': FundCodeEntry(
        fund_code='G03462',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000プライムバランス（安定型）（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイプライムバランスアンテイガタカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03463': FundCodeEntry(
        fund_code='G03463',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000プライムバランス（安定成長型）（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイプライムバランスアンテイセイチョウガタカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03464': FundCodeEntry(
        fund_code='G03464',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000プライムバランス（成長型）（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイプライムバランスセイチョウガタカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03470': FundCodeEntry(
        fund_code='G03470',
        sec_code=None,
        fund_name='パインブリッジ米国優先証券ファンド',
        fund_name_yomi='パインブリッジベイコクユウセンショウケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G03475': FundCodeEntry(
        fund_code='G03475',
        sec_code=None,
        fund_name='野村国内債券インデックスファンド',
        fund_name_yomi='ノムラコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03476': FundCodeEntry(
        fund_code='G03476',
        sec_code=None,
        fund_name='野村外国株式インデックスファンド',
        fund_name_yomi='ノムラガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03477': FundCodeEntry(
        fund_code='G03477',
        sec_code=None,
        fund_name='野村外国債券インデックスファンド',
        fund_name_yomi='ノムラガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03478': FundCodeEntry(
        fund_code='G03478',
        sec_code=None,
        fund_name='ＤＩＡＭ国内株式インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムコクナイカブシキインデックスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03486': FundCodeEntry(
        fund_code='G03486',
        sec_code=None,
        fund_name='第１２回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイジュウニカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03493': FundCodeEntry(
        fund_code='G03493',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣトピックスオープン',
        fund_name_yomi='ミツビシユーエフジェイディーシートピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03494': FundCodeEntry(
        fund_code='G03494',
        sec_code=None,
        fund_name='ＤＩＡＭ国内債券インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムコクナイサイケンインデックスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03500': FundCodeEntry(
        fund_code='G03500',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ユーロ債券オープン（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイユーロサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03503': FundCodeEntry(
        fund_code='G03503',
        sec_code=None,
        fund_name='ＤＣダイワ外国債券インデックス',
        fund_name_yomi='ディーシーダイワガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03512': FundCodeEntry(
        fund_code='G03512',
        sec_code=None,
        fund_name='ＤＩＡＭ外国債券インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムガイコクサイケンインデックスファンド\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03513': FundCodeEntry(
        fund_code='G03513',
        sec_code=None,
        fund_name='インデックスファンド海外債券ヘッジあり（ＤＣ専用）',
        fund_name_yomi='インデックスファンドカイガイサイケンヘッジアリディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03514': FundCodeEntry(
        fund_code='G03514',
        sec_code=None,
        fund_name='インデックスファンド海外債券ヘッジなし（ＤＣ専用）',
        fund_name_yomi='インデックスファンドカイガイサイケンヘッジナシディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03515': FundCodeEntry(
        fund_code='G03515',
        sec_code=None,
        fund_name='インデックスファンド海外株式ヘッジあり（ＤＣ専用）',
        fund_name_yomi='インデックスファンドカイガイカブシキヘッジアリディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03516': FundCodeEntry(
        fund_code='G03516',
        sec_code=None,
        fund_name='インデックスファンド海外株式ヘッジなし（ＤＣ専用）',
        fund_name_yomi='インデックスファンドカイガイカブシキヘッジナシディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03517': FundCodeEntry(
        fund_code='G03517',
        sec_code=None,
        fund_name='ＤＣインデックスバランス（株式２０）',
        fund_name_yomi='ディーシーインデックスバランスカブシキニジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03518': FundCodeEntry(
        fund_code='G03518',
        sec_code=None,
        fund_name='ＤＣインデックスバランス（株式６０）',
        fund_name_yomi='ディーシーインデックスバランスカブシキロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03519': FundCodeEntry(
        fund_code='G03519',
        sec_code=None,
        fund_name='ＤＣインデックスバランス（株式４０）',
        fund_name_yomi='ディーシーインデックスバランスカブシキヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03520': FundCodeEntry(
        fund_code='G03520',
        sec_code=None,
        fund_name='ＤＣインデックスバランス（株式８０）',
        fund_name_yomi='ディーシーインデックスバランスカブシキハチジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03523': FundCodeEntry(
        fund_code='G03523',
        sec_code=None,
        fund_name='ＤＩＡＭバランス・ファンド＜ＤＣ年金＞１安定型、ＤＩＡＭバランス・ファンド＜ＤＣ年金＞２安定・成長型、ＤＩＡＭバランス・ファンド＜ＤＣ年金＞３成長型',
        fund_name_yomi='ダイアムバランスファンドディーシーネンキンイチアンテイガタ\u3000ダイアムバランスファンドディーシーネンキンニアンテイセイチョウガタ\u3000ダイアムバランスファンドディーシーネンキンサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03529': FundCodeEntry(
        fund_code='G03529',
        sec_code=None,
        fund_name='第１回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイイッカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03534': FundCodeEntry(
        fund_code='G03534',
        sec_code=None,
        fund_name='彩の国応援ファンド',
        fund_name_yomi='サイノクニオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03541': FundCodeEntry(
        fund_code='G03541',
        sec_code=None,
        fund_name='ＤＣニッセイワールドセレクトファンド（債券重視型）／ＤＣニッセイワールドセレクトファンド（標準型）／ＤＣニッセイワールドセレクトファンド（株式重視型）',
        fund_name_yomi='ディーシーニッセイワールドセレクトファンドサイケンジュウシガタ\u3000ディーシーニッセイワールドセレクトファンドヒョウジュンガタ\u3000ディーシーニッセイワールドセレクトファンドカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03542': FundCodeEntry(
        fund_code='G03542',
        sec_code=None,
        fund_name='ＤＣ\u3000アクティブ\u3000バリュー\u3000オープン',
        fund_name_yomi='ディーシーアクティブバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G03544': FundCodeEntry(
        fund_code='G03544',
        sec_code=None,
        fund_name='三井住友・日本株式インデックス年金ファンド',
        fund_name_yomi='ミツイスミトモニホンカブシキインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03546': FundCodeEntry(
        fund_code='G03546',
        sec_code=None,
        fund_name='イーストスプリング米国高利回り社債オープン',
        fund_name_yomi='イーストスプリングベイコクコウリマワリシャサイオープン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G03547': FundCodeEntry(
        fund_code='G03547',
        sec_code=None,
        fund_name='ＤＩＡＭグローバル・ボンド・ポート\u3000毎月決算コース２',
        fund_name_yomi='ダイアムグローバルボンドポートマイツキケッサンコースツー',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03549': FundCodeEntry(
        fund_code='G03549',
        sec_code=None,
        fund_name='第２回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイニカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03550': FundCodeEntry(
        fund_code='G03550',
        sec_code=None,
        fund_name='スパークス・日本株・Ｌ＆Ｓ',
        fund_name_yomi='スパークス\u3000ニホンカブ\u3000エルアンドエス',
        security_type='内国投資信託受益証券',
        period_1='2月13日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G03554': FundCodeEntry(
        fund_code='G03554',
        sec_code=None,
        fund_name='ＤＣダイワ日本株式インデックス',
        fund_name_yomi='ディーシーダイワニホンカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03555': FundCodeEntry(
        fund_code='G03555',
        sec_code=None,
        fund_name='ＤＣダイワ日本債券インデックス',
        fund_name_yomi='ディーシーダイワニホンサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03556': FundCodeEntry(
        fund_code='G03556',
        sec_code=None,
        fund_name='ＤＣダイワ外国株式インデックス',
        fund_name_yomi='ディーシーダイワガイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03558': FundCodeEntry(
        fund_code='G03558',
        sec_code=None,
        fund_name='三井住友・ヨーロッパ国債ファンド',
        fund_name_yomi='ミツイスミトモヨーロッパコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03560': FundCodeEntry(
        fund_code='G03560',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国債券オープン（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ベイコクサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03561': FundCodeEntry(
        fund_code='G03561',
        sec_code=None,
        fund_name='インベスコ\u3000オーストラリア債券ファンド（毎月決算型）',
        fund_name_yomi='インベスコ\u3000オーストラリアサイケンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G03563': FundCodeEntry(
        fund_code='G03563',
        sec_code=None,
        fund_name='ＤＣ日本債券インデックス・オープンＳ',
        fund_name_yomi='ディーシーニホンサイケンインデックスオープンエス',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03565': FundCodeEntry(
        fund_code='G03565',
        sec_code=None,
        fund_name='ＧＷ７つの卵',
        fund_name_yomi='ジーダブリュウナナツノタマゴ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03568': FundCodeEntry(
        fund_code='G03568',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ジャパン・アクティブ・ファンド',
        fund_name_yomi='ミツビシユーエフジェイジャパンアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月30日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03571': FundCodeEntry(
        fund_code='G03571',
        sec_code=None,
        fund_name='ヨーロッパ国債ファンド（毎月決算型）',
        fund_name_yomi='ヨーロッパコクサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03573': FundCodeEntry(
        fund_code='G03573',
        sec_code=None,
        fund_name='第３回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイサンカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03576': FundCodeEntry(
        fund_code='G03576',
        sec_code=None,
        fund_name='ニッセイ日本勝ち組ファンド',
        fund_name_yomi='ニッセイニホンカチグミファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03587': FundCodeEntry(
        fund_code='G03587',
        sec_code=None,
        fund_name='外国債券オープン（毎月決算型）',
        fund_name_yomi='ガイコクサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03590': FundCodeEntry(
        fund_code='G03590',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000豪ドル債券インカムオープン',
        fund_name_yomi='ミツビシユーエフジェイゴウドルサイケンインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03593': FundCodeEntry(
        fund_code='G03593',
        sec_code=None,
        fund_name='日興・ＧＳ\u3000世界ソブリン・ファンド（毎月分配型）',
        fund_name_yomi='ニッコウジーエスセカイソブリンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03596': FundCodeEntry(
        fund_code='G03596',
        sec_code=None,
        fund_name='東海３県ファンド（確定拠出年金）',
        fund_name_yomi='トウカイサンケンファンドカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G03599': FundCodeEntry(
        fund_code='G03599',
        sec_code=None,
        fund_name='第４回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイヨンカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03601': FundCodeEntry(
        fund_code='G03601',
        sec_code=None,
        fund_name='ワールド・インカムオープン',
        fund_name_yomi='ワールドインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03615': FundCodeEntry(
        fund_code='G03615',
        sec_code=None,
        fund_name='第５回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイゴカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03623': FundCodeEntry(
        fund_code='G03623',
        sec_code=None,
        fund_name='豪ドル毎月分配型ファンド',
        fund_name_yomi='ゴウドルマイツキブンパイガタファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03624': FundCodeEntry(
        fund_code='G03624',
        sec_code=None,
        fund_name='ダイワ高格付カナダドル債オープン（毎月分配型）',
        fund_name_yomi='ダイワコウカクツケカナダドルサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03631': FundCodeEntry(
        fund_code='G03631',
        sec_code=None,
        fund_name='ハイグレード・オセアニア・ボンド・オープン（毎月分配型）',
        fund_name_yomi='ハイグレードオセアニアボンドオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03633': FundCodeEntry(
        fund_code='G03633',
        sec_code=None,
        fund_name='第６回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイロッカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03634': FundCodeEntry(
        fund_code='G03634',
        sec_code=None,
        fund_name='明治安田ＴＯＰＩＸオープン',
        fund_name_yomi='メイジヤスダトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03635': FundCodeEntry(
        fund_code='G03635',
        sec_code=None,
        fund_name='ピクテ・ハイインカム・ソブリン・ファンド（毎月決算型）為替ヘッジなしコース',
        fund_name_yomi='ピクテハイインカムソブリンファンドマイツキケッサンガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G03648': FundCodeEntry(
        fund_code='G03648',
        sec_code=None,
        fund_name='三井住友・豪ドル債ファンド',
        fund_name_yomi='ミツイスミトモゴウドルサイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03651': FundCodeEntry(
        fund_code='G03651',
        sec_code=None,
        fund_name='ピクテ・ユーロ最高格付国債インカム・ファンド（毎月決算型）',
        fund_name_yomi='ピクテユーロサイコウカクヅケコクサイインカムファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G03652': FundCodeEntry(
        fund_code='G03652',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・オーストラリア毎月分配型ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000オーストラリアマイツキブンパイガタファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G03656': FundCodeEntry(
        fund_code='G03656',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000グローバル・ボンド・オープン（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイグローバルボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03664': FundCodeEntry(
        fund_code='G03664',
        sec_code=None,
        fund_name='しんきん海外ソブリン債セレクション',
        fund_name_yomi='シンキンカイガイソブリンサイセレクション',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G03666': FundCodeEntry(
        fund_code='G03666',
        sec_code=None,
        fund_name='第７回\u3000野村短期公社債ファンド',
        fund_name_yomi='ダイナナカイ\u3000ノムラタンキコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03675': FundCodeEntry(
        fund_code='G03675',
        sec_code=None,
        fund_name='ニッセイ／パトナム・毎月分配インカムオープン',
        fund_name_yomi='ニッセイパトナムマイツキブンパイインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03677': FundCodeEntry(
        fund_code='G03677',
        sec_code=None,
        fund_name='ＤＩＡＭ高格付インカム・オープン（毎月決算コース）',
        fund_name_yomi='ダイアムコウカクツケインカムオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03684': FundCodeEntry(
        fund_code='G03684',
        sec_code=None,
        fund_name='日興グローイング・ベンチャーファンド',
        fund_name_yomi='ニッコウグローイングベンチャーファンド',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03693': FundCodeEntry(
        fund_code='G03693',
        sec_code=None,
        fund_name='ピムコ\u3000ハイ・インカム毎月分配型ファンド',
        fund_name_yomi='ピムコハイインカムマイツキブンパイガタファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03702': FundCodeEntry(
        fund_code='G03702',
        sec_code=None,
        fund_name='ＵＢＳオーストラリア債券オープン（毎月分配型）',
        fund_name_yomi='ユービエースオーストラリアサイケンオープン\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G03706': FundCodeEntry(
        fund_code='G03706',
        sec_code=None,
        fund_name='財産３分法ファンド（不動産・債券・株式）毎月分配型',
        fund_name_yomi='ザイサンサンブンポウファンドフドウサンサイケンカブシキマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03707': FundCodeEntry(
        fund_code='G03707',
        sec_code=None,
        fund_name='高金利先進国債券オープン（毎月分配型）',
        fund_name_yomi='コウキンリセンシンコクサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03711': FundCodeEntry(
        fund_code='G03711',
        sec_code=None,
        fund_name='ＪＰＭジャパン・ディスカバリー・ファンド',
        fund_name_yomi='ジェイピーエムジャパンディスカバリーファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G03719': FundCodeEntry(
        fund_code='G03719',
        sec_code='89570',
        fund_name='東急リアル・エステート投資法人',
        fund_name_yomi='トウキュウリアルエステートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E13661',
        issuer_name='東急リアル・エステート投資法人',
    ),
    'G03726': FundCodeEntry(
        fund_code='G03726',
        sec_code=None,
        fund_name='野村豪州債券ファンド（年２回決算型）、野村豪州債券ファンド（毎月分配型）',
        fund_name_yomi='ノムラゴウシュウサイケンファンド\u3000ネンニカイケッサンガタ\u3000ノムラゴウシュウサイケンファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03732': FundCodeEntry(
        fund_code='G03732',
        sec_code=None,
        fund_name='ハイグレード・オセアニア・ボンド・オープン（３カ月決算型）',
        fund_name_yomi='ハイグレードオセアニアボンドオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03733': FundCodeEntry(
        fund_code='G03733',
        sec_code=None,
        fund_name='ニッセイ／パトナム・毎月分配ユーロインカムオープン',
        fund_name_yomi='ニッセイパトナムマイツキブンパイユーロインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03736': FundCodeEntry(
        fund_code='G03736',
        sec_code=None,
        fund_name='三井住友・中小型株ファンド',
        fund_name_yomi='ミツイスミトモチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03737': FundCodeEntry(
        fund_code='G03737',
        sec_code=None,
        fund_name='オーストラリアインカムオープン',
        fund_name_yomi='オーストラリアインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03744': FundCodeEntry(
        fund_code='G03744',
        sec_code='89580',
        fund_name='グローバル・ワン不動産投資法人',
        fund_name_yomi='グローバルワンフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='3月31日',
        period_2='9月30日',
        edinet_code='E13678',
        issuer_name='グローバル・ワン不動産投資法人',
    ),
    'G03746': FundCodeEntry(
        fund_code='G03746',
        sec_code=None,
        fund_name='日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（米ドルコース）日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（円ヘッジコース）',
        fund_name_yomi='ニッコウピムコハイインカムソブリンファンドマイツキブンパイガタベイドルコースニッコウピムコハイインカムソブリンファンドマイツキブンパイガタエンヘッジコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03747': FundCodeEntry(
        fund_code='G03747',
        sec_code=None,
        fund_name='日興\u3000豪州\u3000インカム・オープン（毎月分配型）',
        fund_name_yomi='ニッコウゴウシュウインカムオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03752': FundCodeEntry(
        fund_code='G03752',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（米国）',
        fund_name_yomi='ワールドリートセレクションベイコク',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G03755': FundCodeEntry(
        fund_code='G03755',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ国内株式インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーコクナイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03764': FundCodeEntry(
        fund_code='G03764',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000オーストラリアボンドファンド（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイオーストラリアボンドファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03769': FundCodeEntry(
        fund_code='G03769',
        sec_code=None,
        fund_name='アムンディ・中国株ファンド',
        fund_name_yomi='アムンディチュウゴクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G03771': FundCodeEntry(
        fund_code='G03771',
        sec_code=None,
        fund_name='ゴールドマン・サックス米国ＲＥＩＴファンドＡコース（毎月分配型、為替ヘッジあり）／Ｂコース（毎月分配型、為替ヘッジなし）',
        fund_name_yomi='ゴールドマン\u3000サックスベイコクリートファンドエーコース\u3000マイツキブンパイガタ\u3000カワセヘッジアリ\u3000\u3000ビーコース\u3000マイツキブンパイガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G03775': FundCodeEntry(
        fund_code='G03775',
        sec_code=None,
        fund_name='Ｏｎｅ中国関連株オープン',
        fund_name_yomi='ワンチュウゴクカンレンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2='10月30日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03776': FundCodeEntry(
        fund_code='G03776',
        sec_code=None,
        fund_name='野村リアルグロース・オープン',
        fund_name_yomi='ノムラリアルグロースオープン',
        security_type='内国投資信託受益証券',
        period_1='10月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03779': FundCodeEntry(
        fund_code='G03779',
        sec_code=None,
        fund_name='フィデリティ・ジャパン・グロース・オープン',
        fund_name_yomi='フィデリティジャパングロースオープン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03787': FundCodeEntry(
        fund_code='G03787',
        sec_code=None,
        fund_name='グローバル・ハイインカム・ストック・ファンド',
        fund_name_yomi='グローバル\u3000ハイインカム\u3000ストック\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03788': FundCodeEntry(
        fund_code='G03788',
        sec_code=None,
        fund_name='オーストラリア債券ファンド',
        fund_name_yomi='オーストラリアサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03790': FundCodeEntry(
        fund_code='G03790',
        sec_code=None,
        fund_name='ＵＢＳ\u3000ＤＣ海外株式ファンド',
        fund_name_yomi='ユービーエス\u3000ディーシー\u3000カイガイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G03798': FundCodeEntry(
        fund_code='G03798',
        sec_code=None,
        fund_name='ワールド・ゲノムテクノロジー・オープン\u3000Ａコース、ワールド・ゲノムテクノロジー・オープン\u3000Ｂコース',
        fund_name_yomi='ワールドゲノムテクノロジーオープン\u3000エーコース\u3000ワールドゲノムテクノロジーオープン\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='11月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03800': FundCodeEntry(
        fund_code='G03800',
        sec_code=None,
        fund_name='ダイワＪ－ＲＥＩＴオープン',
        fund_name_yomi='ダイワジェイリートオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03803': FundCodeEntry(
        fund_code='G03803',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・グローバル・プラス（毎月分配型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000グローバル\u3000プラス\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G03804': FundCodeEntry(
        fund_code='G03804',
        sec_code=None,
        fund_name='インデックスファンド日本債券（ＤＣ専用）',
        fund_name_yomi='インデックスファンドニホンサイケンディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03805': FundCodeEntry(
        fund_code='G03805',
        sec_code=None,
        fund_name='インデックスファンド日本株式（ＤＣ専用）',
        fund_name_yomi='インデックスファンドニホンカブシキディーシーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03811': FundCodeEntry(
        fund_code='G03811',
        sec_code=None,
        fund_name='エル・プラス２００３－１１',
        fund_name_yomi='エルプラスニセンサンジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03814': FundCodeEntry(
        fund_code='G03814',
        sec_code=None,
        fund_name='フィデリティ・ＵＳリート・ファンドＡ（為替ヘッジあり）\u3000フィデリティ・ＵＳリート・ファンドＢ（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスリートファンドエイカワセヘッジアリ\u3000フィデリティユーエスリートファンドビーカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G03819': FundCodeEntry(
        fund_code='G03819',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳトレジャリ－・インカム・ファンド（３ヶ月決算型）',
        fund_name_yomi='ジェイピーエムユーエストレジャリーインカムファンド\u3000サンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G03824': FundCodeEntry(
        fund_code='G03824',
        sec_code=None,
        fund_name='明治安田ＤＣ日本株式アルファオープン',
        fund_name_yomi='メイジヤスダディーシーニホンカブシキアルファオープン',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G03829': FundCodeEntry(
        fund_code='G03829',
        sec_code=None,
        fund_name='利回り財産３分法ファンド（不動産・債券・株式）毎月分配型',
        fund_name_yomi='リマワリザイサンサンブンポウファンドフドウサンサイケンカブシキマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03832': FundCodeEntry(
        fund_code='G03832',
        sec_code=None,
        fund_name='ピムコ\u3000ハイ・インカム毎月分配型ファンド（為替ヘッジ付き）',
        fund_name_yomi='ピムコハイインカムマイツキブンパイガタファンドカワセヘッジツキ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03839': FundCodeEntry(
        fund_code='G03839',
        sec_code=None,
        fund_name='ＳＲＩ・ジャパン・オープン',
        fund_name_yomi='エスアールアイジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='12月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03840': FundCodeEntry(
        fund_code='G03840',
        sec_code=None,
        fund_name='パインブリッジ世界国債インカムオープン「毎月タイプ」\u3000パインブリッジ世界国債インカムオープン「年金タイプ」',
        fund_name_yomi='パインブリッジセカイコクサイインカムオープンマイツキタイプ\u3000パインブリッジセカイコクサイインカムオープンネンキンタイプ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G03852': FundCodeEntry(
        fund_code='G03852',
        sec_code=None,
        fund_name='米欧債券・インカムオープン',
        fund_name_yomi='ベイオウサイケン\u3000インカムオープン',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03857': FundCodeEntry(
        fund_code='G03857',
        sec_code='89600',
        fund_name='ユナイテッド・アーバン投資法人',
        fund_name_yomi='ユナイテッドアーバントウシホウジン',
        security_type='内国投資証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E13756',
        issuer_name='ユナイテッド・アーバン投資法人',
    ),
    'G03862': FundCodeEntry(
        fund_code='G03862',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000Ｊ‐ＲＥＩＴオープン（毎月決算コース）',
        fund_name_yomi='ダイアムジェイリートオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03867': FundCodeEntry(
        fund_code='G03867',
        sec_code=None,
        fund_name='日興ワールド・カレンシー・ファンド２００４－０１',
        fund_name_yomi='ニッコウワールドカレンシーファンドニーマルマルヨンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2='7月29日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03869': FundCodeEntry(
        fund_code='G03869',
        sec_code=None,
        fund_name='日興グローバルＲＥＩＴファンド毎月分配型\u3000Ａ（ヘッジなし）',
        fund_name_yomi='ニッコウグローバルリートファンドマイツキブンパイガタ\u3000エー\u3000ヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03875': FundCodeEntry(
        fund_code='G03875',
        sec_code=None,
        fund_name='きらめきジャパン',
        fund_name_yomi='キラメキジャパン',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03876': FundCodeEntry(
        fund_code='G03876',
        sec_code=None,
        fund_name='チャイナ・ロード',
        fund_name_yomi='チャイナロード',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2='7月28日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G03880': FundCodeEntry(
        fund_code='G03880',
        sec_code=None,
        fund_name='三井住友・グローバル・リート・オープン',
        fund_name_yomi='ミツイスミトモグローバルリートオープン',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G03883': FundCodeEntry(
        fund_code='G03883',
        sec_code='89610',
        fund_name='森トラストリート投資法人',
        fund_name_yomi='モリトラストリートトウシホウジン',
        security_type='内国投資証券',
        period_1='8月末日',
        period_2='2月末日',
        edinet_code='E13771',
        issuer_name='森トラストリート投資法人',
    ),
    'G03887': FundCodeEntry(
        fund_code='G03887',
        sec_code=None,
        fund_name='ニッセイ日経２２５インデックスファンド',
        fund_name_yomi='ニッセイニッケイニニゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G03889': FundCodeEntry(
        fund_code='G03889',
        sec_code=None,
        fund_name='ラッセル・インベストメント日本株式ファンド（ＤＣ向け）',
        fund_name_yomi='ラッセルインベストメントニホンカブシキファンド\u3000ディーシームケ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G03893': FundCodeEntry(
        fund_code='G03893',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000Ｊ‐ＲＥＩＴオープン（２カ月決算コース）',
        fund_name_yomi='ダイアム\u3000ジェイリートオープンニカゲツケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03897': FundCodeEntry(
        fund_code='G03897',
        sec_code=None,
        fund_name='日興ワールド・カレンシー・ファンド２００４－０２',
        fund_name_yomi='ニッコウワールドカレンシーファンドニーマルマルヨンゼロニ',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2='7月29日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03898': FundCodeEntry(
        fund_code='G03898',
        sec_code=None,
        fund_name='ピムコ・ハイイールド・ファンドＡコース（為替ヘッジなし）ピムコ・ハイイールド・ファンドＢコース（為替ヘッジあり）',
        fund_name_yomi='ピムコハイイールドファンドエーコースカワセヘッジナシピムコハイイールドファンドビーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03901': FundCodeEntry(
        fund_code='G03901',
        sec_code=None,
        fund_name='世界ソブリン債券インカムオープン',
        fund_name_yomi='セカイソブリンサイケンインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03912': FundCodeEntry(
        fund_code='G03912',
        sec_code=None,
        fund_name='パインブリッジ米国ＲＥＩＴインカムファンドＡコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='パインブリッジベイコクリートインカムファンド\u3000エイコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G03917': FundCodeEntry(
        fund_code='G03917',
        sec_code=None,
        fund_name='ノムラファンドマスターズ日本小型株',
        fund_name_yomi='ノムラファンドマスターズニホンコガタカブ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03927': FundCodeEntry(
        fund_code='G03927',
        sec_code=None,
        fund_name='ＤＣグッドカンパニー（社会的責任投資）',
        fund_name_yomi='ディーシーグッドカンパニーシャカイテキセキニントウシ',
        security_type='内国投資信託受益証券',
        period_1='12月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G03942': FundCodeEntry(
        fund_code='G03942',
        sec_code=None,
        fund_name='ワールド・ウォーター・ファンドＡコース\u3000ワールド・ウォーター・ファンドＢコース',
        fund_name_yomi='ワールドウォーターファンドエイコース\u3000ワールドウォーターファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03947': FundCodeEntry(
        fund_code='G03947',
        sec_code=None,
        fund_name='ラサール・グローバルＲＥＩＴファンド（毎月分配型）',
        fund_name_yomi='ラサールグローバルリートファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03961': FundCodeEntry(
        fund_code='G03961',
        sec_code=None,
        fund_name='Ｏｎｅワールド・リート・インカム・オープン（毎月決算コース）',
        fund_name_yomi='ワンワールドリートインカムオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='4月9日',
        period_2='10月9日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G03967': FundCodeEntry(
        fund_code='G03967',
        sec_code=None,
        fund_name='ノムラ日米ＲＥＩＴファンド',
        fund_name_yomi='ノムラニチベイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='4月6日',
        period_2='10月6日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G03975': FundCodeEntry(
        fund_code='G03975',
        sec_code=None,
        fund_name='スパークス・アクティブ・ジャパン',
        fund_name_yomi='スパークス\u3000アクティブ\u3000ジャパン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G03980': FundCodeEntry(
        fund_code='G03980',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000外国株式インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G03982': FundCodeEntry(
        fund_code='G03982',
        sec_code=None,
        fund_name='フコクＳＲＩ（社会的責任投資）ファンド',
        fund_name_yomi='フコクエスアールアイシャカイテキセキニントウシファンド',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G03983': FundCodeEntry(
        fund_code='G03983',
        sec_code=None,
        fund_name='スパークス・ジャパン・オープン',
        fund_name_yomi='スパークス\u3000ジャパン\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G03984': FundCodeEntry(
        fund_code='G03984',
        sec_code=None,
        fund_name='日興ワールドＲＥＩＴファンド',
        fund_name_yomi='ニッコウワールドリートファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2='8月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G03985': FundCodeEntry(
        fund_code='G03985',
        sec_code=None,
        fund_name='ダイワＪ－ＲＥＩＴオープン（毎月分配型）',
        fund_name_yomi='ダイワジェイリートオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03986': FundCodeEntry(
        fund_code='G03986',
        sec_code=None,
        fund_name='ダイワ米国リート・ファンド（毎月分配型）\u3000為替ヘッジあり／為替ヘッジなし',
        fund_name_yomi='ダイワベイコクリートファンドマイツキブンパイガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G03991': FundCodeEntry(
        fund_code='G03991',
        sec_code='89630',
        fund_name='インヴィンシブル投資法人',
        fund_name_yomi='インヴィンシブルトウシホウジン',
        security_type='内国投資証券',
        period_1='6月30日',
        period_2='12月31日',
        edinet_code='E13833',
        issuer_name='インヴィンシブル投資法人',
    ),
    'G04006': FundCodeEntry(
        fund_code='G04006',
        sec_code=None,
        fund_name='野村グローバルＳＲＩ\u3000１００',
        fund_name_yomi='ノムラグローバルエスアールアイ\u3000ヒャク',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04014': FundCodeEntry(
        fund_code='G04014',
        sec_code=None,
        fund_name='チャイナ・リサーチ・オープン',
        fund_name_yomi='チャイナリサーチオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04021': FundCodeEntry(
        fund_code='G04021',
        sec_code=None,
        fund_name='ハイブリッド・インカムオープン',
        fund_name_yomi='ハイブリッド\u3000インカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04023': FundCodeEntry(
        fund_code='G04023',
        sec_code=None,
        fund_name='三井住友・グローバル・リート・オープン（３カ月決算型）',
        fund_name_yomi='ミツイスミトモグローバルリートオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04043': FundCodeEntry(
        fund_code='G04043',
        sec_code=None,
        fund_name='日興グローバルＲＥＩＴファンド（６ヵ月決算型）',
        fund_name_yomi='ニッコウグローバルリートファンドロッカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04047': FundCodeEntry(
        fund_code='G04047',
        sec_code='89640',
        fund_name='フロンティア不動産投資法人',
        fund_name_yomi='フロンティアフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='6月30日',
        period_2='12月31日',
        edinet_code='E13869',
        issuer_name='フロンティア不動産投資法人',
    ),
    'G04050': FundCodeEntry(
        fund_code='G04050',
        sec_code=None,
        fund_name='グローバル・インカム・プラス（毎月分配型）',
        fund_name_yomi='グローバルインカムプラスマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G04051': FundCodeEntry(
        fund_code='G04051',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000Ｊリートオープン（３ヵ月決算型）',
        fund_name_yomi='ミツビシユーエフジェイジェイリートオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04065': FundCodeEntry(
        fund_code='G04065',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・オープン（毎月決算型）：Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ダイワユーエスリートオープンマイツキケッサンガタエーコースカワセヘッジアリビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04070': FundCodeEntry(
        fund_code='G04070',
        sec_code=None,
        fund_name='ノムラファンドマスターズ世界債券Ａコース、ノムラファンドマスターズ世界債券Ｂコース',
        fund_name_yomi='ノムラファンドマスターズセカイサイケンエーコース\u3000ノムラファンドマスターズセカイサイケンビーコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04076': FundCodeEntry(
        fund_code='G04076',
        sec_code=None,
        fund_name='ＤＣ・ダイワＳＲＩファンド',
        fund_name_yomi='ディーシーダイワエスアールアイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04077': FundCodeEntry(
        fund_code='G04077',
        sec_code=None,
        fund_name='野村世界ＥＳＧ株式インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラセカイイーエスジーカブシキインデックスファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04089': FundCodeEntry(
        fund_code='G04089',
        sec_code=None,
        fund_name='りそな・小型株ファンド',
        fund_name_yomi='リソナコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G04093': FundCodeEntry(
        fund_code='G04093',
        sec_code=None,
        fund_name='ノムラファンドマスターズ日本株',
        fund_name_yomi='ノムラファンドマスターズニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='2月28日',
        period_2='8月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04101': FundCodeEntry(
        fund_code='G04101',
        sec_code=None,
        fund_name='明治安田ＤＣ・ＴＯＰＩＸオープン',
        fund_name_yomi='メイジヤスダディーシートピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G04109': FundCodeEntry(
        fund_code='G04109',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００４－０９',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロヨンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04111': FundCodeEntry(
        fund_code='G04111',
        sec_code=None,
        fund_name='ありがとうファンド',
        fund_name_yomi='アリガトウファンド',
        security_type='内国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E13909',
        issuer_name='ありがとう投信株式会社',
    ),
    'G04118': FundCodeEntry(
        fund_code='G04118',
        sec_code=None,
        fund_name='ピムコ・グローバル・ハイイールド・ファンド（毎月分配型）',
        fund_name_yomi='ピムコグローバルハイイールドファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04123': FundCodeEntry(
        fund_code='G04123',
        sec_code=None,
        fund_name='ＤＣ・ダイワＪ－ＲＥＩＴオープン',
        fund_name_yomi='ディーシーダイワジェイリートオープン',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04124': FundCodeEntry(
        fund_code='G04124',
        sec_code=None,
        fund_name='ＪＰＭグローバルＣＢプラス',
        fund_name_yomi='ジェイピーエムグローバルシービープラス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04129': FundCodeEntry(
        fund_code='G04129',
        sec_code=None,
        fund_name='パインブリッジ米国優先証券ファンド（為替ヘッジなし）',
        fund_name_yomi='パインブリッジベイコクユウセンショウケンファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G04137': FundCodeEntry(
        fund_code='G04137',
        sec_code=None,
        fund_name='イーストスプリング・インド株式オープン',
        fund_name_yomi='イーストスプリングインドカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G04139': FundCodeEntry(
        fund_code='G04139',
        sec_code=None,
        fund_name='ＧＳハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ジーエスハイ\u3000イールド\u3000ボンド\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G04145': FundCodeEntry(
        fund_code='G04145',
        sec_code=None,
        fund_name='インデックスファンドＪリート（東証ＲＥＩＴ指数）毎月分配型',
        fund_name_yomi='インデックスファンドジェイリート\u3000トウショウリートシスウ\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04149': FundCodeEntry(
        fund_code='G04149',
        sec_code=None,
        fund_name='ピクテ・バイオ医薬品ファンド（毎月決算型）為替ヘッジなしコース',
        fund_name_yomi='ピクテバイオイヤクヒンファンドマイツキケッサンガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G04160': FundCodeEntry(
        fund_code='G04160',
        sec_code=None,
        fund_name='フィデリティ・チャイナ・フォーカス・オープン',
        fund_name_yomi='フィデリティチャイナフォーカスオープン',
        security_type='内国投資信託受益証券',
        period_1='10月31日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04171': FundCodeEntry(
        fund_code='G04171',
        sec_code=None,
        fund_name='オーストラリア・リート・オープン（毎月決算型）',
        fund_name_yomi='オーストラリアリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04175': FundCodeEntry(
        fund_code='G04175',
        sec_code=None,
        fund_name='高利回り社債オープン',
        fund_name_yomi='コウリマワリシャサイオープン',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04177': FundCodeEntry(
        fund_code='G04177',
        sec_code=None,
        fund_name='ウツミ屋\u3000日本株ファンド「あゆみ」',
        fund_name_yomi='ウツミヤニホンカブファンドアユミ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04180': FundCodeEntry(
        fund_code='G04180',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＳＲＩファンド',
        fund_name_yomi='ミツビシユーエフジェイエスアールアイファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04181': FundCodeEntry(
        fund_code='G04181',
        sec_code=None,
        fund_name='りそな・ＴＯＰＩＸオープン',
        fund_name_yomi='リソナトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G04183': FundCodeEntry(
        fund_code='G04183',
        sec_code=None,
        fund_name='グローバル・インカム＆プラス（毎月決算型）',
        fund_name_yomi='グローバルインカムアンドプラスマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04191': FundCodeEntry(
        fund_code='G04191',
        sec_code=None,
        fund_name='ＨＳＢＣインドオープン',
        fund_name_yomi='エイチエスビーシーインドオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G04194': FundCodeEntry(
        fund_code='G04194',
        sec_code=None,
        fund_name='ＤＣ日本債券インデックス・オープンＰ',
        fund_name_yomi='ディーシーニホンサイケンインデックスオープンピー',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04195': FundCodeEntry(
        fund_code='G04195',
        sec_code=None,
        fund_name='東京海上セレクション・物価連動国債',
        fund_name_yomi='トウキョウカイジョウセレクションブッカレンドウコクサイ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G04196': FundCodeEntry(
        fund_code='G04196',
        sec_code=None,
        fund_name='世界好配当株投信',
        fund_name_yomi='セカイコウハイトウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04197': FundCodeEntry(
        fund_code='G04197',
        sec_code=None,
        fund_name='年金インデックスファンド日本株式（ＴＯＰＩＸ連動型）',
        fund_name_yomi='ネンキンインデックスファンドニホンカブシキトピックスレンドウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04199': FundCodeEntry(
        fund_code='G04199',
        sec_code=None,
        fund_name='損保ジャパン欧州国債オープン（毎月分配型）',
        fund_name_yomi='ソンポジャパンオウシュウコクサイオープン\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月1日',
        period_2='12月1日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04214': FundCodeEntry(
        fund_code='G04214',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国株式インデックスファンドＳ',
        fund_name_yomi='ミツイスミトモディーシーガイコクカブシキインデックスファンドエス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04215': FundCodeEntry(
        fund_code='G04215',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国債券インデックスファンドＳ',
        fund_name_yomi='ミツイスミトモディーシーガイコクサイケンインデックスファンドエス',
        security_type='内国投資信託受益証券',
        period_1='12月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04216': FundCodeEntry(
        fund_code='G04216',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000バランスインカムオープン（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイバランスインカムオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04239': FundCodeEntry(
        fund_code='G04239',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000ＤＣ日経平均ファンド',
        fund_name_yomi='アラムコディーシーニッケイヘイキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G04242': FundCodeEntry(
        fund_code='G04242',
        sec_code=None,
        fund_name='ドイチェ・インド株式ファンド',
        fund_name_yomi='ドイチェ\u3000インドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G04245': FundCodeEntry(
        fund_code='G04245',
        sec_code=None,
        fund_name='日本Ｊリートオープン（毎月分配型）',
        fund_name_yomi='ニホンジェイリートオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04247': FundCodeEntry(
        fund_code='G04247',
        sec_code=None,
        fund_name='ＳＢＩ中小型成長株ファンド\u3000ジェイネクスト（愛称：ｊｎｅｘｔ）',
        fund_name_yomi='エスビーアイチュウコガタセイチョウカブファンド\u3000ジェイネクスト\u3000アイショウ\u3000ジェイネクスト',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G04260': FundCodeEntry(
        fund_code='G04260',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴ・リサーチ・オープン（毎月決算型）',
        fund_name_yomi='ジェイリートリサーチオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04265': FundCodeEntry(
        fund_code='G04265',
        sec_code=None,
        fund_name='しんきんＪリートオープン（毎月決算型）',
        fund_name_yomi='シンキンジェイリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G04268': FundCodeEntry(
        fund_code='G04268',
        sec_code=None,
        fund_name='グローバル・リート・セレクション',
        fund_name_yomi='グローバルリートセレクション',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04276': FundCodeEntry(
        fund_code='G04276',
        sec_code=None,
        fund_name='世界高配当株式ファンド（毎月分配型）',
        fund_name_yomi='セカイコウハイトウカブシキファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04281': FundCodeEntry(
        fund_code='G04281',
        sec_code=None,
        fund_name='中国Ａ株ファンド',
        fund_name_yomi='チュウゴクエーカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月21日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04282': FundCodeEntry(
        fund_code='G04282',
        sec_code=None,
        fund_name='高利回り社債オープン・為替ヘッジ',
        fund_name_yomi='コウリマワリシャサイオープン\u3000カワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04284': FundCodeEntry(
        fund_code='G04284',
        sec_code='89660',
        fund_name='平和不動産リート投資法人',
        fund_name_yomi='ヘイワフドウサンリートトウシホウジン',
        security_type='内国投資証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E14005',
        issuer_name='平和不動産リート投資法人',
    ),
    'G04287': FundCodeEntry(
        fund_code='G04287',
        sec_code=None,
        fund_name='ピムコ・エマージング・ボンド・オープン\u3000Ａコース（為替ヘッジなし）／Ｂコース（為替ヘッジあり）',
        fund_name_yomi='ピムコエマージングボンドオープンエーコースカワセヘッジナシビーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04293': FundCodeEntry(
        fund_code='G04293',
        sec_code=None,
        fund_name='フィデリティ・グローバル好配当株ファンド',
        fund_name_yomi='フィデリティグローバルコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04294': FundCodeEntry(
        fund_code='G04294',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（毎月分配型）',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G04303': FundCodeEntry(
        fund_code='G04303',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳトレジャリー・インカム・ファンド（毎月決算型）',
        fund_name_yomi='ジェイ\u3000ピー\u3000エム\u3000ユー\u3000エス\u3000トレジャリーインカムファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04312': FundCodeEntry(
        fund_code='G04312',
        sec_code=None,
        fund_name='りそなジャパンＣＳＲファンド',
        fund_name_yomi='リソナジャパンシーエスアールファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G04317': FundCodeEntry(
        fund_code='G04317',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴオープン（毎月決算型）、Ｊ－ＲＥＩＴオープン（年４回決算型）、Ｊ－ＲＥＩＴオープン（資産成長型）',
        fund_name_yomi='ジェイリートオープンマイツキケッサンガタ\u3000ジェイリートオープンネンヨンカイケッサンガタ\u3000ジェイリートオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04318': FundCodeEntry(
        fund_code='G04318',
        sec_code=None,
        fund_name='グローバルＲＥＩＴオープン',
        fund_name_yomi='グローバルリートオープン',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04322': FundCodeEntry(
        fund_code='G04322',
        sec_code=None,
        fund_name='損保ジャパン拡大中国株投信',
        fund_name_yomi='ソンポジャパンカクダイチュウゴクカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='10月31日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04323': FundCodeEntry(
        fund_code='G04323',
        sec_code=None,
        fund_name='損保ジャパンＳＲＩオープン',
        fund_name_yomi='ソンポジャパンエスアールアイオープン',
        security_type='内国投資信託受益証券',
        period_1='12月8日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04327': FundCodeEntry(
        fund_code='G04327',
        sec_code=None,
        fund_name='ドイチェ・グローバル好配当株式ファンド（毎月分配型）',
        fund_name_yomi='ドイチェグローバルコウハイトウカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G04337': FundCodeEntry(
        fund_code='G04337',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００５－０４',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロゴゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04340': FundCodeEntry(
        fund_code='G04340',
        sec_code=None,
        fund_name='アムンディ・東欧株ファンド',
        fund_name_yomi='アムンディトウオウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G04344': FundCodeEntry(
        fund_code='G04344',
        sec_code=None,
        fund_name='しんきん３資産ファンド（毎月決算型）',
        fund_name_yomi='シンキンサンシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G04345': FundCodeEntry(
        fund_code='G04345',
        sec_code=None,
        fund_name='日本好配当リバランスオープン',
        fund_name_yomi='ニホンコウハイトウリバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04346': FundCodeEntry(
        fund_code='G04346',
        sec_code=None,
        fund_name='日興キャッシュリッチ・ファンド',
        fund_name_yomi='ニッコウキャッシュリッチファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04352': FundCodeEntry(
        fund_code='G04352',
        sec_code='89670',
        fund_name='日本ロジスティクスファンド投資法人',
        fund_name_yomi='ニホンロジスティクスファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E14042',
        issuer_name='日本ロジスティクスファンド投資法人',
    ),
    'G04356': FundCodeEntry(
        fund_code='G04356',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（米国）為替ヘッジあり',
        fund_name_yomi='ワールドリートセレクションベイコクカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04357': FundCodeEntry(
        fund_code='G04357',
        sec_code=None,
        fund_name='日本好配当株投信',
        fund_name_yomi='ニホンコウハイトウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04365': FundCodeEntry(
        fund_code='G04365',
        sec_code=None,
        fund_name='野村Ｊ―ＲＥＩＴファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラジェイリートファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04395': FundCodeEntry(
        fund_code='G04395',
        sec_code=None,
        fund_name='Ｏｎｅ世界好配当株オープン（毎月決算コース）',
        fund_name_yomi='ワンセカイコウハイトウカブオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04397': FundCodeEntry(
        fund_code='G04397',
        sec_code=None,
        fund_name='三井住友・グローバル好配当株式オープン',
        fund_name_yomi='ミツイスミトモグローバルコウハイトウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04398': FundCodeEntry(
        fund_code='G04398',
        sec_code=None,
        fund_name='ＧＳ新成長国債券ファンド',
        fund_name_yomi='ジーエスシンセイチョウコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G04401': FundCodeEntry(
        fund_code='G04401',
        sec_code=None,
        fund_name='みずほ好配当日本株オープン',
        fund_name_yomi='ミズホコウハイトウニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04404': FundCodeEntry(
        fund_code='G04404',
        sec_code=None,
        fund_name='日本好配当利回り株オープン（３ヵ月決算型）',
        fund_name_yomi='ニホンコウハイトウリマワリカブオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04408': FundCodeEntry(
        fund_code='G04408',
        sec_code=None,
        fund_name='マイストーリー分配型（年６回）Ａコース、マイストーリー分配型（年６回）Ｂコース',
        fund_name_yomi='マイストーリーブンパイガタ\u3000ネンロッカイ\u3000エーコース\u3000マイストーリーブンパイガタ\u3000ネンロッカイ\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04413': FundCodeEntry(
        fund_code='G04413',
        sec_code='89680',
        fund_name='福岡リート投資法人',
        fund_name_yomi='フクオカリートトウシホウジン',
        security_type='内国投資証券',
        period_1='8月31日',
        period_2='2月末日',
        edinet_code='E14079',
        issuer_name='福岡リート投資法人',
    ),
    'G04416': FundCodeEntry(
        fund_code='G04416',
        sec_code=None,
        fund_name='世界ソブリン債券・日本株ファンド（毎月分配型）',
        fund_name_yomi='セカイソブリンサイケンニホンカブファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04417': FundCodeEntry(
        fund_code='G04417',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００５－０６',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロゴゼロロク',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04418': FundCodeEntry(
        fund_code='G04418',
        sec_code=None,
        fund_name='野村日経２２５インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラニッケイニニゴインデックスファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04420': FundCodeEntry(
        fund_code='G04420',
        sec_code=None,
        fund_name='野村世界好配当株投信（確定拠出年金向け）',
        fund_name_yomi='ノムラセカイコウハイトウカブトウシン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04430': FundCodeEntry(
        fund_code='G04430',
        sec_code=None,
        fund_name='中国Ａ株ファンド２',
        fund_name_yomi='チュウゴクエーカブファンドニ',
        security_type='内国投資信託受益証券',
        period_1='9月21日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04436': FundCodeEntry(
        fund_code='G04436',
        sec_code=None,
        fund_name='好配当日本株式\u3000オープン',
        fund_name_yomi='コウハイトウニホンカブシキ\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04442': FundCodeEntry(
        fund_code='G04442',
        sec_code=None,
        fund_name='ダイワ・グローバルＲＥＩＴ・オープン（毎月分配型）',
        fund_name_yomi='ダイワグローバルリートオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04443': FundCodeEntry(
        fund_code='G04443',
        sec_code=None,
        fund_name='ダイワ・ライフ・バランス３０',
        fund_name_yomi='ダイワライフバランスサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04444': FundCodeEntry(
        fund_code='G04444',
        sec_code=None,
        fund_name='ダイワ・ライフ・バランス５０',
        fund_name_yomi='ダイワライフバランスゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04445': FundCodeEntry(
        fund_code='G04445',
        sec_code=None,
        fund_name='ダイワ・ライフ・バランス７０',
        fund_name_yomi='ダイワライフバランスナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04453': FundCodeEntry(
        fund_code='G04453',
        sec_code=None,
        fund_name='野村インド株投資',
        fund_name_yomi='ノムラインドカブトウシ',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04454': FundCodeEntry(
        fund_code='G04454',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００５－０７',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロゴゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04464': FundCodeEntry(
        fund_code='G04464',
        sec_code=None,
        fund_name='三井住友・アジア・オセアニア好配当株式オープン',
        fund_name_yomi='ミツイスミトモアジアオセアニアコウハイトウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04467': FundCodeEntry(
        fund_code='G04467',
        sec_code='89720',
        fund_name='ＫＤＸ不動産投資法人',
        fund_name_yomi='ケイディーエックスフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E14109',
        issuer_name='ＫＤＸ不動産投資法人',
    ),
    'G04470': FundCodeEntry(
        fund_code='G04470',
        sec_code=None,
        fund_name='ダイワ日本好配当株ファンド',
        fund_name_yomi='ダイワニホンコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04481': FundCodeEntry(
        fund_code='G04481',
        sec_code=None,
        fund_name='たんぎん世界好配当株式ファンド（毎月分配型）',
        fund_name_yomi='タンギンセカイコウハイトウカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G04488': FundCodeEntry(
        fund_code='G04488',
        sec_code=None,
        fund_name='ダイワ好配当日本株投信（季節点描）',
        fund_name_yomi='ダイワコウハイトウニホンカブトウシンキセツテンビョウ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04493': FundCodeEntry(
        fund_code='G04493',
        sec_code=None,
        fund_name='ニュー配当利回り株オープン',
        fund_name_yomi='ニューハイトウリマワリカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04499': FundCodeEntry(
        fund_code='G04499',
        sec_code=None,
        fund_name='野村世界不動産投信',
        fund_name_yomi='ノムラセカイフドウサントウシン',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04504': FundCodeEntry(
        fund_code='G04504',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・新興国成長株投信Ａコース（為替ヘッジあり）／アライアンス・バーンスタイン・新興国成長株投信Ｂコース（為替ヘッジなし）',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000シンコウコクセイチョウカブトウシンエーコース\u3000カワセヘッジアリ\u3000アライアンス\u3000バーンスタイン\u3000シンコウコクセイチョウカブトウシンビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G04511': FundCodeEntry(
        fund_code='G04511',
        sec_code=None,
        fund_name='日本ＥＳＧオープン（愛称\u3000絆（きずな））',
        fund_name_yomi='ニホンイーエスジーオープンアイショウキズナ',
        security_type='内国投資信託受益証券',
        period_1='8月11日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04513': FundCodeEntry(
        fund_code='G04513',
        sec_code=None,
        fund_name='世界三資産バランスファンド',
        fund_name_yomi='セカイサンシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04516': FundCodeEntry(
        fund_code='G04516',
        sec_code='89840',
        fund_name='大和ハウスリート投資法人',
        fund_name_yomi='ダイワハウスリートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月28日',
        period_2='8月31日',
        edinet_code='E14140',
        issuer_name='大和ハウスリート投資法人',
    ),
    'G04518': FundCodeEntry(
        fund_code='G04518',
        sec_code=None,
        fund_name='ソフトバンク＆ＳＢＩグループ株式ファンド',
        fund_name_yomi='ソフトバンクアンドエスビーアイグループカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月27日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G04521': FundCodeEntry(
        fund_code='G04521',
        sec_code=None,
        fund_name='ラッセル・インベストメント外国株式ファンド（ＤＣ向け）',
        fund_name_yomi='ラッセルインベストメントガイコクカブシキファンド\u3000ディーシームケ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G04536': FundCodeEntry(
        fund_code='G04536',
        sec_code='89750',
        fund_name='いちごオフィスリート投資法人',
        fund_name_yomi='イチゴオフィスリートトウシホウジン',
        security_type='内国投資証券',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E14150',
        issuer_name='いちごオフィスリート投資法人',
    ),
    'G04538': FundCodeEntry(
        fund_code='G04538',
        sec_code=None,
        fund_name='三重県応援ファンド',
        fund_name_yomi='ミエケンオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04555': FundCodeEntry(
        fund_code='G04555',
        sec_code=None,
        fund_name='ＤＩＡＭ世界インカム・オープン（毎月決算コース）',
        fund_name_yomi='ダイアムセカイインカムオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04557': FundCodeEntry(
        fund_code='G04557',
        sec_code=None,
        fund_name='ＤＣダイワ・グローバルＲＥＩＴインデックスファンド',
        fund_name_yomi='ディーシーダイワグローバルリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04558': FundCodeEntry(
        fund_code='G04558',
        sec_code=None,
        fund_name='ＤＣダイワ中小型株ファンド',
        fund_name_yomi='ディーシーダイワチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04559': FundCodeEntry(
        fund_code='G04559',
        sec_code=None,
        fund_name='ＤＣダイワ物価連動国債ファンド',
        fund_name_yomi='ディーシーダイワブッカレンドウコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04560': FundCodeEntry(
        fund_code='G04560',
        sec_code=None,
        fund_name='ダイワ外債ソブリン・オープン（毎月分配型）',
        fund_name_yomi='ダイワガイサイソブリンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04563': FundCodeEntry(
        fund_code='G04563',
        sec_code=None,
        fund_name='グローバル３資産ファンド',
        fund_name_yomi='グローバルサンシサンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04572': FundCodeEntry(
        fund_code='G04572',
        sec_code=None,
        fund_name='株ちょファンド日本（高配当株・割安株・成長株）毎月分配型',
        fund_name_yomi='カブチョファンドニッポンコウハイトウカブワリヤスカブセイチョウカブマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04575': FundCodeEntry(
        fund_code='G04575',
        sec_code=None,
        fund_name='フィデリティ・日本配当成長株・ファンド（分配重視型）',
        fund_name_yomi='フィデリティニホンハイトウセイチョウカブファンド\u3000ブンパイジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04576': FundCodeEntry(
        fund_code='G04576',
        sec_code=None,
        fund_name='パインブリッジ新成長国債券プラス',
        fund_name_yomi='パインブリッジシンセイチョウコクサイケンプラス',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G04578': FundCodeEntry(
        fund_code='G04578',
        sec_code=None,
        fund_name='ＨＳＢＣＢＩＣｓオープン',
        fund_name_yomi='エイチエスビーシービックスオープン',
        security_type='内国投資信託受益証券',
        period_1='9月29日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G04580': FundCodeEntry(
        fund_code='G04580',
        sec_code=None,
        fund_name='損保ジャパン外国債券ファンド（為替ヘッジなし）',
        fund_name_yomi='ソンポジャパンガイコクサイケンファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04581': FundCodeEntry(
        fund_code='G04581',
        sec_code=None,
        fund_name='ＪＰＭ新興国ソブリン・オープン',
        fund_name_yomi='ジェイピーエムシンコウコクソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04582': FundCodeEntry(
        fund_code='G04582',
        sec_code=None,
        fund_name='フィデリティ・グローバル・エクイティ（野村ＳＭＡ向け）Ａコース（限定為替ヘッジ）\u3000フィデリティ・グローバル・エクイティ（野村ＳＭＡ向け）Ｂコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティグローバルエクイティノムラエスエムエイムケエイコースゲンテイカワセヘッジ\u3000フィデリティグローバルエクイティノムラエスエムエイムケビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04589': FundCodeEntry(
        fund_code='G04589',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００５－１０',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロゴイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04593': FundCodeEntry(
        fund_code='G04593',
        sec_code=None,
        fund_name='世界の財産３分法ファンド（不動産・債券・株式）毎月分配型',
        fund_name_yomi='セカイノザイサンサンブンポウファンドフドウサンサイケンカブシキマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04597': FundCodeEntry(
        fund_code='G04597',
        sec_code=None,
        fund_name='三井住友・ＤＣ年金バランス３０（債券重点型）、三井住友・ＤＣ年金バランス５０（標準型）、三井住友・ＤＣ年金バランス７０（株式重点型）',
        fund_name_yomi='ミツイスミトモディーシーネンキンバランスサンジュウサイケンジュウテンガタ\u3000ミツイスミトモディーシーネンキンバランスゴジュウヒョウジュンガタ\u3000ミツイスミトモディーシーネンキンバランスナナジュウカブシキジュウテンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04598': FundCodeEntry(
        fund_code='G04598',
        sec_code=None,
        fund_name='ゴールドマン・サックス・世界債券オープンＡ限定為替ヘッジ（野村ＳＭＡ向け）Ｂ為替ヘッジなし（野村ＳＭＡ向け）',
        fund_name_yomi='ゴールドマン\u3000サックス\u3000セカイサイケンオープンエーゲンテイカワセヘッジ\u3000ノムラエスエムエームケ\u3000ビーカワセヘッジナシ\u3000ノムラエスエムエームエームケ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G04600': FundCodeEntry(
        fund_code='G04600',
        sec_code=None,
        fund_name='ＧＳ日本株式インデックス・プラス',
        fund_name_yomi='ジーエスニホンカブシキインデックス\u3000プラス',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G04601': FundCodeEntry(
        fund_code='G04601',
        sec_code='89760',
        fund_name='大和証券オフィス投資法人',
        fund_name_yomi='ダイワショウケンオフィストウシホウジン',
        security_type='内国投資証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E14197',
        issuer_name='大和証券オフィス投資法人',
    ),
    'G04603': FundCodeEntry(
        fund_code='G04603',
        sec_code=None,
        fund_name='世界好配当株投信（野村ＳＭＡ向け）',
        fund_name_yomi='セカイコウハイトウカブトウシン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04604': FundCodeEntry(
        fund_code='G04604',
        sec_code=None,
        fund_name='ノムラ日本債券オープン（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラニホンサイケンオープン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='8月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04605': FundCodeEntry(
        fund_code='G04605',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴファンドＡコース（野村ＳＭＡ向け）、野村世界ＲＥＩＴファンドＢコース（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラセカイリートファンドエーコース\u3000ノムラエスエムエームケ\u3000ノムラセカイリートファンドビーコース\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04606': FundCodeEntry(
        fund_code='G04606',
        sec_code=None,
        fund_name='ノムラ日本株戦略ファンド（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラニホンカブセンリャクファンド\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04607': FundCodeEntry(
        fund_code='G04607',
        sec_code=None,
        fund_name='ハイ・イールド\u3000ボンド\u3000オープンＡコース（野村ＳＭＡ向け）、ハイ・イールド\u3000ボンド\u3000オープンＢコース（野村ＳＭＡ向け）',
        fund_name_yomi='ハイイールド\u3000ボンド\u3000オープンエーコース\u3000ノムラエスエムエームケ\u3000ハイイールド\u3000ボンド\u3000オープンビーコース\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='9月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04609': FundCodeEntry(
        fund_code='G04609',
        sec_code=None,
        fund_name='大和\u3000ストック\u3000インデックス\u3000２２５\u3000ファンド',
        fund_name_yomi='ダイワストックインデックスニーニーゴファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04614': FundCodeEntry(
        fund_code='G04614',
        sec_code='89770',
        fund_name='阪急阪神リート投資法人',
        fund_name_yomi='ハンキュウハンシンリートトウシホウジン',
        security_type='内国投資証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E14207',
        issuer_name='阪急阪神リート投資法人',
    ),
    'G04618': FundCodeEntry(
        fund_code='G04618',
        sec_code=None,
        fund_name='野村世界６資産分散投信（安定コース）、野村世界６資産分散投信（分配コース）、野村世界６資産分散投信（成長コース）、野村世界６資産分散投信（配分変更コース）',
        fund_name_yomi='ノムラセカイロクシサンブンサントウシンアンテイコース\u3000ノムラセカイロクシサンブンサントウシンブンパイコース\u3000ノムラセカイロクシサンブンサントウシンセイチョウコース\u3000ノムラセカイロクシサンブンサントウシンハイブンヘンコウコース',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04621': FundCodeEntry(
        fund_code='G04621',
        sec_code=None,
        fund_name='三井住友・フォーカス・ジャパン・オープン',
        fund_name_yomi='ミツイスミトモフォーカスジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04623': FundCodeEntry(
        fund_code='G04623',
        sec_code=None,
        fund_name='毎月分配パッケージファンド',
        fund_name_yomi='マイツキブンパイパッケージファンド',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04624': FundCodeEntry(
        fund_code='G04624',
        sec_code=None,
        fund_name='ダイワ・バランス３資産（外債・海外リート・好配当日本株）',
        fund_name_yomi='ダイワバランスサンシサンガイサイカイガイリートコウハイトウニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04628': FundCodeEntry(
        fund_code='G04628',
        sec_code=None,
        fund_name='京都・滋賀インデックス\u3000ファンド',
        fund_name_yomi='キョウトシガインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04631': FundCodeEntry(
        fund_code='G04631',
        sec_code=None,
        fund_name='アジア・オセアニア好配当成長株オープン（毎月分配型）',
        fund_name_yomi='アジアオセアニアコウハイトウセイチョウカブオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04641': FundCodeEntry(
        fund_code='G04641',
        sec_code='89790',
        fund_name='スターツプロシード投資法人',
        fund_name_yomi='スターツプロシードトウシホウジン',
        security_type='内国投資証券',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E14223',
        issuer_name='スターツプロシード投資法人',
    ),
    'G04644': FundCodeEntry(
        fund_code='G04644',
        sec_code=None,
        fund_name='りそな・世界資産分散ファンド',
        fund_name_yomi='リソナセカイシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04645': FundCodeEntry(
        fund_code='G04645',
        sec_code=None,
        fund_name='ニッセイ／パトナム・バランスアップオープン',
        fund_name_yomi='ニッセイパトナムバランスアップオープン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G04646': FundCodeEntry(
        fund_code='G04646',
        sec_code=None,
        fund_name='グローバル高配当株式ファンド（奇数月分配型）',
        fund_name_yomi='グローバルコウハイトウカブシキファンド\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04647': FundCodeEntry(
        fund_code='G04647',
        sec_code=None,
        fund_name='日興グローバル・ボンド＆カレンシー・ロング・ショート\u3000２００５－１１',
        fund_name_yomi='ニッコウグローバルボンドアンドカレンシーロングショートニゼロゼロゴジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04654': FundCodeEntry(
        fund_code='G04654',
        sec_code=None,
        fund_name='ＵＢＳニュー・メジャー・バランス・ファンド（毎月分配型）',
        fund_name_yomi='ユービーエス\u3000ニューメジャーバランスファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G04657': FundCodeEntry(
        fund_code='G04657',
        sec_code=None,
        fund_name='日興中小型グロース・ファンド',
        fund_name_yomi='ニッコウチュウコガタグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04661': FundCodeEntry(
        fund_code='G04661',
        sec_code=None,
        fund_name='アムンディ・世界好配当株式ファンド（毎月分配型）',
        fund_name_yomi='アムンディセカイコウハイトウカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2='2月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G04663': FundCodeEntry(
        fund_code='G04663',
        sec_code=None,
        fund_name='しんきん世界好配当利回り株ファンド（毎月決算型）',
        fund_name_yomi='シンキンセカイコウハイトウリマワリカブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2='5月10日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G04671': FundCodeEntry(
        fund_code='G04671',
        sec_code=None,
        fund_name='ＤＩＡＭ高格付インカム・オープン＜ＤＣ年金＞',
        fund_name_yomi='ダイアムコウカクヅケインカムオープンディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04676': FundCodeEntry(
        fund_code='G04676',
        sec_code=None,
        fund_name='フィデリティ・ワールド好配当株・ファンド',
        fund_name_yomi='フィデリティワールドコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04679': FundCodeEntry(
        fund_code='G04679',
        sec_code=None,
        fund_name='福井県応援ファンド',
        fund_name_yomi='フクイケンオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04683': FundCodeEntry(
        fund_code='G04683',
        sec_code=None,
        fund_name='ＳＢＩ小型成長株ファンド\u3000ジェイクール（愛称：ｊｃｏｏｌ）',
        fund_name_yomi='エスビーアイコガタセイチョウカブファンド\u3000ジェイクール\u3000アイショウ\u3000ジェイクール',
        security_type='内国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G04684': FundCodeEntry(
        fund_code='G04684',
        sec_code=None,
        fund_name='日本バリュースターオープン（愛称\u3000経営進化論）',
        fund_name_yomi='ニホンバリュースターオープンアイショウケイエイシンカロン',
        security_type='内国投資信託受益証券',
        period_1='11月27日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04687': FundCodeEntry(
        fund_code='G04687',
        sec_code=None,
        fund_name='ダイワ・マルチアセット・ファンド・シリーズ（奇数月分配型）：安定重視ポートフォリオ、インカム重視ポートフォリオ、成長重視ポートフォリオ',
        fund_name_yomi='ダイワマルチアセットファンドシリーズキスウヅキブンパイガタアンテイジュウシポートフォリオインカムジュウシポートフォリオセイチョウジュウシポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04695': FundCodeEntry(
        fund_code='G04695',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000３資産分散ファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイサンシサンブンサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04702': FundCodeEntry(
        fund_code='G04702',
        sec_code=None,
        fund_name='Ｏｎｅパッシブ資産分散ファンド',
        fund_name_yomi='ワンパッシブシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月6日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04714': FundCodeEntry(
        fund_code='G04714',
        sec_code=None,
        fund_name='世界資源株ファンド',
        fund_name_yomi='セカイシゲンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2='10月19日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04715': FundCodeEntry(
        fund_code='G04715',
        sec_code=None,
        fund_name='パインブリッジ新成長国債インカムオープン',
        fund_name_yomi='パインブリッジシンセイチョウコクサイインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G04728': FundCodeEntry(
        fund_code='G04728',
        sec_code=None,
        fund_name='ＪＰＭ・ＢＲＩＣＳ５・ファンド',
        fund_name_yomi='ジェイピーエムブリックスファイブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04733': FundCodeEntry(
        fund_code='G04733',
        sec_code=None,
        fund_name='野村小型株オープン',
        fund_name_yomi='ノムラコガタカブオープン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04735': FundCodeEntry(
        fund_code='G04735',
        sec_code='89850',
        fund_name='ジャパン・ホテル・リート投資法人',
        fund_name_yomi='ジャパンホテルリートトウシホウジン',
        security_type='内国投資証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E14273',
        issuer_name='ジャパン・ホテル・リート投資法人',
    ),
    'G04745': FundCodeEntry(
        fund_code='G04745',
        sec_code=None,
        fund_name='ＪＰＭインド株アクティブ・オープン',
        fund_name_yomi='ジェイピーエム\u3000インドカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04747': FundCodeEntry(
        fund_code='G04747',
        sec_code=None,
        fund_name='日本株プライムニュートラル・ファンド（ラップ向け）',
        fund_name_yomi='ニホンカブプライムニュートラルファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04764': FundCodeEntry(
        fund_code='G04764',
        sec_code=None,
        fund_name='ＤＣダイワ・ワールドアセット（六つの羽／安定コース）、（六つの羽／６分散コース）、（六つの羽／成長コース）',
        fund_name_yomi='ディーシーダイワワールドアセットムッツノハネアンテイコースムッツノハネロクブンサンコースムッツノハネセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04765': FundCodeEntry(
        fund_code='G04765',
        sec_code=None,
        fund_name='シュローダーＢＩＣｓ株式ファンド',
        fund_name_yomi='シュローダービックスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G04766': FundCodeEntry(
        fund_code='G04766',
        sec_code=None,
        fund_name='アジア・オセアニア配当利回り株オープン',
        fund_name_yomi='アジアオセアニアハイトウリマワリカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04773': FundCodeEntry(
        fund_code='G04773',
        sec_code=None,
        fund_name='京都応援バランスファンド（隔月分配型）',
        fund_name_yomi='キョウトオウエンバランスファンドカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04780': FundCodeEntry(
        fund_code='G04780',
        sec_code=None,
        fund_name='ノムラファンドマスターズ新興国株\u3000Ａコース、ノムラファンドマスターズ新興国株\u3000Ｂコース',
        fund_name_yomi='ノムラファンドマスターズシンコウコクカブ\u3000エーコース\u3000ノムラファンドマスターズシンコウコクカブ\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04783': FundCodeEntry(
        fund_code='G04783',
        sec_code=None,
        fund_name='インベスコ\u3000女性力フォーカス日本株式ファンド',
        fund_name_yomi='インベスコ\u3000ジョセイリョクフォーカスニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G04791': FundCodeEntry(
        fund_code='G04791',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000好配当日本株ファンド（２ヵ月決算型）',
        fund_name_yomi='ミツビシユーエフジェイコウハイトウニホンカブファンドニカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04793': FundCodeEntry(
        fund_code='G04793',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ロシア・欧州新興国株投信',
        fund_name_yomi='ディーダブリューエスロシアオウシュウシンコウコクカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G04801': FundCodeEntry(
        fund_code='G04801',
        sec_code=None,
        fund_name='フィデリティ・世界３資産・ファンド（毎月決算型）',
        fund_name_yomi='フィデリティセイカイサンシサンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04802': FundCodeEntry(
        fund_code='G04802',
        sec_code=None,
        fund_name='好配当ジャパン・オープン',
        fund_name_yomi='コウハイトウジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04803': FundCodeEntry(
        fund_code='G04803',
        sec_code=None,
        fund_name='明治安田ＤＣ日本株式アクティブ・ポートフォリオ',
        fund_name_yomi='メイジヤスダディーシーニホンカブシキアクティブポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G04806': FundCodeEntry(
        fund_code='G04806',
        sec_code=None,
        fund_name='ニッセイ／パトナム・グローバル好配当株式オープン',
        fund_name_yomi='ニッセイパトナムグローバルコウハイトウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G04815': FundCodeEntry(
        fund_code='G04815',
        sec_code=None,
        fund_name='フィデリティ・世界分散・ファンド（債券重視型）\u3000フィデリティ・世界分散・ファンド（株式重視型）',
        fund_name_yomi='フィデリティセカイブンサンファンドサイケンジュウシガタ\u3000フィデリティセカイブンサンファンドカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04818': FundCodeEntry(
        fund_code='G04818',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000６資産バランスファンド（２ヵ月分配型）',
        fund_name_yomi='ミツビシユーエフジェイロクシサンバランスファンドニカゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04819': FundCodeEntry(
        fund_code='G04819',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000６資産バランスファンド（成長型）',
        fund_name_yomi='ミツビシユーエフジェイロクシサンバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04821': FundCodeEntry(
        fund_code='G04821',
        sec_code=None,
        fund_name='日興ＢＲＩＣｓ株式ファンド',
        fund_name_yomi='ニッコウブリックスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04824': FundCodeEntry(
        fund_code='G04824',
        sec_code=None,
        fund_name='フィデリティ・海外株式・ファンド（ＤＣ年金）',
        fund_name_yomi='フィデリティカイガイカブシキファンド\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04832': FundCodeEntry(
        fund_code='G04832',
        sec_code=None,
        fund_name='イーストスプリング・アジア・オセアニア好配当株式オープン（毎月分配型）',
        fund_name_yomi='イーストスプリングアジアオセアニアコウハイトウカブシキオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G04844': FundCodeEntry(
        fund_code='G04844',
        sec_code=None,
        fund_name='ＤＣワールド・ソブリンインカム',
        fund_name_yomi='ディーシーワールドソブリンインカム',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04845': FundCodeEntry(
        fund_code='G04845',
        sec_code=None,
        fund_name='ＤＣグローバル・リート・セレクション',
        fund_name_yomi='ディーシーグローバルリートセレクション',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04847': FundCodeEntry(
        fund_code='G04847',
        sec_code=None,
        fund_name='しんきん好配当利回り株ファンド（３ヵ月決算型）',
        fund_name_yomi='シンキンコウハイトウリマワリカブファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G04848': FundCodeEntry(
        fund_code='G04848',
        sec_code=None,
        fund_name='ＨＳＢＣブラジルオープン',
        fund_name_yomi='エイチエスビーシーブラジルオープン',
        security_type='内国投資信託受益証券',
        period_1='3月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G04857': FundCodeEntry(
        fund_code='G04857',
        sec_code=None,
        fund_name='ダイワ海外ソブリン・ファンド（毎月分配型）',
        fund_name_yomi='ダイワカイガイソブリンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04858': FundCodeEntry(
        fund_code='G04858',
        sec_code=None,
        fund_name='６資産バランスファンド：６資産バランスファンド（分配型）、６資産バランスファンド（成長型）',
        fund_name_yomi='ロクシサンバランスファンドロクシサンバランスファンドブンパイガタロクシサンバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04864': FundCodeEntry(
        fund_code='G04864',
        sec_code=None,
        fund_name='三井住友・グローバル・リート・オープン（１年決算型）',
        fund_name_yomi='ミツイスミトモグローバルリートオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04867': FundCodeEntry(
        fund_code='G04867',
        sec_code=None,
        fund_name='シュローダー日本ファンド（野村ＳＭＡ向け）',
        fund_name_yomi='シュローダーニホンファンドノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G04870': FundCodeEntry(
        fund_code='G04870',
        sec_code=None,
        fund_name='フィデリティ・ジャパン・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='フィデリティジャパンオープン\u3000ノムラエスエムエイムケ',
        security_type='内国投資信託受益証券',
        period_1='9月21日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04871': FundCodeEntry(
        fund_code='G04871',
        sec_code=None,
        fund_name='フィデリティ・中小型株・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='フィデリティチュウコガタカブオープン\u3000ノムラエスエムエイムケ',
        security_type='内国投資信託受益証券',
        period_1='9月13日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04872': FundCodeEntry(
        fund_code='G04872',
        sec_code=None,
        fund_name='ラッセル・インベストメント・グローバル・バランス\u3000安定型／安定成長型／成長型',
        fund_name_yomi='ラッセルインベストメント\u3000グローバルバランス\u3000アンテイガタ\u3000アンテイセイチョウガタ\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月18日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G04879': FundCodeEntry(
        fund_code='G04879',
        sec_code=None,
        fund_name='ＪＰＭ中小型株オープン（野村ＳＭＡ向け）',
        fund_name_yomi='ジェイピーエムチュウコガタカブオープン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G04883': FundCodeEntry(
        fund_code='G04883',
        sec_code=None,
        fund_name='三井住友・インド・中国株オープン',
        fund_name_yomi='ミツイスミトモインドチュウゴクカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04884': FundCodeEntry(
        fund_code='G04884',
        sec_code=None,
        fund_name='ノムラ・ジャパン・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラジャパンオープン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04885': FundCodeEntry(
        fund_code='G04885',
        sec_code=None,
        fund_name='ノムラ・ジャパン・バリュー・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラ\u3000ジャパン\u3000バリュー\u3000オープン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04886': FundCodeEntry(
        fund_code='G04886',
        sec_code=None,
        fund_name='リサーチ・アクティブ・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='リサーチアクティブオープン\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='10月30日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G04888': FundCodeEntry(
        fund_code='G04888',
        sec_code=None,
        fund_name='りそな東欧フロンティア株式ファンド',
        fund_name_yomi='リソナトウオウフロンティアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G04889': FundCodeEntry(
        fund_code='G04889',
        sec_code=None,
        fund_name='ドイチェ・ロシア東欧株式ファンド',
        fund_name_yomi='ドイチェ\u3000ロシアトウオウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G04891': FundCodeEntry(
        fund_code='G04891',
        sec_code=None,
        fund_name='ＧＳ日本株・プラス（通貨分散コース）',
        fund_name_yomi='ジーエスニホンカブプラス\u3000ツウカブンサンコース',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G04893': FundCodeEntry(
        fund_code='G04893',
        sec_code=None,
        fund_name='香川県応援ファンド',
        fund_name_yomi='カガワケンオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G04912': FundCodeEntry(
        fund_code='G04912',
        sec_code=None,
        fund_name='フィデリティ・ヨーロッパ株式・ファンド',
        fund_name_yomi='フィデリティヨーロッパカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04914': FundCodeEntry(
        fund_code='G04914',
        sec_code=None,
        fund_name='尾瀬紀行',
        fund_name_yomi='オゼキコウ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04917': FundCodeEntry(
        fund_code='G04917',
        sec_code=None,
        fund_name='財産四分法ファンド（毎月決算型）',
        fund_name_yomi='ザイサンヨンブンポウファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04918': FundCodeEntry(
        fund_code='G04918',
        sec_code=None,
        fund_name='エマージング株式オープン',
        fund_name_yomi='エマージングカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='5月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04921': FundCodeEntry(
        fund_code='G04921',
        sec_code=None,
        fund_name='トルコ株式オープン',
        fund_name_yomi='トルコカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G04924': FundCodeEntry(
        fund_code='G04924',
        sec_code='89860',
        fund_name='大和証券リビング投資法人',
        fund_name_yomi='ダイワショウケンリビングトウシホウジン',
        security_type='内国投資証券',
        period_1='3月末日',
        period_2='9月末日',
        edinet_code='E14380',
        issuer_name='大和証券リビング投資法人',
    ),
    'G04925': FundCodeEntry(
        fund_code='G04925',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・米国成長株投信Ａコース（為替ヘッジあり）／アライアンス・バーンスタイン・米国成長株投信Ｂコース（為替ヘッジなし）',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000ベイコクセイチョウカブトウシンエーコース\u3000カワセヘッジアリ\u3000アライアンス\u3000バーンスタイン\u3000ベイコクセイチョウカブトウシンビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G04933': FundCodeEntry(
        fund_code='G04933',
        sec_code=None,
        fund_name='ＨＳＢＣ中国株式ファンド（３ヶ月決算型）',
        fund_name_yomi='エイチエスビーシーチュウゴクカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G04934': FundCodeEntry(
        fund_code='G04934',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ海外株式インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーカイガイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04935': FundCodeEntry(
        fund_code='G04935',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ海外債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーカイガイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G04941': FundCodeEntry(
        fund_code='G04941',
        sec_code=None,
        fund_name='ダイワ金融新時代ファンド',
        fund_name_yomi='ダイワキンユウシンジダイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04944': FundCodeEntry(
        fund_code='G04944',
        sec_code=None,
        fund_name='エマージング・カレンシー・債券ファンド（毎月分配型）',
        fund_name_yomi='エマージング\u3000カレンシー\u3000サイケンファンド\u3000\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G04945': FundCodeEntry(
        fund_code='G04945',
        sec_code=None,
        fund_name='しんきんグローバル６資産ファンド（毎月決算型）',
        fund_name_yomi='シンキングローバルロクシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G04949': FundCodeEntry(
        fund_code='G04949',
        sec_code=None,
        fund_name='ニッセイ日本勝ち組ファンド（３ヵ月決算型）',
        fund_name_yomi='ニッセイニホンカチグミファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G04954': FundCodeEntry(
        fund_code='G04954',
        sec_code=None,
        fund_name='世界高金利債券ファンド',
        fund_name_yomi='セカイコウキンリサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G04956': FundCodeEntry(
        fund_code='G04956',
        sec_code='89870',
        fund_name='ジャパンエクセレント投資法人',
        fund_name_yomi='ジャパンエクセレントトウシホウジン',
        security_type='内国投資証券',
        period_1='6月30日',
        period_2='12月31日',
        edinet_code='E14394',
        issuer_name='ジャパンエクセレント投資法人',
    ),
    'G04958': FundCodeEntry(
        fund_code='G04958',
        sec_code=None,
        fund_name='五大陸株式ファンド',
        fund_name_yomi='ゴタイリクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04959': FundCodeEntry(
        fund_code='G04959',
        sec_code=None,
        fund_name='五大陸債券ファンド（毎月分配型）',
        fund_name_yomi='ゴタイリクサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G04966': FundCodeEntry(
        fund_code='G04966',
        sec_code=None,
        fund_name='Ｏｎｅ世界リートインデックスファンド（毎月分配型）',
        fund_name_yomi='ワンセカイリートインデックスファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G04968': FundCodeEntry(
        fund_code='G04968',
        sec_code=None,
        fund_name='ニッセイＪ－ＲＥＩＴファンド（毎月決算型）',
        fund_name_yomi='ニッセイジェイリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G04969': FundCodeEntry(
        fund_code='G04969',
        sec_code=None,
        fund_name='ピクテ・プレミアム・ブランド・ファンド（３ヵ月決算型）',
        fund_name_yomi='ピクテプレミアムブランドファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G04971': FundCodeEntry(
        fund_code='G04971',
        sec_code=None,
        fund_name='ダイワ日本国債ファンド（毎月分配型）',
        fund_name_yomi='ダイワニホンコクサイファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04972': FundCodeEntry(
        fund_code='G04972',
        sec_code=None,
        fund_name='世界６資産均等分散ファンド（毎月分配型）',
        fund_name_yomi='セカイロクシサンキントウブンサンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04973': FundCodeEntry(
        fund_code='G04973',
        sec_code=None,
        fund_name='日本株式ＳＲＩファンド',
        fund_name_yomi='ニホンカブシキエスアールアイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G04974': FundCodeEntry(
        fund_code='G04974',
        sec_code=None,
        fund_name='りそな\u3000ハイグレード・ソブリン・ファンド（毎月決算型）',
        fund_name_yomi='リソナハイグレードソブリンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04975': FundCodeEntry(
        fund_code='G04975',
        sec_code=None,
        fund_name='りそな\u3000ワールド・リート・ファンド',
        fund_name_yomi='リソナワールドリートファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04976': FundCodeEntry(
        fund_code='G04976',
        sec_code='32260',
        fund_name='三井不動産アコモデーションファンド投資法人',
        fund_name_yomi='ミツイフドウサンアコモデーションファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='2月28日',
        period_2='8月31日',
        edinet_code='E14404',
        issuer_name='三井不動産アコモデーションファンド投資法人',
    ),
    'G04978': FundCodeEntry(
        fund_code='G04978',
        sec_code=None,
        fund_name='フィデリティ・日本・アジア成長株投信',
        fund_name_yomi='フィデリティニホンアジアセイチョウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G04984': FundCodeEntry(
        fund_code='G04984',
        sec_code=None,
        fund_name='ＨＳＢＣ新ＢＩＣｓファンド',
        fund_name_yomi='エイチエスビーシーシンビックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G04986': FundCodeEntry(
        fund_code='G04986',
        sec_code=None,
        fund_name='ニッセイ高金利国債券ファンド',
        fund_name_yomi='ニッセイコウキンリコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G04994': FundCodeEntry(
        fund_code='G04994',
        sec_code=None,
        fund_name='ダイワ外債ソブリン・ファンド（毎月分配型）',
        fund_name_yomi='ダイワガイサイソブリンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04995': FundCodeEntry(
        fund_code='G04995',
        sec_code=None,
        fund_name='ダイワ新興企業株ファンド',
        fund_name_yomi='ダイワシンコウキギョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G04998': FundCodeEntry(
        fund_code='G04998',
        sec_code=None,
        fund_name='ＭＣＵＢＳ\u3000ＭｉｄＣｉｔｙ投資法人',
        fund_name_yomi='エムシーユービーエス\u3000ミッドシティトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E13410',
        issuer_name='日本都市ファンド投資法人',
    ),
    'G05004': FundCodeEntry(
        fund_code='G05004',
        sec_code=None,
        fund_name='ＳＢＩ中小型割安成長株ファンド\u3000ジェイリバイブ\u3000（愛称：ｊｒｅｖｉｖｅ）',
        fund_name_yomi='エスビーアイチュウコガタワリヤスセイチョウカブファンド\u3000ジェイリバイブ\u3000アイショウ\u3000ジェイリバイブ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05007': FundCodeEntry(
        fund_code='G05007',
        sec_code=None,
        fund_name='三井住友・グローバル・リート・プラス',
        fund_name_yomi='ミツイスミトモグローバルリートプラス',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05009': FundCodeEntry(
        fund_code='G05009',
        sec_code=None,
        fund_name='グローバル不動産投信（隔月決算型）',
        fund_name_yomi='グローバルフドウサントウシンカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05011': FundCodeEntry(
        fund_code='G05011',
        sec_code=None,
        fund_name='日本製鉄グループ株式オープン',
        fund_name_yomi='ニッポンセイテツグループカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05012': FundCodeEntry(
        fund_code='G05012',
        sec_code=None,
        fund_name='ノムラ・オールインワン・ファンド',
        fund_name_yomi='ノムラ\u3000オールインワン\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05013': FundCodeEntry(
        fund_code='G05013',
        sec_code=None,
        fund_name='ＤＣニッセイ日本勝ち組ファンド',
        fund_name_yomi='ディーシーニッセイニホンカチグミファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G05019': FundCodeEntry(
        fund_code='G05019',
        sec_code=None,
        fund_name='ＬＭ・米国・ラージ・キャップ・グロース・ファンド',
        fund_name_yomi='エルエム\u3000ベイコク\u3000ラージ\u3000キャップ\u3000グロース\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G05024': FundCodeEntry(
        fund_code='G05024',
        sec_code=None,
        fund_name='みずほ日本株アクティブ・オープン',
        fund_name_yomi='ミズホニホンカブアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05025': FundCodeEntry(
        fund_code='G05025',
        sec_code=None,
        fund_name='野村グローバル・ファンズ・プレミアム（３ヵ月決算型）',
        fund_name_yomi='ノムラグローバルファンズプレミアム\u3000サンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05027': FundCodeEntry(
        fund_code='G05027',
        sec_code=None,
        fund_name='グローバル・ボンド・ニューマーケット（毎月決算型）',
        fund_name_yomi='グローバルボンドニューマーケットマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05039': FundCodeEntry(
        fund_code='G05039',
        sec_code=None,
        fund_name='野村ピクテ・プレミアム・ブランド・ファンド\u3000Ａコース、野村ピクテ・プレミアム・ブランド・ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラピクテプレミアムブランドファンド\u3000エーコース\u3000ノムラピクテプレミアムブランドファンド\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05046': FundCodeEntry(
        fund_code='G05046',
        sec_code=None,
        fund_name='兵庫応援バランスファンド（毎月分配型）',
        fund_name_yomi='ヒョウゴオウエンバランスファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05047': FundCodeEntry(
        fund_code='G05047',
        sec_code=None,
        fund_name='『しがぎん』ＳＲＩ三資産バランス・オープン（奇数月分配型）',
        fund_name_yomi='シガギンエスアールアイサンシサンバランスオープンキスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05049': FundCodeEntry(
        fund_code='G05049',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ジャパン・アクティブ・プラス',
        fund_name_yomi='ミツビシユーエフジェイジャパンアクティブプラス',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05065': FundCodeEntry(
        fund_code='G05065',
        sec_code=None,
        fund_name='ＤＩＡＭバランス・インカム・オープン（毎月分配型）',
        fund_name_yomi='ダイアムバランスインカムオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='8月8日',
        period_2='2月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05074': FundCodeEntry(
        fund_code='G05074',
        sec_code=None,
        fund_name='ＪＰＭグローバル債券３分散ファンド（毎月決算型）',
        fund_name_yomi='ジェイピーエムグローバルサイケンサンブンサンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05075': FundCodeEntry(
        fund_code='G05075',
        sec_code=None,
        fund_name='パインブリッジ・イレブンプラス＜毎月決算型＞',
        fund_name_yomi='パインブリッジイレブンプラスマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05076': FundCodeEntry(
        fund_code='G05076',
        sec_code=None,
        fund_name='ダイワ日本株・バリュー発掘ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワニホンカブバリューハックツファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05077': FundCodeEntry(
        fund_code='G05077',
        sec_code=None,
        fund_name='三井住友グローバル債券オープン',
        fund_name_yomi='ミツイスミトモグローバルサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05078': FundCodeEntry(
        fund_code='G05078',
        sec_code=None,
        fund_name='ニッセイ日本インカムオープン',
        fund_name_yomi='ニッセイニホンインカムオープン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G05082': FundCodeEntry(
        fund_code='G05082',
        sec_code=None,
        fund_name='ＪＡ海外債券ファンド（隔月分配型）',
        fund_name_yomi='ジェイエイカイガイサイケンファンド\u3000カクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G05083': FundCodeEntry(
        fund_code='G05083',
        sec_code=None,
        fund_name='ハッピーライフファンド・株２５、ハッピーライフファンド・株５０、ハッピーライフファンド・株１００',
        fund_name_yomi='ハッピーライフファンドカブニジュウゴ\u3000ハッピーライフファンドカブゴジュウ\u3000ハッピーライフファンドカブヒャク',
        security_type='内国投資信託受益証券',
        period_1='8月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05088': FundCodeEntry(
        fund_code='G05088',
        sec_code=None,
        fund_name='世界ダブルハイインカム（奇数月決算型）',
        fund_name_yomi='セカイダブルハイインカムキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05089': FundCodeEntry(
        fund_code='G05089',
        sec_code=None,
        fund_name='ダイワ・株／債券／コモディティ・バランスファンド',
        fund_name_yomi='ダイワカブサイケンコモディティバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05095': FundCodeEntry(
        fund_code='G05095',
        sec_code=None,
        fund_name='野村ファンドラップ外国債券\u3000Ａコース、野村ファンドラップ外国債券\u3000Ｂコース',
        fund_name_yomi='ノムラファンドラップガイコクサイケン\u3000エーコース\u3000ノムラファンドラップガイコクサイケン\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05096': FundCodeEntry(
        fund_code='G05096',
        sec_code=None,
        fund_name='野村ファンドラップ外国株\u3000Ａコース、野村ファンドラップ外国株\u3000Ｂコース',
        fund_name_yomi='ノムラファンドラップガイコクカブ\u3000エーコース\u3000ノムラファンドラップガイコクカブ\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05099': FundCodeEntry(
        fund_code='G05099',
        sec_code=None,
        fund_name='野村ファンドラップ日本株',
        fund_name_yomi='ノムラファンドラップニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05113': FundCodeEntry(
        fund_code='G05113',
        sec_code=None,
        fund_name='技術成長株オープン',
        fund_name_yomi='ギジュツセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05117': FundCodeEntry(
        fund_code='G05117',
        sec_code=None,
        fund_name='日興スリートップ（隔月分配型）',
        fund_name_yomi='ニッコウスリートップカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05127': FundCodeEntry(
        fund_code='G05127',
        sec_code=None,
        fund_name='年金ダイワ日本株式インデックス',
        fund_name_yomi='ネンキンダイワニホンカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05131': FundCodeEntry(
        fund_code='G05131',
        sec_code=None,
        fund_name='イーストスプリング・インド・インフラ株式ファンド',
        fund_name_yomi='イーストスプリングインドインフラカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G05133': FundCodeEntry(
        fund_code='G05133',
        sec_code=None,
        fund_name='野村国内株式アクティブオープン（確定拠出年金向け）',
        fund_name_yomi='ノムラコクナイカブシキアクティブオープン\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05139': FundCodeEntry(
        fund_code='G05139',
        sec_code=None,
        fund_name='ＤＣマイセレクションＳ２５',
        fund_name_yomi='ディーシーマイセレクションエスニジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05140': FundCodeEntry(
        fund_code='G05140',
        sec_code=None,
        fund_name='ＤＣマイセレクションＳ５０',
        fund_name_yomi='ディーシーマイセレクションエスゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05141': FundCodeEntry(
        fund_code='G05141',
        sec_code=None,
        fund_name='ＤＣマイセレクションＳ７５',
        fund_name_yomi='ディーシーマイセレクションエスナナジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05145': FundCodeEntry(
        fund_code='G05145',
        sec_code=None,
        fund_name='アジア好配当株投信',
        fund_name_yomi='アジアコウハイトウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05146': FundCodeEntry(
        fund_code='G05146',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000バランスインカム・グローバル（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイバランスインカムグローバルマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05147': FundCodeEntry(
        fund_code='G05147',
        sec_code='32340',
        fund_name='森ヒルズリート投資法人',
        fund_name_yomi='モリヒルズリートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E14490',
        issuer_name='森ヒルズリート投資法人',
    ),
    'G05156': FundCodeEntry(
        fund_code='G05156',
        sec_code=None,
        fund_name='ライフハーモニー（ダイワ世界資産分散ファンド）（成長型／安定型／分配型）',
        fund_name_yomi='ライフハーモニーダイワセカイシサンブンサンファンドセイチョウガタアンテイガタブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05164': FundCodeEntry(
        fund_code='G05164',
        sec_code=None,
        fund_name='ＤＩＡＭ世界６資産バランスファンド',
        fund_name_yomi='ダイアムセカイロクシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05165': FundCodeEntry(
        fund_code='G05165',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000Ｊ－ＲＥＩＴアクティブファンド（毎月決算型）',
        fund_name_yomi='ダイアムジェイリートアクティブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05170': FundCodeEntry(
        fund_code='G05170',
        sec_code=None,
        fund_name='野村米国好利回り社債投信\u3000Ａコース、野村米国好利回り社債投信\u3000Ｂコース',
        fund_name_yomi='ノムラベイコクコウリマワリシャサイトウシン\u3000エーコース\u3000ノムラベイコクコウリマワリシャサイトウシン\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='12月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05171': FundCodeEntry(
        fund_code='G05171',
        sec_code=None,
        fund_name='野村米国好利回り社債投信\u3000Ｃコース、野村米国好利回り社債投信\u3000Ｄコース',
        fund_name_yomi='ノムラベイコクコウリマワリシャサイトウシン\u3000シーコース\u3000ノムラベイコクコウリマワリシャサイトウシン\u3000ディーコース',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05176': FundCodeEntry(
        fund_code='G05176',
        sec_code=None,
        fund_name='パインブリッジ日本株オープン',
        fund_name_yomi='パインブリッジニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='5月4日',
        period_2='11月4日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05178': FundCodeEntry(
        fund_code='G05178',
        sec_code=None,
        fund_name='世界のサイフ',
        fund_name_yomi='セカイノサイフ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05179': FundCodeEntry(
        fund_code='G05179',
        sec_code=None,
        fund_name='しんきんＳＲＩファンド',
        fund_name_yomi='シンキンエスアールアイファンド',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G05182': FundCodeEntry(
        fund_code='G05182',
        sec_code=None,
        fund_name='新生・ＵＴＩインドファンド',
        fund_name_yomi='シンセイ\u3000ユーティーアイインドファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05184': FundCodeEntry(
        fund_code='G05184',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（欧州）',
        fund_name_yomi='ワールドリートセレクションオウシュウ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G05191': FundCodeEntry(
        fund_code='G05191',
        sec_code=None,
        fund_name='ピクテ・インカム・コレクション・ファンド（毎月分配型）',
        fund_name_yomi='ピクテインカムコレクションファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G05193': FundCodeEntry(
        fund_code='G05193',
        sec_code=None,
        fund_name='常陽３分法ファンド',
        fund_name_yomi='ジョウヨウサンブンポウファンド',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05195': FundCodeEntry(
        fund_code='G05195',
        sec_code=None,
        fund_name='世界好利回り短期債券ファンド（毎月決算型）',
        fund_name_yomi='セカイコウリマワリタンキサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05196': FundCodeEntry(
        fund_code='G05196',
        sec_code=None,
        fund_name='野村日本不動産投信',
        fund_name_yomi='ノムラニホンフドウサントウシン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05204': FundCodeEntry(
        fund_code='G05204',
        sec_code=None,
        fund_name='日興・ＤＷＳ・ニュー・リソース・ファンド',
        fund_name_yomi='ニッコウディーダブリューエスニューリソースファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G05211': FundCodeEntry(
        fund_code='G05211',
        sec_code=None,
        fund_name='ニュー・グローバル・バランス・ファンド',
        fund_name_yomi='ニューグローバルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05213': FundCodeEntry(
        fund_code='G05213',
        sec_code=None,
        fund_name='ＤＩＡＭＤＣバランス３０インデックスファンド、ＤＩＡＭＤＣバランス５０インデックスファンド、ＤＩＡＭＤＣバランス７０インデックスファンド',
        fund_name_yomi='ダイアムディーシーバランスサンジュウインデックスファンド\u3000ダイアムディーシーバランスゴジュウインデックスファンド\u3000ダイアムディーシーバランスナナジュウインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05216': FundCodeEntry(
        fund_code='G05216',
        sec_code=None,
        fund_name='野村ＤＣ日本株式アクティブファンド',
        fund_name_yomi='ノムラディーシーニホンカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05217': FundCodeEntry(
        fund_code='G05217',
        sec_code=None,
        fund_name='ＤＣダイワＪ－ＲＥＩＴアクティブファンド',
        fund_name_yomi='ディーシーダイワジェイリートアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05218': FundCodeEntry(
        fund_code='G05218',
        sec_code=None,
        fund_name='ＤＷＳ世界新興国株式ファンド',
        fund_name_yomi='ディーダブリューエスセカイシンコウコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G05219': FundCodeEntry(
        fund_code='G05219',
        sec_code=None,
        fund_name='大和ＤＣ海外株式インデックスファンド',
        fund_name_yomi='ダイワディーシーカイガイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05226': FundCodeEntry(
        fund_code='G05226',
        sec_code=None,
        fund_name='ＢＮＰパリバ欧州高配当・成長株式ファンド（毎月分配型）',
        fund_name_yomi='ビーエヌピーパリバオウシュウコウハイトウセイチョウカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12431',
        issuer_name='ＢＮＰパリバ・アセットマネジメント株式会社',
    ),
    'G05232': FundCodeEntry(
        fund_code='G05232',
        sec_code=None,
        fund_name='日本株式インデックス・オープン\u3000（ＳＭＡ専用）',
        fund_name_yomi='ニホンカブシキインデックスオープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05233': FundCodeEntry(
        fund_code='G05233',
        sec_code=None,
        fund_name='外国株式インデックス・オープン\u3000（ＳＭＡ専用）',
        fund_name_yomi='ガイコクカブシキインデックスオープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05234': FundCodeEntry(
        fund_code='G05234',
        sec_code=None,
        fund_name='日本債券インデックス・オープン\u3000（ＳＭＡ専用）',
        fund_name_yomi='ニホンサイケンインデックスオープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05235': FundCodeEntry(
        fund_code='G05235',
        sec_code=None,
        fund_name='外国債券インデックス・オープン\u3000（ＳＭＡ専用）',
        fund_name_yomi='ガイコクサイケンインデックスオープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05241': FundCodeEntry(
        fund_code='G05241',
        sec_code=None,
        fund_name='世界好配当株投信（毎月分配型）',
        fund_name_yomi='セカイコウハイトウカブトウシン\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05246': FundCodeEntry(
        fund_code='G05246',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳトレジャリ－・インカム・ファンド（ＳＭＡ専用）',
        fund_name_yomi='ジェイピーエム\u3000ユーエストレジャリーインカムファンドエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05247': FundCodeEntry(
        fund_code='G05247',
        sec_code=None,
        fund_name='スパークス・Ｍ＆Ｓ・ジャパン・ファンド',
        fund_name_yomi='スパークス\u3000エムアンドエス\u3000ジャパン\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G05249': FundCodeEntry(
        fund_code='G05249',
        sec_code=None,
        fund_name='ピクテ・ユーロ最高格付国債インカム・ファンド（ＳＭＡ専用）',
        fund_name_yomi='ピクテユーロサイコウカクヅケコクサイインカムファンドエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G05251': FundCodeEntry(
        fund_code='G05251',
        sec_code=None,
        fund_name='テンプルトン・グローバル株式ファンド',
        fund_name_yomi='テンプルトングローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G05255': FundCodeEntry(
        fund_code='G05255',
        sec_code=None,
        fund_name='マネックス資産設計ファンド＜隔月分配型＞',
        fund_name_yomi='マネックスシサンセッケイファンドカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05256': FundCodeEntry(
        fund_code='G05256',
        sec_code=None,
        fund_name='マネックス資産設計ファンド＜育成型＞',
        fund_name_yomi='マネックスシサンセッケイファンドイクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05260': FundCodeEntry(
        fund_code='G05260',
        sec_code=None,
        fund_name='ＤＷＳグローバル新興国株投信',
        fund_name_yomi='ディーダブリューエスグローバルシンコウコクカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G05263': FundCodeEntry(
        fund_code='G05263',
        sec_code=None,
        fund_name='ＧＳグローバルＲＥＩＴポートフォリオ（毎月分配型）',
        fund_name_yomi='ジーエスグローバルリートポートフォリオ\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G05273': FundCodeEntry(
        fund_code='G05273',
        sec_code=None,
        fund_name='ノムラ・グローバル・オールスターズ',
        fund_name_yomi='ノムラ\u3000グローバル\u3000オールスターズ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05280': FundCodeEntry(
        fund_code='G05280',
        sec_code=None,
        fund_name='ＪＰＭ新興国現地通貨ソブリン・ファンド（毎月決算型）',
        fund_name_yomi='ジェイピーエムシンコウコクゲンチツウカソブリンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05295': FundCodeEntry(
        fund_code='G05295',
        sec_code=None,
        fund_name='ＨＳＢＣロシアオープン',
        fund_name_yomi='エイチエスビーシーロシアオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G05296': FundCodeEntry(
        fund_code='G05296',
        sec_code=None,
        fund_name='ＨＳＢＣ世界資源エネルギーオープン',
        fund_name_yomi='エイチエスビーシーセカイシゲンエネルギーオープン',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G05301': FundCodeEntry(
        fund_code='G05301',
        sec_code=None,
        fund_name='セゾン・グローバルバランスファンド',
        fund_name_yomi='セゾングローバルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E14561',
        issuer_name='セゾン投信株式会社',
    ),
    'G05306': FundCodeEntry(
        fund_code='G05306',
        sec_code=None,
        fund_name='ＪＰＭアセアン成長株オープン',
        fund_name_yomi='ジェイピーエムアセアンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05309': FundCodeEntry(
        fund_code='G05309',
        sec_code=None,
        fund_name='三菱ＵＦＪ資産設計ファンド（分配型）\u3000三菱ＵＦＪ資産設計ファンド（バランス型）\u3000三菱ＵＦＪ資産設計ファンド（株式重視型）',
        fund_name_yomi='ミツビシユーエフジェイシサンセッケイファンドブンパイガタミツビシユーエフジェイシサンセッケイファンドバランスガタミツビシユーエフジェイシサンセッケイファンドカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05313': FundCodeEntry(
        fund_code='G05313',
        sec_code=None,
        fund_name='三井住友・中国Ａ株・香港株オープン',
        fund_name_yomi='ミツイスミトモチュウゴクエーカブホンコンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05319': FundCodeEntry(
        fund_code='G05319',
        sec_code=None,
        fund_name='野村ユーロ・トップ・カンパニー\u3000Ａコース、野村ユーロ・トップ・カンパニー\u3000Ｂコース',
        fund_name_yomi='ノムラユーロトップカンパニー\u3000エーコース\u3000ノムラユーロトップカンパニー\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05322': FundCodeEntry(
        fund_code='G05322',
        sec_code=None,
        fund_name='セゾン資産形成の達人ファンド',
        fund_name_yomi='セゾンシサンケイセイノタツジンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E14561',
        issuer_name='セゾン投信株式会社',
    ),
    'G05324': FundCodeEntry(
        fund_code='G05324',
        sec_code=None,
        fund_name='ＪＰＭ・ＶＩＳＴＡ５・ファンド',
        fund_name_yomi='ジェイピーエムビスタファイブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05327': FundCodeEntry(
        fund_code='G05327',
        sec_code=None,
        fund_name='三井住友・Ａ株メインランド・チャイナ・オープン',
        fund_name_yomi='ミツイスミトモエーカブメインランドチャイナオープン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05334': FundCodeEntry(
        fund_code='G05334',
        sec_code=None,
        fund_name='ダイワ・セレクト日本',
        fund_name_yomi='ダイワセレクトニッポン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05335': FundCodeEntry(
        fund_code='G05335',
        sec_code=None,
        fund_name='世界好配当インフラ株ファンド（偶数月分配型）',
        fund_name_yomi='セカイコウハイトウインフラカブファンド\u3000グウスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05339': FundCodeEntry(
        fund_code='G05339',
        sec_code=None,
        fund_name='アジア・ダブルプレミア・ファンド',
        fund_name_yomi='アジアダブルプレミアファンド',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G05343': FundCodeEntry(
        fund_code='G05343',
        sec_code=None,
        fund_name='シュローダー・エマージング株式ファンド（１年決算型）',
        fund_name_yomi='シュローダーエマージングカブシキファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G05344': FundCodeEntry(
        fund_code='G05344',
        sec_code=None,
        fund_name='シュローダー・エマージング株式ファンド（３ヵ月決算型）',
        fund_name_yomi='シュローダーエマージングカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G05345': FundCodeEntry(
        fund_code='G05345',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＶＩＰフォーカス・ファンド',
        fund_name_yomi='ワンビップフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05349': FundCodeEntry(
        fund_code='G05349',
        sec_code=None,
        fund_name='野村グローバル・コントラリアン・ファンド\u3000Ａコース、野村グローバル・コントラリアン・ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラグローバルコントラリアンファンド\u3000エーコース\u3000ノムラグローバルコントラリアンファンド\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05350': FundCodeEntry(
        fund_code='G05350',
        sec_code=None,
        fund_name='日興・アッシュモア・グローイング・マルチストラテジー・ファンド',
        fund_name_yomi='ニッコウアッシュモアグローイングマルチストラテジーファンド',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05351': FundCodeEntry(
        fund_code='G05351',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000世界国債インデックスファンド（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイセカイコクサイインデックスファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05353': FundCodeEntry(
        fund_code='G05353',
        sec_code=None,
        fund_name='ＵＢＳ中国株式ファンド',
        fund_name_yomi='ユービーエスチュウゴクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G05355': FundCodeEntry(
        fund_code='G05355',
        sec_code=None,
        fund_name='ＤＩＡＭグローバル・アクティブ・バランスファンド',
        fund_name_yomi='ダイアムグローバルアクティブバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05356': FundCodeEntry(
        fund_code='G05356',
        sec_code=None,
        fund_name='ＯｎｅワールドＲＥＩＴアクティブファンド（毎月決算型）',
        fund_name_yomi='ワンワールドリートアクティブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月9日',
        period_2='4月9日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05364': FundCodeEntry(
        fund_code='G05364',
        sec_code=None,
        fund_name='ＨＳＢＣアジア・プラス',
        fund_name_yomi='エイチエスビーシーアジアプラス',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G05365': FundCodeEntry(
        fund_code='G05365',
        sec_code=None,
        fund_name='ＨＳＢＣアジア・プラス（３ヶ月決算型）',
        fund_name_yomi='エイチエスビーシーアジアプラスサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G05366': FundCodeEntry(
        fund_code='G05366',
        sec_code=None,
        fund_name='メロン世界新興国ソブリン・ファンド',
        fund_name_yomi='メロンセカイシンコウコクソブリンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G05374': FundCodeEntry(
        fund_code='G05374',
        sec_code=None,
        fund_name='パインブリッジ現地通貨建て新成長国債インカムオープン＜毎月分配型＞',
        fund_name_yomi='パインブリッジゲンチツウカダテシンセイチョウコクサイインカムオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05375': FundCodeEntry(
        fund_code='G05375',
        sec_code=None,
        fund_name='ピクテ・メジャー・プレイヤーズ・ファンド（３ヵ月決算型）',
        fund_name_yomi='ピクテメジャープレイヤーズファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G05380': FundCodeEntry(
        fund_code='G05380',
        sec_code=None,
        fund_name='インベスコ\u3000世界株式オープン',
        fund_name_yomi='インベスコセカイカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G05387': FundCodeEntry(
        fund_code='G05387',
        sec_code=None,
        fund_name='野村ＲＡＦＩ（Ｒ）日本株投信',
        fund_name_yomi='ノムララフィニホンカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05392': FundCodeEntry(
        fund_code='G05392',
        sec_code=None,
        fund_name='グローバル・カレンシー・ファンド（毎月決算型）',
        fund_name_yomi='グローバルカレンシーファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05393': FundCodeEntry(
        fund_code='G05393',
        sec_code=None,
        fund_name='アメリカン・ドリーム・ファンド',
        fund_name_yomi='アメリカン\u3000ドリーム\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05394': FundCodeEntry(
        fund_code='G05394',
        sec_code=None,
        fund_name='ダイワ資産分散インカムオープン（奇数月決算型）',
        fund_name_yomi='ダイワシサンブンサンインカムオープンキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05395': FundCodeEntry(
        fund_code='G05395',
        sec_code=None,
        fund_name='ダイワ世界リート・ファンド（毎月分配型）',
        fund_name_yomi='ダイワセカイリートファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05399': FundCodeEntry(
        fund_code='G05399',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000欧豪リートファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイオウゴウリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05401': FundCodeEntry(
        fund_code='G05401',
        sec_code=None,
        fund_name='フィデリティ・日本配当成長株投信',
        fund_name_yomi='フィデリティニホンハイトウセイチョウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2='10月19日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G05405': FundCodeEntry(
        fund_code='G05405',
        sec_code=None,
        fund_name='Ｏｎｅ世界３資産オープン（毎月決算型）',
        fund_name_yomi='ワンセカイサンシサンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月8日',
        period_2='5月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05411': FundCodeEntry(
        fund_code='G05411',
        sec_code=None,
        fund_name='世界銀行債券ファンド（毎月分配型）',
        fund_name_yomi='セカイギンコウサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05416': FundCodeEntry(
        fund_code='G05416',
        sec_code=None,
        fund_name='アバディーン・スタンダード・インフラ・ファンド',
        fund_name_yomi='アバディーンスタンダードインフラファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E08163',
        issuer_name='アバディーン・ジャパン株式会社',
    ),
    'G05417': FundCodeEntry(
        fund_code='G05417',
        sec_code=None,
        fund_name='フィデリティ・資産分散投信（安定型）\u3000フィデリティ・資産分散投信（成長型）',
        fund_name_yomi='フィデリティシサンブンサントウシンアンテイガタ\u3000フィデリティシサンブンサントウシンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G05418': FundCodeEntry(
        fund_code='G05418',
        sec_code=None,
        fund_name='ピクテ・インカム・アルファ・ファンド（毎月分配型）',
        fund_name_yomi='ピクテインカムアルファファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G05421': FundCodeEntry(
        fund_code='G05421',
        sec_code=None,
        fund_name='（トヨタ\u3000モーター\u3000クレジット）トヨタグループ世界債券ファンド（毎月分配型）、（トヨタ\u3000モーター\u3000クレジット）トヨタグループ世界債券ファンド（年２回分配型）',
        fund_name_yomi='トヨタモータークレジットトヨタグループセカイサイケンファンドマイツキブンパイガタ\u3000トヨタモータークレジットトヨタグループセカイサイケンファンドネンニカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05423': FundCodeEntry(
        fund_code='G05423',
        sec_code=None,
        fund_name='野村資産設計ファンド',
        fund_name_yomi='ノムラシサンセッケイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05425': FundCodeEntry(
        fund_code='G05425',
        sec_code=None,
        fund_name='アジアの財産３分法ファンド',
        fund_name_yomi='アジアノザイサンサンブンポウファンド',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05426': FundCodeEntry(
        fund_code='G05426',
        sec_code=None,
        fund_name='ＳＢＩインド＆ベトナム株ファンド',
        fund_name_yomi='エスビーアイインドアンドベトナムカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月4日',
        period_2='12月4日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05427': FundCodeEntry(
        fund_code='G05427',
        sec_code=None,
        fund_name='イーストスプリング・グローイング・アジア株式オープン',
        fund_name_yomi='イーストスプリンググローイングアジアカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G05431': FundCodeEntry(
        fund_code='G05431',
        sec_code=None,
        fund_name='ダイワ／フィデリティ・アジア３資産分散ファンド',
        fund_name_yomi='ダイワフィデリティアジアサンシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05435': FundCodeEntry(
        fund_code='G05435',
        sec_code=None,
        fund_name='三井住友・アジア４大成長国オープン',
        fund_name_yomi='ミツイスミトモアジアヨンダイセイチョウコクオープン',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05438': FundCodeEntry(
        fund_code='G05438',
        sec_code=None,
        fund_name='ワールド・ファイブインカム・ファンド（毎月決算型）',
        fund_name_yomi='ワールドファイブインカムファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05447': FundCodeEntry(
        fund_code='G05447',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000グローバル・エコ・ウォーター・ファンド',
        fund_name_yomi='ミツビシユーエフジェイ\u3000グローバルエコウォーターファンド',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05448': FundCodeEntry(
        fund_code='G05448',
        sec_code=None,
        fund_name='ダイワ世界好配当株ファンド',
        fund_name_yomi='ダイワセカイコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05455': FundCodeEntry(
        fund_code='G05455',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（アジア）／ワールド・リート・セレクション（アジア）（年２回決算型）',
        fund_name_yomi='ワールドリートセレクションアジア\u3000ワールドリートセレクションアジアネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G05458': FundCodeEntry(
        fund_code='G05458',
        sec_code=None,
        fund_name='インベスコ・ニッポン新興成長株ファンド',
        fund_name_yomi='インベスコニッポンシンコウセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月30日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G05475': FundCodeEntry(
        fund_code='G05475',
        sec_code='13280',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000金価格連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000キンカカクレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05480': FundCodeEntry(
        fund_code='G05480',
        sec_code=None,
        fund_name='ベトナム・ＡＳＥＡＮ・バランスファンド',
        fund_name_yomi='ベトナムアセアンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G05483': FundCodeEntry(
        fund_code='G05483',
        sec_code=None,
        fund_name='アジア未来成長株式ファンド（３ヵ月決算型）',
        fund_name_yomi='アジアミライセイチョウカブシキファンド\u3000サンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E11348',
        issuer_name='ベアリングス・ジャパン株式会社',
    ),
    'G05484': FundCodeEntry(
        fund_code='G05484',
        sec_code=None,
        fund_name='ＤＣニッセイＪ－ＲＥＩＴインデックスファンド',
        fund_name_yomi='ディーシーニッセイジェイリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G05486': FundCodeEntry(
        fund_code='G05486',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ金利連動アロケーション型バランスファンド',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ディーシーキンリレンドウアロケーションガタバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05489': FundCodeEntry(
        fund_code='G05489',
        sec_code=None,
        fund_name='ＤＷＳ新資源テクノロジー・ファンド',
        fund_name_yomi='ディーダブリューエスシンシゲンテクノロジーファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G05492': FundCodeEntry(
        fund_code='G05492',
        sec_code=None,
        fund_name='新興国国債オープン（毎月決算型）',
        fund_name_yomi='シンコウコクコクサイオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G05493': FundCodeEntry(
        fund_code='G05493',
        sec_code=None,
        fund_name='新興国国債オープン（１年決算型）',
        fund_name_yomi='シンコウコクコクサイオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月12日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G05498': FundCodeEntry(
        fund_code='G05498',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000世界３地域リートファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000セカイサンチイキリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05500': FundCodeEntry(
        fund_code='G05500',
        sec_code=None,
        fund_name='野村世界高金利通貨投信',
        fund_name_yomi='ノムラセカイコウキンリツウカトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05501': FundCodeEntry(
        fund_code='G05501',
        sec_code=None,
        fund_name='野村アクア投資\u3000Ａコース、野村アクア投資\u3000Ｂコース',
        fund_name_yomi='ノムラアクアトウシ\u3000エーコース\u3000ノムラアクアトウシ\u3000ビーコース',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05502': FundCodeEntry(
        fund_code='G05502',
        sec_code=None,
        fund_name='ＵＢＳ気候変動関連グローバル成長株式ファンド',
        fund_name_yomi='ユービーエスキコウヘンドウカンレングローバルセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G05515': FundCodeEntry(
        fund_code='G05515',
        sec_code=None,
        fund_name='グローバル新成長国オープン',
        fund_name_yomi='グローバルシンセイチョウコクオープン',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G05519': FundCodeEntry(
        fund_code='G05519',
        sec_code=None,
        fund_name='ＨＳＢＣインド株式ファンド（３ヶ月決算型）',
        fund_name_yomi='エイチエスビーシーインドカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G05522': FundCodeEntry(
        fund_code='G05522',
        sec_code=None,
        fund_name='ＤＣ日本株式インデックス・オープンＳ',
        fund_name_yomi='ディーシーニホンカブシキインデックスオープンエス',
        security_type='内国投資信託受益証券',
        period_1='5月29日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05527': FundCodeEntry(
        fund_code='G05527',
        sec_code=None,
        fund_name='新生\u3000フラトンＶＰＩＣファンド',
        fund_name_yomi='シンセイ\u3000フラトンブイピックファンド',
        security_type='内国投資信託受益証券',
        period_1='8月26日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05543': FundCodeEntry(
        fund_code='G05543',
        sec_code=None,
        fund_name='シュローダー・ラテンアメリカ株投資',
        fund_name_yomi='シュローダーラテンアメリカカブトウシ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G05548': FundCodeEntry(
        fund_code='G05548',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000ワールドＲＥＩＴアクティブファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムワールドリートアクティブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05549': FundCodeEntry(
        fund_code='G05549',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000国内株式インデックスファンド',
        fund_name_yomi='ワンディーシーコクナイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05552': FundCodeEntry(
        fund_code='G05552',
        sec_code=None,
        fund_name='ＤＣ\u3000ターゲット・イヤー\u3000ファンド',
        fund_name_yomi='ディーシー\u3000ターゲットイヤー\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05553': FundCodeEntry(
        fund_code='G05553',
        sec_code=None,
        fund_name='マイバランスＤＣ３０',
        fund_name_yomi='マイバランスディーシーサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05554': FundCodeEntry(
        fund_code='G05554',
        sec_code=None,
        fund_name='マイバランスＤＣ５０',
        fund_name_yomi='マイバランスディーシーゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05555': FundCodeEntry(
        fund_code='G05555',
        sec_code=None,
        fund_name='マイバランスＤＣ７０',
        fund_name_yomi='マイバランスディーシーナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05556': FundCodeEntry(
        fund_code='G05556',
        sec_code=None,
        fund_name='野村ＤＣ国内株式インデックスファンド・ＴＯＰＩＸ',
        fund_name_yomi='ノムラディーシーコクナイカブシキインデックスファンドトピックス',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05557': FundCodeEntry(
        fund_code='G05557',
        sec_code=None,
        fund_name='野村ＤＣ国内債券インデックスファンド・ＮＯＭＵＲＡ－ＢＰＩ総合',
        fund_name_yomi='ノムラディーシーコクナイサイケンインデックスファンドノムラ\u3000ビーピーアイソウゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05558': FundCodeEntry(
        fund_code='G05558',
        sec_code=None,
        fund_name='野村ＤＣ外国株式インデックスファンド・ＭＳＣＩ－ＫＯＫＵＳＡＩ',
        fund_name_yomi='ノムラディーシーガイコクカブシキインデックスファンド\u3000エムエスシーアイ\u3000コクサイ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05559': FundCodeEntry(
        fund_code='G05559',
        sec_code=None,
        fund_name='野村ＤＣ外国債券インデックスファンド',
        fund_name_yomi='ノムラディーシーガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05567': FundCodeEntry(
        fund_code='G05567',
        sec_code=None,
        fund_name='キャピタル世界株式ファンド',
        fund_name_yomi='キャピタルセカイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G05568': FundCodeEntry(
        fund_code='G05568',
        sec_code='32490',
        fund_name='産業ファンド投資法人',
        fund_name_yomi='サンギョウファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E14705',
        issuer_name='産業ファンド投資法人',
    ),
    'G05579': FundCodeEntry(
        fund_code='G05579',
        sec_code=None,
        fund_name='日興・ジャナス・グローバル・オポチュニティ・ファンド',
        fund_name_yomi='ニッコウジャナスグローバルオポチュニティファンド',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05583': FundCodeEntry(
        fund_code='G05583',
        sec_code=None,
        fund_name='ダイワファンドラップ\u3000セレクト・シリーズ',
        fund_name_yomi='ダイワファンドラップセレクトシリーズ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05588': FundCodeEntry(
        fund_code='G05588',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ラッセル野村小型コア・インデックス連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ラッセルノムラコガタコアインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05589': FundCodeEntry(
        fund_code='G05589',
        sec_code='13090',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＣｈｉｎａＡＭＣ・中国株式・上証５０連動型上場投信',
        fund_name_yomi='ネクストファンズチャイナエーエムシーチュウゴクカブシキシャンジャンゴジュウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05590': FundCodeEntry(
        fund_code='G05590',
        sec_code=None,
        fund_name='ＵＢＳ海外株式ファンド\u3000Ａコース為替ヘッジあり（野村ＳＭＡ向け）／Ｂコース為替ヘッジなし（野村ＳＭＡ向け）',
        fund_name_yomi='ユービーエスカイガイカブシキファンド\u3000エーコースカワセヘッジアリ\u3000ノムラエスエムエームケ\u3000ビーコースカワセヘッジナシ\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G05596': FundCodeEntry(
        fund_code='G05596',
        sec_code=None,
        fund_name='ノムラ新興国株ファンズ\u3000Ａコース（野村ＳＭＡ向け）、ノムラ新興国株ファンズ\u3000Ｂコース（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラシンコウコクカブファンズ\u3000エーコース\u3000ノムラエスエムエームケ\u3000ノムラシンコウコクカブファンズ\u3000ビーコース\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05597': FundCodeEntry(
        fund_code='G05597',
        sec_code=None,
        fund_name='野村グローバル・アセット・モデル・ファンド（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラグローバルアセットモデルファンド\u3000ノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05598': FundCodeEntry(
        fund_code='G05598',
        sec_code=None,
        fund_name='ファンド・マネジャー（国内債券）',
        fund_name_yomi='ファンドマネジャーコクナイサイケン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05601': FundCodeEntry(
        fund_code='G05601',
        sec_code=None,
        fund_name='ＢＮＰパリバ・ブラジル・ファンド（株式型）',
        fund_name_yomi='ビーエヌピーパリバブラジルファンドカブシキガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12431',
        issuer_name='ＢＮＰパリバ・アセットマネジメント株式会社',
    ),
    'G05602': FundCodeEntry(
        fund_code='G05602',
        sec_code=None,
        fund_name='ＢＮＰパリバ・ブラジル・ファンド（バランス型）',
        fund_name_yomi='ビーエヌピーパリバブラジルファンドバランスガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12431',
        issuer_name='ＢＮＰパリバ・アセットマネジメント株式会社',
    ),
    'G05607': FundCodeEntry(
        fund_code='G05607',
        sec_code=None,
        fund_name='野村バリュー・フォーカス・ジャパン',
        fund_name_yomi='ノムラバリューフォーカスジャパン',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05609': FundCodeEntry(
        fund_code='G05609',
        sec_code=None,
        fund_name='Ｏｎｅ新興市場日本株ファンド',
        fund_name_yomi='ワンシンコウシジョウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05610': FundCodeEntry(
        fund_code='G05610',
        sec_code=None,
        fund_name='アセアン成長国株ファンド',
        fund_name_yomi='アセアンセイチョウコクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05613': FundCodeEntry(
        fund_code='G05613',
        sec_code=None,
        fund_name='スパークス・アジア中東株式ファンド（隔月分配型）',
        fund_name_yomi='スパークス\u3000アジアチュウトウカブシキファンド\u3000カクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2='5月10日',
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G05616': FundCodeEntry(
        fund_code='G05616',
        sec_code=None,
        fund_name='野村新世界高金利通貨投信',
        fund_name_yomi='ノムラシンセカイコウキンリツウカトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05631': FundCodeEntry(
        fund_code='G05631',
        sec_code=None,
        fund_name='パインブリッジ新成長国ダブルプラス＜毎月分配タイプ＞',
        fund_name_yomi='パインブリッジシンセイチョウコクダブルプラスマイツキブンパイタイプ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05632': FundCodeEntry(
        fund_code='G05632',
        sec_code=None,
        fund_name='パインブリッジ新成長国ダブルプラス＜１年決算タイプ＞',
        fund_name_yomi='パインブリッジシンセイチョウコクダブルプラスイチネンケッサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05635': FundCodeEntry(
        fund_code='G05635',
        sec_code=None,
        fund_name='ＳＢＩ資産設計オープン（資産成長型）',
        fund_name_yomi='エスビーアイ\u3000シサンセッケイオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05636': FundCodeEntry(
        fund_code='G05636',
        sec_code=None,
        fund_name='ＳＢＩ資産設計オープン（分配型）',
        fund_name_yomi='エスビーアイ\u3000シサンセッケイオープンブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05637': FundCodeEntry(
        fund_code='G05637',
        sec_code=None,
        fund_name='ＳＭＴ\u3000国内債券インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000コクナイサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05638': FundCodeEntry(
        fund_code='G05638',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＴＯＰＩＸインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000トピックスインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05639': FundCodeEntry(
        fund_code='G05639',
        sec_code=None,
        fund_name='ＳＭＴ\u3000グローバル債券インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000グローバルサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05640': FundCodeEntry(
        fund_code='G05640',
        sec_code=None,
        fund_name='ＳＭＴ\u3000グローバル株式インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000グローバルカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05641': FundCodeEntry(
        fund_code='G05641',
        sec_code=None,
        fund_name='ＳＭＴ\u3000Ｊ－ＲＥＩＴインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ジェイリートインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05642': FundCodeEntry(
        fund_code='G05642',
        sec_code=None,
        fund_name='ＳＭＴ\u3000グローバルＲＥＩＴインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000グローバルリートインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G05649': FundCodeEntry(
        fund_code='G05649',
        sec_code=None,
        fund_name='イーストスプリング・インド株式ファンド（３ヵ月決算型）',
        fund_name_yomi='イーストスプリングインドカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G05650': FundCodeEntry(
        fund_code='G05650',
        sec_code=None,
        fund_name='ＤＩＡＭ高金利ソブリン債券ファンド（毎月決算型）',
        fund_name_yomi='ダイアムコウキンリソブリンサイケンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月8日',
        period_2='2月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05651': FundCodeEntry(
        fund_code='G05651',
        sec_code=None,
        fund_name='東京海上・プレミアムワールド株式ファンド',
        fund_name_yomi='トウキョウカイジョウプレミアムワールドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G05655': FundCodeEntry(
        fund_code='G05655',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞Ｊ－ＲＥＩＴファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシージェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G05660': FundCodeEntry(
        fund_code='G05660',
        sec_code=None,
        fund_name='ＵＢＳ原油先物ファンド',
        fund_name_yomi='ユービーエスゲンユサキモノファンド',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G05661': FundCodeEntry(
        fund_code='G05661',
        sec_code=None,
        fund_name='三井住友・アジア・オセアニア好配当株式ファンド',
        fund_name_yomi='ミツイスミトモアジアオセアニアコウハイトウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05662': FundCodeEntry(
        fund_code='G05662',
        sec_code=None,
        fund_name='日興新世代新興国株式ファンド',
        fund_name_yomi='ニッコウシンセダイシンコウコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月4日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G05666': FundCodeEntry(
        fund_code='G05666',
        sec_code=None,
        fund_name='ダイワ・ダイナミック・インド株ファンド',
        fund_name_yomi='ダイワダイナミックインドカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05672': FundCodeEntry(
        fund_code='G05672',
        sec_code=None,
        fund_name='パインブリッジ日本株式ＳＲＩファンド＜ＤＣ＞',
        fund_name_yomi='パインブリッジニホンカブシキエスアールアイファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G05673': FundCodeEntry(
        fund_code='G05673',
        sec_code=None,
        fund_name='グローバル高金利通貨ファンド',
        fund_name_yomi='グローバルコウキンリツウカファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05681': FundCodeEntry(
        fund_code='G05681',
        sec_code=None,
        fund_name='ＪＰＭ新興国好利回り債投信',
        fund_name_yomi='ジェイピーエムシンコウコクコウリマワリサイトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G05683': FundCodeEntry(
        fund_code='G05683',
        sec_code=None,
        fund_name='アムンディ・アラブ株式ファンド',
        fund_name_yomi='アムンディアラブカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G05684': FundCodeEntry(
        fund_code='G05684',
        sec_code=None,
        fund_name='ピクテ新興国インカム株式ファンド（毎月決算型）',
        fund_name_yomi='ピクテシンコウコクインカムカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G05708': FundCodeEntry(
        fund_code='G05708',
        sec_code=None,
        fund_name='新生・ＵＴＩインドインフラ関連株式ファンド',
        fund_name_yomi='シンセイ\u3000ユーティーアイインドインフラカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G05710': FundCodeEntry(
        fund_code='G05710',
        sec_code=None,
        fund_name='ＮＺＡＭ\u3000日本好配当株オープン（３ヵ月決算型）',
        fund_name_yomi='エヌザム\u3000ニホンコウハイトウカブオープン\u3000サンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G05711': FundCodeEntry(
        fund_code='G05711',
        sec_code=None,
        fund_name='野村日本債券インデックスファンド',
        fund_name_yomi='ノムラニホンサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05712': FundCodeEntry(
        fund_code='G05712',
        sec_code=None,
        fund_name='ダイワ・ロシア株ファンド',
        fund_name_yomi='ダイワロシアカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05713': FundCodeEntry(
        fund_code='G05713',
        sec_code=None,
        fund_name='ＤＩＡＭストラテジックＪ－ＲＥＩＴファンド',
        fund_name_yomi='ダイアムストラテジックジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G05719': FundCodeEntry(
        fund_code='G05719',
        sec_code=None,
        fund_name='メロン世界新興国ソブリン・ファンド（年１回決算型）',
        fund_name_yomi='メロンセカイシンコウコクソブリンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G05734': FundCodeEntry(
        fund_code='G05734',
        sec_code=None,
        fund_name='野村日本株インデックス（野村投資一任口座向け）',
        fund_name_yomi='ノムラニホンカブインデックス\u3000ノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05735': FundCodeEntry(
        fund_code='G05735',
        sec_code=None,
        fund_name='野村日本債券インデックス（野村投資一任口座向け）',
        fund_name_yomi='ノムラニホンサイケンインデックス\u3000ノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05736': FundCodeEntry(
        fund_code='G05736',
        sec_code=None,
        fund_name='野村外国株インデックス\u3000Ｂコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクカブインデックスビーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05737': FundCodeEntry(
        fund_code='G05737',
        sec_code=None,
        fund_name='野村外国債券インデックス\u3000Ｂコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスビーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05738': FundCodeEntry(
        fund_code='G05738',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴインデックス\u3000Ｂコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラセカイリートインデックスビーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05739': FundCodeEntry(
        fund_code='G05739',
        sec_code=None,
        fund_name='野村アフリカ株投資',
        fund_name_yomi='ノムラアフリカカブトウシ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G05740': FundCodeEntry(
        fund_code='G05740',
        sec_code=None,
        fund_name='シンプレクス・ジャパン・バリューアップ・ファンド',
        fund_name_yomi='シンプレクスジャパンバリューアップファンド',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G05743': FundCodeEntry(
        fund_code='G05743',
        sec_code=None,
        fund_name='東京海上・東南アジア株式ファンド',
        fund_name_yomi='トウキョウカイジョウトウナンアジアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G05750': FundCodeEntry(
        fund_code='G05750',
        sec_code=None,
        fund_name='ＤＣダイワ・ターゲットイヤー２０２０',
        fund_name_yomi='ディーシーダイワターゲットイヤーニセンニジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05751': FundCodeEntry(
        fund_code='G05751',
        sec_code=None,
        fund_name='ＤＣダイワ・ターゲットイヤー２０３０',
        fund_name_yomi='ディーシーダイワターゲットイヤーニセンサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05752': FundCodeEntry(
        fund_code='G05752',
        sec_code=None,
        fund_name='ＤＣダイワ・ターゲットイヤー２０４０',
        fund_name_yomi='ディーシーダイワターゲットイヤーニセンヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G05757': FundCodeEntry(
        fund_code='G05757',
        sec_code=None,
        fund_name='ＤＣグローバル・リート・オープン',
        fund_name_yomi='ディーシーグローバルリートオープン',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05758': FundCodeEntry(
        fund_code='G05758',
        sec_code=None,
        fund_name='ＤＣニュー・チャイナ・ファンド',
        fund_name_yomi='ディーシーニューチャイナファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G05766': FundCodeEntry(
        fund_code='G05766',
        sec_code=None,
        fund_name='ＢＮＹメロン・ラージ・キャップ・セキュリティーズ・ファンド・インク',
        fund_name_yomi='ビーエヌワイ\u3000メロン\u3000ラージ\u3000キャップ\u3000セキュリティーズ\u3000ファンド\u3000インク',
        security_type='外国投資信託受益証券',
        period_1='1月1日',
        period_2=None,
        edinet_code='E14830',
        issuer_name='ＢＮＹメロン・ラージ・キャップ・セキュリティーズ・ファンド・インク',
    ),
    'G05769': FundCodeEntry(
        fund_code='G05769',
        sec_code=None,
        fund_name='インベスコ・ファンズ－インベスコ・サステイナブル・グローバル・システマティック・エクイティ・ファンド',
        fund_name_yomi='インベスコファンズインベスコサステイナブルグローバルシステマティックエクイティファンド',
        security_type='外国投資証券',
        period_1='3月1日',
        period_2=None,
        edinet_code='E14832',
        issuer_name='インベスコ・ファンズ',
    ),
    'G05771': FundCodeEntry(
        fund_code='G05771',
        sec_code=None,
        fund_name='デーヴェーエス・イーエスジー・インベスタ',
        fund_name_yomi='デーヴェーエス\u3000イーエスジー\u3000インベスタ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14834',
        issuer_name='ＤＷＳ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000ＧｍｂＨ',
    ),
    'G05773': FundCodeEntry(
        fund_code='G05773',
        sec_code=None,
        fund_name='デーヴェーエス・アーティフィシャル・インテリジェンス',
        fund_name_yomi='デーヴェーエス\u3000アーティフィシャル\u3000インテリジェンス',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E14834',
        issuer_name='ＤＷＳ\u3000Ｉｎｖｅｓｔｍｅｎｔ\u3000ＧｍｂＨ',
    ),
    'G05775': FundCodeEntry(
        fund_code='G05775',
        sec_code=None,
        fund_name='アライアンス・バーンスタインＳＩＣＡＶ－インターナショナル・テクノロジー・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインシカブインターナショナルテクノロジーポートフォリオ',
        security_type='外国投資証券',
        period_1='6月1日',
        period_2=None,
        edinet_code='E14837',
        issuer_name='アライアンス・バーンスタインＳＩＣＡＶ',
    ),
    'G05779': FundCodeEntry(
        fund_code='G05779',
        sec_code=None,
        fund_name='インダストリア',
        fund_name_yomi='インダストリア',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14840',
        issuer_name='アリアンツ・グローバル・インベスターズ・ゲーエムベーハー',
    ),
    'G05780': FundCodeEntry(
        fund_code='G05780',
        sec_code=None,
        fund_name='アライアンス・バーンスタインＳＩＣＡＶ－インターナショナル・ヘルス・ケア・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインシカブインターナショナルヘルスケアポートフォリオ',
        security_type='外国投資証券',
        period_1='6月1日',
        period_2=None,
        edinet_code='E14837',
        issuer_name='アライアンス・バーンスタインＳＩＣＡＶ',
    ),
    'G05789': FundCodeEntry(
        fund_code='G05789',
        sec_code=None,
        fund_name='ブラックロック・グローバル・インベストメント・シリーズ－スーパー・マネー・マーケット・ファンド',
        fund_name_yomi='ブラックロックグローバルインベストメントシリーズスーパーマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E31087',
        issuer_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
    ),
    'G05793': FundCodeEntry(
        fund_code='G05793',
        sec_code=None,
        fund_name='ノムラ外貨ＭＭＦ',
        fund_name_yomi='ノムラガイカエムエムエフ',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05794': FundCodeEntry(
        fund_code='G05794',
        sec_code=None,
        fund_name='ニッコウ・マネー・マーケット・ファンド',
        fund_name_yomi='ニッコウマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G05809': FundCodeEntry(
        fund_code='G05809',
        sec_code=None,
        fund_name='ダイワ外貨ＭＭＦ',
        fund_name_yomi='ダイワガイカエムエムエフ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14857',
        issuer_name='エスエムティー・ファンド・サービシーズ（アイルランド）リミテッド',
    ),
    'G05810': FundCodeEntry(
        fund_code='G05810',
        sec_code=None,
        fund_name='パトナム・ハイ・イールド・ファンド',
        fund_name_yomi='パトナム\u3000ハイ\u3000イールド\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='12月1日',
        period_2=None,
        edinet_code='E14863',
        issuer_name='パトナム・ハイ・イールド・ファンド',
    ),
    'G05817': FundCodeEntry(
        fund_code='G05817',
        sec_code=None,
        fund_name='アライアンス・バーンスタインーアメリカン・インカム・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインアメリカンインカムポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G05818': FundCodeEntry(
        fund_code='G05818',
        sec_code=None,
        fund_name='パトナム・ディバーシファイド・インカム・トラスト',
        fund_name_yomi='パトナムディバーシファイドインカムトラスト',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14867',
        issuer_name='パトナム・ディバーシファイド・インカム・トラスト',
    ),
    'G05821': FundCodeEntry(
        fund_code='G05821',
        sec_code=None,
        fund_name='パトナム・インカム・ファンド',
        fund_name_yomi='パトナム\u3000インカム\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14869',
        issuer_name='パトナム・インカム・ファンド',
    ),
    'G05822': FundCodeEntry(
        fund_code='G05822',
        sec_code=None,
        fund_name='外貨建マネー・マーケット・ファンド',
        fund_name_yomi='ガイカダテマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E41205',
        issuer_name='カーン・グローバル・ファンド・マネージャーズ（ルクセンブルグ）エス・エイ',
    ),
    'G05825': FundCodeEntry(
        fund_code='G05825',
        sec_code=None,
        fund_name='ブラックロック・グローバル・インベストメント・シリーズ－インカム・ストラテジー・ポートフォリオ',
        fund_name_yomi='ブラックロックグローバルインベストメントシリーズインカムストラテジーポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E31087',
        issuer_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
    ),
    'G05826': FundCodeEntry(
        fund_code='G05826',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－グローバル・ハイ・イールド・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタイングローバルハイイールドポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G05827': FundCodeEntry(
        fund_code='G05827',
        sec_code=None,
        fund_name='アリアンツ・ピムコ・ハイ・イールド・インカム・ファンド',
        fund_name_yomi='アリアンツピムコハイイールドインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14840',
        issuer_name='アリアンツ・グローバル・インベスターズ・ゲーエムベーハー',
    ),
    'G05831': FundCodeEntry(
        fund_code='G05831',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－ショート・デュレーション・ボンド・ポートフォリオ',
        fund_name_yomi='アライアンス\u3000バーンスタインショートデュレーションボンドポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G05833': FundCodeEntry(
        fund_code='G05833',
        sec_code=None,
        fund_name='アセット・バック・セキュリティーズ・ファンド',
        fund_name_yomi='アセットバックセキュリティーズファンド',
        security_type='外国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05836': FundCodeEntry(
        fund_code='G05836',
        sec_code=None,
        fund_name='マンスリー\u3000ディビデンド\u3000ハイ\u3000イールド\u3000ファンド',
        fund_name_yomi='マンスリーディビデンドハイイールドファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E14857',
        issuer_name='エスエムティー・ファンド・サービシーズ（アイルランド）リミテッド',
    ),
    'G05862': FundCodeEntry(
        fund_code='G05862',
        sec_code=None,
        fund_name='ノムラ・グローバル・セレクト・トラスト',
        fund_name_yomi='ノムラグローバルセレクトトラスト',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05886': FundCodeEntry(
        fund_code='G05886',
        sec_code=None,
        fund_name='ＵＢＳ\u3000（Ｌｕｘ）\u3000マネー・マーケット・ファンド',
        fund_name_yomi='ユービーエスルクスマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G05894': FundCodeEntry(
        fund_code='G05894',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ボンド・ファンド',
        fund_name_yomi='ユービーエスラックスボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G05911': FundCodeEntry(
        fund_code='G05911',
        sec_code=None,
        fund_name='ＧＳアメリカン・ボンド・インカム',
        fund_name_yomi='ジーエスアメリカンボンドインカム',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05912': FundCodeEntry(
        fund_code='G05912',
        sec_code=None,
        fund_name='ゴールドマン・サックス・ユニット・トラスト（アイルランド）－ゴールドマン・サックス・米ドルファンド',
        fund_name_yomi='ゴールドマンサックスユニットトラストアイルランドゴールドマンサックスベイドルファンド',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E34836',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント・ファンド・サービシズ・リミテッド',
    ),
    'G05921': FundCodeEntry(
        fund_code='G05921',
        sec_code=None,
        fund_name='ソル・ジャパン・ファンド',
        fund_name_yomi='ソルジャパンファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14915',
        issuer_name='スパークス・オーバーシーズ・リミテッド',
    ),
    'G05953': FundCodeEntry(
        fund_code='G05953',
        sec_code=None,
        fund_name='ジャナス・グローバル・テクノロジー・ファンド',
        fund_name_yomi='ジャナスグローバルテクノロジーファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05955': FundCodeEntry(
        fund_code='G05955',
        sec_code=None,
        fund_name='マン・ＡＨＬ・マイルストーン',
        fund_name_yomi='マンエーエッチエルマイルストーン',
        security_type='外国投資信託受益証券',
        period_1='4月1日',
        period_2=None,
        edinet_code='E14924',
        issuer_name='ＭＵＦＧルクスマネジメントカンパニーＳ．Ａ．',
    ),
    'G05956': FundCodeEntry(
        fund_code='G05956',
        sec_code=None,
        fund_name='ジャナス・グローバル・ライフサイエンス・ファンド',
        fund_name_yomi='ジャナスグローバルライフサイエンスファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G05966': FundCodeEntry(
        fund_code='G05966',
        sec_code=None,
        fund_name='バンガード・インデックス・ファンズ－バンガード・スモールキャップ・インデックス・ファンド',
        fund_name_yomi='バンガードインデックスファンズバンガードスモールキャップインデックスファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14945',
        issuer_name='バンガード・インデックス・ファンズ',
    ),
    'G05968': FundCodeEntry(
        fund_code='G05968',
        sec_code=None,
        fund_name='サノフィ・シェアーズ',
        fund_name_yomi='サノフィシェアーズ',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E35693',
        issuer_name='アムンディ・アセット・マネジメント',
    ),
    'G05971': FundCodeEntry(
        fund_code='G05971',
        sec_code=None,
        fund_name='バンガード・ウェルズリー・インカム・ファンド',
        fund_name_yomi='バンガードウェルズリーインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E33990',
        issuer_name='バンガード・ウェルズリー・インカム・ファンド',
    ),
    'G05985': FundCodeEntry(
        fund_code='G05985',
        sec_code=None,
        fund_name='バンガード・インデックス・ファンズーバンガード・トータル・ストック・マーケット・インデックス・ファンド',
        fund_name_yomi='バンガードインデックスファンズバンガードトータルストックマーケットインデックスファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14945',
        issuer_name='バンガード・インデックス・ファンズ',
    ),
    'G05999': FundCodeEntry(
        fund_code='G05999',
        sec_code=None,
        fund_name='ニッコウ・スキル・インベストメンツ・トラスト（ルクセンブルグ）',
        fund_name_yomi='ニッコウ\u3000スキル\u3000インベストメンツ\u3000トラスト\u3000ルクセンブルグ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G06003': FundCodeEntry(
        fund_code='G06003',
        sec_code=None,
        fund_name='アクサ・アクシオナリアＩＩ',
        fund_name_yomi='アクサアクシオナリアツー',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E14940',
        issuer_name='アクサ・インベストメント・マネージャーズ・パリ',
    ),
    'G06013': FundCodeEntry(
        fund_code='G06013',
        sec_code=None,
        fund_name='タワーＫ１Ｊファンド',
        fund_name_yomi='タワーケーワンジェーファンド',
        security_type='外国投資信託受益証券',
        period_1='4月1日',
        period_2=None,
        edinet_code='E14979',
        issuer_name='タワー・アセット・マネジメント・リミテッド',
    ),
    'G06014': FundCodeEntry(
        fund_code='G06014',
        sec_code=None,
        fund_name='ＪＡ－ＶＰチャイナ・ニュー・センチュリー・ファンド',
        fund_name_yomi='ジェイエイブイピーチャイナニューセンチュリーファンド',
        security_type='外国投資信託受益証券',
        period_1='1月1日',
        period_2=None,
        edinet_code='E14980',
        issuer_name='バリュー・パートナーズ・リミテッド',
    ),
    'G06066': FundCodeEntry(
        fund_code='G06066',
        sec_code=None,
        fund_name='ブラックロック・グローバル・ファンズ－アジアン・ドラゴン・ファンド',
        fund_name_yomi='ブラックロック\u3000グローバル\u3000ファンズ\u3000アジアンドラゴンファンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E31398',
        issuer_name='ブラックロック・グローバル・ファンズ',
    ),
    'G06072': FundCodeEntry(
        fund_code='G06072',
        sec_code=None,
        fund_name='ピムコ・バーミューダ・トラスト－ピムコ・ユーロ・トータル・リターン・ファンド',
        fund_name_yomi='ピムコバーミューダトラストピムコユーロトータルリターンファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G06082': FundCodeEntry(
        fund_code='G06082',
        sec_code=None,
        fund_name='シュローダー・セレクション',
        fund_name_yomi='シュローダーセレクション',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15044',
        issuer_name='シュローダー・インベストメント・マネージメント（ヨーロッパ）エス・エイ',
    ),
    'G06093': FundCodeEntry(
        fund_code='G06093',
        sec_code=None,
        fund_name='日興フィデリティ・グローバル・セレクション－ジャパン・アドバンテージ・ファンド',
        fund_name_yomi='ニッコウフィデリティグローバルセレクションジャパンアドバンテージファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31084',
        issuer_name='ＦＩＬ・インベストメント・マネジメント（ルクセンブルグ）エス・エイ・アール・エル',
    ),
    'G06097': FundCodeEntry(
        fund_code='G06097',
        sec_code=None,
        fund_name='ＨＳＢＣポートフォリオ・セレクション・ファンド',
        fund_name_yomi='エイチエスビーシーポートフォリオセレクションファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E31085',
        issuer_name='ＨＳＢＣマネジメント（ガーンジー）リミテッド',
    ),
    'G06109': FundCodeEntry(
        fund_code='G06109',
        sec_code=None,
        fund_name='ピムコ・バーミューダ・トラスト－ピムコ・リアル・リターン・ファンド',
        fund_name_yomi='ピムコバーミューダトラストピムコリアルリターンファンド',
        security_type='外国投資信託受益証券',
        period_1='5月31日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G06117': FundCodeEntry(
        fund_code='G06117',
        sec_code=None,
        fund_name='ＵＢＳオーストラリア・ボンド・インカム',
        fund_name_yomi='ユービーエスオーストラリアボンドインカム',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G06134': FundCodeEntry(
        fund_code='G06134',
        sec_code=None,
        fund_name='ＦＣファンド－レジット不動産証券投資信託',
        fund_name_yomi='エフシーファンドレジットフドウサンショウケントウシシンタク',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E15099',
        issuer_name='ＦＣインベストメント・リミテッド',
    ),
    'G06138': FundCodeEntry(
        fund_code='G06138',
        sec_code=None,
        fund_name='野村ＵＳハイ・イールド・ボンド・インカム',
        fund_name_yomi='ノムラユーエスハイ\u3000イールド\u3000ボンド\u3000インカム',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G06171': FundCodeEntry(
        fund_code='G06171',
        sec_code=None,
        fund_name='ブラックロック・グローバル・ファンズ－ワールド・ボンド・ファンド',
        fund_name_yomi='ブラックロックグローバルファンズワールドボンドファンド',
        security_type='外国投資証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E31398',
        issuer_name='ブラックロック・グローバル・ファンズ',
    ),
    'G06185': FundCodeEntry(
        fund_code='G06185',
        sec_code=None,
        fund_name='ビー・エヌ・ピー・パリバ・アクショナリア・モンド',
        fund_name_yomi='ビーエヌピーパリバアクショナリアモンド',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E15153',
        issuer_name='ビー・エヌ・ピー・パリバ\u3000アセットマネジメント・ヨーロッパ',
    ),
    'G06194': FundCodeEntry(
        fund_code='G06194',
        sec_code=None,
        fund_name='ダイワ・エクイティ・ファンド・シリーズ－ニュー・メジャー・エコノミーズ・ファンド',
        fund_name_yomi='ダイワエクイティファンドシリーズ\u3000ニューメジャーエコノミーズファンド',
        security_type='外国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E14857',
        issuer_name='エスエムティー・ファンド・サービシーズ（アイルランド）リミテッド',
    ),
    'G06200': FundCodeEntry(
        fund_code='G06200',
        sec_code=None,
        fund_name='日興グローバル・ＣＢ・ファンド',
        fund_name_yomi='ニッコウグローバルシービーファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14951',
        issuer_name='ＵＢＳオコーナー・エルエルシー',
    ),
    'G06217': FundCodeEntry(
        fund_code='G06217',
        sec_code=None,
        fund_name='ケープ・チャイナ・ファンド',
        fund_name_yomi='ケープチャイナファンド',
        security_type='外国投資信託受益証券',
        period_1='1月1日',
        period_2=None,
        edinet_code='E23274',
        issuer_name='ケープ・アセット・マネジメント・リミテッド',
    ),
    'G06220': FundCodeEntry(
        fund_code='G06220',
        sec_code=None,
        fund_name='ピクテ・グローバル・セレクション・ファンド－日興ピクテ・グローバル・グローイング・マーケット・ファンド',
        fund_name_yomi='ピクテ\u3000グローバル\u3000セレクション\u3000ファンド\u3000ニッコウピクテ\u3000グローバル\u3000グローイング\u3000マーケット\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30735',
        issuer_name='ピクテ・アセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G06233': FundCodeEntry(
        fund_code='G06233',
        sec_code=None,
        fund_name='日興\u3000フィデリティ・グローバル・セレクション－インド・アドバンテージ・ファンド',
        fund_name_yomi='ニッコウフィデリティグローバルセレクションインドアドバンテージファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31084',
        issuer_name='ＦＩＬ・インベストメント・マネジメント（ルクセンブルグ）エス・エイ・アール・エル',
    ),
    'G06236': FundCodeEntry(
        fund_code='G06236',
        sec_code=None,
        fund_name='フィデリティ・ワールド・ファンズ\u3000インド・フォーカス・ファンド',
        fund_name_yomi='フィデリティワールドファンズインドフォーカスファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31084',
        issuer_name='ＦＩＬ・インベストメント・マネジメント（ルクセンブルグ）エス・エイ・アール・エル',
    ),
    'G06261': FundCodeEntry(
        fund_code='G06261',
        sec_code=None,
        fund_name='ピムコ・バミューダ・トラストＩＩ－ピムコ・ワールド・ハイインカム',
        fund_name_yomi='ピムコバミューダトラストツー\u3000ピムコワールドハイインカム',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G06268': FundCodeEntry(
        fund_code='G06268',
        sec_code=None,
        fund_name='ピクテ・グローバル・セレクション・ファンド－好配当世界公共株ファンド',
        fund_name_yomi='ピクテグローバルセレクションファンド\u3000コウハイトウセカイコウキョウカブファンド',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E30735',
        issuer_name='ピクテ・アセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G06284': FundCodeEntry(
        fund_code='G06284',
        sec_code=None,
        fund_name='ＦＣ\u3000Ｔ\u3000トラスト\u3000－\u3000海通\u3000－\u3000アイザワ\u3000好配当利回り中国株ファンド',
        fund_name_yomi='エフシーテートラスト\u3000ハイトン\u3000アイザワ\u3000コウハイトウリマワリチュウゴクカブファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15099',
        issuer_name='ＦＣインベストメント・リミテッド',
    ),
    'G06291': FundCodeEntry(
        fund_code='G06291',
        sec_code=None,
        fund_name='ケイマン籍パトナム・ディバーシファイド・インカム・トラスト',
        fund_name_yomi='ケイマンセキパトナムディバーシファイドインカムトラスト',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E15262',
        issuer_name='ザ・パトナム・アドバイザリー・カンパニー・エルエルシー',
    ),
    'G06292': FundCodeEntry(
        fund_code='G06292',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－日興グローバル財産３分法ファンド',
        fund_name_yomi='ニッポンオフショアファンズニッコウグローバルザイサンサンブンポウファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G06297': FundCodeEntry(
        fund_code='G06297',
        sec_code=None,
        fund_name='アクサ・シェアプラン・ジャパン',
        fund_name_yomi='アクサシェアプランジャパン',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E14940',
        issuer_name='アクサ・インベストメント・マネージャーズ・パリ',
    ),
    'G06301': FundCodeEntry(
        fund_code='G06301',
        sec_code=None,
        fund_name='ノムラ・マルチ・カレンシー・ジャパン・ストック・ファンド',
        fund_name_yomi='ノムラ\u3000マルチ\u3000カレンシー\u3000ジャパン\u3000ストック\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G06303': FundCodeEntry(
        fund_code='G06303',
        sec_code=None,
        fund_name='リンク・リアル・エステート・インベストメント・トラスト',
        fund_name_yomi='リンクリアルエステートインベストメントトラスト',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E15194',
        issuer_name='リンク・アセット・マネジメント・リミテッド',
    ),
    'G06324': FundCodeEntry(
        fund_code='G06324',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ',
        fund_name_yomi='ユービーエスルクスキーセレクションシキャブ',
        security_type='外国投資証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15296',
        issuer_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ',
    ),
    'G06326': FundCodeEntry(
        fund_code='G06326',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－ＧＷ\u3000セレクト・ファンド\u3000安定型\u3000ＧＷ\u3000セレクト・ファンド\u3000積極型',
        fund_name_yomi='ニッポンオフショアファンズ\u3000ジーダブリューセレクトファンドアンテイガタ\u3000ジーダブリューセレクトファンドセッキョクガタ',
        security_type='外国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G06329': FundCodeEntry(
        fund_code='G06329',
        sec_code=None,
        fund_name='ＨＳＢＣユニ・フォリオ',
        fund_name_yomi='エイチエスビーシーユニフォリオ',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E31085',
        issuer_name='ＨＳＢＣマネジメント（ガーンジー）リミテッド',
    ),
    'G06340': FundCodeEntry(
        fund_code='G06340',
        sec_code=None,
        fund_name='マネックス\u3000ファンド・オブ・ファンズ\u3000シリーズⅠ－Ｍｏｎｅｘ－ＨＦＲ\u3000プライベートエクイティファンド＆ヘッジファンド・インベストメンツ\u3000２００６',
        fund_name_yomi='マネックスファンドオブファンズシリーズワンマネックスエイチエフアールプライベートエクイティファンドアンドヘッジファンドインベストメンツ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30019',
        issuer_name='バターフィールド・バンク（ケイマン）リミテッド',
    ),
    'G06343': FundCodeEntry(
        fund_code='G06343',
        sec_code=None,
        fund_name='ＦＣグローバル\u3000ベトナムファンド',
        fund_name_yomi='エフシーグローバルベトナムファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15099',
        issuer_name='ＦＣインベストメント・リミテッド',
    ),
    'G06356': FundCodeEntry(
        fund_code='G06356',
        sec_code=None,
        fund_name='日興グローバル・ファンズ',
        fund_name_yomi='ニッコウグローバルファンズ',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G06365': FundCodeEntry(
        fund_code='G06365',
        sec_code=None,
        fund_name='フィリップ－アイザワ\u3000トラスト\u3000タイファンド',
        fund_name_yomi='フィリップアイザワトラストタイファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15099',
        issuer_name='ＦＣインベストメント・リミテッド',
    ),
    'G06398': FundCodeEntry(
        fund_code='G06398',
        sec_code=None,
        fund_name='ＨＳＢＣオルタナティブ・ストラテジー・ファンド',
        fund_name_yomi='エイチエスビーシーオルタナティブストラテジーファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31085',
        issuer_name='ＨＳＢＣマネジメント（ガーンジー）リミテッド',
    ),
    'G06399': FundCodeEntry(
        fund_code='G06399',
        sec_code=None,
        fund_name='ＦＣ\u3000Ｔ\u3000トラスト－海通－アイザワ\u3000中国ナンバーワンファンド',
        fund_name_yomi='エフシーティートラスト\u3000ハイトン\u3000アイザワ\u3000チュウゴクナンバーワンファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15099',
        issuer_name='ＦＣインベストメント・リミテッド',
    ),
    'G06404': FundCodeEntry(
        fund_code='G06404',
        sec_code=None,
        fund_name='プレシャス・トラスト\u3000ベトナム・インフラストラクチャー・ファンド',
        fund_name_yomi='プレシャストラストベトナムインフラストラクチャーファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31086',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G06420': FundCodeEntry(
        fund_code='G06420',
        sec_code=None,
        fund_name='マネックス\u3000ファンド・オブ・ファンズシリ－ズＩ－Ｍｏｎｅｘ－ＨＦＲプライベ－トエクイティファンド＆ヘッジファンド・インベストメンツ２００７',
        fund_name_yomi='マネックスファンドオブファンズシリーズワンマネックスエイチエフアールプライベートエクイティファンドヘッジファンドインベストメンツ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30019',
        issuer_name='バターフィールド・バンク（ケイマン）リミテッド',
    ),
    'G06425': FundCodeEntry(
        fund_code='G06425',
        sec_code=None,
        fund_name='サムスンＫＯＤＥＸ２００\u3000証券上場指数投資信託［株式］',
        fund_name_yomi='サムスンコデックスニヒャク\u3000ショウケンジョウジョウシスウトウシシンタク\u3000カブシキ',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E15404',
        issuer_name='サムスン資産運用株式会社',
    ),
    'G06432': FundCodeEntry(
        fund_code='G06432',
        sec_code=None,
        fund_name='ゴールドマン・サックス・グローバル・ファンズ\u3000－ＧＳ新成長国通貨債券ファンド\u3000普通（米ドル建て）クラス受益証券、ユーロ・クラス受益証券、日本円クラス受益証券',
        fund_name_yomi='ゴールドマンサックスグローバルファンズ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E34836',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント・ファンド・サービシズ・リミテッド',
    ),
    'G06472': FundCodeEntry(
        fund_code='G06472',
        sec_code=None,
        fund_name='日亜持株組合',
        fund_name_yomi='ニチアモチカブクミアイ',
        security_type='内国有価証券投資事業権利等',
        period_1='4月30日',
        period_2=None,
        edinet_code='E15447',
        issuer_name='日亜持株組合',
    ),
    'G06565': FundCodeEntry(
        fund_code='G06565',
        sec_code=None,
        fund_name='ジャフコ・スーパーＶ３‐Ａ号投資事業有限責任組合、ジャフコ・スーパーＶ３‐Ｂ号投資事業有限責任組合及びジャフコ・スーパーＶ３‐Ｐ号投資事業有限責任組合',
        fund_name_yomi='ジャフコスーパーヴイスリーエービーピー',
        security_type='内国有価証券投資事業権利等',
        period_1='12月31日',
        period_2=None,
        edinet_code='E04806',
        issuer_name='ジャフコ\u3000グループ株式会社',
    ),
    'G06756': FundCodeEntry(
        fund_code='G06756',
        sec_code=None,
        fund_name='浪花おふくろファンド',
        fund_name_yomi='ナニワオフクロファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E15786',
        issuer_name='株式会社パリミキアセットマネジメント',
    ),
    'G06758': FundCodeEntry(
        fund_code='G06758',
        sec_code=None,
        fund_name='ＤＩＡＭエマージング債券ファンド',
        fund_name_yomi='ダイアムエマージングサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G06761': FundCodeEntry(
        fund_code='G06761',
        sec_code=None,
        fund_name='スパークス・新・国際優良日本株ファンド',
        fund_name_yomi='スパークス\u3000シン\u3000コクサイユウリョウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G06762': FundCodeEntry(
        fund_code='G06762',
        sec_code=None,
        fund_name='ダイワ・ブラジル株式ファンド',
        fund_name_yomi='ダイワブラジルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G06775': FundCodeEntry(
        fund_code='G06775',
        sec_code=None,
        fund_name='ＧＳエマージング通貨債券ファンド',
        fund_name_yomi='ジーエスエマージングツウカサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G06779': FundCodeEntry(
        fund_code='G06779',
        sec_code=None,
        fund_name='ダイワ・エマージング高金利債券ファンド（毎月分配型）',
        fund_name_yomi='ダイワエマージングコウキンリサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G06781': FundCodeEntry(
        fund_code='G06781',
        sec_code='16170',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000食品（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ショクヒン\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06782': FundCodeEntry(
        fund_code='G06782',
        sec_code='16180',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000エネルギー資源（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000エネルギーシゲン\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06783': FundCodeEntry(
        fund_code='G06783',
        sec_code='16190',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000建設・資材（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ケンセツ\u3000シザイ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06784': FundCodeEntry(
        fund_code='G06784',
        sec_code='16200',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000素材・化学（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ソザイ\u3000カガク\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06785': FundCodeEntry(
        fund_code='G06785',
        sec_code='16210',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000医薬品（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000イヤクヒン\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06786': FundCodeEntry(
        fund_code='G06786',
        sec_code='16220',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000自動車・輸送機（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ジドウシャ\u3000ユソウキ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06787': FundCodeEntry(
        fund_code='G06787',
        sec_code='16230',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000鉄鋼・非鉄（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000テッコウ\u3000ヒテツ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06788': FundCodeEntry(
        fund_code='G06788',
        sec_code='16240',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000機械（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000キカイ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06789': FundCodeEntry(
        fund_code='G06789',
        sec_code='16250',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000電機・精密（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000デンキ\u3000セイミツ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06790': FundCodeEntry(
        fund_code='G06790',
        sec_code='16260',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000情報通信・サービスその他（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ジョウホウツウシン\u3000サービスソノタ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06791': FundCodeEntry(
        fund_code='G06791',
        sec_code='16270',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000電力・ガス（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000デンリョク\u3000ガス\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06792': FundCodeEntry(
        fund_code='G06792',
        sec_code='16280',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000運輸・物流（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ウンユ\u3000ブツリュウ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06793': FundCodeEntry(
        fund_code='G06793',
        sec_code='16290',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000商社・卸売（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ショウシャ\u3000オロシウリ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06794': FundCodeEntry(
        fund_code='G06794',
        sec_code='16300',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000小売（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000コウリ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06795': FundCodeEntry(
        fund_code='G06795',
        sec_code='16310',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000銀行（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000ギンコウ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06796': FundCodeEntry(
        fund_code='G06796',
        sec_code='16320',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000金融（除く銀行）（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000キンユウ\u3000ノゾクギンコウ\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06797': FundCodeEntry(
        fund_code='G06797',
        sec_code='16330',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000不動産（ＴＯＰＩＸ－１７）上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000フドウサン\u3000トピックス\u3000ジュウナナ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G06808': FundCodeEntry(
        fund_code='G06808',
        sec_code=None,
        fund_name='ＳＭＡＭ・グローバルバランスファンド（機動的資産配分型）',
        fund_name_yomi='エスエムエーエムグローバルバランスファンドキドウテキシサンハイブンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06809': FundCodeEntry(
        fund_code='G06809',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０２０（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロニイゼロヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06810': FundCodeEntry(
        fund_code='G06810',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０２５（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロニイゴヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06811': FundCodeEntry(
        fund_code='G06811',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０３０（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロサンゼロヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06812': FundCodeEntry(
        fund_code='G06812',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０３５（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロサンゴヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06813': FundCodeEntry(
        fund_code='G06813',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０４０（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロヨンゼロヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06814': FundCodeEntry(
        fund_code='G06814',
        sec_code=None,
        fund_name='三井住友・ＤＣターゲットイヤーファンド２０４５（４資産タイプ）',
        fund_name_yomi='ミツイスミトモディーシーターゲットイヤーファンドニイゼロヨンゴヨンシサンタイプ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G06815': FundCodeEntry(
        fund_code='G06815',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000世界国債インデックスファンド（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイセカイコクサイインデックスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G06820': FundCodeEntry(
        fund_code='G06820',
        sec_code='13220',
        fund_name='上場インデックスファンド中国Ａ株（パンダ）Ｅ\u3000Ｆｕｎｄ\u3000ＣＳＩ３００',
        fund_name_yomi='ジョウジョウインデックスファンドチュウゴクエーカブ\u3000パンダ\u3000イー\u3000ファンド\u3000シーエスアイサンビャク',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06821': FundCodeEntry(
        fund_code='G06821',
        sec_code=None,
        fund_name='インデックスファンド海外新興国（エマージング）株式',
        fund_name_yomi='インデックスファンドカイガイシンコウコク\u3000エマージング\u3000カブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06822': FundCodeEntry(
        fund_code='G06822',
        sec_code=None,
        fund_name='インデックスファンド海外新興国（エマージング）債券（１年決算型）',
        fund_name_yomi='インデックスファンドカイガイシンコウコク\u3000エマージング\u3000サイケン\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06835': FundCodeEntry(
        fund_code='G06835',
        sec_code=None,
        fund_name='ＤＩＡＭアジア消費＆インフラ関連株式ファンド',
        fund_name_yomi='ダイアムアジアショウヒアンドインフラカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G06836': FundCodeEntry(
        fund_code='G06836',
        sec_code=None,
        fund_name='ラッセル・インベストメント世界環境テクノロジー・ファンド',
        fund_name_yomi='ラッセルインベストメントセカイカンキョウテクノロジーファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G06839': FundCodeEntry(
        fund_code='G06839',
        sec_code=None,
        fund_name='損保ジャパン・エコ・オープン（配当利回り重視型）',
        fund_name_yomi='ソンポジャパン\u3000エコ\u3000オープン\u3000ハイトウリマワリジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G06849': FundCodeEntry(
        fund_code='G06849',
        sec_code=None,
        fund_name='日興高金利通貨ファンド（毎月分配型）',
        fund_name_yomi='ニッコウコウキンリツウカファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06850': FundCodeEntry(
        fund_code='G06850',
        sec_code=None,
        fund_name='日興高金利通貨ファンド（資産成長型）',
        fund_name_yomi='ニッコウコウキンリツウカファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06853': FundCodeEntry(
        fund_code='G06853',
        sec_code=None,
        fund_name='好配当グリーン・バランス・オープン',
        fund_name_yomi='コウハイトウグリーン\u3000バランス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G06856': FundCodeEntry(
        fund_code='G06856',
        sec_code=None,
        fund_name='ニッセイ健康応援ファンド',
        fund_name_yomi='ニッセイケンコウオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G06861': FundCodeEntry(
        fund_code='G06861',
        sec_code=None,
        fund_name='イーストスプリング・インド消費関連ファンド',
        fund_name_yomi='イーストスプリングインドショウヒカンレンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G06902': FundCodeEntry(
        fund_code='G06902',
        sec_code=None,
        fund_name='ダイワ・インド株ファンド',
        fund_name_yomi='ダイワインドカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G06904': FundCodeEntry(
        fund_code='G06904',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ロシア・ルーブル債券投信（毎月分配型）／（年２回決算型）',
        fund_name_yomi='ディーダブリューエスロシアルーブルサイケントウシンマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G06907': FundCodeEntry(
        fund_code='G06907',
        sec_code=None,
        fund_name='日興ジャパン高配当株式ファンド',
        fund_name_yomi='ニッコウジャパンコウハイトウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06913': FundCodeEntry(
        fund_code='G06913',
        sec_code=None,
        fund_name='ダイワ・アクティブＪリート・ファンド（年４回決算型）',
        fund_name_yomi='ダイワアクティブジェイリートファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G06934': FundCodeEntry(
        fund_code='G06934',
        sec_code=None,
        fund_name='アムンディ・中東株式ファンド',
        fund_name_yomi='アムンディチュウトウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G06941': FundCodeEntry(
        fund_code='G06941',
        sec_code=None,
        fund_name='ダイワ／“ＲＩＣＩ”コモディティ・ファンド',
        fund_name_yomi='ダイワアールアイシーアイコモディティファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G06946': FundCodeEntry(
        fund_code='G06946',
        sec_code=None,
        fund_name='ノムラ・マルチ・カレンシー・アトラクティブ・ディビデンド・ジャパン・ストック・ファンド',
        fund_name_yomi='ノムラ\u3000マルチ\u3000カレンシー\u3000アトラクティブ\u3000ディビデンド\u3000ジャパン\u3000ストック\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E15291',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G06953': FundCodeEntry(
        fund_code='G06953',
        sec_code=None,
        fund_name='Ｓ＆Ｐ\u3000ＧＳＣＩ商品指数（Ｒ）エネルギー＆メタル・キャップド・コンポーネント３５／２０・ＴＨＥＡＭ・イージーＵＣＩＴＳ・ＥＴＦ',
        fund_name_yomi='エスアンドピージーエスシーアイショウヒンシスウエネルギーアンドメタルキャップドコンポーネントサンジュウゴニジュウテアムイージーユーシッツイーティーエフ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E21176',
        issuer_name='ＢＮＰパリバ・アセットマネジメント・ルクセンブルク',
    ),
    'G06955': FundCodeEntry(
        fund_code='G06955',
        sec_code=None,
        fund_name='ピクテ資源国ソブリン・ファンド（毎月分配型）',
        fund_name_yomi='ピクテシゲンコクソブリンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G06956': FundCodeEntry(
        fund_code='G06956',
        sec_code=None,
        fund_name='ブラジル株式ファンド',
        fund_name_yomi='ブラジルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G06957': FundCodeEntry(
        fund_code='G06957',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ロシア株式ファンド',
        fund_name_yomi='ディーダブリューエス\u3000ロシアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G06964': FundCodeEntry(
        fund_code='G06964',
        sec_code=None,
        fund_name='アイガー・ファンドシリーズ‐ＥＭＦ（エマージング・マネー・ファンド）',
        fund_name_yomi='アイガーファンドシリーズ\u3000イーエムエフエマージングマネーファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E15255',
        issuer_name='アイガー・マネジメント・リミテッド',
    ),
    'G06982': FundCodeEntry(
        fund_code='G06982',
        sec_code=None,
        fund_name='ＨＳＢＣブラジル株式ファンド（３ヶ月決算型）',
        fund_name_yomi='エイチエスビーシーブラジルカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G06987': FundCodeEntry(
        fund_code='G06987',
        sec_code=None,
        fund_name='ＵＢＳブラジル・インデックス・ファンド',
        fund_name_yomi='ユービーエスブラジルインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G06988': FundCodeEntry(
        fund_code='G06988',
        sec_code=None,
        fund_name='ＵＢＳブラジル・レアル債券投信（毎月分配型）／（年２回決算型）',
        fund_name_yomi='ユービーエス\u3000ブラジル\u3000レアル\u3000サイケントウシン\u3000マイツキブンパイガタ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G07016': FundCodeEntry(
        fund_code='G07016',
        sec_code='13260',
        fund_name='ＳＰＤＲゴールド・トラスト',
        fund_name_yomi='エスピーディーアールゴールドトラスト',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E21414',
        issuer_name='ワールド・ゴールド・トラスト・サービシズ・エルエルシー',
    ),
    'G07017': FundCodeEntry(
        fund_code='G07017',
        sec_code='13250',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブラジル株式指数・ボベスパ連動型上場投信',
        fund_name_yomi='ネクストファンズブラジルカブシキシスウボベスパレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07018': FundCodeEntry(
        fund_code='G07018',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ロシア株式指数連動型上場投信',
        fund_name_yomi='ネクストファンズロシアカブシキシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07019': FundCodeEntry(
        fund_code='G07019',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000南アフリカ株式指数・ＦＴＳＥ／ＪＳＥ\u3000Ａｆｒｉｃａ\u3000Ｔｏｐ４０連動型上場投信',
        fund_name_yomi='ネクストファンズミナミアフリカカブシキシスウエフティーエスイージェイエスイーアフリカトップフォーティレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07023': FundCodeEntry(
        fund_code='G07023',
        sec_code=None,
        fund_name='野村外国債券アクティブファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラガイコクサイケンアクティブファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07024': FundCodeEntry(
        fund_code='G07024',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴインデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラセカイリートインデックスファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07032': FundCodeEntry(
        fund_code='G07032',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000世界高金利通貨投信（毎月分配型）／（年２回決算型）',
        fund_name_yomi='モルガンスタンレーセカイコウキンリツウカトウシンマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E08707',
        issuer_name='モルガン・スタンレー・インベストメント・マネジメント株式会社',
    ),
    'G07041': FundCodeEntry(
        fund_code='G07041',
        sec_code=None,
        fund_name='野村新興国株式インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラシンコウコクカブシキインデックスファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07042': FundCodeEntry(
        fund_code='G07042',
        sec_code=None,
        fund_name='野村新興国債券インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラシンコウコクサイケンインデックスファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07059': FundCodeEntry(
        fund_code='G07059',
        sec_code=None,
        fund_name='欧州ハイ・イールド・ボンド・ファンド（欧州通貨コース）、欧州ハイ・イールド・ボンド・ファンド（円コース）、欧州ハイ・イールド・ボンド・ファンド（豪ドルコース）',
        fund_name_yomi='オウシュウハイイールドボンドファンドオウシュウツウカコース\u3000オウシュウハイイールドボンドファンドエンコース\u3000オウシュウハイイールドボンドファンドゴウドルコース',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07083': FundCodeEntry(
        fund_code='G07083',
        sec_code=None,
        fund_name='オーストラリア株式ファンド',
        fund_name_yomi='オーストラリアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07088': FundCodeEntry(
        fund_code='G07088',
        sec_code=None,
        fund_name='金銭信託（予定配当率固定型）第１受益権',
        fund_name_yomi='キンセンシンタクヨテイハイトウリツコテイガタダイイチジュエキケン',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G07089': FundCodeEntry(
        fund_code='G07089',
        sec_code=None,
        fund_name='金銭信託（自由型）',
        fund_name_yomi='キンセンシンタクジユウガタ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G07095': FundCodeEntry(
        fund_code='G07095',
        sec_code=None,
        fund_name='ひふみ投信',
        fund_name_yomi='ヒフミトウシン',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G07104': FundCodeEntry(
        fund_code='G07104',
        sec_code=None,
        fund_name='ＨＳＢＣブラジル債券オープン（毎月決算型）',
        fund_name_yomi='エイチエスビーシーブラジルサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G07106': FundCodeEntry(
        fund_code='G07106',
        sec_code=None,
        fund_name='ＨＳＢＣブラジル債券オープン（１年決算型）',
        fund_name_yomi='エイチエスビシーブラジルサイケンオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G07112': FundCodeEntry(
        fund_code='G07112',
        sec_code='13430',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000東証ＲＥＩＴ指数連動型上場投信',
        fund_name_yomi='ネクスト\u3000ファンズ\u3000トウショウリートシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07113': FundCodeEntry(
        fund_code='G07113',
        sec_code=None,
        fund_name='ＤＩＡＭ高格付インカム・オープン（１年決算コース）',
        fund_name_yomi='ダイアムコウカクヅケインカムオープンイチネンケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07114': FundCodeEntry(
        fund_code='G07114',
        sec_code=None,
        fund_name='ＤＩＡＭ高格付外債ファンド',
        fund_name_yomi='ダイアムコウカクヅケガイサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07124': FundCodeEntry(
        fund_code='G07124',
        sec_code=None,
        fund_name='ユニオンファンド',
        fund_name_yomi='ユニオンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E21708',
        issuer_name='ユニオン投信株式会社',
    ),
    'G07127': FundCodeEntry(
        fund_code='G07127',
        sec_code=None,
        fund_name='ダイワ世界債券ファンド（毎月分配型）',
        fund_name_yomi='ダイワセカイサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07128': FundCodeEntry(
        fund_code='G07128',
        sec_code=None,
        fund_name='ダイワ・グローバル債券ファンド（毎月分配型／年２回決算型）',
        fund_name_yomi='ダイワグローバルサイケンファンドマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07140': FundCodeEntry(
        fund_code='G07140',
        sec_code=None,
        fund_name='ニュース\u3000ＦＰＴ\u3000キャピタル\u3000トラスト\u3000ベトナム\u3000バランス\u3000ファンド',
        fund_name_yomi='ニュース\u3000エフピーティー\u3000キャピタル\u3000トラスト\u3000ベトナム\u3000バランス\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E27577',
        issuer_name='ＦＰＴファンド・マネジメント・ジョイント・ストック・カンパニー',
    ),
    'G07151': FundCodeEntry(
        fund_code='G07151',
        sec_code=None,
        fund_name='ブラデスコ\u3000ブラジル債券ファンド（分配重視型）\u3000ブラデスコ\u3000ブラジル債券ファンド（成長重視型）',
        fund_name_yomi='ブラデスコブラジルサイケンファンドブンパイジュウシガタブラデスコブラジルサイケンファンドセイチョウジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07185': FundCodeEntry(
        fund_code='G07185',
        sec_code=None,
        fund_name='ダイワ海外ソブリン・ファンド（１年決算型）',
        fund_name_yomi='ダイワカイガイソブリンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07194': FundCodeEntry(
        fund_code='G07194',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・ブラジル国債ファンド（毎月分配型）\u3000フランクリン・テンプルトン・ブラジル国債ファンド（年２回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ブラジルコクサイファンド\u3000マイツキブンパイガタ\u3000フランクリン\u3000テンプルトン\u3000ブラジルコクサイファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G07202': FundCodeEntry(
        fund_code='G07202',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ブラジル・レアル債券ファンド（年１回決算型）',
        fund_name_yomi='ディーダブリューエスブラジルレアルサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07203': FundCodeEntry(
        fund_code='G07203',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ブラジル・レアル債券ファンド（毎月分配型）',
        fund_name_yomi='ディーダブリューエスブラジルレアルサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07207': FundCodeEntry(
        fund_code='G07207',
        sec_code=None,
        fund_name='ワールド・ソブリンインカム（１年決算型）（愛称\u3000十二単衣（１年決算型））',
        fund_name_yomi='ワールドソブリンインカムイチネンケッサンガタ\u3000アイショウジュウニヒトエイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G07208': FundCodeEntry(
        fund_code='G07208',
        sec_code='13450',
        fund_name='上場インデックスファンドＪリート（東証ＲＥＩＴ指数）隔月分配型',
        fund_name_yomi='ジョウジョウインデックスファンドジェイリートトウショウリートシスウカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07211': FundCodeEntry(
        fund_code='G07211',
        sec_code=None,
        fund_name='りそな\u3000ブラジル・ソブリン・ファンド（毎月決算型／年２回決算型）',
        fund_name_yomi='リソナブラジルソブリンファンドマイツキケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07216': FundCodeEntry(
        fund_code='G07216',
        sec_code=None,
        fund_name='ダイワ・ブラジル・レアル債オープン（毎月分配型／年２回決算型）',
        fund_name_yomi='ダイワブラジルレアルサイオープンマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07217': FundCodeEntry(
        fund_code='G07217',
        sec_code=None,
        fund_name='ブラジル・ボンド・オープン（毎月決算型／年２回決算型）',
        fund_name_yomi='ブラジルボンドオープンマイツキケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07218': FundCodeEntry(
        fund_code='G07218',
        sec_code=None,
        fund_name='ハイグレード・オセアニア・ボンド・オープン（年２回決算型）',
        fund_name_yomi='ハイグレードオセアニアボンドオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07220': FundCodeEntry(
        fund_code='G07220',
        sec_code=None,
        fund_name='スパークス・アジア中東株式ファンド（資産成長型）',
        fund_name_yomi='スパークス\u3000アジア\u3000チュウトウカブシキファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G07224': FundCodeEntry(
        fund_code='G07224',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（１年決算型）',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G07253': FundCodeEntry(
        fund_code='G07253',
        sec_code=None,
        fund_name='高金利先進国債券オープン（資産成長型）',
        fund_name_yomi='コウキンリセンシンコクサイケンオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07254': FundCodeEntry(
        fund_code='G07254',
        sec_code=None,
        fund_name='世界のサイフ（資産成長型）',
        fund_name_yomi='セカイノサイフシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07255': FundCodeEntry(
        fund_code='G07255',
        sec_code=None,
        fund_name='日興スリートップ（資産成長型）',
        fund_name_yomi='ニッコウスリートップシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07256': FundCodeEntry(
        fund_code='G07256',
        sec_code=None,
        fund_name='日興ピムコ・ハイインカム・ソブリン・ファンド資産成長型（米ドルコース）',
        fund_name_yomi='ニッコウピムコハイインカムソブリンファンドシサンセイチョウガタベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07257': FundCodeEntry(
        fund_code='G07257',
        sec_code=None,
        fund_name='日興グローバルＲＥＩＴファンド資産成長型（ヘッジなし）',
        fund_name_yomi='ニッコウグローバルリートファンドシサンセイチョウガタヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07258': FundCodeEntry(
        fund_code='G07258',
        sec_code=None,
        fund_name='世界高配当株式ファンド（資産成長型）',
        fund_name_yomi='セカイコウハイトウカブシキファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月18日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07261': FundCodeEntry(
        fund_code='G07261',
        sec_code=None,
        fund_name='ＪＰＭジャパン・フォーカス・ファンド',
        fund_name_yomi='ジェイピーエムジャパンフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月27日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G07264': FundCodeEntry(
        fund_code='G07264',
        sec_code=None,
        fund_name='ホライズン・トラスト－南アフリカ・ランド・マネー・マーケット・ファンド',
        fund_name_yomi='ホライズントラストミナミアフリカランドマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E21970',
        issuer_name='ＵＴＩインターナショナル（シンガポール）・プライベート・リミテッド',
    ),
    'G07265': FundCodeEntry(
        fund_code='G07265',
        sec_code=None,
        fund_name='高金利国際機関債ファンド（毎月決算型）',
        fund_name_yomi='コウキンリコクサイキカンサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G07270': FundCodeEntry(
        fund_code='G07270',
        sec_code=None,
        fund_name='ダイヤセレクト日本株オープン',
        fund_name_yomi='ダイヤセレクトニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07298': FundCodeEntry(
        fund_code='G07298',
        sec_code=None,
        fund_name='ニッセイ高金利国債券ファンド（１年決算型）',
        fund_name_yomi='ニッセイコウキンリコクサイケンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G07309': FundCodeEntry(
        fund_code='G07309',
        sec_code=None,
        fund_name='ＳＭＴ\u3000新興国株式インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000シンコウコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07310': FundCodeEntry(
        fund_code='G07310',
        sec_code=None,
        fund_name='ＳＭＴ\u3000新興国債券インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000シンコウコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07313': FundCodeEntry(
        fund_code='G07313',
        sec_code=None,
        fund_name='フィデリティ・グローバル・ハイ・イールド・ファンド（毎月決算型）',
        fund_name_yomi='フィデリティグローバルハイイールドファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G07316': FundCodeEntry(
        fund_code='G07316',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ',
        fund_name_yomi='ユービーエス\u3000ルクス\u3000ボンド\u3000シキャブ',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E22239',
        issuer_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ',
    ),
    'G07317': FundCodeEntry(
        fund_code='G07317',
        sec_code=None,
        fund_name='コモンズ３０ファンド',
        fund_name_yomi='コモンズサーティファンド',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E22096',
        issuer_name='コモンズ投信株式会社',
    ),
    'G07319': FundCodeEntry(
        fund_code='G07319',
        sec_code=None,
        fund_name='野村世界高格付債券投信（年２回決算型）',
        fund_name_yomi='ノムラセカイコウカクヅケサイケントウシンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07359': FundCodeEntry(
        fund_code='G07359',
        sec_code=None,
        fund_name='野村米国ハイ・イールド債券投信（通貨選択型）',
        fund_name_yomi='ノムラベイコクハイイールドサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07360': FundCodeEntry(
        fund_code='G07360',
        sec_code=None,
        fund_name='マネー\u3000セレクト\u3000トラスト\u3000南アフリカ\u3000ランド\u3000ファンド',
        fund_name_yomi='マネー\u3000セレクト\u3000トラスト\u3000ミナミアフリカ\u3000ランド\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E26445',
        issuer_name='マスター・トラスト・カンパニー',
    ),
    'G07361': FundCodeEntry(
        fund_code='G07361',
        sec_code=None,
        fund_name='世界経済インデックスファンド',
        fund_name_yomi='セカイケイザイインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07362': FundCodeEntry(
        fund_code='G07362',
        sec_code=None,
        fund_name='Ｊリートインデックス・オープン（ＳＭＡ専用）',
        fund_name_yomi='ジェイリートインデックスオープンエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07363': FundCodeEntry(
        fund_code='G07363',
        sec_code=None,
        fund_name='グローバルリートインデックス・オープン（ＳＭＡ専用）',
        fund_name_yomi='グローバルリートインデックスオープンエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07364': FundCodeEntry(
        fund_code='G07364',
        sec_code=None,
        fund_name='コモディティ・オープン（ＳＭＡ専用）',
        fund_name_yomi='コモディティオープンエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07366': FundCodeEntry(
        fund_code='G07366',
        sec_code=None,
        fund_name='中小型株式オープン（ＳＭＡ専用）',
        fund_name_yomi='チュウコガタカブシキオープンエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07367': FundCodeEntry(
        fund_code='G07367',
        sec_code=None,
        fund_name='ピクテ日本ナンバーワン・ファンド（毎月決算実績分配型）',
        fund_name_yomi='ピクテニホンナンバーワンファンドマイツキケッサンジッセキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G07380': FundCodeEntry(
        fund_code='G07380',
        sec_code=None,
        fund_name='ＤＩＡＭコモディティパッシブ・ファンド',
        fund_name_yomi='ダイアムコモディティパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07381': FundCodeEntry(
        fund_code='G07381',
        sec_code=None,
        fund_name='ＤＩＡＭ国内債券パッシブ・ファンド',
        fund_name_yomi='ダイアムコクナイサイケンパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月13日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07382': FundCodeEntry(
        fund_code='G07382',
        sec_code=None,
        fund_name='ＤＩＡＭ国内株式パッシブ・ファンド',
        fund_name_yomi='ダイアムコクナイカブシキパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月13日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07383': FundCodeEntry(
        fund_code='G07383',
        sec_code=None,
        fund_name='ＤＩＡＭ外国株式パッシブ・ファンド',
        fund_name_yomi='ダイアムガイコクカブシキパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07384': FundCodeEntry(
        fund_code='G07384',
        sec_code=None,
        fund_name='ＤＩＡＭ外国債券パッシブ・ファンド',
        fund_name_yomi='ダイアムガイコクサイケンパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07403': FundCodeEntry(
        fund_code='G07403',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ワールド・ファンズ―ＤＷＳ\u3000南アフリカ・ランド・短期債・ファンド',
        fund_name_yomi='ディーダブリューエスワールドファンズディーダブリューエスミナミアフリカランドタンキサイファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14961',
        issuer_name='ＤＷＳインベストメント・エス・エー',
    ),
    'G07406': FundCodeEntry(
        fund_code='G07406',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000国内債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07407': FundCodeEntry(
        fund_code='G07407',
        sec_code=None,
        fund_name='みずほ好配当日本株オープン（ノーロード型）',
        fund_name_yomi='ミズホコウハイトウニホンカブオープン\u3000ノーロードガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G07410': FundCodeEntry(
        fund_code='G07410',
        sec_code=None,
        fund_name='キャピタル日本株式ファンド',
        fund_name_yomi='キャピタルニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G07417': FundCodeEntry(
        fund_code='G07417',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・日本プレミア・バリュー株投信',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000ニホン\u3000プレミア\u3000バリューカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G07420': FundCodeEntry(
        fund_code='G07420',
        sec_code=None,
        fund_name='ブラジル株式オープン',
        fund_name_yomi='ブラジルカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07428': FundCodeEntry(
        fund_code='G07428',
        sec_code='13460',
        fund_name='ＭＡＸＩＳ\u3000日経２２５上場投信',
        fund_name_yomi='マクシスニッケイニイニイゴジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07434': FundCodeEntry(
        fund_code='G07434',
        sec_code=None,
        fund_name='優良日本株ファンド',
        fund_name_yomi='ユウリョウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07438': FundCodeEntry(
        fund_code='G07438',
        sec_code=None,
        fund_name='ＪＰＭ日本債券アルファ',
        fund_name_yomi='ジェイピーエムニホンサイケンアルファ',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G07451': FundCodeEntry(
        fund_code='G07451',
        sec_code=None,
        fund_name='ダイワ外国債券ファンド（毎月分配型）－ダイワスピリット－',
        fund_name_yomi='ダイワガイコクサイケンファンドマイツキブンパイガタダイワスピリット',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07453': FundCodeEntry(
        fund_code='G07453',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・インベストメント・ファンド',
        fund_name_yomi='エイチエスビーシーグローバルインベストメントファンド',
        security_type='外国投資証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E22760',
        issuer_name='ＨＳＢＣグローバル・インベストメント・ファンド',
    ),
    'G07460': FundCodeEntry(
        fund_code='G07460',
        sec_code=None,
        fund_name='ベトナム株ノーロードファンド',
        fund_name_yomi='ベトナムカブノーロードファンド',
        security_type='内国有価証券投資事業権利等',
        period_1='2月末日',
        period_2=None,
        edinet_code='E22658',
        issuer_name='グローバルリンクアドバイザーズ株式会社',
    ),
    'G07461': FundCodeEntry(
        fund_code='G07461',
        sec_code=None,
        fund_name='ベトナム株ノーロードファンド２',
        fund_name_yomi='ベトナムカブノーロードファンドニ',
        security_type='内国有価証券投資事業権利等',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22658',
        issuer_name='グローバルリンクアドバイザーズ株式会社',
    ),
    'G07464': FundCodeEntry(
        fund_code='G07464',
        sec_code=None,
        fund_name='損保ジャパン・グローバルＲＥＩＴファンド（毎月分配型）',
        fund_name_yomi='ソンポジャパン\u3000グローバル\u3000リート\u3000ファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G07466': FundCodeEntry(
        fund_code='G07466',
        sec_code=None,
        fund_name='ＨＳＢＣ中国クオリティ株式オープン',
        fund_name_yomi='エイチエスビーシーチュウゴククオリティカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G07467': FundCodeEntry(
        fund_code='G07467',
        sec_code=None,
        fund_name='ＨＳＢＣ中国クオリティ株式ファンド（３ヶ月決算型）',
        fund_name_yomi='エイチエスビーシーチュウゴククオリティカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G07471': FundCodeEntry(
        fund_code='G07471',
        sec_code=None,
        fund_name='三井住友・米国ハイ・イールド債券ファンド（為替ヘッジ型）',
        fund_name_yomi='ミツイスミトモベイコクハイイールドサイケンファンドカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07472': FundCodeEntry(
        fund_code='G07472',
        sec_code=None,
        fund_name='三井住友・米国ハイ・イールド債券ファンド（為替ノーヘッジ型）',
        fund_name_yomi='ミツイスミトモベイコクハイイールドサイケンファンドカワセノーヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07473': FundCodeEntry(
        fund_code='G07473',
        sec_code=None,
        fund_name='野村日本ブランド株投資（通貨選択型）',
        fund_name_yomi='ノムラニホンブランドカブトウシツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07477': FundCodeEntry(
        fund_code='G07477',
        sec_code=None,
        fund_name='ダイワ／ロジャーズ国際コモディティ・ファンド',
        fund_name_yomi='ダイワロジャーズコクサイコモディティファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07483': FundCodeEntry(
        fund_code='G07483',
        sec_code=None,
        fund_name='ＤＷＳ\u3000グローバル公益債券ファンド（毎月分配型）Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ディーダブリューエスグローバルコウエキサイケンファンドマイツキブンパイガタエーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07487': FundCodeEntry(
        fund_code='G07487',
        sec_code='13480',
        fund_name='ＭＡＸＩＳ\u3000トピックス上場投信',
        fund_name_yomi='マクシストピックスジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07491': FundCodeEntry(
        fund_code='G07491',
        sec_code=None,
        fund_name='エル・プラス\u3000２００９－０５',
        fund_name_yomi='エルプラスニゼロゼロキュウゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07493': FundCodeEntry(
        fund_code='G07493',
        sec_code=None,
        fund_name='コーポレート・ボンド・インカム（為替ノーヘッジ型）',
        fund_name_yomi='コーポレートボンドインカムカワセノーヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07494': FundCodeEntry(
        fund_code='G07494',
        sec_code=None,
        fund_name='コーポレート・ボンド・インカム（為替ヘッジ型）',
        fund_name_yomi='コーポレートボンドインカムカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07495': FundCodeEntry(
        fund_code='G07495',
        sec_code=None,
        fund_name='ＤＩＡＭアジア関連日本株ファンド',
        fund_name_yomi='ダイアムアジアカンレンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07497': FundCodeEntry(
        fund_code='G07497',
        sec_code=None,
        fund_name='日興ターゲット・ジャパン・ファンド',
        fund_name_yomi='ニッコウターゲットジャパンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07506': FundCodeEntry(
        fund_code='G07506',
        sec_code=None,
        fund_name='野村新米国ハイ・イールド債券投信（通貨選択型）',
        fund_name_yomi='ノムラシンベイコクハイイールドサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07511': FundCodeEntry(
        fund_code='G07511',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・財産設計\u3000２０２０、アライアンス・バーンスタイン・財産設計\u3000２０３０、アライアンス・バーンスタイン・財産設計\u3000２０４０、アライアンス・バーンスタイン・財産設計\u3000２０５０',
        fund_name_yomi='アライアンス\u3000バーンスタイン\u3000ザイサンセッケイ\u3000ニセンニジュウ\u3000アライアンス\u3000バーンスタイン\u3000ザイサンセッケイ\u3000ニセンサンジュウ\u3000アライアンス\u3000バーンスタイン\u3000ザイサンセッケイ\u3000ニセンヨンジュウ\u3000アライアンス\u3000バーンスタイン\u3000ザイサンセッケイ\u3000ニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G07520': FundCodeEntry(
        fund_code='G07520',
        sec_code=None,
        fund_name='エマージング・ボンド・ファンド・カレンシー・セレクション\u3000―\u3000ＵＳＤポートフォリオ、ＥＵＲポートフォリオ、ＡＵＤポートフォリオ、ＺＡＲポートフォリオ',
        fund_name_yomi='エマージングボンドファンドカレンシーセレクションユーエスディーポートフォリオイーユーアールポートフォリオエーユーディーポートフォリオゼットエーアールポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G07534': FundCodeEntry(
        fund_code='G07534',
        sec_code=None,
        fund_name='野村ピクテ・ヘルスケア・ファンド',
        fund_name_yomi='ノムラピクテヘルスケアファンド',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07536': FundCodeEntry(
        fund_code='G07536',
        sec_code=None,
        fund_name='楽天日本株トリプル・ブル',
        fund_name_yomi='ラクテンニホンカブトリプルブル',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G07547': FundCodeEntry(
        fund_code='G07547',
        sec_code='13490',
        fund_name='ＡＢＦ汎アジア債券インデックスファンド',
        fund_name_yomi='エービーエフパンアジアサイケンインデックスファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E23201',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ・シンガポール・リミテッド',
    ),
    'G07555': FundCodeEntry(
        fund_code='G07555',
        sec_code=None,
        fund_name='スーパーファンド・ジャパン',
        fund_name_yomi='スーパーファンドジャパン',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E23303',
        issuer_name='スーパーファンド・ジャパン・トレーディング（ケイマン）リミテッド',
    ),
    'G07556': FundCodeEntry(
        fund_code='G07556',
        sec_code=None,
        fund_name='資源ファンド（株式と通貨）ブラジルレアル・コース、資源ファンド（株式と通貨）南アフリカランド・コース',
        fund_name_yomi='シゲンファンド\u3000カブシキトツウカ\u3000ブラジルレアル\u3000コース\u3000シゲンファンド\u3000カブシキトツウカ\u3000ミナミアフリカランド\u3000コース',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07557': FundCodeEntry(
        fund_code='G07557',
        sec_code=None,
        fund_name='日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（ブラジルレアルコース）日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（トルコリラコース）',
        fund_name_yomi='ニッコウピムコハイインカムソブリンファンドマイツキブンパイガタブラジルレアルコースニッコウピムコハイインカムソブリンファンドマイツキブンパイガタトルコリラコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07560': FundCodeEntry(
        fund_code='G07560',
        sec_code=None,
        fund_name='ＵＢＳ世界公共インフラ債券投信（通貨選択型）',
        fund_name_yomi='ユービーエスセカイコウキョウインフラサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G07564': FundCodeEntry(
        fund_code='G07564',
        sec_code=None,
        fund_name='東京海上・ニッポン世界債券ファンド',
        fund_name_yomi='トウキョウカイジョウニッポンセカイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07565': FundCodeEntry(
        fund_code='G07565',
        sec_code=None,
        fund_name='野村新興国消費関連株投信',
        fund_name_yomi='ノムラシンコウコクショウヒカンレンカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07571': FundCodeEntry(
        fund_code='G07571',
        sec_code=None,
        fund_name='日経２２５インデックス・オープン',
        fund_name_yomi='ニッケイニイニイゴインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='7月7日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G07576': FundCodeEntry(
        fund_code='G07576',
        sec_code=None,
        fund_name='香港ハンセン指数ファンド',
        fund_name_yomi='ホンコンハンセンシスウファンド',
        security_type='内国投資信託受益証券',
        period_1='8月14日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07579': FundCodeEntry(
        fund_code='G07579',
        sec_code=None,
        fund_name='ＭＡＸＩＳ\u3000Ｓ＆Ｐ三菱系企業群上場投信',
        fund_name_yomi='マクシスエスアンドピーミツビシケイキギョウグンジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07580': FundCodeEntry(
        fund_code='G07580',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－利回り債券３分法ファンド',
        fund_name_yomi='ニッポンオフショアファンズリマワリサイケンサンブンホウファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G07581': FundCodeEntry(
        fund_code='G07581',
        sec_code=None,
        fund_name='ブラジル債券オープン（毎月決算型）',
        fund_name_yomi='ブラジルサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07582': FundCodeEntry(
        fund_code='G07582',
        sec_code=None,
        fund_name='新ソブ',
        fund_name_yomi='シンソブ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07588': FundCodeEntry(
        fund_code='G07588',
        sec_code=None,
        fund_name='ゴールドマン・サックス・グローバル・ファンズ\u3000－ＧＳ新成長国通貨債券ファンド\u3000普通（米ドル建て・毎月分配型）クラス受益証券',
        fund_name_yomi='ゴールドマンサックスグローバルファンズジーエスシンセイチョウコクツウカサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E34836',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント・ファンド・サービシズ・リミテッド',
    ),
    'G07589': FundCodeEntry(
        fund_code='G07589',
        sec_code='16710',
        fund_name='ＷＴＩ原油価格連動型上場投信',
        fund_name_yomi='ゲンユカカクレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G07592': FundCodeEntry(
        fund_code='G07592',
        sec_code=None,
        fund_name='野村日本真小型株投信',
        fund_name_yomi='ノムラニホンシンコガタカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07599': FundCodeEntry(
        fund_code='G07599',
        sec_code=None,
        fund_name='楽天グローバル・バランス（安定型）／楽天グローバル・バランス（成長型）／楽天グローバル・バランス（積極型）',
        fund_name_yomi='ラクテングローバルバランスアンテイガタ\u3000ラクテングローバルバランスセイチョウガタ\u3000ラクテングローバルバランスセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G07602': FundCodeEntry(
        fund_code='G07602',
        sec_code=None,
        fund_name='ウィズダムツリーメタルセキュリティーズリミテッド',
        fund_name_yomi='ウィズダムツリーメタルセキュリティーズリミテッド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E23448',
        issuer_name='ウィズダムツリー・メタル・セキュリティーズ・リミテッド',
    ),
    'G07603': FundCodeEntry(
        fund_code='G07603',
        sec_code=None,
        fund_name='ブラックロック・グローバル・インベストメント・シリーズ－ワールド・インカム・ポートフォリオ',
        fund_name_yomi='ブラックロックグローバルインベストメントシリーズワールドインカムポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E31087',
        issuer_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
    ),
    'G07604': FundCodeEntry(
        fund_code='G07604',
        sec_code=None,
        fund_name='財産３分法ファンド（不動産・債券・株式）資産成長型',
        fund_name_yomi='ザイサンサンブンポウファンドフドウサンサイケンカブシキシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07611': FundCodeEntry(
        fund_code='G07611',
        sec_code=None,
        fund_name='野村世界業種別投資シリーズ（世界金融株投資）、野村世界業種別投資シリーズ（世界半導体株投資）、野村世界業種別投資シリーズ（世界資源株投資）、野村世界業種別投資シリーズ（世界ヘルスケア株投資）、野村世界業種別投資シリーズ（マネープール・ファンド）',
        fund_name_yomi='ノムラセカイギョウシュベツトウシシリーズセカイキンユウカブトウシ\u3000ノムラセカイギョウシュベツトウシシリーズセカイハンドウタイカブトウシ\u3000ノムラセカイギョウシュベツトウシシリーズセカイシゲンカブトウシ\u3000ノムラセカイギョウシュベツトウシシリーズセカイヘルスケアカブトウシ\u3000ノムラセカイギョウシュベツトウシシリーズマネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07613': FundCodeEntry(
        fund_code='G07613',
        sec_code=None,
        fund_name='日興レジェンド・イーグル・ファンド（資産成長コース）日興レジェンド・イーグル・ファンド（円ヘッジコース）日興レジェンド・イーグル・ファンド（毎月決算コース）',
        fund_name_yomi='ニッコウレジェンドイーグルファンドシサンセイチョウコースニッコウレジェンドイーグルファンドエンヘッジコースニッコウレジェンドイーグルファンドマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07619': FundCodeEntry(
        fund_code='G07619',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・米国ハイ・イールド債券投信（通貨選択型）',
        fund_name_yomi='ノムラピムコベイコクハイイールドサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07620': FundCodeEntry(
        fund_code='G07620',
        sec_code=None,
        fund_name='ＬＰＳ４資産分散ファンド（慎重型）／ＬＰＳ４資産分散ファンド（安定重視型）／ＬＰＳ４資産分散ファンド（バランス型）／ＬＰＳ４資産分散ファンド（成長重視型）／ＬＰＳ４資産分散ファンド（積極型）',
        fund_name_yomi='エルピーエスヨンシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07622': FundCodeEntry(
        fund_code='G07622',
        sec_code=None,
        fund_name='ＵＢＳ中国Ａ株ファンド（年１回決算型）',
        fund_name_yomi='ユービーエスチュウゴクエイカブファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G07625': FundCodeEntry(
        fund_code='G07625',
        sec_code=None,
        fund_name='ノムラ・アジア・シリーズ',
        fund_name_yomi='ノムラアジアシリーズ',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07632': FundCodeEntry(
        fund_code='G07632',
        sec_code=None,
        fund_name='ＤＷＳ\u3000通貨選択型エマージング・ソブリン・ボンド・ファンド\u3000豪ドルコース（毎月分配型）／ブラジルレアルコース（毎月分配型）／円コース（毎月分配型）',
        fund_name_yomi='ディーダブリューエス\u3000ツウカセンタクガタエマージング\u3000ソブリン\u3000ボンド\u3000ファンド\u3000ゴウドルコース\u3000マイツキブンパイガタ\u3000ブラジルレアルコース\u3000マイツキブンパイガタ\u3000エンコース\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07636': FundCodeEntry(
        fund_code='G07636',
        sec_code=None,
        fund_name='ＨＳＢＣインド・インフラ株式オープン',
        fund_name_yomi='エイチエスビーシーインドインフラカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G07649': FundCodeEntry(
        fund_code='G07649',
        sec_code=None,
        fund_name='ＤＣ新興国債券インデックス・オープン',
        fund_name_yomi='ディーシーシンコウコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07650': FundCodeEntry(
        fund_code='G07650',
        sec_code=None,
        fund_name='ＤＣ新興国株式インデックス・オープン',
        fund_name_yomi='ディーシーシンコウコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07652': FundCodeEntry(
        fund_code='G07652',
        sec_code='16770',
        fund_name='上場インデックスファンド海外債券（ＦＴＳＥ\u3000ＷＧＢＩ）毎月分配型',
        fund_name_yomi='ジョウジョウインデックスファンドカイガイサイケンエフティエスイーウィグビーマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07654': FundCodeEntry(
        fund_code='G07654',
        sec_code=None,
        fund_name='ＤＩＡＭ新興国ソブリンオープン通貨選択シリーズ',
        fund_name_yomi='ダイアムシンコウコクソブリンオープンツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07655': FundCodeEntry(
        fund_code='G07655',
        sec_code=None,
        fund_name='ＵＢＳ次世代テクノロジー・ファンド',
        fund_name_yomi='ユービーエスジセダイテクノロジーファンド',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G07657': FundCodeEntry(
        fund_code='G07657',
        sec_code=None,
        fund_name='ノムラ・マスター・セレクト‐ユー・エス・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ノムラ\u3000マスター\u3000セレクト\u3000ユー\u3000エス\u3000ハイ\u3000イールド\u3000ボンド\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15291',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G07661': FundCodeEntry(
        fund_code='G07661',
        sec_code=None,
        fund_name='ＳＭＢＣ・日興ニューワールド債券ファンド（ブラジルレアル）ＳＭＢＣ・日興ニューワールド債券ファンド（南アランド）ＳＭＢＣ・日興ニューワールド債券ファンド（中国元）ＳＭＢＣ・日興ニューワールド債券ファンド（豪ドル）ＳＭＢＣ・日興ニューワールド債券ファンド（円）',
        fund_name_yomi='エスエムビーシーニッコウニューワールドサイケンファンドブラジルレアルエスエムビーシーニッコウニューワールドサイケンファンドナンアランドエスエムビーシーニッコウニューワールドサイケンファンドチュウゴクゲンエスエムビーシーニッコウニューワールドサイケンファンドゴウドルエスエムビーシーニッコウニューワールドサイケンファンドエン',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07664': FundCodeEntry(
        fund_code='G07664',
        sec_code=None,
        fund_name='野村北米ＲＥＩＴ投信（通貨選択型）',
        fund_name_yomi='ノムラホクベイリートトウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07666': FundCodeEntry(
        fund_code='G07666',
        sec_code=None,
        fund_name='エル・プラス\u3000２００９－１０',
        fund_name_yomi='エルプラスニゼロゼロキュウイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07670': FundCodeEntry(
        fund_code='G07670',
        sec_code=None,
        fund_name='日本株アジア戦略ファンド',
        fund_name_yomi='ニホンカブアジアセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07674': FundCodeEntry(
        fund_code='G07674',
        sec_code=None,
        fund_name='ＪＰＭ新興国毎月決算ファンド',
        fund_name_yomi='ジェイピーエムシンコウコクマイツキケッサンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G07677': FundCodeEntry(
        fund_code='G07677',
        sec_code=None,
        fund_name='国内株式指数ファンド（ＴＯＰＩＸ）',
        fund_name_yomi='コクナイカブシキシスウファンドトピックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07678': FundCodeEntry(
        fund_code='G07678',
        sec_code=None,
        fund_name='外国株式指数ファンド',
        fund_name_yomi='ガイコクカブシキシスウファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G07681': FundCodeEntry(
        fund_code='G07681',
        sec_code=None,
        fund_name='インドネシア株式ファンド',
        fund_name_yomi='インドネシアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G07682': FundCodeEntry(
        fund_code='G07682',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000新興国株式インデックス',
        fund_name_yomi='イーマクシスシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07683': FundCodeEntry(
        fund_code='G07683',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000先進国リートインデックス（除く日本）',
        fund_name_yomi='イーマクシスセンシンコクリートインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07684': FundCodeEntry(
        fund_code='G07684',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000先進国債券インデックス（除く日本）',
        fund_name_yomi='イーマクシスセンシンコクサイケンインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07685': FundCodeEntry(
        fund_code='G07685',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000先進国株式インデックス（除く日本）',
        fund_name_yomi='イーマクシスセンシンコクカブシキインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07686': FundCodeEntry(
        fund_code='G07686',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000国内リートインデックス',
        fund_name_yomi='イーマクシスコクナイリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07687': FundCodeEntry(
        fund_code='G07687',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000国内債券インデックス',
        fund_name_yomi='イーマクシスコクナイサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07688': FundCodeEntry(
        fund_code='G07688',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＴＯＰＩＸインデックス',
        fund_name_yomi='イーマクシストピックスインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07689': FundCodeEntry(
        fund_code='G07689',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000日経２２５インデックス',
        fund_name_yomi='イーマクシスニッケイニイニイゴインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07695': FundCodeEntry(
        fund_code='G07695',
        sec_code=None,
        fund_name='エマージング債券投信（通貨・代替通貨選択型）',
        fund_name_yomi='エマージングサイケントウシン\u3000ツウカダイタイツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G07696': FundCodeEntry(
        fund_code='G07696',
        sec_code=None,
        fund_name='資源株ファンド\u3000通貨選択シリーズ＜ブラジルレアル・コース＞（毎月分配型）',
        fund_name_yomi='シゲンカブファンド\u3000ツウカセンタクシリーズ\u3000ブラジルレアル\u3000コース\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07697': FundCodeEntry(
        fund_code='G07697',
        sec_code=None,
        fund_name='ダイワ・ブラジル株式オープン\u3000－リオの風－',
        fund_name_yomi='ダイワブラジルカブシキオープンリオノカゼ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07698': FundCodeEntry(
        fund_code='G07698',
        sec_code=None,
        fund_name='ウィズダムツリー・コモディティ・セキュリティーズ・リミテッド',
        fund_name_yomi='ウィズダムツリーコモディティセキュリティーズリミテッド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E23770',
        issuer_name='ウィズダムツリー・コモディティ・セキュリティーズ・リミテッド',
    ),
    'G07703': FundCodeEntry(
        fund_code='G07703',
        sec_code=None,
        fund_name='イーストスプリング・インドネシア株式オープン',
        fund_name_yomi='イーストスプリングインドネシアカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G07712': FundCodeEntry(
        fund_code='G07712',
        sec_code=None,
        fund_name='東京海上・アジア中小型成長株ファンド',
        fund_name_yomi='トウキョウカイジョウアジアチュウコガタセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07716': FundCodeEntry(
        fund_code='G07716',
        sec_code=None,
        fund_name='ピクテ・エコディスカバリー・アロケーション・ファンド（年２回決算型）為替ヘッジなし',
        fund_name_yomi='ピクテエコディスカバリーアロケーションファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G07723': FundCodeEntry(
        fund_code='G07723',
        sec_code='16780',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000インド株式指数・Ｎｉｆｔｙ\u3000５０連動型上場投信',
        fund_name_yomi='ネクストファンズインドカブシキシスウニフティゴジュウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07724': FundCodeEntry(
        fund_code='G07724',
        sec_code=None,
        fund_name='ブラックロック・インド株ファンド',
        fund_name_yomi='ブラックロックインドカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07725': FundCodeEntry(
        fund_code='G07725',
        sec_code=None,
        fund_name='ブラックロック・ゴールド・メタル・オープン\u3000Ａ／Ｂ',
        fund_name_yomi='ブラックロックゴールドメタルオープンエイビー',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07726': FundCodeEntry(
        fund_code='G07726',
        sec_code=None,
        fund_name='ブラックロック米国小型成長株式オープン\u3000Ａコース（為替ヘッジなし）／Ｂコース（為替ヘッジあり）',
        fund_name_yomi='ブラックロックベイコクコガタセイチョウカブシキオープンエーコースカワセヘッジナシビーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07727': FundCodeEntry(
        fund_code='G07727',
        sec_code=None,
        fund_name='ブラックロック・アクティブ・ジャパン・オープン',
        fund_name_yomi='ブラックロックアクティブジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07729': FundCodeEntry(
        fund_code='G07729',
        sec_code=None,
        fund_name='ブラックロック・ＵＳベーシック・バリュー・オープン',
        fund_name_yomi='ブラックロックユーエスベーシックバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07730': FundCodeEntry(
        fund_code='G07730',
        sec_code=None,
        fund_name='ブラックロック・ワールド・ボンド・オープン\u3000為替ヘッジなし／為替ヘッジあり',
        fund_name_yomi='ブラックロックワールドボンドオープンカワセヘッジナシカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07731': FundCodeEntry(
        fund_code='G07731',
        sec_code=None,
        fund_name='ブラックロック欧州株式オープン',
        fund_name_yomi='ブラックロックオウシュウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07732': FundCodeEntry(
        fund_code='G07732',
        sec_code=None,
        fund_name='ブラックロック日本小型株オープン',
        fund_name_yomi='ブラックロックニホンコガタカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07733': FundCodeEntry(
        fund_code='G07733',
        sec_code=None,
        fund_name='ブラックロック日本株式オープン',
        fund_name_yomi='ブラックロックニホンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07734': FundCodeEntry(
        fund_code='G07734',
        sec_code=None,
        fund_name='ブラックロック・ワールド債券ファンド\u3000為替ヘッジなし／為替ヘッジあり',
        fund_name_yomi='ブラックロックワールドサイケンファンドカワセヘッジナシカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07735': FundCodeEntry(
        fund_code='G07735',
        sec_code=None,
        fund_name='ブラックロック・グローバル・バランス・ファンド',
        fund_name_yomi='ブラックロックグローバルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07736': FundCodeEntry(
        fund_code='G07736',
        sec_code=None,
        fund_name='ブラックロック世界バランス・ファンド',
        fund_name_yomi='ブラックロックセカイバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07737': FundCodeEntry(
        fund_code='G07737',
        sec_code=None,
        fund_name='ブラックロック・ゴールド・ファンド',
        fund_name_yomi='ブラックロックゴールドファンド',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07740': FundCodeEntry(
        fund_code='G07740',
        sec_code=None,
        fund_name='ブラックロック・ワールド・インカム・ストラテジー',
        fund_name_yomi='ブラックロックワールドインカムストラテジー',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07741': FundCodeEntry(
        fund_code='G07741',
        sec_code=None,
        fund_name='ブラックロック世界好配当株式オープン',
        fund_name_yomi='ブラックロックセカイコウハイトウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07744': FundCodeEntry(
        fund_code='G07744',
        sec_code=None,
        fund_name='ブラックロック・ラテンアメリカ株式ファンド',
        fund_name_yomi='ブラックロックラテンアメリカカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月1日',
        period_2='10月1日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07749': FundCodeEntry(
        fund_code='G07749',
        sec_code=None,
        fund_name='ブラックロック・グローバル・フレキシブル・バランス・ファンド',
        fund_name_yomi='ブラックロックグローバルフレキシブルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07750': FundCodeEntry(
        fund_code='G07750',
        sec_code=None,
        fund_name='ブラックロック天然資源株ファンド',
        fund_name_yomi='ブラックロックテンネンシゲンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G07752': FundCodeEntry(
        fund_code='G07752',
        sec_code=None,
        fund_name='ダイワ・インド株式オープン\u3000－ガンジスの恵み－',
        fund_name_yomi='ダイワインドカブシキオープンガンジスノメグミ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07755': FundCodeEntry(
        fund_code='G07755',
        sec_code=None,
        fund_name='東京海上・ニッポン世界債券ファンド（為替ヘッジあり）',
        fund_name_yomi='トウキョウカイジョウニッポンセカイサイケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07762': FundCodeEntry(
        fund_code='G07762',
        sec_code=None,
        fund_name='アジア・オセアニア債券オープン（毎月決算型）',
        fund_name_yomi='アジアオセアニアサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G07763': FundCodeEntry(
        fund_code='G07763',
        sec_code=None,
        fund_name='日興ブラジル株式ファンド',
        fund_name_yomi='ニッコウブラジルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月24日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07766': FundCodeEntry(
        fund_code='G07766',
        sec_code=None,
        fund_name='ドイチェ・グローバルＲＥＩＴ投信（通貨選択型）',
        fund_name_yomi='ドイチェグローバルリートトウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07768': FundCodeEntry(
        fund_code='G07768',
        sec_code='16790',
        fund_name='Ｓｉｍｐｌｅ－Ｘ\u3000ＮＹダウ・ジョーンズ・インデックス上場投信',
        fund_name_yomi='ダウジョーンズインデックスジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G07769': FundCodeEntry(
        fund_code='G07769',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ新興国株式インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07770': FundCodeEntry(
        fund_code='G07770',
        sec_code=None,
        fund_name='Ｏｎｅ新興資源国債券ファンド',
        fund_name_yomi='ワンシンコウシゲンコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2='10月19日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07773': FundCodeEntry(
        fund_code='G07773',
        sec_code=None,
        fund_name='東京海上Ｒｏｇｇｅニッポン海外債券ファンド（為替ヘッジあり）',
        fund_name_yomi='トウキョウカイジョウロゲーニッポンカイガイサイケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07774': FundCodeEntry(
        fund_code='G07774',
        sec_code=None,
        fund_name='ピクテ円インカム・セレクト・ファンド（毎月分配型）',
        fund_name_yomi='ピクテエンインカムセレクトファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G07782': FundCodeEntry(
        fund_code='G07782',
        sec_code=None,
        fund_name='エマージング・ボンド・ファンド・カレンシー・セレクション－米ドル（ブラジルレアル・ヘッジ）ポートフォリオ－豪ドル（ブラジルレアル・ヘッジ）ポートフォリオ',
        fund_name_yomi='エマージングボンドファンドカレンシーセレクションベイドルブラジルレアルヘッジポートフォリオゴウドルブラジルレアルヘッジポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G07785': FundCodeEntry(
        fund_code='G07785',
        sec_code=None,
        fund_name='しんきん公共債ファンド',
        fund_name_yomi='シンキンコウキョウサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G07788': FundCodeEntry(
        fund_code='G07788',
        sec_code=None,
        fund_name='三重県応援・債券ファンド（毎月決算型）',
        fund_name_yomi='ミエケンオウエンサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G07796': FundCodeEntry(
        fund_code='G07796',
        sec_code='16800',
        fund_name='上場インデックスファンド海外先進国株式（ＭＳＣＩ－ＫＯＫＵＳＡＩ）',
        fund_name_yomi='ジョウジョウインデックスファンドカイガイセンシンコクカブシキエムエスシーアイコクサイ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07797': FundCodeEntry(
        fund_code='G07797',
        sec_code='16810',
        fund_name='上場インデックスファンド海外新興国株式（ＭＳＣＩエマージング）',
        fund_name_yomi='ジョウジョウインデックスファンドカイガイシンコウコクカブシキエムエスシーアイエマージング',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07807': FundCodeEntry(
        fund_code='G07807',
        sec_code=None,
        fund_name='ＳＭＢＣ・日興\u3000世銀債ファンド',
        fund_name_yomi='エスエムビーシーニッコウセギンサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07808': FundCodeEntry(
        fund_code='G07808',
        sec_code=None,
        fund_name='日興マネー・アカウント・ファンド',
        fund_name_yomi='ニッコウマネーアカウントファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07815': FundCodeEntry(
        fund_code='G07815',
        sec_code=None,
        fund_name='ＤＩＡＭ世界好配当株式ファンド（毎月決算型）',
        fund_name_yomi='ダイアムセカイコウハイトウカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07818': FundCodeEntry(
        fund_code='G07818',
        sec_code=None,
        fund_name='ダイワ成長国セレクト債券ファンド（毎月決算型）',
        fund_name_yomi='ダイワセイチョウコクセレクトサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07821': FundCodeEntry(
        fund_code='G07821',
        sec_code=None,
        fund_name='日興アッシュモア新興国財産３分法ファンド毎月分配型（ブラジルレアルコース）、日興アッシュモア新興国財産３分法ファンド毎月分配型（インドルピーコース）',
        fund_name_yomi='ニッコウアッシュモアシンコウコクザイサンサンブンポウファンドマイツキブンパイガタ\u3000ブラジルレアルコース\u3000ニッコウアッシュモアシンコウコクザイサンサンブンポウファンドマイツキブンパイガタ\u3000インドルピーコース',
        security_type='内国投資信託受益証券',
        period_1='2月3日',
        period_2='8月3日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07822': FundCodeEntry(
        fund_code='G07822',
        sec_code=None,
        fund_name='日興マネー・アセット・ファンド',
        fund_name_yomi='ニッコウマネーアセットファンド',
        security_type='内国投資信託受益証券',
        period_1='2月3日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07825': FundCodeEntry(
        fund_code='G07825',
        sec_code=None,
        fund_name='成長国高金利債券ファンド（毎月決算型）',
        fund_name_yomi='セイチョウコクコウキンリサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07827': FundCodeEntry(
        fund_code='G07827',
        sec_code=None,
        fund_name='野村新エマージング債券投信（通貨選択型）',
        fund_name_yomi='ノムラシンエマージングサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07828': FundCodeEntry(
        fund_code='G07828',
        sec_code=None,
        fund_name='外国債券インデックス\u3000為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='ガイコクサイケンインデックス\u3000カワセヘッジアリエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07831': FundCodeEntry(
        fund_code='G07831',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経・ＪＰＸ白金指数連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイジェイピーエックスハッキンシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07832': FundCodeEntry(
        fund_code='G07832',
        sec_code=None,
        fund_name='結い２１０１',
        fund_name_yomi='ユイニィイチゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E23943',
        issuer_name='鎌倉投信株式会社',
    ),
    'G07839': FundCodeEntry(
        fund_code='G07839',
        sec_code=None,
        fund_name='ニッセイＪリートオープン（毎月分配型）',
        fund_name_yomi='ニッセイジェイリートオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G07843': FundCodeEntry(
        fund_code='G07843',
        sec_code=None,
        fund_name='世界標準債券ファンド',
        fund_name_yomi='セカイヒョウジュンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07846': FundCodeEntry(
        fund_code='G07846',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000先進国高金利債券ファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイセンシンコクコウキンリサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07848': FundCodeEntry(
        fund_code='G07848',
        sec_code=None,
        fund_name='アムンディ・チャインドネシア株投信',
        fund_name_yomi='アムンディチャインドネシアカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07849': FundCodeEntry(
        fund_code='G07849',
        sec_code=None,
        fund_name='チャイナ・グッドカンパニー',
        fund_name_yomi='チャイナグッドカンパニー',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G07850': FundCodeEntry(
        fund_code='G07850',
        sec_code=None,
        fund_name='ＭＵＧＣ\u3000ＧＳケイマン・ファンド－ＧＳ\u3000バンク・キャピタル証券ファンド（マルチ・カレンシー型）',
        fund_name_yomi='エムユージーシージーエスケイマンファンドジーエスバンクキャピタルショウケンファンドマルチカレンシーガタ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G07859': FundCodeEntry(
        fund_code='G07859',
        sec_code=None,
        fund_name='のむラップ・ファンド（保守型）、のむラップ・ファンド（やや保守型）、のむラップ・ファンド（普通型）、のむラップ・ファンド（やや積極型）、のむラップ・ファンド（積極型）',
        fund_name_yomi='ノムラップファンドホシュガタ\u3000ノムラップファンドヤヤホシュガタ\u3000ノムラップファンドフツウガタ\u3000ノムラップファンドヤヤセッキョクガタ\u3000ノムラップファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07861': FundCodeEntry(
        fund_code='G07861',
        sec_code=None,
        fund_name='ニッセイアジア好配当株式ファンド（毎月分配型）',
        fund_name_yomi='ニッセイアジアコウハイトウカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G07866': FundCodeEntry(
        fund_code='G07866',
        sec_code=None,
        fund_name='ハリス世界株ファンド（毎月決算型）',
        fund_name_yomi='ハリスセカイカブファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月9日',
        period_2='3月9日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G07881': FundCodeEntry(
        fund_code='G07881',
        sec_code=None,
        fund_name='野村クラウド関連株式投信\u3000Ａコース（為替ヘッジあり）、野村クラウド関連株式投信\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ノムラクラウドカンレンカブシキトウシンエーコースカワセヘッジアリ\u3000ノムラクラウドカンレンカブシキトウシンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07884': FundCodeEntry(
        fund_code='G07884',
        sec_code='32690',
        fund_name='アドバンス・レジデンス投資法人',
        fund_name_yomi='アドバンスレジデンストウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E24347',
        issuer_name='アドバンス・レジデンス投資法人',
    ),
    'G07885': FundCodeEntry(
        fund_code='G07885',
        sec_code=None,
        fund_name='野村グローバル・ハイ・イールド債券投信（バスケット通貨選択型）',
        fund_name_yomi='ノムラグローバルハイイールドサイケントウシンバスケットツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07891': FundCodeEntry(
        fund_code='G07891',
        sec_code=None,
        fund_name='東京海上セレクション・外国株式インデックス',
        fund_name_yomi='トウキョウカイジョウセレクションガイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07892': FundCodeEntry(
        fund_code='G07892',
        sec_code=None,
        fund_name='東京海上セレクション・外国債券インデックス',
        fund_name_yomi='トウキョウカイジョウセレクションガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07893': FundCodeEntry(
        fund_code='G07893',
        sec_code=None,
        fund_name='東京海上セレクション・日本債券インデックス',
        fund_name_yomi='トウキョウカイジョウセレクションニホンサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07896': FundCodeEntry(
        fund_code='G07896',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000新興国債券ファンド\u3000通貨選択シリーズ',
        fund_name_yomi='ミツビシユーエフジェイ\u3000シンコウコクサイケンファンド\u3000ツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07898': FundCodeEntry(
        fund_code='G07898',
        sec_code=None,
        fund_name='ダイワＦＥグローバル・バリュー株ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワエフイーグローバルバリューカブファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G07899': FundCodeEntry(
        fund_code='G07899',
        sec_code=None,
        fund_name='ノムラ・マスター・セレクト‐グローバル・リート・ファンド',
        fund_name_yomi='ノムラ\u3000マスター\u3000セレクト\u3000グローバル\u3000リート\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E15291',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G07900': FundCodeEntry(
        fund_code='G07900',
        sec_code=None,
        fund_name='フィリピン株ファンド',
        fund_name_yomi='フィリピンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G07904': FundCodeEntry(
        fund_code='G07904',
        sec_code=None,
        fund_name='みずほＧＳインベストメント・ユニット・トラスト―みずほＧＳハイブリッド証券ファンド',
        fund_name_yomi='ミズホジーエスインベストメントユニットトラストミズホジーエスハイブリッドショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G07905': FundCodeEntry(
        fund_code='G07905',
        sec_code=None,
        fund_name='シュローダー厳選グロース・ジャパン',
        fund_name_yomi='シュローダーゲンセングロース\u3000ジャパン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G07909': FundCodeEntry(
        fund_code='G07909',
        sec_code='16980',
        fund_name='上場インデックスファンド日本高配当（東証配当フォーカス１００）',
        fund_name_yomi='ジョウジョウインデックスファンドニホンコウハイトウトウショウハイトウフォーカスヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07910': FundCodeEntry(
        fund_code='G07910',
        sec_code='16990',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＮＯＭＵＲＡ原油インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズノムラゲンユインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07911': FundCodeEntry(
        fund_code='G07911',
        sec_code=None,
        fund_name='マネックス資産設計ファンド\u3000エボリューション',
        fund_name_yomi='マネックスシサンセッケイファンド\u3000エボリューション',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G07913': FundCodeEntry(
        fund_code='G07913',
        sec_code=None,
        fund_name='ピクテ・インデックス・ファンド・シリーズ\u3000－\u3000ブラジル株',
        fund_name_yomi='ピクテインデックスファンドシリーズブラジルカブ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G07914': FundCodeEntry(
        fund_code='G07914',
        sec_code=None,
        fund_name='東京海上・円建て投資適格債券ファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウエンダテトウシテキカクサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07915': FundCodeEntry(
        fund_code='G07915',
        sec_code=None,
        fund_name='東京海上・円建て投資適格債券ファンド（年２回決算型）',
        fund_name_yomi='トウキョウカイジョウエンダテトウシテキカクサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G07921': FundCodeEntry(
        fund_code='G07921',
        sec_code=None,
        fund_name='野村アジアＣＢ投信（毎月分配型）',
        fund_name_yomi='ノムラアジアシービートウシンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G07932': FundCodeEntry(
        fund_code='G07932',
        sec_code=None,
        fund_name='ＰＲＵグッドライフ２０５０（年金）',
        fund_name_yomi='プルグッドライフ\u3000ニゼロゴゼロ\u3000ネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12429',
        issuer_name='ＰＧＩＭジャパン株式会社',
    ),
    'G07934': FundCodeEntry(
        fund_code='G07934',
        sec_code=None,
        fund_name='ＤＷＳ\u3000欧州ハイ・イールド債券ファンド（通貨選択型）',
        fund_name_yomi='ディーダブリューエスオウシュウハイイールドサイケンファンドツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G07963': FundCodeEntry(
        fund_code='G07963',
        sec_code=None,
        fund_name='ヘッジファンド・リターン・ターゲットファンド・為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='ヘッジファンドリターンターゲットファンドカワセヘッジアリエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E12431',
        issuer_name='ＢＮＰパリバ・アセットマネジメント株式会社',
    ),
    'G07965': FundCodeEntry(
        fund_code='G07965',
        sec_code=None,
        fund_name='新興国株式インデックスオープン',
        fund_name_yomi='シンコウコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G07966': FundCodeEntry(
        fund_code='G07966',
        sec_code=None,
        fund_name='グリーン世銀債ファンド',
        fund_name_yomi='グリーンセギンサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G07971': FundCodeEntry(
        fund_code='G07971',
        sec_code=None,
        fund_name='アムンディ・米国・ユーロ投資適格債ファンド',
        fund_name_yomi='アムンディベイコクユーロトウシテキカクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07972': FundCodeEntry(
        fund_code='G07972',
        sec_code=None,
        fund_name='アムンディ・毎月分配ユーロ債券ファンド',
        fund_name_yomi='アムンディマイツキブンパイユーロサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07974': FundCodeEntry(
        fund_code='G07974',
        sec_code=None,
        fund_name='アムンディ・りそなインド・ファンド',
        fund_name_yomi='アムンディリソナインドファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07975': FundCodeEntry(
        fund_code='G07975',
        sec_code=None,
        fund_name='アムンディ・りそな米国ハイ・イールド債券ファンド',
        fund_name_yomi='アムンディリソナベイコクハイイールドサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07976': FundCodeEntry(
        fund_code='G07976',
        sec_code=None,
        fund_name='アムンディ・インドネシア・ファンド',
        fund_name_yomi='アムンディインドネシアファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07979': FundCodeEntry(
        fund_code='G07979',
        sec_code=None,
        fund_name='アムンディ・りそなアセアン・ファンド',
        fund_name_yomi='アムンディリソナアセアンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07981': FundCodeEntry(
        fund_code='G07981',
        sec_code=None,
        fund_name='アムンディ・りそなワールド・セレクト・ファンド',
        fund_name_yomi='アムンディリソナワールドセレクトファンド',
        security_type='内国投資信託受益証券',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07982': FundCodeEntry(
        fund_code='G07982',
        sec_code=None,
        fund_name='アムンディ・米国・ユーロ高利回り債ファンド',
        fund_name_yomi='アムンディベイコクユーロコウリマワリサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07983': FundCodeEntry(
        fund_code='G07983',
        sec_code=None,
        fund_name='アムンディ・グラン・チャイナ・ファンド',
        fund_name_yomi='アムンディグランチャイナファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G07990': FundCodeEntry(
        fund_code='G07990',
        sec_code=None,
        fund_name='インベスコ\u3000マグナム・ジャパン・バリュー・オープン',
        fund_name_yomi='インベスコマグナムジャパンバリューオープン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07991': FundCodeEntry(
        fund_code='G07991',
        sec_code=None,
        fund_name='インベスコ\u3000世界厳選株式オープン（毎月決算型）',
        fund_name_yomi='インベスコセカイゲンセンカブシキオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07992': FundCodeEntry(
        fund_code='G07992',
        sec_code=None,
        fund_name='インベスコ\u3000ジャパン・グロース・ファンド',
        fund_name_yomi='インベスコジャパングロースファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07993': FundCodeEntry(
        fund_code='G07993',
        sec_code=None,
        fund_name='ＭＳＣＩインデックス・セレクト・ファンド',
        fund_name_yomi='エムエスシーアイインデックスセレクトファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07994': FundCodeEntry(
        fund_code='G07994',
        sec_code=None,
        fund_name='インベスコ\u3000マンスリー・インカム・ファンド',
        fund_name_yomi='インベスコマンスリーインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07995': FundCodeEntry(
        fund_code='G07995',
        sec_code=None,
        fund_name='インベスコ\u3000ＭＳＣＩコクサイ・インデックス・ファンド',
        fund_name_yomi='インベスコエムエスシーアイコクサイインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G07996': FundCodeEntry(
        fund_code='G07996',
        sec_code=None,
        fund_name='インベスコ\u3000日本株式グロース・ファンド',
        fund_name_yomi='インベスコニホンカブシキグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G08000': FundCodeEntry(
        fund_code='G08000',
        sec_code=None,
        fund_name='楽天ブルベア・マネープール',
        fund_name_yomi='ラクテンブルベアマネープール',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G08003': FundCodeEntry(
        fund_code='G08003',
        sec_code='15400',
        fund_name='純金上場信託（現物国内保管型）',
        fund_name_yomi='ジュンキンジョウジョウシンタクゲンブツコクナイホカンガタ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月20日',
        period_2=None,
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G08004': FundCodeEntry(
        fund_code='G08004',
        sec_code='15410',
        fund_name='純プラチナ上場信託（現物国内保管型）',
        fund_name_yomi='ジュンプラチナジョウジョウシンタクゲンブツコクナイホカンガタ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月20日',
        period_2=None,
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G08005': FundCodeEntry(
        fund_code='G08005',
        sec_code='15430',
        fund_name='純パラジウム上場信託（現物国内保管型）',
        fund_name_yomi='ジュンパラジウムジョウジョウシンタクゲンブツコクナイホカンガタ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月20日',
        period_2=None,
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G08006': FundCodeEntry(
        fund_code='G08006',
        sec_code='15420',
        fund_name='純銀上場信託（現物国内保管型）',
        fund_name_yomi='ジュンギンジョウジョウシンタクゲンブツコクナイホカンガタ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月20日',
        period_2=None,
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G08009': FundCodeEntry(
        fund_code='G08009',
        sec_code=None,
        fund_name='ベトナム株式ファンド',
        fund_name_yomi='ベトナムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08013': FundCodeEntry(
        fund_code='G08013',
        sec_code=None,
        fund_name='ＵＢＳ公益・金融社債ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ユービーエスコウエキキンユウシャサイファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G08017': FundCodeEntry(
        fund_code='G08017',
        sec_code=None,
        fund_name='野村グローバルＣＢ投信（バスケット通貨選択型）',
        fund_name_yomi='ノムラグローバルシービートウシンバスケットツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08019': FundCodeEntry(
        fund_code='G08019',
        sec_code=None,
        fund_name='ＤＣダイワ新興国株式ファンダメンタル・インデックスファンド',
        fund_name_yomi='ディーシーダイワシンコウコクカブシキファンダメンタルインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08020': FundCodeEntry(
        fund_code='G08020',
        sec_code=None,
        fund_name='ＤＣダイワ新興国債券インデックスファンド',
        fund_name_yomi='ディーシーダイワシンコウコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08029': FundCodeEntry(
        fund_code='G08029',
        sec_code=None,
        fund_name='ＣＡＭベトナムファンド',
        fund_name_yomi='キャムベトナムファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G08031': FundCodeEntry(
        fund_code='G08031',
        sec_code=None,
        fund_name='ＳＭＴ\u3000日経２２５インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ニッケイニーニーゴインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08032': FundCodeEntry(
        fund_code='G08032',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000全世界株式インデックス（除く日本）',
        fund_name_yomi='イーマクシスゼンセカイカブシキインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08037': FundCodeEntry(
        fund_code='G08037',
        sec_code=None,
        fund_name='いちよし・インベスコ\u3000中小型成長株オープン',
        fund_name_yomi='イチヨシインベスコチュウコガタセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G08041': FundCodeEntry(
        fund_code='G08041',
        sec_code=None,
        fund_name='ストラテジック・バリュー・オープン（野村ＳＭＡ向け）',
        fund_name_yomi='ストラテジックバリューオープンノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08042': FundCodeEntry(
        fund_code='G08042',
        sec_code=None,
        fund_name='野村日本債券インデックス（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラニホンサイケンインデックスノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08043': FundCodeEntry(
        fund_code='G08043',
        sec_code=None,
        fund_name='野村外国債券インデックス（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08044': FundCodeEntry(
        fund_code='G08044',
        sec_code=None,
        fund_name='野村外国債券アクティブファンドＡコース（野村ＳＭＡ向け）、野村外国債券アクティブファンドＢコース（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラガイコクサイケンアクティブファンドエーコースノムラエスエムエームケ\u3000ノムラガイコクサイケンアクティブファンドビーコースノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08045': FundCodeEntry(
        fund_code='G08045',
        sec_code=None,
        fund_name='ノムラ新興国債券ファンズ（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラシンコウコクサイケンファンズノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='7月13日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08048': FundCodeEntry(
        fund_code='G08048',
        sec_code=None,
        fund_name='ＨＳＢＣインドネシア債券オープン（毎月決算型）',
        fund_name_yomi='エイチエスビーシーインドネシアサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G08050': FundCodeEntry(
        fund_code='G08050',
        sec_code=None,
        fund_name='ダイワ・ファンド・シリーズ－ダイワ新興国債券ファンド（通貨選択型）－通貨タワー－',
        fund_name_yomi='ダイワファンドシリーズ\u3000ダイワシンコウコクサイケンファンドツウカセンタクガタ\u3000ツウカタワー',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E15791',
        issuer_name='ダイワ・アセット・マネジメント・サービシイズ・リミテッド（ケイマン）',
    ),
    'G08056': FundCodeEntry(
        fund_code='G08056',
        sec_code=None,
        fund_name='ブラックロック・グローバル・インベストメント・シリーズ‐グローバル・アロケーション・ポートフォリオ',
        fund_name_yomi='ブラックロックグローバルインベストメントシリーズグローバルアロケーションポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E31087',
        issuer_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
    ),
    'G08061': FundCodeEntry(
        fund_code='G08061',
        sec_code=None,
        fund_name='楽天ＵＳリート・トリプルエンジン（レアル）毎月分配型',
        fund_name_yomi='ラクテンユーエスリートトリプルエンジンレアルマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G08064': FundCodeEntry(
        fund_code='G08064',
        sec_code='15450',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＮＡＳＤＡＱ－１００（Ｒ）（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズナスダックヒャクカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08065': FundCodeEntry(
        fund_code='G08065',
        sec_code='15460',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ダウ・ジョーンズ工業株３０種平均株価（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズダウジョーンズコウギョウカブサンジュウシュヘイキンカブカカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08075': FundCodeEntry(
        fund_code='G08075',
        sec_code=None,
        fund_name='ＤＩＡＭアジア・オセアニア・リートファンド',
        fund_name_yomi='ダイアムアジアオセアニアリートファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08076': FundCodeEntry(
        fund_code='G08076',
        sec_code=None,
        fund_name='コクサイ・ケイマン・トラスト‐外貨建\u3000米国ハイ・イールド・ボンド・オープン・カレンシー・セレクション',
        fund_name_yomi='コクサイケイマントラストガイカダテベイコクハイイールドボンドオープンカレンシーセレクション',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E30992',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G08087': FundCodeEntry(
        fund_code='G08087',
        sec_code=None,
        fund_name='ＤＩＡＭ毎月分配債券ファンド',
        fund_name_yomi='ダイアムマイツキブンパイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08089': FundCodeEntry(
        fund_code='G08089',
        sec_code=None,
        fund_name='ウエスタン・アセット・オフショア・ファンド・シリーズ\u3000―\u3000ＷＡ\u3000ハイ・インカム社債ファンド\u3000（マルチ・カレンシー型）',
        fund_name_yomi='ウエスタンアセットオフショアファンドシリーズダブリュエーハイインカムシャサイファンドマルチカレンシーガタ',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E24736',
        issuer_name='ウエスタン・アセット・マネジメント・カンパニー・リミテッド',
    ),
    'G08093': FundCodeEntry(
        fund_code='G08093',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000新興国債券インデックス',
        fund_name_yomi='イーマクシスシンコウコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08104': FundCodeEntry(
        fund_code='G08104',
        sec_code=None,
        fund_name='明治安田日本株式ファンド',
        fund_name_yomi='メイジヤスダニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08105': FundCodeEntry(
        fund_code='G08105',
        sec_code=None,
        fund_name='明治安田欧州株式ファンド',
        fund_name_yomi='メイジヤスダオウシュウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08106': FundCodeEntry(
        fund_code='G08106',
        sec_code=None,
        fund_name='明治安田日本債券ファンド',
        fund_name_yomi='メイジヤスダニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08107': FundCodeEntry(
        fund_code='G08107',
        sec_code=None,
        fund_name='明治安田外国債券ファンド',
        fund_name_yomi='メイジヤスダガイコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08108': FundCodeEntry(
        fund_code='G08108',
        sec_code=None,
        fund_name='明治安田アメリカ株式ファンド',
        fund_name_yomi='メイジヤスダアメリカカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08109': FundCodeEntry(
        fund_code='G08109',
        sec_code=None,
        fund_name='明治安田ライフプランファンド２０明治安田ライフプランファンド５０明治安田ライフプランファンド７０',
        fund_name_yomi='メイジヤスダライフプランファンドニジュウメイジヤスダライフプランファンドゴジュウメイジヤスダライフプランファンドナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08110': FundCodeEntry(
        fund_code='G08110',
        sec_code=None,
        fund_name='明治安田日本株バリューアップ・セレクト１００',
        fund_name_yomi='メイジヤスダニホンカブバリューアップセレクトヒャク',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08111': FundCodeEntry(
        fund_code='G08111',
        sec_code=None,
        fund_name='明治安田セレクト日本株式ファンド',
        fund_name_yomi='メイジヤスダセレクトニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08112': FundCodeEntry(
        fund_code='G08112',
        sec_code=None,
        fund_name='フコク日本株式ファンド',
        fund_name_yomi='フコクニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08113': FundCodeEntry(
        fund_code='G08113',
        sec_code=None,
        fund_name='フコク日本債券ファンド',
        fund_name_yomi='フコクニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08114': FundCodeEntry(
        fund_code='G08114',
        sec_code=None,
        fund_name='フコク株２５大河フコク株５０大河フコク株７５大河',
        fund_name_yomi='フコクカブニジュウゴタイガフコクカブゴジュウタイガフコクカブナナジュウゴタイガ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08115': FundCodeEntry(
        fund_code='G08115',
        sec_code=None,
        fund_name='小型株ファンド',
        fund_name_yomi='コガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月12日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08117': FundCodeEntry(
        fund_code='G08117',
        sec_code=None,
        fund_name='パン・パシフィック外国債券オープン',
        fund_name_yomi='パンパシフィックガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2='2月15日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08119': FundCodeEntry(
        fund_code='G08119',
        sec_code=None,
        fund_name='新成長株ファンド',
        fund_name_yomi='シンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08123': FundCodeEntry(
        fund_code='G08123',
        sec_code=None,
        fund_name='明治安田ＤＣトピックスプラス',
        fund_name_yomi='メイジヤスダディーシートピックスプラス',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08130': FundCodeEntry(
        fund_code='G08130',
        sec_code=None,
        fund_name='資産形成ファンド',
        fund_name_yomi='シサンケイセイファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08136': FundCodeEntry(
        fund_code='G08136',
        sec_code=None,
        fund_name='野村円債投資インデックスファンド',
        fund_name_yomi='ノムラエンサイトウシインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08137': FundCodeEntry(
        fund_code='G08137',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－グローバル・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ニッポンオフショアファンズグローバルハイイールドボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G08141': FundCodeEntry(
        fund_code='G08141',
        sec_code=None,
        fund_name='ＢＮＰパリバ・グローバル債券ファンド',
        fund_name_yomi='ビーエヌピーパリバグローバルサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14903',
        issuer_name='ＢＮＰパリバ・アセットマネジメント・ルクセンブルグ',
    ),
    'G08142': FundCodeEntry(
        fund_code='G08142',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本国債ファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイニホンコクサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08156': FundCodeEntry(
        fund_code='G08156',
        sec_code=None,
        fund_name='ダイワ米国高金利社債ファンド（通貨選択型）：米ドル・コース（毎月分配型）、豪ドル・コース（毎月分配型）、ブラジル・レアル・コース（毎月分配型）、日本円・コース（毎月分配型）、南アフリカ・ランド・コース（毎月分配型）、トルコ・リラ・コース（毎月分配型）、通貨セレクト・コース（毎月分配型）',
        fund_name_yomi='ダイワベイコクコウキンリシャサイファンドツウカセンタクガタベイドルコースマイツキブンパイガタゴウドルコースマイツキブンパイガタブラジルレアルコースマイツキブンパイガタニホンエンコースマイツキブンパイガタミナミアフリカランドコースマイツキブンパイガタトルコリラコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08158': FundCodeEntry(
        fund_code='G08158',
        sec_code=None,
        fund_name='ノムラ・ポートフォリオ・セレクト‐エマージング・ボンド・ファンド',
        fund_name_yomi='ノムラ\u3000ポートフォリオ\u3000セレクト\u3000エマージング\u3000ボンド\u3000ファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15291',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G08162': FundCodeEntry(
        fund_code='G08162',
        sec_code=None,
        fund_name='三井住友・米国ハイ・イールド債券・ブラジルレアルファンド',
        fund_name_yomi='ミツイスミトモベイコクハイイールドサイケンブラジルレアルファンド',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08164': FundCodeEntry(
        fund_code='G08164',
        sec_code=None,
        fund_name='野村ドイチェ・高配当インフラ関連株投信',
        fund_name_yomi='ノムラドイチェコウハイトウインフラカンレンカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08165': FundCodeEntry(
        fund_code='G08165',
        sec_code='15470',
        fund_name='上場インデックスファンド米国株式（Ｓ＆Ｐ５００）',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08168': FundCodeEntry(
        fund_code='G08168',
        sec_code=None,
        fund_name='ＤＩＡＭ円ストラテジー債券ファンド',
        fund_name_yomi='ダイアムエンストラテジーサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08170': FundCodeEntry(
        fund_code='G08170',
        sec_code=None,
        fund_name='野村先進国ヘッジ付き債券ファンド',
        fund_name_yomi='ノムラセンシンコクヘッジツキサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08172': FundCodeEntry(
        fund_code='G08172',
        sec_code=None,
        fund_name='ダイワ・インドネシア・ルピア債オープン（毎月分配型）',
        fund_name_yomi='ダイワインドネシアルピアサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08177': FundCodeEntry(
        fund_code='G08177',
        sec_code=None,
        fund_name='中華圏株式ファンド（毎月分配型）',
        fund_name_yomi='チュウカケンカブシキファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月4日',
        period_2='10月4日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08180': FundCodeEntry(
        fund_code='G08180',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ新興国債券インデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーシンコウコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08183': FundCodeEntry(
        fund_code='G08183',
        sec_code=None,
        fund_name='東京海上Ｊ－ＲＥＩＴ投信（通貨選択型）',
        fund_name_yomi='トウキョウカイジョウジェイリートトウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G08192': FundCodeEntry(
        fund_code='G08192',
        sec_code=None,
        fund_name='コクサイ・ケイマン・トラスト‐外貨建\u3000世界投資適格債オープン・カレンシー・セレクション',
        fund_name_yomi='コクサイケイマントラストガイカダテセカイトウシテキカクサイオープンカレンシーセレクション',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30992',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G08198': FundCodeEntry(
        fund_code='G08198',
        sec_code='15500',
        fund_name='ＭＡＸＩＳ\u3000海外株式（ＭＳＣＩコクサイ）上場投信',
        fund_name_yomi='マクシスカイガイカブシキエムエスシーアイコクサイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08199': FundCodeEntry(
        fund_code='G08199',
        sec_code=None,
        fund_name='野村インデックスファンド・ＴＯＰＩＸ',
        fund_name_yomi='ノムラインデックスファンドトピックス',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08200': FundCodeEntry(
        fund_code='G08200',
        sec_code=None,
        fund_name='野村インデックスファンド・日経２２５',
        fund_name_yomi='ノムラインデックスファンドニッケイニニゴ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08201': FundCodeEntry(
        fund_code='G08201',
        sec_code=None,
        fund_name='野村インデックスファンド・国内債券',
        fund_name_yomi='ノムラインデックスファンドコクナイサイケン',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08202': FundCodeEntry(
        fund_code='G08202',
        sec_code=None,
        fund_name='野村インデックスファンド・外国株式',
        fund_name_yomi='ノムラインデックスファンドガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08203': FundCodeEntry(
        fund_code='G08203',
        sec_code=None,
        fund_name='野村インデックスファンド・外国債券',
        fund_name_yomi='ノムラインデックスファンドガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08204': FundCodeEntry(
        fund_code='G08204',
        sec_code=None,
        fund_name='野村インデックスファンド・Ｊ－ＲＥＩＴ',
        fund_name_yomi='ノムラインデックスファンドジェイリート',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08205': FundCodeEntry(
        fund_code='G08205',
        sec_code=None,
        fund_name='野村インデックスファンド・外国ＲＥＩＴ',
        fund_name_yomi='ノムラインデックスファンドガイコクリート',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08206': FundCodeEntry(
        fund_code='G08206',
        sec_code=None,
        fund_name='野村インデックスファンド・新興国株式',
        fund_name_yomi='ノムラインデックスファンドシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08207': FundCodeEntry(
        fund_code='G08207',
        sec_code=None,
        fund_name='野村インデックスファンド・新興国債券',
        fund_name_yomi='ノムラインデックスファンドシンコウコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08208': FundCodeEntry(
        fund_code='G08208',
        sec_code=None,
        fund_name='野村インデックスファンド・新興国債券・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドシンコウコクサイケンカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08209': FundCodeEntry(
        fund_code='G08209',
        sec_code='15510',
        fund_name='東証スタンダードＴＯＰ２０ＥＴＦ',
        fund_name_yomi='トウショウスタンダードトップニジュウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G08211': FundCodeEntry(
        fund_code='G08211',
        sec_code=None,
        fund_name='エマージング・ハイ・イールド・ボンド・ファンド・ブラジルレアルコース、エマージング・ハイ・イールド・ボンド・ファンド（マネープールファンド）',
        fund_name_yomi='エマージングハイイールドボンドファンドブラジルレアルコース\u3000エマージングハイイールドボンドファンドマネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08226': FundCodeEntry(
        fund_code='G08226',
        sec_code=None,
        fund_name='ダイワ外国為替債券戦略ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワガイコクカワセサイケンセンリャクファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08227': FundCodeEntry(
        fund_code='G08227',
        sec_code=None,
        fund_name='テンプルトン世界債券ファンド\u3000限定為替ヘッジコース\u3000／\u3000テンプルトン世界債券ファンド\u3000為替ヘッジなしコース\u3000／\u3000テンプルトン世界債券ファンド\u3000毎月分配型・為替ヘッジなしコース',
        fund_name_yomi='テンプルトンセカイサイケンファンド\u3000ゲンテイカワセヘッジコース\u3000\u3000\u3000テンプルトンセカイサイケンファンド\u3000カワセヘッジナシコース\u3000\u3000\u3000テンプルトンセカイサイケンファンド\u3000マイツキブンパイガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G08229': FundCodeEntry(
        fund_code='G08229',
        sec_code='15530',
        fund_name='ＭＡＸＩＳ\u3000Ｓ＆Ｐ東海上場投信',
        fund_name_yomi='マクシスエスアンドピートウカイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08230': FundCodeEntry(
        fund_code='G08230',
        sec_code=None,
        fund_name='フィデリティ・世界インカム株式・ファンド（毎月決算型）',
        fund_name_yomi='フィデリティセカイインカムカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G08231': FundCodeEntry(
        fund_code='G08231',
        sec_code=None,
        fund_name='日本ニューテクノロジー・オープン',
        fund_name_yomi='ニホンニューテクノロジーオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08234': FundCodeEntry(
        fund_code='G08234',
        sec_code=None,
        fund_name='新興国株式インデックス・オープン（ＳＭＡ専用）',
        fund_name_yomi='シンコウコクカブシキインデックスオープンエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08235': FundCodeEntry(
        fund_code='G08235',
        sec_code=None,
        fund_name='ＤＩＡＭ中国Ａ株ファンド',
        fund_name_yomi='ダイアムチュウゴクエーカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08236': FundCodeEntry(
        fund_code='G08236',
        sec_code=None,
        fund_name='ピムコ・ルクセンブルグ・トラスト\u3000Ⅳ',
        fund_name_yomi='ピムコルクセンブルグトラストフォー',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E25088',
        issuer_name='ピムコ・グローバル・アドバイザーズ（ルクセンブルグ）エス・エイ',
    ),
    'G08238': FundCodeEntry(
        fund_code='G08238',
        sec_code=None,
        fund_name='アムンディ・日経平均オープン',
        fund_name_yomi='アムンディニッケイヘイキンオープン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G08241': FundCodeEntry(
        fund_code='G08241',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・ブラジル高配当株ファンド（毎月分配型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ブラジルコウハイトウカブファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G08246': FundCodeEntry(
        fund_code='G08246',
        sec_code=None,
        fund_name='欧州ハイ・イールド債券オープン（毎月決算型）円コース、欧州ハイ・イールド債券オープン（毎月決算型）ユーロコース',
        fund_name_yomi='オウシュウハイイールドサイケンオープンマイツキケッサンガタエンコース\u3000オウシュウハイイールドサイケンオープンマイツキケッサンガタユーロコース',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08247': FundCodeEntry(
        fund_code='G08247',
        sec_code=None,
        fund_name='ＡＢケイマン・トラスト－エマージング・ボンド・ファンド（外貨建）',
        fund_name_yomi='エービーケイマントラストエマージングボンドファンドガイカダテ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E06241',
        issuer_name='アライアンス・バーンスタイン・エル・ピー',
    ),
    'G08249': FundCodeEntry(
        fund_code='G08249',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ユーロ・ハイ・イールド債券ファンド（毎月分配型）Ａコース（円ヘッジあり）／Ｂコース（円ヘッジなし）',
        fund_name_yomi='ディーダブリューエス\u3000ユーロハイイールドサイケンファンドマイツキブンパイガタ\u3000エーコースエンヘッジアリ\u3000ビーコースエンヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G08250': FundCodeEntry(
        fund_code='G08250',
        sec_code=None,
        fund_name='バークレイズ・ポートフォリオ',
        fund_name_yomi='バークレイズポートフォリオ',
        security_type='外国投資証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E25175',
        issuer_name='バークレイズ・ポートフォリオ',
    ),
    'G08253': FundCodeEntry(
        fund_code='G08253',
        sec_code=None,
        fund_name='楽天ＵＳリート・トリプルエンジン（豪ドル）毎月分配型',
        fund_name_yomi='ラクテンユーエスリートトリプルエンジンゴウドルマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月27日',
        period_2='12月27日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G08254': FundCodeEntry(
        fund_code='G08254',
        sec_code=None,
        fund_name='アムンディ・ジャパン・プラス債券ファンド',
        fund_name_yomi='アムンディジャパンプラスサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G08257': FundCodeEntry(
        fund_code='G08257',
        sec_code=None,
        fund_name='Ｔ＆Ｄインド中小型株ファンド',
        fund_name_yomi='ティアンドディインドチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G08260': FundCodeEntry(
        fund_code='G08260',
        sec_code=None,
        fund_name='三井住友・公益債券投信（毎月決算型）',
        fund_name_yomi='ミツイスミトモコウエキサイケントウシンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08261': FundCodeEntry(
        fund_code='G08261',
        sec_code=None,
        fund_name='豪ドル建\u3000ＤＷＳ\u3000エマージング・ソブリン・ボンド・ファンド（毎月分配型）、米ドル建\u3000ＤＷＳ\u3000エマージング・ソブリン・ボンド・ファンド（毎月分配型）',
        fund_name_yomi='ゴウドルダテディーダブユーエスエマージングソブリンボンドファンドマイツキブンパイガタベイドルダテディーダブユーエスエマージングソブリンボンドファンドマイツキブンパイガタ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14961',
        issuer_name='ＤＷＳインベストメント・エス・エー',
    ),
    'G08262': FundCodeEntry(
        fund_code='G08262',
        sec_code=None,
        fund_name='アムンディ・欧州ハイ・イールド債券ファンド',
        fund_name_yomi='アムンディオウシュウハイイールドサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G08267': FundCodeEntry(
        fund_code='G08267',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000純金ファンド',
        fund_name_yomi='ミツビシユーエフジェイジュンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08269': FundCodeEntry(
        fund_code='G08269',
        sec_code=None,
        fund_name='ＰＩＭＣＯニューワールド円インカムファンド\u3000ＰＩＭＣＯニューワールド米ドルインカムファンド',
        fund_name_yomi='ピムコ\u3000ニューワールドエンインカムファンド\u3000ピムコ\u3000ニューワールドベイドルインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08271': FundCodeEntry(
        fund_code='G08271',
        sec_code=None,
        fund_name='ステート・ストリートＵＳボンド・オープン（為替ヘッジあり）',
        fund_name_yomi='ステート\u3000ストリート\u3000ユーエス\u3000ボンド\u3000オープン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G08273': FundCodeEntry(
        fund_code='G08273',
        sec_code=None,
        fund_name='ラッセル・インベストメント・アジア増配継続株１００\u3000Ａ（為替ヘッジあり）、ラッセル・インベストメント・アジア増配継続株１００\u3000Ｂ（為替ヘッジなし）',
        fund_name_yomi='ラッセルインベストメントアジアゾウハイケイゾクカブヒャク\u3000エー\u3000カワセヘッジアリ\u3000ラッセルインベストメントアジアゾウハイケイゾクカブヒャク\u3000ビー\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G08283': FundCodeEntry(
        fund_code='G08283',
        sec_code=None,
        fund_name='ＢＮＹメロン・新興国ソブリン・ファンド（円ヘッジ）',
        fund_name_yomi='ビーエヌワイメロンシンコウコクソブリンファンドエンヘッジ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G08289': FundCodeEntry(
        fund_code='G08289',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ新興国インフラ関連債券投信（通貨選択型）',
        fund_name_yomi='ノムラピムコシンコウコクインフラカンレンサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08296': FundCodeEntry(
        fund_code='G08296',
        sec_code=None,
        fund_name='円サポート',
        fund_name_yomi='エンサポート',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08297': FundCodeEntry(
        fund_code='G08297',
        sec_code='15540',
        fund_name='上場インデックスファンド世界株式（ＭＳＣＩ\u3000ＡＣＷＩ）除く日本',
        fund_name_yomi='ジョウジョウインデックスファンドセカイカブシキエムエスシーアイアクイノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08298': FundCodeEntry(
        fund_code='G08298',
        sec_code='15550',
        fund_name='上場インデックスファンド豪州リート（Ｓ＆Ｐ／ＡＳＸ２００\u3000Ａ－ＲＥＩＴ）',
        fund_name_yomi='ジョウジョウインデックスファンドゴウシュウリートエスアンドピーエーエスエックスニヒャクエーリート',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08299': FundCodeEntry(
        fund_code='G08299',
        sec_code=None,
        fund_name='ニッセイ次世代医療ファンド',
        fund_name_yomi='ニッセイジセダイイリョウファンド',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08302': FundCodeEntry(
        fund_code='G08302',
        sec_code=None,
        fund_name='ピクテ・ハイインカム・ソブリン・ファンド（毎月決算型）為替ヘッジコース',
        fund_name_yomi='ピクテハイインカムソブリンファンドマイツキケッサンガタカワセヘッジコース',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G08303': FundCodeEntry(
        fund_code='G08303',
        sec_code=None,
        fund_name='ＤＣチャイナ・ロード',
        fund_name_yomi='ディーシーチャイナロード',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08304': FundCodeEntry(
        fund_code='G08304',
        sec_code=None,
        fund_name='利金・分配金専用ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='リキンブンパイキンセンヨウエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08305': FundCodeEntry(
        fund_code='G08305',
        sec_code=None,
        fund_name='ダイワ・ファンド・シリーズ－ダイワ新興国債券ファンド（毎月分配型）',
        fund_name_yomi='ダイワファンドシリーズ\u3000ダイワシンコウコクサイケンファンドマイツキブンパイガタ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E15791',
        issuer_name='ダイワ・アセット・マネジメント・サービシイズ・リミテッド（ケイマン）',
    ),
    'G08315': FundCodeEntry(
        fund_code='G08315',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（毎月分配型）円コース',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドマイツキブンパイガタエンコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G08316': FundCodeEntry(
        fund_code='G08316',
        sec_code=None,
        fund_name='ピクテ・グローバル・セレクション・ファンド－新興国ハイインカム株式ファンド',
        fund_name_yomi='ピクテグローバルセレクションファンドシンコウコクハイインカムカブシキファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30735',
        issuer_name='ピクテ・アセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G08317': FundCodeEntry(
        fund_code='G08317',
        sec_code=None,
        fund_name='野村米国ブランド株投資',
        fund_name_yomi='ノムラベイコクブランドカブトウシ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08319': FundCodeEntry(
        fund_code='G08319',
        sec_code=None,
        fund_name='ステート・ストリートＤＣグローバル株式インデックス・オープン',
        fund_name_yomi='ステートストリートディーシーグローバルカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G08320': FundCodeEntry(
        fund_code='G08320',
        sec_code=None,
        fund_name='ステート・ストリートＤＣグローバル債券インデックス・オープン',
        fund_name_yomi='ステートストリートディーシーグローバルサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G08321': FundCodeEntry(
        fund_code='G08321',
        sec_code=None,
        fund_name='ハチソン・ポート・ホールディングス・トラスト',
        fund_name_yomi='ハチソンポートホールディングストラスト',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E25351',
        issuer_name='ハチソン・ポート・ホールディングス・マネジメント・ピーティーイー・リミテッド',
    ),
    'G08326': FundCodeEntry(
        fund_code='G08326',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000ニューワールドインカムファンド',
        fund_name_yomi='ピムコニューワールドインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08327': FundCodeEntry(
        fund_code='G08327',
        sec_code=None,
        fund_name='ダイワ／ハリス世界厳選株ファンド、ダイワ／ハリス世界厳選株ファンド・マネー・ポートフォリオ',
        fund_name_yomi='ダイワハリスセカイゲンセンカブファンドダイワハリスセカイゲンセンカブファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08338': FundCodeEntry(
        fund_code='G08338',
        sec_code='15570',
        fund_name='Ｓｔａｔｅ\u3000Ｓｔｒｅｅｔ\u3000ＳＰＤＲ\u3000Ｓ＆Ｐ５００\u3000ＥＴＦ',
        fund_name_yomi='ステートストリートスパイダーエスアンドピーゴヒャクイーティーエフ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E33989',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ・トラスト・カンパニー',
    ),
    'G08344': FundCodeEntry(
        fund_code='G08344',
        sec_code=None,
        fund_name='ノムラ・グローバルトレンド（バスケット通貨選択型）',
        fund_name_yomi='ノムラグローバルトレンドバスケットツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08346': FundCodeEntry(
        fund_code='G08346',
        sec_code=None,
        fund_name='マイ・ロード',
        fund_name_yomi='マイロード',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08350': FundCodeEntry(
        fund_code='G08350',
        sec_code=None,
        fund_name='三井住友・ＤＣつみたてＮＩＳＡ・全海外株インデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーツミタテニーサゼンカイガイカブインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08351': FundCodeEntry(
        fund_code='G08351',
        sec_code=None,
        fund_name='三井住友・ＤＣ新興国株式インデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08353': FundCodeEntry(
        fund_code='G08353',
        sec_code=None,
        fund_name='しんきんアジアＥＴＦ株式ファンド',
        fund_name_yomi='シンキンアジアイーティーエフカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G08361': FundCodeEntry(
        fund_code='G08361',
        sec_code='15590',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000タイ株式ＳＥＴ５０指数連動型上場投信',
        fund_name_yomi='ネクストファンズタイカブシキセットゴジュウシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08362': FundCodeEntry(
        fund_code='G08362',
        sec_code='15600',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＦＴＳＥブルサ・マレーシアＫＬＣＩ連動型上場投信',
        fund_name_yomi='ネクストファンズフッツイーブルサマレーシアケーエルシーアイレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08370': FundCodeEntry(
        fund_code='G08370',
        sec_code=None,
        fund_name='アセアン株式ファンド',
        fund_name_yomi='アセアンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08371': FundCodeEntry(
        fund_code='G08371',
        sec_code=None,
        fund_name='ＤＩＡＭ新興国株式インデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムシンコウコクカブシキインデックスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08373': FundCodeEntry(
        fund_code='G08373',
        sec_code=None,
        fund_name='世界レアメタル関連株ファンド',
        fund_name_yomi='セカイレアメタルカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08374': FundCodeEntry(
        fund_code='G08374',
        sec_code=None,
        fund_name='ダイワ／アムンディ食糧増産関連ファンド',
        fund_name_yomi='ダイワアムンディショクリョウゾウサンカンレンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08388': FundCodeEntry(
        fund_code='G08388',
        sec_code=None,
        fund_name='水戸証券アジア・オセアニア債券オープン（寄附付）',
        fund_name_yomi='ミトショウケンアジアオセアニアサイケンオープンキフツキ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08391': FundCodeEntry(
        fund_code='G08391',
        sec_code=None,
        fund_name='ＵＢＳ地方銀行株ファンド',
        fund_name_yomi='ユービーエスチホウギンコウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G08398': FundCodeEntry(
        fund_code='G08398',
        sec_code=None,
        fund_name='明日の日本（ジャパンエクイティファンド）',
        fund_name_yomi='アスノニホンジャパンエクイティファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08399': FundCodeEntry(
        fund_code='G08399',
        sec_code=None,
        fund_name='野村アジアＲＥＩＴファンド（毎月分配型）',
        fund_name_yomi='ノムラアジアリートファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08400': FundCodeEntry(
        fund_code='G08400',
        sec_code=None,
        fund_name='ＪＰＭアジア・オセアニア高配当株式ファンド',
        fund_name_yomi='ジェイピーエムアジアオセアニアコウハイトウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2='12月19日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G08415': FundCodeEntry(
        fund_code='G08415',
        sec_code=None,
        fund_name='明治安田Ｊ－ＲＥＩＴ戦略ファンド（毎月分配型）',
        fund_name_yomi='メイジヤスダジェイリートセンリャクファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08420': FundCodeEntry(
        fund_code='G08420',
        sec_code=None,
        fund_name='大阪・兵庫応援外国債券オープン',
        fund_name_yomi='オオサカヒョウゴオウエンガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08421': FundCodeEntry(
        fund_code='G08421',
        sec_code=None,
        fund_name='ダイワ／フィデリティ・アジア・ハイ・イールド債券ファンド（通貨選択型）：日本円・コース（毎月分配型）、ブラジル・レアル・コース（毎月分配型）、アジア通貨・コース（毎月分配型）',
        fund_name_yomi='ダイワフィデリティアジアハイイールドサイケンファンドツウカセンタクガタニホンエンコースマイツキブンパイガタブラジルレアルコースマイツキブンパイガタアジアツウカコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月3日',
        period_2='7月3日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08424': FundCodeEntry(
        fund_code='G08424',
        sec_code=None,
        fund_name='米国小型ハイクオリティファンド（毎月決算型）',
        fund_name_yomi='ベイコクコガタハイクオリティファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08425': FundCodeEntry(
        fund_code='G08425',
        sec_code=None,
        fund_name='米国小型ハイクオリティファンド（資産成長型）',
        fund_name_yomi='ベイコクコガタハイクオリティファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08427': FundCodeEntry(
        fund_code='G08427',
        sec_code=None,
        fund_name='ネット証券専用ファンドシリーズ\u3000新興市場日本株\u3000レアル型',
        fund_name_yomi='ネットショウケンセンヨウファンドシリーズ\u3000シンコウシジョウニホンカブ\u3000レアルガタ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08431': FundCodeEntry(
        fund_code='G08431',
        sec_code=None,
        fund_name='スイス・グローバル・リーダー・ファンド',
        fund_name_yomi='スイス\u3000グローバル\u3000リーダー\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月4日',
        period_2='12月4日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G08435': FundCodeEntry(
        fund_code='G08435',
        sec_code=None,
        fund_name='野村米国ハイ・イールド・ファンド（毎月決算型）、野村米国ハイ・イールド・ファンド（毎月決算型）為替ヘッジあり',
        fund_name_yomi='ノムラベイコクハイイールドファンドマイツキケッサンガタ\u3000ノムラベイコクハイイールドファンドマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08438': FundCodeEntry(
        fund_code='G08438',
        sec_code=None,
        fund_name='ニッセイ日本債券ファンド（毎月決算型）',
        fund_name_yomi='ニッセイニホンサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08440': FundCodeEntry(
        fund_code='G08440',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000グローバル・ハイイールド・ボンド・ファンド・通貨選択シリーズ',
        fund_name_yomi='ダイアムグローバルハイイールドボンドファンドツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08447': FundCodeEntry(
        fund_code='G08447',
        sec_code=None,
        fund_name='ＤＩＡＭケイマン・トラスト－グローバル・ハイイールド・ボンド・ファンド・カレンシー・セレクション',
        fund_name_yomi='ダイアムケイマントラスト\u3000グローバルハイイールドボンドファンドカレンシーセレクション',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E25766',
        issuer_name='クイーンズゲート',
    ),
    'G08451': FundCodeEntry(
        fund_code='G08451',
        sec_code=None,
        fund_name='野村テンプルトン・トータル・リターン\u3000Ａコース、野村テンプルトン・トータル・リターン\u3000Ｂコース、野村テンプルトン・トータル・リターン\u3000Ｃコース、野村テンプルトン・トータル・リターン\u3000Ｄコース',
        fund_name_yomi='ノムラテンプルトントータルリターンエーコース\u3000ノムラテンプルトントータルリターンビーコース\u3000ノムラテンプルトントータルリターンシーコース\u3000ノムラテンプルトントータルリターンディーコース',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08454': FundCodeEntry(
        fund_code='G08454',
        sec_code=None,
        fund_name='ブラックロック・グローバル・インベストメント・シリーズ‐世界株式インカム・ポートフォリオ',
        fund_name_yomi='ブラックロックグローバルインベストメントシリーズセカイカブシキインカムポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E31087',
        issuer_name='ブラックロック・ファンド・マネジメント・カンパニー・エス・エー',
    ),
    'G08455': FundCodeEntry(
        fund_code='G08455',
        sec_code=None,
        fund_name='高成長インド・中型株式ファンド',
        fund_name_yomi='コウセイチョウインドチュウガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08462': FundCodeEntry(
        fund_code='G08462',
        sec_code=None,
        fund_name='エマージング・プラス・円戦略コース、エマージング・プラス・成長戦略コース、エマージング・プラス（マネープールファンド）',
        fund_name_yomi='エマージングプラスエンセンリャクコース\u3000エマージングプラスセイチョウセンリャクコース\u3000エマージングプラスマネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08470': FundCodeEntry(
        fund_code='G08470',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・オーストラリア高配当株ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000オーストラリアコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G08472': FundCodeEntry(
        fund_code='G08472',
        sec_code=None,
        fund_name='りそなアジア・ハイ・イールド債券ファンド\u3000アジア通貨コース、りそなアジア・ハイ・イールド債券ファンド\u3000高金利通貨コース、りそなアジア・ハイ・イールド債券ファンド\u3000ブラジルレアルコース、りそなアジア・ハイ・イールド債券ファンド\u3000米ドルコース、りそなアジア・ハイ・イールド債券ファンド\u3000日本円コース',
        fund_name_yomi='リソナアジア\u3000ハイ\u3000イールドサイケンファンド\u3000アジアツウカコース\u3000リソナアジア\u3000ハイ\u3000イールドサイケンファンド\u3000コウキンリツウカコース\u3000リソナアジア\u3000ハイ\u3000イールドサイケンファンド\u3000ブラジルレアルコース\u3000リソナアジア\u3000ハイ\u3000イールドサイケンファンド\u3000ベイドルコース\u3000リソナアジア\u3000ハイ\u3000イールドサイケンファンド\u3000ニホンエンコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G08473': FundCodeEntry(
        fund_code='G08473',
        sec_code=None,
        fund_name='ダイワ米国株ストラテジーα（通貨選択型）\u3000－トリプルリターンズ－：日本円・コース（毎月分配型）、豪ドル・コース（毎月分配型）、ブラジル・レアル・コース（毎月分配型）、米ドル・コース（毎月分配型）、通貨セレクト・コース（毎月分配型）',
        fund_name_yomi='ダイワベイコクカブストラテジーアルファツウカセンタクガタトリプルリターンズニホンエンコースマイツキブンパイガタゴウドルコースマイツキブンパイガタブラジルレアルコースマイツキブンパイガタベイドルコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08479': FundCodeEntry(
        fund_code='G08479',
        sec_code=None,
        fund_name='ダイワ・ディスカバリー・ファンド・シリーズ－ダイワ／フィデリティ・アジア・ハイ・イールド債券ファンド（毎月分配型）－通貨ドラゴン－',
        fund_name_yomi='ダイワディスカバリーファンドシリーズダイワフィデリティアジアハイイールドサイケンファンドマイツキブンパイガタツウカドラゴン',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E15791',
        issuer_name='ダイワ・アセット・マネジメント・サービシイズ・リミテッド（ケイマン）',
    ),
    'G08481': FundCodeEntry(
        fund_code='G08481',
        sec_code=None,
        fund_name='ＡＢケイマン・トラスト－グローバル・ハイ・インカム・エクイティ・ファンド（外貨建）',
        fund_name_yomi='エービーケイマン\u3000トラスト\u3000グローバル\u3000ハイ\u3000インカム\u3000エクイティ\u3000ファンド\u3000ガイカダテ',
        security_type='外国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E06241',
        issuer_name='アライアンス・バーンスタイン・エル・ピー',
    ),
    'G08484': FundCodeEntry(
        fund_code='G08484',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000新興国高利回り社債ファンド\u3000通貨選択シリーズ',
        fund_name_yomi='ミツビシユーエフジェイシンコウコクコウリマワリシャサイファンドツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08493': FundCodeEntry(
        fund_code='G08493',
        sec_code=None,
        fund_name='ハーベスト\u3000アジア\u3000フロンティア株式ファンド',
        fund_name_yomi='ハーベスト\u3000アジア\u3000フロンティアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G08494': FundCodeEntry(
        fund_code='G08494',
        sec_code=None,
        fund_name='野村ＤＣ新興国債券（現地通貨建て）インデックスファンド',
        fund_name_yomi='ノムラディーシーシンコウコクサイケンゲンチツウカダテインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08496': FundCodeEntry(
        fund_code='G08496',
        sec_code=None,
        fund_name='ＵＢＳ世界ＣＢファンド\u3000円ヘッジコース／米ドルヘッジコース',
        fund_name_yomi='ユービーエスセカイシービーファンド\u3000エンヘッジコース\u3000ベイドルヘッジコース',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G08497': FundCodeEntry(
        fund_code='G08497',
        sec_code=None,
        fund_name='ＧＳアジア・ハイ・イールド債券ファンド\u3000アジア通貨コース',
        fund_name_yomi='ジーエスアジアハイイールドサイケンファンド\u3000アジアツウカコース',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G08499': FundCodeEntry(
        fund_code='G08499',
        sec_code=None,
        fund_name='世界のリートファンド・３地域分散タイプ（毎月決算型）',
        fund_name_yomi='セカイノリートファンドサンチイキブンサンタイプマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08502': FundCodeEntry(
        fund_code='G08502',
        sec_code=None,
        fund_name='ネクスト・グロース・ボンド・オープン（毎月決算型）',
        fund_name_yomi='ネクストグロースボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08510': FundCodeEntry(
        fund_code='G08510',
        sec_code=None,
        fund_name='アジア・ハイ・イールド債券ファンド（毎月分配型）為替ヘッジなしコース',
        fund_name_yomi='アジア\u3000ハイ\u3000イールドサイケンファンド\u3000マイツキブンパイガタ\u3000カワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G08511': FundCodeEntry(
        fund_code='G08511',
        sec_code=None,
        fund_name='アメリカン・ニュー・ステージ・オープン',
        fund_name_yomi='アメリカンニューステージオープン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08512': FundCodeEntry(
        fund_code='G08512',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000欧州ハイイールド債券ファンド\u3000通貨選択シリーズ',
        fund_name_yomi='ミツビシユーエフジェイオウシュウハイイールドサイケンファンドツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08513': FundCodeEntry(
        fund_code='G08513',
        sec_code=None,
        fund_name='ＤＣ世界経済インデックスファンド',
        fund_name_yomi='ディーシーセカイケイザイインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08517': FundCodeEntry(
        fund_code='G08517',
        sec_code=None,
        fund_name='ＨＫＴトラスト（愛称\u3000香港テレコム・トラスト）',
        fund_name_yomi='エイチケイティトラスト\u3000アイショウ\u3000ホンコンテレコム\u3000トラスト',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E25940',
        issuer_name='ＨＫＴマネジメント・リミテッド',
    ),
    'G08518': FundCodeEntry(
        fund_code='G08518',
        sec_code=None,
        fund_name='東京海上Ｒｏｇｇｅ世界ハイブリッド証券ファンド（通貨選択型）',
        fund_name_yomi='トウキョウカイジョウロゲーセカイハイブリッドショウケンファンドツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G08520': FundCodeEntry(
        fund_code='G08520',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１１１０',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチイチイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08528': FundCodeEntry(
        fund_code='G08528',
        sec_code=None,
        fund_name='Ｔ＆Ｄ通貨トレード新興国社債ファンド（毎月分配型）',
        fund_name_yomi='ティアンドディツウカトレードシンコウコクシャサイファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G08530': FundCodeEntry(
        fund_code='G08530',
        sec_code=None,
        fund_name='ニッセイグローバル好配当株式プラス（毎月決算型）',
        fund_name_yomi='ニッセイグローバルコウハイトウカブシキプラスマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08536': FundCodeEntry(
        fund_code='G08536',
        sec_code=None,
        fund_name='楽天ＵＳリート・トリプルエンジン（トルコリラ）毎月分配型',
        fund_name_yomi='ラクテンユーエスリートトリプルエンジントルコリラマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G08537': FundCodeEntry(
        fund_code='G08537',
        sec_code=None,
        fund_name='ＳＭＴ\u3000アジア新興国株式インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000アジアシンコウコクカブシキインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08538': FundCodeEntry(
        fund_code='G08538',
        sec_code=None,
        fund_name='明治安田インドネシア債券ファンド（毎月決算型）',
        fund_name_yomi='メイジヤスダインドネシアサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08539': FundCodeEntry(
        fund_code='G08539',
        sec_code=None,
        fund_name='野村グローバル高配当株プレミアム（円コース）毎月分配型、野村グローバル高配当株プレミアム（円コース）年２回決算型、野村グローバル高配当株プレミアム（通貨セレクトコース）毎月分配型、野村グローバル高配当株プレミアム（通貨セレクトコース）年２回決算型',
        fund_name_yomi='ノムラグローバルコウハイトウカブプレミアムエンコースマイツキブンパイガタ\u3000ノムラグローバルコウハイトウカブプレミアムエンコースネンニカイケッサンガタ\u3000ノムラグローバルコウハイトウカブプレミアムツウカセレクトコースマイツキブンパイガタ\u3000ノムラグローバルコウハイトウカブプレミアムツウカセレクトコースネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08541': FundCodeEntry(
        fund_code='G08541',
        sec_code=None,
        fund_name='アセアンＣＡＭ－ＶＩＰファンド',
        fund_name_yomi='アセアンキャムヴィップファンド',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G08542': FundCodeEntry(
        fund_code='G08542',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000バランス（８資産均等型）',
        fund_name_yomi='イーマクシスバランスハチシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08543': FundCodeEntry(
        fund_code='G08543',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000バランス（波乗り型）',
        fund_name_yomi='イーマクシスバランスナミノリガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08544': FundCodeEntry(
        fund_code='G08544',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－新興国中小型株式アクティブファンド',
        fund_name_yomi='ニッポンオフショアファンズシンコウコクチュウショウガタカブシキアクティブファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G08545': FundCodeEntry(
        fund_code='G08545',
        sec_code=None,
        fund_name='アジア\u3000ハイ・イールド債券オープン（為替ヘッジあり）、アジア\u3000ハイ・イールド債券オープン（為替ヘッジなし）',
        fund_name_yomi='アジアハイイールドサイケンオープンカワセヘッジアリ\u3000アジアハイイールドサイケンオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08550': FundCodeEntry(
        fund_code='G08550',
        sec_code=None,
        fund_name='ＡＲＴ\u3000テクニカル運用日本株式ファンド',
        fund_name_yomi='エーアールティー\u3000テクニカルウンヨウニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08551': FundCodeEntry(
        fund_code='G08551',
        sec_code=None,
        fund_name='アジア・ハイ・イールド債券ファンド（毎月分配型）成長通貨コース',
        fund_name_yomi='アジア\u3000ハイ\u3000イールドサイケンファンド\u3000マイツキブンパイガタ\u3000セイチョウツウカコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G08553': FundCodeEntry(
        fund_code='G08553',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１１１１',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチイチイチイチ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08556': FundCodeEntry(
        fund_code='G08556',
        sec_code=None,
        fund_name='インドネシア・ボンド・オープン（毎月決算型）',
        fund_name_yomi='インドネシアボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08557': FundCodeEntry(
        fund_code='G08557',
        sec_code=None,
        fund_name='ダイワ・インド・ルピー債オープン（毎月分配型）',
        fund_name_yomi='ダイワインドルピーサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08562': FundCodeEntry(
        fund_code='G08562',
        sec_code=None,
        fund_name='野村インド債券ファンド（毎月分配型）、野村インド債券ファンド（年２回決算型）［Ｇ１２３５１と統合］',
        fund_name_yomi='ノムラインドサイケンファンドマイツキブンパイガタ\u3000ノムラインドサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08570': FundCodeEntry(
        fund_code='G08570',
        sec_code='15630',
        fund_name='東証グロース・コアＥＴＦ',
        fund_name_yomi='トウショウグロース\u3000コアイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G08575': FundCodeEntry(
        fund_code='G08575',
        sec_code=None,
        fund_name='トルコ・ボンド・オープン（毎月決算型）',
        fund_name_yomi='トルコボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08578': FundCodeEntry(
        fund_code='G08578',
        sec_code=None,
        fund_name='セレブライフ・ストーリー２０２５、セレブライフ・ストーリー２０３５、セレブライフ・ストーリー２０４５、セレブライフ・ストーリー２０５５',
        fund_name_yomi='セレブライフ\u3000ストーリー\u3000ニセンニジュウゴ\u3000セレブライフ\u3000ストーリー\u3000ニセンサンジュウゴ\u3000セレブライフ\u3000ストーリー\u3000ニセンヨンジュウゴ\u3000セレブライフ\u3000ストーリー\u3000ニセンゴジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月14日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G08580': FundCodeEntry(
        fund_code='G08580',
        sec_code=None,
        fund_name='三井住友・ＤＣつみたてＮＩＳＡ・日本株インデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーツミタテニーサニホンカブインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08584': FundCodeEntry(
        fund_code='G08584',
        sec_code=None,
        fund_name='野村アジアブランド株式\u3000Ａコース、野村アジアブランド株式\u3000Ｂコース',
        fund_name_yomi='ノムラアジアブランドカブシキエーコース\u3000ノムラアジアブランドカブシキビーコース',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08588': FundCodeEntry(
        fund_code='G08588',
        sec_code=None,
        fund_name='しんきんアジア債券ファンド（毎月決算型）',
        fund_name_yomi='シンキンアジアサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G08590': FundCodeEntry(
        fund_code='G08590',
        sec_code=None,
        fund_name='ダイワ・ニッポン応援ファンドＶｏｌ．４\u3000－日本の真価－\u3000（高配当株コース／国債コース）',
        fund_name_yomi='ダイワニッポンオウエンファンドボリュームフォーニッポンノシンカコウハイトウカブコースコクサイコース',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08591': FundCodeEntry(
        fund_code='G08591',
        sec_code=None,
        fund_name='大塚グループ株式ファンド（確定拠出年金向け）＜大塚ホールディングス株式、アース製薬株式＞',
        fund_name_yomi='オオツカグループカブシキファンドカクテイキョシュツネンキンムケオオツカホールディングスカブシキアースセイヤクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08594': FundCodeEntry(
        fund_code='G08594',
        sec_code=None,
        fund_name='明治安田ＤＣ中小型株式オープン',
        fund_name_yomi='メイジヤスダディーシーチュウコガタカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08597': FundCodeEntry(
        fund_code='G08597',
        sec_code=None,
        fund_name='ピクテ・ゴールド（為替ヘッジあり）',
        fund_name_yomi='ピクテゴールドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G08599': FundCodeEntry(
        fund_code='G08599',
        sec_code=None,
        fund_name='明治安田米国中小型成長株式ファンド',
        fund_name_yomi='メイジヤスダベイコクチュウコガタセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G08604': FundCodeEntry(
        fund_code='G08604',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞Ｊ－ＲＥＩＴインデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシージェイリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08605': FundCodeEntry(
        fund_code='G08605',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000＜ＤＣ＞先進国ＲＥＩＴインデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーセンシンコクリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08607': FundCodeEntry(
        fund_code='G08607',
        sec_code=None,
        fund_name='野村アジアハイ・イールド債券投信（通貨選択型）',
        fund_name_yomi='ノムラアジアハイイールドサイケントウシンツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08608': FundCodeEntry(
        fund_code='G08608',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－アジア・エックス・ジャパン・エクイティ・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインアジアエックスジャパンエクイティポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月31日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G08611': FundCodeEntry(
        fund_code='G08611',
        sec_code=None,
        fund_name='アジア・ハイ・イールド債券ファンド（毎月分配型）円ヘッジコース',
        fund_name_yomi='アジア\u3000ハイ\u3000イールドサイケンファンド\u3000マイツキブンパイガタ\u3000エンヘッジコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G08615': FundCodeEntry(
        fund_code='G08615',
        sec_code=None,
        fund_name='Ｏｎｅ割安日本株ファンド',
        fund_name_yomi='ワンワリヤスニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08616': FundCodeEntry(
        fund_code='G08616',
        sec_code='15660',
        fund_name='上場インデックスファンド新興国債券',
        fund_name_yomi='ジョウジョウインデックスファンドシンコウコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08618': FundCodeEntry(
        fund_code='G08618',
        sec_code=None,
        fund_name='国内債券通貨プラス',
        fund_name_yomi='コクナイサイケンツウカプラス',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08620': FundCodeEntry(
        fund_code='G08620',
        sec_code=None,
        fund_name='ダイワ・アセアン内需関連株ファンド、ダイワ・アセアン内需関連株ファンド・マネー・ポートフォリオ',
        fund_name_yomi='ダイワアセアンナイジュカンレンカブファンドダイワアセアンナイジュカンレンカブファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08626': FundCodeEntry(
        fund_code='G08626',
        sec_code=None,
        fund_name='野村豪ドル債オープン・プレミアム毎月分配型、野村豪ドル債オープン・プレミアム年２回決算型',
        fund_name_yomi='ノムラゴウドルサイオープンプレミアムマイツキブンパイガタ\u3000ノムラゴウドルサイオープンプレミアムネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月13日',
        period_2='8月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08630': FundCodeEntry(
        fund_code='G08630',
        sec_code=None,
        fund_name='イーストスプリング・インドネシア債券オープン（毎月決算型）\u3000イーストスプリング・インドネシア債券オープン（年２回決算型）',
        fund_name_yomi='イーストスプリングインドネシアサイケンオープンマイツキケッサンガタ\u3000イーストスプリングインドネシアサイケンオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G08631': FundCodeEntry(
        fund_code='G08631',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000プライムバランス（８資産）（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイプライムバランスハチシサンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08632': FundCodeEntry(
        fund_code='G08632',
        sec_code=None,
        fund_name='フィデリティ・ハイ・イールド・ボンド・オープンポートフォリオＢ（為替ヘッジあり）',
        fund_name_yomi='フィデリティハイイールドボンドオープンポートフォリオビーカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G08633': FundCodeEntry(
        fund_code='G08633',
        sec_code=None,
        fund_name='ＤＩＡＭケイマン・トラスト－Ａｓｐｅｃｔ\u3000マネージド・フューチャーズ・ファンド',
        fund_name_yomi='ダイアムケイマントラストアスペクトマネージドフューチャーズファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E26326',
        issuer_name='クイーンズゲート',
    ),
    'G08634': FundCodeEntry(
        fund_code='G08634',
        sec_code=None,
        fund_name='日本債券インデックスファンド',
        fund_name_yomi='ニホンサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08635': FundCodeEntry(
        fund_code='G08635',
        sec_code=None,
        fund_name='日本株式インデックスファンド',
        fund_name_yomi='ニホンカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08636': FundCodeEntry(
        fund_code='G08636',
        sec_code=None,
        fund_name='外国債券インデックスファンド',
        fund_name_yomi='ガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08637': FundCodeEntry(
        fund_code='G08637',
        sec_code=None,
        fund_name='外国株式インデックスファンド',
        fund_name_yomi='ガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08639': FundCodeEntry(
        fund_code='G08639',
        sec_code=None,
        fund_name='ＤＣ日本株式インデックスファンド',
        fund_name_yomi='ディーシーニホンカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08640': FundCodeEntry(
        fund_code='G08640',
        sec_code=None,
        fund_name='ＤＣ日本債券インデックスファンド',
        fund_name_yomi='ディーシーニホンサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08641': FundCodeEntry(
        fund_code='G08641',
        sec_code=None,
        fund_name='ＤＣ外国株式インデックスファンド',
        fund_name_yomi='ディーシーガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08642': FundCodeEntry(
        fund_code='G08642',
        sec_code=None,
        fund_name='ＤＣ外国債券インデックスファンド',
        fund_name_yomi='ディーシーガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08643': FundCodeEntry(
        fund_code='G08643',
        sec_code=None,
        fund_name='ＤＣ日本株式インデックスファンドＬ',
        fund_name_yomi='ディーシーニホンカブシキインデックスファンドエル',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08644': FundCodeEntry(
        fund_code='G08644',
        sec_code=None,
        fund_name='ＤＣ日本株式エクセレント・フォーカス',
        fund_name_yomi='ディーシーニホンカブシキエクセレント\u3000フォーカス',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08645': FundCodeEntry(
        fund_code='G08645',
        sec_code=None,
        fund_name='ＤＣ日本株式インデックスファンドＡ',
        fund_name_yomi='ディーシーニホンカブシキインデックスファンドエー',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08647': FundCodeEntry(
        fund_code='G08647',
        sec_code=None,
        fund_name='ＤＣ外国株式インデックスファンドＬ',
        fund_name_yomi='ディーシーガイコクカブシキインデックスファンドエル',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08648': FundCodeEntry(
        fund_code='G08648',
        sec_code=None,
        fund_name='ＤＣ日本債券インデックスファンドＬ',
        fund_name_yomi='ディーシーニホンサイケンインデックスファンドエル',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08649': FundCodeEntry(
        fund_code='G08649',
        sec_code=None,
        fund_name='ＤＣ外国債券インデックスファンドＬ',
        fund_name_yomi='ディーシーガイコクサイケンインデックスファンドエル',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08650': FundCodeEntry(
        fund_code='G08650',
        sec_code=None,
        fund_name='Ｊリートファンド',
        fund_name_yomi='ジェイリートファント',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08651': FundCodeEntry(
        fund_code='G08651',
        sec_code=None,
        fund_name='高金利ソブリンオープン',
        fund_name_yomi='コウキンリソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08653': FundCodeEntry(
        fund_code='G08653',
        sec_code=None,
        fund_name='ＤＣ日産株ファンド',
        fund_name_yomi='ディーシーニッサンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08654': FundCodeEntry(
        fund_code='G08654',
        sec_code=None,
        fund_name='日本株配当オープン',
        fund_name_yomi='ニホンカブハイトウオープン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08655': FundCodeEntry(
        fund_code='G08655',
        sec_code=None,
        fund_name='３資産バランスオープン',
        fund_name_yomi='サンシサンバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08656': FundCodeEntry(
        fund_code='G08656',
        sec_code=None,
        fund_name='３資産バランスオープンアルファ',
        fund_name_yomi='サンシサンバランスオープンアルファ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08658': FundCodeEntry(
        fund_code='G08658',
        sec_code=None,
        fund_name='ＤＣバランスファンド３０\u3000ＤＣバランスファンド５０\u3000ＤＣバランスファンド７０',
        fund_name_yomi='ディーシーバランスファンドサンジュウ\u3000ディーシーバランスファンドゴジュウ\u3000ディーシーバランスファンドナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08659': FundCodeEntry(
        fund_code='G08659',
        sec_code=None,
        fund_name='社会的責任ファンド',
        fund_name_yomi='シャカイテキセキニンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08660': FundCodeEntry(
        fund_code='G08660',
        sec_code=None,
        fund_name='グローバル３資産バランスオープン',
        fund_name_yomi='グローバルサンシサンバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08665': FundCodeEntry(
        fund_code='G08665',
        sec_code=None,
        fund_name='Ｊリートアクティブファンド（１年決算型）',
        fund_name_yomi='ジェイリートアクティブファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08668': FundCodeEntry(
        fund_code='G08668',
        sec_code=None,
        fund_name='グローバル・インデックス・バランス・ファンド',
        fund_name_yomi='グローバル\u3000インデックス\u3000バランス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08671': FundCodeEntry(
        fund_code='G08671',
        sec_code=None,
        fund_name='ＳＭＴＡＭダウ・ジョーンズ\u3000インデックスファンド',
        fund_name_yomi='エスエムティエーエムダウ\u3000ジョーンズ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08672': FundCodeEntry(
        fund_code='G08672',
        sec_code=None,
        fund_name='日経２２５インデックスファンド',
        fund_name_yomi='ニッケイニイニイゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08676': FundCodeEntry(
        fund_code='G08676',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000米国ハイイールド債券\u3000通貨選択型ファンド',
        fund_name_yomi='ピムコ\u3000ベイコクハイイールドサイケン\u3000ツウカセンタクガタファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08677': FundCodeEntry(
        fund_code='G08677',
        sec_code=None,
        fund_name='日本株式インデックスｅ',
        fund_name_yomi='ニホンカブシキインデックスイー',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08678': FundCodeEntry(
        fund_code='G08678',
        sec_code=None,
        fund_name='外国株式インデックスｅ',
        fund_name_yomi='ガイコクカブシキインデックスイー',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08679': FundCodeEntry(
        fund_code='G08679',
        sec_code=None,
        fund_name='外国債券インデックスｅ',
        fund_name_yomi='ガイコクサイケンインデックスイー',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08680': FundCodeEntry(
        fund_code='G08680',
        sec_code=None,
        fund_name='日本債券インデックスｅ',
        fund_name_yomi='ニホンサイケンインデックスイー',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08681': FundCodeEntry(
        fund_code='G08681',
        sec_code=None,
        fund_name='オーストラリア公社債ファンド',
        fund_name_yomi='オーストラリアコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08683': FundCodeEntry(
        fund_code='G08683',
        sec_code=None,
        fund_name='インデックスコレクション（国内債券）',
        fund_name_yomi='インデックスコレクション\u3000コクナイサイケン',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08684': FundCodeEntry(
        fund_code='G08684',
        sec_code=None,
        fund_name='インデックスコレクション（国内株式）',
        fund_name_yomi='インデックスコレクション\u3000コクナイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08685': FundCodeEntry(
        fund_code='G08685',
        sec_code=None,
        fund_name='インデックスコレクション（外国債券）',
        fund_name_yomi='インデックスコレクション\u3000ガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08686': FundCodeEntry(
        fund_code='G08686',
        sec_code=None,
        fund_name='インデックスコレクション（外国株式）',
        fund_name_yomi='インデックスコレクション\u3000ガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08687': FundCodeEntry(
        fund_code='G08687',
        sec_code=None,
        fund_name='インデックスコレクション（バランス株式３０）\u3000インデックスコレクション（バランス株式５０）\u3000インデックスコレクション（バランス株式７０）',
        fund_name_yomi='インデックスコレクション\u3000バランスカブシキサンジュウ\u3000インデックスコレクション\u3000バランスカブシキゴジュウ\u3000インデックスコレクション\u3000バランスカブシキナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08689': FundCodeEntry(
        fund_code='G08689',
        sec_code=None,
        fund_name='インドネシア・ソブリン・ファンド（毎月決算型）',
        fund_name_yomi='インドネシア\u3000ソブリン\u3000ファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08690': FundCodeEntry(
        fund_code='G08690',
        sec_code=None,
        fund_name='ＳＭＴＡＭダウ・ジョーンズ\u3000インデックスファンド（為替ヘッジあり）',
        fund_name_yomi='エスエムティエーエムダウ\u3000ジョーンズ\u3000インデックスファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08691': FundCodeEntry(
        fund_code='G08691',
        sec_code=None,
        fund_name='世界インフラ関連好配当株式\u3000通貨選択型ファンド',
        fund_name_yomi='セカイインフラカンレンコウハイトウカブシキ\u3000ツウカセンタクガタファンド',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08692': FundCodeEntry(
        fund_code='G08692',
        sec_code=None,
        fund_name='ブラジル公社債ファンド',
        fund_name_yomi='ブラジルコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08694': FundCodeEntry(
        fund_code='G08694',
        sec_code=None,
        fund_name='ピクテ・アセット・アロケーション・ファンド（毎月分配型）',
        fund_name_yomi='ピクテアセットアロケーションファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G08697': FundCodeEntry(
        fund_code='G08697',
        sec_code=None,
        fund_name='ジャパン・オフショア・ファンド・シリーズ－ＮＭ米国投資適格社債ファンド',
        fund_name_yomi='ジャパンオフショアファンドシリーズエヌエムベイコクトウシテキカクシャサイファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G08701': FundCodeEntry(
        fund_code='G08701',
        sec_code=None,
        fund_name='ＭＡＸＩＳトピックスリスクコントロール（５％）上場投信',
        fund_name_yomi='マクシストピックスリスクコントロールゴパーセントジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08702': FundCodeEntry(
        fund_code='G08702',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－新興国社債オープン',
        fund_name_yomi='ニッポンオフショアファンズシンコウコクシャサイオープン',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G08706': FundCodeEntry(
        fund_code='G08706',
        sec_code=None,
        fund_name='日本割安株オープン',
        fund_name_yomi='ニホンワリヤスカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08708': FundCodeEntry(
        fund_code='G08708',
        sec_code=None,
        fund_name='野村ＤＣ運用戦略ファンド',
        fund_name_yomi='ノムラディーシーウンヨウセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08712': FundCodeEntry(
        fund_code='G08712',
        sec_code=None,
        fund_name='ダイワ・オーストラリア高配当株ファンド、ダイワ・オーストラリア高配当株ファンド・マネー・ポートフォリオ',
        fund_name_yomi='ダイワオーストラリアコウハイトウカブファンドダイワオーストラリアコウハイトウカブファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08721': FundCodeEntry(
        fund_code='G08721',
        sec_code=None,
        fund_name='ＡＭＣ／ステート・ストリート・リスクバジェット型バランス・オープン（ステイブル）',
        fund_name_yomi='エーエムシーステートストリートリスクバジェットガタバランスオープンステイブル',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G08729': FundCodeEntry(
        fund_code='G08729',
        sec_code=None,
        fund_name='日興ＪＰＭアジア・ディスカバリー・ファンド',
        fund_name_yomi='ニッコウジェイピーエムアジアディスカバリーファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G08731': FundCodeEntry(
        fund_code='G08731',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２０３',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08739': FundCodeEntry(
        fund_code='G08739',
        sec_code=None,
        fund_name='資源ファンド（株式と通貨）円コース',
        fund_name_yomi='シゲンファンド\u3000カブシキトツウカ\u3000エンコース',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08741': FundCodeEntry(
        fund_code='G08741',
        sec_code=None,
        fund_name='メキシコ・ボンド・オープン（毎月決算型）',
        fund_name_yomi='メキシコボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08754': FundCodeEntry(
        fund_code='G08754',
        sec_code=None,
        fund_name='野村グローバルＲＥＩＴプレミアム（円コース）毎月分配型、野村グローバルＲＥＩＴプレミアム（円コース）年２回決算型、野村グローバルＲＥＩＴプレミアム（通貨セレクトコース）毎月分配型、野村グローバルＲＥＩＴプレミアム（通貨セレクトコース）年２回決算型',
        fund_name_yomi='ノムラグローバルリートプレミアムエンコースマイツキブンパイガタ\u3000ノムラグローバルリートプレミアムエンコースネンニカイケッサンガタ\u3000ノムラグローバルリートプレミアムツウカセレクトコースマイツキブンパイガタ\u3000ノムラグローバルリートプレミアムツウカセレクトコースネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08755': FundCodeEntry(
        fund_code='G08755',
        sec_code='15700',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経平均レバレッジ・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイヘイキンレバレッジインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08756': FundCodeEntry(
        fund_code='G08756',
        sec_code='15710',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経平均インバース・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイヘイキンインバースインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08760': FundCodeEntry(
        fund_code='G08760',
        sec_code='15680',
        fund_name='ＴＯＰＩＸブル２倍上場投信',
        fund_name_yomi='トピックスブルニバイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G08761': FundCodeEntry(
        fund_code='G08761',
        sec_code='15690',
        fund_name='ＴＯＰＩＸベア上場投信',
        fund_name_yomi='トピックスベアジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G08762': FundCodeEntry(
        fund_code='G08762',
        sec_code=None,
        fund_name='ケネディクス・レジデンシャル・ネクスト投資法人',
        fund_name_yomi='ケネディクスレジデンシャルネクストトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E14109',
        issuer_name='ＫＤＸ不動産投資法人',
    ),
    'G08763': FundCodeEntry(
        fund_code='G08763',
        sec_code=None,
        fund_name='ＪＰＭ新興国高配当・成長株ファンド（毎月決算型）／ＪＰＭ新興国高配当・成長株ファンド（年２回決算型）',
        fund_name_yomi='ジェイピーエムシンコウコクコウハイトウセイチョウカブファンドマイツキケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2='10月19日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G08765': FundCodeEntry(
        fund_code='G08765',
        sec_code=None,
        fund_name='ブラジル国債ファンド（毎月分配型）\u3000ブラジル国債ファンド（年２回決算型）',
        fund_name_yomi='ブラジルコクサイファンドマイツキブンパイガタ\u3000ブラジルコクサイファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08770': FundCodeEntry(
        fund_code='G08770',
        sec_code=None,
        fund_name='米ドル建\u3000ＤＷＳ\u3000エマージング・ソブリン・ボンド・ファンド（豪ドルコース／毎月分配型）',
        fund_name_yomi='ベイドルダテディーダブリューエスエマージングソブリンボンドファンドゴウドルコースマイツキブンパイガタ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14961',
        issuer_name='ＤＷＳインベストメント・エス・エー',
    ),
    'G08774': FundCodeEntry(
        fund_code='G08774',
        sec_code=None,
        fund_name='パインブリッジ日本住宅金融支援機構債ファンド',
        fund_name_yomi='パインブリッジニホンジュウタクキンユウシエンキコウサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G08775': FundCodeEntry(
        fund_code='G08775',
        sec_code=None,
        fund_name='ＧＳグロース・マーケッツ・ファンド\u3000株式Ａコース（米ドル売り円買い）／株式Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000グロース\u3000マーケッツ\u3000ファンド\u3000カブシキエーコース\u3000ベイドルウリエンガイ\u3000カブシキビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G08780': FundCodeEntry(
        fund_code='G08780',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリーグローバル・インフラ債券ファンド＜為替ヘッジあり＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーグローバルインフラサイケンファンドカワセヘッジアリカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08781': FundCodeEntry(
        fund_code='G08781',
        sec_code='32790',
        fund_name='アクティビア・プロパティーズ投資法人',
        fund_name_yomi='アクティビアプロパティーズトウシホウジン',
        security_type='内国投資証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E26572',
        issuer_name='アクティビア・プロパティーズ投資法人',
    ),
    'G08782': FundCodeEntry(
        fund_code='G08782',
        sec_code=None,
        fund_name='ちゅうぎん日経２２５インデックスファンド',
        fund_name_yomi='チュウギンニッケイニーニーゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G08784': FundCodeEntry(
        fund_code='G08784',
        sec_code=None,
        fund_name='インド債券ファンド（毎月分配型）',
        fund_name_yomi='インドサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08786': FundCodeEntry(
        fund_code='G08786',
        sec_code=None,
        fund_name='米国短期ハイ・イールド・ボンド・ファンド（為替ヘッジあり）、米国短期ハイ・イールド・ボンド・ファンド（為替ヘッジなし）',
        fund_name_yomi='ベイコクタンキハイイールドボンドファンドカワセヘッジアリ\u3000ベイコクタンキハイイールドボンドファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08787': FundCodeEntry(
        fund_code='G08787',
        sec_code=None,
        fund_name='ひふみプラス',
        fund_name_yomi='ヒフミプラス',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G08788': FundCodeEntry(
        fund_code='G08788',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２０５',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08789': FundCodeEntry(
        fund_code='G08789',
        sec_code=None,
        fund_name='米国製造業株式ファンド',
        fund_name_yomi='ベイコクセイゾウギョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G08793': FundCodeEntry(
        fund_code='G08793',
        sec_code=None,
        fund_name='フィデリティ・オーストラリア配当株投信',
        fund_name_yomi='フィデリティオーストラリアハイトウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G08794': FundCodeEntry(
        fund_code='G08794',
        sec_code=None,
        fund_name='ダイワ米国厳選株ファンド\u3000－イーグルアイ－：Ａコース（為替ヘッジあり）、Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ダイワベイコクゲンセンカブファンドイーグルアイエーコースカワセヘッジアリビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08796': FundCodeEntry(
        fund_code='G08796',
        sec_code=None,
        fund_name='インドネシア債券ファンド',
        fund_name_yomi='インドネシアサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08797': FundCodeEntry(
        fund_code='G08797',
        sec_code=None,
        fund_name='ニッセイオーストラリア高配当株ファンド（毎月決算型）／ニッセイマネープールファンド（豪高配当株Ｆ）',
        fund_name_yomi='ニッセイオーストラリアコウハイトウカブファンドマイツキケッサンガタ\u3000ニッセイマネープールファンドゴウコウハイトウカブエフ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08799': FundCodeEntry(
        fund_code='G08799',
        sec_code=None,
        fund_name='ＪＰＭインドネシア債券ファンド（毎月決算型）',
        fund_name_yomi='ジェイピーエムインドネシアサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G08801': FundCodeEntry(
        fund_code='G08801',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000欧州ハイイールド債券ファンド\u3000ユーロ円プレミアム（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイオウシュウハイイールドサイケンファンドユーロエンプレミアムマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08802': FundCodeEntry(
        fund_code='G08802',
        sec_code=None,
        fund_name='ニッセイ・ワールドスポーツ・ファンド－メダリスト－Ａコース（為替ヘッジあり）／ニッセイ・ワールドスポーツ・ファンド－メダリスト－Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ニッセイワールドスポーツファンドメダリストエーコースカワセヘッジアリ\u3000ニッセイワールドスポーツファンドメダリストビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08803': FundCodeEntry(
        fund_code='G08803',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000インド債券オープン（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイインドサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08804': FundCodeEntry(
        fund_code='G08804',
        sec_code=None,
        fund_name='オーストラリア・高配当株ファンド（毎月決算型）',
        fund_name_yomi='オーストラリアコウハイトウカブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08805': FundCodeEntry(
        fund_code='G08805',
        sec_code=None,
        fund_name='グローバル・ハイブリッド証券ファンド（為替ヘッジ型）グローバル・ハイブリッド証券ファンド（為替ノーヘッジ型）',
        fund_name_yomi='グローバルハイブリッドショウケンファンドカワセヘッジガタグローバルハイブリッドショウケンファンドカワセノーヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08807': FundCodeEntry(
        fund_code='G08807',
        sec_code=None,
        fund_name='野村日本高配当株プレミアム（円コース）毎月分配型、野村日本高配当株プレミアム（円コース）年２回決算型、野村日本高配当株プレミアム（通貨セレクトコース）毎月分配型、野村日本高配当株プレミアム（通貨セレクトコース）年２回決算型',
        fund_name_yomi='ノムラニホンコウハイトウカブプレミアムエンコースマイツキブンパイガタ\u3000ノムラニホンコウハイトウカブプレミアムエンコースネンニカイケッサンガタ\u3000ノムラニホンコウハイトウカブプレミアムツウカセレクトコースマイツキブンパイガタ\u3000ノムラニホンコウハイトウカブプレミアムツウカセレクトコースネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08808': FundCodeEntry(
        fund_code='G08808',
        sec_code=None,
        fund_name='Ｏｎｅオーストラリアリートオープン',
        fund_name_yomi='ワンオーストラリアリートオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08812': FundCodeEntry(
        fund_code='G08812',
        sec_code=None,
        fund_name='アジア・ハイイールド債券ファンド（為替ヘッジなし）、アジア・ハイイールド債券ファンド（為替ヘッジあり）',
        fund_name_yomi='アジア\u3000ハイイールドサイケンファンド\u3000カワセヘッジナシ\u3000\u3000アジア\u3000ハイイールドサイケンファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08813': FundCodeEntry(
        fund_code='G08813',
        sec_code=None,
        fund_name='ニッセイ豪州ハイ・インカム株式ファンド（毎月決算型）',
        fund_name_yomi='ニッセイゴウシュウハイインカムカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08816': FundCodeEntry(
        fund_code='G08816',
        sec_code=None,
        fund_name='欧州ハイイールド債券ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='オウシュウハイイールドサイケンファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08818': FundCodeEntry(
        fund_code='G08818',
        sec_code=None,
        fund_name='新興国連続増配成長株オープン',
        fund_name_yomi='シンコウコクレンゾクゾウハイセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08820': FundCodeEntry(
        fund_code='G08820',
        sec_code=None,
        fund_name='ダイワ日本リート・ファンド、ダイワ日本リート・ファンド・マネー・ポートフォリオ',
        fund_name_yomi='ダイワニホンリートファンドダイワニホンリートファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08828': FundCodeEntry(
        fund_code='G08828',
        sec_code=None,
        fund_name='ダイワ先進国リートα：為替ヘッジあり（毎月分配型）、為替ヘッジなし（毎月分配型）',
        fund_name_yomi='ダイワセンシンコクリートアルファカワセヘッジアリマイツキブンパイガタカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08829': FundCodeEntry(
        fund_code='G08829',
        sec_code=None,
        fund_name='通貨選択型ダイワ先進国リートα：円ヘッジコース（毎月分配型）、通貨セレクトコース（毎月分配型）',
        fund_name_yomi='ツウカセンタクガタダイワセンシンコクリートアルファエンヘッジコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08830': FundCodeEntry(
        fund_code='G08830',
        sec_code=None,
        fund_name='みずほＡＢトラストシリーズ－みずほＵＳハイインカム・ボンド・ファンド',
        fund_name_yomi='ミズホエービートラストシリーズミズホユーエスハイインカムボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E06241',
        issuer_name='アライアンス・バーンスタイン・エル・ピー',
    ),
    'G08837': FundCodeEntry(
        fund_code='G08837',
        sec_code=None,
        fund_name='ワールド・バリュー・アロケーション\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ワールドバリューアロケーションエーコースカワセヘッジアリビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G08838': FundCodeEntry(
        fund_code='G08838',
        sec_code=None,
        fund_name='ニュージーランド株式ファンド',
        fund_name_yomi='ニュージーランドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G08839': FundCodeEntry(
        fund_code='G08839',
        sec_code=None,
        fund_name='アジア・ハイイールド債券ファンド毎月分配型（通貨アクティブヘッジコース）',
        fund_name_yomi='ニッコウアジアハイイールドサイケンファンドマイツキブンパイガタツウカアクティブヘッジコース',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08845': FundCodeEntry(
        fund_code='G08845',
        sec_code=None,
        fund_name='ＲＳ豪ドル債券ファンド',
        fund_name_yomi='アールエスゴウドルサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08851': FundCodeEntry(
        fund_code='G08851',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ワールド・ハイ・ディビデンド・イールド・ストック・プレミアム',
        fund_name_yomi='ノムラファンドセレクトワールドハイディビデンドイールドストックプレミアム',
        security_type='外国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G08852': FundCodeEntry(
        fund_code='G08852',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国リートファンドＡ＜為替ヘッジあり＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイベイコクリートファンドエーカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08858': FundCodeEntry(
        fund_code='G08858',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ヘッジ付外国債券オープン',
        fund_name_yomi='ミツビシユーエフジェイヘッジツキガイコクサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08861': FundCodeEntry(
        fund_code='G08861',
        sec_code=None,
        fund_name='コア投資戦略ファンド',
        fund_name_yomi='コアトウシセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08867': FundCodeEntry(
        fund_code='G08867',
        sec_code=None,
        fund_name='オーストラリア好配当株式オープン（毎月決算型）',
        fund_name_yomi='オーストラリアコウハイトウカブシキオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08869': FundCodeEntry(
        fund_code='G08869',
        sec_code=None,
        fund_name='ＭＡＸＩＳトピックスリスクコントロール（１０％）上場投信',
        fund_name_yomi='マクシストピックスリスクコントロールジュッパーセントジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08871': FundCodeEntry(
        fund_code='G08871',
        sec_code=None,
        fund_name='世界シェールガス株ファンド',
        fund_name_yomi='セカイシェールガスカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G08875': FundCodeEntry(
        fund_code='G08875',
        sec_code=None,
        fund_name='豪州高配当株ツインαファンド（毎月分配型）',
        fund_name_yomi='ゴウシュウコウハイトウカブツインアルファファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G08876': FundCodeEntry(
        fund_code='G08876',
        sec_code=None,
        fund_name='アジアリートファンド（毎月分配型）',
        fund_name_yomi='アジアリートファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08877': FundCodeEntry(
        fund_code='G08877',
        sec_code=None,
        fund_name='ニッポン・オフショア・ファンズ－エマージング・カレンシー・ボンド・ファンド',
        fund_name_yomi='ニッポンオフショアファンズエマージングカレンシーボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G08878': FundCodeEntry(
        fund_code='G08878',
        sec_code=None,
        fund_name='米国リート・プレミアムファンド',
        fund_name_yomi='ベイコクリートプレミアムファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G08879': FundCodeEntry(
        fund_code='G08879',
        sec_code=None,
        fund_name='新興国債券インデックス・オープン（ＳＭＡ専用）',
        fund_name_yomi='シンコウコクサイケンインデックス\u3000オープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G08880': FundCodeEntry(
        fund_code='G08880',
        sec_code=None,
        fund_name='アジア\u3000ハイ・イールド・プラス（毎月決算型）（為替ヘッジあり）、アジア\u3000ハイ・イールド・プラス（毎月決算型）（為替ヘッジなし）',
        fund_name_yomi='アジアハイイールドプラスマイツキケッサンガタカワセヘッジアリ\u3000アジアハイイールドプラスマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08881': FundCodeEntry(
        fund_code='G08881',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２０８',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08882': FundCodeEntry(
        fund_code='G08882',
        sec_code=None,
        fund_name='ＤＷＳ\u3000グローバル公益債券ファンドＤＣ\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ディーダブリューエスグローバルコウエキサイケンファンドディーシーエーコースカワセヘッジアリビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G08888': FundCodeEntry(
        fund_code='G08888',
        sec_code=None,
        fund_name='オーストラリア・インカム株式ファンド（毎月分配型）',
        fund_name_yomi='オーストラリア\u3000インカムカブシキファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08889': FundCodeEntry(
        fund_code='G08889',
        sec_code=None,
        fund_name='ノーロード・パン・アジア高配当株式フォーカス（毎月分配型）',
        fund_name_yomi='ノーロード\u3000パン\u3000アジアコウハイトウカブシキフォーカス\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08891': FundCodeEntry(
        fund_code='G08891',
        sec_code=None,
        fund_name='ダイワ日本株・バリュー発掘ファンド・ヘッジ型（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワニホンカブバリューハックツファンドヘッジガタダイワエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08894': FundCodeEntry(
        fund_code='G08894',
        sec_code=None,
        fund_name='日興グラビティ・ファンド',
        fund_name_yomi='ニッコウグラビティ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08896': FundCodeEntry(
        fund_code='G08896',
        sec_code=None,
        fund_name='ＭＵＧＣ\u3000ＧＳケイマン・ファンド－ＧＳ\u3000オーストラリア・ハイブリッド証券ファンド',
        fund_name_yomi='エムユージーシージーエスケイマンファンドジーエスオーストラリアハイブリッドショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G08898': FundCodeEntry(
        fund_code='G08898',
        sec_code=None,
        fund_name='ラッセル・インベストメント新興国増配優良株\u3000Ａ（米ドル円ヘッジ）、ラッセル・インベストメント新興国増配優良株\u3000Ｂ（為替ヘッジなし）',
        fund_name_yomi='ラッセルインベストメントシンコウコクゾウハイユウリョウカブ\u3000エー\u3000ベイドルエンヘッジ\u3000ラッセルインベストメントシンコウコクゾウハイユウリョウカブ\u3000ビー\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2='12月3日',
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G08905': FundCodeEntry(
        fund_code='G08905',
        sec_code=None,
        fund_name='ダイワ／ミレーアセット・グローバル・グレートコンシューマー株式ファンド：（為替ヘッジあり）、（為替ヘッジなし）',
        fund_name_yomi='ダイワミレーアセットグローバルグレートコンシューマーカブシキファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08909': FundCodeEntry(
        fund_code='G08909',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000ＤＣ\u3000８資産バランスファンド（新興国１０）、ＤＩＡＭ\u3000ＤＣ\u3000８資産バランスファンド（新興国２０）、ＤＩＡＭ\u3000ＤＣ\u3000８資産バランスファンド（新興国３０）',
        fund_name_yomi='ダイアムディーシーハチシサンバランスファンドシンコウコクジュウ\u3000ダイアムディーシーハチシサンバランスファンドシンコウコクニジュウ\u3000ダイアムディーシーハチシサンバランスファンドシンコウコクサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08914': FundCodeEntry(
        fund_code='G08914',
        sec_code=None,
        fund_name='イーストスプリング・フィリピン株式オープン',
        fund_name_yomi='イーストスプリングフィリピンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G08920': FundCodeEntry(
        fund_code='G08920',
        sec_code=None,
        fund_name='ダイワ／ＮＢ・米国債券戦略ファンド：為替ヘッジあり（毎月分配型）、為替ヘッジなし（毎月分配型）',
        fund_name_yomi='ダイワエヌビーベイコクサイケンセンリャクファンドカワセヘッジアリマイツキブンパイガタカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08921': FundCodeEntry(
        fund_code='G08921',
        sec_code=None,
        fund_name='通貨選択型\u3000ダイワ／ＮＢ・米国債券戦略ファンド：日本円コース（毎月分配型）、通貨セレクトコース（毎月分配型）',
        fund_name_yomi='ツウカセンタクガタダイワエヌビーベイコクサイケンセンリャクファンドニホンエンコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08933': FundCodeEntry(
        fund_code='G08933',
        sec_code=None,
        fund_name='ダイワ豪ドル建て高利回り証券ファンド\u3000－予想分配金提示型－',
        fund_name_yomi='ダイワゴウドルダテコウリマワリショウケンファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08936': FundCodeEntry(
        fund_code='G08936',
        sec_code=None,
        fund_name='アセアン株式オープン',
        fund_name_yomi='アセアンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08937': FundCodeEntry(
        fund_code='G08937',
        sec_code=None,
        fund_name='野村高配当インフラ関連株プレミアム（円コース）毎月分配型、野村高配当インフラ関連株プレミアム（円コース）年２回決算型、野村高配当インフラ関連株プレミアム（通貨セレクトコース）毎月分配型、野村高配当インフラ関連株プレミアム（通貨セレクトコース）年２回決算型',
        fund_name_yomi='ノムラコウハイトウインフラカンレンカブプレミアムエンコースマイツキブンパイガタ\u3000ノムラコウハイトウインフラカンレンカブプレミアムエンコースネンニカイケッサンガタ\u3000ノムラコウハイトウインフラカンレンカブプレミアムツウカセレクトコースマイツキブンパイガタ\u3000ノムラコウハイトウインフラカンレンカブプレミアムツウカセレクトコースネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08938': FundCodeEntry(
        fund_code='G08938',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－アジア・ハイ・イールド・ボンド',
        fund_name_yomi='ノムラファンドセレクトアジアハイイールドボンド',
        security_type='外国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G08943': FundCodeEntry(
        fund_code='G08943',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２１０',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08945': FundCodeEntry(
        fund_code='G08945',
        sec_code=None,
        fund_name='ニッセイ／ＡＥＷ・ＵＳリートファンド為替ヘッジあり（毎月分配型）\u3000／\u3000ニッセイ／ＡＥＷ・ＵＳリートファンド為替ヘッジなし（毎月分配型）',
        fund_name_yomi='ニッセイエーイーダブリューユーエスリートファンドカワセヘッジアリマイツキブンパイガタ\u3000ニッセイエーイーダブリューユーエスリートファンドカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08946': FundCodeEntry(
        fund_code='G08946',
        sec_code=None,
        fund_name='ニッセイブラジル高配当株ファンド（毎月決算型）',
        fund_name_yomi='ニッセイブラジルコウハイトウカブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2='9月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08947': FundCodeEntry(
        fund_code='G08947',
        sec_code=None,
        fund_name='ジャパン・アクティブ・セレクト・オープン',
        fund_name_yomi='ジャパンアクティブセレクトオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08948': FundCodeEntry(
        fund_code='G08948',
        sec_code=None,
        fund_name='日本株・アクティブ・セレクト・オープン',
        fund_name_yomi='ニホンカブアクティブセレクトオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08951': FundCodeEntry(
        fund_code='G08951',
        sec_code=None,
        fund_name='投資のソムリエ',
        fund_name_yomi='トウシノソムリエ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08952': FundCodeEntry(
        fund_code='G08952',
        sec_code=None,
        fund_name='クルーズコントロール',
        fund_name_yomi='クルーズコントロール',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G08956': FundCodeEntry(
        fund_code='G08956',
        sec_code=None,
        fund_name='ハイグレード・オセアニア・ボンド・オープン・フレックスヘッジ（毎月決算型）',
        fund_name_yomi='ハイグレードオセアニアボンドオープンフレックスヘッジマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G08957': FundCodeEntry(
        fund_code='G08957',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000国内債券インデックスファンド（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイコクナイサイケンインデックスファンドカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08960': FundCodeEntry(
        fund_code='G08960',
        sec_code=None,
        fund_name='ニッセイオーストラリア利回り資産ファンド（毎月決算型）',
        fund_name_yomi='ニッセイオーストラリアリマワリシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G08961': FundCodeEntry(
        fund_code='G08961',
        sec_code=None,
        fund_name='東京海上・円資産バランスファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウエンシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G08963': FundCodeEntry(
        fund_code='G08963',
        sec_code=None,
        fund_name='アジア社債ファンド\u3000Ａコース（為替ヘッジあり）、アジア社債ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='アジアシャサイファンド\u3000エーコース\u3000カワセヘッジアリ\u3000アジアシャサイファンド\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08969': FundCodeEntry(
        fund_code='G08969',
        sec_code=None,
        fund_name='サイエンティフィック・エクイティ・ファンド',
        fund_name_yomi='サイエンティフィックエクイティファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G08971': FundCodeEntry(
        fund_code='G08971',
        sec_code=None,
        fund_name='グローイング台湾株式ファンド',
        fund_name_yomi='グローイングタイワンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G08972': FundCodeEntry(
        fund_code='G08972',
        sec_code=None,
        fund_name='ステートストリート・ゴールドファンド（為替ヘッジあり）',
        fund_name_yomi='ステート\u3000ストリート\u3000ゴールド\u3000ファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G08974': FundCodeEntry(
        fund_code='G08974',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２１１',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニイチイチ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G08976': FundCodeEntry(
        fund_code='G08976',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー\u3000オーストラリア・ハイインカム債券ファンド（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーオーストラリアハイインカムサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G08977': FundCodeEntry(
        fund_code='G08977',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞Ｊ－ＲＥＩＴインデックスファンド（毎月分配型）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ジェイリートインデックスファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G08984': FundCodeEntry(
        fund_code='G08984',
        sec_code=None,
        fund_name='中国Ａ株オープン',
        fund_name_yomi='チュウゴクエーカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G08990': FundCodeEntry(
        fund_code='G08990',
        sec_code=None,
        fund_name='スイス株式ファンド',
        fund_name_yomi='スイスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G08993': FundCodeEntry(
        fund_code='G08993',
        sec_code=None,
        fund_name='ロックフェラー・オールアメリカ株式ファンド',
        fund_name_yomi='ロックフェラー\u3000オールアメリカカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月27日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G08994': FundCodeEntry(
        fund_code='G08994',
        sec_code=None,
        fund_name='東京海上ストラテジック・トラストー東京海上Ｒｏｇｇｅグローバル・ハイブリッド・セキュリティーズ・ファンド',
        fund_name_yomi='トウキョウカイジョウストラテジックトラストトウキョウカイジョウロゲーグローバルハイブリッドセキュリティーズファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G08997': FundCodeEntry(
        fund_code='G08997',
        sec_code='32810',
        fund_name='ＧＬＰ投資法人',
        fund_name_yomi='ジーエルピートウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E27092',
        issuer_name='ＧＬＰ投資法人',
    ),
    'G08998': FundCodeEntry(
        fund_code='G08998',
        sec_code=None,
        fund_name='ブラジル高配当株オープン（毎月決算型）',
        fund_name_yomi='ブラジルコウハイトウカブオープン\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09002': FundCodeEntry(
        fund_code='G09002',
        sec_code=None,
        fund_name='実績配当型金銭信託（信託のチカラ）りそな日本国債オープン',
        fund_name_yomi='ジッセキハイトウガタキンセンシンタクシンタクノチカラリソナニホンコクサイオープン',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E03538',
        issuer_name='株式会社りそな銀行',
    ),
    'G09005': FundCodeEntry(
        fund_code='G09005',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１２１２',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチニイチニ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09007': FundCodeEntry(
        fund_code='G09007',
        sec_code='15720',
        fund_name='中国Ｈ株ブル２倍上場投信',
        fund_name_yomi='チュウゴクエイチカブブルニバイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='12月4日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G09008': FundCodeEntry(
        fund_code='G09008',
        sec_code='15730',
        fund_name='中国Ｈ株ベア上場投信',
        fund_name_yomi='チュウゴクエイチカブベアジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='12月4日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G09010': FundCodeEntry(
        fund_code='G09010',
        sec_code=None,
        fund_name='ＡＢケイマン・トラスト－エマージング・ボンド・ファンド（外貨建）‐円建－円ヘッジクラス',
        fund_name_yomi='エービーケイマントラストエマージングボンドファンドガイカダテ\u3000エンダテエンヘッジクラス',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E06241',
        issuer_name='アライアンス・バーンスタイン・エル・ピー',
    ),
    'G09012': FundCodeEntry(
        fund_code='G09012',
        sec_code=None,
        fund_name='フィデリティ・Ｊリート・アクティブ・ファンド',
        fund_name_yomi='フィデリティジェイリートアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G09018': FundCodeEntry(
        fund_code='G09018',
        sec_code=None,
        fund_name='アジア好利回りリート・ファンド',
        fund_name_yomi='アジアコウリマワリリートファンド',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09027': FundCodeEntry(
        fund_code='G09027',
        sec_code=None,
        fund_name='ダイワ・オーストラリア高配当株α（毎月分配型）：株式αコース、通貨αコース、株式＆通貨ツインαコース',
        fund_name_yomi='ダイワオーストラリアコウハイトウカブアルファマイツキブンパイガタカブシキアルファコースツウカアルファコースカブシキアンドツウカツインアルファコース',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09028': FundCodeEntry(
        fund_code='G09028',
        sec_code=None,
        fund_name='ストラテジック・リート・ファンド\u3000－予想分配金提示型－\u3000Ａコース（為替ヘッジあり）、Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ストラテジックリートファンド\u3000ヨソウブンパイキンテイジガタ\u3000エーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G09031': FundCodeEntry(
        fund_code='G09031',
        sec_code=None,
        fund_name='ＵＳ短期ハイ・イールド社債ファンド（為替ヘッジあり／毎月決算型）',
        fund_name_yomi='ユーエスタンキハイイールドシャサイファンドカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09033': FundCodeEntry(
        fund_code='G09033',
        sec_code='32820',
        fund_name='コンフォリア・レジデンシャル投資法人',
        fund_name_yomi='コンフォリアレジデンシャルトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E27159',
        issuer_name='コンフォリア・レジデンシャル投資法人',
    ),
    'G09040': FundCodeEntry(
        fund_code='G09040',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１３０１',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチサンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09043': FundCodeEntry(
        fund_code='G09043',
        sec_code=None,
        fund_name='ＵＢＳ米国成長株式リスク・コントロール・ファンド',
        fund_name_yomi='ユービーエスベイコクセイチョウカブシキリスクコントロールファンド',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G09044': FundCodeEntry(
        fund_code='G09044',
        sec_code=None,
        fund_name='ネクストコア',
        fund_name_yomi='ネクストコア',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09045': FundCodeEntry(
        fund_code='G09045',
        sec_code=None,
        fund_name='好配当グローバルＲＥＩＴプレミアム・ファンド\u3000円ヘッジありコース、好配当グローバルＲＥＩＴプレミアム・ファンド\u3000円ヘッジなしコース',
        fund_name_yomi='コウハイトウグローバルリートプレミアム\u3000ファンド\u3000エンヘッジアリコース\u3000コウハイトウグローバルリートプレミアム\u3000ファンド\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G09046': FundCodeEntry(
        fund_code='G09046',
        sec_code=None,
        fund_name='好配当グローバルＲＥＩＴプレミアム・ファンド\u3000通貨セレクトコース',
        fund_name_yomi='コウハイトウグローバルリートプレミアム\u3000ファンド\u3000ツウカセレクトコース',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G09050': FundCodeEntry(
        fund_code='G09050',
        sec_code=None,
        fund_name='アジアＲＥＩＴ・リサーチ・オープン（毎月決算型）',
        fund_name_yomi='アジアリート\u3000リサーチ\u3000オープン\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2='7月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09051': FundCodeEntry(
        fund_code='G09051',
        sec_code=None,
        fund_name='日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（メキシコペソコース）',
        fund_name_yomi='ニッコウピムコ\u3000ハイインカム\u3000ソブリン\u3000ファンドマイツキブンパイガタ\u3000メキシコペソコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09054': FundCodeEntry(
        fund_code='G09054',
        sec_code='32830',
        fund_name='日本プロロジスリート投資法人',
        fund_name_yomi='ニッポンプロロジスリートトウシホウジン',
        security_type='内国投資証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E27230',
        issuer_name='日本プロロジスリート投資法人',
    ),
    'G09056': FundCodeEntry(
        fund_code='G09056',
        sec_code=None,
        fund_name='カレラＪリートファンド',
        fund_name_yomi='カレラジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G09057': FundCodeEntry(
        fund_code='G09057',
        sec_code=None,
        fund_name='ピクテ・アセット・アロケーション・ファンド（１年決算型）',
        fund_name_yomi='ピクテアセットアロケーションファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G09058': FundCodeEntry(
        fund_code='G09058',
        sec_code=None,
        fund_name='野村ＤＣテンプルトン・トータル・リターン\u3000Ａコース、野村ＤＣテンプルトン・トータル・リターン\u3000Ｂコース',
        fund_name_yomi='ノムラディーシーテンプルトントータルリターンエーコース\u3000ノムラディーシーテンプルトントータルリターンビーコース',
        security_type='内国投資信託受益証券',
        period_1='11月13日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09060': FundCodeEntry(
        fund_code='G09060',
        sec_code=None,
        fund_name='ＧＳアジア・ハイ・イールド債券ファンド\u3000米ドルコース／円コース',
        fund_name_yomi='ジーエスアジアハイイールドサイケンファンド\u3000ベイドルコース\u3000エンコース',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G09069': FundCodeEntry(
        fund_code='G09069',
        sec_code=None,
        fund_name='ＤＣニッセイ日本株グロースファンド',
        fund_name_yomi='ディーシーニッセイニホンカブグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09071': FundCodeEntry(
        fund_code='G09071',
        sec_code=None,
        fund_name='ＤＷＳ\u3000グローバル・ユーティリティ・ボンド・マスター・ファンド',
        fund_name_yomi='ディーダブリューエスグローバルユーティリティボンドマスターファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14961',
        issuer_name='ＤＷＳインベストメント・エス・エー',
    ),
    'G09073': FundCodeEntry(
        fund_code='G09073',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１３０２',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチサンゼロニ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09080': FundCodeEntry(
        fund_code='G09080',
        sec_code=None,
        fund_name='メキシコ債券ファンド（資産成長型）',
        fund_name_yomi='メキシコサイケンファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09081': FundCodeEntry(
        fund_code='G09081',
        sec_code=None,
        fund_name='メキシコ債券ファンド（毎月分配型）',
        fund_name_yomi='メキシコサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09083': FundCodeEntry(
        fund_code='G09083',
        sec_code=None,
        fund_name='ＨＳＢＣメキシコ株式オープン',
        fund_name_yomi='エイチエスビーシーメキシコカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G09084': FundCodeEntry(
        fund_code='G09084',
        sec_code=None,
        fund_name='ピクテ・プライム・インカム・コレクション（ヘッジ７０）毎月分配型、ピクテ・プライム・インカム・コレクション（ヘッジ７０）資産形成型',
        fund_name_yomi='ピクテプライムインカムコレクションヘッジナナジュウマイツキブンパイガタ\u3000ピクテプライムインカムコレクションヘッジナナジュウシサンケイセイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G09085': FundCodeEntry(
        fund_code='G09085',
        sec_code=None,
        fund_name='ＤＣニッセイ安定収益追求ファンド',
        fund_name_yomi='ディーシーニッセイアンテイシュウエキツイキュウファンド',
        security_type='内国投資信託受益証券',
        period_1='12月24日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09094': FundCodeEntry(
        fund_code='G09094',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー米国ハイインカムリートファンド＜為替ヘッジあり＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーベイコクハイインカムリートファンドカワセヘッジアリカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09097': FundCodeEntry(
        fund_code='G09097',
        sec_code=None,
        fund_name='三井住友マネー・リザーブ・ファンド（三井住友ＭＲＦ）',
        fund_name_yomi='ミツイスミトモマネーリザーブファンドミツイスミトモエムアールエフ',
        security_type='内国投資信託受益証券',
        period_1='2月28日',
        period_2='8月31日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09098': FundCodeEntry(
        fund_code='G09098',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国債券インデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーガイコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09099': FundCodeEntry(
        fund_code='G09099',
        sec_code=None,
        fund_name='ＤＣトヨタ自動車／トヨタグループ株式ファンド',
        fund_name_yomi='ディーシートヨタジドウシャトヨタグループカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09104': FundCodeEntry(
        fund_code='G09104',
        sec_code=None,
        fund_name='三井住友ＤＳ・海外株式ＥＴＦファンド',
        fund_name_yomi='ミツイスミトモディーエスカイガイカブシキイーティーエフファンド',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09107': FundCodeEntry(
        fund_code='G09107',
        sec_code=None,
        fund_name='三井住友・国債プラスファンド（毎月分配型）',
        fund_name_yomi='ミツイスミトモコクサイプラスファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09110': FundCodeEntry(
        fund_code='G09110',
        sec_code=None,
        fund_name='中部経済圏株式ファンド',
        fund_name_yomi='チュウブケイザイケンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月16日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09112': FundCodeEntry(
        fund_code='G09112',
        sec_code=None,
        fund_name='三井住友・配当フォーカスオープン',
        fund_name_yomi='ミツイスミトモハイトウフォーカスオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09113': FundCodeEntry(
        fund_code='G09113',
        sec_code=None,
        fund_name='トヨタ自動車／トヨタグループ株式ファンド',
        fund_name_yomi='トヨタジドウシャトヨタグループカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09115': FundCodeEntry(
        fund_code='G09115',
        sec_code=None,
        fund_name='ダイワ・ライジング・タイランド株式ファンド',
        fund_name_yomi='ダイワライジングタイランドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09117': FundCodeEntry(
        fund_code='G09117',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000グローバル・コーポレート・ボンド',
        fund_name_yomi='プレミアムファンズグローバルコーポレートボンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G09119': FundCodeEntry(
        fund_code='G09119',
        sec_code=None,
        fund_name='日興・新経済成長国エクイティ・ファンド',
        fund_name_yomi='ニッコウシンケイザイセイチョウコクエクイティファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09123': FundCodeEntry(
        fund_code='G09123',
        sec_code=None,
        fund_name='ＣｈｉｎａＡＭＣ\u3000ＣＳＩ\u3000３００\u3000Ｉｎｄｅｘ\u3000ＥＴＦ－ＪＤＲ',
        fund_name_yomi='チャイナエーエムシー\u3000シーエスアイ\u3000サンビャク\u3000インデックス\u3000イーティーエフ\u3000ジェーディーアール',
        security_type='外国信託受益証券・信託受益権',
        period_1='12月末日',
        period_2=None,
        edinet_code='E27312',
        issuer_name='チャイナ・アセット・マネジメント（香港）・リミテッド',
    ),
    'G09125': FundCodeEntry(
        fund_code='G09125',
        sec_code=None,
        fund_name='ＢＮＹメロン・リアル・リターン・ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ビーエヌワイメロンリアルリターンファンド\u3000エーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G09126': FundCodeEntry(
        fund_code='G09126',
        sec_code=None,
        fund_name='ピムコ世界債券戦略ファンド（毎月決算型）\u3000Ａコース（為替ヘッジあり）／ピムコ世界債券戦略ファンド（毎月決算型）\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ピムコセカイサイケンセンリャクファンドマイツキケッサンガタ\u3000エーコース\u3000カワセヘッジアリ\u3000ピムコセカイサイケンセンリャクファンドマイツキケッサンガタ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09127': FundCodeEntry(
        fund_code='G09127',
        sec_code=None,
        fund_name='＜中京＞アジア・オセアニア債券オープン（環境応援寄附付）',
        fund_name_yomi='チュウキョウアジアオセアニアサイケンオープンカンキョウオウエンキフツキ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09129': FundCodeEntry(
        fund_code='G09129',
        sec_code=None,
        fund_name='Ｊリート・アジアミックス・オープン（毎月決算型）',
        fund_name_yomi='ジェイリートアジアミックスオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09133': FundCodeEntry(
        fund_code='G09133',
        sec_code='15770',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000野村日本株高配当７０連動型上場投信',
        fund_name_yomi='ネクストファンズノムラニホンカブコウハイトウナナジュウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09135': FundCodeEntry(
        fund_code='G09135',
        sec_code=None,
        fund_name='ダイワ／フィデリティ北米株式ファンド\u3000－パラダイムシフト－',
        fund_name_yomi='ダイワフィデリティホクベイカブシキファンドパラダイムシフト',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09136': FundCodeEntry(
        fund_code='G09136',
        sec_code=None,
        fund_name='ＵＳストラテジック・インカム・ファンド\u3000Ａコース（為替ヘッジあり）、ＵＳストラテジック・インカム・ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ユーエスストラテジックインカムファンドエーコースカワセヘッジアリ\u3000ユーエスストラテジックインカムファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09139': FundCodeEntry(
        fund_code='G09139',
        sec_code=None,
        fund_name='メキシコ株式ファンド',
        fund_name_yomi='メキシコカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G09140': FundCodeEntry(
        fund_code='G09140',
        sec_code=None,
        fund_name='野村エマージング・ソブリン\u3000円投資型１３０３',
        fund_name_yomi='ノムラエマージングソブリンエントウシガタイチサンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09141': FundCodeEntry(
        fund_code='G09141',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ターキッシュ・ボンド',
        fund_name_yomi='ノムラファンドセレクトターキッシュボンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G09143': FundCodeEntry(
        fund_code='G09143',
        sec_code=None,
        fund_name='ウエスタン・アセット・オフショア・ファンド・シリーズ\u3000－\u3000ＷＡ\u3000バンクローン・ファンド（マルチ・カレンシー型）',
        fund_name_yomi='ウエスタンアセットオフショアファンドシリーズダブリュエーバンクローンファンドマルチカレンシーガタ',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E24736',
        issuer_name='ウエスタン・アセット・マネジメント・カンパニー・リミテッド',
    ),
    'G09144': FundCodeEntry(
        fund_code='G09144',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ・ＭＳＣＩ・グローイング・アセアン株式ファンド',
        fund_name_yomi='アラムコエムエスシーアイグローイングアセアンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G09146': FundCodeEntry(
        fund_code='G09146',
        sec_code=None,
        fund_name='利回り株チャンス１３－０３（年４回決算型）',
        fund_name_yomi='リマワリカブチャンスジュウサンゼロサンネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09153': FundCodeEntry(
        fund_code='G09153',
        sec_code=None,
        fund_name='楽天みらいファンド',
        fund_name_yomi='ラクテンミライファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G09154': FundCodeEntry(
        fund_code='G09154',
        sec_code='15780',
        fund_name='上場インデックスファンド日経２２５（ミニ）',
        fund_name_yomi='ジョウジョウインデックスファンドニッケイニーニーゴ\u3000ミニ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09159': FundCodeEntry(
        fund_code='G09159',
        sec_code=None,
        fund_name='高格付債券ファンド（為替ヘッジ７０）資産成長型',
        fund_name_yomi='コウカクヅケサイケンファンド\u3000カワセヘッジナナジュウ\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09160': FundCodeEntry(
        fund_code='G09160',
        sec_code=None,
        fund_name='高格付債券ファンド（為替ヘッジ７０）毎月分配型',
        fund_name_yomi='コウカクヅケサイケンファンド\u3000カワセヘッジナナジュウ\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09161': FundCodeEntry(
        fund_code='G09161',
        sec_code=None,
        fund_name='ファイン・ブレンド（資産成長型）',
        fund_name_yomi='ファイン\u3000ブレンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09162': FundCodeEntry(
        fund_code='G09162',
        sec_code=None,
        fund_name='ファイン・ブレンド（毎月分配型）',
        fund_name_yomi='ファイン\u3000ブレンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09163': FundCodeEntry(
        fund_code='G09163',
        sec_code=None,
        fund_name='日興ＪＰＭ環太平洋ディスカバリー・ファンド',
        fund_name_yomi='ニッコウジェイピーエムカンタイヘイヨウディスカバリーファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G09164': FundCodeEntry(
        fund_code='G09164',
        sec_code=None,
        fund_name='ＪＰＭ北米高配当・成長株ファンド（為替ヘッジなし、３ヵ月決算型）／ＪＰＭ北米高配当・成長株ファンド（米ドル対円ヘッジあり、３ヵ月決算型）／ＪＰＭ北米高配当・成長株ファンド（為替ヘッジなし、年２回決算型）／ＪＰＭ北米高配当・成長株ファンド（米ドル対円ヘッジあり、年２回決算型）',
        fund_name_yomi='ジェイピーエムホクベイコウハイトウセイチョウカブファンドカワセヘッジナシサンカゲツケッサンガタジェイピーエムホクベイコウハイトウセイチョウカブファンドベイドルタイエンヘッジアリサンカゲツケッサンガタジェイピーエムホクベイコウハイトウセイチョウカブファンドカワセヘッジナシネンニカイケッサンガタジェイピーエムホクベイコウハイトウセイチョウカブファンドベイドルタイエンヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G09172': FundCodeEntry(
        fund_code='G09172',
        sec_code=None,
        fund_name='分散投資コア戦略ファンド',
        fund_name_yomi='ブンサントウシコアセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09176': FundCodeEntry(
        fund_code='G09176',
        sec_code=None,
        fund_name='野村ＤＣ運用戦略ファンド（マイルド）',
        fund_name_yomi='ノムラディーシーウンヨウセンリャクファンドマイルド',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09178': FundCodeEntry(
        fund_code='G09178',
        sec_code=None,
        fund_name='野村Ｊリートファンド',
        fund_name_yomi='ノムラジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2='7月6日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09180': FundCodeEntry(
        fund_code='G09180',
        sec_code=None,
        fund_name='ダイワ・ライジング・アセアン株式ファンド',
        fund_name_yomi='ダイワライジングアセアンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09183': FundCodeEntry(
        fund_code='G09183',
        sec_code=None,
        fund_name='ＤＩＡＭ－ジャナス\u3000グローバル債券コアプラス・ファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムジャナスグローバルサイケンコアプラスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09185': FundCodeEntry(
        fund_code='G09185',
        sec_code=None,
        fund_name='みのりの投信',
        fund_name_yomi='ミノリノトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E27426',
        issuer_name='株式会社ポートフォリア',
    ),
    'G09186': FundCodeEntry(
        fund_code='G09186',
        sec_code=None,
        fund_name='オランダ株式ファンド',
        fund_name_yomi='オランダカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G09191': FundCodeEntry(
        fund_code='G09191',
        sec_code=None,
        fund_name='ＥＸＥ－ｉ\u3000先進国株式ファンド',
        fund_name_yomi='エグゼアイセンシンコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09192': FundCodeEntry(
        fund_code='G09192',
        sec_code=None,
        fund_name='ＥＸＥ－ｉ\u3000新興国株式ファンド',
        fund_name_yomi='エグゼアイシンコウコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09193': FundCodeEntry(
        fund_code='G09193',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・全世界債券インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ゼンセカイサイケンインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09194': FundCodeEntry(
        fund_code='G09194',
        sec_code=None,
        fund_name='ＥＸＥ－ｉ\u3000全世界ＲＥＩＴファンド',
        fund_name_yomi='エグゼアイゼンセカイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09196': FundCodeEntry(
        fund_code='G09196',
        sec_code=None,
        fund_name='ＥＸＥ－ｉ\u3000全世界中小型株式ファンド',
        fund_name_yomi='エグゼアイゼンセカイチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09197': FundCodeEntry(
        fund_code='G09197',
        sec_code=None,
        fund_name='日本債券ベアファンド（５倍型）',
        fund_name_yomi='ニホンサイケンベアファンドゴバイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G09199': FundCodeEntry(
        fund_code='G09199',
        sec_code=None,
        fund_name='債券総合型ファンド（為替ヘッジあり）\u3000債券総合型ファンド（為替ヘッジなし）',
        fund_name_yomi='サイケンソウゴウガタファンド\u3000カワセヘッジアリ\u3000サイケンソウゴウガタファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09200': FundCodeEntry(
        fund_code='G09200',
        sec_code=None,
        fund_name='シェール関連株オープン',
        fund_name_yomi='シェールカンレンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月9日',
        period_2='10月9日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09202': FundCodeEntry(
        fund_code='G09202',
        sec_code=None,
        fund_name='野村カルミニャック・ファンド\u3000Ａコース、野村カルミニャック・ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラカルミニャックファンドエーコース\u3000ノムラカルミニャックファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09203': FundCodeEntry(
        fund_code='G09203',
        sec_code=None,
        fund_name='東京海上・ジャパン・オーナーズ株式オープン',
        fund_name_yomi='トウキョウカイジョウジャパンオーナーズカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G09206': FundCodeEntry(
        fund_code='G09206',
        sec_code=None,
        fund_name='コドモファンド',
        fund_name_yomi='コドモファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E15786',
        issuer_name='株式会社パリミキアセットマネジメント',
    ),
    'G09217': FundCodeEntry(
        fund_code='G09217',
        sec_code=None,
        fund_name='アメリカ高配当株オープン（毎月決算型）\u3000アメリカ高配当株オープン（年２回決算型）',
        fund_name_yomi='アメリカコウハイトウカブオープン\u3000マイツキケッサンガタ\u3000アメリカコウハイトウカブオープン\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09226': FundCodeEntry(
        fund_code='G09226',
        sec_code=None,
        fund_name='フィデリティ・ストラテジック・インカム・ファンド（資産成長型）Ｃコース（為替ヘッジ付き）\u3000フィデリティ・ストラテジック・インカム・ファンド（資産成長型）Ｄコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティストラテジックインカムファンドシサンセイチョウガタシーコースカワセヘッジツキ\u3000フィデリティストラテジックインカムファンドシサンセイチョウガタディーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G09227': FundCodeEntry(
        fund_code='G09227',
        sec_code=None,
        fund_name='アジアＲＥＩＴオープン（毎月分配型）',
        fund_name_yomi='アジアリートオープン\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09228': FundCodeEntry(
        fund_code='G09228',
        sec_code=None,
        fund_name='野村インデックスファンド・外国株式・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドガイコクカブシキカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09229': FundCodeEntry(
        fund_code='G09229',
        sec_code=None,
        fund_name='米国エネルギー革命関連ファンド\u3000Ａコース（為替ヘッジあり）、米国エネルギー革命関連ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ベイコクエネルギーカクメイカンレンファンドエーコースカワセヘッジアリ\u3000ベイコクエネルギーカクメイカンレンファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2='11月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09231': FundCodeEntry(
        fund_code='G09231',
        sec_code='15790',
        fund_name='日経平均ブル２倍上場投信',
        fund_name_yomi='ニッケイヘイキンブルニバイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G09232': FundCodeEntry(
        fund_code='G09232',
        sec_code='15800',
        fund_name='日経平均ベア上場投信',
        fund_name_yomi='ニッケイヘイキンベアジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G09235': FundCodeEntry(
        fund_code='G09235',
        sec_code=None,
        fund_name='ダイワ／ミレーアセット・アジア・セクターリーダー株ファンド',
        fund_name_yomi='ダイワミレーアセットアジアセクターリーダーカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09236': FundCodeEntry(
        fund_code='G09236',
        sec_code=None,
        fund_name='スマート・ミックス・Ｄガード（為替ヘッジあり）',
        fund_name_yomi='スマートミックスディーガードカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09241': FundCodeEntry(
        fund_code='G09241',
        sec_code=None,
        fund_name='次世代米国代表株ファンド',
        fund_name_yomi='ジセダイベイコクダイヒョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09242': FundCodeEntry(
        fund_code='G09242',
        sec_code=None,
        fund_name='Ｏｎｅ新興企業日本株ファンド',
        fund_name_yomi='ワンシンコウキギョウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09245': FundCodeEntry(
        fund_code='G09245',
        sec_code=None,
        fund_name='フィデリティ・ＵＳハイ・イールド・ファンド（資産成長型）Ｄ（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスハイイールドファンドシサンセイチョウガタディーカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G09246': FundCodeEntry(
        fund_code='G09246',
        sec_code=None,
        fund_name='日本復活成長株ファンド',
        fund_name_yomi='ニッポンフッカツセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G09248': FundCodeEntry(
        fund_code='G09248',
        sec_code=None,
        fund_name='ＭＵＧＣ\u3000ＧＳケイマン・ファンド－ＧＳエマージング・ハイ・イールド債券ファンド（マルチ・カレンシー型）',
        fund_name_yomi='エムユージーシージーエスケイマンファンドジーエスエマージングハイイールドサイケンファンドマルチカレンシーガタ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G09249': FundCodeEntry(
        fund_code='G09249',
        sec_code=None,
        fund_name='ＧＳ米国成長株集中投資ファンド\u3000毎月決算コース／年４回決算コース',
        fund_name_yomi='ジーエスベイコクセイチョウカブシュウチュウトウシファンド\u3000マイツキケッサンコース\u3000ネンヨンカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G09252': FundCodeEntry(
        fund_code='G09252',
        sec_code=None,
        fund_name='日本株・市場リスクコントロールファンド',
        fund_name_yomi='ニホンカブ\u3000シジョウリスクコントロールファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G09253': FundCodeEntry(
        fund_code='G09253',
        sec_code=None,
        fund_name='インフラ関連好配当資産ファンド（毎月決算型）（円投資型）／インフラ関連好配当資産ファンド（毎月決算型）（米ドル投資型）／インフラ関連好配当資産ファンド（毎月決算型）（豪ドル投資型）',
        fund_name_yomi='インフラカンレンコウハイトウシサンファンドマイツキケッサンガタエントウシガタ\u3000インフラカンレンコウハイトウシサンファンドマイツキケッサンガタベイドルトウシガタ\u3000インフラカンレンコウハイトウシサンファンドマイツキケッサンガタゴウドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09256': FundCodeEntry(
        fund_code='G09256',
        sec_code=None,
        fund_name='日興エドモン・ドゥ・ロスチャイルド・ラグジュアリーファンド',
        fund_name_yomi='ニッコウエドモンドゥロスチャイルドラグジュアリーファンド',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09259': FundCodeEntry(
        fund_code='G09259',
        sec_code=None,
        fund_name='ＤＩＡＭシェール株ファンド',
        fund_name_yomi='ダイアムシェールカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09263': FundCodeEntry(
        fund_code='G09263',
        sec_code=None,
        fund_name='ＲＳ日本株式ファンド',
        fund_name_yomi='アールエスニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09268': FundCodeEntry(
        fund_code='G09268',
        sec_code=None,
        fund_name='ダイワ日本株ストラテジーα（通貨選択型）\u3000－ジャパン・トリプルリターンズ－：日本円・コース（毎月分配型）、豪ドル・コース（毎月分配型）、ブラジル・レアル・コース（毎月分配型）、米ドル・コース（毎月分配型）、通貨セレクト・コース（毎月分配型）',
        fund_name_yomi='ダイワニホンカブストラテジーアルファツウカセンタクガタジャパントリプルリターンズニホンエンコースマイツキブンパイガタゴウドルコースマイツキブンパイガタブラジルレアルコースマイツキブンパイガタベイドルコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09269': FundCodeEntry(
        fund_code='G09269',
        sec_code=None,
        fund_name='シュローダー・インカムアセット・アロケーション（毎月決算型）\u3000Ａコース（為替ヘッジなし）、シュローダー・インカムアセット・アロケーション（毎月決算型）\u3000Ｂコース（為替ヘッジあり）',
        fund_name_yomi='シュローダーインカムアセットアロケーションマイツキケッサンガタエーコースカワセヘッジナシシュローダーインカムアセットアロケーションマイツキケッサンガタビーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2='12月3日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G09272': FundCodeEntry(
        fund_code='G09272',
        sec_code=None,
        fund_name='グローバル・リート・トリプル・プレミアム・ファンド（毎月分配型）（愛称：トリプル・プレミアム）',
        fund_name_yomi='グローバル\u3000リート\u3000トリプル\u3000プレミアム\u3000ファンド\u3000マイツキブンパイガタ\u3000アイショウ\u3000トリプル\u3000プレミアム',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09274': FundCodeEntry(
        fund_code='G09274',
        sec_code=None,
        fund_name='日本経済『大転換』ファンド',
        fund_name_yomi='ニホンケイザイダイテンカンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09277': FundCodeEntry(
        fund_code='G09277',
        sec_code=None,
        fund_name='イーストスプリング・タイ株式オープン',
        fund_name_yomi='イーストスプリングタイカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G09278': FundCodeEntry(
        fund_code='G09278',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国高配当株式プラス＜為替ヘッジあり＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイベイコクコウハイトウカブシキプラスカワセヘッジアリカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09282': FundCodeEntry(
        fund_code='G09282',
        sec_code=None,
        fund_name='スマート・ミックス・Ｄガード（為替ヘッジなし）',
        fund_name_yomi='スマートミックスディーガードカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09284': FundCodeEntry(
        fund_code='G09284',
        sec_code=None,
        fund_name='フィデリティ・ＵＳリート・ファンド（資産成長型）Ｃ（為替ヘッジあり）\u3000フィデリティ・ＵＳリート・ファンド（資産成長型）Ｄ（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスリートファンドシサンセイチョウガタシーカワセヘッジアリ\u3000フィデリティユーエスリートファンドシサンセイチョウガタデーカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G09286': FundCodeEntry(
        fund_code='G09286',
        sec_code=None,
        fund_name='ノーロード・シンガポール高配当株式フォーカス（毎月分配型）',
        fund_name_yomi='ノーロード\u3000シンガポールコウハイトウカブシキフォーカス\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09288': FundCodeEntry(
        fund_code='G09288',
        sec_code=None,
        fund_name='ニッセイＪリートインデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイジェイリートインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09289': FundCodeEntry(
        fund_code='G09289',
        sec_code=None,
        fund_name='野村エマージング債券プレミアム毎月分配型、野村エマージング債券プレミアム年２回決算型',
        fund_name_yomi='ノムラエマージングサイケンプレミアムマイツキブンパイガタ\u3000ノムラエマージングサイケンプレミアムネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2='11月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09290': FundCodeEntry(
        fund_code='G09290',
        sec_code=None,
        fund_name='ＤＷＳ\u3000グローバル・ユーティリティ・ボンド・マスター・ファンド（年１回分配型）',
        fund_name_yomi='ディーダブリューエスグローバルユーティリティボンドマスターファンドネンイチカイブンパイガタ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14961',
        issuer_name='ＤＷＳインベストメント・エス・エー',
    ),
    'G09291': FundCodeEntry(
        fund_code='G09291',
        sec_code='32870',
        fund_name='星野リゾート・リート投資法人',
        fund_name_yomi='ホシノリゾートリートトウシホウジン',
        security_type='内国投資証券',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E27652',
        issuer_name='星野リゾート・リート投資法人',
    ),
    'G09293': FundCodeEntry(
        fund_code='G09293',
        sec_code=None,
        fund_name='新経済成長ジャパン',
        fund_name_yomi='シンケイザイセイチョウジャパン',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09294': FundCodeEntry(
        fund_code='G09294',
        sec_code=None,
        fund_name='米国成長株式ファンド',
        fund_name_yomi='ベイコクセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09295': FundCodeEntry(
        fund_code='G09295',
        sec_code=None,
        fund_name='Ｔ＆Ｄ日本株ファンド（通貨選択型）',
        fund_name_yomi='ティーアンドディーニホンカブファンドツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G09296': FundCodeEntry(
        fund_code='G09296',
        sec_code=None,
        fund_name='ＭＵＧＣ／フィデリティ・トラスト－フィデリティ・北米経済圏・新成長株式ファンド',
        fund_name_yomi='エムユージーシーフィデリティトラストフィデリティホクベイケイザイケンシンセイチョウカブシキファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E30992',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G09299': FundCodeEntry(
        fund_code='G09299',
        sec_code=None,
        fund_name='野村通貨選択日本株投信',
        fund_name_yomi='ノムラツウカセンタクニホンカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09302': FundCodeEntry(
        fund_code='G09302',
        sec_code=None,
        fund_name='ニッセイＪリートオープン（年１回決算型）',
        fund_name_yomi='ニッセイジェイリートオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09303': FundCodeEntry(
        fund_code='G09303',
        sec_code=None,
        fund_name='ニッセイアジア好配当株式ファンド（年１回決算型）',
        fund_name_yomi='ニッセイアジアコウハイトウカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09308': FundCodeEntry(
        fund_code='G09308',
        sec_code=None,
        fund_name='ＪＰＭジャパンマイスター',
        fund_name_yomi='ジェイピーエムジャパンマイスター',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G09310': FundCodeEntry(
        fund_code='G09310',
        sec_code=None,
        fund_name='米国国債ファンド（年１回決算型）：為替ヘッジあり、為替ヘッジなし、フレックスヘッジ',
        fund_name_yomi='ベイコクコクサイファンドネンイッカイケッサンガタカワセヘッジアリカワセヘッジナシフレックスヘッジ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09311': FundCodeEntry(
        fund_code='G09311',
        sec_code=None,
        fund_name='高利回り社債オープン・為替ヘッジ（年１回決算型）高利回り社債オープン（年１回決算型）',
        fund_name_yomi='コウリマワリシャサイオープンカワセヘッジネンイチカイケッサンガタコウリマワリシャサイオープンネンイチカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09312': FundCodeEntry(
        fund_code='G09312',
        sec_code=None,
        fund_name='野村新興国債券投信・為替ヘッジあり（年１回決算型）野村新興国債券投信・為替ヘッジなし（年１回決算型）',
        fund_name_yomi='ノムラシンコウコクサイケントウシンカワセヘッジアリネンイチカイケッサンガタノムラシンコウコクサイケントウシンカワセヘッジナシネンイチカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09313': FundCodeEntry(
        fund_code='G09313',
        sec_code=None,
        fund_name='日興グラビティ・グローバル・ファンド',
        fund_name_yomi='ニッコウグラビティ\u3000グローバル\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09314': FundCodeEntry(
        fund_code='G09314',
        sec_code=None,
        fund_name='ノーロードＪリート・フォーカス（毎月分配型）',
        fund_name_yomi='ノーロードジェイリート\u3000フォーカス\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09315': FundCodeEntry(
        fund_code='G09315',
        sec_code=None,
        fund_name='ピムコ世界債券戦略ファンド（年１回決算型）\u3000Ｃコース（為替ヘッジあり）／ピムコ世界債券戦略ファンド（年１回決算型）\u3000Ｄコース（為替ヘッジなし）',
        fund_name_yomi='ピムコセカイサイケンセンリャクファンド\u3000ネンイッカイケッサンガタ\u3000シーコース\u3000\u3000カワセヘッジアリ\u3000ピムコセカイサイケンセンリャクファンド\u3000ネンイッカイケッサンガタ\u3000ディーコース\u3000\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09317': FundCodeEntry(
        fund_code='G09317',
        sec_code=None,
        fund_name='通貨選択型ニッセイ世界高配当株ファンド（毎月決算型）／通貨選択型ニッセイ世界高配当株ファンド（年２回決算型）',
        fund_name_yomi='ツウカセンタクガタニッセイセカイコウハイトウカブファンドマイツキケッサンガタ\u3000ツウカセンタクガタニッセイセカイコウハイトウカブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09319': FundCodeEntry(
        fund_code='G09319',
        sec_code=None,
        fund_name='ニッセイ世界高配当株ファンド（毎月決算型）／ニッセイ世界高配当株ファンド（年２回決算型）',
        fund_name_yomi='ニッセイセカイコウハイトウカブファンドマイツキケッサンガタ\u3000ニッセイセカイコウハイトウカブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09327': FundCodeEntry(
        fund_code='G09327',
        sec_code=None,
        fund_name='コアバランス',
        fund_name_yomi='コアバランス',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09328': FundCodeEntry(
        fund_code='G09328',
        sec_code=None,
        fund_name='ＪＰＭグローバル医療関連株式ファンド',
        fund_name_yomi='ジェイピーエムグローバルイリョウカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G09329': FundCodeEntry(
        fund_code='G09329',
        sec_code=None,
        fund_name='みずほジャパン・アクティブ・ストラテジー（通貨選択型）',
        fund_name_yomi='ミズホジャパンアクティブストラテジーツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09332': FundCodeEntry(
        fund_code='G09332',
        sec_code=None,
        fund_name='短期ロシアルーブル債オープン（毎月分配型）',
        fund_name_yomi='タンキロシアルーブルサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09333': FundCodeEntry(
        fund_code='G09333',
        sec_code=None,
        fund_name='ニッセイアメリカ高配当株ファンド（毎月決算型）／ニッセイアメリカ高配当株ファンド（年２回決算型）',
        fund_name_yomi='ニッセイアメリカコウハイトウカブファンドマイツキケッサンガタ\u3000ニッセイアメリカコウハイトウカブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2='12月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09334': FundCodeEntry(
        fund_code='G09334',
        sec_code=None,
        fund_name='インドネシア・ルピア債券ファンド（毎月決算型）',
        fund_name_yomi='インドネシア\u3000ルピアサイケンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09335': FundCodeEntry(
        fund_code='G09335',
        sec_code=None,
        fund_name='ＤＣ世界経済インデックスファンド（株式シフト型）',
        fund_name_yomi='ディーシーセカイケイザイインデックスファンド\u3000カブシキシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09336': FundCodeEntry(
        fund_code='G09336',
        sec_code=None,
        fund_name='ＤＣ世界経済インデックスファンド（債券シフト型）',
        fund_name_yomi='ディーシーセカイケイザイインデックスファンド\u3000サイケンシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09339': FundCodeEntry(
        fund_code='G09339',
        sec_code=None,
        fund_name='カタール・アブダビ株式ファンド',
        fund_name_yomi='カタール\u3000アブダビカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G09341': FundCodeEntry(
        fund_code='G09341',
        sec_code=None,
        fund_name='スマート・アロケーション・Ｄガード',
        fund_name_yomi='スマートアロケーションディーガード',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09342': FundCodeEntry(
        fund_code='G09342',
        sec_code=None,
        fund_name='インド・ボンド・オープン（毎月決算型）',
        fund_name_yomi='インドボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09343': FundCodeEntry(
        fund_code='G09343',
        sec_code=None,
        fund_name='スマート・ファイブ（１年決算型）',
        fund_name_yomi='スマート\u3000ファイブ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09344': FundCodeEntry(
        fund_code='G09344',
        sec_code=None,
        fund_name='スマート・ファイブ（毎月決算型）',
        fund_name_yomi='スマート\u3000ファイブ\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09345': FundCodeEntry(
        fund_code='G09345',
        sec_code=None,
        fund_name='米国好配当株プレミアム戦略ファンド（毎月分配型）株式コース、米国好配当株プレミアム戦略ファンド（毎月分配型）株式＆通貨コース',
        fund_name_yomi='ベイコクコウハイトウカブプレミアムセンリャクファンド\u3000マイツキブンパイガタ\u3000カブシキコース\u3000ベイコクコウハイトウカブプレミアムセンリャクファンド\u3000マイツキブンパイガタ\u3000カブシキアンドツウカコース',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G09347': FundCodeEntry(
        fund_code='G09347',
        sec_code=None,
        fund_name='りそな日本株リサーチ戦略ファンド（オープン型）',
        fund_name_yomi='リソナニホンカブリサーチセンリャクファンドオープンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G09348': FundCodeEntry(
        fund_code='G09348',
        sec_code=None,
        fund_name='スパークス・少数精鋭・日本株ファンド',
        fund_name_yomi='スパークス\u3000ショウスウセイエイ\u3000ニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G09351': FundCodeEntry(
        fund_code='G09351',
        sec_code=None,
        fund_name='ＵＳ債券ＮＢ戦略ファンド：為替ヘッジあり／年１回決算型、為替ヘッジなし／年１回決算型',
        fund_name_yomi='ユーエスサイケンエヌビーセンリャクファンドカワセヘッジアリネンイッカイケッサンガタカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09352': FundCodeEntry(
        fund_code='G09352',
        sec_code=None,
        fund_name='ダイワ／ＮＢ・米国債券戦略ファンド（年１回決算型）：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワエヌビーベイコクサイケンセンリャクファンドネンイッカイケッサンガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09353': FundCodeEntry(
        fund_code='G09353',
        sec_code=None,
        fund_name='Ｂａｙｖｉｅｗ\u3000日本株式ロングショート\u3000ファンド',
        fund_name_yomi='ベイビューニホンカブシキロングショートファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2='5月25日',
        edinet_code='E27736',
        issuer_name='ベイビュー・アセット・マネジメント株式会社',
    ),
    'G09354': FundCodeEntry(
        fund_code='G09354',
        sec_code=None,
        fund_name='ニッセイ安定収益追求ファンド',
        fund_name_yomi='ニッセイアンテイシュウエキツイキュウファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09358': FundCodeEntry(
        fund_code='G09358',
        sec_code=None,
        fund_name='ＤＷＳ\u3000グローバル公益債券ファンド（年１回決算型）Ｃコース（為替ヘッジあり）／Ｄコース（為替ヘッジなし）',
        fund_name_yomi='ディーダブリューエスグローバルコウエキサイケンファンドネンイッカイケッサンガタシーコースカワセヘッジアリ\u3000ディーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G09359': FundCodeEntry(
        fund_code='G09359',
        sec_code=None,
        fund_name='バリュー・ボンド・ファンド＜為替リスク軽減型＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='バリューボンドファンドカワセリスクケイゲンガタカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月6日',
        period_2='10月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09360': FundCodeEntry(
        fund_code='G09360',
        sec_code=None,
        fund_name='バリュー・ボンド・ファンド＜為替リスク軽減型＞／＜為替ヘッジなし＞（年１回決算型）',
        fund_name_yomi='バリューボンドファンドカワセリスクケイゲンガタカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月6日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09364': FundCodeEntry(
        fund_code='G09364',
        sec_code=None,
        fund_name='ゴールドマン・サックス（ケイマン諸島）ユニット・トラスト－ＧＳ米国フォーカス・グロース',
        fund_name_yomi='ゴールドマンサックスケイマンショトウユニットトラストジーエスベイコクフォーカスグロース',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G09373': FundCodeEntry(
        fund_code='G09373',
        sec_code=None,
        fund_name='米国・シェールＭＬＰ・高配当株ファンド',
        fund_name_yomi='ベイコク\u3000シェールエムエルピー\u3000コウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E11776',
        issuer_name='あいグローバル・アセット・マネジメント株式会社',
    ),
    'G09374': FundCodeEntry(
        fund_code='G09374',
        sec_code=None,
        fund_name='Ｔ＆Ｄ日本株式投信（通貨選択型）米ドルコース',
        fund_name_yomi='ティアンドディニホンカブシキトウシンツウカセンタクガタベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G09375': FundCodeEntry(
        fund_code='G09375',
        sec_code=None,
        fund_name='インベスコ\u3000日本株式アドバンテージ・ファンド',
        fund_name_yomi='インベスコ\u3000ニホンカブシキアドバンテージファンド',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G09377': FundCodeEntry(
        fund_code='G09377',
        sec_code=None,
        fund_name='ダイワ日本国債ファンド（年１回決算型）',
        fund_name_yomi='ダイワニホンコクサイファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09378': FundCodeEntry(
        fund_code='G09378',
        sec_code=None,
        fund_name='ダイワ高格付カナダドル債オープン（年１回決算型）',
        fund_name_yomi='ダイワコウカクヅケカナダドルサイオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09379': FundCodeEntry(
        fund_code='G09379',
        sec_code=None,
        fund_name='通貨選択型ダイワ米国厳選株ファンド\u3000－イーグルアイⅡ－\u3000予想分配金提示型：日本円・コース、豪ドル・コース、ブラジル・レアル・コース、米ドル・コース、通貨セレクト・コース',
        fund_name_yomi='ツウカセンタクガタダイワベイコクゲンセンカブファンドイーグルアイツーヨソウブンパイキンテイジガタニホンエンコースゴウドルコースブラジルレアルコースベイドルコースツウカセレクトコース',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09381': FundCodeEntry(
        fund_code='G09381',
        sec_code=None,
        fund_name='日本金融ハイブリッド証券オープン（毎月分配型）\u3000円ヘッジありコース、日本金融ハイブリッド証券オープン（毎月分配型）\u3000円ヘッジなしコース',
        fund_name_yomi='ニホンキンユウハイブリッドショウケンオープン\u3000マイツキブンパイガタ\u3000エンヘッジアリコース\u3000ニホンキンユウハイブリッドショウケンオープン\u3000マイツキブンパイガタ\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G09382': FundCodeEntry(
        fund_code='G09382',
        sec_code=None,
        fund_name='ノムラ\u3000ＴＨＥ\u3000ＵＳＡ\u3000Ａコース、ノムラ\u3000ＴＨＥ\u3000ＵＳＡ\u3000Ｂコース',
        fund_name_yomi='ノムラザユーエスエーエーコース\u3000ノムラザユーエスエービーコース',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2='8月21日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09386': FundCodeEntry(
        fund_code='G09386',
        sec_code=None,
        fund_name='ピムコＵＳハイインカム・ローン・ファンド（毎月分配型）為替ヘッジなし、ピムコＵＳハイインカム・ローン・ファンド（毎月分配型）為替ヘッジあり',
        fund_name_yomi='ピムコユーエスハイインカム\u3000ローン\u3000ファンド\u3000マイツキブンパイガタ\u3000カワセヘッジナシ\u3000ピムコユーエスハイインカム\u3000ローン\u3000ファンド\u3000マイツキブンパイガタ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09388': FundCodeEntry(
        fund_code='G09388',
        sec_code=None,
        fund_name='トルコ・ボンド・オープン（年１回決算型）',
        fund_name_yomi='トルコボンドオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09389': FundCodeEntry(
        fund_code='G09389',
        sec_code=None,
        fund_name='ロシア株式ファンド',
        fund_name_yomi='ロシアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G09390': FundCodeEntry(
        fund_code='G09390',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＮＹダウインデックス',
        fund_name_yomi='イーマクシスニューヨークダウインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09394': FundCodeEntry(
        fund_code='G09394',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000メキシコ債券オープン＜為替ヘッジなし＞／＜為替アクティブヘッジ＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイメキシコサイケンオープンカワセヘッジナシカワセアクティブヘッジマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月4日',
        period_2='11月4日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09395': FundCodeEntry(
        fund_code='G09395',
        sec_code=None,
        fund_name='シュローダー・インカムアセット・アロケーション（１年決算型）\u3000Ａコース（為替ヘッジなし）、シュローダー・インカムアセット・アロケーション（１年決算型）\u3000Ｂコース（為替ヘッジあり）',
        fund_name_yomi='シュローダーインカムアセットアロケーションイチネンケッサンガタエーコースカワセヘッジナシシュローダーインカムアセットアロケーションイチネンケッサンガタビーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G09398': FundCodeEntry(
        fund_code='G09398',
        sec_code=None,
        fund_name='ダイワ欧州高配当株ファンド：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワオウシュウコウハイトウカブファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09399': FundCodeEntry(
        fund_code='G09399',
        sec_code=None,
        fund_name='ブラジル・ボンド・オープン（年１回決算型）',
        fund_name_yomi='ブラジルボンドオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09406': FundCodeEntry(
        fund_code='G09406',
        sec_code=None,
        fund_name='サムスンＫＯＤＥＸサムスングループ株証券上場指数投資信託［株式］',
        fund_name_yomi='サムスンコデックスサムスングループカブショウケンジョウジョウシスウトウシシンタクカブシキ',
        security_type='外国投資信託受益証券',
        period_1='12月31日',
        period_2=None,
        edinet_code='E15404',
        issuer_name='サムスン資産運用株式会社',
    ),
    'G09410': FundCodeEntry(
        fund_code='G09410',
        sec_code=None,
        fund_name='東京海上・ニッポン世界債券ファンド（為替ヘッジあり）（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウニッポンセカイサイケンファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G09411': FundCodeEntry(
        fund_code='G09411',
        sec_code=None,
        fund_name='東京海上・米国新興成長株式ファンド',
        fund_name_yomi='トウキョウカイジョウベイコクシンコウセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G09414': FundCodeEntry(
        fund_code='G09414',
        sec_code=None,
        fund_name='ＤＷＳ\u3000欧州ハイ・イールド債券ファンド（メキシコペソコース）（毎月分配型）／（トルコリラコース）（毎月分配型）',
        fund_name_yomi='ディーダブリューエスオウシュウハイイールドサイケンファンドメキシコペソコースマイツキブンパイガタトルコリラコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G09416': FundCodeEntry(
        fund_code='G09416',
        sec_code=None,
        fund_name='実績配当型金銭信託（信託のチカラ）りそな世界公共・金融債オープン',
        fund_name_yomi='ジッセキハイトウガタキンセンシンタクシンタクノチカラリソナセカイコウキョウキンユウサイオープン',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E03538',
        issuer_name='株式会社りそな銀行',
    ),
    'G09419': FundCodeEntry(
        fund_code='G09419',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000ゴールドインデックス・ファンド（為替ヘッジなし）',
        fund_name_yomi='アイシェアーズゴールドインデックスファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09420': FundCodeEntry(
        fund_code='G09420',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000コモディティインデックス・ファンド',
        fund_name_yomi='アイシェアーズコモディティインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09421': FundCodeEntry(
        fund_code='G09421',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000先進国リートインデックス・ファンド',
        fund_name_yomi='アイシェアーズセンシンコクリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09422': FundCodeEntry(
        fund_code='G09422',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000国内リートインデックス・ファンド',
        fund_name_yomi='アイシェアーズコクナイリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09425': FundCodeEntry(
        fund_code='G09425',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000新興国株式インデックス・ファンド',
        fund_name_yomi='アイシェアーズシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09428': FundCodeEntry(
        fund_code='G09428',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000米国株式（Ｓ＆Ｐ５００）インデックス・ファンド',
        fund_name_yomi='アイシェアーズベイコクカブシキエスアンドピーゴヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09429': FundCodeEntry(
        fund_code='G09429',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000先進国株式インデックス・ファンド',
        fund_name_yomi='アイシェアーズセンシンコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09430': FundCodeEntry(
        fund_code='G09430',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000国内株式インデックス・ファンド',
        fund_name_yomi='アイシェアーズコクナイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09432': FundCodeEntry(
        fund_code='G09432',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000ハイイールド債券インデックス・ファンド',
        fund_name_yomi='アイシェアーズハイイールドサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09435': FundCodeEntry(
        fund_code='G09435',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000先進国債券インデックス・ファンド',
        fund_name_yomi='アイシェアーズセンシンコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09436': FundCodeEntry(
        fund_code='G09436',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000国内債券インデックス・ファンド',
        fund_name_yomi='アイシェアーズコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09437': FundCodeEntry(
        fund_code='G09437',
        sec_code=None,
        fund_name='アジアＲＥＩＴ・リサーチ・オープン（年２回決算型）',
        fund_name_yomi='アジアリート\u3000リサーチ\u3000オープン\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2='7月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09438': FundCodeEntry(
        fund_code='G09438',
        sec_code=None,
        fund_name='ダイワ米国リート・ファンドⅡ（年１回決算型）',
        fund_name_yomi='ダイワベイコクリートファンドツーネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09439': FundCodeEntry(
        fund_code='G09439',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・オープン（年１回決算型）為替ヘッジなし',
        fund_name_yomi='ダイワユーエスリートオープンネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09440': FundCodeEntry(
        fund_code='G09440',
        sec_code=None,
        fund_name='ハイグレード・オセアニア・ボンド・オープン（年１回決算型）',
        fund_name_yomi='ハイグレードオセアニアボンドオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09446': FundCodeEntry(
        fund_code='G09446',
        sec_code=None,
        fund_name='ＥＴＦバランス・ファンド',
        fund_name_yomi='イーティーエフバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09447': FundCodeEntry(
        fund_code='G09447',
        sec_code=None,
        fund_name='日経２２５リスクコントロールオープン',
        fund_name_yomi='ニッケイニーニーゴリスクコントロールオープン',
        security_type='内国投資信託受益証券',
        period_1='8月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09452': FundCodeEntry(
        fund_code='G09452',
        sec_code=None,
        fund_name='コーポレート・ボンド・インカム（為替ヘッジ型／１年決算型）',
        fund_name_yomi='コーポレートボンドインカムカワセヘッジガタイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09453': FundCodeEntry(
        fund_code='G09453',
        sec_code=None,
        fund_name='コーポレート・ボンド・インカム（為替ノーヘッジ型／１年決算型）',
        fund_name_yomi='コーポレートボンドインカムカワセノーヘッジガタイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09454': FundCodeEntry(
        fund_code='G09454',
        sec_code=None,
        fund_name='キャピタル・エマージング・ストラテジー・ファンドＡコース（年２回決算／米ドル売り円買い）／Ｂコース（年２回決算／為替ヘッジなし）／Ｃコース（毎月分配／米ドル売り円買い）／Ｄコース（毎月分配／為替ヘッジなし）',
        fund_name_yomi='キャピタルエマージングストラテジーファンドエイコースネンニカイケッサンベイドルウリエンガイビーコースネンニカイケッサンカワセヘッジナシシーコースマイツキブンパイベイドルウリエンガイディーコースマイツキブンパイカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G09455': FundCodeEntry(
        fund_code='G09455',
        sec_code=None,
        fund_name='フィデリティ・日本中小型株・リサーチ・ファンド',
        fund_name_yomi='フィデリティニホンチュウコガタリサーチファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G09458': FundCodeEntry(
        fund_code='G09458',
        sec_code=None,
        fund_name='ニッセイ日本インカムオープン（年１回決算型）',
        fund_name_yomi='ニッセイニホンインカムオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G09462': FundCodeEntry(
        fund_code='G09462',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－テンプルトン世界債券ファンド\u3000外貨建てシリーズ',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000テンプルトンセカイサイケンファンド\u3000ガイカダテシリーズ',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G09465': FundCodeEntry(
        fund_code='G09465',
        sec_code=None,
        fund_name='ＳＭＢＣ・日興資産成長ナビゲーション',
        fund_name_yomi='エスエムビーシーニッコウシサンセイチョウナビゲーション',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G09466': FundCodeEntry(
        fund_code='G09466',
        sec_code=None,
        fund_name='米国連続増配成長株オープン',
        fund_name_yomi='ベイコクレンゾクゾウハイセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09471': FundCodeEntry(
        fund_code='G09471',
        sec_code=None,
        fund_name='日本物価連動国債ファンド',
        fund_name_yomi='ニホンブッカレンドウコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09472': FundCodeEntry(
        fund_code='G09472',
        sec_code=None,
        fund_name='ダイワ・トップ・オブ・ジャパン',
        fund_name_yomi='ダイワトップオブジャパン',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09473': FundCodeEntry(
        fund_code='G09473',
        sec_code=None,
        fund_name='通貨選択型ダイワ・トップ・オブ・ジャパン（米ドル投資型）',
        fund_name_yomi='ツウカセンタクガタダイワトップオブジャパンベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09474': FundCodeEntry(
        fund_code='G09474',
        sec_code=None,
        fund_name='ピクテ日本厳選株アルファ・プラス\u3000円コース',
        fund_name_yomi='ピクテニホンゲンセンカブアルファプラスエンコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G09475': FundCodeEntry(
        fund_code='G09475',
        sec_code=None,
        fund_name='ＵＢＳグローバルＣＢオープン（年１回決算型・為替ヘッジあり）／（年１回決算型・為替ヘッジなし）',
        fund_name_yomi='ユービーエスグローバルシービーオープン\u3000マイツキケッサンガタ\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G09476': FundCodeEntry(
        fund_code='G09476',
        sec_code=None,
        fund_name='ＵＢＳグローバルＣＢオープン（毎月決算型・為替ヘッジあり）／（毎月決算型・為替ヘッジなし）',
        fund_name_yomi='ユービーエスグローバルシービーオープン\u3000マイツキケッサンガタ\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G09477': FundCodeEntry(
        fund_code='G09477',
        sec_code=None,
        fund_name='米国短期ハイ・イールド債券オープン',
        fund_name_yomi='ベイコクタンキハイイールドサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09482': FundCodeEntry(
        fund_code='G09482',
        sec_code=None,
        fund_name='ダイワ外国債券ファンド（年１回決算型）－ダイワスピリット（年１回）－',
        fund_name_yomi='ダイワガイコクサイケンファンドネンイッカイケッサンガタダイワスピリットネンイッカイ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09483': FundCodeEntry(
        fund_code='G09483',
        sec_code=None,
        fund_name='ダイワ・インドネシア・ルピア債オープン（年１回決算型）',
        fund_name_yomi='ダイワインドネシアルピアサイオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09484': FundCodeEntry(
        fund_code='G09484',
        sec_code=None,
        fund_name='ダイワ・エマージング高金利債券ファンド（年１回決算型）',
        fund_name_yomi='ダイワエマージングコウキンリサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09485': FundCodeEntry(
        fund_code='G09485',
        sec_code=None,
        fund_name='東京海上Ｒｏｇｇｅニッポン海外債券ファンド（為替ヘッジあり）（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウロゲーニッポンカイガイサイケンファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G09487': FundCodeEntry(
        fund_code='G09487',
        sec_code=None,
        fund_name='ピクテ資源国ソブリン・ファンド（１年決算型）',
        fund_name_yomi='ピクテシゲンコクソブリンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G09491': FundCodeEntry(
        fund_code='G09491',
        sec_code=None,
        fund_name='ＤＩＡＭ新興企業日本株オープン\u3000米ドル型',
        fund_name_yomi='ダイアムシンコウキギョウニホンカブオープン\u3000ベイドルガタ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G09496': FundCodeEntry(
        fund_code='G09496',
        sec_code=None,
        fund_name='野村インデックスファンド・外国債券・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドガイコクサイケンカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09497': FundCodeEntry(
        fund_code='G09497',
        sec_code=None,
        fund_name='野村インデックスファンド・外国ＲＥＩＴ・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドガイコクリートカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09498': FundCodeEntry(
        fund_code='G09498',
        sec_code=None,
        fund_name='野村インデックスファンド・内外７資産バランス・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドナイガイナナシサンバランスカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09499': FundCodeEntry(
        fund_code='G09499',
        sec_code=None,
        fund_name='野村インデックスファンド・海外５資産バランス',
        fund_name_yomi='ノムラインデックスファンドカイガイゴシサンバランス',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G09500': FundCodeEntry(
        fund_code='G09500',
        sec_code=None,
        fund_name='ＢＡＭワールド・ボンド＆カレンシー・ファンド（１年決算型）',
        fund_name_yomi='バムワールドボンドアンドカレンシーファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E11348',
        issuer_name='ベアリングス・ジャパン株式会社',
    ),
    'G09502': FundCodeEntry(
        fund_code='G09502',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（米国）（１年決算型）',
        fund_name_yomi='ワールドリートセレクションベイコクイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09503': FundCodeEntry(
        fund_code='G09503',
        sec_code=None,
        fund_name='ワールド・リート・セレクション（米国）為替ヘッジあり（１年決算型）',
        fund_name_yomi='ワールドリートセレクションベイコクカワセヘッジアリイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09504': FundCodeEntry(
        fund_code='G09504',
        sec_code='32900',
        fund_name='Ｏｎｅリート投資法人',
        fund_name_yomi='ワンリートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E27884',
        issuer_name='Ｏｎｅリート投資法人',
    ),
    'G09505': FundCodeEntry(
        fund_code='G09505',
        sec_code=None,
        fund_name='資源株ファンド\u3000通貨選択シリーズ＜米ドル・コース＞（毎月分配型）',
        fund_name_yomi='シゲンカブファンド\u3000ツウカセンタクシリーズ\u3000ベイドル\u3000コース\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09506': FundCodeEntry(
        fund_code='G09506',
        sec_code=None,
        fund_name='資源ファンド（株式と通貨）メキシコペソ・コース、資源ファンド（株式と通貨）トルコリラ・コース、資源ファンド（株式と通貨）米ドル・コース',
        fund_name_yomi='シゲンファンド\u3000カブシキトツウカ\u3000メキシコペソ\u3000コース\u3000シゲンファンド\u3000カブシキトツウカ\u3000トルコリラ\u3000コース\u3000シゲンファンド\u3000カブシキトツウカ\u3000ベイドル\u3000コース',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09507': FundCodeEntry(
        fund_code='G09507',
        sec_code=None,
        fund_name='ブラックロック・ヘルスサイエンス・ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブラックロックヘルスサイエンスファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G09509': FundCodeEntry(
        fund_code='G09509',
        sec_code=None,
        fund_name='利回り株チャンス\u3000米ドル型（年４回決算型）',
        fund_name_yomi='リマワリカブチャンスベイドルガタネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09510': FundCodeEntry(
        fund_code='G09510',
        sec_code='15860',
        fund_name='上場インデックスファンドＴＯＰＩＸ\u3000Ｅｘ‐Ｆｉｎａｎｃｉａｌｓ',
        fund_name_yomi='ジョウジョウインデックスファンドトピックス\u3000イーエックス\u3000ファイナンシャルズ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G09514': FundCodeEntry(
        fund_code='G09514',
        sec_code=None,
        fund_name='日興ＪＰＭグローバル中小型株式ディスカバリー・ファンド',
        fund_name_yomi='ニッコウジェイピーエムグローバルチュウコガタカブシキディスカバリーファンド',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G09515': FundCodeEntry(
        fund_code='G09515',
        sec_code=None,
        fund_name='ＧＳ債券戦略ファンド\u3000Ａコース（毎月決算型、為替ヘッジあり）／Ｂコース（毎月決算型、為替ヘッジなし）／Ｃコース（年２回決算型、為替ヘッジあり）／Ｄコース（年２回決算型、為替ヘッジなし）',
        fund_name_yomi='ジーエスサイケンセンリャクファンド\u3000エーコース\u3000マイツキケッサンガタ\u3000カワセヘッジアリ\u3000ビーコース\u3000マイツキケッサンガタ\u3000カワセヘッジナシ\u3000シーコース\u3000ネンニカイケッサンガタ\u3000カワセヘッジアリ\u3000ディーコース\u3000ネンニカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G09517': FundCodeEntry(
        fund_code='G09517',
        sec_code='15850',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸ\u3000Ｅｘ‐Ｆｉｎａｎｃｉａｌｓ',
        fund_name_yomi='アイフリーイーティーエフトピックスエクスフィナンシャルズ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09518': FundCodeEntry(
        fund_code='G09518',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国バンクローンファンド\u3000通貨選択シリーズ',
        fund_name_yomi='ミツビシユーエフジェイベイコクバンクローンファンドツウカセンタクシリーズ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G09526': FundCodeEntry(
        fund_code='G09526',
        sec_code=None,
        fund_name='バンクローン・オープン（ＳＭＡ専用）',
        fund_name_yomi='バンクローン\u3000オープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09527': FundCodeEntry(
        fund_code='G09527',
        sec_code=None,
        fund_name='国内債券ＳＭＴＢセレクション（ＳＭＡ専用）',
        fund_name_yomi='コクナイサイケンエスエムティービーセレクション\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G09529': FundCodeEntry(
        fund_code='G09529',
        sec_code=None,
        fund_name='アジア・オセアニア好配当成長株オープン（１年決算型）',
        fund_name_yomi='アジアオセアニアコウハイトウセイチョウカブオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G09533': FundCodeEntry(
        fund_code='G09533',
        sec_code=None,
        fund_name='ダイワ米国国債ファンド－ラダー１０－：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワベイコクコクサイファンドラダーテンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G09535': FundCodeEntry(
        fund_code='G09535',
        sec_code=None,
        fund_name='マルチ・ストラテジーズ・ファンド－トルコリラ・マネー・マーケット・ファンド',
        fund_name_yomi='マルチストラテジーズファンドトルコリラマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E14984',
        issuer_name='インターナショナル・マネジメント・サービシズ・リミテッド',
    ),
    'G10000': FundCodeEntry(
        fund_code='G10000',
        sec_code=None,
        fund_name='ピクテ新興国インカム株式ファンド（１年決算型）',
        fund_name_yomi='ピクテシンコウコクインカムカブシキファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G10003': FundCodeEntry(
        fund_code='G10003',
        sec_code=None,
        fund_name='好配当米国株式プレミアム・ファンド\u3000通貨セレクト・プレミアムコース',
        fund_name_yomi='コウハイトウベイコクカブシキプレミアムファンド\u3000ツウカセレクトプレミアムコース',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10004': FundCodeEntry(
        fund_code='G10004',
        sec_code=None,
        fund_name='おとなのお財布＜奇数月定額払出型＞',
        fund_name_yomi='オトナノオサイフキスウヅキテイガクハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10006': FundCodeEntry(
        fund_code='G10006',
        sec_code=None,
        fund_name='三井住友・公益債券投信（資産成長型）',
        fund_name_yomi='ミツイスミトモコウエキサイケントウシンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10010': FundCodeEntry(
        fund_code='G10010',
        sec_code=None,
        fund_name='２１世紀東京\u3000日本株式ファンド',
        fund_name_yomi='ニジュウイッセイキトウキョウ\u3000ニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10011': FundCodeEntry(
        fund_code='G10011',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000バランス・イノベーション（株式抑制型）／（株式重視型）／（新興国投資型）',
        fund_name_yomi='ミツビシユーエフジェイバランスイノベーションカブシキヨクセイガタカブシキジュウシガタシンコウコクトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10012': FundCodeEntry(
        fund_code='G10012',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・オーストラリア債券ファンド（年２回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000オーストラリアサイケンファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G10014': FundCodeEntry(
        fund_code='G10014',
        sec_code=None,
        fund_name='三菱ＵＦＪ／ピムコ\u3000トータル・リターン・ファンド＜米ドルヘッジ型＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイピムコトータルリターンファンドベイドルヘッジガタカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10015': FundCodeEntry(
        fund_code='G10015',
        sec_code=None,
        fund_name='三菱ＵＦＪ／ピムコ\u3000トータル・リターン・ファンド＜米ドルヘッジ型＞／＜為替ヘッジなし＞（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイピムコトータルリターンファンドベイドルヘッジガタカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10016': FundCodeEntry(
        fund_code='G10016',
        sec_code=None,
        fund_name='ゴールドマン・サックス米国ＲＥＩＴファンドＣコース（年１回決算型、為替ヘッジあり）／Ｄコース（年１回決算型、為替ヘッジなし）',
        fund_name_yomi='ゴールドマン\u3000サックスベイコクリートファンドシーコース\u3000ネンイッカイケッサンガタ\u3000カワセヘッジアリ\u3000ディーコース\u3000ネンイッカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月23日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10017': FundCodeEntry(
        fund_code='G10017',
        sec_code=None,
        fund_name='コア投資戦略ファンド（切替型）',
        fund_name_yomi='コアトウシセンリャクファンド\u3000キリカエガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10018': FundCodeEntry(
        fund_code='G10018',
        sec_code=None,
        fund_name='ＧＡＲＳファンド',
        fund_name_yomi='ジーエーアールエスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10021': FundCodeEntry(
        fund_code='G10021',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000Ｊ－ＲＥＩＴアクティブファンド（１年決算型）',
        fund_name_yomi='ダイアムジェイリートアクティブファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10022': FundCodeEntry(
        fund_code='G10022',
        sec_code=None,
        fund_name='ダイワ外国３資産バランス・ファンド：部分為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワガイコクサンシサンバランスファンドブブンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10023': FundCodeEntry(
        fund_code='G10023',
        sec_code=None,
        fund_name='しんきん世界アロケーションファンド',
        fund_name_yomi='シンキンセカイアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G10024': FundCodeEntry(
        fund_code='G10024',
        sec_code=None,
        fund_name='ニッセイ世界リートオープン（毎月決算型）／ニッセイ世界リートオープン（年２回決算型）',
        fund_name_yomi='ニッセイセカイリートオープンマイツキケッサンガタ\u3000ニッセイセカイリートオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10030': FundCodeEntry(
        fund_code='G10030',
        sec_code=None,
        fund_name='りそな\u3000ダイナミック・アロケーション・ファンド',
        fund_name_yomi='リソナダイナミックアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10032': FundCodeEntry(
        fund_code='G10032',
        sec_code=None,
        fund_name='ラサール・グローバルＲＥＩＴファンド（１年決算型）',
        fund_name_yomi='ラサール\u3000グローバルリートファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10033': FundCodeEntry(
        fund_code='G10033',
        sec_code=None,
        fund_name='ＵＳストラテジック・インカム・アルファ\u3000毎月決算型',
        fund_name_yomi='ユーエスストラテジックインカムアルファマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10034': FundCodeEntry(
        fund_code='G10034',
        sec_code=None,
        fund_name='ＵＳストラテジック・インカム・アルファ\u3000年１回決算型',
        fund_name_yomi='ユーエスストラテジックインカムアルファネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10037': FundCodeEntry(
        fund_code='G10037',
        sec_code=None,
        fund_name='ニッセイＪ－ＲＥＩＴファンド（年１回決算型）',
        fund_name_yomi='ニッセイジェイリートファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10038': FundCodeEntry(
        fund_code='G10038',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１３－１１',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチサンイチイチ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10039': FundCodeEntry(
        fund_code='G10039',
        sec_code=None,
        fund_name='Ｊリート・アジアミックス・オープン（資産成長型）',
        fund_name_yomi='ジェイリートアジアミックスオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10040': FundCodeEntry(
        fund_code='G10040',
        sec_code=None,
        fund_name='三井住友・バンクローン・ファンド（為替ヘッジあり）毎月決算型、三井住友・バンクローン・ファンド（為替ヘッジあり）年２回決算型',
        fund_name_yomi='ミツイスミトモバンクローンファンドカワセヘッジアリマイツキケッサンガタ\u3000ミツイスミトモバンクローンファンドカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10046': FundCodeEntry(
        fund_code='G10046',
        sec_code=None,
        fund_name='ダイワ成長国セレクト債券ファンド（年１回決算型）',
        fund_name_yomi='ダイワセイチョウコクセレクトサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10051': FundCodeEntry(
        fund_code='G10051',
        sec_code=None,
        fund_name='ピムコ・エマージング・ボンド・オープン\u3000Ｃコース（為替ヘッジなし）／Ｄコース（為替ヘッジあり）（年１回決算型）',
        fund_name_yomi='ピムコエマージングボンドオープンシーコースカワセヘッジナシディーコースカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10052': FundCodeEntry(
        fund_code='G10052',
        sec_code=None,
        fund_name='投資のソムリエ＜ＤＣ年金＞',
        fund_name_yomi='トウシノソムリエディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10053': FundCodeEntry(
        fund_code='G10053',
        sec_code=None,
        fund_name='世界経済インデックスファンド（株式シフト型）',
        fund_name_yomi='セカイケイザイインデックスファンド\u3000カブシキシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10054': FundCodeEntry(
        fund_code='G10054',
        sec_code=None,
        fund_name='世界経済インデックスファンド（債券シフト型）',
        fund_name_yomi='セカイケイザイインデックスファンド\u3000サイケンシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10055': FundCodeEntry(
        fund_code='G10055',
        sec_code='32920',
        fund_name='イオンリート投資法人',
        fund_name_yomi='イオンリートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E30064',
        issuer_name='イオンリート投資法人',
    ),
    'G10059': FundCodeEntry(
        fund_code='G10059',
        sec_code=None,
        fund_name='ダイワ・ダブルバランス・ファンド（Ｄガード付／部分為替ヘッジあり）',
        fund_name_yomi='ダイワダブルバランスファンドディーガードツキブブンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10060': FundCodeEntry(
        fund_code='G10060',
        sec_code=None,
        fund_name='ダイワ外国３資産アロケーション・ファンド（部分為替ヘッジあり）',
        fund_name_yomi='ダイワガイコクサンシサンアロケーションファンドブブンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10061': FundCodeEntry(
        fund_code='G10061',
        sec_code=None,
        fund_name='ダイワ６資産バランス・ファンド（Ｄガード付）：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワロクシサンバランスファンドディーガードツキカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10062': FundCodeEntry(
        fund_code='G10062',
        sec_code=None,
        fund_name='ＨＳＢＣニューフロンティア株式オープン',
        fund_name_yomi='エイチエスビーシーニューフロンティアカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G10063': FundCodeEntry(
        fund_code='G10063',
        sec_code=None,
        fund_name='米国ハイ・インカムＢＤＣファンド（年１回決算型）',
        fund_name_yomi='ベイコクハイインカムビーディーシーファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10064': FundCodeEntry(
        fund_code='G10064',
        sec_code=None,
        fund_name='米国ハイ・インカムＢＤＣファンド（毎月決算型）',
        fund_name_yomi='ベイコクハイインカムビーディーシーファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10066': FundCodeEntry(
        fund_code='G10066',
        sec_code=None,
        fund_name='野村米国ハイ・イールド・ファンド（年１回決算型）、野村米国ハイ・イールド・ファンド（年１回決算型）為替ヘッジあり',
        fund_name_yomi='ノムラベイコクハイイールドファンドネンイッカイケッサンガタ\u3000ノムラベイコクハイイールドファンドネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10067': FundCodeEntry(
        fund_code='G10067',
        sec_code=None,
        fund_name='ダイワ・インフラビジネス・ファンド\u3000－インフラ革命－：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワインフラビジネスファンドインフラカクメイカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10068': FundCodeEntry(
        fund_code='G10068',
        sec_code=None,
        fund_name='みずほ・ケイマン・トラスト－ＵＳバンクローン・オープン（米ドル建）',
        fund_name_yomi='ミズホケイマントラストユーエスバンクローンオープンベイドルダテ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E31086',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G10073': FundCodeEntry(
        fund_code='G10073',
        sec_code=None,
        fund_name='ＤＩＡＭ８資産バランスファンドＮ＜ＤＣ年金＞',
        fund_name_yomi='ダイアムハチシサンバランスファンドエヌディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10074': FundCodeEntry(
        fund_code='G10074',
        sec_code=None,
        fund_name='アジア・オセアニア債券オープン（１年決算型）',
        fund_name_yomi='アジアオセアニアサイケンオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10077': FundCodeEntry(
        fund_code='G10077',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000新興国リートインデックス',
        fund_name_yomi='イーマクシスシンコウコクリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10080': FundCodeEntry(
        fund_code='G10080',
        sec_code=None,
        fund_name='東京海上Ｒｏｇｇｅ世界ハイブリッド証券ファンド\u3000円コース（年１回決算型）\u3000米ドルコース（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウロゲーセカイハイブリッドショウケンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10081': FundCodeEntry(
        fund_code='G10081',
        sec_code=None,
        fund_name='野村グローバル・ボンド・アクティブ・ファンド（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラグローバルボンドアクティブファンドノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10082': FundCodeEntry(
        fund_code='G10082',
        sec_code=None,
        fund_name='野村Ｊ－ＲＥＩＴファンド（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラジェイリートファンドノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10083': FundCodeEntry(
        fund_code='G10083',
        sec_code=None,
        fund_name='野村米国国債部分ラダーファンド\u3000Ａコース（野村ＳＭＡ向け）、野村米国国債部分ラダーファンド\u3000Ｂコース（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラベイコクコクサイブブンラダーファンドエーコースノムラエスエムエームケ\u3000ノムラベイコクコクサイブブンラダーファンドビーコースノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10084': FundCodeEntry(
        fund_code='G10084',
        sec_code=None,
        fund_name='野村豪州債券ファンド\u3000Ａコース（野村ＳＭＡ向け）、野村豪州債券ファンド\u3000Ｂコース（野村ＳＭＡ向け）',
        fund_name_yomi='ノムラゴウシュウサイケンファンドエーコースノムラエスエムエームケ\u3000ノムラゴウシュウサイケンファンドビーコースノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10086': FundCodeEntry(
        fund_code='G10086',
        sec_code=None,
        fund_name='ＵＢＳ公益・金融社債ファンド（年１回決算型・為替ヘッジあり）',
        fund_name_yomi='ユービーエスコウエキキンユウシャサイファンドネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G10089': FundCodeEntry(
        fund_code='G10089',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000日経２２５',
        fund_name_yomi='ダイワインデックスセレクトニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10090': FundCodeEntry(
        fund_code='G10090',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000ＴＯＰＩＸ',
        fund_name_yomi='ダイワインデックスセレクトトピックス',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10091': FundCodeEntry(
        fund_code='G10091',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000日本債券',
        fund_name_yomi='ダイワインデックスセレクトニホンサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10092': FundCodeEntry(
        fund_code='G10092',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000Ｊ－ＲＥＩＴ',
        fund_name_yomi='ダイワインデックスセレクトジェイリート',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10093': FundCodeEntry(
        fund_code='G10093',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000外国株式',
        fund_name_yomi='ダイワインデックスセレクトガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10094': FundCodeEntry(
        fund_code='G10094',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000外国債券',
        fund_name_yomi='ダイワインデックスセレクトガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10095': FundCodeEntry(
        fund_code='G10095',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000グローバルＲＥＩＴ',
        fund_name_yomi='ダイワインデックスセレクトグローバルリート',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10096': FundCodeEntry(
        fund_code='G10096',
        sec_code=None,
        fund_name='ＵＢＳ日本株式リスク・コントロール・ファンド',
        fund_name_yomi='ユービーエスニホンカブシキリスクコントロールファンド',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G10097': FundCodeEntry(
        fund_code='G10097',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ダウ・ジョーンズ\u3000インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ダウ\u3000ジョーンズ\u3000インデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10101': FundCodeEntry(
        fund_code='G10101',
        sec_code=None,
        fund_name='ＤＩＡＭ日本経済成長戦略ファンド',
        fund_name_yomi='ダイアムニホンケイザイセイチョウセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10104': FundCodeEntry(
        fund_code='G10104',
        sec_code=None,
        fund_name='日本Ｊリートオープン（１年決算型）',
        fund_name_yomi='ニホンジェイリートオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10105': FundCodeEntry(
        fund_code='G10105',
        sec_code=None,
        fund_name='ザ・コリア・ファンド・インク',
        fund_name_yomi='ザコリアファンドインク',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E05803',
        issuer_name='ザ・コリア・ファンド・インク',
    ),
    'G10106': FundCodeEntry(
        fund_code='G10106',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴ・リサーチ・オープン（年２回決算型）',
        fund_name_yomi='ジェイリートリサーチオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10108': FundCodeEntry(
        fund_code='G10108',
        sec_code=None,
        fund_name='ニッセイグローバルリートインデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイグローバルリートインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10110': FundCodeEntry(
        fund_code='G10110',
        sec_code=None,
        fund_name='米国バンクローンファンド＜為替ヘッジあり＞／＜為替ヘッジなし＞（毎月分配型）',
        fund_name_yomi='ベイコクバンクローンファンドカワセヘッジアリカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10111': FundCodeEntry(
        fund_code='G10111',
        sec_code=None,
        fund_name='ニッセイ外国債券インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイガイコクサイケンインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10112': FundCodeEntry(
        fund_code='G10112',
        sec_code=None,
        fund_name='ニッセイ外国株式インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイガイコクカブシキインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10115': FundCodeEntry(
        fund_code='G10115',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000Ｓ＆Ｐ５００配当貴族インデックスファンド＜為替ヘッジなし＞／＜為替ヘッジあり＞',
        fund_name_yomi='ミツビシユーエフジェイエスアンドピーゴヒャクハイトウキゾクインデックスファンドカワセヘッジナシカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10118': FundCodeEntry(
        fund_code='G10118',
        sec_code=None,
        fund_name='東京海上・日本債券オープン（野村ＳＭＡ向け）',
        fund_name_yomi='トウキョウカイジョウニホンサイケンオープンノムラエスエムエームケ',
        security_type='内国投資信託受益証券',
        period_1='8月27日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10124': FundCodeEntry(
        fund_code='G10124',
        sec_code=None,
        fund_name='ＳＭＴＡＭコモディティ・オープン',
        fund_name_yomi='エスエムティーエーエムコモディティ\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10126': FundCodeEntry(
        fund_code='G10126',
        sec_code=None,
        fund_name='イタリア株式ファンド',
        fund_name_yomi='イタリアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10129': FundCodeEntry(
        fund_code='G10129',
        sec_code=None,
        fund_name='ダイワＵＳ短期ハイ・イールド社債ファンド（為替ヘッジあり／年１回決算型）',
        fund_name_yomi='ダイワユーエスタンキハイイールドシャサイファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10131': FundCodeEntry(
        fund_code='G10131',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１３－１２',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチサンイチニ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10132': FundCodeEntry(
        fund_code='G10132',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000Ｊリートオープン（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイジェイリートオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10134': FundCodeEntry(
        fund_code='G10134',
        sec_code=None,
        fund_name='米国エネルギー革命関連ファンド（年１回決算型）為替ヘッジあり、米国エネルギー革命関連ファンド（年１回決算型）為替ヘッジなし',
        fund_name_yomi='ベイコクエネルギーカクメイカンレンファンドネンイッカイケッサンガタカワセヘッジアリ\u3000ベイコクエネルギーカクメイカンレンファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10135': FundCodeEntry(
        fund_code='G10135',
        sec_code=None,
        fund_name='米国ＭＬＰファンド（毎月分配型）Ａコース（円ヘッジあり）／Ｂコース（円ヘッジなし）',
        fund_name_yomi='ベイコクエムエルピーファンドマイツキブンパイガタエーコースエンヘッジアリ\u3000ビーコースエンヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2='7月19日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G10137': FundCodeEntry(
        fund_code='G10137',
        sec_code=None,
        fund_name='資源ファンド（株式と通貨）ブラジルレアル・コース（資産成長型）、資源ファンド（株式と通貨）南アフリカランド・コース（資産成長型）、資源ファンド（株式と通貨）米ドル・コース（資産成長型）',
        fund_name_yomi='シゲンファンド\u3000カブシキトツウカ\u3000ブラジルレアル\u3000コース\u3000シサンセイチョウガタ\u3000シゲンファンド\u3000カブシキトツウカ\u3000ミナミアフリカランド\u3000コース\u3000シサンセイチョウガタ\u3000シゲンファンド\u3000カブシキトツウカ\u3000ベイドル\u3000コース\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10138': FundCodeEntry(
        fund_code='G10138',
        sec_code=None,
        fund_name='米国エネルギー・ハイインカム・ファンド',
        fund_name_yomi='ベイコクエネルギーハイインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E14732',
        issuer_name='ソシエテ・ジェネラル・オスマン・マネジメント株式会社',
    ),
    'G10139': FundCodeEntry(
        fund_code='G10139',
        sec_code=None,
        fund_name='米国ツイン・スターズ・ファンド\u3000－予想分配金提示型－\u3000Ａコース（為替ヘッジあり）、Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ベイコクツインスターズファンド\u3000ヨソウブンパイキンテイジガタ\u3000エーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月2日',
        period_2='9月2日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G10140': FundCodeEntry(
        fund_code='G10140',
        sec_code=None,
        fund_name='ＤＩＡＭ\u3000Ｊ－ＲＥＩＴオープン（１年決算コース）',
        fund_name_yomi='ダイアムジェイリートオープンイチネンケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='7月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10141': FundCodeEntry(
        fund_code='G10141',
        sec_code=None,
        fund_name='ピクテ・マルチアセット・アロケーション・ファンド',
        fund_name_yomi='ピクテマルチアセットアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G10142': FundCodeEntry(
        fund_code='G10142',
        sec_code=None,
        fund_name='ノムラ\u3000ＴＨＥ\u3000ＮＩＰＰＯＮ',
        fund_name_yomi='ノムラザニッポン',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10143': FundCodeEntry(
        fund_code='G10143',
        sec_code=None,
        fund_name='ダイワ・スイス高配当株ツインα（毎月分配型）',
        fund_name_yomi='ダイワスイスコウハイトウカブツインアルファマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10144': FundCodeEntry(
        fund_code='G10144',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000新興国株式',
        fund_name_yomi='ダイワインデックスセレクトシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10145': FundCodeEntry(
        fund_code='G10145',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000新興国債券',
        fund_name_yomi='ダイワインデックスセレクトシンコウコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10146': FundCodeEntry(
        fund_code='G10146',
        sec_code=None,
        fund_name='日本中小型成長株アクティブ・ファンド',
        fund_name_yomi='ニッポンチュウコガタセイチョウカブアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G10148': FundCodeEntry(
        fund_code='G10148',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000豪ドル債券インカムオープン（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイゴウドルサイケンインカムオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10149': FundCodeEntry(
        fund_code='G10149',
        sec_code=None,
        fund_name='Ｊキャップ日本株ファンド',
        fund_name_yomi='ジェイキャップニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10151': FundCodeEntry(
        fund_code='G10151',
        sec_code=None,
        fund_name='Ｏｎｅ割安日本株ファンド（年１回決算型）',
        fund_name_yomi='ワンワリヤスニホンカブファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10161': FundCodeEntry(
        fund_code='G10161',
        sec_code=None,
        fund_name='ダイワＪ－ＲＥＩＴオープン（年１回決算型）',
        fund_name_yomi='ダイワジェイリートオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10162': FundCodeEntry(
        fund_code='G10162',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000ＴＯＰＩＸインデックス',
        fund_name_yomi='ディーアイズトピックスインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10163': FundCodeEntry(
        fund_code='G10163',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000日経２２５インデックス',
        fund_name_yomi='ディーアイズニッケイニイニイゴインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10165': FundCodeEntry(
        fund_code='G10165',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000外国株式インデックス',
        fund_name_yomi='ディーアイズガイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10166': FundCodeEntry(
        fund_code='G10166',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000外国債券インデックス',
        fund_name_yomi='ディーアイズガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10167': FundCodeEntry(
        fund_code='G10167',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000グローバルＲＥＩＴインデックス',
        fund_name_yomi='ディーアイズグローバルリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10168': FundCodeEntry(
        fund_code='G10168',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000新興国株式インデックス',
        fund_name_yomi='ディーアイズシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10169': FundCodeEntry(
        fund_code='G10169',
        sec_code=None,
        fund_name='Ｄ－Ｉ’ｓ\u3000新興国債券インデックス',
        fund_name_yomi='ディーアイズシンコウコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10177': FundCodeEntry(
        fund_code='G10177',
        sec_code=None,
        fund_name='ＢＮＹメロン・日本株式ファンド\u3000市場リスク管理型',
        fund_name_yomi='ビーエヌワイメロンニッポンカブシキファンドシジョウリスクカンリガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G10178': FundCodeEntry(
        fund_code='G10178',
        sec_code=None,
        fund_name='明治安田ＤＣ日本債券パッシブファンド',
        fund_name_yomi='メイジヤスダディーシーニホンサイケンパッシブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月27日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G10179': FundCodeEntry(
        fund_code='G10179',
        sec_code=None,
        fund_name='みずほ好配当日本株オープン（年１回決算型）',
        fund_name_yomi='ミズホコウハイトウニホンカブオープン\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10180': FundCodeEntry(
        fund_code='G10180',
        sec_code=None,
        fund_name='ザ・２０２０ビジョン',
        fund_name_yomi='ザトゥエンティトゥエンティビジョン',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E22096',
        issuer_name='コモンズ投信株式会社',
    ),
    'G10184': FundCodeEntry(
        fund_code='G10184',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000グローバル・ボンド・オープン（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイグローバルボンドオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10185': FundCodeEntry(
        fund_code='G10185',
        sec_code=None,
        fund_name='ＵＳストラテジック・インカム・ファンド（年１回決算型）為替ヘッジあり、ＵＳストラテジック・インカム・ファンド（年１回決算型）為替ヘッジなし',
        fund_name_yomi='ユーエスストラテジックインカムファンドネンイッカイケッサンガタカワセヘッジアリ\u3000ユーエスストラテジックインカムファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10188': FundCodeEntry(
        fund_code='G10188',
        sec_code=None,
        fund_name='ＳＭＴ\u3000米ドル建新興国債券インデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='エスエムティー\u3000ベイドルダテシンコウコクサイケンインデックス\u3000オープン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10189': FundCodeEntry(
        fund_code='G10189',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000米国ハイイールド債券\u3000通貨選択型ファンド（年１回決算型）',
        fund_name_yomi='ピムコ\u3000ベイコクハイイールドサイケン\u3000ツウカセンタクガタファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月16日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10192': FundCodeEntry(
        fund_code='G10192',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・オープン（年１回決算型）為替ヘッジあり',
        fund_name_yomi='ダイワユーエスリートオープンネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10193': FundCodeEntry(
        fund_code='G10193',
        sec_code=None,
        fund_name='ＳＭＴ\u3000グローバル債券インデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='エスエムティー\u3000グローバルサイケンインデックス\u3000オープン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10195': FundCodeEntry(
        fund_code='G10195',
        sec_code=None,
        fund_name='三井住友・ＮＹダウ・ジョーンズ・インデックスファンド（為替ノーヘッジ型）',
        fund_name_yomi='ミツイスミトモニューヨークダウジョーンズインデックスファンドカワセノーヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10198': FundCodeEntry(
        fund_code='G10198',
        sec_code='32950',
        fund_name='ヒューリックリート投資法人',
        fund_name_yomi='ヒューリックリートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E30291',
        issuer_name='ヒューリックリート投資法人',
    ),
    'G10201': FundCodeEntry(
        fund_code='G10201',
        sec_code=None,
        fund_name='ダイワ新興国ソブリン債券ファンド：資産成長コース、通貨αコース',
        fund_name_yomi='ダイワシンコウコクソブリンサイケンファンドシサンセイチョウコースツウカアルファコース',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10204': FundCodeEntry(
        fund_code='G10204',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０１',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10206': FundCodeEntry(
        fund_code='G10206',
        sec_code=None,
        fund_name='２０２３年満期日本公共債ファンド',
        fund_name_yomi='ニセンニジュウサンネンマンキニホンコウキョウサイファンド',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10208': FundCodeEntry(
        fund_code='G10208',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000東京関連オープン（米ドル投資型）／（円投資型）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000トウキョウカンレンオープンベイドルトウシガタエントウシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10210': FundCodeEntry(
        fund_code='G10210',
        sec_code=None,
        fund_name='ＭＵＡＭグローバル・ケイマン・トラスト－ＵＳバンクローンファンド\u3000米ドル建／ＵＳバンクローンファンド\u3000豪ドル建\u3000豪ドルヘッジ',
        fund_name_yomi='エムユーエーエムグローバルケイマントラストユーエスバンクローンファンドベイドルダテユーエスバンクローンファンドゴウドルダテゴウドルヘッジ',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G10211': FundCodeEntry(
        fund_code='G10211',
        sec_code=None,
        fund_name='三井住友・ＮＹダウ・ジョーンズ・インデックスオープン',
        fund_name_yomi='ミツイスミトモニューヨークダウジョーンズインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10214': FundCodeEntry(
        fund_code='G10214',
        sec_code=None,
        fund_name='しんきんＪリートオープン（１年決算型）',
        fund_name_yomi='シンキンジェイリートオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G10215': FundCodeEntry(
        fund_code='G10215',
        sec_code=None,
        fund_name='ＪＰＸ日経４００ノーロードオープン',
        fund_name_yomi='ジェイピーエックスニッケイヨンヒャクノーロードオープン',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10217': FundCodeEntry(
        fund_code='G10217',
        sec_code=None,
        fund_name='ダイワＪＰＸ日経４００ファンド',
        fund_name_yomi='ダイワジェイピーエックスニッケイヨンヒャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10218': FundCodeEntry(
        fund_code='G10218',
        sec_code=None,
        fund_name='ダイワＪＰＸ日経４００ファンド（米ドル投資型）',
        fund_name_yomi='ダイワジェイピーエックスニッケイヨンヒャクファンドベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10219': FundCodeEntry(
        fund_code='G10219',
        sec_code=None,
        fund_name='フィデリティ・世界インカム株式・ファンド（資産成長型）',
        fund_name_yomi='フィデリティセカイインカムカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10225': FundCodeEntry(
        fund_code='G10225',
        sec_code=None,
        fund_name='イオングループ・ファンド',
        fund_name_yomi='イオングループファンド',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10226': FundCodeEntry(
        fund_code='G10226',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＪＰＸ日経インデックス４００・オープン',
        fund_name_yomi='エスエムティー\u3000ジェイピーエックスニッケイインデックスヨンヒャク\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10229': FundCodeEntry(
        fund_code='G10229',
        sec_code=None,
        fund_name='ＨＫエレクトリック・インベストメンツ（愛称\u3000香港電力インベストメンツ）',
        fund_name_yomi='エイチケイエレクトリック\u3000インベストメンツ\u3000アイショウ\u3000ホンコンデンリョクインベストメンツ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E30309',
        issuer_name='ＨＫエレクトリック・インベストメンツ・マネジャー・リミテッド',
    ),
    'G10230': FundCodeEntry(
        fund_code='G10230',
        sec_code=None,
        fund_name='ＧＳ日本株・プラス（米ドルコース）',
        fund_name_yomi='ジーエス\u3000ニホンカブプラス\u3000ベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10231': FundCodeEntry(
        fund_code='G10231',
        sec_code='15910',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸ日経インデックス４００連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエックスニッケイインデックスヨンヒャクレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10232': FundCodeEntry(
        fund_code='G10232',
        sec_code=None,
        fund_name='りそな・ＪＰＸ日経４００オープン',
        fund_name_yomi='リソナジェイピーエックスニッケイヨンヒャクオープン',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G10233': FundCodeEntry(
        fund_code='G10233',
        sec_code='15920',
        fund_name='上場インデックスファンドＪＰＸ日経インデックス４００',
        fund_name_yomi='ジョウジョウインデックスファンドジェーピーエックスニッケイインデックスヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10240': FundCodeEntry(
        fund_code='G10240',
        sec_code=None,
        fund_name='三重県応援・債券ファンド（１年決算型）',
        fund_name_yomi='ミエケンオウエンサイケンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10241': FundCodeEntry(
        fund_code='G10241',
        sec_code=None,
        fund_name='日米４資産スマートバランス',
        fund_name_yomi='ニチベイヨンシンサンスマートバランス',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10250': FundCodeEntry(
        fund_code='G10250',
        sec_code=None,
        fund_name='インデックスファンドＪＰＸ日経４００',
        fund_name_yomi='インデックスファンドジェーピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='2月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10252': FundCodeEntry(
        fund_code='G10252',
        sec_code=None,
        fund_name='ＭＬＰ関連証券ファンド（為替ヘッジあり）\u3000ＭＬＰ関連証券ファンド（為替ヘッジなし）',
        fund_name_yomi='エムエルピーカンレンショウケンファンド\u3000カワセヘッジアリ\u3000エムエルピーカンレンショウケンファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10253': FundCodeEntry(
        fund_code='G10253',
        sec_code=None,
        fund_name='ＪＰＸ日経４００ファンド',
        fund_name_yomi='ジェイピーエックスニッケイヨンヒャクファンド',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10254': FundCodeEntry(
        fund_code='G10254',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０２',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロニ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10255': FundCodeEntry(
        fund_code='G10255',
        sec_code=None,
        fund_name='ニュージーランド公社債ファンド（毎月分配型）',
        fund_name_yomi='ニュージーランドコウシャサイファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10256': FundCodeEntry(
        fund_code='G10256',
        sec_code=None,
        fund_name='ダイワ・インデックスセレクト\u3000ＪＰＸ日経４００',
        fund_name_yomi='ダイワインデックスセレクトジェイピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10265': FundCodeEntry(
        fund_code='G10265',
        sec_code='15930',
        fund_name='ＭＡＸＩＳ\u3000ＪＰＸ日経インデックス４００上場投信',
        fund_name_yomi='マクシスジェーピーエックスニッケイインデックスヨンヒャクジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10270': FundCodeEntry(
        fund_code='G10270',
        sec_code=None,
        fund_name='コクサイ・ケイマン・トラスト－米ドル建\u3000米ドルヘッジ\u3000国際・キャピタル\u3000日本株式オープン\u3000豪ドル建\u3000豪ドルヘッジ\u3000国際・キャピタル\u3000日本株式オープン',
        fund_name_yomi='コクサイケンマントラストベイドルダテベイドルヘッジコクサイキャピタルニホンカブシキオープンゴウドルダテゴウドルヘッジコクサイキャピタルニホンカブシキオープン',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E30992',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G10273': FundCodeEntry(
        fund_code='G10273',
        sec_code='15960',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＴＯＰＩＸ\u3000Ｅｘ－Ｆｉｎａｎｃｉａｌｓ',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000トピックス\u3000エクスフィナンシャルズ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G10274': FundCodeEntry(
        fund_code='G10274',
        sec_code='15950',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000東証ＲＥＩＴ指数',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000トウショウリートシスウ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G10276': FundCodeEntry(
        fund_code='G10276',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・ニュージーランド債券ファンド（毎月分配型）\u3000フランクリン・テンプルトン・ニュージーランド債券ファンド（年２回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ニュージーランドサイケンファンド\u3000マイツキブンパイガタ\u3000フランクリン\u3000テンプルトン\u3000ニュージーランドサイケンファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G10277': FundCodeEntry(
        fund_code='G10277',
        sec_code=None,
        fund_name='三井住友・ＪＰＸ日経４００オープン',
        fund_name_yomi='ミツイスミトモジェイピーエックスニッケイヨンヒャクオープン',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10278': FundCodeEntry(
        fund_code='G10278',
        sec_code=None,
        fund_name='日興グラビティ・ヨーロピアン・ファンド',
        fund_name_yomi='ニッコウグラビティヨーロピアンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10281': FundCodeEntry(
        fund_code='G10281',
        sec_code=None,
        fund_name='インデックスファンドＭＬＰ（毎月分配型）',
        fund_name_yomi='インデックスファンドエムエルピー\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10284': FundCodeEntry(
        fund_code='G10284',
        sec_code=None,
        fund_name='ダイワ新興アセアン中小型株ファンド\u3000－５つの芽－',
        fund_name_yomi='ダイワシンコウアセアンチュウコガタカブファンドイツツノメ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10285': FundCodeEntry(
        fund_code='G10285',
        sec_code=None,
        fund_name='ニッセイＪＰＸ日経４００アクティブファンド',
        fund_name_yomi='ニッセイジェイピーエックスニッケイヨンヒャクアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10293': FundCodeEntry(
        fund_code='G10293',
        sec_code=None,
        fund_name='米国国債ファンド\u3000為替ヘッジなし（毎月決算型）',
        fund_name_yomi='ベイコクコクサイファンドカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10294': FundCodeEntry(
        fund_code='G10294',
        sec_code=None,
        fund_name='ジャパン・エクセレント',
        fund_name_yomi='ジャパンエクセレント',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10298': FundCodeEntry(
        fund_code='G10298',
        sec_code=None,
        fund_name='ＭＵＡＭグローバル・ケイマン・トラスト－ＰＩＭＣＯ\u3000インカム・ファンド\u3000米ドル／ＰＩＭＣＯ\u3000インカム・ファンド\u3000円',
        fund_name_yomi='エムユーエーエムグローバルケイマントラストピムコインカムファンドベイドルピムコインカムファンドエン',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G10300': FundCodeEntry(
        fund_code='G10300',
        sec_code=None,
        fund_name='米国割安株ファンド',
        fund_name_yomi='ベイコクワリヤスカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10301': FundCodeEntry(
        fund_code='G10301',
        sec_code='15970',
        fund_name='ＭＡＸＩＳ\u3000Ｊリート上場投信',
        fund_name_yomi='マクシスジェイリートジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10304': FundCodeEntry(
        fund_code='G10304',
        sec_code=None,
        fund_name='ＳＢＩ日本小型成長株選抜ファンド（愛称：センバツ）',
        fund_name_yomi='エスビーアイニホンコガタセイチョウカブセンバツファンド\u3000アイショウ\u3000センバツ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G10307': FundCodeEntry(
        fund_code='G10307',
        sec_code=None,
        fund_name='フランス株式ファンド',
        fund_name_yomi='フランスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10309': FundCodeEntry(
        fund_code='G10309',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０３',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10312': FundCodeEntry(
        fund_code='G10312',
        sec_code=None,
        fund_name='ダイワ米国バイバック・ファンド：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワベイコクバイバックファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10316': FundCodeEntry(
        fund_code='G10316',
        sec_code=None,
        fund_name='インデックスファンドＤＡＸ（ドイツ株式）',
        fund_name_yomi='インデックスファンドダックス\u3000ドイツカブシキ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10322': FundCodeEntry(
        fund_code='G10322',
        sec_code=None,
        fund_name='ＲＯＥ日本株ファンド',
        fund_name_yomi='アールオーイーニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G10323': FundCodeEntry(
        fund_code='G10323',
        sec_code=None,
        fund_name='野村インデックスファンド・ＪＰＸ日経４００',
        fund_name_yomi='ノムラインデックスファンドジェイピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10329': FundCodeEntry(
        fund_code='G10329',
        sec_code=None,
        fund_name='中小型成長株オープン',
        fund_name_yomi='チュウコガタセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月4日',
        period_2='9月4日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10330': FundCodeEntry(
        fund_code='G10330',
        sec_code=None,
        fund_name='日興ＪＰＭ日本ディスカバリー・ファンド',
        fund_name_yomi='ニッコウジェイピーエムニホンディスカバリーファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10334': FundCodeEntry(
        fund_code='G10334',
        sec_code=None,
        fund_name='東京海上・米国優先リートファンド',
        fund_name_yomi='トウキョウカイジョウベイコクユウセンリートファンド',
        security_type='内国投資信託受益証券',
        period_1='6月2日',
        period_2='12月2日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10336': FundCodeEntry(
        fund_code='G10336',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｒ／Ｎファンダメンタル・インデックス上場投信',
        fund_name_yomi='ネクストファンズアールエヌファンダメンタルインデックスジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10341': FundCodeEntry(
        fund_code='G10341',
        sec_code='15990',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＪＰＸ日経４００',
        fund_name_yomi='アイフリーイーティーエフジェイピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10342': FundCodeEntry(
        fund_code='G10342',
        sec_code=None,
        fund_name='Ｔ＆Ｄ\u3000ＪＰＸ日経４００投信（通貨選択型）米ドルコース',
        fund_name_yomi='ティアンドディ\u3000ジェイピーエックスニッケイヨンヒャクトウシン\u3000ツウカセンタクガタ\u3000ベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G10343': FundCodeEntry(
        fund_code='G10343',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000シュローダー日本株式ファンド',
        fund_name_yomi='プレミアムファンズシュローダーニホンカブシキファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G10344': FundCodeEntry(
        fund_code='G10344',
        sec_code=None,
        fund_name='インデックスファンドＮＹダウ３０（アメリカ株式）',
        fund_name_yomi='インデックスファンドニューヨークダウサンジュウ\u3000アメリカカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10345': FundCodeEntry(
        fund_code='G10345',
        sec_code=None,
        fund_name='ＪＰＸ日経４００インデックスファンド',
        fund_name_yomi='ジェイピーエックスニッケイヨンヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10346': FundCodeEntry(
        fund_code='G10346',
        sec_code='32960',
        fund_name='日本リート投資法人',
        fund_name_yomi='ニッポンリートトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E30513',
        issuer_name='日本リート投資法人',
    ),
    'G10349': FundCodeEntry(
        fund_code='G10349',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０４',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10350': FundCodeEntry(
        fund_code='G10350',
        sec_code=None,
        fund_name='楽天ボラティリティ・ファンド（毎月分配型）、楽天ボラティリティ・ファンド（資産成長型）',
        fund_name_yomi='ラクテンボラティリティファンドマイツキブンパイガタ\u3000ラクテンボラティリティファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G10352': FundCodeEntry(
        fund_code='G10352',
        sec_code=None,
        fund_name='ダイワ・ニッポン応援ファンドＶｏｌ．５\u3000－ライジング・ジャパン－',
        fund_name_yomi='ダイワニッポンオウエンファンドボリュームファイブライジングジャパン',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10354': FundCodeEntry(
        fund_code='G10354',
        sec_code=None,
        fund_name='日本優良成長株オープン（米ドル投資型）、日本優良成長株オープン（円投資型）',
        fund_name_yomi='ニホンユウリョウセイチョウカブオープンベイドルトウシガタ\u3000ニホンユウリョウセイチョウカブオープンエントウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月6日',
        period_2='10月6日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10355': FundCodeEntry(
        fund_code='G10355',
        sec_code=None,
        fund_name='日本経済再生戦略株式ファンド',
        fund_name_yomi='ニホンケイザイサイセイセンリャクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10356': FundCodeEntry(
        fund_code='G10356',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＪＰＸ日経４００インデックス',
        fund_name_yomi='イーマクシスジェーピーエックスニッケイヨンヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10358': FundCodeEntry(
        fund_code='G10358',
        sec_code=None,
        fund_name='ＪＰＸ日経４００プラスにいがた・アクティブ',
        fund_name_yomi='ジェーピーエックスニッケイヨンヒャクプラスニイガタアクティブ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10368': FundCodeEntry(
        fund_code='G10368',
        sec_code=None,
        fund_name='フィデリティ・グローバル・ハイ・イールド・ファンド（資産成長型）',
        fund_name_yomi='フィデリティグローバルハイイールドファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10377': FundCodeEntry(
        fund_code='G10377',
        sec_code=None,
        fund_name='ＵＳバンクローンファンド・為替ヘッジあり（毎月分配型）、ＵＳバンクローンファンド・為替ヘッジなし（毎月分配型）、ＵＳバンクローンファンド・為替ヘッジあり（年２回決算型）、ＵＳバンクローンファンド・為替ヘッジなし（年２回決算型）',
        fund_name_yomi='ユーエスバンクローンファンドカワセヘッジアリマイツキブンパイガタ\u3000ユーエスバンクローンファンドカワセヘッジナシマイツキブンパイガタ\u3000ユーエスバンクローンファンドカワセヘッジアリネンニカイケッサンガタ\u3000ユーエスバンクローンファンドカワセヘッジナシネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10378': FundCodeEntry(
        fund_code='G10378',
        sec_code=None,
        fund_name='グローバル変動金利債券ファンド\u3000円ヘッジありコース\u3000グローバル変動金利債券ファンド\u3000円ヘッジなしコース',
        fund_name_yomi='グローバルヘンドウキンリサイケンファンド\u3000エンヘッジアリコース\u3000グローバルヘンドウキンリサイケンファンド\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10380': FundCodeEntry(
        fund_code='G10380',
        sec_code=None,
        fund_name='グローバルＲＥＩＴオープン（資産成長型）',
        fund_name_yomi='グローバルリートオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10385': FundCodeEntry(
        fund_code='G10385',
        sec_code=None,
        fund_name='野村サービス関連株ファンド',
        fund_name_yomi='ノムラサービスカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10386': FundCodeEntry(
        fund_code='G10386',
        sec_code=None,
        fund_name='明治安田米国リート・インカム・プレミアム・ファンド（毎月決算型）',
        fund_name_yomi='メイジヤスダベイコクリートインカムプレミアムファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2='8月1日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G10389': FundCodeEntry(
        fund_code='G10389',
        sec_code=None,
        fund_name='インベスコ・オフィス・ジェイリート投資法人',
        fund_name_yomi='インベスコオフィスジェイリートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E30620',
        issuer_name='インベスコ・オフィス・ジェイリート投資法人',
    ),
    'G10390': FundCodeEntry(
        fund_code='G10390',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０５',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロゴー',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10392': FundCodeEntry(
        fund_code='G10392',
        sec_code=None,
        fund_name='三井住友・ピムコ・ストラテジック・インカムファンド（為替ヘッジあり／３カ月決算型）、三井住友・ピムコ・ストラテジック・インカムファンド（為替ヘッジなし／３カ月決算型）',
        fund_name_yomi='ミツイスミトモピムコストラテジックインカムファンドカワセヘッジアリサンカゲツケッサンガタミツイスミトモピムコストラテジックインカムファンドカワセヘッジナシサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10393': FundCodeEntry(
        fund_code='G10393',
        sec_code=None,
        fund_name='三井住友・ピムコ・ストラテジック・インカムファンド（為替ヘッジあり／年１回決算型）、三井住友・ピムコ・ストラテジック・インカムファンド（為替ヘッジなし／年１回決算型）',
        fund_name_yomi='ミツイスミトモピムコストラテジックインカムファンドカワセヘッジアリネンイッカイケッサンガタミツイスミトモピムコストラテジックインカムファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10396': FundCodeEntry(
        fund_code='G10396',
        sec_code=None,
        fund_name='米国バンクローン・オープン＜為替ヘッジあり＞／＜為替ヘッジなし＞（年１回決算型）',
        fund_name_yomi='ベイコクバンクローンオープンカワセヘッジアリカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10397': FundCodeEntry(
        fund_code='G10397',
        sec_code=None,
        fund_name='米国バンクローン・オープン＜為替ヘッジあり＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ベイコクバンクローンオープンカワセヘッジアリカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10398': FundCodeEntry(
        fund_code='G10398',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ',
        fund_name_yomi='ユービーエスルクスエクイティシキャブ',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E30637',
        issuer_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ',
    ),
    'G10401': FundCodeEntry(
        fund_code='G10401',
        sec_code=None,
        fund_name='ダイワ英国高配当株ツインα（毎月分配型）',
        fund_name_yomi='ダイワエイコクコウハイトウカブツインアルファマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10402': FundCodeEntry(
        fund_code='G10402',
        sec_code=None,
        fund_name='ダイワ英国高配当株ファンド、ダイワ英国高配当株ファンド・マネー・ポートフォリオ',
        fund_name_yomi='ダイワエイコクコウハイトウカブファンドダイワエイコクコウハイトウカブファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10406': FundCodeEntry(
        fund_code='G10406',
        sec_code=None,
        fund_name='ブラックロック世界分散投資ファンド',
        fund_name_yomi='ブラックロックセカイブンサントウシファンド',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G10409': FundCodeEntry(
        fund_code='G10409',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000インカム戦略ファンド＜円インカム＞（毎月分配型）／（年２回分配型）ＰＩＭＣＯ\u3000インカム戦略ファンド＜米ドルインカム＞（毎月分配型）／（年２回分配型）',
        fund_name_yomi='ピムコインカムセンリャクファンドエンインカムマイツキブンパイガタネンニカイブンパイガタ\u3000ピムコインカムセンリャクファンドベイドルインカムマイツキブンパイガタネンニカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10410': FundCodeEntry(
        fund_code='G10410',
        sec_code=None,
        fund_name='ニッセイアジアリートファンド（毎月決算型）',
        fund_name_yomi='ニッセイアジアリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10411': FundCodeEntry(
        fund_code='G10411',
        sec_code=None,
        fund_name='ニッセイアジアリートファンド（毎月決算型）限定為替ヘッジあり',
        fund_name_yomi='ニッセイアジアリートファンドマイツキケッサンガタゲンテイカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10412': FundCodeEntry(
        fund_code='G10412',
        sec_code=None,
        fund_name='インド株式フォーカス（奇数月分配型）',
        fund_name_yomi='インドカブシキフォーカス\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10415': FundCodeEntry(
        fund_code='G10415',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンドＤＣ',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G10416': FundCodeEntry(
        fund_code='G10416',
        sec_code=None,
        fund_name='欧州成長株式ファンド',
        fund_name_yomi='オウシュウセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10417': FundCodeEntry(
        fund_code='G10417',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ストラテジー・エクストラ・シキャブ－バランスド（米ドル）',
        fund_name_yomi='ユービーエスルクスストラテジーエクストラシキャブバランスドベイドル',
        security_type='外国投資証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E30664',
        issuer_name='ＵＢＳ（Ｌｕｘ）ストラテジー・エクストラ・シキャブ',
    ),
    'G10418': FundCodeEntry(
        fund_code='G10418',
        sec_code=None,
        fund_name='ＬＭ・ニュージーランド公社債ファンド（毎月分配型）',
        fund_name_yomi='エルエム\u3000ニュージーランドコウシャサイファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G10421': FundCodeEntry(
        fund_code='G10421',
        sec_code=None,
        fund_name='しんきんＪＰＸ日経４００オープン',
        fund_name_yomi='シンキンジェイピーエックスニッケイヨンヒャクオープン',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G10422': FundCodeEntry(
        fund_code='G10422',
        sec_code=None,
        fund_name='女性活力日本株ファンド',
        fund_name_yomi='ジョセイカツリョクニッポンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G10423': FundCodeEntry(
        fund_code='G10423',
        sec_code=None,
        fund_name='ＭＵＧＣ\u3000ＧＳケイマン・ファンド－ＧＳ\u3000ＣｏＣｏｓ＆キャピタル証券ファンド',
        fund_name_yomi='エムユージーシージーエスケイマンファンドジーエスココスアンドキャピタルショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G10425': FundCodeEntry(
        fund_code='G10425',
        sec_code='13560',
        fund_name='ＴＯＰＩＸベア２倍上場投信',
        fund_name_yomi='トピックスベアニバイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G10431': FundCodeEntry(
        fund_code='G10431',
        sec_code=None,
        fund_name='ファイブスター・バリコレ・ファンド',
        fund_name_yomi='ファイブスターバリコレファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G10433': FundCodeEntry(
        fund_code='G10433',
        sec_code=None,
        fund_name='世界標準債券ファンド（１年決算型）',
        fund_name_yomi='セカイヒョウジュンサイケンファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10434': FundCodeEntry(
        fund_code='G10434',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣバランス・イノベーション（ＫＡＫＵＳＨＩＮ）',
        fund_name_yomi='ミツビシユーエフジェイ\u3000ディーシーバランスイノベーションカクシン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10435': FundCodeEntry(
        fund_code='G10435',
        sec_code=None,
        fund_name='３つの財布\u3000欧州リートファンド',
        fund_name_yomi='ミッツノサイフ\u3000オウシュウリートファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10437': FundCodeEntry(
        fund_code='G10437',
        sec_code=None,
        fund_name='ダイワ豪ドル建て高利回り証券α（毎月分配型）',
        fund_name_yomi='ダイワゴウドルダテコウリマワリショウケンアルファマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10440': FundCodeEntry(
        fund_code='G10440',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０６',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロロク',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10443': FundCodeEntry(
        fund_code='G10443',
        sec_code=None,
        fund_name='トヨタグループ・バランスファンド',
        fund_name_yomi='トヨタグループバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10445': FundCodeEntry(
        fund_code='G10445',
        sec_code=None,
        fund_name='ＧＩＭ（ケイマン諸島）トラスト－ＧＩＭ世界金融債券ファンド\u3000円投資型１４０７',
        fund_name_yomi='ジーアイエムケイマンショトウトラストジーアイエムセカイキンユウサイケンファンドエントウシガタイチヨンゼロナナ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E26661',
        issuer_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
    ),
    'G10446': FundCodeEntry(
        fund_code='G10446',
        sec_code=None,
        fund_name='ＮＮ欧州リート・ファンド（毎月決算コース／為替ヘッジなし）ＮＮ欧州リート・ファンド（資産形成コース／為替ヘッジなし）',
        fund_name_yomi='エヌエヌオウシュウリートファンドマイツキケッサンコースカワセヘッジナシエヌエヌオウシュウリートファンドシサンケイセイコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10451': FundCodeEntry(
        fund_code='G10451',
        sec_code=None,
        fund_name='ブラックロック世界株式絶対収益追求ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブラックロックセカイカブシキゼッタイシュウエキツイキュウファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G10454': FundCodeEntry(
        fund_code='G10454',
        sec_code=None,
        fund_name='ＪＰＭグローバルマイスター',
        fund_name_yomi='ジェイピーエムグローバルマイスター',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10455': FundCodeEntry(
        fund_code='G10455',
        sec_code=None,
        fund_name='日興ブラックロック・ハイ・クオリティ・アロケーション・ファンド（為替ヘッジなし）、日興ブラックロック・ハイ・クオリティ・アロケーション・ファンド（限定為替ヘッジ）',
        fund_name_yomi='ニッコウブラックロックハイクオリティアロケーションファンドカワセヘッジナシ\u3000ニッコウブラックロックハイクオリティアロケーションファンドゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10456': FundCodeEntry(
        fund_code='G10456',
        sec_code=None,
        fund_name='ミューズニッチ米国ＢＤＣファンド（毎月分配型）、ミューズニッチ米国ＢＤＣファンド（年２回決算型）',
        fund_name_yomi='ミューズニッチベイコクビーディシーファンド\u3000マイツキブンパイガタ\u3000ミューズニッチベイコクビーディシーファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10457': FundCodeEntry(
        fund_code='G10457',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000インカム戦略ファンド＜世界通貨分散コース＞（毎月分配型）／（年２回分配型）',
        fund_name_yomi='ピムコインカムセンリャクファンドセカイツウカブンサンコースマイツキブンパイガタネンニカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10458': FundCodeEntry(
        fund_code='G10458',
        sec_code=None,
        fund_name='通貨選択型ダイワ／ミレーアセット・グローバル・グレートコンシューマー株式ファンドⅡ：豪ドル・コース（毎月分配型）、ブラジル・レアル・コース（毎月分配型）、通貨セレクト・コース（毎月分配型）',
        fund_name_yomi='ツウカセンタクガタダイワミレーアセットグローバルグレートコンシューマーカブシキファンドツーゴウドルコースマイツキブンパイガタブラジルレアルコースマイツキブンパイガタツウカセレクトコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10462': FundCodeEntry(
        fund_code='G10462',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー\u3000オーストラリア・ハイインカム債券ファンド\u3000豪ドル円プレミアム（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーオーストラリアハイインカムサイケンファンドゴウドルエンプレミアムマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10464': FundCodeEntry(
        fund_code='G10464',
        sec_code=None,
        fund_name='ＧＩＭケイマン・トラストⅠ－日興グローバル金融機関ハイブリッド証券ファンド',
        fund_name_yomi='ジイアイエムケイマントラストワンニッコウグローバルキンユウキカンハイブリッドショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E26661',
        issuer_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
    ),
    'G10466': FundCodeEntry(
        fund_code='G10466',
        sec_code=None,
        fund_name='三井住友・ＮＹダウ・ジョーンズ指数オープン（為替ヘッジあり）、三井住友・ＮＹダウ・ジョーンズ指数オープン（為替ヘッジなし）',
        fund_name_yomi='ミツイスミトモニューヨークダウジョーンズシスウオープンカワセヘッジアリ\u3000ミツイスミトモニューヨークダウジョーンズシスウオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10471': FundCodeEntry(
        fund_code='G10471',
        sec_code=None,
        fund_name='ヘッジ付先進国株式インデックスオープン',
        fund_name_yomi='ヘッジツキセンシンコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10473': FundCodeEntry(
        fund_code='G10473',
        sec_code=None,
        fund_name='ニッセイ欧州株式厳選ファンド\u3000フルインベストメントコース／ニッセイ欧州株式厳選ファンド\u3000リスクコントロールコース',
        fund_name_yomi='ニッセイオウシュウカブシキゲンセンファンドフルインベストメントコース\u3000ニッセイオウシュウカブシキゲンセンファンドリスクコントロールコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10478': FundCodeEntry(
        fund_code='G10478',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０７',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10481': FundCodeEntry(
        fund_code='G10481',
        sec_code=None,
        fund_name='ブルーベイ\u3000クレジットＬＳファンド（ＳＭＡ専用）',
        fund_name_yomi='ブルーベイ\u3000クレジットエルエスファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10483': FundCodeEntry(
        fund_code='G10483',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（毎月分配型）フレックス・コース',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドマイツキブンパイガタフレックスコース',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G10484': FundCodeEntry(
        fund_code='G10484',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（１年決算型）フレックス・コース',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドイチネンケッサンガタフレックスコース',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G10491': FundCodeEntry(
        fund_code='G10491',
        sec_code=None,
        fund_name='アムンディ・グローバル・サステナブル・バリュー・ファンド',
        fund_name_yomi='アムンディグローバルサステナブルバリューファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G10493': FundCodeEntry(
        fund_code='G10493',
        sec_code=None,
        fund_name='ＤＩＡＭ厳選米国株式ファンド',
        fund_name_yomi='ダイアムゲンセンベイコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10498': FundCodeEntry(
        fund_code='G10498',
        sec_code=None,
        fund_name='ダイワ高格付カナダドル債オープン・為替アクティブヘッジ（毎月分配型）',
        fund_name_yomi='ダイワコウカクヅケカナダドルサイオープンカワセアクティブヘッジマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10502': FundCodeEntry(
        fund_code='G10502',
        sec_code='13570',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経平均ダブルインバース・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイヘイキンダブルインバースインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10506': FundCodeEntry(
        fund_code='G10506',
        sec_code=None,
        fund_name='メディカル・サイエンス・ファンド',
        fund_name_yomi='メディカルサイエンスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10508': FundCodeEntry(
        fund_code='G10508',
        sec_code=None,
        fund_name='グローバル変動金利債券ファンド（毎月分配型）円ヘッジありコース\u3000グローバル変動金利債券ファンド（毎月分配型）円ヘッジなしコース',
        fund_name_yomi='グローバルヘンドウキンリサイケンファンド\u3000マイツキブンパイガタ\u3000エンヘッジアリコース\u3000グローバルヘンドウキンリサイケンファンド\u3000マイツキブンパイガタ\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10510': FundCodeEntry(
        fund_code='G10510',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000米国バンクローンファンド\u3000米ドル円プレミアム（毎月分配型）',
        fund_name_yomi='ミツビシユーエフジェイベイコクバンクローンファンドベイドルエンプレミアムマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10515': FundCodeEntry(
        fund_code='G10515',
        sec_code=None,
        fund_name='りそなスイス・グローバル・リーダー・ファンド',
        fund_name_yomi='リソナスイスグローバルリーダーファンド',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10516': FundCodeEntry(
        fund_code='G10516',
        sec_code=None,
        fund_name='アムンディ・英国債ファンド（毎月決算型）、アムンディ・英国債ファンド（年２回決算型）',
        fund_name_yomi='アムンディエイコクサイファンドマイツキケッサンガタ\u3000アムンディエイコクサイファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G10518': FundCodeEntry(
        fund_code='G10518',
        sec_code=None,
        fund_name='ベトナム成長株インカムファンド',
        fund_name_yomi='ベトナムセイチョウカブインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G10519': FundCodeEntry(
        fund_code='G10519',
        sec_code=None,
        fund_name='欧州社債ファンド\u3000Ａコース（為替ヘッジあり）、欧州社債ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='オウシュウシャサイファンド\u3000エーコース\u3000カワセヘッジアリ\u3000オウシュウシャサイファンド\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10520': FundCodeEntry(
        fund_code='G10520',
        sec_code=None,
        fund_name='イーストスプリング・ジャパン中小型厳選バリュー株ファンド',
        fund_name_yomi='イーストスプリングジャパンチュウコガタゲンセンバリューカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G10521': FundCodeEntry(
        fund_code='G10521',
        sec_code=None,
        fund_name='野村グローバルボンド投信\u3000Ａコース、野村グローバルボンド投信\u3000Ｂコース、野村グローバルボンド投信\u3000Ｃコース、野村グローバルボンド投信\u3000Ｄコース、野村グローバルボンド投信\u3000Ｅコース、野村グローバルボンド投信\u3000Ｆコース',
        fund_name_yomi='ノムラグローバルボンドトウシンエーコース\u3000ノムラグローバルボンドトウシンビーコース\u3000ノムラグローバルボンドトウシンシーコース\u3000ノムラグローバルボンドトウシンディーコース\u3000ノムラグローバルボンドトウシンイーコース\u3000ノムラグローバルボンドトウシンエフコース',
        security_type='内国投資信託受益証券',
        period_1='2月6日',
        period_2='8月6日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10523': FundCodeEntry(
        fund_code='G10523',
        sec_code=None,
        fund_name='バンクローン・オープン（為替ヘッジあり）\u3000バンクローン・オープン（為替ヘッジなし）',
        fund_name_yomi='バンクローン\u3000オープン\u3000カワセヘッジアリ\u3000バンクローン\u3000オープン\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10525': FundCodeEntry(
        fund_code='G10525',
        sec_code=None,
        fund_name='ワールド・リゾート関連株式ファンド',
        fund_name_yomi='ワールドリゾートカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月1日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10527': FundCodeEntry(
        fund_code='G10527',
        sec_code=None,
        fund_name='ＤＩＡＭジャナス米国中小型株式ファンド',
        fund_name_yomi='ダイアムジャナスベイコクチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10529': FundCodeEntry(
        fund_code='G10529',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０８',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10530': FundCodeEntry(
        fund_code='G10530',
        sec_code=None,
        fund_name='４資産分散投資・ハイクラス＜ＤＣ年金＞',
        fund_name_yomi='ヨンシサンブンサントウシハイクラスディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10536': FundCodeEntry(
        fund_code='G10536',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・新興国成長株投信Ｃコース毎月決算型（為替ヘッジあり）予想分配金提示型／アライアンス・バーンスタイン・新興国成長株投信Ｄコース毎月決算型（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='アライアンスバーンスタインシンコウコクセイチョウカブトウシンシーコースマイツキケッサンガタカワセヘッジアリヨソウブンパイキンテイジガタ\u3000アライアンスバーンスタインシンコウコクセイチョウカブトウシンディーコースマイツキケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月28日',
        period_2='8月28日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G10537': FundCodeEntry(
        fund_code='G10537',
        sec_code=None,
        fund_name='ニュージーランド債券オープン＜為替ヘッジなし＞（毎月分配型）、ニュージーランド債券オープン＜為替ヘッジなし＞（年２回決算型）、ニュージーランド債券オープン＜為替アクティブヘッジ＞（毎月分配型）、ニュージーランド債券オープン＜為替アクティブヘッジ＞（年２回決算型）',
        fund_name_yomi='ニュージーランドサイケンオープンカワセヘッジナシマイツキブンパイガタ\u3000ニュージーランドサイケンオープンカワセヘッジナシネンニカイケッサンガタ\u3000ニュージーランドサイケンオープンカワセアクティブヘッジマイツキブンパイガタ\u3000ニュージーランドサイケンオープンカワセアクティブヘッジネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10546': FundCodeEntry(
        fund_code='G10546',
        sec_code=None,
        fund_name='ＤＣダイナミック・アロケーション・ファンド',
        fund_name_yomi='ディーシーダイナミックアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10550': FundCodeEntry(
        fund_code='G10550',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・米国成長株投信Ｃコース毎月決算型（為替ヘッジあり）予想分配金提示型／アライアンス・バーンスタイン・米国成長株投信Ｄコース毎月決算型（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='アライアンスバーンスタインベイコクセイチョウカブトウシンシーコースマイツキケッサンガタカワセヘッジアリヨソウブンパイキンテイジガタ\u3000アライアンスバーンスタインベイコクセイチョウカブトウシンディーコースマイツキケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G10551': FundCodeEntry(
        fund_code='G10551',
        sec_code=None,
        fund_name='アセアン真成長株式ファンド',
        fund_name_yomi='アセアンシンセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10552': FundCodeEntry(
        fund_code='G10552',
        sec_code=None,
        fund_name='アセアン社債ファンド（毎月決算型）',
        fund_name_yomi='アセアンシャサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10553': FundCodeEntry(
        fund_code='G10553',
        sec_code='13580',
        fund_name='上場インデックスファンド日経レバレッジ指数',
        fund_name_yomi='ジョウジョウインデックスファンドニッケイレバレッジシスウ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10554': FundCodeEntry(
        fund_code='G10554',
        sec_code=None,
        fund_name='ＵＢＳグローバルＣＢオープン（年４回決算型・為替ヘッジあり）／（年４回決算型・為替ヘッジなし）',
        fund_name_yomi='ユービーエス\u3000グローバル\u3000シービー\u3000オープン\u3000ネンヨンカイケッサンガタ\u3000カワセヘッジアリ\u3000ネンヨンカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G10558': FundCodeEntry(
        fund_code='G10558',
        sec_code=None,
        fund_name='ノムラ・ルクセンブルグ・セレクト－野村ブラジル債券ファンド',
        fund_name_yomi='ノムラルクセンブルグセレクトノムラブラジルサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G10559': FundCodeEntry(
        fund_code='G10559',
        sec_code=None,
        fund_name='ＳＭＴＡＭ\u3000ＪＰＸ日経インデックス４００オープン',
        fund_name_yomi='エスエムティーエーエム\u3000ジェイピーエックスニッケイインデックスヨンヒャクオープン',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10560': FundCodeEntry(
        fund_code='G10560',
        sec_code=None,
        fund_name='ＳＭＴＡＭ\u3000ＮＹダウインデックスオープン\u3000ＳＭＴＡＭ\u3000ＮＹダウインデックスオープン（為替ヘッジあり）',
        fund_name_yomi='エスエムティーエーエム\u3000ニューヨークダウインデックスオープン\u3000エスエムティーエーエム\u3000ニューヨークダウインデックスオープン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10561': FundCodeEntry(
        fund_code='G10561',
        sec_code=None,
        fund_name='スマート・ラップ・ジャパン（毎月分配型）',
        fund_name_yomi='スマート\u3000ラップ\u3000ジャパン\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10562': FundCodeEntry(
        fund_code='G10562',
        sec_code=None,
        fund_name='スマート・ラップ・ジャパン（１年決算型）',
        fund_name_yomi='スマート\u3000ラップ\u3000ジャパン\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10564': FundCodeEntry(
        fund_code='G10564',
        sec_code=None,
        fund_name='日米４資産スマートバランス（ＤＣ年金）',
        fund_name_yomi='ニチベイヨンシサンスマートバランスディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G10565': FundCodeEntry(
        fund_code='G10565',
        sec_code=None,
        fund_name='ＧＳ\u3000ＭＬＰインフラ関連証券ファンド\u3000毎月決算コース／年２回決算コース',
        fund_name_yomi='ジーエスエムエルピーインフラカンレンショウケンファンド\u3000マイツキケッサンコース\u3000ネンニカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10566': FundCodeEntry(
        fund_code='G10566',
        sec_code=None,
        fund_name='グローバルＣｏＣｏ債ファンド（為替ヘッジなし・毎月分配型）、グローバルＣｏＣｏ債ファンド（為替ヘッジあり・毎月分配型）',
        fund_name_yomi='グローバルココサイファンド\u3000カワセヘッジナシ\u3000マイツキブンパイガタ\u3000\u3000グローバルココサイファンド\u3000カワセヘッジアリ\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10567': FundCodeEntry(
        fund_code='G10567',
        sec_code=None,
        fund_name='グローバルＣｏＣｏ債ファンド\u3000先進国高金利通貨コース\u3000グローバルＣｏＣｏ債ファンド\u3000新興国高金利通貨コース',
        fund_name_yomi='グローバルココサイファンド\u3000センシンコクコウキンリツウカコース\u3000グローバルココサイファンド\u3000シンコウコクコウキンリツウカコース',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10570': FundCodeEntry(
        fund_code='G10570',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－０９',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10572': FundCodeEntry(
        fund_code='G10572',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ヨーロピアン・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ノムラファンドセレクトヨーロピアンハイイールドボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G10573': FundCodeEntry(
        fund_code='G10573',
        sec_code=None,
        fund_name='野村ニュージーランド債券ファンド（毎月分配型）、野村ニュージーランド債券ファンド（年２回決算型）',
        fund_name_yomi='ノムラニュージーランドサイケンファンドマイツキブンパイガタ\u3000ノムラニュージーランドサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10579': FundCodeEntry(
        fund_code='G10579',
        sec_code=None,
        fund_name='ニッセイ短期インド債券ファンド（毎月決算型）／ニッセイ短期インド債券ファンド（年２回決算型）',
        fund_name_yomi='ニッセイタンキインドサイケンファンドマイツキケッサンガタ\u3000ニッセイタンキインドサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10580': FundCodeEntry(
        fund_code='G10580',
        sec_code=None,
        fund_name='ニッセイ・インド厳選株式ファンド',
        fund_name_yomi='ニッセイインドゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10581': FundCodeEntry(
        fund_code='G10581',
        sec_code=None,
        fund_name='ダイワ新成長株主還元株ファンド\u3000－株主の微笑み－',
        fund_name_yomi='ダイワシンセイチョウカブヌシカンゲンカブファンドカブヌシノホホエミ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10583': FundCodeEntry(
        fund_code='G10583',
        sec_code=None,
        fund_name='ＪＰＭベスト・インカム（年１回決算型）',
        fund_name_yomi='ジェイピーエムベストインカムネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10586': FundCodeEntry(
        fund_code='G10586',
        sec_code=None,
        fund_name='ＪＰＭベスト・インカム（毎月決算型）',
        fund_name_yomi='ジェイピーエムベストインカムマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10595': FundCodeEntry(
        fund_code='G10595',
        sec_code=None,
        fund_name='ニッセイ世界ハイブリッド証券戦略ファンド（毎月決算型・通貨プレミアムコース）',
        fund_name_yomi='ニッセイセカイハイブリッドショウケンセンリャクファンドマイツキケッサンガタツウカプレミアムコース',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10596': FundCodeEntry(
        fund_code='G10596',
        sec_code=None,
        fund_name='ニッセイ世界ハイブリッド証券戦略ファンド（毎月決算型・為替ヘッジありコース）／ニッセイ世界ハイブリッド証券戦略ファンド（毎月決算型・為替ヘッジなしコース）',
        fund_name_yomi='ニッセイセカイハイブリッドショウケンセンリャクファンドマイツキケッサンガタカワセヘッジアリコース\u3000ニッセイセカイハイブリッドショウケンセンリャクファンドマイツキケッサンガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10597': FundCodeEntry(
        fund_code='G10597',
        sec_code=None,
        fund_name='優先リート・オープン',
        fund_name_yomi='ユウセンリートオープン',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10598': FundCodeEntry(
        fund_code='G10598',
        sec_code=None,
        fund_name='ＧＩＭ（ケイマン諸島）トラスト－ＧＩＭ世界金融債券ファンド\u3000円投資型１４１０',
        fund_name_yomi='ジーアイエムケイマンショトウトラストジーアイエムセカイキンユウサイケンファンドエントウシガタイチヨンイチゼロ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E26661',
        issuer_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
    ),
    'G10600': FundCodeEntry(
        fund_code='G10600',
        sec_code=None,
        fund_name='３つの財布\u3000欧州銀行株式ファンド（毎月分配型）',
        fund_name_yomi='ミッツノサイフ\u3000オウシュウギンコウカブシキファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10601': FundCodeEntry(
        fund_code='G10601',
        sec_code=None,
        fund_name='ＢＮＰパリバ・グローバル金融機関ハイブリッド証券ファンド（為替ヘッジあり）',
        fund_name_yomi='ビーエヌピーパリバグローバルキンユウキカンハイブリッドショウケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10603': FundCodeEntry(
        fund_code='G10603',
        sec_code=None,
        fund_name='ＪＰＸ日経インデックス４００・コアプラス',
        fund_name_yomi='ジェイピーエックスニッケイインデックスヨンヒャクコアプラス',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10608': FundCodeEntry(
        fund_code='G10608',
        sec_code=None,
        fund_name='野村高配当インフラ関連株ファンド（通貨選択型）',
        fund_name_yomi='ノムラコウハイトウインフラカンレンカブファンドツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10611': FundCodeEntry(
        fund_code='G10611',
        sec_code=None,
        fund_name='日興ＵＳグローイング・ベンチャーファンド',
        fund_name_yomi='ニッコウユーエスグローイング\u3000ベンチャーファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10612': FundCodeEntry(
        fund_code='G10612',
        sec_code=None,
        fund_name='アジア・リートオープン（毎月決算型）',
        fund_name_yomi='アジアリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10613': FundCodeEntry(
        fund_code='G10613',
        sec_code=None,
        fund_name='ＤＣニッセイ国内株式インデックス',
        fund_name_yomi='ディーシーニッセイコクナイカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10614': FundCodeEntry(
        fund_code='G10614',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－１０',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10617': FundCodeEntry(
        fund_code='G10617',
        sec_code=None,
        fund_name='ダイワ米国ＭＬＰファンド（毎月分配型）：米ドルコース、日本円コース、通貨αコース',
        fund_name_yomi='ダイワベイコクエムエルピーファンドマイツキブンパイガタベイドルコースニホンエンコースツウカアルファコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10618': FundCodeEntry(
        fund_code='G10618',
        sec_code=None,
        fund_name='あおぞら・短期ハイ・イールド債券ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='アオゾラタンキハイイールドサイケンファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G10621': FundCodeEntry(
        fund_code='G10621',
        sec_code=None,
        fund_name='スパークス・日本株式スチュワードシップ・ファンド',
        fund_name_yomi='スパークスニホンカブシキスチュワードシップファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G10624': FundCodeEntry(
        fund_code='G10624',
        sec_code=None,
        fund_name='日本の未来図（米ドル投資型）、日本の未来図（円投資型）',
        fund_name_yomi='ニホンノミライズベイドルトウシガタ\u3000ニホンノミライズエントウシガタ',
        security_type='内国投資信託受益証券',
        period_1='10月6日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10629': FundCodeEntry(
        fund_code='G10629',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（アクティブ）２０５０',
        fund_name_yomi='フィデリティターゲットデートファンドアクティブニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10630': FundCodeEntry(
        fund_code='G10630',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０５０',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10632': FundCodeEntry(
        fund_code='G10632',
        sec_code=None,
        fund_name='ＭＡＳＡＭＩＴＳＵ日本株戦略ファンド',
        fund_name_yomi='マサミツニホンカブセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G10633': FundCodeEntry(
        fund_code='G10633',
        sec_code=None,
        fund_name='世界ハイインカム入替戦略ファンド\u3000為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='セカイハイインカムイレカエセンリャクファンド\u3000カワセヘッジアリ\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10640': FundCodeEntry(
        fund_code='G10640',
        sec_code=None,
        fund_name='グローバル・ハイブリッド・プレミア（為替ヘッジなし）、グローバル・ハイブリッド・プレミア（為替ヘッジあり）',
        fund_name_yomi='グローバル\u3000ハイブリッド\u3000プレミア\u3000カワセヘッジナシ\u3000グローバル\u3000ハイブリッド\u3000プレミア\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10642': FundCodeEntry(
        fund_code='G10642',
        sec_code=None,
        fund_name='アジア・ハイイールド債券ファンド毎月分配型（ヘッジなしコース）',
        fund_name_yomi='ニッコウアジアハイイールドサイケンファンドマイツキブンパイガタヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10649': FundCodeEntry(
        fund_code='G10649',
        sec_code='34510',
        fund_name='トーセイ・リート投資法人',
        fund_name_yomi='トーセイリートトウシホウジン',
        security_type='内国投資証券',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E30997',
        issuer_name='トーセイ・リート投資法人',
    ),
    'G10650': FundCodeEntry(
        fund_code='G10650',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－１１',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンイチイチ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10654': FundCodeEntry(
        fund_code='G10654',
        sec_code=None,
        fund_name='東京海上・円資産バランスファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウエンシサンバランスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月23日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10655': FundCodeEntry(
        fund_code='G10655',
        sec_code='13600',
        fund_name='日経平均ベア２倍上場投信',
        fund_name_yomi='ニッケイヘイキンベアニバイジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G10659': FundCodeEntry(
        fund_code='G10659',
        sec_code=None,
        fund_name='ニュージーランド・ボンド・オープン（毎月決算型）',
        fund_name_yomi='ニュージーランドボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10661': FundCodeEntry(
        fund_code='G10661',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000国内物価連動国債インデックス',
        fund_name_yomi='イーマクシスコクナイブッカレンドウコクサイインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10663': FundCodeEntry(
        fund_code='G10663',
        sec_code=None,
        fund_name='インデックスファンドＭＬＰ（１年決算型）',
        fund_name_yomi='インデックスファンドエムエルピー\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10669': FundCodeEntry(
        fund_code='G10669',
        sec_code=None,
        fund_name='野村新興国高配当株トリプルウイング\u3000ブラジルレアル毎月分配型',
        fund_name_yomi='ノムラシンコウコクコウハイトウカブトリプルウイングブラジルレアルマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2='11月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10671': FundCodeEntry(
        fund_code='G10671',
        sec_code='33090',
        fund_name='積水ハウス・リート投資法人',
        fund_name_yomi='セキスイハウスリートトウシホウジン',
        security_type='内国投資証券',
        period_1='10月末日',
        period_2='4月末日',
        edinet_code='E31038',
        issuer_name='積水ハウス・リート投資法人',
    ),
    'G10672': FundCodeEntry(
        fund_code='G10672',
        sec_code=None,
        fund_name='日興ワールド・トラスト－日興ブラックロック・ハイ・クオリティ・アロケーション・ファンド（米ドル建て）',
        fund_name_yomi='ニッコウワールドトラストニッコウブラックロックハイクオリティアロケーションファンドベイドルダテ',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G10675': FundCodeEntry(
        fund_code='G10675',
        sec_code=None,
        fund_name='いちよしインフラ関連成長株ファンド',
        fund_name_yomi='イチヨシインフラカンレンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G10679': FundCodeEntry(
        fund_code='G10679',
        sec_code=None,
        fund_name='ＳＢＩグローバル・ラップファンド（安定型）（積極型）',
        fund_name_yomi='エスビーアイ\u3000グローバル\u3000ラップファンド\u3000アンテイガタ\u3000セッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G10681': FundCodeEntry(
        fund_code='G10681',
        sec_code=None,
        fund_name='ミューズニッチ米国ＢＤＣファンド（為替ヘッジあり・毎月分配型）、ミューズニッチ米国ＢＤＣファンド（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='ミューズニッチベイコクビーディシーファンド\u3000カワセヘッジアリ\u3000マイツキブンパイガタ\u3000ミューズニッチベイコクビーディシーファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10683': FundCodeEntry(
        fund_code='G10683',
        sec_code=None,
        fund_name='ラップ・コンシェルジュ（安定タイプ／ミドルタイプ／成長タイプ）',
        fund_name_yomi='ラップコンシェルジュアンテイタイプミドルタイプセイチョウタイプ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10690': FundCodeEntry(
        fund_code='G10690',
        sec_code=None,
        fund_name='インベスコ\u3000プレミア・プラス・ファンド',
        fund_name_yomi='インベスコプレミアプラスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G10694': FundCodeEntry(
        fund_code='G10694',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１４－１２',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチヨンイチニイ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10696': FundCodeEntry(
        fund_code='G10696',
        sec_code=None,
        fund_name='ブラジル株式ツインαファンド（毎月分配型）',
        fund_name_yomi='ブラジルカブシキツインアルファファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G10697': FundCodeEntry(
        fund_code='G10697',
        sec_code=None,
        fund_name='ＳＭＴ\u3000新興国ＲＥＩＴインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000シンコウコクリートインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10698': FundCodeEntry(
        fund_code='G10698',
        sec_code=None,
        fund_name='ＳＭＴ\u3000インデックスバランス・オープン',
        fund_name_yomi='エスエムティー\u3000インデックスバランス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10701': FundCodeEntry(
        fund_code='G10701',
        sec_code='13640',
        fund_name='ｉシェアーズ\u3000ＪＰＸ日経４００\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズジェイピーエックスニッケイヨンヒャクイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G10706': FundCodeEntry(
        fund_code='G10706',
        sec_code=None,
        fund_name='スロベニア・クロアチア・ギリシャ株式ファンド',
        fund_name_yomi='スロベニアクロアチアギリシャカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10707': FundCodeEntry(
        fund_code='G10707',
        sec_code=None,
        fund_name='ダイワ日本株ニュー・グロース・ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワニホンカブニューグロースファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='12月4日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10715': FundCodeEntry(
        fund_code='G10715',
        sec_code=None,
        fund_name='日本株式セレクト－アクティブ・ウーマン－',
        fund_name_yomi='ニホンカブシキセレクトアクティブウーマン',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10717': FundCodeEntry(
        fund_code='G10717',
        sec_code=None,
        fund_name='ＧＩＭ（ケイマン諸島）トラスト－ＧＩＭ世界金融債券ファンド\u3000円投資型１５０１',
        fund_name_yomi='ジーアイエムケイマンショトウトラストジーアイエムセカイキンユウサイケンファンドエントウシガタイチゴウゼロイチ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E26661',
        issuer_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
    ),
    'G10722': FundCodeEntry(
        fund_code='G10722',
        sec_code=None,
        fund_name='アジア・ヘルスケア株式ファンド',
        fund_name_yomi='アジア\u3000ヘルスケアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10725': FundCodeEntry(
        fund_code='G10725',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000優良日本株ファンド',
        fund_name_yomi='ミツビシユーエフジェイユウリョウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10728': FundCodeEntry(
        fund_code='G10728',
        sec_code=None,
        fund_name='ＰＨＥＩＭ\u3000ＡＳＥＡＮ株式ファンド',
        fund_name_yomi='フェイムアセアンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G10730': FundCodeEntry(
        fund_code='G10730',
        sec_code=None,
        fund_name='三井住友・ＤＣ年金バランスゼロ（債券型）',
        fund_name_yomi='ミツイスミトモディーシーネンキンバランスゼロサイケンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10738': FundCodeEntry(
        fund_code='G10738',
        sec_code=None,
        fund_name='スマート・ラップ・グローバル・インカム（毎月分配型）',
        fund_name_yomi='スマート\u3000ラップ\u3000グローバル\u3000インカム\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10739': FundCodeEntry(
        fund_code='G10739',
        sec_code=None,
        fund_name='スマート・ラップ・グローバル・インカム（１年決算型）',
        fund_name_yomi='スマート\u3000ラップ\u3000グローバル\u3000インカム\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10740': FundCodeEntry(
        fund_code='G10740',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000米国バンクローンファンド＜円インカム＞（毎月分配型）／（年２回分配型）ＰＩＭＣＯ\u3000米国バンクローンファンド＜米ドルインカム＞（毎月分配型）／（年２回分配型）',
        fund_name_yomi='ピムコベイコクバンクローンファンドエンインカムマイツキブンパイガタネンニカイブンパイガタピムコベイコクバンクローンファンドベイドルインカムマイツキブンパイガタネンニカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10741': FundCodeEntry(
        fund_code='G10741',
        sec_code=None,
        fund_name='コモンズ３０＋しずぎんファンド',
        fund_name_yomi='コモンズサーティープラスシズギンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E22096',
        issuer_name='コモンズ投信株式会社',
    ),
    'G10742': FundCodeEntry(
        fund_code='G10742',
        sec_code=None,
        fund_name='東京海上・ＵＳ優先リートオープン',
        fund_name_yomi='トウキョウカイジョウユーエスユウセンリートオープン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10745': FundCodeEntry(
        fund_code='G10745',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000バランス・イノベーション（債券重視型）',
        fund_name_yomi='ミツビシユーエフジェイバランスイノベーションサイケンジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10749': FundCodeEntry(
        fund_code='G10749',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１５－０１',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチゴゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10752': FundCodeEntry(
        fund_code='G10752',
        sec_code=None,
        fund_name='ダイワ米国バンクローン・オープン：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワベイコクバンクローンオープンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2='7月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10753': FundCodeEntry(
        fund_code='G10753',
        sec_code=None,
        fund_name='ダイワ短期国際機関債ファンド（毎月分配型／年２回決算型）－成長の絆－',
        fund_name_yomi='ダイワタンキコクサイキカンサイファンドマイツキブンパイガタネンニカイケッサンガタセイチョウノキズナ',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10754': FundCodeEntry(
        fund_code='G10754',
        sec_code=None,
        fund_name='ＮＮ欧州リート・ファンド（毎月決算コース／為替ヘッジあり）ＮＮ欧州リート・ファンド（資産形成コース／為替ヘッジあり）',
        fund_name_yomi='エヌエヌオウシュウリートファンドマイツキケッサンコースカワセヘッジアリエヌエヌオウシュウリートファンドシサンケイセイコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10755': FundCodeEntry(
        fund_code='G10755',
        sec_code=None,
        fund_name='東京海上Ｒｏｇｇｅグローバルインフラ・ハイイールド債ファンド',
        fund_name_yomi='トウキョウカイジョウロゲーグローバルインフラハイイールドサイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10756': FundCodeEntry(
        fund_code='G10756',
        sec_code=None,
        fund_name='ちゅうぎん日本大型株アクティブファンド',
        fund_name_yomi='チュウギンニホンオオガタカブアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G10758': FundCodeEntry(
        fund_code='G10758',
        sec_code=None,
        fund_name='ニッセイ国内債券インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイコクナイサイケンインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10759': FundCodeEntry(
        fund_code='G10759',
        sec_code=None,
        fund_name='ニッセイＪＰＸ日経４００インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイジェイピーエックスニッケイヨンヒャクインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10760': FundCodeEntry(
        fund_code='G10760',
        sec_code=None,
        fund_name='ケネディクス商業リート投資法人',
        fund_name_yomi='ケネディクスショウギョウリートトウシホウジン',
        security_type='内国投資証券',
        period_1='9月末日',
        period_2='3月末日',
        edinet_code='E14109',
        issuer_name='ＫＤＸ不動産投資法人',
    ),
    'G10764': FundCodeEntry(
        fund_code='G10764',
        sec_code='13650',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経平均レバレッジ・インデックス',
        fund_name_yomi='アイフリーイーティーエフニッケイヘイキンレバレッジインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10765': FundCodeEntry(
        fund_code='G10765',
        sec_code=None,
        fund_name='三井住友・米国ハイクオリティ株式ファンド（為替ヘッジあり）、三井住友・米国ハイクオリティ株式ファンド（為替ヘッジなし）',
        fund_name_yomi='ミツイスミトモベイコクハイクオリティカブシキファンドカワセヘッジアリ\u3000ミツイスミトモベイコクハイクオリティカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10766': FundCodeEntry(
        fund_code='G10766',
        sec_code='13660',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経平均ダブルインバース・インデックス',
        fund_name_yomi='アイフリーイーティーエフニッケイヘイキンダブルインバースインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10767': FundCodeEntry(
        fund_code='G10767',
        sec_code='13670',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸレバレッジ（２倍）指数',
        fund_name_yomi='アイフリーイーティーエフトピックスレバレッジニバイシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10769': FundCodeEntry(
        fund_code='G10769',
        sec_code='13680',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸダブルインバース（－２倍）指数',
        fund_name_yomi='アイフリーイーティーエフトピックスダブルインバースマイナスニバイシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10774': FundCodeEntry(
        fund_code='G10774',
        sec_code=None,
        fund_name='三井住友・新興国ハイクオリティ株式ファンド',
        fund_name_yomi='ミツイスミトモシンコウコクハイクオリティカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10775': FundCodeEntry(
        fund_code='G10775',
        sec_code=None,
        fund_name='ジャパン・ストラテジック・バリュー',
        fund_name_yomi='ジャパンストラテジックバリュー',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10776': FundCodeEntry(
        fund_code='G10776',
        sec_code=None,
        fund_name='三井住友・新興国債券トータルリターン・ファンド（為替ヘッジあり）、三井住友・新興国債券トータルリターン・ファンド（為替ヘッジなし）',
        fund_name_yomi='ミツイスミトモシンコウコクサイケントータルリターンファンドカワセヘッジアリミツイスミトモシンコウコクサイケントータルリターンファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10780': FundCodeEntry(
        fund_code='G10780',
        sec_code=None,
        fund_name='ニッポン成長株オープン',
        fund_name_yomi='ニッポンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10789': FundCodeEntry(
        fund_code='G10789',
        sec_code='13690',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日経２２５',
        fund_name_yomi='ワンイーティーエフニッケイニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10790': FundCodeEntry(
        fund_code='G10790',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・豪州インカム資産ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ゴウシュウインカムシサンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G10791': FundCodeEntry(
        fund_code='G10791',
        sec_code=None,
        fund_name='国内株式ＳＭＴＢセレクション（ＳＭＡ専用）',
        fund_name_yomi='コクナイカブシキエスエムティービーセレクション\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10795': FundCodeEntry(
        fund_code='G10795',
        sec_code=None,
        fund_name='ＪＰＸ日経４００アクティブ・オープン\u3000米ドル投資型／ＪＰＸ日経４００アクティブ・プレミアム・オープン（毎月決算型）',
        fund_name_yomi='ジェイピーエックスニッケイヨンヒャクアクティブオープンベイドルトウシガタ\u3000ジェイピーエックスニッケイヨンヒャクアクティブプレミアムオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10796': FundCodeEntry(
        fund_code='G10796',
        sec_code=None,
        fund_name='ＪＰＸ日経インデックス４００・オープン（ＳＭＡ専用）',
        fund_name_yomi='ジェイピーエックスニッケイインデックスヨンヒャク\u3000オープン\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10797': FundCodeEntry(
        fund_code='G10797',
        sec_code=None,
        fund_name='アジア・ハイブリッド・ファンド',
        fund_name_yomi='アジア\u3000ハイブリッド\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10798': FundCodeEntry(
        fund_code='G10798',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000アドバンスト・バランス（安定型）／（安定成長型）',
        fund_name_yomi='ミツビシユーエフジェイアドバンストバランスアンテイガタアンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10799': FundCodeEntry(
        fund_code='G10799',
        sec_code=None,
        fund_name='ダイワ・ブラジル・レアル債α（毎月分配型）－スーパー・ハイインカム－：α５０コース、α１００コース',
        fund_name_yomi='ダイワブラジルレアルサイアルファマイツキブンパイガタスーパーハイインカムアルファゴジュウコースアルファヒャクコース',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10800': FundCodeEntry(
        fund_code='G10800',
        sec_code=None,
        fund_name='英国公社債ファンド（毎月分配型）',
        fund_name_yomi='エイコクコウシャサイファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月8日',
        period_2='8月8日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10801': FundCodeEntry(
        fund_code='G10801',
        sec_code=None,
        fund_name='ＤＩＡＭ外国リートインデックスファンド＜ＤＣ年金＞',
        fund_name_yomi='ダイアムガイコクリートインデックスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G10802': FundCodeEntry(
        fund_code='G10802',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１５－０２',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチゴゼロニイ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10804': FundCodeEntry(
        fund_code='G10804',
        sec_code=None,
        fund_name='ワールド・コモディティ・オープン（ラップ向け）',
        fund_name_yomi='ワールドコモディティオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10806': FundCodeEntry(
        fund_code='G10806',
        sec_code=None,
        fund_name='債券コア戦略ファンド',
        fund_name_yomi='サイケンコアセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G10807': FundCodeEntry(
        fund_code='G10807',
        sec_code=None,
        fund_name='フィデリティ・アジアリート・ファンド（毎月決算型）',
        fund_name_yomi='フィデリティアジアリートファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10811': FundCodeEntry(
        fund_code='G10811',
        sec_code=None,
        fund_name='あおぞら・日本株式フォーカス戦略ファンド',
        fund_name_yomi='アオゾラニホンカブシキフォーカスセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G10814': FundCodeEntry(
        fund_code='G10814',
        sec_code=None,
        fund_name='三井住友・ニュー・アジア・ファンド',
        fund_name_yomi='ミツイスミトモニューアジアファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10823': FundCodeEntry(
        fund_code='G10823',
        sec_code=None,
        fund_name='為替ヘッジ付ソブリン／農業関連オープン',
        fund_name_yomi='カワセヘッジツキソブリンノウギョウカンレンオープン',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2='8月14日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10824': FundCodeEntry(
        fund_code='G10824',
        sec_code=None,
        fund_name='イーストスプリング・インド公益インフラ債券ファンド（毎月決算型）\u3000イーストスプリング・インド公益インフラ債券ファンド（年２回決算型）',
        fund_name_yomi='イーストスプリングインドコウエキインフラサイケンファンドマイツキケッサンガタ\u3000イーストスプリングインドコウエキインフラサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G10825': FundCodeEntry(
        fund_code='G10825',
        sec_code=None,
        fund_name='国内株式エンハンスト運用戦略ファンド（ＳＭＡ専用）',
        fund_name_yomi='コクナイカブシキエンハンストウンヨウセンリャクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G10826': FundCodeEntry(
        fund_code='G10826',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000米国バンクローンファンド＜世界通貨分散コース＞（毎月分配型）／（年２回分配型）',
        fund_name_yomi='ピムコベイコクバンクローンファンドセカイツウカブンサンコースマイツキブンパイガタネンニカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10831': FundCodeEntry(
        fund_code='G10831',
        sec_code=None,
        fund_name='あおぞら・徹底分散グローバル株式ファンド',
        fund_name_yomi='アオゾラテッテイブンサングローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G10834': FundCodeEntry(
        fund_code='G10834',
        sec_code='34550',
        fund_name='ヘルスケア＆メディカル投資法人',
        fund_name_yomi='ヘルスケアアンドメディカルトウシホウジン',
        security_type='内国投資証券',
        period_1='7月末日',
        period_2='1月末日',
        edinet_code='E31280',
        issuer_name='ヘルスケア＆メディカル投資法人',
    ),
    'G10838': FundCodeEntry(
        fund_code='G10838',
        sec_code=None,
        fund_name='シャリア関連アセアン株式オープン',
        fund_name_yomi='シャリアカンレンアセアンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10840': FundCodeEntry(
        fund_code='G10840',
        sec_code=None,
        fund_name='東京海上・日本債券オープン（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='トウキョウカイジョウニホンサイケンオープンノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G10841': FundCodeEntry(
        fund_code='G10841',
        sec_code=None,
        fund_name='アムンディ・ＵＳインカム・エクイティ・ファンド（毎月決算型）、アムンディ・ＵＳインカム・エクイティ・ファンド（年２回決算型）',
        fund_name_yomi='アムンディユーエスインカムエクイティファンドマイツキケッサンガタ\u3000アムンディユーエスインカムエクイティファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2='8月14日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G10842': FundCodeEntry(
        fund_code='G10842',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000内外株式',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000ナイガイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G10843': FundCodeEntry(
        fund_code='G10843',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000内外債券',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000ナイガイサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G10844': FundCodeEntry(
        fund_code='G10844',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000オルタナティブ',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000オルタナティブ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G10846': FundCodeEntry(
        fund_code='G10846',
        sec_code=None,
        fund_name='日本株発掘ファンド',
        fund_name_yomi='ニホンカブハックツファンド',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10847': FundCodeEntry(
        fund_code='G10847',
        sec_code=None,
        fund_name='女性活躍応援ファンド',
        fund_name_yomi='ジョセイカツヤクオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10848': FundCodeEntry(
        fund_code='G10848',
        sec_code=None,
        fund_name='アムンディ\u3000デュアル・バリュー・アロケーション',
        fund_name_yomi='アムンディデュアルバリューアロケーション',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G10853': FundCodeEntry(
        fund_code='G10853',
        sec_code=None,
        fund_name='マイターゲット２０５０（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンゴジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10854': FundCodeEntry(
        fund_code='G10854',
        sec_code=None,
        fund_name='ダイワ米国厳選バリュー株ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワベイコクゲンセンバリューカブファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10855': FundCodeEntry(
        fund_code='G10855',
        sec_code=None,
        fund_name='オーストラリア・バランス（資産成長型）、オーストラリア・バランス（毎月決算型）、オーストラリア・バランス（為替ヘッジ型）',
        fund_name_yomi='オーストラリアバランスシサンセイチョウガタ\u3000オーストラリアバランスマイツキケッサンガタ\u3000オーストラリアバランスカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10857': FundCodeEntry(
        fund_code='G10857',
        sec_code=None,
        fund_name='ＵＢＳ海外株式ファンド\u3000Ａコース為替ヘッジあり（野村ＳＭＡ・ＥＷ向け）／Ｂコース為替ヘッジなし（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ユービーエスカイガイカブシキファンド\u3000エーコースカワセヘッジアリ\u3000ノムラエスエムエーイーダブリュームケ\u3000ビーコースカワセヘッジナシ\u3000ノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G10858': FundCodeEntry(
        fund_code='G10858',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１５－０３',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチゴゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10859': FundCodeEntry(
        fund_code='G10859',
        sec_code=None,
        fund_name='ＪＰＸ日経４００インデックスファンド（ラップ向け）',
        fund_name_yomi='ジェーピーエックスニッケイヨンヒャクインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10860': FundCodeEntry(
        fund_code='G10860',
        sec_code=None,
        fund_name='新興国株式インデックスファンド（ラップ向け）',
        fund_name_yomi='シンコウコクカブシキインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10861': FundCodeEntry(
        fund_code='G10861',
        sec_code=None,
        fund_name='新興国債券インデックスファンド（ラップ向け）',
        fund_name_yomi='シンコウコクサイケンインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10862': FundCodeEntry(
        fund_code='G10862',
        sec_code=None,
        fund_name='米国バイオ＆テクノロジー株オープン',
        fund_name_yomi='ベイコクバイオアンドテクノロジーカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10864': FundCodeEntry(
        fund_code='G10864',
        sec_code=None,
        fund_name='フィデリティ・グローバル・エクイティ（野村ＳＭＡ・ＥＷ向け）Ａコース（限定為替ヘッジ）\u3000フィデリティ・グローバル・エクイティ（野村ＳＭＡ・ＥＷ向け）Ｂコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティグローバルエクイティノムラエスエムエーイーダブリュームケエーコースゲンテイカワセヘッジ\u3000フィデリティグローバルエクイティノムラエスエムエーイーダブリュームケビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G10866': FundCodeEntry(
        fund_code='G10866',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー\u3000オーストラリアＲＥＩＴファンド＜Ｗプレミアム＞／＜為替ヘッジなし＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーオーストラリアリートファンドダブルプレミアムカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10867': FundCodeEntry(
        fund_code='G10867',
        sec_code=None,
        fund_name='野村グローバル・ボンド・アクティブ・ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラグローバルボンドアクティブファンドノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10868': FundCodeEntry(
        fund_code='G10868',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村世界ＲＥＩＴファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラセカイリートファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラセカイリートファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10869': FundCodeEntry(
        fund_code='G10869',
        sec_code=None,
        fund_name='野村グローバル・アセット・モデル・ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラグローバルアセットモデルファンドノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10870': FundCodeEntry(
        fund_code='G10870',
        sec_code=None,
        fund_name='ストラテジック・バリュー・オープン（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ストラテジックバリューオープンノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10871': FundCodeEntry(
        fund_code='G10871',
        sec_code=None,
        fund_name='世界好配当株投信（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='セカイコウハイトウカブトウシンノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10872': FundCodeEntry(
        fund_code='G10872',
        sec_code=None,
        fund_name='ノムラ新興国債券ファンズ（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラシンコウコクサイケンファンズノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10873': FundCodeEntry(
        fund_code='G10873',
        sec_code=None,
        fund_name='野村米国国債部分ラダーファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村米国国債部分ラダーファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラベイコクコクサイブブンラダーファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラベイコクコクサイブブンラダーファンドビーコースノムラエスエムーエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10876': FundCodeEntry(
        fund_code='G10876',
        sec_code=None,
        fund_name='ノムラ日本株戦略ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニホンカブセンリャクファンドノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10877': FundCodeEntry(
        fund_code='G10877',
        sec_code=None,
        fund_name='リサーチ・アクティブ・オープン（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='リサーチアクティブオープンノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10878': FundCodeEntry(
        fund_code='G10878',
        sec_code=None,
        fund_name='ノムラ・ザ・セレクト（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラザセレクトノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10879': FundCodeEntry(
        fund_code='G10879',
        sec_code=None,
        fund_name='野村ＴＯＰＩＸインデックス（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラトピックスインデックスノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10880': FundCodeEntry(
        fund_code='G10880',
        sec_code=None,
        fund_name='ノムラ日本債券オープン（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニホンサイケンオープンノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10881': FundCodeEntry(
        fund_code='G10881',
        sec_code=None,
        fund_name='ノムラ新興国株ファンズ\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、ノムラ新興国株ファンズ\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラシンコウコクカブファンズエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラシンコウコクカブファンズビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10882': FundCodeEntry(
        fund_code='G10882',
        sec_code=None,
        fund_name='野村外国債券アクティブファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村外国債券アクティブファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラガイコクサイケンアクティブファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラガイコクサイケンアクティブファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10883': FundCodeEntry(
        fund_code='G10883',
        sec_code=None,
        fund_name='野村豪州債券ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村豪州債券ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラゴウシュウサイケンファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラゴウシュウサイケンファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10888': FundCodeEntry(
        fund_code='G10888',
        sec_code=None,
        fund_name='ＪＰＭ中小型株オープン（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ジェーピーエムチュウコガタカブオープンノムラエスエムエーイーダブリュムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10889': FundCodeEntry(
        fund_code='G10889',
        sec_code=None,
        fund_name='シュローダー日本ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='シュローダーニホンファンド\u3000ノムラエスエムエー\u3000イーダブリュムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G10890': FundCodeEntry(
        fund_code='G10890',
        sec_code=None,
        fund_name='野村日本債券インデックス（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニホンサイケンインデックスノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10891': FundCodeEntry(
        fund_code='G10891',
        sec_code=None,
        fund_name='野村外国株インデックス\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラガイコクカブインデックスビーコースノムラエスエムエーエーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10892': FundCodeEntry(
        fund_code='G10892',
        sec_code=None,
        fund_name='ハイ・イールド\u3000ボンド\u3000オープン\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、ハイ・イールド\u3000ボンド\u3000オープン\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ハイイールドボンドオープンエーコースノムラエスエムエーイーダブリュームケ\u3000ハイイールドボンドオープンビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10893': FundCodeEntry(
        fund_code='G10893',
        sec_code=None,
        fund_name='野村外国債券インデックス\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスビーコースノムラエスエムエーエーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10894': FundCodeEntry(
        fund_code='G10894',
        sec_code=None,
        fund_name='野村Ｊ－ＲＥＩＴインデックス（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラジェイリートインデックスノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10895': FundCodeEntry(
        fund_code='G10895',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴインデックス（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラセカイリートインデックスノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10896': FundCodeEntry(
        fund_code='G10896',
        sec_code=None,
        fund_name='野村セレクト・オポチュニティ（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラセレクトオポチュニティノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10897': FundCodeEntry(
        fund_code='G10897',
        sec_code=None,
        fund_name='野村ジャパンドリーム（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラジャパンドリームノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10898': FundCodeEntry(
        fund_code='G10898',
        sec_code=None,
        fund_name='ノムラスマートプレミアム（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラスマートプレミアムノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10899': FundCodeEntry(
        fund_code='G10899',
        sec_code=None,
        fund_name='野村ブルーベイ・トータルリターンファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラブルーベイトータルリターンファンドノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10903': FundCodeEntry(
        fund_code='G10903',
        sec_code=None,
        fund_name='ゴールドマン・サックス・世界債券オープンＡ限定為替ヘッジ（野村ＳＭＡ・ＥＷ向け）／Ｂ為替ヘッジなし（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ゴールドマン\u3000サックス\u3000セカイサイケンオープン\u3000エーゲンテイカワセヘッジ\u3000ノムラエスエムエー\u3000イーダブリュームケ\u3000ビーカワセヘッジナシ\u3000ノムラエスエムエー\u3000イーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10905': FundCodeEntry(
        fund_code='G10905',
        sec_code=None,
        fund_name='米国優先リートオープン（毎月決算型）（為替ヘッジあり）、米国優先リートオープン（毎月決算型）（為替ヘッジなし）',
        fund_name_yomi='ベイコクユウセンリートオープンマイツキケッサンガタカワセヘッジアリ\u3000ベイコクユウセンリートオープンマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G10907': FundCodeEntry(
        fund_code='G10907',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ファンド・ソリューションズ・シキャブ',
        fund_name_yomi='ユービーエス\u3000ルクス\u3000ファンド\u3000ソリューションズ\u3000シキャブ',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E31387',
        issuer_name='ＵＢＳ（Ｌｕｘ）ファンド・ソリューションズ・シキャブ',
    ),
    'G10908': FundCodeEntry(
        fund_code='G10908',
        sec_code=None,
        fund_name='ＧＩＭケイマン・トラストＩＩ－オルタナティブ・インベストメント・ストラテジーズ・ファンド',
        fund_name_yomi='ジーアイエムケイマントラストツーオルタナティブインベストメントストラテジーズファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E26661',
        issuer_name='ＪＰＭＡＭジャパン・ケイマン・ファンド・リミテッド',
    ),
    'G10910': FundCodeEntry(
        fund_code='G10910',
        sec_code=None,
        fund_name='ＧＳトータル・リターン\u3000積極（年２回決算）／安定（年２回決算）／安定（毎月決算）',
        fund_name_yomi='ジーエス\u3000トータルリターン\u3000セッキョク\u3000ネンニカイケッサン\u3000アンテイ\u3000ネンニカイケッサン\u3000アンテイ\u3000マイツキケッサン',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2='8月19日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G10912': FundCodeEntry(
        fund_code='G10912',
        sec_code=None,
        fund_name='３つの財布\u3000欧州不動産関連株ファンド（毎月分配型）',
        fund_name_yomi='ミッツノサイフ\u3000オウシュウフドウサンカンレンカブファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G10913': FundCodeEntry(
        fund_code='G10913',
        sec_code=None,
        fund_name='ＪＰＭジャパンプライム',
        fund_name_yomi='ジェイピーエムジャパンプライム',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10917': FundCodeEntry(
        fund_code='G10917',
        sec_code=None,
        fund_name='ＪＰＭ北米高配当株プライム',
        fund_name_yomi='ジェイピーエムホクベイコウハイトウカブプライム',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G10919': FundCodeEntry(
        fund_code='G10919',
        sec_code=None,
        fund_name='ミルバーン・コーナーストーン・ファンド',
        fund_name_yomi='ミルバーンコーナーストーンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E14732',
        issuer_name='ソシエテ・ジェネラル・オスマン・マネジメント株式会社',
    ),
    'G10920': FundCodeEntry(
        fund_code='G10920',
        sec_code=None,
        fund_name='日本企業価値向上ファンド（限定追加型）',
        fund_name_yomi='ニホンキギョウカチコウジョウファンドゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G10926': FundCodeEntry(
        fund_code='G10926',
        sec_code=None,
        fund_name='ＤＣスマート・アロケーション・Ｄガード',
        fund_name_yomi='ディーシースマートアロケーションディーガード',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G10927': FundCodeEntry(
        fund_code='G10927',
        sec_code='13970',
        fund_name='ＳＭＤＡＭ\u3000日経２２５上場投信',
        fund_name_yomi='エスエムディーエーエム\u3000ニッケイニーニーゴジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10928': FundCodeEntry(
        fund_code='G10928',
        sec_code='13980',
        fund_name='ＳＭＤＡＭ\u3000東証ＲＥＩＴ指数上場投信',
        fund_name_yomi='エスエムディーエーエム\u3000トウショウリートシスウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10929': FundCodeEntry(
        fund_code='G10929',
        sec_code=None,
        fund_name='ＤＣニッセイ外国株式インデックス',
        fund_name_yomi='ディーシーニッセイガイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10934': FundCodeEntry(
        fund_code='G10934',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１５－０４',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチゴゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10936': FundCodeEntry(
        fund_code='G10936',
        sec_code=None,
        fund_name='好配当海外株ファンド（ラップ向け）',
        fund_name_yomi='コウハイトウカイガイカブファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10943': FundCodeEntry(
        fund_code='G10943',
        sec_code=None,
        fund_name='アセアンワールド\u3000ファンド',
        fund_name_yomi='アセアンワールド\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G10945': FundCodeEntry(
        fund_code='G10945',
        sec_code=None,
        fund_name='アセットアロケーション・ファンド（安定型）、アセットアロケーション・ファンド（安定成長型）、アセットアロケーション・ファンド（成長型）',
        fund_name_yomi='アセットアロケーションファンドアンテイガタ\u3000アセットアロケーションファンドアンテイセイチョウガタ\u3000アセットアロケーションファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G10953': FundCodeEntry(
        fund_code='G10953',
        sec_code=None,
        fund_name='ニッセイＴＯＰＩＸインデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイトピックスインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G10955': FundCodeEntry(
        fund_code='G10955',
        sec_code=None,
        fund_name='フィロソフィック２・インベストメント・トラスト－ウィントン・パフォーマンス連動ボンドプラスファンド１５－０５（豪ドル建）',
        fund_name_yomi='フィロソフィックツーインベストメントトラストウィントンパフォーマンスレンドウボンドプラスファンドイチゴゼロゴゴウドルダテ',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E15033',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G10956': FundCodeEntry(
        fund_code='G10956',
        sec_code=None,
        fund_name='いちよし\u3000公開ベンチャー・ファンド',
        fund_name_yomi='イチヨシコウカイベンチャーファンド',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10957': FundCodeEntry(
        fund_code='G10957',
        sec_code=None,
        fund_name='株式オープン',
        fund_name_yomi='カブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10958': FundCodeEntry(
        fund_code='G10958',
        sec_code=None,
        fund_name='システム・オープン',
        fund_name_yomi='システムオープン',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10959': FundCodeEntry(
        fund_code='G10959',
        sec_code=None,
        fund_name='ユーロ・ソブリン・オープン',
        fund_name_yomi='ユーロソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10960': FundCodeEntry(
        fund_code='G10960',
        sec_code=None,
        fund_name='国際機関債オープン（為替ヘッジあり）',
        fund_name_yomi='コクサイキカンサイオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10961': FundCodeEntry(
        fund_code='G10961',
        sec_code=None,
        fund_name='インデックス・タイプ（ミリオン）',
        fund_name_yomi='インデックスタイプミリオン',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10963': FundCodeEntry(
        fund_code='G10963',
        sec_code=None,
        fund_name='グローバル・ソブリン・オープン（毎月決算型）',
        fund_name_yomi='グローバルソブリンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10964': FundCodeEntry(
        fund_code='G10964',
        sec_code=None,
        fund_name='ユーロランド・ソブリン・インカム',
        fund_name_yomi='ユーロランドソブリンインカム',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10965': FundCodeEntry(
        fund_code='G10965',
        sec_code=None,
        fund_name='グローバル財産３分法ファンド（毎月決算型）',
        fund_name_yomi='グローバルザイサンサンブンポウファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10966': FundCodeEntry(
        fund_code='G10966',
        sec_code=None,
        fund_name='グローバル株式インカム（毎月決算型）',
        fund_name_yomi='グローバルカブシキインカムマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10968': FundCodeEntry(
        fund_code='G10968',
        sec_code=None,
        fund_name='エマージング株式オープン',
        fund_name_yomi='エマージングカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10972': FundCodeEntry(
        fund_code='G10972',
        sec_code=None,
        fund_name='アジア・パシフィック・ソブリン・オープン（毎月決算型）',
        fund_name_yomi='アジアパシフィックソブリンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10973': FundCodeEntry(
        fund_code='G10973',
        sec_code=None,
        fund_name='アジア・パシフィック・ソブリン・オープン（年２回決算型）',
        fund_name_yomi='アジアパシフィックソブリンオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10981': FundCodeEntry(
        fund_code='G10981',
        sec_code=None,
        fund_name='成長株ジャパン・オープン',
        fund_name_yomi='セイチョウカブジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10982': FundCodeEntry(
        fund_code='G10982',
        sec_code=None,
        fund_name='割安株ジャパン・オープン',
        fund_name_yomi='ワリヤスカブジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10983': FundCodeEntry(
        fund_code='G10983',
        sec_code=None,
        fund_name='マネー・プール・ファンドⅥ',
        fund_name_yomi='マネープールファンドシックス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10986': FundCodeEntry(
        fund_code='G10986',
        sec_code=None,
        fund_name='好配当優良株ジャパン・オープン',
        fund_name_yomi='コウハイトウユウリョウカブジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10987': FundCodeEntry(
        fund_code='G10987',
        sec_code=None,
        fund_name='アジア・オセアニア好配当株オープン（毎月決算型）',
        fund_name_yomi='アジアオセアニアコウハイトウカブオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10990': FundCodeEntry(
        fund_code='G10990',
        sec_code=None,
        fund_name='トルコ債券オープン（毎月決算型）為替ヘッジなし',
        fund_name_yomi='トルコサイケンオープンマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10991': FundCodeEntry(
        fund_code='G10991',
        sec_code=None,
        fund_name='中小型成長株ジャパン・オープン',
        fund_name_yomi='チュウコガタセイチョウカブジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10992': FundCodeEntry(
        fund_code='G10992',
        sec_code=None,
        fund_name='トルコ債券オープン（毎月決算型）為替アクティブヘッジ',
        fund_name_yomi='トルコサイケンオープンマイツキケッサンガタカワセアクティブヘッジ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10993': FundCodeEntry(
        fund_code='G10993',
        sec_code=None,
        fund_name='グローバル・ソブリン・オープン（資産成長型）',
        fund_name_yomi='グローバルソブリンオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10994': FundCodeEntry(
        fund_code='G10994',
        sec_code=None,
        fund_name='ジャパン・ソブリン・オープン（資産成長型）',
        fund_name_yomi='ジャパンソブリンオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10995': FundCodeEntry(
        fund_code='G10995',
        sec_code=None,
        fund_name='ワールド・リート・オープン（資産成長型）',
        fund_name_yomi='ワールドリートオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G10996': FundCodeEntry(
        fund_code='G10996',
        sec_code=None,
        fund_name='日本厳選プレミアム株式オープン（年２回決算型）',
        fund_name_yomi='ニホンゲンセンプレミアムカブシキオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11001': FundCodeEntry(
        fund_code='G11001',
        sec_code=None,
        fund_name='ジャパン・ソブリン・オープン',
        fund_name_yomi='ジャパンソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11002': FundCodeEntry(
        fund_code='G11002',
        sec_code=None,
        fund_name='ワールド・リート・オープン（毎月決算型）',
        fund_name_yomi='ワールドリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11003': FundCodeEntry(
        fund_code='G11003',
        sec_code=None,
        fund_name='ワールド・リート・オープン（１年決算型）',
        fund_name_yomi='ワールドリートオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11005': FundCodeEntry(
        fund_code='G11005',
        sec_code=None,
        fund_name='国際のＥＴＦ\u3000ＶＩＸ短期先物指数',
        fund_name_yomi='コクサイノイーティーエフ\u3000ヴィックスタンキサキモノシスウ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11008': FundCodeEntry(
        fund_code='G11008',
        sec_code=None,
        fund_name='国際のＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='コクサイノエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11010': FundCodeEntry(
        fund_code='G11010',
        sec_code=None,
        fund_name='ＵＳ成長株オープン（円ヘッジありコース）\u3000ＵＳ成長株オープン（円ヘッジなしコース）',
        fund_name_yomi='ユーエスセイチョウカブオープンエンヘッジアリコース\u3000ユーエスセイチョウカブオープンエンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11012': FundCodeEntry(
        fund_code='G11012',
        sec_code=None,
        fund_name='国際オルタナティブ戦略\u3000ＱＴＸ－ウィントン・アルファ・インベストメント・オープン（円ヘッジ）成長型\u3000国際オルタナティブ戦略\u3000ＱＴＸ－ウィントン・アルファ・インベストメント・オープン（円ヘッジなし）成長型',
        fund_name_yomi='コクサイオルタナティブセンリャクキューティーエックスウィントンアルファインベストメントオープンエンヘッジセイチョウガタ\u3000コクサイオルタナティブセンリャクキューティーエックスウィントンアルファインベストメントオープンエンヘッジナシセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11013': FundCodeEntry(
        fund_code='G11013',
        sec_code=None,
        fund_name='国際オルタナティブ戦略\u3000ＱＴＸ－ウィントン・アルファ・インベストメント・オープン（円ヘッジ）分配型\u3000国際オルタナティブ戦略\u3000ＱＴＸ－ウィントン・アルファ・インベストメント・オープン（円ヘッジなし）分配型',
        fund_name_yomi='コクサイオルタナティブセンリャクキューティーエックスウィントンアルファインベストメントオープンエンヘッジブンパイガタ\u3000コクサイオルタナティブセンリャクキューティーエックスウィントンアルファインベストメントオープンエンヘッジナシブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月27日',
        period_2='12月27日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11015': FundCodeEntry(
        fund_code='G11015',
        sec_code=None,
        fund_name='米国エネルギーＭＬＰオープン（毎月決算型）為替ヘッジあり、米国エネルギーＭＬＰオープン（毎月決算型）為替ヘッジなし',
        fund_name_yomi='ベイコクエネルギーエムエルピーオープンマイツキケッサンガタカワセヘッジアリベイコクエネルギーエムエルピーオープンマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11016': FundCodeEntry(
        fund_code='G11016',
        sec_code=None,
        fund_name='国際\u3000アジア・リート・ファンド（通貨選択型）',
        fund_name_yomi='コクサイアジアリートファンドツウカセンタクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11017': FundCodeEntry(
        fund_code='G11017',
        sec_code=None,
        fund_name='国際・キャピタル\u3000日本株式オープン（通貨選択型）（１年決算型）',
        fund_name_yomi='コクサイキャピタルニホンカブシキオープンツウカセンタクガタイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11018': FundCodeEntry(
        fund_code='G11018',
        sec_code=None,
        fund_name='国際・キャピタル\u3000日本株式オープン（通貨選択型）（毎月決算型）',
        fund_name_yomi='コクサイキャピタルニホンカブシキオープンツウカセンタクガタマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11019': FundCodeEntry(
        fund_code='G11019',
        sec_code=None,
        fund_name='グローバル・バランス・ファンド（安定型）、グローバル・バランス・ファンド（安定成長型）、グローバル・バランス・ファンド（成長型）',
        fund_name_yomi='グローバルバランスファンドアンテイガタグローバルバランスファンドアンテイセイチョウガタグローバルバランスファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11020': FundCodeEntry(
        fund_code='G11020',
        sec_code=None,
        fund_name='欧州アクティブ株式オープン（為替ヘッジあり）、欧州アクティブ株式オープン（為替ヘッジなし）',
        fund_name_yomi='オウシュウアクティブカブシキオープンカワセヘッジアリ\u3000オウシュウアクティブカブシキオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11022': FundCodeEntry(
        fund_code='G11022',
        sec_code=None,
        fund_name='スマート・クオリティ・オープン（安定型）（１年決算型）、スマート・クオリティ・オープン（安定成長型）（１年決算型）、スマート・クオリティ・オープン（成長型）（１年決算型）',
        fund_name_yomi='スマートクオリティオープンアンテイガタイチネンケッサンガタスマートクオリティオープンアンテイセイチョウガタイチネンケッサンガタスマートクオリティオープンセイチョウガタイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月13日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11024': FundCodeEntry(
        fund_code='G11024',
        sec_code=None,
        fund_name='日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（インドネシアルピアコース）、日興ピムコ・ハイインカム・ソブリン・ファンド毎月分配型（インドルピーコース）',
        fund_name_yomi='ニッコウピムコ\u3000ハイインカム\u3000ソブリン\u3000ファンドマイツキブンパイガタ\u3000インドネシアルピアコース\u3000ニッコウピムコ\u3000ハイインカム\u3000ソブリン\u3000ファンドマイツキブンパイガタ\u3000インドルピーコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11025': FundCodeEntry(
        fund_code='G11025',
        sec_code=None,
        fund_name='フィデリティ・コア・インカム・ファンド（毎月決算型）為替ヘッジあり\u3000フィデリティ・コア・インカム・ファンド（毎月決算型）為替ヘッジなし',
        fund_name_yomi='フィデリティコアインカムファンドマイツキケッサンガタカワセヘッジアリ\u3000フィデリティコアインカムファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11026': FundCodeEntry(
        fund_code='G11026',
        sec_code=None,
        fund_name='フィデリティ・コア・インカム・ファンド（資産成長型）為替ヘッジあり\u3000フィデリティ・コア・インカム・ファンド（資産成長型）為替ヘッジなし',
        fund_name_yomi='フィデリティコアインカムファンドシサンセイチョウガタカワセヘッジアリ\u3000フィデリティコアインカムファンドシサンセイチョウガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11027': FundCodeEntry(
        fund_code='G11027',
        sec_code=None,
        fund_name='ノルディック社債ファンド\u3000為替ヘッジあり、ノルディック社債ファンド\u3000為替ヘッジなし',
        fund_name_yomi='ノルディックシャサイファンドカワセヘッジアリ\u3000ノルディックシャサイファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11028': FundCodeEntry(
        fund_code='G11028',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000Ｊリート不動産株ファンド＜米ドル投資型＞（３ヵ月決算型）／＜Ｗプレミアム＞（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェージェーリートフドウサンカブファンドベイドルトウシガタサンカゲツケッサンガタダブルプレミアムマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11029': FundCodeEntry(
        fund_code='G11029',
        sec_code='14560',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経平均インバース・インデックス',
        fund_name_yomi='アイフリーイーティーエフニッケイヘイキンインバースインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11030': FundCodeEntry(
        fund_code='G11030',
        sec_code='14570',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸインバース（－１倍）指数',
        fund_name_yomi='アイフリーイーティーエフトピックスインバースマイナスイチバイシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11038': FundCodeEntry(
        fund_code='G11038',
        sec_code=None,
        fund_name='グローバル・ソブリン・オープン（３ヵ月決算型）',
        fund_name_yomi='グローバルソブリンオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11040': FundCodeEntry(
        fund_code='G11040',
        sec_code=None,
        fund_name='ジャパニーズ・ドリーム・オープン',
        fund_name_yomi='ジャパニーズドリームオープン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11041': FundCodeEntry(
        fund_code='G11041',
        sec_code=None,
        fund_name='Ｊ・エクイティ',
        fund_name_yomi='ジェイエクイティ',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11042': FundCodeEntry(
        fund_code='G11042',
        sec_code=None,
        fund_name='グローバル・ヘルスケア＆バイオ・オープン\u3000Ａコース（為替ヘッジあり）',
        fund_name_yomi='グローバルヘルスケアアンドバイオオープンエーコースカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11043': FundCodeEntry(
        fund_code='G11043',
        sec_code=None,
        fund_name='グローバル・ヘルスケア＆バイオ・オープン\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='グローバルヘルスケアアンドバイオオープンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11044': FundCodeEntry(
        fund_code='G11044',
        sec_code=None,
        fund_name='グローバル・ソブリン・オープン（１年決算型）',
        fund_name_yomi='グローバルソブリンオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11045': FundCodeEntry(
        fund_code='G11045',
        sec_code=None,
        fund_name='Ｊ・エクイティ（ＤＣ年金）',
        fund_name_yomi='ジェイエクイティディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11046': FundCodeEntry(
        fund_code='G11046',
        sec_code=None,
        fund_name='グローバル・ソブリン・オープン（ＤＣ年金）',
        fund_name_yomi='グローバルソブリンオープンディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11047': FundCodeEntry(
        fund_code='G11047',
        sec_code=None,
        fund_name='エマージング・ソブリン・オープン（毎月決算型）',
        fund_name_yomi='エマージングソブリンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11048': FundCodeEntry(
        fund_code='G11048',
        sec_code=None,
        fund_name='エマージング・ソブリン・オープン（１年決算型）',
        fund_name_yomi='エマージングソブリンオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11049': FundCodeEntry(
        fund_code='G11049',
        sec_code=None,
        fund_name='グローバル・ヘルスケア＆バイオ・ファンド',
        fund_name_yomi='グローバルヘルスケアアンドバイオファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11050': FundCodeEntry(
        fund_code='G11050',
        sec_code=None,
        fund_name='ワールド短期ソブリンオープン',
        fund_name_yomi='ワールドタンキソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11053': FundCodeEntry(
        fund_code='G11053',
        sec_code=None,
        fund_name='グローバルＥＴＦオープン',
        fund_name_yomi='グローバルイーティーエフオープン',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11054': FundCodeEntry(
        fund_code='G11054',
        sec_code=None,
        fund_name='エマージング・ソブリン・オープン（毎月決算型）為替ヘッジあり',
        fund_name_yomi='エマージングソブリンオープンマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11056': FundCodeEntry(
        fund_code='G11056',
        sec_code=None,
        fund_name='アジア・ソブリン・オープン（毎月決算型）',
        fund_name_yomi='アジアソブリンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11058': FundCodeEntry(
        fund_code='G11058',
        sec_code=None,
        fund_name='世界投資適格債オープン（為替ヘッジあり）（毎月決算型）',
        fund_name_yomi='セカイトウシテキカクサイオープンカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11061': FundCodeEntry(
        fund_code='G11061',
        sec_code=None,
        fund_name='米国ハイ・イールド債オープン（通貨選択型）（円コース、米ドルコース、豪ドルコース、ブラジル・レアルコース、トルコ・リラコース）',
        fund_name_yomi='ベイコクハイイールドサイオープンツウカセンタクガタエンコースベイドルコースゴウドルコースブラジルレアルコーストルコリラコース',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11075': FundCodeEntry(
        fund_code='G11075',
        sec_code=None,
        fund_name='インド債券オープン（毎月決算型）',
        fund_name_yomi='インドサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11076': FundCodeEntry(
        fund_code='G11076',
        sec_code=None,
        fund_name='国際インド債券オープン（毎月決算型）',
        fund_name_yomi='コクサイインドサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11077': FundCodeEntry(
        fund_code='G11077',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000グローバル・プレミアム株式オープン（為替ヘッジあり）モルガン・スタンレー\u3000グローバル・プレミアム株式オープン（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーグローバルプレミアムカブシキオープンカワセヘッジアリ\u3000モルガンスタンレーグローバルプレミアムカブシキオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11079': FundCodeEntry(
        fund_code='G11079',
        sec_code=None,
        fund_name='トレンド・アロケーション・オープン',
        fund_name_yomi='トレンドアロケーションオープン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11081': FundCodeEntry(
        fund_code='G11081',
        sec_code=None,
        fund_name='エマージング・ソブリン・オープン（資産成長型）',
        fund_name_yomi='エマージングソブリンオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11082': FundCodeEntry(
        fund_code='G11082',
        sec_code=None,
        fund_name='エマージング・ソブリン・オープン（資産成長型）為替ヘッジあり',
        fund_name_yomi='エマージングソブリンオープンシサンセイチョウガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11087': FundCodeEntry(
        fund_code='G11087',
        sec_code=None,
        fund_name='世界メディカル関連株式オープン',
        fund_name_yomi='セカイメディカルカンレンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='8月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11088': FundCodeEntry(
        fund_code='G11088',
        sec_code=None,
        fund_name='スマート・クオリティ・オープン（安定型）、スマート・クオリティ・オープン（安定成長型）、スマート・クオリティ・オープン（成長型）',
        fund_name_yomi='スマートクオリティオープンアンテイガタ\u3000スマートクオリティオープンアンテイセイチョウガタ\u3000スマートクオリティオープンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月13日',
        period_2='8月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11092': FundCodeEntry(
        fund_code='G11092',
        sec_code=None,
        fund_name='ピクテ・エコディスカバリー・アロケーション・ファンド（毎月決算型）為替ヘッジなし',
        fund_name_yomi='ピクテエコディスカバリーアロケーションファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11096': FundCodeEntry(
        fund_code='G11096',
        sec_code=None,
        fund_name='野村ＤＣ・ＪＰＸ日経４００ファンド',
        fund_name_yomi='ノムラディーシージェイピーエックスニッケイヨンヒャクファンド',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11099': FundCodeEntry(
        fund_code='G11099',
        sec_code=None,
        fund_name='ジャパン・オフショア・ファンド・シリーズ－ＮＭ世界金融債券ファンド',
        fund_name_yomi='ジャパンオフショアファンドシリーズエヌエムセカイキンユウサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G11100': FundCodeEntry(
        fund_code='G11100',
        sec_code=None,
        fund_name='ラップ・アプローチ（安定コース）、ラップ・アプローチ（安定成長コース）、ラップ・アプローチ（成長コース）',
        fund_name_yomi='ラップアプローチアンテイコース\u3000ラップアプローチアンテイセイチョウコース\u3000ラップアプローチセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G11101': FundCodeEntry(
        fund_code='G11101',
        sec_code=None,
        fund_name='マッコーリー\u3000ヘッジ付グローバル・インフラ債券ファンド（ラップ向け）',
        fund_name_yomi='マッコーリーヘッジツキグローバルインフラサイケンファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11102': FundCodeEntry(
        fund_code='G11102',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴインデックスファンド（ラップ向け）',
        fund_name_yomi='ジェーリートインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11104': FundCodeEntry(
        fund_code='G11104',
        sec_code=None,
        fund_name='スカイオーシャン・コアラップ',
        fund_name_yomi='スカイオーシャンコアラップ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G11105': FundCodeEntry(
        fund_code='G11105',
        sec_code=None,
        fund_name='通貨選択型ダイワ／ミレーアセット・グローバル好配当株α（毎月分配型）：米ドル・コース、ブラジル・レアル・コース、通貨セレクト・コース',
        fund_name_yomi='ツウカセンタクガタダイワミレーアセットグローバルコウハイトウカブアルファマイツキブンパイガタベイドルコースブラジルレアルコースツウカセレクトコース',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11106': FundCodeEntry(
        fund_code='G11106',
        sec_code=None,
        fund_name='ダイワ／ミレーアセット・グローバル好配当株ファンド',
        fund_name_yomi='ダイワミレーアセットグローバルコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11107': FundCodeEntry(
        fund_code='G11107',
        sec_code=None,
        fund_name='日興・米国バンクローン・ファンド（為替ヘッジあり）１５－０５',
        fund_name_yomi='ニッコウベイコクバンクローンファンドカワセヘッジアリイチゴゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11108': FundCodeEntry(
        fund_code='G11108',
        sec_code=None,
        fund_name='インベスコ\u3000世界高利回り債券ファンド',
        fund_name_yomi='インベスコ\u3000セカイコウリマワリサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11109': FundCodeEntry(
        fund_code='G11109',
        sec_code=None,
        fund_name='インベスコ\u3000英国ポンド建て債券ファンド',
        fund_name_yomi='インベスコ\u3000エイコクポンドダテ\u3000サイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11114': FundCodeEntry(
        fund_code='G11114',
        sec_code=None,
        fund_name='高金利先進国債券ファンド（早期償還条項付）',
        fund_name_yomi='コウキンリセンシンコクサイケンファンド\u3000ソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11116': FundCodeEntry(
        fund_code='G11116',
        sec_code=None,
        fund_name='外国債券ＳＭＴＢセレクション（ＳＭＡ専用）',
        fund_name_yomi='ガイコクサイケンエスエムティービーセレクション\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11117': FundCodeEntry(
        fund_code='G11117',
        sec_code=None,
        fund_name='野村日本企業価値向上オープン（円投資型）、野村日本企業価値向上オープン（米ドル投資型）',
        fund_name_yomi='ノムラニホンキギョウカチコウジョウオープンエントウシガタ\u3000ノムラニホンキギョウカチコウジョウオープンベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11118': FundCodeEntry(
        fund_code='G11118',
        sec_code=None,
        fund_name='ダイワ・アジアリート・ファンド（毎月分配型）',
        fund_name_yomi='ダイワアジアリートファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11122': FundCodeEntry(
        fund_code='G11122',
        sec_code=None,
        fund_name='サテライト投資戦略ファンド（株式型）',
        fund_name_yomi='サテライトトウシセンリャクファンド\u3000カブシキガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11125': FundCodeEntry(
        fund_code='G11125',
        sec_code=None,
        fund_name='ＤＩＡＭベトナム株式ファンド',
        fund_name_yomi='ダイアムベトナムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11130': FundCodeEntry(
        fund_code='G11130',
        sec_code=None,
        fund_name='野村サービス関連株ファンド（米ドルコース）',
        fund_name_yomi='ノムラサービスカンレンカブファンドベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11132': FundCodeEntry(
        fund_code='G11132',
        sec_code=None,
        fund_name='ニッセイ・オーストラリア・リート・オープン（毎月決算型）／ニッセイ・オーストラリア・リート・オープン（年２回決算型）',
        fund_name_yomi='ニッセイオーストラリアリートオープンマイツキケッサンガタ\u3000ニッセイオーストラリアリートオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11133': FundCodeEntry(
        fund_code='G11133',
        sec_code=None,
        fund_name='バークレイズ・マルチマネージャー・ファンド・パブリック・リミテッド・カンパニー',
        fund_name_yomi='バークレイズマルチマネージャーファンドパブリックリミテッドカンパニー',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E31493',
        issuer_name='バークレイズ・マルチマネージャー・ファンド・パブリック・リミテッド・カンパニー',
    ),
    'G11136': FundCodeEntry(
        fund_code='G11136',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ストラテジー・シキャブ',
        fund_name_yomi='ユービーエスルクスストラテジーシキャブ',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E31583',
        issuer_name='ＵＢＳ（Ｌｕｘ）ストラテジー・シキャブ',
    ),
    'G11144': FundCodeEntry(
        fund_code='G11144',
        sec_code=None,
        fund_name='好配当日本株ファンド（ラップ向け）',
        fund_name_yomi='コウハイトウニホンカブファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11145': FundCodeEntry(
        fund_code='G11145',
        sec_code=None,
        fund_name='先進国高格付国債ファンド（ラップ向け）',
        fund_name_yomi='センシンコクコウカクヅケコクサイファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11147': FundCodeEntry(
        fund_code='G11147',
        sec_code=None,
        fund_name='シュローダー・ユーロ株式ファンド\u3000為替リスク軽減型、シュローダー・ユーロ株式ファンド\u3000為替ヘッジなし、シュローダー・ユーロ株式ファンド\u3000米ドル投資型',
        fund_name_yomi='シュローダー\u3000ユーロカブシキファンド\u3000カワセリスクケイゲンガタ\u3000シュローダー\u3000ユーロカブシキファンド\u3000カワセヘッジナシ\u3000シュローダー\u3000ユーロカブシキファンド\u3000ベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G11148': FundCodeEntry(
        fund_code='G11148',
        sec_code=None,
        fund_name='ＧＳ\u3000日本フォーカス・グロース\u3000毎月決算コース',
        fund_name_yomi='ジーエス\u3000ニホンフォーカスグロース\u3000マイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G11149': FundCodeEntry(
        fund_code='G11149',
        sec_code=None,
        fund_name='ＧＳ\u3000日本フォーカス・グロース\u3000年２回決算コース',
        fund_name_yomi='ジーエス\u3000ニホンフォーカスグロース\u3000ネンニカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G11155': FundCodeEntry(
        fund_code='G11155',
        sec_code='34590',
        fund_name='サムティ・レジデンシャル投資法人',
        fund_name_yomi='サムティレジデンシャルトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E31604',
        issuer_name='サムティ・レジデンシャル投資法人',
    ),
    'G11157': FundCodeEntry(
        fund_code='G11157',
        sec_code=None,
        fund_name='インベスコ\u3000新興国債券ファンド',
        fund_name_yomi='インベスコ\u3000シンコウコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11160': FundCodeEntry(
        fund_code='G11160',
        sec_code=None,
        fund_name='ＲＯＥ向上・日本厳選株式ファンド',
        fund_name_yomi='アールオーイーコウジョウニホンゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11161': FundCodeEntry(
        fund_code='G11161',
        sec_code=None,
        fund_name='アジア好利回りリート・ファンド（年１回決算型）',
        fund_name_yomi='アジアコウリマワリリートファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11162': FundCodeEntry(
        fund_code='G11162',
        sec_code=None,
        fund_name='豪州インフラ関連好配当資産ファンド（毎月決算型）、豪州インフラ関連好配当資産ファンド（年２回決算型）',
        fund_name_yomi='ゴウシュウインフラカンレンコウハイトウシサンファンドマイツキケッサンガタ\u3000ゴウシュウインフラカンレンコウハイトウシサンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11165': FundCodeEntry(
        fund_code='G11165',
        sec_code=None,
        fund_name='日興ロックフェラー・グローバル・エクイティ・ファンド',
        fund_name_yomi='ニッコウロックフェラー\u3000グローバル\u3000エクイティ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11168': FundCodeEntry(
        fund_code='G11168',
        sec_code=None,
        fund_name='イーストスプリング・アジア・オセアニア公益インフラ債券ファンド（毎月決算型）\u3000イーストスプリング・アジア・オセアニア公益インフラ債券ファンド（年２回決算型）',
        fund_name_yomi='イーストスプリングアジアオセアニアコウエキインフラサイケンファンドマイツキケッサンガタ\u3000イーストスプリングアジアオセアニアコウエキインフラサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G11169': FundCodeEntry(
        fund_code='G11169',
        sec_code=None,
        fund_name='ＨＳＢＣインド債券オープン（１年決算型）',
        fund_name_yomi='エイチエスビーシーインドサイケンオープンイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G11170': FundCodeEntry(
        fund_code='G11170',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－米国成長株集中投資ファンド\u3000外貨建てシリーズ',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ベイコクセイチョウカブシュウチュウトウシファンド\u3000ガイカダテシリーズ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G11171': FundCodeEntry(
        fund_code='G11171',
        sec_code='14580',
        fund_name='楽天ＥＴＦ‐日経レバレッジ指数連動型',
        fund_name_yomi='ラクテンイーティーエフ\u3000ニッケイレバレッジシスウレンドウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G11172': FundCodeEntry(
        fund_code='G11172',
        sec_code='14590',
        fund_name='楽天ＥＴＦ‐日経ダブルインバース指数連動型',
        fund_name_yomi='ラクテンイーティーエフ\u3000ニッケイダブルインバースシスウレンドウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G11173': FundCodeEntry(
        fund_code='G11173',
        sec_code=None,
        fund_name='ＳＢＩ中小型割安成長株ファンド\u3000ジェイリバイブ（年２回決算型）／愛称：ｊｒｅｖｉｖｅⅡ',
        fund_name_yomi='エスビーアイチュウコガタワリヤスセイチョウカブファンドジェイリバイブ\u3000ネンニカイケッサンガタ\u3000アイショウ\u3000ジェイリバイブツー',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G11175': FundCodeEntry(
        fund_code='G11175',
        sec_code=None,
        fund_name='東京海上・年金運用型戦略ファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウネンキンウンヨウガタセンリャクファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G11178': FundCodeEntry(
        fund_code='G11178',
        sec_code=None,
        fund_name='日本超長期国債ファンド',
        fund_name_yomi='ニホンチョウチョウキコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11179': FundCodeEntry(
        fund_code='G11179',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳプラス\u3000コモディティインデックス',
        fund_name_yomi='イーマクシスプラスコモディティインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11181': FundCodeEntry(
        fund_code='G11181',
        sec_code=None,
        fund_name='マイターゲット２０３０（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンサンジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11182': FundCodeEntry(
        fund_code='G11182',
        sec_code=None,
        fund_name='マイターゲット２０４０（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンヨンジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11184': FundCodeEntry(
        fund_code='G11184',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴバリューファンド\u3000毎月分配型、Ｊ－ＲＥＩＴバリューファンド\u3000年２回決算型',
        fund_name_yomi='ジェイリートバリューファンドマイツキブンパイガタ\u3000ジェイリートバリューファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11187': FundCodeEntry(
        fund_code='G11187',
        sec_code=None,
        fund_name='通貨選択型\u3000米国リート・αクワトロ（毎月分配型）',
        fund_name_yomi='ツウカセンタクガタベイコクリートアルファクワトロマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11189': FundCodeEntry(
        fund_code='G11189',
        sec_code=None,
        fund_name='通貨選択型アメリカン・エクイティ・αクワトロ（毎月分配型）',
        fund_name_yomi='ツウカセンタクガタアメリカンエクイティアルファクワトロマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11190': FundCodeEntry(
        fund_code='G11190',
        sec_code=None,
        fund_name='日本株発掘ファンド\u3000米ドル型',
        fund_name_yomi='ニホンカブハックツファンドベイドルカタ',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11192': FundCodeEntry(
        fund_code='G11192',
        sec_code=None,
        fund_name='アジア・パシフィック・セレクト・リート・ファンド（毎月決算型）',
        fund_name_yomi='アジアパシフィックセレクトリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11197': FundCodeEntry(
        fund_code='G11197',
        sec_code=None,
        fund_name='ジャパン・オフショア・ファンド・シリーズ－ＮＭ世界投資適格社債ファンド',
        fund_name_yomi='ジャパンオフショアファンドシリーズエヌエムセカイトウシテキカクシャサイファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15214',
        issuer_name='ＢＮＹメロン・インターナショナル・マネジメント・リミテッド',
    ),
    'G11198': FundCodeEntry(
        fund_code='G11198',
        sec_code=None,
        fund_name='ダイワ・ハイクオリティ日本株セレクト\u3000－叡智の和－',
        fund_name_yomi='ダイワハイクオリティニホンカブセレクトエイチノワ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11203': FundCodeEntry(
        fund_code='G11203',
        sec_code=None,
        fund_name='ニッセイ・ケイマン・トラスト－ＪＰＸ日経４００ジャパン・ファンド',
        fund_name_yomi='ニッセイケイマントラストジェイピーエックスニッケイヨンヒャクジャパンファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G11204': FundCodeEntry(
        fund_code='G11204',
        sec_code=None,
        fund_name='ちばぎんコア投資ファンド（安定型）／ちばぎんコア投資ファンド（成長型）',
        fund_name_yomi='チバギンコアトウシファンドアンテイガタ\u3000チバギンコアトウシファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G11205': FundCodeEntry(
        fund_code='G11205',
        sec_code=None,
        fund_name='外国株式ＳＭＴＢセレクション（ＳＭＡ専用）',
        fund_name_yomi='ガイコクカブシキエスエムティービーセレクション\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11209': FundCodeEntry(
        fund_code='G11209',
        sec_code=None,
        fund_name='米国優先リートファンド（為替ヘッジあり）、米国優先リートファンド（為替ヘッジなし）',
        fund_name_yomi='ベイコクユウセンリートファンドカワセヘッジアリ\u3000ベイコクユウセンリートファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11215': FundCodeEntry(
        fund_code='G11215',
        sec_code=None,
        fund_name='明治安田女性活躍推進ファンド',
        fund_name_yomi='メイジヤスダジョセイカツヤクスイシンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G11221': FundCodeEntry(
        fund_code='G11221',
        sec_code=None,
        fund_name='オーストラリアＲＥＩＴ・リサーチ・オープン（毎月決算型）',
        fund_name_yomi='オーストラリアリートリサーチオープン\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2='7月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11222': FundCodeEntry(
        fund_code='G11222',
        sec_code=None,
        fund_name='ＭＡＳＡＭＩＴＳＵ・Ｌｉｎｋ－Ｕ・ビッグデータ・ファンド',
        fund_name_yomi='マサミツリンクユービッグデータファンド',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G11230': FundCodeEntry(
        fund_code='G11230',
        sec_code=None,
        fund_name='グローバル・ロボティクス株式ファンド（１年決算型）',
        fund_name_yomi='グローバル\u3000ロボティクスカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11231': FundCodeEntry(
        fund_code='G11231',
        sec_code=None,
        fund_name='グローバル・ロボティクス株式ファンド（年２回決算型）',
        fund_name_yomi='グローバル\u3000ロボティクスカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11236': FundCodeEntry(
        fund_code='G11236',
        sec_code=None,
        fund_name='ＤＩＡＭコア資産設計ファンド（堅実型）、ＤＩＡＭコア資産設計ファンド（積極型）',
        fund_name_yomi='ダイアムコアシサンセッケイファンドケンジツガタ\u3000ダイアムコアシサンセッケイファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11239': FundCodeEntry(
        fund_code='G11239',
        sec_code=None,
        fund_name='ダイワ世界コーポレート・ハイブリッド証券ファンド（為替ヘッジあり）',
        fund_name_yomi='ダイワセカイコーポレートハイブリッドショウケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11240': FundCodeEntry(
        fund_code='G11240',
        sec_code=None,
        fund_name='ダイワ新グローバル・ハイブリッド証券ファンド：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワシングローバルハイブリッドショウケンファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11241': FundCodeEntry(
        fund_code='G11241',
        sec_code=None,
        fund_name='アジアセレクト・インフラ関連株オープン',
        fund_name_yomi='アジアセレクトインフラカンレンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G11245': FundCodeEntry(
        fund_code='G11245',
        sec_code=None,
        fund_name='アジアリート戦略オープン（為替ヘッジあり）毎月決算型、アジアリート戦略オープン（為替ヘッジあり）年２回決算型、アジアリート戦略オープン（為替ヘッジなし）毎月決算型、アジアリート戦略オープン（為替ヘッジなし）年２回決算型',
        fund_name_yomi='アジアリートセンリャクオープンカワセヘッジアリマイツキケッサンガタアジアリートセンリャクオープンカワセヘッジアリネンニカイケッサンガタアジアリートセンリャクオープンカワセヘッジナシマイツキケッサンガタアジアリートセンリャクオープンカワセヘッジナシネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11249': FundCodeEntry(
        fund_code='G11249',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸ日経４００レバレッジ・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエクスニッケイヨンヒャクレバレッジインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11250': FundCodeEntry(
        fund_code='G11250',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸ日経４００インバース・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエクスニッケイヨンヒャクインバースインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11251': FundCodeEntry(
        fund_code='G11251',
        sec_code='14720',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸ日経４００ダブルインバース・インデックス連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエクスニッケイヨンヒャクダブルインバースインデックスレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11252': FundCodeEntry(
        fund_code='G11252',
        sec_code=None,
        fund_name='南アジア株式ファンド',
        fund_name_yomi='ミナミアジアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G11255': FundCodeEntry(
        fund_code='G11255',
        sec_code=None,
        fund_name='ＪＰＸ日経４００ブル２倍上場投信（レバレッジ）',
        fund_name_yomi='ジェーピーエックスニッケイヨンヒャクブルニバイジョウジョウトウシン\u3000レバレッジ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G11256': FundCodeEntry(
        fund_code='G11256',
        sec_code=None,
        fund_name='ＪＰＸ日経４００ベア上場投信（インバース）',
        fund_name_yomi='ジェーピーエックスニッケイヨンヒャクベアジョウジョウトウシン\u3000インバース',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G11257': FundCodeEntry(
        fund_code='G11257',
        sec_code='14690',
        fund_name='ＪＰＸ日経４００ベア２倍上場投信（ダブルインバース）',
        fund_name_yomi='ジェーピーエックスニッケイヨンヒャクベアニバイジョウジョウトウシン\u3000ダブルインバース',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G11263': FundCodeEntry(
        fund_code='G11263',
        sec_code=None,
        fund_name='パインブリッジ・キャピタル証券ファンド（為替ヘッジなし）\u3000パインブリッジ・キャピタル証券ファンド（為替ヘッジあり）',
        fund_name_yomi='パインブリッジキャピタルショウケンファンドカワセヘッジナシ\u3000パインブリッジキャピタルショウケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G11267': FundCodeEntry(
        fund_code='G11267',
        sec_code=None,
        fund_name='ＧＣＩエンダウメントファンド（成長型／安定型）',
        fund_name_yomi='ジーシーアイエンダウメントファンド\u3000セイチョウガタ\u3000アンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E31744',
        issuer_name='株式会社ＧＣＩアセット・マネジメント',
    ),
    'G11268': FundCodeEntry(
        fund_code='G11268',
        sec_code=None,
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＪＰＸ日経４００レバレッジ・インデックス',
        fund_name_yomi='アイフリーイーティーエフジェイピーエックスニッケイヨンヒャクレバレッジインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11269': FundCodeEntry(
        fund_code='G11269',
        sec_code=None,
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＪＰＸ日経４００インバース・インデックス',
        fund_name_yomi='アイフリーイーティーエフジェイピーエックスニッケイヨンヒャクインバースインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11270': FundCodeEntry(
        fund_code='G11270',
        sec_code='14660',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＪＰＸ日経４００ダブルインバース・インデックス',
        fund_name_yomi='アイフリーイーティーエフジェイピーエックスニッケイヨンヒャクダブルインバースインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11272': FundCodeEntry(
        fund_code='G11272',
        sec_code=None,
        fund_name='ニッセイ・インド債券オープン（毎月決算型）／ニッセイ・インド債券オープン（年２回決算型）',
        fund_name_yomi='ニッセイインドサイケンオープンマイツキケッサンガタ\u3000ニッセイインドサイケンオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11273': FundCodeEntry(
        fund_code='G11273',
        sec_code=None,
        fund_name='ニッセイ・インデックスバランスファンド（４資産均等型）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイインデックスバランスファンドヨンシサンキントウガタコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11274': FundCodeEntry(
        fund_code='G11274',
        sec_code=None,
        fund_name='しんきん日経平均オープン',
        fund_name_yomi='シンキンニッケイヘイキンオープン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G11275': FundCodeEntry(
        fund_code='G11275',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000債券バランス（２資産均等型）',
        fund_name_yomi='イーマクシスサイケンバランスニシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11276': FundCodeEntry(
        fund_code='G11276',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000バランス（４資産均等型）',
        fund_name_yomi='イーマクシスバランスヨンシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11278': FundCodeEntry(
        fund_code='G11278',
        sec_code=None,
        fund_name='インバウンド関連日本株ファンド',
        fund_name_yomi='インバウンドカンレンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11280': FundCodeEntry(
        fund_code='G11280',
        sec_code=None,
        fund_name='３つの財布\u3000米国銀行株式ファンド\u3000（毎月分配型）',
        fund_name_yomi='ミッツノサイフ\u3000ベイコクギンコウカブシキファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G11281': FundCodeEntry(
        fund_code='G11281',
        sec_code=None,
        fund_name='日本エネルギー関連株式オープン',
        fund_name_yomi='ニホンエネルギーカンレンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11283': FundCodeEntry(
        fund_code='G11283',
        sec_code=None,
        fund_name='関西応援ファンド',
        fund_name_yomi='カンサイオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11284': FundCodeEntry(
        fund_code='G11284',
        sec_code=None,
        fund_name='ジャパン・アクティブ・グロース（分配型）、ジャパン・アクティブ・グロース（資産成長型）',
        fund_name_yomi='ジャパンアクティブグロースブンパイガタ\u3000ジャパンアクティブグロースシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11287': FundCodeEntry(
        fund_code='G11287',
        sec_code=None,
        fund_name='インベスコ\u3000インド債券ファンド（毎月決算型）',
        fund_name_yomi='インベスコインドサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11289': FundCodeEntry(
        fund_code='G11289',
        sec_code=None,
        fund_name='フィロソフィック２・インベストメント・トラスト－ウィントン・パフォーマンス連動ボンドプラスファンド１５－１０（豪ドル建）',
        fund_name_yomi='フィロソフィックツーインベストメントトラストウィントンパフォーマンスレンドウボンドプラスファンドイチゴイチゼロゴウドルダテ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E15033',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G11290': FundCodeEntry(
        fund_code='G11290',
        sec_code=None,
        fund_name='ウエスタン・アセット・オフショア・ファンド・シリーズ‐ＷＡ\u3000トータルリターン・オポチュニティーズ',
        fund_name_yomi='ウエスタンアセットオフショアファンドシリーズダブリューエートータルリターンオポチュニティーズ',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E24736',
        issuer_name='ウエスタン・アセット・マネジメント・カンパニー・リミテッド',
    ),
    'G11291': FundCodeEntry(
        fund_code='G11291',
        sec_code=None,
        fund_name='ダイワ債券コア戦略ファンド：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワサイケンコアセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11292': FundCodeEntry(
        fund_code='G11292',
        sec_code=None,
        fund_name='高金利先進国債券ファンド\u3000２０１５‐０９（早期償還機能付）',
        fund_name_yomi='コウキンリセンシンコクサイケンファンド\u3000ニセンジュウゴ\u3000ゼロキュウ\u3000ソウキショウカンキノウツキ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11295': FundCodeEntry(
        fund_code='G11295',
        sec_code=None,
        fund_name='スパークス・プレミアム・日本超小型株式ファンド',
        fund_name_yomi='スパークスプレミアムニホンチョウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G11296': FundCodeEntry(
        fund_code='G11296',
        sec_code='14730',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000トピックス',
        fund_name_yomi='ワンイーティーエフトピックス',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11297': FundCodeEntry(
        fund_code='G11297',
        sec_code='14740',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000ＪＰＸ日経４００',
        fund_name_yomi='ワンイーティーエフジェーピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11299': FundCodeEntry(
        fund_code='G11299',
        sec_code=None,
        fund_name='ＨＳＢＣワールド・セレクション（安定コース）／（安定成長コース）／（成長コース）',
        fund_name_yomi='エイチエスビーシーワールドセレクションアンテイコースアンテイセイチョウコースセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G11300': FundCodeEntry(
        fund_code='G11300',
        sec_code=None,
        fund_name='ブラックロックＥＳＧ世界株式ファンド（限定為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブラックロックイーエスジーセカイカブシキファンドゲンテイカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11301': FundCodeEntry(
        fund_code='G11301',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－グローバル・ハイ・イールド・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタイングローバルハイイールドポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G11303': FundCodeEntry(
        fund_code='G11303',
        sec_code=None,
        fund_name='あおぞら・世界配当成長株ベガ・ファンド（毎月分配型）',
        fund_name_yomi='アオゾラセカイハイトウセイチョウカブベガファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G11310': FundCodeEntry(
        fund_code='G11310',
        sec_code=None,
        fund_name='日興ブラックロック・ハイ・クオリティ・アロケーション・ファンド（為替ヘッジなし／年２回決算型）、日興ブラックロック・ハイ・クオリティ・アロケーション・ファンド（限定為替ヘッジ／年２回決算型）',
        fund_name_yomi='ニッコウブラックロックハイクオリティアロケーションファンドカワセヘッジナシネンニカイケッサンガタ\u3000ニッコウブラックロックハイクオリティアロケーションファンドゲンテイカワセヘッジネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2='12月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11311': FundCodeEntry(
        fund_code='G11311',
        sec_code=None,
        fund_name='日興ワールド・トラスト－ワールド・ハイブリッド・セキュリティーズ・ファンド',
        fund_name_yomi='ニッコウワールドトラストワールドハイブリッドセキュリティーズファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G11316': FundCodeEntry(
        fund_code='G11316',
        sec_code=None,
        fund_name='ＤＣニッセイ外国債券インデックス',
        fund_name_yomi='ディーシーニッセイガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11317': FundCodeEntry(
        fund_code='G11317',
        sec_code=None,
        fund_name='ターゲットイヤータイプ\u3000ラップ・コンシェルジュ２０２５',
        fund_name_yomi='ターゲットイヤータイプラップコンシェルジュニセンニジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11318': FundCodeEntry(
        fund_code='G11318',
        sec_code=None,
        fund_name='ターゲットイヤータイプ\u3000ラップ・コンシェルジュ２０２８',
        fund_name_yomi='ターゲットイヤータイプラップコンシェルジュニセンニジュウハチ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11319': FundCodeEntry(
        fund_code='G11319',
        sec_code=None,
        fund_name='ターゲットイヤータイプ\u3000ラップ・コンシェルジュ２０３１',
        fund_name_yomi='ターゲットイヤータイプラップコンシェルジュニセンサンジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11320': FundCodeEntry(
        fund_code='G11320',
        sec_code=None,
        fund_name='ターゲットイヤータイプ\u3000ラップ・コンシェルジュ２０３４',
        fund_name_yomi='ターゲットイヤータイプラップコンシェルジュニセンサンジュウヨン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11322': FundCodeEntry(
        fund_code='G11322',
        sec_code=None,
        fund_name='楽天日本株４．３倍ブル',
        fund_name_yomi='ラクテンニホンカブヨンテンサンバイブル',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G11323': FundCodeEntry(
        fund_code='G11323',
        sec_code=None,
        fund_name='ＵＢＳ（ＬＵＸ）エクイティ・ファンド',
        fund_name_yomi='ユービーエスルクスエクイティファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G11329': FundCodeEntry(
        fund_code='G11329',
        sec_code='14750',
        fund_name='ｉシェアーズ・コア\u3000ＴＯＰＩＸ\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズコアトピックスイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11330': FundCodeEntry(
        fund_code='G11330',
        sec_code='14770',
        fund_name='ｉシェアーズ\u3000ＭＳＣＩ\u3000日本株最小分散\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズエムエスシーアイニホンカブサイショウブンサンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11331': FundCodeEntry(
        fund_code='G11331',
        sec_code='14780',
        fund_name='ｉシェアーズ\u3000ＭＳＣＩ\u3000ジャパン高配当利回り\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズエムエスシーアイジャパンコウハイトウリマワリイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11332': FundCodeEntry(
        fund_code='G11332',
        sec_code='14760',
        fund_name='ｉシェアーズ・コア\u3000Ｊリート\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズコアジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11333': FundCodeEntry(
        fund_code='G11333',
        sec_code=None,
        fund_name='高金利先進国債券ファンド２（早期償還条項付）',
        fund_name_yomi='コウキンリセンシンコクサイケンファンドツウ\u3000ソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11334': FundCodeEntry(
        fund_code='G11334',
        sec_code=None,
        fund_name='ダイワ・ディスカバリー・ファンド・シリーズ－ダイワ債券コア戦略ファンド',
        fund_name_yomi='ダイワディスカバリーファンドシリーズダイワサイケンコアセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15791',
        issuer_name='ダイワ・アセット・マネジメント・サービシイズ・リミテッド（ケイマン）',
    ),
    'G11335': FundCodeEntry(
        fund_code='G11335',
        sec_code=None,
        fund_name='通貨選択型ダイワ米国株主還元株αクワトロプレミアム（毎月分配型／年２回決算型）',
        fund_name_yomi='ツウカセンタクガタダイワベイコクカブヌシカンゲンカブアルファクワトロプレミアムマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11336': FundCodeEntry(
        fund_code='G11336',
        sec_code=None,
        fund_name='ダイワ米国株主還元株ツインαプレミアム（毎月分配型／年２回決算型）',
        fund_name_yomi='ダイワベイコクカブヌシカンゲンカブツインアルファプレミアムマイツキブンパイガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11337': FundCodeEntry(
        fund_code='G11337',
        sec_code=None,
        fund_name='ダイワ米国株主還元株ファンド',
        fund_name_yomi='ダイワベイコクカブヌシカンゲンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11340': FundCodeEntry(
        fund_code='G11340',
        sec_code=None,
        fund_name='日興エドモン・ドゥ・ロスチャイルド・グローバルＣＢファンド（為替ヘッジあり）、日興エドモン・ドゥ・ロスチャイルド・グローバルＣＢファンド（為替ヘッジなし）',
        fund_name_yomi='ニッコウエドモンドゥロスチャイルドグローバルシービーファンドカワセヘッジアリ\u3000ニッコウエドモンドゥロスチャイルドグローバルシービーファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11342': FundCodeEntry(
        fund_code='G11342',
        sec_code=None,
        fund_name='日本郵政株式／グループ株式ファンド',
        fund_name_yomi='ニホンユウセイカブシキ\u3000グループカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月9日',
        period_2='10月9日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11350': FundCodeEntry(
        fund_code='G11350',
        sec_code=None,
        fund_name='ＤＩＡＭ新興国債券インデックスファンド＜為替ヘッジなし＞（ファンドラップ）',
        fund_name_yomi='ダイアムシンコウコクサイケンインデックスファンドカワセヘッジナシファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11352': FundCodeEntry(
        fund_code='G11352',
        sec_code=None,
        fund_name='ＳＭＴ\u3000米国ＲＥＩＴインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ベイコクリートインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11357': FundCodeEntry(
        fund_code='G11357',
        sec_code=None,
        fund_name='たわらノーロード\u3000新興国株式＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000シンコウコクカブシキラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11359': FundCodeEntry(
        fund_code='G11359',
        sec_code=None,
        fund_name='ピムコ・バミューダ・トラストＩＩ－ＰＩＭＣＯショート・ターム・モーゲージ・インカム',
        fund_name_yomi='ピムコバミューダトラストツー\u3000ピムコショートタームモーゲージインカム',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G11367': FundCodeEntry(
        fund_code='G11367',
        sec_code=None,
        fund_name='欧州厳選株式ファンド',
        fund_name_yomi='オウシュウゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G11372': FundCodeEntry(
        fund_code='G11372',
        sec_code=None,
        fund_name='日系企業海外債券オープン（為替ヘッジあり）、日系企業海外債券オープン（為替ヘッジなし）',
        fund_name_yomi='ニッケイキギョウカイガイサイケンオープンカワセヘッジアリニッケイキギョウカイガイサイケンオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2='10月30日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11373': FundCodeEntry(
        fund_code='G11373',
        sec_code=None,
        fund_name='ＤＩＡＭ新興国株式インカムプラスファンド（ファンドラップ）',
        fund_name_yomi='ダイアムシンコウコクカブシキインカムプラスファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11375': FundCodeEntry(
        fund_code='G11375',
        sec_code=None,
        fund_name='東京海上・グローバルヘルスケアＲＥＩＴオープン（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウグローバルヘルスケアリートオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G11376': FundCodeEntry(
        fund_code='G11376',
        sec_code=None,
        fund_name='東京海上・グローバルヘルスケアＲＥＩＴオープン（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウグローバルヘルスケアリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G11380': FundCodeEntry(
        fund_code='G11380',
        sec_code='34620',
        fund_name='野村不動産マスターファンド投資法人',
        fund_name_yomi='ノムラフドウサンマスターファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E31931',
        issuer_name='野村不動産マスターファンド投資法人',
    ),
    'G11381': FundCodeEntry(
        fund_code='G11381',
        sec_code=None,
        fund_name='フィデリティ・日本ＲＯＥフォーカス・ファンド',
        fund_name_yomi='フィデリティニホンアールオーイーフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11382': FundCodeEntry(
        fund_code='G11382',
        sec_code='34630',
        fund_name='いちごホテルリート投資法人',
        fund_name_yomi='イチゴホテルリートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E31889',
        issuer_name='いちごホテルリート投資法人',
    ),
    'G11385': FundCodeEntry(
        fund_code='G11385',
        sec_code=None,
        fund_name='日興アムンディ日本政策関連株式ファンド',
        fund_name_yomi='ニッコウアムンディニホンセイサクカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G11386': FundCodeEntry(
        fund_code='G11386',
        sec_code=None,
        fund_name='投資のソムリエ＜ＤＣ年金＞リスク抑制型',
        fund_name_yomi='トウシノソムリエディーシーネンキンリスクヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11389': FundCodeEntry(
        fund_code='G11389',
        sec_code=None,
        fund_name='ジャナス米国中小型成長株ファンド（年４回決算型）',
        fund_name_yomi='ジャナスベイコクチュウコガタセイチョウカブファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11391': FundCodeEntry(
        fund_code='G11391',
        sec_code=None,
        fund_name='ＳＢＩ中小型成長株ファンド\u3000ジェイネクスト（年２回決算型）／愛称：ｊｎｅｘｔⅡ',
        fund_name_yomi='エスビーアイ\u3000チュウコガタセイチョウカブファンド\u3000ジェイネクスト\u3000ネンニカイケッサンガタ\u3000アイショウ\u3000ジェイネクストツー',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G11393': FundCodeEntry(
        fund_code='G11393',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＪＡＰＡＮ\u3000クオリティ１５０インデックス',
        fund_name_yomi='イーマクシスジャパンクオリティヒャクゴジュウインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11394': FundCodeEntry(
        fund_code='G11394',
        sec_code=None,
        fund_name='ＭＩＴＯ\u3000ラップ型ファンド（安定型）、ＭＩＴＯ\u3000ラップ型ファンド（中立型）、ＭＩＴＯ\u3000ラップ型ファンド（積極型）',
        fund_name_yomi='ミトラップガタファンドアンテイガタ\u3000ミトラップガタファンドチュウリツガタ\u3000ミトラップガタファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11395': FundCodeEntry(
        fund_code='G11395',
        sec_code=None,
        fund_name='インベスコ\u3000オーストラリア債券ファンド（年１回決算型）',
        fund_name_yomi='インベスコオーストラリアサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11396': FundCodeEntry(
        fund_code='G11396',
        sec_code=None,
        fund_name='グローバル８資産ラップファンド（安定型）、グローバル８資産ラップファンド（中立型）、グローバル８資産ラップファンド（積極型）',
        fund_name_yomi='グローバルハチシサンラップファンドアンテイガタ\u3000グローバルハチシサンラップファンドチュウリツガタ\u3000グローバルハチシサンラップファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11398': FundCodeEntry(
        fund_code='G11398',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ワールド・バランス・インベストメント',
        fund_name_yomi='ノムラファンドセレクトワールドバランスインベストメント',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G11401': FundCodeEntry(
        fund_code='G11401',
        sec_code=None,
        fund_name='アムンディ・パトリモア・ジャパン（隔月決算型）',
        fund_name_yomi='アムンディパトリモアジャパンカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G11402': FundCodeEntry(
        fund_code='G11402',
        sec_code=None,
        fund_name='アムンディ・パトリモア・ジャパン（年１回決算型）',
        fund_name_yomi='アムンディパトリモアジャパンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G11403': FundCodeEntry(
        fund_code='G11403',
        sec_code=None,
        fund_name='ニッセイ国内債券アルファ',
        fund_name_yomi='ニッセイコクナイサイケンアルファ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11409': FundCodeEntry(
        fund_code='G11409',
        sec_code=None,
        fund_name='ＬＯＳＡ長期保有型国際分散インデックスファンド',
        fund_name_yomi='ローサチョウキホユウガタコクサイブンサンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11410': FundCodeEntry(
        fund_code='G11410',
        sec_code=None,
        fund_name='ダイナミック・マルチアセット戦略ファンド（為替ヘッジなし）、ダイナミック・マルチアセット戦略ファンド（限定為替ヘッジ）',
        fund_name_yomi='ダイナミックマルチアセットセンリャクファンドカワセヘッジナシ\u3000ダイナミックマルチアセットセンリャクファンドゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11416': FundCodeEntry(
        fund_code='G11416',
        sec_code=None,
        fund_name='日本連続増配成長株オープン',
        fund_name_yomi='ニホンレンゾクゾウハイセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G11417': FundCodeEntry(
        fund_code='G11417',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000ウェルス・コアポートフォリオ\u3000コンサバティブ型／ウェルス・コアポートフォリオ\u3000グロース型',
        fund_name_yomi='プレミアムファンズウェルスコアポートフォリオコンサバティブガタウェルスコアポートフォリオグロースガタ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G11420': FundCodeEntry(
        fund_code='G11420',
        sec_code='13990',
        fund_name='上場インデックスファンドＭＳＣＩ日本株高配当低ボラティリティ',
        fund_name_yomi='ジョウジョウインデックスファンドエムエスシーアイニホンカブコウハイトウテイボラティリティ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11425': FundCodeEntry(
        fund_code='G11425',
        sec_code=None,
        fund_name='グローバル・ストック\u3000Ａコース、グローバル・ストック\u3000Ｂコース、グローバル・ストック\u3000Ｃコース、グローバル・ストック\u3000Ｄコース',
        fund_name_yomi='グローバルストックエーコース\u3000グローバルストックビーコース\u3000グローバルストックシーコース\u3000グローバルストックディーコース',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11426': FundCodeEntry(
        fund_code='G11426',
        sec_code=None,
        fund_name='野村未来トレンド発見ファンド\u3000Ａコース（為替ヘッジあり）、野村未来トレンド発見ファンド\u3000Ｂコース（為替ヘッジなし）［Ｇ１２５３４と統合］',
        fund_name_yomi='ノムラミライトレンドハッケンファンドエーコースカワセヘッジアリ\u3000ノムラミライトレンドハッケンファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11431': FundCodeEntry(
        fund_code='G11431',
        sec_code=None,
        fund_name='ＬＭ・オーストラリア・インカム・アロケーション・ファンド（毎月分配型）\u3000ＬＭ・オーストラリア・インカム・アロケーション・ファンド（年２回決算型）',
        fund_name_yomi='エルエム\u3000オーストラリア\u3000インカム\u3000アロケーション\u3000ファンド\u3000マイツキブンパイガタ\u3000エルエム\u3000オーストラリア\u3000インカム\u3000アロケーション\u3000ファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G11434': FundCodeEntry(
        fund_code='G11434',
        sec_code=None,
        fund_name='グローバル・スマート・イノベーション・オープン（年２回決算型）',
        fund_name_yomi='グローバルスマートイノベーションオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11435': FundCodeEntry(
        fund_code='G11435',
        sec_code=None,
        fund_name='グローバル・スマート・イノベーション・オープン（年１回決算型）',
        fund_name_yomi='グローバルスマートイノベーションオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11439': FundCodeEntry(
        fund_code='G11439',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（アクティブ）２０３０',
        fund_name_yomi='フィデリティターゲットデートファンドアクティブニセンサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11440': FundCodeEntry(
        fund_code='G11440',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（アクティブ）２０４０',
        fund_name_yomi='フィデリティターゲットデートファンドアクティブニセンヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11441': FundCodeEntry(
        fund_code='G11441',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０３０',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11442': FundCodeEntry(
        fund_code='G11442',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０４０',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11443': FundCodeEntry(
        fund_code='G11443',
        sec_code=None,
        fund_name='ハリス\u3000グローバル\u3000バリュー株ファンド（年４回決算型）',
        fund_name_yomi='ハリスグローバルバリューカブファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G11454': FundCodeEntry(
        fund_code='G11454',
        sec_code=None,
        fund_name='産業競争力強化ファンド',
        fund_name_yomi='サンギョウキョウソウリョクキョウカファンド',
        security_type='内国投資信託受益証券',
        period_1='12月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11455': FundCodeEntry(
        fund_code='G11455',
        sec_code=None,
        fund_name='たわらノーロード\u3000日経２２５',
        fund_name_yomi='タワラノーロードニッケイニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11456': FundCodeEntry(
        fund_code='G11456',
        sec_code=None,
        fund_name='インベスコ\u3000インカム・ナビゲーター',
        fund_name_yomi='インベスコインカムナビゲーター',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11459': FundCodeEntry(
        fund_code='G11459',
        sec_code=None,
        fund_name='ロボット・テクノロジー関連株ファンド\u3000－ロボテック－',
        fund_name_yomi='ロボットテクノロジーカンレンカブファンドロボテック',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11460': FundCodeEntry(
        fund_code='G11460',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000日経２２５ファンド',
        fund_name_yomi='ダイワノーロードニッケイニイニイゴファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11461': FundCodeEntry(
        fund_code='G11461',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000Ｊ－ＲＥＩＴファンド',
        fund_name_yomi='ダイワノーロードジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11464': FundCodeEntry(
        fund_code='G11464',
        sec_code=None,
        fund_name='フォーカス・シキャブ',
        fund_name_yomi='フォーカスシキャブ',
        security_type='外国投資証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E32015',
        issuer_name='フォーカス・シキャブ',
    ),
    'G11467': FundCodeEntry(
        fund_code='G11467',
        sec_code=None,
        fund_name='グローバル・オポチュニティーズ・アクセス－ハイ・イールド・アンド・ＥＭボンド－グローバル・ボンド（米ドル）－コーポレート・ボンド－グローバル・エクイティ－グローバル・エクイティⅡ－キー・マルチマネジャー・ヘッジ・ファンド－ボンド－エクイティ',
        fund_name_yomi='グローバルオポチュニティーズアクセスハイイールドアンドイーエムボンドグローバルボンドベイドルコーポレートボンドグローバルエクイティグローバルエクイティツーキーマルチマネジャーヘッジファンドボンドエクイティ',
        security_type='外国投資証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E32021',
        issuer_name='グローバル・オポチュニティーズ・アクセス',
    ),
    'G11468': FundCodeEntry(
        fund_code='G11468',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国リート',
        fund_name_yomi='タワラノーロード\u3000センシンコクリート',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11469': FundCodeEntry(
        fund_code='G11469',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国債券',
        fund_name_yomi='タワラノーロード\u3000センシンコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11470': FundCodeEntry(
        fund_code='G11470',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内リート',
        fund_name_yomi='タワラノーロードコクナイリート',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11471': FundCodeEntry(
        fund_code='G11471',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内債券',
        fund_name_yomi='タワラノーロード\u3000コクナイサイケン',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11474': FundCodeEntry(
        fund_code='G11474',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国株式',
        fund_name_yomi='タワラノーロード\u3000センシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11475': FundCodeEntry(
        fund_code='G11475',
        sec_code=None,
        fund_name='ＰＩＭＣＯセレクト・ファンズ・ピーエルシー－ユーロドル・ハイ・クオリティ・ファンド',
        fund_name_yomi='ピムコセレクトファンズピーエルシーユーロドルハイクオリティファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E32040',
        issuer_name='ＰＩＭＣＯセレクト・ファンズ・ピーエルシー',
    ),
    'G11476': FundCodeEntry(
        fund_code='G11476',
        sec_code=None,
        fund_name='ＵＢＳ（Ｉｒｌ）ファンド・ソリューションズ・ピーエルシー－ＵＢＳ\u3000ＭＳＣＩ\u3000ＡＣＷＩ\u3000エス・エフ\u3000ＵＣＩＴＳ\u3000ＥＴＦ',
        fund_name_yomi='ユービーエスアイルランドファンドソリューションズピーエルシーユービーエスエムエスシーアイエーシーダブリューアイエスエフユーシッツイーティーエフ',
        security_type='外国投資証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E32037',
        issuer_name='ＵＢＳ（Ｉｒｌ）ファンド・ソリューションズ・ピーエルシー',
    ),
    'G11477': FundCodeEntry(
        fund_code='G11477',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ターゲット・イヤー・ファンド２０３０／２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５／２０７０（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイターゲットイヤーファンドニセンサンジュウニセンサンジュウゴニセンヨンジュウニセンヨンジュウゴニセンゴジュウニセンゴジュウゴニセンロクジュウニセンロクジュウゴニセンナナジュウカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11478': FundCodeEntry(
        fund_code='G11478',
        sec_code=None,
        fund_name='楽天ＵＳリート・トリプルエンジン・プラス（レアル）毎月分配型',
        fund_name_yomi='ラクテンユーエスリートトリプルエンジンプラスレアルマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G11479': FundCodeEntry(
        fund_code='G11479',
        sec_code='34660',
        fund_name='ラサールロジポート投資法人',
        fund_name_yomi='ラサールロジポートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E32042',
        issuer_name='ラサールロジポート投資法人',
    ),
    'G11481': FundCodeEntry(
        fund_code='G11481',
        sec_code=None,
        fund_name='キャピタル日本株式ファンドＦ',
        fund_name_yomi='キャピタルニホンカブシキファンドエフ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11482': FundCodeEntry(
        fund_code='G11482',
        sec_code=None,
        fund_name='キャピタル世界株式ファンドＦ',
        fund_name_yomi='キャピタルセカイカブシキファンドエフ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11483': FundCodeEntry(
        fund_code='G11483',
        sec_code=None,
        fund_name='キャピタル・エマージング・ストラテジー・ファンドＦ（米ドル売り円買い）',
        fund_name_yomi='キャピタルエマージングストラテジーファンドエフベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11484': FundCodeEntry(
        fund_code='G11484',
        sec_code=None,
        fund_name='キャピタル世界配当成長ファンドＦ',
        fund_name_yomi='キャピタルセカイハイトウセイチョウファンドエフ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11485': FundCodeEntry(
        fund_code='G11485',
        sec_code=None,
        fund_name='キャピタル・グローバル・アロケーション・ファンドＦ（限定為替ヘッジ）',
        fund_name_yomi='キャピタルグローバルアロケーションファンドエフゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11486': FundCodeEntry(
        fund_code='G11486',
        sec_code=None,
        fund_name='キャピタル・グローバル・ボンド・ファンドＦ（限定為替ヘッジ）',
        fund_name_yomi='キャピタルグローバルボンドファンドエフゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11487': FundCodeEntry(
        fund_code='G11487',
        sec_code=None,
        fund_name='キャピタル・グローバル・ハイインカム債券ファンドＦ（米ドル売り円買い）',
        fund_name_yomi='キャピタルグローバルハイインカムサイケンファンドエフベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11490': FundCodeEntry(
        fund_code='G11490',
        sec_code=None,
        fund_name='ニッセイ北欧株式ファンド（為替ヘッジあり）／ニッセイ北欧株式ファンド（為替ヘッジなし）',
        fund_name_yomi='ニッセイホクオウカブシキファンドカワセヘッジアリ\u3000ニッセイホクオウカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11491': FundCodeEntry(
        fund_code='G11491',
        sec_code=None,
        fund_name='ダイワ米国国債７－１０年ラダー型ファンド（部分為替ヘッジあり／為替ヘッジなし）、ダイワ米国国債７－１０年ラダー型ファンド・マネーポートフォリオ\u3000－\u3000ＵＳトライアングル\u3000－',
        fund_name_yomi='ダイワベイコクコクサイナナカラジュウネンラダーガタファンドブブンカワセヘッジアリカワセヘッジナシダイワベイコクコクサイナナカラジュウネンラダーガタファンドマネーポートフォリオユーエストライアングル',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11492': FundCodeEntry(
        fund_code='G11492',
        sec_code=None,
        fund_name='Ｊリート・アジアミックス・オープン（年２回決算型）',
        fund_name_yomi='ジェイリートアジアミックスオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11494': FundCodeEntry(
        fund_code='G11494',
        sec_code=None,
        fund_name='インベスコ\u3000英国ポンド建て債券ファンド＜為替アクティブヘッジ＞（毎月決算型）',
        fund_name_yomi='インベスコエイコクポンドダテサイケンファンドカワセアクティブヘッジマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11496': FundCodeEntry(
        fund_code='G11496',
        sec_code=None,
        fund_name='世界プレミア企業債券ファンド（為替ヘッジあり）',
        fund_name_yomi='セカイプレミアキギョウサイケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11499': FundCodeEntry(
        fund_code='G11499',
        sec_code=None,
        fund_name='日経２２５インデックスｅ',
        fund_name_yomi='ニッケイニーニーゴインデックスイー',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11501': FundCodeEntry(
        fund_code='G11501',
        sec_code=None,
        fund_name='ピクテ\u3000マルチストラテジー\u3000リンクファンド（ＳＭＡ専用）',
        fund_name_yomi='ピクテ\u3000マルチストラテジー\u3000リンクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11503': FundCodeEntry(
        fund_code='G11503',
        sec_code=None,
        fund_name='ＳｕＭｉ\u3000ＴＲＵＳＴ\u3000マルチストラテジー／ＳＭＡＲＳ（ＳＭＡ専用）',
        fund_name_yomi='エスユーエムアイ\u3000ティーアールユーエスティー\u3000マルチストラテジー\u3000エスエムエーアールエス\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11504': FundCodeEntry(
        fund_code='G11504',
        sec_code=None,
        fund_name='アムンディ・欧州ハイ・イールド債券ファンド＜年２回決算型＞',
        fund_name_yomi='アムンディオウシュウハイイールドサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G11506': FundCodeEntry(
        fund_code='G11506',
        sec_code=None,
        fund_name='日興ＪＰＭ環太平洋ディスカバリー・ファンド（年４回決算型）',
        fund_name_yomi='ニッコウジェイピーエムカンタイヘイヨウディスカバリーファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G11508': FundCodeEntry(
        fund_code='G11508',
        sec_code=None,
        fund_name='ダイワ／ミレーアセット亜細亜株式ファンド',
        fund_name_yomi='ダイワミレーアセットアジアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11511': FundCodeEntry(
        fund_code='G11511',
        sec_code=None,
        fund_name='ジャパン・ロボティクス株式ファンド（年２回決算型）',
        fund_name_yomi='ジャパン\u3000ロボティクスカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11512': FundCodeEntry(
        fund_code='G11512',
        sec_code=None,
        fund_name='ジャパン・ロボティクス株式ファンド（１年決算型）',
        fund_name_yomi='ジャパン\u3000ロボティクスカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11513': FundCodeEntry(
        fund_code='G11513',
        sec_code=None,
        fund_name='未来変革日本株ファンド',
        fund_name_yomi='ミライヘンカクニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11516': FundCodeEntry(
        fund_code='G11516',
        sec_code=None,
        fund_name='りそなラップ型ファンド（安定型）\u3000りそなラップ型ファンド（安定成長型）\u3000りそなラップ型ファンド（成長型）',
        fund_name_yomi='リソナラップガタファンドアンテイガタ\u3000リソナラップガタファンドアンテイセイチョウガタ\u3000リソナラップガタファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G11519': FundCodeEntry(
        fund_code='G11519',
        sec_code=None,
        fund_name='ＴＨＥ日本株オープン（円投資型）／（米ドル投資型）',
        fund_name_yomi='ザニホンカブオープンエントウシガタベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11522': FundCodeEntry(
        fund_code='G11522',
        sec_code=None,
        fund_name='しんきん世界アロケーションファンド（積極型）',
        fund_name_yomi='シンキンセカイアロケーションファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G11526': FundCodeEntry(
        fund_code='G11526',
        sec_code=None,
        fund_name='先進国好配当株式ファンド（３ヵ月決算型）（年２回決算型）',
        fund_name_yomi='センシンコクコウハイトウカブシキファンドサンカゲツケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11530': FundCodeEntry(
        fund_code='G11530',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000米国リートインデックス',
        fund_name_yomi='イーマクシスベイコクリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11531': FundCodeEntry(
        fund_code='G11531',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000欧州リートインデックス',
        fund_name_yomi='イーマクシスオウシュウリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11532': FundCodeEntry(
        fund_code='G11532',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000豪州リートインデックス',
        fund_name_yomi='イーマクシスゴウシュウリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11541': FundCodeEntry(
        fund_code='G11541',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔロボ',
        fund_name_yomi='アイトラストロボ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11542': FundCodeEntry(
        fund_code='G11542',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔバイオ',
        fund_name_yomi='アイトラストバイオ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11543': FundCodeEntry(
        fund_code='G11543',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔ世界株式',
        fund_name_yomi='アイトラストセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11544': FundCodeEntry(
        fund_code='G11544',
        sec_code=None,
        fund_name='インベスコ\u3000リアル資産成長ファンド（毎月決算型）',
        fund_name_yomi='インベスコリアルシサンセイチョウファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11548': FundCodeEntry(
        fund_code='G11548',
        sec_code=None,
        fund_name='ＵＳテクノロジー・イノベーターズ・ファンド',
        fund_name_yomi='ユーエステクノロジーイノベーターズファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11550': FundCodeEntry(
        fund_code='G11550',
        sec_code=None,
        fund_name='ロボット・テクノロジー関連株ファンド（年１回決算型）\u3000－ロボテック（年１回）－',
        fund_name_yomi='ロボットテクノロジーカンレンカブファンドネンイッカイケッサンガタロボテックネンイッカイ',
        security_type='内国投資信託受益証券',
        period_1='9月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11552': FundCodeEntry(
        fund_code='G11552',
        sec_code=None,
        fund_name='ピクテ・セキュリティ・ファンド（為替ヘッジなし）',
        fund_name_yomi='ピクテセキュリティファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11554': FundCodeEntry(
        fund_code='G11554',
        sec_code=None,
        fund_name='ピムコ世界金融ハイブリッド証券戦略ファンド（毎月決算型・通貨プレミアム）',
        fund_name_yomi='ピムコセカイキンユウハイブリッドショウケンセンリャクファンド\u3000マイツキケッサンガタ\u3000ツウカプレミアム',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G11559': FundCodeEntry(
        fund_code='G11559',
        sec_code=None,
        fund_name='ＪＰ４資産バランスファンド\u3000安定コース\u3000安定成長コース\u3000成長コース',
        fund_name_yomi='ジェイピーヨンシサンバランスファンド\u3000アンテイコース\u3000アンテイセイチョウコース\u3000セイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E32151',
        issuer_name='ＪＰ投信株式会社',
    ),
    'G11561': FundCodeEntry(
        fund_code='G11561',
        sec_code=None,
        fund_name='コクサイ－ＭＵＧＣトラスト－ウィントン・パフォーマンス連動ボンドプラスファンド１６－０３（豪ドル建）',
        fund_name_yomi='コクサイエムユージーシートラストウィントンパフォーマンスレンドウボンドプラスファンドイチロクゼロサンゴウドルダテ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G11565': FundCodeEntry(
        fund_code='G11565',
        sec_code=None,
        fund_name='堅実バランスファンド－ハジメの一歩－',
        fund_name_yomi='ケンジツバランスファンドハジメノイッポ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11569': FundCodeEntry(
        fund_code='G11569',
        sec_code=None,
        fund_name='野村ターゲットデートファンド２０１６\u3000２０２６－２０２８年目標型、野村ターゲットデートファンド２０１６\u3000２０２９－２０３１年目標型、野村ターゲットデートファンド２０１６\u3000２０３２－２０３４年目標型、野村ターゲットデートファンド２０１６\u3000２０３５－２０３７年目標型',
        fund_name_yomi='ノムラターゲットデートファンドニセンジュウロクニセンニジュウロクニセンニジュウハチネンモクヒョウガタ\u3000ノムラターゲットデートファンドニセンジュウロクニセンニジュウクニセンサンジュウイチネンモクヒョウガタ\u3000ノムラターゲットデートファンドニセンジュウロクニセンサンジュウニニセンサンジュウヨネンモクヒョウガタ\u3000ノムラターゲットデートファンドドニセンジュウロクニセンサンジュウゴニセンサンジュウナナネンモクヒョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月26日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11570': FundCodeEntry(
        fund_code='G11570',
        sec_code=None,
        fund_name='北海道未来の夢創生ファンド',
        fund_name_yomi='ホッカイドウミライノユメソウセイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11571': FundCodeEntry(
        fund_code='G11571',
        sec_code=None,
        fund_name='ダイワ日本国債１５‐２０年ラダー型ファンド\u3000－ＳＬトレード－、ダイワ日本国債１５‐２０年ラダー型ファンド・マネーポートフォリオ\u3000－ＳＬトレード－',
        fund_name_yomi='ダイワニホンコクサイジュウゴカラニジュウネンラダーガタファンドエスエルトレードダイワニホンコクサイジュウゴカラニジュウネンラダーガタファンドマネーポートフォリオエスエルトレード',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11578': FundCodeEntry(
        fund_code='G11578',
        sec_code=None,
        fund_name='米国連続増配成長株オープン（３ヵ月決算型）',
        fund_name_yomi='ベイコクレンゾクゾウハイセイチョウカブオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G11581': FundCodeEntry(
        fund_code='G11581',
        sec_code=None,
        fund_name='ニッセイＪＰＸ日経４００アクティブファンド（資産成長型）',
        fund_name_yomi='ニッセイジェイピーエックスニッケイヨンヒャクアクティブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G11582': FundCodeEntry(
        fund_code='G11582',
        sec_code=None,
        fund_name='テキサス州株式ファンド',
        fund_name_yomi='テキサスシュウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G11583': FundCodeEntry(
        fund_code='G11583',
        sec_code=None,
        fund_name='ＧＳ米国成長株集中投資ファンド\u3000年２回決算コース',
        fund_name_yomi='ジーエスベイコクセイチョウカブシュウチュウトウシファンド\u3000ネンニカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G11585': FundCodeEntry(
        fund_code='G11585',
        sec_code=None,
        fund_name='オーストラリアＲＥＩＴ・リサーチ・オープン（年２回決算型）',
        fund_name_yomi='オーストラリア\u3000リート\u3000リサーチ\u3000オープン\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2='7月14日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11590': FundCodeEntry(
        fund_code='G11590',
        sec_code=None,
        fund_name='ダイワ住宅金融支援機構債ファンド\u3000－Ｍｒ．フラット－',
        fund_name_yomi='ダイワジュウタクキンユウシエンキコウサイファンドミスターフラット',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11591': FundCodeEntry(
        fund_code='G11591',
        sec_code=None,
        fund_name='ダイワ米国リート・プラス（毎月分配型）：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワベイコクリートプラスマイツキブンパイガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11592': FundCodeEntry(
        fund_code='G11592',
        sec_code=None,
        fund_name='ダイワ米国リート・プラス（年２回決算型）：為替ヘッジあり、為替ヘッジなし',
        fund_name_yomi='ダイワベイコクリートプラスネンニカイケッサンガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11597': FundCodeEntry(
        fund_code='G11597',
        sec_code=None,
        fund_name='インベスコ\u3000新興国社債ファンド',
        fund_name_yomi='インベスコ\u3000シンコウコクシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11599': FundCodeEntry(
        fund_code='G11599',
        sec_code=None,
        fund_name='たわらノーロードｐｌｕｓ\u3000新興国株式低ボラティリティ高配当戦略',
        fund_name_yomi='タワラノーロードプラス\u3000シンコウコクカブシキテイボラティリティコウハイトウセンリャク',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11600': FundCodeEntry(
        fund_code='G11600',
        sec_code=None,
        fund_name='たわらノーロードｐｌｕｓ\u3000国内株式高配当最小分散戦略',
        fund_name_yomi='タワラノーロードプラスコクナイカブシキコウハイトウサイショウブンサンセンリャク',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11601': FundCodeEntry(
        fund_code='G11601',
        sec_code=None,
        fund_name='たわらノーロード\u3000新興国株式',
        fund_name_yomi='タワラノーロード\u3000シンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11605': FundCodeEntry(
        fund_code='G11605',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000ＴＯＰＩＸファンド',
        fund_name_yomi='ダイワノーロードトピックスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11606': FundCodeEntry(
        fund_code='G11606',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000ＪＰＸ日経４００ファンド',
        fund_name_yomi='ダイワノーロードジェイピーエックスニッケイヨンヒャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11607': FundCodeEntry(
        fund_code='G11607',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000日本債券ファンド',
        fund_name_yomi='ダイワノーロードニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11608': FundCodeEntry(
        fund_code='G11608',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000外国株式ファンド',
        fund_name_yomi='ダイワノーロードガイコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11609': FundCodeEntry(
        fund_code='G11609',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000外国債券ファンド',
        fund_name_yomi='ダイワノーロードガイコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11610': FundCodeEntry(
        fund_code='G11610',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000グローバルＲＥＩＴファンド',
        fund_name_yomi='ダイワノーロードグローバルリートファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11611': FundCodeEntry(
        fund_code='G11611',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000新興国株式ファンド',
        fund_name_yomi='ダイワノーロードシンコウコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11612': FundCodeEntry(
        fund_code='G11612',
        sec_code=None,
        fund_name='ダイワ・ノーロード\u3000新興国債券ファンド',
        fund_name_yomi='ダイワノーロードシンコウコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11614': FundCodeEntry(
        fund_code='G11614',
        sec_code=None,
        fund_name='明治安田ＤＣ先進国コアファンド',
        fund_name_yomi='メイジヤスダディーシーセンシンコクコアファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G11615': FundCodeEntry(
        fund_code='G11615',
        sec_code=None,
        fund_name='ＭＡＸＩＳ\u3000ＪＡＰＡＮ\u3000クオリティ１５０上場投信',
        fund_name_yomi='マクシスジャパンクオリティヒャクゴジュウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11618': FundCodeEntry(
        fund_code='G11618',
        sec_code='34680',
        fund_name='スターアジア不動産投資法人',
        fund_name_yomi='スターアジアフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E32253',
        issuer_name='スターアジア不動産投資法人',
    ),
    'G11619': FundCodeEntry(
        fund_code='G11619',
        sec_code=None,
        fund_name='ロボ・ジャパン（円投資型）、ロボ・ジャパン（米ドル投資型）',
        fund_name_yomi='ロボジャパンエントウシガタ\u3000ロボジャパンベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11626': FundCodeEntry(
        fund_code='G11626',
        sec_code=None,
        fund_name='ＳＢＩ中小型割安成長株ファンド\u3000ジェイリバイブ＜ＤＣ年金＞',
        fund_name_yomi='エスビーアイチュウコガタワリヤスセイチョウカブファンドジェイリバイブ\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G11629': FundCodeEntry(
        fund_code='G11629',
        sec_code=None,
        fund_name='グローバル株式トップフォーカス',
        fund_name_yomi='グローバルカブシキトップフォーカス',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11634': FundCodeEntry(
        fund_code='G11634',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000最適化バランス（マイゴールキーパー）／（マイディフェンダー）／（マイミッドフィルダー）／（マイフォワード）／（マイストライカー）',
        fund_name_yomi='イーマクシスサイテキカバランスマイゴールキーパーマイディフェンダーマイミッドフィルダーマイフォワードマイストライカー',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11635': FundCodeEntry(
        fund_code='G11635',
        sec_code=None,
        fund_name='インベスコ\u3000世界インカム資産ファンド（毎月決算型）',
        fund_name_yomi='インベスコセカイインカムシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11639': FundCodeEntry(
        fund_code='G11639',
        sec_code=None,
        fund_name='ＤＣダイワ・マネー・ポートフォリオ',
        fund_name_yomi='ディーシーダイワマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11641': FundCodeEntry(
        fund_code='G11641',
        sec_code=None,
        fund_name='ダイワ・アジアリート・ファンド（年１回決算型）',
        fund_name_yomi='ダイワアジアリートファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11645': FundCodeEntry(
        fund_code='G11645',
        sec_code=None,
        fund_name='先進国資産配分コントロールファンド＜安定型＞／先進国資産配分コントロールファンド＜成長型＞',
        fund_name_yomi='センシンコクシサンハイブンコントロールファンドアンテイガタ\u3000センシンコクシサンハイブンコントロールファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G11647': FundCodeEntry(
        fund_code='G11647',
        sec_code=None,
        fund_name='米国地方債ファンド\u3000為替ヘッジあり（毎月決算型）\u3000米国地方債ファンド\u3000為替ヘッジなし（毎月決算型）',
        fund_name_yomi='ベイコクチホウサイファンド\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000ベイコクチホウサイファンド\u3000カワセヘッジナシ\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11648': FundCodeEntry(
        fund_code='G11648',
        sec_code=None,
        fund_name='米国地方債ファンド\u3000為替ヘッジあり（年２回決算型）\u3000米国地方債ファンド\u3000為替ヘッジなし（年２回決算型）',
        fund_name_yomi='ベイコクチホウサイファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ\u3000ベイコクチホウサイファンド\u3000カワセヘッジナシ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G11649': FundCodeEntry(
        fund_code='G11649',
        sec_code=None,
        fund_name='新ホリコ・フォーカス・ファンド',
        fund_name_yomi='シンホリコフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G11651': FundCodeEntry(
        fund_code='G11651',
        sec_code=None,
        fund_name='世界分散投資戦略ファンド',
        fund_name_yomi='セカイブンサントウシセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11652': FundCodeEntry(
        fund_code='G11652',
        sec_code=None,
        fund_name='フィリピン株式ファンド',
        fund_name_yomi='フィリピンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G11653': FundCodeEntry(
        fund_code='G11653',
        sec_code=None,
        fund_name='タカラレーベン・インフラ投資法人',
        fund_name_yomi='タカラレーベンインフラトウシホウジン',
        security_type='内国投資証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E32280',
        issuer_name='タカラレーベン・インフラ投資法人',
    ),
    'G11659': FundCodeEntry(
        fund_code='G11659',
        sec_code=None,
        fund_name='ｉＳＴＯＸＸ\u3000ＭＵＴＢ\u3000ＪＡＰＡＮ\u3000クオリティ１５０インデックスファンド（ラップ向け）',
        fund_name_yomi='アイストックスエムユーティービージャパンクオリティヒャクゴジュウインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11660': FundCodeEntry(
        fund_code='G11660',
        sec_code=None,
        fund_name='マッコーリー\u3000グローバル・インフラ株式ファンド（ラップ向け）',
        fund_name_yomi='マッコーリーグローバルインフラカブシキファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11661': FundCodeEntry(
        fund_code='G11661',
        sec_code=None,
        fund_name='キャピタル世界株式ファンド（ＤＣ年金つみたて専用）',
        fund_name_yomi='キャピタルセカイカブシキファンドディーシーネンキンツミタテセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G11662': FundCodeEntry(
        fund_code='G11662',
        sec_code=None,
        fund_name='ｉＳＴＯＸＸ\u3000ＭＵＴＢ\u3000ＪＡＰＡＮ\u3000クオリティ１５０アクティブオープン',
        fund_name_yomi='アイストックスエムユーティービージャパンクオリティヒャクゴジュウアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11665': FundCodeEntry(
        fund_code='G11665',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ａコース、野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ｂコース、野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ｃコース、野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ｄコース',
        fund_name_yomi='ノムラピムコセカイインカムセンリャクファンドエーコース\u3000ノムラピムコセカイインカムセンリャクファンドビーコース\u3000ノムラピムコセカイインカムセンリャクファンドシーコース\u3000ノムラピムコセカイインカムセンリャクファンドディーコース',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11667': FundCodeEntry(
        fund_code='G11667',
        sec_code=None,
        fund_name='三井住友・ＤＣ世界バランスファンド（動的配分型）',
        fund_name_yomi='ミツイスミトモディーシーセカイバランスファンドドウテキハイブンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11668': FundCodeEntry(
        fund_code='G11668',
        sec_code=None,
        fund_name='りそな・ストラテジック・インカムファンド２０１６－０５（為替ヘッジあり）、りそな・ストラテジック・インカムファンド２０１６－０５（為替ヘッジなし）',
        fund_name_yomi='リソナストラテジックインカムファンドニセンジュウロクノゼロゴカワセヘッジアリ\u3000リソナストラテジックインカムファンドニセンジュウロクノゼロゴカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G11675': FundCodeEntry(
        fund_code='G11675',
        sec_code=None,
        fund_name='インベスコ\u3000アジア成長資産ファンド（毎月決算型）',
        fund_name_yomi='インベスコアジアセイチョウシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11678': FundCodeEntry(
        fund_code='G11678',
        sec_code=None,
        fund_name='ピクテＹＥＮアセット・アロケーション・ファンド（毎月分配型）',
        fund_name_yomi='ピクテエンアセットアロケーションファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11679': FundCodeEntry(
        fund_code='G11679',
        sec_code=None,
        fund_name='ピクテＹＥＮアセット・アロケーション・ファンド（１年決算型）',
        fund_name_yomi='ピクテエンアセットアロケーションファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11682': FundCodeEntry(
        fund_code='G11682',
        sec_code=None,
        fund_name='カレラ\u3000日本小型株式ファンド',
        fund_name_yomi='カレラ\u3000ニホンコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G11683': FundCodeEntry(
        fund_code='G11683',
        sec_code=None,
        fund_name='ステート・ストリート新興国株式インデックス・オープン',
        fund_name_yomi='ステートストリートシンコウコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11684': FundCodeEntry(
        fund_code='G11684',
        sec_code=None,
        fund_name='ステート・ストリート新興国債券インデックス・オープン',
        fund_name_yomi='ステートストリートシンコウコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11685': FundCodeEntry(
        fund_code='G11685',
        sec_code=None,
        fund_name='ステート・ストリート先進国株式インデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='ステートストリートセンシンコクカブシキインデックスオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11686': FundCodeEntry(
        fund_code='G11686',
        sec_code=None,
        fund_name='ステート・ストリート先進国株式インデックス・オープン',
        fund_name_yomi='ステートストリートセンシンコクカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11687': FundCodeEntry(
        fund_code='G11687',
        sec_code=None,
        fund_name='ステート・ストリート先進国債券インデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='ステートストリートセンシンコクサイケンインデックスオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11688': FundCodeEntry(
        fund_code='G11688',
        sec_code=None,
        fund_name='ステート・ストリート先進国債券インデックス・オープン',
        fund_name_yomi='ステートストリートセンシンコクサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11689': FundCodeEntry(
        fund_code='G11689',
        sec_code=None,
        fund_name='ステート・ストリート日本株式インデックス・オープン',
        fund_name_yomi='ステートストリートニホンカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11690': FundCodeEntry(
        fund_code='G11690',
        sec_code=None,
        fund_name='ステート・ストリート日本債券インデックス・オープン',
        fund_name_yomi='ステートストリートニホンサイケンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G11692': FundCodeEntry(
        fund_code='G11692',
        sec_code=None,
        fund_name='ＤＣりそな\u3000グローバルバランス',
        fund_name_yomi='ディシーリソナ\u3000グローバルバランス',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G11693': FundCodeEntry(
        fund_code='G11693',
        sec_code='14820',
        fund_name='ｉシェアーズ・コア\u3000米国債７－１０年\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000コア\u3000ベイコクサイナナ\u3000ジュウネン\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11694': FundCodeEntry(
        fund_code='G11694',
        sec_code=None,
        fund_name='イーストスプリングＵＳ投資適格債ファンド・為替ヘッジ付（年２回決算型）',
        fund_name_yomi='イーストスプリングユーエストウシテキカクサイファンドカワセヘッジツキネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G11695': FundCodeEntry(
        fund_code='G11695',
        sec_code=None,
        fund_name='成長応援日本株ファンド',
        fund_name_yomi='セイチョウオウエンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G11697': FundCodeEntry(
        fund_code='G11697',
        sec_code=None,
        fund_name='ＤＣダイワ・ターゲットイヤー２０５０',
        fund_name_yomi='ディーシーダイワターゲットイヤーニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11698': FundCodeEntry(
        fund_code='G11698',
        sec_code='14790',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＭＳＣＩ日本株人材設備投資指数',
        fund_name_yomi='アイフリーイーティーエフエムエスシーアイニホンカブジンザイセツビトウシシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11699': FundCodeEntry(
        fund_code='G11699',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）マネー・マーケット・ファンド－米ドル',
        fund_name_yomi='ユービーエスルクスマネーマーケットファンドベイドル',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G11700': FundCodeEntry(
        fund_code='G11700',
        sec_code='14810',
        fund_name='上場インデックスファンド日本経済貢献株',
        fund_name_yomi='ジョウジョウインデックスファンドニホンケイザイコウケンカブ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11701': FundCodeEntry(
        fund_code='G11701',
        sec_code='14800',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000野村企業価値分配指数連動型上場投信',
        fund_name_yomi='ネクストファンズノムラキギョウカチブンパイシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11703': FundCodeEntry(
        fund_code='G11703',
        sec_code=None,
        fund_name='ラッセル・インベストメント外国株式ファンド',
        fund_name_yomi='ラッセルインベストメントガイコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G11704': FundCodeEntry(
        fund_code='G11704',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ストラテジー・ファンド',
        fund_name_yomi='ユービーエスルクスストラテジーファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G11706': FundCodeEntry(
        fund_code='G11706',
        sec_code=None,
        fund_name='ＵＳ株主還元ファンド（年４回決算型）',
        fund_name_yomi='ユーエスカブヌシカンゲンファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11707': FundCodeEntry(
        fund_code='G11707',
        sec_code=None,
        fund_name='ＵＳ株主還元ファンド（年１回決算型）',
        fund_name_yomi='ユーエスカブヌシカンゲンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11708': FundCodeEntry(
        fund_code='G11708',
        sec_code=None,
        fund_name='マニュライフ・米国銀行株式ファンド',
        fund_name_yomi='マニュライフベイコクギンコウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11710': FundCodeEntry(
        fund_code='G11710',
        sec_code=None,
        fund_name='マニュライフ・新グローバル配当株ファンド（年２回決算型）',
        fund_name_yomi='マニュライフシングローバルハイトウカブファンドネンニカイ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11715': FundCodeEntry(
        fund_code='G11715',
        sec_code=None,
        fund_name='マニュライフ・変動高金利戦略ファンド\u3000Ａコース（為替ヘッジあり・毎月）、マニュライフ・変動高金利戦略ファンド\u3000Ｂコース（為替ヘッジなし・毎月）、マニュライフ・変動高金利戦略ファンド\u3000Ｃコース（為替ヘッジあり・年２回）、マニュライフ・変動高金利戦略ファンド\u3000Ｄコース（為替ヘッジなし・年２回）',
        fund_name_yomi='マニュライフヘンドウコウキンリセンリャクファンドエイコース\u3000マニュライフヘンドウコウキンリセンリャクファンドビーコース\u3000マニュライフヘンドウコウキンリセンリャクファンドシーコース\u3000マニュライフヘンドウコウキンリセンリャクファンドディーコース',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11716': FundCodeEntry(
        fund_code='G11716',
        sec_code=None,
        fund_name='マニュライフ・アジア経済圏・小型成長株ファンド',
        fund_name_yomi='マニュライフアジアケイザイケンコガタセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11717': FundCodeEntry(
        fund_code='G11717',
        sec_code=None,
        fund_name='マニュライフ・カナダ債券ファンド',
        fund_name_yomi='マニュライフカナダサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11718': FundCodeEntry(
        fund_code='G11718',
        sec_code=None,
        fund_name='マニュライフ・新グローバル配当株ファンド（毎月分配型）',
        fund_name_yomi='マニュライフ\u3000シングローバルハイトウカブファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2='2月10日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11719': FundCodeEntry(
        fund_code='G11719',
        sec_code=None,
        fund_name='マニュライフ・カナダ株式ファンド',
        fund_name_yomi='マニュライフ\u3000カナダカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G11720': FundCodeEntry(
        fund_code='G11720',
        sec_code=None,
        fund_name='マクロ・トータル・リターン・ファンド',
        fund_name_yomi='マクロトータルリターンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2='12月3日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11721': FundCodeEntry(
        fund_code='G11721',
        sec_code=None,
        fund_name='ＧＳフォーカス・イールド・ボンド\u3000毎月決算コース／年２回決算コース',
        fund_name_yomi='ジーエスフォーカスイールドボンド\u3000マイツキケッサンコース\u3000ネンニカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G11722': FundCodeEntry(
        fund_code='G11722',
        sec_code=None,
        fund_name='先進国資本エマージング株式ファンド（１年決算型）',
        fund_name_yomi='センシンコクシホンエマージングカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11723': FundCodeEntry(
        fund_code='G11723',
        sec_code=None,
        fund_name='先進国資本エマージング株式ファンド（年２回決算型）',
        fund_name_yomi='センシンコクシホンエマージングカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G11724': FundCodeEntry(
        fund_code='G11724',
        sec_code=None,
        fund_name='ダイワ高格付日本企業外債ファンド（為替ヘッジあり／為替ヘッジなし）２０１６‐０６',
        fund_name_yomi='ダイワコウカクヅケニホンキギョウガイサイファンドカワセヘッジアリカワセヘッジナシニセンジュウロクゼロロク',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11726': FundCodeEntry(
        fund_code='G11726',
        sec_code=None,
        fund_name='米国国債ファンド\u3000為替ヘッジあり（毎月決算型）',
        fund_name_yomi='ベイコクコクサイファンドカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11727': FundCodeEntry(
        fund_code='G11727',
        sec_code=None,
        fund_name='リビング・アース戦略ファンド（年２回決算コース）',
        fund_name_yomi='リビングアースセンリャクファンドネンニカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G11728': FundCodeEntry(
        fund_code='G11728',
        sec_code=None,
        fund_name='リビング・アース戦略ファンド（年４回決算コース）',
        fund_name_yomi='リビングアースセンリャクファンドネンヨンカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G11729': FundCodeEntry(
        fund_code='G11729',
        sec_code=None,
        fund_name='ＳＢＩ－ＰＩＭＣＯ\u3000ジャパン・ベターインカム・ファンド',
        fund_name_yomi='エスビーアイピムコジャパンベターインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G11731': FundCodeEntry(
        fund_code='G11731',
        sec_code='14830',
        fund_name='ｉシェアーズ\u3000ＪＰＸ／Ｓ＆Ｐ\u3000設備・人材投資\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズジェイピーエックスエスアンドピーセツビジンザイトウシイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G11732': FundCodeEntry(
        fund_code='G11732',
        sec_code=None,
        fund_name='インベスコ\u3000ジャパン成長株・夢ファンド',
        fund_name_yomi='インベスコジャパンセイチョウカブユメファンド',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11733': FundCodeEntry(
        fund_code='G11733',
        sec_code=None,
        fund_name='インベスコ\u3000米国優良株式ファンド（毎月決算型）',
        fund_name_yomi='インベスコベイコクユウリョウカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11734': FundCodeEntry(
        fund_code='G11734',
        sec_code=None,
        fund_name='日本株ロングショート戦略ファンド',
        fund_name_yomi='ニホンカブロングショートセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G11735': FundCodeEntry(
        fund_code='G11735',
        sec_code=None,
        fund_name='いちよし中小型成長株ファンド',
        fund_name_yomi='イチヨシチュウショウガタセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G11738': FundCodeEntry(
        fund_code='G11738',
        sec_code=None,
        fund_name='野村ＳＴＦ（ショートターム・ファンド）',
        fund_name_yomi='ノムラエスティーエフショートタームファンド',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11739': FundCodeEntry(
        fund_code='G11739',
        sec_code=None,
        fund_name='フィデリティ・新興国厳選株ファンドＡコース（米ドル売り円買い）\u3000フィデリティ・新興国厳選株ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティシンコウコクゲンセンカブファンドエーコースベイドルウリエンガイ\u3000フィデリティシンコウコクゲンセンカブファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G11740': FundCodeEntry(
        fund_code='G11740',
        sec_code='14840',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000ＪＰＸ／Ｓ＆Ｐ\u3000設備・人材投資指数',
        fund_name_yomi='ワンイーティーエフジェイピーエックスエスアンドピーセツビジンザイトウシシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11741': FundCodeEntry(
        fund_code='G11741',
        sec_code=None,
        fund_name='ＹＭアセット・バランスファンド（安定タイプ）／（成長タイプ）',
        fund_name_yomi='ワイエムアセットバランスファンドアンテイタイプセイチョウタイプ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2=None,
        edinet_code='E32437',
        issuer_name='ワイエムアセットマネジメント株式会社',
    ),
    'G11742': FundCodeEntry(
        fund_code='G11742',
        sec_code=None,
        fund_name='ＭＳＣＩジャパン高配当利回りインデックス・ファンド（毎月決算型）',
        fund_name_yomi='エムエスシーアイコウハイトウリマワリインデックスファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G11744': FundCodeEntry(
        fund_code='G11744',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ａコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドエーコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11745': FundCodeEntry(
        fund_code='G11745',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｂコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11746': FundCodeEntry(
        fund_code='G11746',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｃコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドシーコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11747': FundCodeEntry(
        fund_code='G11747',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｄコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドディーコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11748': FundCodeEntry(
        fund_code='G11748',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｅコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドイーコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11749': FundCodeEntry(
        fund_code='G11749',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｆコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドエフコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11750': FundCodeEntry(
        fund_code='G11750',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｇコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドジーコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11751': FundCodeEntry(
        fund_code='G11751',
        sec_code=None,
        fund_name='ＭＳＶ内外ＥＴＦ資産配分ファンド（Ｈコース）',
        fund_name_yomi='エムエスブイナイガイエーティーエフシサンハイブンファンドエイチコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G11752': FundCodeEntry(
        fund_code='G11752',
        sec_code=None,
        fund_name='野村継続増配日本株',
        fund_name_yomi='ノムラケイゾクゾウハイニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11753': FundCodeEntry(
        fund_code='G11753',
        sec_code=None,
        fund_name='日本インバウンドオープン',
        fund_name_yomi='ニホンインバウンドオープン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G11754': FundCodeEntry(
        fund_code='G11754',
        sec_code=None,
        fund_name='日本金融ハイブリッド証券オープン（年１回決算型）\u3000円ヘッジありコース\u3000日本金融ハイブリッド証券オープン（年１回決算型）\u3000円ヘッジなしコース',
        fund_name_yomi='ニホンキンユウハイブリッドショウケンオープンネンイッカイケッサンガタ\u3000エンヘッジアリコース\u3000ニホンキンユウハイブリッドショウケンオープンネンイッカイケッサンガタ\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G11755': FundCodeEntry(
        fund_code='G11755',
        sec_code='34700',
        fund_name='マリモ地方創生リート投資法人',
        fund_name_yomi='マリモチホウソウセイリートトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E32350',
        issuer_name='マリモ地方創生リート投資法人',
    ),
    'G11756': FundCodeEntry(
        fund_code='G11756',
        sec_code=None,
        fund_name='先進国普通社債ファンド（為替ヘッジあり）２０１６－０８',
        fund_name_yomi='センシンコクフツウシャサイファンドカワセヘッジアリニセンジュウロクゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2='12月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G11757': FundCodeEntry(
        fund_code='G11757',
        sec_code=None,
        fund_name='世界コアインフラ株式ファンド',
        fund_name_yomi='セカイコアインフラカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11758': FundCodeEntry(
        fund_code='G11758',
        sec_code=None,
        fund_name='シュローダー・アジアパシフィックＥＳＧフォーカス・ファンド（資産成長型）',
        fund_name_yomi='シュローダー\u3000アジアパシフィックイーエスジーフォーカス\u3000ファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G11759': FundCodeEntry(
        fund_code='G11759',
        sec_code=None,
        fund_name='Ｏｎｅニッポン債券オープン',
        fund_name_yomi='ワンニッポンサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11760': FundCodeEntry(
        fund_code='G11760',
        sec_code='34710',
        fund_name='三井不動産ロジスティクスパーク投資法人',
        fund_name_yomi='ミツイフドウサンロジスティクスパークトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E32450',
        issuer_name='三井不動産ロジスティクスパーク投資法人',
    ),
    'G11761': FundCodeEntry(
        fund_code='G11761',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔ日本株式',
        fund_name_yomi='アイトラストニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G11762': FundCodeEntry(
        fund_code='G11762',
        sec_code=None,
        fund_name='パインブリッジ日本企業外貨建て社債ファンド２０１６－０７',
        fund_name_yomi='パインブリッジニホンキギョウガイカダテシャサイファンドニセンジュウロクノナナ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G11764': FundCodeEntry(
        fund_code='G11764',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国債券＜ラップ向け＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクサイケンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11765': FundCodeEntry(
        fund_code='G11765',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内リート＜ラップ向け＞',
        fund_name_yomi='タワラノーロード\u3000コクナイリートラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11766': FundCodeEntry(
        fund_code='G11766',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国リート＜ラップ向け＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクリートラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11767': FundCodeEntry(
        fund_code='G11767',
        sec_code=None,
        fund_name='あおぞら・先進国中短期公社債ファンド（為替ヘッジあり）',
        fund_name_yomi='アオゾラセンシンコクチュウタンキコウシャサイファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G11768': FundCodeEntry(
        fund_code='G11768',
        sec_code=None,
        fund_name='あおぞら・先進国バランス・ファンド（為替ヘッジあり）',
        fund_name_yomi='アオゾラセンシンコクバランスファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G11769': FundCodeEntry(
        fund_code='G11769',
        sec_code=None,
        fund_name='あおぞら・グローバル・バランス・ファンド（部分為替ヘッジあり）',
        fund_name_yomi='アオゾラグローバルバランスファンドブブンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G11771': FundCodeEntry(
        fund_code='G11771',
        sec_code=None,
        fund_name='たわらノーロード\u3000新興国株式＜ラップ向け＞',
        fund_name_yomi='タワラノーロード\u3000シンコウコクカブシキラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11772': FundCodeEntry(
        fund_code='G11772',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国株式＜ラップ向け＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクカブシキラップムケ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11776': FundCodeEntry(
        fund_code='G11776',
        sec_code='14850',
        fund_name='ＭＡＸＩＳ\u3000ＪＡＰＡＮ\u3000設備・人材積極投資企業２００上場投信',
        fund_name_yomi='マクシスジャパンセツビジンザイセッキョクトウシキギョウニヒャクジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11780': FundCodeEntry(
        fund_code='G11780',
        sec_code=None,
        fund_name='米国地方債ファンド２０１６－０７（為替ヘッジあり）',
        fund_name_yomi='ベイコクチホウサイファンドニゼロイチロクゼロナナカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2='8月19日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11783': FundCodeEntry(
        fund_code='G11783',
        sec_code=None,
        fund_name='インベスコ\u3000米国ハイ・イールド債券ファンド（毎月決算型）',
        fund_name_yomi='インベスコベイコクハイイールドサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G11785': FundCodeEntry(
        fund_code='G11785',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000豪州債券インデックス',
        fund_name_yomi='イーマクシスゴウシュウサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11786': FundCodeEntry(
        fund_code='G11786',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000先進国債券インデックス（除く日本・為替ヘッジあり）',
        fund_name_yomi='イーマクシスセンシンコクサイケンインデックスノゾクニホンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11787': FundCodeEntry(
        fund_code='G11787',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000新興国債券インデックス（為替ヘッジあり）',
        fund_name_yomi='イーマクシスシンコウコクサイケンインデックスカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G11789': FundCodeEntry(
        fund_code='G11789',
        sec_code=None,
        fund_name='ダイワＦＥグローバル・バリュー（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ダイワエフイーグローバルバリューカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11790': FundCodeEntry(
        fund_code='G11790',
        sec_code=None,
        fund_name='ダイワ米国投資法人債ファンド（為替ヘッジあり）２０１６‐０７',
        fund_name_yomi='ダイワベイコクトウシホウジンサイファンドカワセヘッジアリニセンジュウロクゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G11796': FundCodeEntry(
        fund_code='G11796',
        sec_code=None,
        fund_name='公社債投信（１月号）',
        fund_name_yomi='コウシャサイトウシンイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11797': FundCodeEntry(
        fund_code='G11797',
        sec_code=None,
        fund_name='公社債投信（２月号）',
        fund_name_yomi='コウシャサイトウシンニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11798': FundCodeEntry(
        fund_code='G11798',
        sec_code=None,
        fund_name='公社債投信（３月号）',
        fund_name_yomi='コウシャサイトウシンサンガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11799': FundCodeEntry(
        fund_code='G11799',
        sec_code=None,
        fund_name='公社債投信（４月号）',
        fund_name_yomi='コウシャサイトウシンシガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11800': FundCodeEntry(
        fund_code='G11800',
        sec_code=None,
        fund_name='公社債投信（５月号）',
        fund_name_yomi='コウシャサイトウシンゴガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11801': FundCodeEntry(
        fund_code='G11801',
        sec_code=None,
        fund_name='公社債投信（６月号）',
        fund_name_yomi='コウシャサイトウシンロクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11802': FundCodeEntry(
        fund_code='G11802',
        sec_code=None,
        fund_name='公社債投信（７月号）',
        fund_name_yomi='コウシャサイトウシンシチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11803': FundCodeEntry(
        fund_code='G11803',
        sec_code=None,
        fund_name='公社債投信（８月号）',
        fund_name_yomi='コウシャサイトウシンハチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11804': FundCodeEntry(
        fund_code='G11804',
        sec_code=None,
        fund_name='公社債投信（９月号）',
        fund_name_yomi='コウシャサイトウシンクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11805': FundCodeEntry(
        fund_code='G11805',
        sec_code=None,
        fund_name='公社債投信（１０月号）',
        fund_name_yomi='コウシャサイトウシンジュウガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11806': FundCodeEntry(
        fund_code='G11806',
        sec_code=None,
        fund_name='公社債投信（１１月号）',
        fund_name_yomi='コウシャサイトウシンジュウイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11807': FundCodeEntry(
        fund_code='G11807',
        sec_code=None,
        fund_name='公社債投信（１２月号）',
        fund_name_yomi='コウシャサイトウシンジュウニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11808': FundCodeEntry(
        fund_code='G11808',
        sec_code=None,
        fund_name='ＭＨＡＭ株式オープン',
        fund_name_yomi='エムエイチエーエムカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11809': FundCodeEntry(
        fund_code='G11809',
        sec_code=None,
        fund_name='ＭＨＡＭ株式インデックスファンド２２５',
        fund_name_yomi='エムエイチエーエムカブシキインデックスファンドニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11810': FundCodeEntry(
        fund_code='G11810',
        sec_code=None,
        fund_name='インデックスミリオン\u3000ボンドミックスミリオン',
        fund_name_yomi='インデックスミリオン\u3000ボンドミックスミリオン',
        security_type='内国投資信託受益証券',
        period_1='10月29日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11811': FundCodeEntry(
        fund_code='G11811',
        sec_code=None,
        fund_name='ＭＨＡＭスリーウェイオープン',
        fund_name_yomi='エムエイチエーエムスリーウェイオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11812': FundCodeEntry(
        fund_code='G11812',
        sec_code=None,
        fund_name='ＭＨＡＭグローバル・アクティブ・オープン',
        fund_name_yomi='エムエイチエーエムグローバルアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11813': FundCodeEntry(
        fund_code='G11813',
        sec_code=None,
        fund_name='ＭＨＡＭ\u3000ＵＳインカムオープンＡコース（為替ヘッジあり）／ＭＨＡＭ\u3000ＵＳインカムオープンＢコース（為替ヘッジなし）',
        fund_name_yomi='エムエイチエーエムユーエスインカムオープンエーコースカワセヘッジアリ\u3000エムエイチエーエムユーエスインカムオープンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11814': FundCodeEntry(
        fund_code='G11814',
        sec_code=None,
        fund_name='ＭＨＡＭのＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='エムエイチエーエムノエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11815': FundCodeEntry(
        fund_code='G11815',
        sec_code=None,
        fund_name='ＭＨＡＭ\u3000ＴＯＰＩＸオープン',
        fund_name_yomi='エムエイチエーエムトピックスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11816': FundCodeEntry(
        fund_code='G11816',
        sec_code=None,
        fund_name='ＭＨＡＭジャパンオープン',
        fund_name_yomi='エムエイチエーエムジャパンオープン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11817': FundCodeEntry(
        fund_code='G11817',
        sec_code=None,
        fund_name='ＭＨＡＭ日本成長株オープン',
        fund_name_yomi='エムエイチエーエムニホンセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2='9月3日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11818': FundCodeEntry(
        fund_code='G11818',
        sec_code=None,
        fund_name='Ｏｎｅキャピタル・グロース・オープン',
        fund_name_yomi='ワンキャピタルグロースオープン',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11819': FundCodeEntry(
        fund_code='G11819',
        sec_code=None,
        fund_name='ＭＨＡＭ新興成長株オープン',
        fund_name_yomi='エムエイチエーエムシンコウセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11820': FundCodeEntry(
        fund_code='G11820',
        sec_code=None,
        fund_name='ＭＨＡＭ日本株式',
        fund_name_yomi='エムエイチエーエムニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11822': FundCodeEntry(
        fund_code='G11822',
        sec_code=None,
        fund_name='マネックス・日本成長株ファンド',
        fund_name_yomi='マネックスニホンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11823': FundCodeEntry(
        fund_code='G11823',
        sec_code=None,
        fund_name='ＭＨＡＭライフナビゲーション２０５０\u3000ＭＨＡＭライフナビゲーション２０４０\u3000ＭＨＡＭライフナビゲーション２０３０\u3000ＭＨＡＭライフナビゲーションインカム',
        fund_name_yomi='エムエイチエーエムライフナビゲーションニイゼロゴゼロ\u3000エムエイチエーエムライフナビゲーションニイゼロヨンゼロ\u3000エムエイチエーエムライフナビゲーションニイゼロサンゼロ\u3000エムエイチエーエムライフナビゲーションインカム',
        security_type='内国投資信託受益証券',
        period_1='6月30日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11824': FundCodeEntry(
        fund_code='G11824',
        sec_code=None,
        fund_name='ＭＨＡＭトピックスファンド',
        fund_name_yomi='エムエイチエーエムトピックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11825': FundCodeEntry(
        fund_code='G11825',
        sec_code=None,
        fund_name='ＭＨＡＭ日本株式〈ＤＣ年金〉',
        fund_name_yomi='エムエイチエーエムニホンカブシキディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11826': FundCodeEntry(
        fund_code='G11826',
        sec_code=None,
        fund_name='ＭＨＡＭ日本バリュー株オープン〈ＤＣ年金〉',
        fund_name_yomi='エムエイチエーエムニホンバリューカブオープンディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11827': FundCodeEntry(
        fund_code='G11827',
        sec_code=None,
        fund_name='ＭＨＡＭ日本成長株ファンド＜ＤＣ年金＞',
        fund_name_yomi='エムエイチエーエムニホンセイチョウカブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月3日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11828': FundCodeEntry(
        fund_code='G11828',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＵＳインカムオープン毎月決算コース（為替ヘッジなし）',
        fund_name_yomi='ワンユウエスインカムオープンマイツキケッサンコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11829': FundCodeEntry(
        fund_code='G11829',
        sec_code=None,
        fund_name='ＭＨＡＭ豪ドル債券ファンド（毎月決算型）',
        fund_name_yomi='エムエイチエーエムゴウドルサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11830': FundCodeEntry(
        fund_code='G11830',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴインデックスファンド（毎月決算型）',
        fund_name_yomi='ワンジェイリートインデックスファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11831': FundCodeEntry(
        fund_code='G11831',
        sec_code=None,
        fund_name='みずほ豪ドル債券ファンド',
        fund_name_yomi='ミズホゴウドルサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11832': FundCodeEntry(
        fund_code='G11832',
        sec_code=None,
        fund_name='ルーミス米国投資適格債券ファンド［毎月決算型］',
        fund_name_yomi='ルーミスベイコクトウシテキカクサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11833': FundCodeEntry(
        fund_code='G11833',
        sec_code=None,
        fund_name='みずほ\u3000Ｊ－ＲＥＩＴ\u3000ファンド',
        fund_name_yomi='ミズホジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11834': FundCodeEntry(
        fund_code='G11834',
        sec_code=None,
        fund_name='ＭＨＡＭ物価連動国債ファンド',
        fund_name_yomi='エムエイチエーエムブッカレンドウコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11835': FundCodeEntry(
        fund_code='G11835',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴアクティブオープン毎月決算コース',
        fund_name_yomi='ワンジェイリートアクティブオープンマイツキケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11836': FundCodeEntry(
        fund_code='G11836',
        sec_code=None,
        fund_name='ＭＨＡＭ\u3000Ｊ－ＲＥＩＴインデックスファンド〈ＤＣ年金〉',
        fund_name_yomi='エムエイチエーエムジェイリートインデックスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11837': FundCodeEntry(
        fund_code='G11837',
        sec_code=None,
        fund_name='みずほＵＳハイイールドオープンＡコース（為替ヘッジあり）／みずほＵＳハイイールドオープンＢコース（為替ヘッジなし）',
        fund_name_yomi='ミズホユーエスハイイールドオープンエーコースカワセヘッジアリ\u3000ミズホユーエスハイイールドオープンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11838': FundCodeEntry(
        fund_code='G11838',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴアクティブファンド＜ＤＣ年金＞',
        fund_name_yomi='ワンジェイリートアクティブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11839': FundCodeEntry(
        fund_code='G11839',
        sec_code=None,
        fund_name='みずほＵＳハイイールドファンド＜ＤＣ年金＞',
        fund_name_yomi='ミズホユーエスハイイールドファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11843': FundCodeEntry(
        fund_code='G11843',
        sec_code=None,
        fund_name='みずほ好配当世界株オープン',
        fund_name_yomi='ミズホコウハイトウセカイカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11845': FundCodeEntry(
        fund_code='G11845',
        sec_code=None,
        fund_name='みずほエマージング株式オープン',
        fund_name_yomi='ミズホエマージングカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11846': FundCodeEntry(
        fund_code='G11846',
        sec_code=None,
        fund_name='ＭＨＡＭトリニティオープン（毎月決算型）',
        fund_name_yomi='エムエイチエーエムトリニティオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11847': FundCodeEntry(
        fund_code='G11847',
        sec_code=None,
        fund_name='きらやかグローバル好配当株式オープン',
        fund_name_yomi='キラヤカグローバルコウハイトウカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11848': FundCodeEntry(
        fund_code='G11848',
        sec_code=None,
        fund_name='日本株好配当ファンド（年２回決算型）',
        fund_name_yomi='ニホンカブコウハイトウファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G11849': FundCodeEntry(
        fund_code='G11849',
        sec_code=None,
        fund_name='北都好配当グローバル株式オープン',
        fund_name_yomi='ホクトコウハイトウグローバルカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11850': FundCodeEntry(
        fund_code='G11850',
        sec_code=None,
        fund_name='日本株好配当ファンド（年１回決算型）',
        fund_name_yomi='ニホンカブコウハイトウファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G11852': FundCodeEntry(
        fund_code='G11852',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000６資産バランスファンド',
        fund_name_yomi='ワンロクシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11853': FundCodeEntry(
        fund_code='G11853',
        sec_code=None,
        fund_name='世界８資産ファンド\u3000安定コース、世界８資産ファンド\u3000分配コース、世界８資産ファンド\u3000成長コース',
        fund_name_yomi='セカイハチシサンファンドアンテイコース\u3000セカイハチシサンファンドブンパイコース\u3000セカイハチシサンファンドセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2='11月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11856': FundCodeEntry(
        fund_code='G11856',
        sec_code=None,
        fund_name='ＭＨＡＭ日本好配当株オープン',
        fund_name_yomi='エムエイチエーエムニホンコウハイトウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11857': FundCodeEntry(
        fund_code='G11857',
        sec_code=None,
        fund_name='日本３資産ファンド\u3000安定コース、日本３資産ファンド\u3000成長コース',
        fund_name_yomi='ニホンサンシサンファンドアンテイコース\u3000ニホンサンシサンファンドセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11858': FundCodeEntry(
        fund_code='G11858',
        sec_code=None,
        fund_name='ルーミス・グローバル債券ファンド（毎月決算型）',
        fund_name_yomi='ルーミスグローバルサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11861': FundCodeEntry(
        fund_code='G11861',
        sec_code=None,
        fund_name='アジア３資産ファンド\u3000分配コース、アジア３資産ファンド\u3000資産形成コース',
        fund_name_yomi='アジアサンシサンファンドブンパイコース\u3000アジアサンシサンファンドシサンケイセイコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11864': FundCodeEntry(
        fund_code='G11864',
        sec_code=None,
        fund_name='世界債券ファンド',
        fund_name_yomi='セカイサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11865': FundCodeEntry(
        fund_code='G11865',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内株式＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000コクナイカブシキラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11866': FundCodeEntry(
        fund_code='G11866',
        sec_code=None,
        fund_name='ＭＨＡＭ新興国株式ファンド（ファンドラップ）',
        fund_name_yomi='エムエイチエーエムシンコウコクカブシキファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11867': FundCodeEntry(
        fund_code='G11867',
        sec_code=None,
        fund_name='ＭＨＡＭ世界リートファンド（ファンドラップ）',
        fund_name_yomi='エムエイチエーエムセカイリートファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11868': FundCodeEntry(
        fund_code='G11868',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内債券＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000コクナイサイケンラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11869': FundCodeEntry(
        fund_code='G11869',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国株式（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクカブシキカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11870': FundCodeEntry(
        fund_code='G11870',
        sec_code=None,
        fund_name='たわらノーロード\u3000外国債券（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ガイコクサイケンカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11871': FundCodeEntry(
        fund_code='G11871',
        sec_code=None,
        fund_name='ＭＨＡＭ新興国現地通貨建債券ファンド（ファンドラップ）',
        fund_name_yomi='エムエイチエーエムシンコウコクゲンチツウカダテサイケンファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11872': FundCodeEntry(
        fund_code='G11872',
        sec_code=None,
        fund_name='ＭＨＡＭコモディティ・インデックスファンド（ファンドラップ）',
        fund_name_yomi='エムエイチエーエムコモディティインデックスファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11874': FundCodeEntry(
        fund_code='G11874',
        sec_code=None,
        fund_name='ファンド・コロワイド〈ＤＣ年金〉',
        fund_name_yomi='ファンドコロワイドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11875': FundCodeEntry(
        fund_code='G11875',
        sec_code=None,
        fund_name='ＭＨＡＭ\u3000ＵＳハイイールドファンド（毎月決算型）',
        fund_name_yomi='エムエイチエーエムユーエスハイイールドファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11877': FundCodeEntry(
        fund_code='G11877',
        sec_code=None,
        fund_name='米国ハイイールド債券ファンド\u3000円コース、米国ハイイールド債券ファンド\u3000米ドルコース、米国ハイイールド債券ファンド\u3000豪ドルコース、米国ハイイールド債券ファンド\u3000南アフリカランドコース、米国ハイイールド債券ファンド\u3000ブラジルレアルコース',
        fund_name_yomi='ベイコクハイイールドサイケンファンドエンコース\u3000ベイコクハイイールドサイケンファンドベイドルコース\u3000ベイコクハイイールドサイケンファンドゴウドルコース\u3000ベイコクハイイールドサイケンファンドミナミアフリカランドコース\u3000ベイコクハイイールドサイケンファンドブラジルレアルコース',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11879': FundCodeEntry(
        fund_code='G11879',
        sec_code=None,
        fund_name='世界８資産ファンド＜ＤＣ年金＞',
        fund_name_yomi='セカイハチシサンファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11880': FundCodeEntry(
        fund_code='G11880',
        sec_code=None,
        fund_name='みずほ日本債券アドバンス（豪ドル債券型）',
        fund_name_yomi='ミズホニホンサイケンアドバンスゴウドルサイケンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11883': FundCodeEntry(
        fund_code='G11883',
        sec_code=None,
        fund_name='Ｏｎｅ外国株式インデックスファンド',
        fund_name_yomi='ワンガイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11885': FundCodeEntry(
        fund_code='G11885',
        sec_code=None,
        fund_name='通貨選択型Ｊリート・ファンド（毎月分配型）\u3000円コース、通貨選択型Ｊリート・ファンド（毎月分配型）\u3000米ドルコース、通貨選択型Ｊリート・ファンド（毎月分配型）\u3000豪ドルコース、通貨選択型Ｊリート・ファンド（毎月分配型）\u3000ブラジルレアルコース',
        fund_name_yomi='ツウカセンタクガタジェイリートファンドマイツキブンパイガタエンコース\u3000ツウカセンタクガタジェイリートファンドマイツキブンパイガタベイドルコース\u3000ツウカセンタクガタジェイリートファンドマイツキブンパイガタゴウドルコース\u3000ツウカセンタクガタジェイリートファンドマイツキブンパイガタブラジルレアルコース',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11890': FundCodeEntry(
        fund_code='G11890',
        sec_code=None,
        fund_name='みずほオセアニア債券ファンド',
        fund_name_yomi='ミズホオセアニアサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11891': FundCodeEntry(
        fund_code='G11891',
        sec_code=None,
        fund_name='ＡＲ国内バリュー株式ファンド',
        fund_name_yomi='エーアールコクナイバリューカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11899': FundCodeEntry(
        fund_code='G11899',
        sec_code=None,
        fund_name='ＡＭＯ\u3000Ｊリートアクティブファンド（毎月決算型）',
        fund_name_yomi='エーエムオージェイリートアクティブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11900': FundCodeEntry(
        fund_code='G11900',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴアクティブオープン年１回決算コース',
        fund_name_yomi='ワンジェイリートアクティブオープンネンイッカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11901': FundCodeEntry(
        fund_code='G11901',
        sec_code=None,
        fund_name='ＭＨＡＭ豪ドル債券ファンド（年１回決算型）',
        fund_name_yomi='エムハイチエーエムゴウドルサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11902': FundCodeEntry(
        fund_code='G11902',
        sec_code=None,
        fund_name='みずほ\u3000Ｊ－ＲＥＩＴ\u3000ファンド（年１回決算型）',
        fund_name_yomi='ミズホジェイリートファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11903': FundCodeEntry(
        fund_code='G11903',
        sec_code=None,
        fund_name='みずほＵＳハイイールドオープン（年１回決算型）為替ヘッジあり、みずほＵＳハイイールドオープン（年１回決算型）為替ヘッジなし',
        fund_name_yomi='ミズホユーエスハイイールドオープンネンイッカイケッサンガタカワセヘッジアリ\u3000ミズホユーエスハイイールドオープンネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11904': FundCodeEntry(
        fund_code='G11904',
        sec_code=None,
        fund_name='ＭＨＡＭ米国好配当株式ファンド（毎月決算型）為替ヘッジあり、ＭＨＡＭ米国好配当株式ファンド（毎月決算型）為替ヘッジなし',
        fund_name_yomi='エムエイチエーエムベイコクコウハイトウカブシキファンドマイツキケッサンガタカワセヘッジアリ\u3000エムエイチエーエムベイコクコウハイトウカブシキファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11905': FundCodeEntry(
        fund_code='G11905',
        sec_code=None,
        fund_name='ＭＨＡＭ米国好配当株式ファンド（年１回決算型）為替ヘッジあり、ＭＨＡＭ米国好配当株式ファンド（年１回決算型）為替ヘッジなし',
        fund_name_yomi='エムエイチエーエムベイコクコウハイトウカブシキファンドネンイッカイケッサンガタカワセヘッジアリ\u3000エムエイチエーエムベイコクコウハイトウカブシキファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11906': FundCodeEntry(
        fund_code='G11906',
        sec_code=None,
        fund_name='米国厳選成長株集中投資ファンド\u3000Ａコース（為替ヘッジあり）、米国厳選成長株集中投資ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ベイコクゲンセンセイチョウカブシュウチュウトウシファンドエーコースカワセヘッジアリ\u3000ベイコクゲンセンセイチョウカブシュウチュウトウシファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11907': FundCodeEntry(
        fund_code='G11907',
        sec_code=None,
        fund_name='みずほ日本債券アドバンス（豪ドル債券型）年１回決算コース',
        fund_name_yomi='ミズホニホンサイケンアドバンスゴウドルサイケンガタネンイッカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11908': FundCodeEntry(
        fund_code='G11908',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴインデックスファンド（年１回決算型）',
        fund_name_yomi='ワンジェイリートインデックスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11909': FundCodeEntry(
        fund_code='G11909',
        sec_code=None,
        fund_name='みずほ豪ドル債券ファンド（年１回決算型）',
        fund_name_yomi='ミズホゴウドルサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11910': FundCodeEntry(
        fund_code='G11910',
        sec_code=None,
        fund_name='インカムビルダー（毎月決算型）限定為替ヘッジ、インカムビルダー（毎月決算型）為替ヘッジなし',
        fund_name_yomi='インカムビルダーマイツキケッサンガタゲンテイカワセヘッジ\u3000インカムビルダーマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11911': FundCodeEntry(
        fund_code='G11911',
        sec_code=None,
        fund_name='インカムビルダー（年１回決算型）限定為替ヘッジ、インカムビルダー（年１回決算型）為替ヘッジなし',
        fund_name_yomi='インカムビルダーネンイッカイケッサンガタゲンテイカワセヘッジ\u3000インカムビルダーネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11912': FundCodeEntry(
        fund_code='G11912',
        sec_code=None,
        fund_name='欧州不動産戦略ファンド（３ヵ月決算型）',
        fund_name_yomi='オウシュウフドウサンセンリャクファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11913': FundCodeEntry(
        fund_code='G11913',
        sec_code=None,
        fund_name='欧州不動産戦略ファンド（年１回決算型）',
        fund_name_yomi='オウシュウフドウサンセンリャクファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11914': FundCodeEntry(
        fund_code='G11914',
        sec_code=None,
        fund_name='インカムビルダー（毎月決算型）世界通貨分散コース',
        fund_name_yomi='インカムビルダーマイツキケッサンガタセカイツウカブンサンコース',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2='10月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11915': FundCodeEntry(
        fund_code='G11915',
        sec_code=None,
        fund_name='インカムビルダー（年１回決算型）世界通貨分散コース',
        fund_name_yomi='インカムビルダーネンイッカイケッサンガタセカイツウカブンサンコース',
        security_type='内国投資信託受益証券',
        period_1='4月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11916': FundCodeEntry(
        fund_code='G11916',
        sec_code=None,
        fund_name='先進国投資適格債券ファンド（為替ヘッジあり）',
        fund_name_yomi='センシンコクトウシテキカクサイケンファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11917': FundCodeEntry(
        fund_code='G11917',
        sec_code=None,
        fund_name='コア資産形成ファンド',
        fund_name_yomi='コアシサンケイセイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11918': FundCodeEntry(
        fund_code='G11918',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000６資産バランスファンド（年１回決算型）',
        fund_name_yomi='ワンロクシサンバランスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11919': FundCodeEntry(
        fund_code='G11919',
        sec_code=None,
        fund_name='日本３資産ファンド（年１回決算型）',
        fund_name_yomi='ニホンサンシサンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11921': FundCodeEntry(
        fund_code='G11921',
        sec_code=None,
        fund_name='みずほ日経平均ファンド＜ＤＣ年金＞',
        fund_name_yomi='ミズホニッケイヘイキンファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11922': FundCodeEntry(
        fund_code='G11922',
        sec_code=None,
        fund_name='米国小型バリュー株ファンド\u3000Ａコース（為替ヘッジあり）、米国小型バリュー株ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ベイコクコガタバリューカブファンドエーコースカワセヘッジアリ\u3000ベイコクコガタバリューカブファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11923': FundCodeEntry(
        fund_code='G11923',
        sec_code=None,
        fund_name='資本収益力日本株ファンド（年１回決算型）',
        fund_name_yomi='シホンシュウエキリョクニホンカブファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11924': FundCodeEntry(
        fund_code='G11924',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国株式（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクカブシキカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11925': FundCodeEntry(
        fund_code='G11925',
        sec_code=None,
        fund_name='たわらノーロード\u3000外国債券（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ガイコクサイケンカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11926': FundCodeEntry(
        fund_code='G11926',
        sec_code=None,
        fund_name='たわらノーロード\u3000国内リート＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000コクナイリートラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11927': FundCodeEntry(
        fund_code='G11927',
        sec_code=None,
        fund_name='動的パッケージファンド＜ＤＣ年金＞',
        fund_name_yomi='ドウテキパッケージファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11928': FundCodeEntry(
        fund_code='G11928',
        sec_code=None,
        fund_name='グローバル・セキュリティ株式ファンド（３ヵ月決算型）',
        fund_name_yomi='グローバルセキュリティカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11929': FundCodeEntry(
        fund_code='G11929',
        sec_code=None,
        fund_name='グローバル・セキュリティ株式ファンド（年１回決算型）',
        fund_name_yomi='グローバルセキュリティカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11930': FundCodeEntry(
        fund_code='G11930',
        sec_code=None,
        fund_name='資本収益力日本株ファンド（３ヵ月決算型）',
        fund_name_yomi='シホンシュウエキリョクニホンカブファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11931': FundCodeEntry(
        fund_code='G11931',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴセレクション（毎月決算型）',
        fund_name_yomi='ジェイリートセレクションマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11932': FundCodeEntry(
        fund_code='G11932',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴセレクション（年１回決算型）',
        fund_name_yomi='ジェイリートセレクションネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11934': FundCodeEntry(
        fund_code='G11934',
        sec_code=None,
        fund_name='ファンド“メガ・テック”',
        fund_name_yomi='ファンドメガテック',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11935': FundCodeEntry(
        fund_code='G11935',
        sec_code=None,
        fund_name='日本株オープン\u3000新潮流',
        fund_name_yomi='ニホンカブオープンシンチョウリュウ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11936': FundCodeEntry(
        fund_code='G11936',
        sec_code=None,
        fund_name='ブランドエクイティ',
        fund_name_yomi='ブランドエクイティ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11937': FundCodeEntry(
        fund_code='G11937',
        sec_code=None,
        fund_name='日本実力株ファンド',
        fund_name_yomi='ニホンジツリョクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11938': FundCodeEntry(
        fund_code='G11938',
        sec_code=None,
        fund_name='ディープバリュー株オープン',
        fund_name_yomi='ディープバリューカブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11940': FundCodeEntry(
        fund_code='G11940',
        sec_code=None,
        fund_name='インデックスポートフォリオ',
        fund_name_yomi='インデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11941': FundCodeEntry(
        fund_code='G11941',
        sec_code=None,
        fund_name='ボンドミックスポートフォリオ',
        fund_name_yomi='ボンドミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11942': FundCodeEntry(
        fund_code='G11942',
        sec_code=None,
        fund_name='ハイパーバランスオープン',
        fund_name_yomi='ハイパーバランスオープン',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11943': FundCodeEntry(
        fund_code='G11943',
        sec_code=None,
        fund_name='ジャパンニューエイジオープン',
        fund_name_yomi='ジャパンニューエイジオープン',
        security_type='内国投資信託受益証券',
        period_1='9月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11944': FundCodeEntry(
        fund_code='G11944',
        sec_code=None,
        fund_name='コア３０インデックス',
        fund_name_yomi='コアサンジュウインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11945': FundCodeEntry(
        fund_code='G11945',
        sec_code=None,
        fund_name='新光ＭＲＦ（マネー・リザーブ・ファンド）',
        fund_name_yomi='シンコウエムアールエフマネーリザーブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11946': FundCodeEntry(
        fund_code='G11946',
        sec_code=None,
        fund_name='財形株投\u3000（一般財形３０）',
        fund_name_yomi='ザイケイカブトウイッパンザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11947': FundCodeEntry(
        fund_code='G11947',
        sec_code=None,
        fund_name='財形株投\u3000（一般財形５０）',
        fund_name_yomi='ザイケイカブトウイッパンザイケイゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11948': FundCodeEntry(
        fund_code='G11948',
        sec_code=None,
        fund_name='財形株投\u3000（年金・住宅財形３０）',
        fund_name_yomi='ザイケイカブトウネンキンジュウタクザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11949': FundCodeEntry(
        fund_code='G11949',
        sec_code=None,
        fund_name='太陽財形株投\u3000太陽一般財形\u3000３０',
        fund_name_yomi='タイヨウザイケイカブトウタイヨウイッパンザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11950': FundCodeEntry(
        fund_code='G11950',
        sec_code=None,
        fund_name='太陽財形株投\u3000太陽一般財形\u3000５０',
        fund_name_yomi='タイヨウザイケイカブトウタイヨウイッパンザイケイゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11951': FundCodeEntry(
        fund_code='G11951',
        sec_code=None,
        fund_name='太陽財形株投\u3000太陽年金・住宅財形\u3000３０',
        fund_name_yomi='タイヨウザイケイカブトウタイヨウネンキンジュウタクザイケイサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11952': FundCodeEntry(
        fund_code='G11952',
        sec_code=None,
        fund_name='ニュー\u3000トピックス\u3000インデックス',
        fund_name_yomi='ニュー\u3000トピックス\u3000インデックス',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11953': FundCodeEntry(
        fund_code='G11953',
        sec_code=None,
        fund_name='インデックス\u3000マネジメント\u3000ファンド\u3000２２５',
        fund_name_yomi='インデックス\u3000マネジメント\u3000ファンド\u3000ニ\u3000ニ\u3000ゴ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11954': FundCodeEntry(
        fund_code='G11954',
        sec_code=None,
        fund_name='太陽ミリオン（太陽ミリオン・インデックスポートフォリオ）',
        fund_name_yomi='タイヨウミリオンタイヨウミリオン\u3000インデックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11955': FundCodeEntry(
        fund_code='G11955',
        sec_code=None,
        fund_name='太陽ミリオン（太陽ミリオン・ボンドミックスポートフォリオ）',
        fund_name_yomi='タイヨウミリオンタイヨウミリオン\u3000ボンドミックスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11956': FundCodeEntry(
        fund_code='G11956',
        sec_code=None,
        fund_name='公社債投信１月号',
        fund_name_yomi='コウシャサイトウシンイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11957': FundCodeEntry(
        fund_code='G11957',
        sec_code=None,
        fund_name='公社債投信２月号',
        fund_name_yomi='コウシャサイトウシンニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11958': FundCodeEntry(
        fund_code='G11958',
        sec_code=None,
        fund_name='公社債投信３月号',
        fund_name_yomi='コウシャサイトウシンサンガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11959': FundCodeEntry(
        fund_code='G11959',
        sec_code=None,
        fund_name='公社債投信４月号',
        fund_name_yomi='コウシャサイトウシンシガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11960': FundCodeEntry(
        fund_code='G11960',
        sec_code=None,
        fund_name='公社債投信５月号',
        fund_name_yomi='コウシャサイトウシンゴガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11961': FundCodeEntry(
        fund_code='G11961',
        sec_code=None,
        fund_name='公社債投信６月号',
        fund_name_yomi='コウシャサイトウシンロクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11962': FundCodeEntry(
        fund_code='G11962',
        sec_code=None,
        fund_name='公社債投信７月号',
        fund_name_yomi='コウシャサイトウシンシチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='7月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11963': FundCodeEntry(
        fund_code='G11963',
        sec_code=None,
        fund_name='公社債投信８月号',
        fund_name_yomi='コウシャサイトウシンハチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11964': FundCodeEntry(
        fund_code='G11964',
        sec_code=None,
        fund_name='公社債投信９月号',
        fund_name_yomi='コウシャサイトウシンクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11965': FundCodeEntry(
        fund_code='G11965',
        sec_code=None,
        fund_name='公社債投信１０月号',
        fund_name_yomi='コウシャサイトウシンジュウガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='10月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11966': FundCodeEntry(
        fund_code='G11966',
        sec_code=None,
        fund_name='公社債投信１１月号',
        fund_name_yomi='コウシャサイトウシンジュウイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11967': FundCodeEntry(
        fund_code='G11967',
        sec_code=None,
        fund_name='公社債投信１２月号',
        fund_name_yomi='コウシャサイトウシンジュウニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11980': FundCodeEntry(
        fund_code='G11980',
        sec_code=None,
        fund_name='海外国債ファンド',
        fund_name_yomi='カイガイコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11981': FundCodeEntry(
        fund_code='G11981',
        sec_code=None,
        fund_name='インデックス\u3000マネジメント\u3000ファンド\u3000２２５（ＤＣ年金）',
        fund_name_yomi='インデックス\u3000マネジメント\u3000ファンド\u3000ニ\u3000ニ\u3000ゴ\u3000ディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11982': FundCodeEntry(
        fund_code='G11982',
        sec_code=None,
        fund_name='日本実力株ファンド（ＤＣ年金）',
        fund_name_yomi='ニホンジツリョクカブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11984': FundCodeEntry(
        fund_code='G11984',
        sec_code=None,
        fund_name='海外国債ファンド（３ヵ月決算型）',
        fund_name_yomi='カイガイコクサイファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11985': FundCodeEntry(
        fund_code='G11985',
        sec_code=None,
        fund_name='海外投資適格社債ファンド',
        fund_name_yomi='カイガイトウシテキカクシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11986': FundCodeEntry(
        fund_code='G11986',
        sec_code=None,
        fund_name='新光小型株オープン',
        fund_name_yomi='シンコウコガタカブオープン',
        security_type='内国投資信託受益証券',
        period_1='2月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11987': FundCodeEntry(
        fund_code='G11987',
        sec_code=None,
        fund_name='ＡＭＯ\u3000Ｊ－ＲＥＩＴオープン',
        fund_name_yomi='エーエムオージェイリートオープン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11988': FundCodeEntry(
        fund_code='G11988',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴパッケージ',
        fund_name_yomi='ジェイリートパッケージ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11989': FundCodeEntry(
        fund_code='G11989',
        sec_code=None,
        fund_name='新光\u3000ＵＳ－ＲＥＩＴ\u3000オープン',
        fund_name_yomi='シンコウユーエスリートオープン',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11994': FundCodeEntry(
        fund_code='G11994',
        sec_code=None,
        fund_name='新光ピクテ世界インカム株式ファンド（毎月決算型）',
        fund_name_yomi='シンコウピクテセカイインカムカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11995': FundCodeEntry(
        fund_code='G11995',
        sec_code=None,
        fund_name='新光日本インカム株式ファンド（３ヵ月決算型）',
        fund_name_yomi='シンコウニホンインカムカブシキファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2='7月28日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11997': FundCodeEntry(
        fund_code='G11997',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000国内リートインデックスファンド',
        fund_name_yomi='ワン\u3000ディーシー\u3000コクナイリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11998': FundCodeEntry(
        fund_code='G11998',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000国内債券インデックスファンド',
        fund_name_yomi='ワンディーシーコクナイサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G11999': FundCodeEntry(
        fund_code='G11999',
        sec_code=None,
        fund_name='新光ジャパンオープンⅡ',
        fund_name_yomi='シンコウジャパンオープンツー',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12000': FundCodeEntry(
        fund_code='G12000',
        sec_code=None,
        fund_name='フロンティア・ワールド・インカム・ファンド',
        fund_name_yomi='フロンティアワールドインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12001': FundCodeEntry(
        fund_code='G12001',
        sec_code=None,
        fund_name='Ｏｎｅピュア・インド株式ファンド',
        fund_name_yomi='ワンピュアインドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12003': FundCodeEntry(
        fund_code='G12003',
        sec_code=None,
        fund_name='瀬戸内４県ファンド',
        fund_name_yomi='セトウチヨンケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12004': FundCodeEntry(
        fund_code='G12004',
        sec_code=None,
        fund_name='新光７資産バランスファンド',
        fund_name_yomi='シンコウナナシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12005': FundCodeEntry(
        fund_code='G12005',
        sec_code=None,
        fund_name='サザンアジア・オールスター株式ファンド',
        fund_name_yomi='サザンアジアオールスターカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12009': FundCodeEntry(
        fund_code='G12009',
        sec_code=None,
        fund_name='新成長中国株式ファンド',
        fund_name_yomi='シンセイチョウチュウゴクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12010': FundCodeEntry(
        fund_code='G12010',
        sec_code=None,
        fund_name='高金利通貨ファンド',
        fund_name_yomi='コウキンリツウカファンド',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12011': FundCodeEntry(
        fund_code='G12011',
        sec_code=None,
        fund_name='日本株リーダーズファンド',
        fund_name_yomi='ニホンカブリーダーズファンド',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12015': FundCodeEntry(
        fund_code='G12015',
        sec_code=None,
        fund_name='海外国債ファンド（１年決算型）',
        fund_name_yomi='カイガイコクサイファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12016': FundCodeEntry(
        fund_code='G12016',
        sec_code=None,
        fund_name='新光ブラジル債券ファンド',
        fund_name_yomi='シンコウブラジルサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12018': FundCodeEntry(
        fund_code='G12018',
        sec_code=None,
        fund_name='優先株ＥＴＦファンド（毎月分配型・ヘッジあり）',
        fund_name_yomi='ユウセンカブイーティーエフファンド\u3000マイツキブンパイガタ\u3000ヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12021': FundCodeEntry(
        fund_code='G12021',
        sec_code=None,
        fund_name='日本債券ファンド',
        fund_name_yomi='ニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12024': FundCodeEntry(
        fund_code='G12024',
        sec_code=None,
        fund_name='新光サザンアジア株式ファンド',
        fund_name_yomi='シンコウサザンアジアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12026': FundCodeEntry(
        fund_code='G12026',
        sec_code=None,
        fund_name='りそなＪリート・アクティブ・オープン',
        fund_name_yomi='リソナジェイリートアクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12027': FundCodeEntry(
        fund_code='G12027',
        sec_code=None,
        fund_name='世界好配当ピュア・インフラ株式ファンド（毎月決算型）',
        fund_name_yomi='セカイコウハイトウピュアインフラカブシキファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12028': FundCodeEntry(
        fund_code='G12028',
        sec_code=None,
        fund_name='世界好配当ピュア・インフラ株式ファンド（成長型）',
        fund_name_yomi='セカイコウハイトウピュアインフラカブシキファンド\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12034': FundCodeEntry(
        fund_code='G12034',
        sec_code=None,
        fund_name='ワールド・インフラ好配当株式ファンド（毎月決算型／成長型）',
        fund_name_yomi='ワールドインフラコウハイトウカブシキファンドマイツキケッサンガタセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12035': FundCodeEntry(
        fund_code='G12035',
        sec_code=None,
        fund_name='短期ハイイールド債券ファンド（ヘッジあり）',
        fund_name_yomi='タンキハイイールドサイケンファンドヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2='10月30日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12036': FundCodeEntry(
        fund_code='G12036',
        sec_code=None,
        fund_name='新光世界インフラ株式ファンド',
        fund_name_yomi='シンコウセカイインフラカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12037': FundCodeEntry(
        fund_code='G12037',
        sec_code=None,
        fund_name='世界高配当株セレクト（目標払出し型）毎月決算・為替ヘッジなしコース、毎月決算・為替ヘッジありコース',
        fund_name_yomi='セカイコウハイトウカブセレクトモクヒョウハライダシガタマイツキケッサンカワセヘッジナシコースマイツキケッサンカワセヘッジアリコース',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12038': FundCodeEntry(
        fund_code='G12038',
        sec_code=None,
        fund_name='バンクローン・ファンド（ヘッジなし）／バンクローン・ファンド（ヘッジあり）',
        fund_name_yomi='バンクローンファンドヘッジナシバンクローンファンドヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12039': FundCodeEntry(
        fund_code='G12039',
        sec_code=None,
        fund_name='新光トルコ・リラ債券ファンド（毎月決算型）',
        fund_name_yomi='シンコウトルコリラサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12040': FundCodeEntry(
        fund_code='G12040',
        sec_code=None,
        fund_name='新光メキシコ・ペソ債券ファンド（毎月決算型）',
        fund_name_yomi='シンコウメキシコペソサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12042': FundCodeEntry(
        fund_code='G12042',
        sec_code=None,
        fund_name='グローバル・アロケーション・ファンド（毎月決算・為替ヘッジなしコース、毎月決算・限定為替ヘッジコース）（目標払出し型）',
        fund_name_yomi='グローバルアロケーションファンドマイツキケッサンカワセヘッジナシコースマイツキケッサンゲンテイカワセヘッジコースモクヒョウハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12048': FundCodeEntry(
        fund_code='G12048',
        sec_code=None,
        fund_name='海外消費関連日本株ファンド',
        fund_name_yomi='カイガイショウヒカンレンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12050': FundCodeEntry(
        fund_code='G12050',
        sec_code=None,
        fund_name='新光バンクローン・ファンド・ネオ（円ヘッジ型）',
        fund_name_yomi='シンコウバンクローンファンドネオ\u3000エンヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12051': FundCodeEntry(
        fund_code='G12051',
        sec_code=None,
        fund_name='新光日本小型株ファンド',
        fund_name_yomi='シンコウニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12052': FundCodeEntry(
        fund_code='G12052',
        sec_code=None,
        fund_name='グローバル・アロケーション・オープンＡコース（年１回決算・為替ヘッジなし）、グローバル・アロケーション・オープンＣコース（年１回決算・限定為替ヘッジ）',
        fund_name_yomi='グローバルアロケーションオープンエーコース\u3000ネンイッカイケッサン\u3000カワセヘッジナシ\u3000グローバルアロケーションオープンシーコース\u3000ネンイッカイケッサン\u3000ゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12053': FundCodeEntry(
        fund_code='G12053',
        sec_code=None,
        fund_name='グローバル・アロケーション・オープンＢコース（年４回決算・為替ヘッジなし）、グローバル・アロケーション・オープンＤコース（年４回決算・限定為替ヘッジ）',
        fund_name_yomi='グローバルアロケーションオープンビーコース\u3000ネンヨンカイケッサン\u3000カワセヘッジナシ\u3000グローバルアロケーションオープンディーコース\u3000ネンヨンカイケッサン\u3000ゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12054': FundCodeEntry(
        fund_code='G12054',
        sec_code=None,
        fund_name='バンクローン・ファンド（ヘッジなし／年１回決算型）、バンクローン・ファンド（ヘッジあり／年１回決算型）',
        fund_name_yomi='バンクローンファンド\u3000ヘッジナシ\u3000ネンイッカイケッサンガタ\u3000バンクローンファンド\u3000ヘッジアリ\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12055': FundCodeEntry(
        fund_code='G12055',
        sec_code=None,
        fund_name='フロンティア・ワールド・インカム・ファンド（年１回決算型）',
        fund_name_yomi='フロンティア\u3000ワールド\u3000インカム\u3000ファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12056': FundCodeEntry(
        fund_code='G12056',
        sec_code=None,
        fund_name='新光グローバル・ハイイールド債券ファンド（年１回決算型）',
        fund_name_yomi='シンコウグローバル\u3000ハイイールドサイケンファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12057': FundCodeEntry(
        fund_code='G12057',
        sec_code=None,
        fund_name='新光\u3000ＵＳ－ＲＥＩＴ\u3000オープン（年１回決算型）',
        fund_name_yomi='シンコウユーエスリートオープン\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12059': FundCodeEntry(
        fund_code='G12059',
        sec_code=None,
        fund_name='グローバル・ナビ',
        fund_name_yomi='グローバル\u3000ナビ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12060': FundCodeEntry(
        fund_code='G12060',
        sec_code=None,
        fund_name='グローバルドライブ（３ヵ月決算型）限定為替ヘッジ／グローバルドライブ（３ヵ月決算型）為替ヘッジなし',
        fund_name_yomi='グローバルドライブ\u3000サンカゲツケッサンガタ\u3000ゲンテイカワセヘッジ\u3000グローバルドライブ\u3000サンカゲツケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12061': FundCodeEntry(
        fund_code='G12061',
        sec_code=None,
        fund_name='グローバルドライブ（年１回決算型）限定為替ヘッジ／グローバルドライブ（年１回決算型）為替ヘッジなし',
        fund_name_yomi='グローバルドライブ\u3000ネンイッカイケッサンガタ\u3000ゲンテイカワセヘッジ\u3000グローバルドライブ\u3000ネンイッカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12062': FundCodeEntry(
        fund_code='G12062',
        sec_code=None,
        fund_name='新光シラー・ケープ米欧株式戦略ファンド（リスク・コントロール付）為替ヘッジなしコース／新光シラー・ケープ米欧株式戦略ファンド（リスク・コントロール付）為替ヘッジありコース',
        fund_name_yomi='シンコウシラー\u3000ケープベイオウカブシキセンリャクファンド\u3000リスク\u3000コントロールツキ\u3000カワセヘッジナシコース\u3000シンコウシラー\u3000ケープベイオウカブシキセンリャクファンド\u3000リスク\u3000コントロールツキ\u3000カワセヘッジアリコース',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12063': FundCodeEntry(
        fund_code='G12063',
        sec_code=None,
        fund_name='グローバル・フォーカス（毎月決算型）',
        fund_name_yomi='グローバル\u3000フォーカス\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12064': FundCodeEntry(
        fund_code='G12064',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド１月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000イチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12065': FundCodeEntry(
        fund_code='G12065',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド２月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000ニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12066': FundCodeEntry(
        fund_code='G12066',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド３月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000サンガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12067': FundCodeEntry(
        fund_code='G12067',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド４月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000シガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12068': FundCodeEntry(
        fund_code='G12068',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド５月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドゴガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12069': FundCodeEntry(
        fund_code='G12069',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド６月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000ロクガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12070': FundCodeEntry(
        fund_code='G12070',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド７月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドシチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12071': FundCodeEntry(
        fund_code='G12071',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド８月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドハチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12072': FundCodeEntry(
        fund_code='G12072',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド９月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンド\u3000クガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12073': FundCodeEntry(
        fund_code='G12073',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド１０月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドジュウガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12074': FundCodeEntry(
        fund_code='G12074',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド１１月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドジュウイチガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12075': FundCodeEntry(
        fund_code='G12075',
        sec_code=None,
        fund_name='新光ピムコ・ストラテジック・インカム・ファンド１２月号',
        fund_name_yomi='シンコウピムコ\u3000ストラテジック\u3000インカム\u3000ファンドジュウニガツゴウ',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12076': FundCodeEntry(
        fund_code='G12076',
        sec_code=None,
        fund_name='生活基盤関連株式ファンド',
        fund_name_yomi='セイカツキバンカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12077': FundCodeEntry(
        fund_code='G12077',
        sec_code=None,
        fund_name='新光アジア・オセアニアＲＥＩＴオープン（毎月決算型）',
        fund_name_yomi='シンコウアジア\u3000オセアニアリートオープン\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12078': FundCodeEntry(
        fund_code='G12078',
        sec_code=None,
        fund_name='新光アジア・オセアニアＲＥＩＴオープン（成長型）',
        fund_name_yomi='シンコウアジア\u3000オセアニアリートオープン\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12079': FundCodeEntry(
        fund_code='G12079',
        sec_code=None,
        fund_name='ＡＭＯ\u3000Ｊ－ＲＥＩＴオープン（年２回決算型）',
        fund_name_yomi='エーエムオージェイリートオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12080': FundCodeEntry(
        fund_code='G12080',
        sec_code=None,
        fund_name='ハイブリッド証券ファンド円コース',
        fund_name_yomi='ハイブリッドショウケンファンドエンコース',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12081': FundCodeEntry(
        fund_code='G12081',
        sec_code=None,
        fund_name='ハイブリッド証券ファンド米ドルコース、豪ドルコース、ブラジルレアルコース、マネープールファンド',
        fund_name_yomi='ハイブリッドショウケンファンドベイドルコース\u3000ゴウドルコース\u3000ブラジルレアルコース\u3000マネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12084': FundCodeEntry(
        fund_code='G12084',
        sec_code=None,
        fund_name='新光シラー・ケープ日本株式戦略ファンド（リスク・コントロール付）',
        fund_name_yomi='シンコウシラー\u3000ケープニホンカブシキセンリャクファンド\u3000リスク\u3000コントロールツキ',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12085': FundCodeEntry(
        fund_code='G12085',
        sec_code=None,
        fund_name='みずほラップファンド（堅実型コース）／（安定成長型コース）／（成長型コース）',
        fund_name_yomi='ミズホラップファンド\u3000ケンジツガタコース\u3000アンテイセイチョウガタコース\u3000セイチョウガタコース',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12086': FundCodeEntry(
        fund_code='G12086',
        sec_code=None,
        fund_name='新光スマート・アロケーション・ファンド（安定型）',
        fund_name_yomi='シンコウスマート\u3000アロケーション\u3000ファンド\u3000アンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12087': FundCodeEntry(
        fund_code='G12087',
        sec_code=None,
        fund_name='新光スマート・アロケーション・ファンド（安定成長型）',
        fund_name_yomi='シンコウスマート\u3000アロケーション\u3000ファンド\u3000アンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12088': FundCodeEntry(
        fund_code='G12088',
        sec_code=None,
        fund_name='新光スマート・アロケーション・ファンド（成長型）',
        fund_name_yomi='シンコウスマート\u3000アロケーション\u3000ファンド\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12091': FundCodeEntry(
        fund_code='G12091',
        sec_code=None,
        fund_name='新光グローバル・ハイイールド債券ファンド円コース',
        fund_name_yomi='シンコウグローバル\u3000ハイイールドサイケンファンドエンコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12092': FundCodeEntry(
        fund_code='G12092',
        sec_code=None,
        fund_name='新光グローバル・ハイイールド債券ファンド米ドルコース、豪ドルコース、ブラジルレアルコース、マネープールファンド',
        fund_name_yomi='シンコウグローバル\u3000ハイイールドサイケンファンドベイドルコース\u3000ゴウドルコース\u3000ブラジルレアルコース\u3000マネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12093': FundCodeEntry(
        fund_code='G12093',
        sec_code=None,
        fund_name='フィッシャーＵＳマイクロ株式ファンド',
        fund_name_yomi='フィッシャーユーエスマイクロカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12094': FundCodeEntry(
        fund_code='G12094',
        sec_code=None,
        fund_name='新光日本株式変動抑制型ファンド（ファンドラップ）',
        fund_name_yomi='シンコウニホンカブシキヘンドウヨクセイガタファンド\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12095': FundCodeEntry(
        fund_code='G12095',
        sec_code=None,
        fund_name='新光外国株式変動抑制型ファンド（ファンドラップ）',
        fund_name_yomi='シンコウガイコクカブシキヘンドウヨクセイガタファンド\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12096': FundCodeEntry(
        fund_code='G12096',
        sec_code=None,
        fund_name='新光グローバル・マクロ戦略ファンド（ファンドラップ）',
        fund_name_yomi='シンコウグローバル\u3000マクロセンリャクファンド\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12097': FundCodeEntry(
        fund_code='G12097',
        sec_code=None,
        fund_name='新光シラー・グローバルＲＥＩＴファンド（ファンドラップ）',
        fund_name_yomi='シンコウシラー\u3000グローバルリートファンド\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12098': FundCodeEntry(
        fund_code='G12098',
        sec_code=None,
        fund_name='新光外国債券ファンド（為替リスク抑制型）（ファンドラップ）',
        fund_name_yomi='シンコウガイコクサイケンファンド\u3000カワセリスクヨクセイガタ\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12099': FundCodeEntry(
        fund_code='G12099',
        sec_code=None,
        fund_name='新光債券ストラテジック・アロケーション戦略ファンド（ファンドラップ）',
        fund_name_yomi='シンコウサイケンストラテジック\u3000アロケーションセンリャクファンド\u3000ファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12100': FundCodeEntry(
        fund_code='G12100',
        sec_code=None,
        fund_name='企業価値成長小型株ファンド',
        fund_name_yomi='キギョウカチセイチョウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12101': FundCodeEntry(
        fund_code='G12101',
        sec_code=None,
        fund_name='グローバル新世代関連株式ファンド',
        fund_name_yomi='グローバルシンセダイカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12102': FundCodeEntry(
        fund_code='G12102',
        sec_code=None,
        fund_name='野村インデックスファンド・米国ハイ・イールド債券',
        fund_name_yomi='ノムラインデックスファンドベイコクハイイールドサイケン',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12103': FundCodeEntry(
        fund_code='G12103',
        sec_code=None,
        fund_name='野村インデックスファンド・米国ハイ・イールド債券・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドベイコクハイイールドサイケンカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12104': FundCodeEntry(
        fund_code='G12104',
        sec_code=None,
        fund_name='ニッセイＪリートオープン\u3000米ドル投資型（毎月分配型）',
        fund_name_yomi='ニッセイジェイリートオープン\u3000ベイドルトウシガタマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12105': FundCodeEntry(
        fund_code='G12105',
        sec_code=None,
        fund_name='ニッセイＪリートオープン\u3000米ドル投資型（年１回決算型）',
        fund_name_yomi='ニッセイジェイリートオープン\u3000ベイドルトウシガタネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12106': FundCodeEntry(
        fund_code='G12106',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（１年決算型）円コース',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドイチネンケッサンガタエンコース',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12108': FundCodeEntry(
        fund_code='G12108',
        sec_code=None,
        fund_name='ドイチェ世界コーポレート・ハイブリッド証券ファンド（年４回決算型）Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ドイチェセカイコーポレートハイブリッドショウケンファンドネンヨンカイケッサンガタエイコースカワセヘッジアリビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G12109': FundCodeEntry(
        fund_code='G12109',
        sec_code=None,
        fund_name='日本株＆Ｊリート\u3000好配当フォーカスファンド',
        fund_name_yomi='ニホンカブアンドジェイリート\u3000コウハイトウフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12111': FundCodeEntry(
        fund_code='G12111',
        sec_code='34720',
        fund_name='日本ホテル＆レジデンシャル投資法人',
        fund_name_yomi='ニッポンホテルアンドレジデンシャルトウシホウジン',
        security_type='内国投資証券',
        period_1='5月31日',
        period_2='11月30日',
        edinet_code='E32428',
        issuer_name='日本ホテル＆レジデンシャル投資法人',
    ),
    'G12112': FundCodeEntry(
        fund_code='G12112',
        sec_code=None,
        fund_name='東京海上・世界ヘルスケアＲＥＩＴファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウセカイヘルスケアリートファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12113': FundCodeEntry(
        fund_code='G12113',
        sec_code=None,
        fund_name='米国・地方公共事業債ファンド（為替ヘッジあり）、米国・地方公共事業債ファンド（為替ヘッジなし）',
        fund_name_yomi='ベイコクチホウコウキョウジギョウサイファンドカワセヘッジアリ\u3000ベイコクチホウコウキョウジギョウサイファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12115': FundCodeEntry(
        fund_code='G12115',
        sec_code=None,
        fund_name='明治安田生命２０１６基金特定目的会社',
        fund_name_yomi='メイジヤスダセイメイニセンジュウロクキキントクテイモクテキカイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E32546',
        issuer_name='明治安田生命２０１６基金特定目的会社',
    ),
    'G12116': FundCodeEntry(
        fund_code='G12116',
        sec_code=None,
        fund_name='時間分散型バランスファンド（安定指向）２０１６－０８',
        fund_name_yomi='ジカンブンサンガタバランスファンド\u3000アンテイシコウ\u3000ニーゼロイチロク\u3000ゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12118': FundCodeEntry(
        fund_code='G12118',
        sec_code=None,
        fund_name='日本株テーマセレクション',
        fund_name_yomi='ニホンカブテーマセレクション',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12121': FundCodeEntry(
        fund_code='G12121',
        sec_code=None,
        fund_name='インベスコ\u3000米国公共インフラ債ファンド（毎月決算型）',
        fund_name_yomi='インベスコベイコクコウキョウインフラサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G12122': FundCodeEntry(
        fund_code='G12122',
        sec_code=None,
        fund_name='インベスコ\u3000米国公共インフラ債ファンド（年１回決算型）',
        fund_name_yomi='インベスコベイコクコウキョウインフラサイファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G12126': FundCodeEntry(
        fund_code='G12126',
        sec_code=None,
        fund_name='ＤＣニッセイターゲットデートファンド２０２５／２０３０／２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５',
        fund_name_yomi='ディーシーニッセイターゲットデートファンドニイゼロニイゴ\u3000ニイゼロサンゼロ\u3000ニイゼロサンゴ\u3000ニイゼロヨンゼロ\u3000ニイゼロヨンゴ\u3000ニイゼロゴゼロ\u3000ニイゼロゴゴ\u3000ニイゼロロクゼロ\u3000ニイゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12127': FundCodeEntry(
        fund_code='G12127',
        sec_code=None,
        fund_name='ＤＣニッセイ日本債券インデックス',
        fund_name_yomi='ディーシーニッセイニホンサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12128': FundCodeEntry(
        fund_code='G12128',
        sec_code=None,
        fund_name='ＤＣニッセイＪＰＸ日経４００アクティブ',
        fund_name_yomi='ディーシーニッセイジェイピーエックスニッケイヨンヒャクアクティブ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12131': FundCodeEntry(
        fund_code='G12131',
        sec_code=None,
        fund_name='米国ＲＥＩＴ・リサーチ・オープン\u3000為替ヘッジあり（毎月決算型）\u3000米国ＲＥＩＴ・リサーチ・オープン\u3000為替ヘッジなし（毎月決算型）',
        fund_name_yomi='ベイコクリート\u3000リサーチ\u3000オープン\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000ベイコクリート\u3000リサーチ\u3000オープン\u3000カワセヘッジナシ\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12132': FundCodeEntry(
        fund_code='G12132',
        sec_code=None,
        fund_name='米国ＲＥＩＴ・リサーチ・オープン\u3000為替ヘッジあり（年２回決算型）\u3000米国ＲＥＩＴ・リサーチ・オープン\u3000為替ヘッジなし（年２回決算型）',
        fund_name_yomi='ベイコクリート\u3000リサーチ\u3000オープン\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ\u3000ベイコクリート\u3000リサーチ\u3000オープン\u3000カワセヘッジナシ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12137': FundCodeEntry(
        fund_code='G12137',
        sec_code=None,
        fund_name='オーストラリア・リアルアセット・ファンド',
        fund_name_yomi='オーストラリアリアルアセットファンド',
        security_type='内国投資信託受益証券',
        period_1='2月3日',
        period_2='8月3日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12139': FundCodeEntry(
        fund_code='G12139',
        sec_code=None,
        fund_name='ダイワ高格付日本企業外債ファンド（為替ヘッジあり／為替ヘッジなし／部分為替ヘッジあり）２０１６‐０８',
        fund_name_yomi='ダイワコウカクヅケニホンキギョウガイサイファンドカワセヘッジアリカワセヘッジナシブブンカワセヘッジアリニセンジュウロクゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12140': FundCodeEntry(
        fund_code='G12140',
        sec_code=None,
        fund_name='インベスコ\u3000世界債券戦略ファンド',
        fund_name_yomi='インベスコセカイサイケンセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G12141': FundCodeEntry(
        fund_code='G12141',
        sec_code=None,
        fund_name='野村外国株インデックス\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラガイコクカブインデックスエーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12142': FundCodeEntry(
        fund_code='G12142',
        sec_code=None,
        fund_name='野村外国債券インデックス\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスエーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12143': FundCodeEntry(
        fund_code='G12143',
        sec_code=None,
        fund_name='野村グローバル・クオリティ・グロース\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村グローバル・クオリティ・グロース\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラグローバルクオリティグロースエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラグローバルクオリティグロースビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12144': FundCodeEntry(
        fund_code='G12144',
        sec_code=None,
        fund_name='野村ＭＦＳグローバル・リサーチ・フォーカス株式\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村ＭＦＳグローバル・リサーチ・フォーカス株式\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラエムエフエスグローバルリサーチフォーカスカブシキエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラエムエフエスグローバルリサーチフォーカスカブシキビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12145': FundCodeEntry(
        fund_code='G12145',
        sec_code=None,
        fund_name='野村ハリス外国株式バリュー戦略ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村ハリス外国株式バリュー戦略ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラハリスガイコクカブシキバリューセンリャクファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラハリスガイコクカブシキバリューセンリャクファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12147': FundCodeEntry(
        fund_code='G12147',
        sec_code=None,
        fund_name='オーストラリアＲＥＩＴファンド',
        fund_name_yomi='オーストラリアリートファンド',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G12148': FundCodeEntry(
        fund_code='G12148',
        sec_code=None,
        fund_name='ブラックロック・アメリカ大陸ロング・ショート・ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ブラックロックアメリカタイリクロングショートファンド\u3000ダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12149': FundCodeEntry(
        fund_code='G12149',
        sec_code=None,
        fund_name='ゴールドマン・サックス日本株厳選投資ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ゴールドマンサックスニホンカブゲンセントウシファンド\u3000ダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12150': FundCodeEntry(
        fund_code='G12150',
        sec_code=None,
        fund_name='ＵＢＳグローバル株式厳選投資ファンドＡコース（ダイワ投資一任専用）／Ｂコース（ダイワ投資一任専用）',
        fund_name_yomi='ユービーエスグローバルカブシキゲンセントウシファンドエーコースダイワトウシイチニンセンヨウビーコースダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12151': FundCodeEntry(
        fund_code='G12151',
        sec_code=None,
        fund_name='アムンディ円建債券アクティブ・ファンド（ダイワ投資一任専用）',
        fund_name_yomi='アムンディエンダテサイケンアクティブファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12152': FundCodeEntry(
        fund_code='G12152',
        sec_code=None,
        fund_name='フィデリティ外国債券アクティブ・ファンド\u3000Ａコース（ダイワ投資一任専用）\u3000フィデリティ外国債券アクティブ・ファンド\u3000Ｂコース（ダイワ投資一任専用）',
        fund_name_yomi='フィデリティガイコクサイケンアクティブファンドエーコースダイワトウシイチニンセンヨウ\u3000フィデリティガイコクサイケンアクティブファンドビーコースダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12153': FundCodeEntry(
        fund_code='G12153',
        sec_code=None,
        fund_name='セキュリティ関連日本株ファンド',
        fund_name_yomi='セキュリティカンレンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月12日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12156': FundCodeEntry(
        fund_code='G12156',
        sec_code=None,
        fund_name='ＳＭＴ\u3000米国株配当貴族インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ベイコクカブハイトウキゾクインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12157': FundCodeEntry(
        fund_code='G12157',
        sec_code=None,
        fund_name='ＳＭＴ\u3000日本株配当貴族インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ニホンカブハイトウキゾクインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12161': FundCodeEntry(
        fund_code='G12161',
        sec_code=None,
        fund_name='ダイワ日本成長株ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ダイワニホンセイチョウカブファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12162': FundCodeEntry(
        fund_code='G12162',
        sec_code=None,
        fund_name='ダイワ／ＪＰＭオルタナティブ戦略オープン（ダイワ投資一任専用）',
        fund_name_yomi='ダイワジェイピーエムオルタナティブセンリャクオープンダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12163': FundCodeEntry(
        fund_code='G12163',
        sec_code=None,
        fund_name='ダイワファンドラップ\u3000インデックス・シリーズ',
        fund_name_yomi='ダイワファンドラップインデックスシリーズ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12164': FundCodeEntry(
        fund_code='G12164',
        sec_code=None,
        fund_name='ダイワファンドラップ\u3000インデックスプラス・シリーズ',
        fund_name_yomi='ダイワファンドラップインデックスプラスシリーズ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12165': FundCodeEntry(
        fund_code='G12165',
        sec_code=None,
        fund_name='りそな・ストラテジック・インカムファンド２０１６－０９（為替ヘッジあり）、りそな・ストラテジック・インカムファンド２０１６－０９（為替ヘッジなし）',
        fund_name_yomi='リソナストラテジックインカムファンドニセンジュウロクノゼロキュウカワセヘッジアリ\u3000リソナストラテジックインカムファンドニセンジュウロクノゼロキュウカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12166': FundCodeEntry(
        fund_code='G12166',
        sec_code=None,
        fund_name='あしぎん世界コーポレート・ハイブリッド証券ファンド２０１６－０９',
        fund_name_yomi='アシギンセカイコーポレートハイブリッドショウケンファンドニイゼロイチロクゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12171': FundCodeEntry(
        fund_code='G12171',
        sec_code=None,
        fund_name='ロボット戦略\u3000世界分散ファンド',
        fund_name_yomi='ロボットセンリャク\u3000セカイブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G12172': FundCodeEntry(
        fund_code='G12172',
        sec_code=None,
        fund_name='ＧＳエマージング通貨債券ファンド（米ドル売り円買い）',
        fund_name_yomi='ジーエスエマージングツウカサイケンファンド\u3000ベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12173': FundCodeEntry(
        fund_code='G12173',
        sec_code='14870',
        fund_name='上場インデックスファンド米国債券（為替ヘッジあり）',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクサイケン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12174': FundCodeEntry(
        fund_code='G12174',
        sec_code='14860',
        fund_name='上場インデックスファンド米国債券（為替ヘッジなし）',
        fund_name_yomi='ジョウジヨウインデックスファンドベイコクサケン\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12176': FundCodeEntry(
        fund_code='G12176',
        sec_code=None,
        fund_name='ピムコ・バーミューダ・トラスト－ピムコ\u3000ショート・ターム\u3000ストラテジー',
        fund_name_yomi='ピムコバーミューダトラスト\u3000ピムコショートタームストラテジー',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G12177': FundCodeEntry(
        fund_code='G12177',
        sec_code=None,
        fund_name='グローバルＡＩファンド',
        fund_name_yomi='グローバルエーアイファンド',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12178': FundCodeEntry(
        fund_code='G12178',
        sec_code=None,
        fund_name='豪州インフラ関連好配当資産ファンド\u3000為替ヘッジあり\u3000（毎月決算型）、豪州インフラ関連好配当資産ファンド\u3000為替ヘッジあり\u3000（年２回決算型）',
        fund_name_yomi='ゴウシュウインフラカンレンコウハイトウシサンファンドカワセヘッジアリマイツキケッサンガタ\u3000ゴウシュウインフラカンレンコウハイトウシサンファンドカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12181': FundCodeEntry(
        fund_code='G12181',
        sec_code=None,
        fund_name='ニッセイ／ＡＥＷ・ＵＳリートファンド為替ヘッジあり（年１回決算型）\u3000／\u3000ニッセイ／ＡＥＷ・ＵＳリートファンド為替ヘッジなし（年１回決算型）',
        fund_name_yomi='ニッセイエーイーダブリューユーエスリートファンドカワセヘッジアリネンイッカイケッサンガタ\u3000ニッセイエーイーダブリューユーエスリートファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12183': FundCodeEntry(
        fund_code='G12183',
        sec_code=None,
        fund_name='マニュライフ・日系企業外貨建社債ファンド\u3000２０１６‐０９（為替ヘッジあり／限定追加型）',
        fund_name_yomi='マニュライフ\u3000ニッケイキギョウガイカダテシャサイファンド\u3000カワセヘッジアリ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12188': FundCodeEntry(
        fund_code='G12188',
        sec_code=None,
        fund_name='インベスコ\u3000欧州インカム資産ファンド（毎月決算型）',
        fund_name_yomi='インベスコオウシュウインカムシサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G12189': FundCodeEntry(
        fund_code='G12189',
        sec_code=None,
        fund_name='ダイワ日本株ニュートラル・ファンド２０１６‐０９',
        fund_name_yomi='ダイワニホンカブニュートラルファンドニセンジュウロクゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12192': FundCodeEntry(
        fund_code='G12192',
        sec_code=None,
        fund_name='パッシム・トラスト\u3000‐\u3000シリーズ２０１６\u3000ＴＯＰＩＸファンド',
        fund_name_yomi='パッシムトラストシリーズニセンジュウロクトピックスファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E30829',
        issuer_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
    ),
    'G12193': FundCodeEntry(
        fund_code='G12193',
        sec_code=None,
        fund_name='スパークス・日本株式ファンド（ラップ向け）',
        fund_name_yomi='スパークスニホンカブシキファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12196': FundCodeEntry(
        fund_code='G12196',
        sec_code=None,
        fund_name='パッシム・トラスト\u3000－\u3000豪ドル建て償還時ターゲット債券ファンド２０１６０９',
        fund_name_yomi='ゴウドルダテショウカンジターゲットサイケンファンドニセンジュウロクレイキュウ',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E30829',
        issuer_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
    ),
    'G12198': FundCodeEntry(
        fund_code='G12198',
        sec_code=None,
        fund_name='スパークス・日本中小型株式ファンド（ラップ向け）',
        fund_name_yomi='スパークス\u3000ニホンチュウコガタカブシキファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12199': FundCodeEntry(
        fund_code='G12199',
        sec_code=None,
        fund_name='クレディ・スイス・ユニバーサル・トラスト（ケイマン）Ⅲ－オーストラリア・リート・ファンド',
        fund_name_yomi='クレディスイスユニバーサルトラストケイマンスリーオーストラリアリートファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G12200': FundCodeEntry(
        fund_code='G12200',
        sec_code=None,
        fund_name='クレディ・スイス・ユニバーサル・トラスト（ケイマン）Ⅲ－オーストラリア・リート・プラス',
        fund_name_yomi='クレディスイスユニバーサルトラストケイマンスリーオーストラリアリートプラス',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G12201': FundCodeEntry(
        fund_code='G12201',
        sec_code=None,
        fund_name='ステート・ストリート日本株式最小分散インデックス・オープン',
        fund_name_yomi='ステートストリートニホンカブシキサイショウブンサンインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12202': FundCodeEntry(
        fund_code='G12202',
        sec_code=None,
        fund_name='ステート・ストリート先進国株式・低ボラティリティ・アルファ・オープン',
        fund_name_yomi='ステートストリートセンシンコクカブシキテイボラティリティアルファオープン',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12203': FundCodeEntry(
        fund_code='G12203',
        sec_code=None,
        fund_name='ステート・ストリート先進国株式・低ボラティリティ・アルファ・オープン（為替ヘッジあり）',
        fund_name_yomi='ステートストリートセンシンコクカブシキテイボラティリティアルファオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12204': FundCodeEntry(
        fund_code='G12204',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000ＪＰＸ日経４００インデックス',
        fund_name_yomi='アイフリージェイピーエックスニッケイヨンヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12205': FundCodeEntry(
        fund_code='G12205',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000ＴＯＰＩＸインデックス',
        fund_name_yomi='アイフリートピックスインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12206': FundCodeEntry(
        fund_code='G12206',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000日経２２５インデックス',
        fund_name_yomi='アイフリーニッケイニイニイゴインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12207': FundCodeEntry(
        fund_code='G12207',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000外国株式インデックス（為替ヘッジなし）',
        fund_name_yomi='アイフリーガイコクカブシキインデックスカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12208': FundCodeEntry(
        fund_code='G12208',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000ＮＹダウ・インデックス',
        fund_name_yomi='アイフリーニューヨークダウインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12209': FundCodeEntry(
        fund_code='G12209',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000新興国株式インデックス',
        fund_name_yomi='アイフリーシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12210': FundCodeEntry(
        fund_code='G12210',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000日本債券インデックス',
        fund_name_yomi='アイフリーニホンサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12211': FundCodeEntry(
        fund_code='G12211',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000外国債券インデックス',
        fund_name_yomi='アイフリーガイコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12212': FundCodeEntry(
        fund_code='G12212',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000新興国債券インデックス',
        fund_name_yomi='アイフリーシンコウコクサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12213': FundCodeEntry(
        fund_code='G12213',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000Ｊ－ＲＥＩＴインデックス',
        fund_name_yomi='アイフリージェイリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12214': FundCodeEntry(
        fund_code='G12214',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000外国ＲＥＩＴインデックス',
        fund_name_yomi='アイフリーガイコクリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12215': FundCodeEntry(
        fund_code='G12215',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000８資産バランス',
        fund_name_yomi='アイフリーハチシサンバランス',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12216': FundCodeEntry(
        fund_code='G12216',
        sec_code=None,
        fund_name='イオン・バランス戦略ファンド',
        fund_name_yomi='イオンバランスセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12217': FundCodeEntry(
        fund_code='G12217',
        sec_code=None,
        fund_name='インカム資産オープン（アジア・オセアニア）',
        fund_name_yomi='インカムシサンオープンアジアオセアニア',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12218': FundCodeEntry(
        fund_code='G12218',
        sec_code=None,
        fund_name='オフショア・ストラテジー・ファンド－オーストラリア高配当株ファンド',
        fund_name_yomi='オフショアストラテジーファンドオーストラリアコウハイトウカブファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14984',
        issuer_name='インターナショナル・マネジメント・サービシズ・リミテッド',
    ),
    'G12220': FundCodeEntry(
        fund_code='G12220',
        sec_code=None,
        fund_name='ダイワ米国債ＲＣ運用ファンド・リスク抑制型（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワベイコクサイアールシーウンヨウファンドリスクヨクセイガタダイワエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12221': FundCodeEntry(
        fund_code='G12221',
        sec_code=None,
        fund_name='楽天グローバル株式ファンド',
        fund_name_yomi='ラクテングローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12222': FundCodeEntry(
        fund_code='G12222',
        sec_code=None,
        fund_name='楽天エマージング株式ファンド',
        fund_name_yomi='ラクテンエマージングカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12223': FundCodeEntry(
        fund_code='G12223',
        sec_code=None,
        fund_name='楽天・世界債券（為替ヘッジ付）ファンド',
        fund_name_yomi='ラクテンセカイサイケンカワセヘッジツキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12224': FundCodeEntry(
        fund_code='G12224',
        sec_code=None,
        fund_name='むさしのコア投資ファンド（安定型）／むさしのコア投資ファンド（成長型）',
        fund_name_yomi='ムサシノコアトウシファンドアンテイガタ\u3000ムサシノコアトウシファンドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G12225': FundCodeEntry(
        fund_code='G12225',
        sec_code=None,
        fund_name='マニュライフ・ストラテジック・インカム・ファンド（為替ヘッジあり）＜ラップ＞、マニュライフ・ストラテジック・インカム・ファンド（為替ヘッジなし）＜ラップ＞',
        fund_name_yomi='マニュライフストラテジックインカムファンドカワセヘッジアリラップ\u3000マニュライフストラテジックインカムファンドカワセヘッジナシラップ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12226': FundCodeEntry(
        fund_code='G12226',
        sec_code=None,
        fund_name='グローバル・ハイクオリティ成長株式ファンド（限定為替ヘッジ）、グローバル・ハイクオリティ成長株式ファンド（為替ヘッジなし）',
        fund_name_yomi='グローバルハイクオリティセイチョウカブシキファンドゲンテイカワセヘッジ\u3000グローバルハイクオリティセイチョウカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12227': FundCodeEntry(
        fund_code='G12227',
        sec_code=None,
        fund_name='ニッセイＲＯＥフォーカス先進国株式ファンド（３ヵ月決算型・為替ヘッジあり）／ニッセイＲＯＥフォーカス先進国株式ファンド（３ヵ月決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイアールオーイーフォーカスセンシンコクカブシキファンドサンカゲツケッサンガタカワセヘッジアリ\u3000ニッセイアールオーイーフォーカスセンシンコクカブシキファンドサンカゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12228': FundCodeEntry(
        fund_code='G12228',
        sec_code=None,
        fund_name='フィデリティ・Ｊリート・アクティブ・ファンド（資産成長型）',
        fund_name_yomi='フィデリティジェイリートアクティブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12229': FundCodeEntry(
        fund_code='G12229',
        sec_code=None,
        fund_name='ＢＮＹメロン・リアル・リターン・ファンド（ＳＭＡ向け）（為替ヘッジあり）',
        fund_name_yomi='ビーエヌワイメロンリアルリターンファンドエスエムエームケカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12230': FundCodeEntry(
        fund_code='G12230',
        sec_code=None,
        fund_name='三井住友・ＤＣ外国リートインデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーガイコクリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12231': FundCodeEntry(
        fund_code='G12231',
        sec_code=None,
        fund_name='三井住友・ＤＣ日本リートインデックスファンド',
        fund_name_yomi='ミツイスミトモディーシーニホンリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12233': FundCodeEntry(
        fund_code='G12233',
        sec_code=None,
        fund_name='日系企業海外債券オープン（為替ヘッジあり）（ＳＭＡ専用）',
        fund_name_yomi='ニッケイキギョウカイガイサイケンオープンカワセヘッジアリエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12236': FundCodeEntry(
        fund_code='G12236',
        sec_code=None,
        fund_name='トヨタモータークレジット／トヨタグループ債券ファンド',
        fund_name_yomi='トヨタモータークレジットトヨタグループサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12237': FundCodeEntry(
        fund_code='G12237',
        sec_code=None,
        fund_name='ひふみ年金',
        fund_name_yomi='ヒフミネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G12238': FundCodeEntry(
        fund_code='G12238',
        sec_code=None,
        fund_name='ＤＣ米国連続増配成長株オープン',
        fund_name_yomi='ディーシーベイコクレンゾクゾウハイセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12239': FundCodeEntry(
        fund_code='G12239',
        sec_code=None,
        fund_name='ニッセイ／ＭＦＳ外国株低ボラティリティ運用ファンド',
        fund_name_yomi='ニッセイエムエフエスガイコクカブテイボラティリティウンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='12月8日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12240': FundCodeEntry(
        fund_code='G12240',
        sec_code=None,
        fund_name='東京海上・日経２２５インデックスファンド',
        fund_name_yomi='トウキョウカイジョウニッケイニーニーゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月6日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12242': FundCodeEntry(
        fund_code='G12242',
        sec_code=None,
        fund_name='ＤＣ日本連続増配成長株オープン',
        fund_name_yomi='ディーシーニホンレンゾクゾウハイセイチョウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12243': FundCodeEntry(
        fund_code='G12243',
        sec_code=None,
        fund_name='ＤＣ日本Ｊリートオープン',
        fund_name_yomi='ディーシーニホンジェイリートオープン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12244': FundCodeEntry(
        fund_code='G12244',
        sec_code=None,
        fund_name='楽天ターゲットイヤー２０３０／楽天ターゲットイヤー２０４０／楽天ターゲットイヤー２０５０',
        fund_name_yomi='ラクテンターゲットイヤーニセンサンジュウ\u3000ラクテンターゲットイヤーニセンヨンジュウ\u3000ラクテンターゲットイヤーニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12246': FundCodeEntry(
        fund_code='G12246',
        sec_code=None,
        fund_name='パッシム・トラスト\u3000‐\u3000シリーズ２０１６日経２２５ファンド',
        fund_name_yomi='パッシムトラストシリーズニセンジュウロクニッケイニニゴファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E30829',
        issuer_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
    ),
    'G12247': FundCodeEntry(
        fund_code='G12247',
        sec_code=None,
        fund_name='フィデリティ・日本配当成長株・ファンド（資産成長型）',
        fund_name_yomi='フィデリティニホンハイトウセイチョウカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12248': FundCodeEntry(
        fund_code='G12248',
        sec_code=None,
        fund_name='ＢＮＹメロン・日本株式ダイナミック戦略ファンド',
        fund_name_yomi='ビーエヌワイメロンニッポンカブシキダイナミックセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12249': FundCodeEntry(
        fund_code='G12249',
        sec_code=None,
        fund_name='東京海上・グローバルヘルスケアＲＥＩＴオープン（為替ヘッジあり）（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウグローバルヘルスケアリートオープンカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12250': FundCodeEntry(
        fund_code='G12250',
        sec_code=None,
        fund_name='東京海上・グローバルヘルスケアＲＥＩＴオープン（為替ヘッジあり）（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウグローバルヘルスケアリートオープンカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12251': FundCodeEntry(
        fund_code='G12251',
        sec_code=None,
        fund_name='ダイワ世界有力企業外債ファンド（為替ヘッジあり／部分為替ヘッジあり）２０１６－１０',
        fund_name_yomi='ダイワセカイユウリョクキギョウガイサイファンドカワセヘッジアリブブンカワセヘッジアリニセンジュウロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12252': FundCodeEntry(
        fund_code='G12252',
        sec_code=None,
        fund_name='ダイワ米国投資法人債ファンド（為替ヘッジあり）２０１６－１０',
        fund_name_yomi='ダイワベイコクトウシホウジンサイファンドカワセヘッジアリニゼンジュウロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12253': FundCodeEntry(
        fund_code='G12253',
        sec_code=None,
        fund_name='ロボット・テクノロジー関連株ファンド\u3000－ロボテック－（為替ヘッジあり）',
        fund_name_yomi='ロボットテクノロジーカンレンカブファンドロボテックカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12254': FundCodeEntry(
        fund_code='G12254',
        sec_code=None,
        fund_name='ロボット・テクノロジー関連株ファンド（年１回決算型）\u3000－ロボテック（年１回）－（為替ヘッジあり）',
        fund_name_yomi='ロボットテクノロジーカンレンカブファンドネンイッカイケッサンガタロボテックネンイッカイカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12255': FundCodeEntry(
        fund_code='G12255',
        sec_code=None,
        fund_name='優先リート・オープン（為替ヘッジあり）',
        fund_name_yomi='ユウセンリートオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12261': FundCodeEntry(
        fund_code='G12261',
        sec_code=None,
        fund_name='みのりの投信（確定拠出年金専用）',
        fund_name_yomi='ミノリノトウシン\u3000カクテイキョシュツネンキンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E27426',
        issuer_name='株式会社ポートフォリア',
    ),
    'G12262': FundCodeEntry(
        fund_code='G12262',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国株式＜為替ヘッジあり＞',
        fund_name_yomi='タワラノーロードセンシンコクカブシキカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12263': FundCodeEntry(
        fund_code='G12263',
        sec_code=None,
        fund_name='野村ファンドラップ債券プレミア',
        fund_name_yomi='ノムラファンドラップサイケンプレミア',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12264': FundCodeEntry(
        fund_code='G12264',
        sec_code=None,
        fund_name='野村ファンドラップＲＥＩＴプレミア\u3000Ａコース、野村ファンドラップＲＥＩＴプレミア\u3000Ｂコース',
        fund_name_yomi='ノムラファンドラップリートプレミアエーコース\u3000ノムラファンドラップリートプレミアビーコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12265': FundCodeEntry(
        fund_code='G12265',
        sec_code=None,
        fund_name='野村ファンドラップオルタナティブプレミア',
        fund_name_yomi='ノムラファンドラップオルタナティブプレミア',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12266': FundCodeEntry(
        fund_code='G12266',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国債券＜為替ヘッジあり＞',
        fund_name_yomi='タワラノーロードセンシンコクサイケンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12268': FundCodeEntry(
        fund_code='G12268',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）日本株式',
        fund_name_yomi='ファンドラップウエルススクエアニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12269': FundCodeEntry(
        fund_code='G12269',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）外国株式',
        fund_name_yomi='ファンドラップウエルススクエアガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12270': FundCodeEntry(
        fund_code='G12270',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）債券・安定型',
        fund_name_yomi='ファンドラップウエルススクエアサイケンアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12271': FundCodeEntry(
        fund_code='G12271',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）債券・成長型',
        fund_name_yomi='ファンドラップウエルススクエアサイケンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12272': FundCodeEntry(
        fund_code='G12272',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）外国債券',
        fund_name_yomi='ファンドラップウエルススクエアガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12273': FundCodeEntry(
        fund_code='G12273',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）ＲＥＩＴ',
        fund_name_yomi='ファンドラップウエルススクエアリート',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12274': FundCodeEntry(
        fund_code='G12274',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）オルタナティブ',
        fund_name_yomi='ファンドラップウエルススクエアオルタナティブ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12276': FundCodeEntry(
        fund_code='G12276',
        sec_code='92820',
        fund_name='いちごグリーンインフラ投資法人',
        fund_name_yomi='イチゴグリーンインフラトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E32725',
        issuer_name='いちごグリーンインフラ投資法人',
    ),
    'G12277': FundCodeEntry(
        fund_code='G12277',
        sec_code=None,
        fund_name='ＹＭアセット・好配当日本株ファンド',
        fund_name_yomi='ワイエムアセットコウハイトウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月1日',
        period_2=None,
        edinet_code='E32437',
        issuer_name='ワイエムアセットマネジメント株式会社',
    ),
    'G12278': FundCodeEntry(
        fund_code='G12278',
        sec_code=None,
        fund_name='ＳＯＭＰＯ外国株式アクティブバリューファンド（リスク抑制型）',
        fund_name_yomi='ソンポガイコクカブシキアクティブバリューファンドリスクヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12279': FundCodeEntry(
        fund_code='G12279',
        sec_code=None,
        fund_name='好循環社会促進日本株ファンド',
        fund_name_yomi='コウジュンカンシャカイソクシンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12280': FundCodeEntry(
        fund_code='G12280',
        sec_code=None,
        fund_name='ＳＯＭＰＯ日本株バリュー・プラスファンド',
        fund_name_yomi='ソンポニホンカブバリュープラスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12281': FundCodeEntry(
        fund_code='G12281',
        sec_code=None,
        fund_name='ＳＯＭＰＯ\u3000Ｊリートファンド',
        fund_name_yomi='ソンポ\u3000ジェイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12282': FundCodeEntry(
        fund_code='G12282',
        sec_code=None,
        fund_name='ＳＯＭＰＯターゲットイヤー・ファンド２０５５\u3000ＳＯＭＰＯターゲットイヤー・ファンド２０４５\u3000ＳＯＭＰＯターゲットイヤー・ファンド２０３５',
        fund_name_yomi='ソンポターゲットイヤーファンドニイゼロゴウゴウ\u3000ソンポターゲットイヤーファンドニイゼロヨンゴウ\u3000ソンポターゲットイヤーファンドニイゼロサンゴウ',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12285': FundCodeEntry(
        fund_code='G12285',
        sec_code=None,
        fund_name='マニュライフ・カナダ・リート・ファンド\u3000Ａコース（為替ヘッジあり・毎月）、マニュライフ・カナダ・リート・ファンド\u3000Ｂコース（為替ヘッジなし・毎月）、マニュライフ・カナダ・リート・ファンド\u3000Ｃコース（為替ヘッジあり・年２回）、マニュライフ・カナダ・リート・ファンド\u3000Ｄコース（為替ヘッジなし・年２回）',
        fund_name_yomi='マニュライフカナダリートファンドエイコースカワセヘッジアリマイツキ\u3000マニュライフカナダリートファンドビーコースカワセヘッジナシマイツキ\u3000マニュライフカナダリートファンドシーコースカワセヘッジアリネンニカイ\u3000マニュライフカナダリートファンドディーコースカワセヘッジナシネンニカイ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12286': FundCodeEntry(
        fund_code='G12286',
        sec_code=None,
        fund_name='ＪＰ日米バランスファンド',
        fund_name_yomi='ジェイピーニチベイバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E32151',
        issuer_name='ＪＰ投信株式会社',
    ),
    'G12288': FundCodeEntry(
        fund_code='G12288',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－米国・地方公共事業債ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーベイコクチホウコウキョウジギョウサイファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G12289': FundCodeEntry(
        fund_code='G12289',
        sec_code=None,
        fund_name='ＤＣニッセイＪ－ＲＥＩＴインデックスファンドＡ',
        fund_name_yomi='ディーシーニッセイジェイリートインデックスファンドエー',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12290': FundCodeEntry(
        fund_code='G12290',
        sec_code=None,
        fund_name='ＤＣニッセイ日経２２５インデックスファンドＡ',
        fund_name_yomi='ディーシーニッセイニッケイニーニーゴインデックスファンドエー',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12292': FundCodeEntry(
        fund_code='G12292',
        sec_code=None,
        fund_name='世界株配当収益追求ファンド（価格変動抑制型）',
        fund_name_yomi='セカイカブハイトウシュウエキツイキュウファンドカカクヘンドウヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12293': FundCodeEntry(
        fund_code='G12293',
        sec_code=None,
        fund_name='日本配当追求株ファンド（価格変動抑制型）',
        fund_name_yomi='ニホンハイトウツイキュウカブファンドカカクヘンドウヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12294': FundCodeEntry(
        fund_code='G12294',
        sec_code=None,
        fund_name='新興国通貨建て世界銀行債券オープン',
        fund_name_yomi='シンコウコクツウカダテセカイギンコウサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12295': FundCodeEntry(
        fund_code='G12295',
        sec_code='14880',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000東証ＲＥＩＴ指数',
        fund_name_yomi='アイフリーイーティーエフトウショウリートシスウ',
        security_type='内国投資信託受益証券',
        period_1='3月4日',
        period_2='9月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12297': FundCodeEntry(
        fund_code='G12297',
        sec_code=None,
        fund_name='時間分散型バランスファンド（安定指向）２０１６－１１',
        fund_name_yomi='ジカンブンサンガタバランスファンド\u3000アンテイシコウ\u3000ニーゼロイチロク\u3000イチイチ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12299': FundCodeEntry(
        fund_code='G12299',
        sec_code=None,
        fund_name='リスク抑制世界８資産バランスファンド',
        fund_name_yomi='リスクヨクセイセカイハチシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12304': FundCodeEntry(
        fund_code='G12304',
        sec_code=None,
        fund_name='ＤＣニッセイ日経２２５インデックスファンドＢ',
        fund_name_yomi='ディーシーニッセイニッケイニーニーゴインデックスファンドビー',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12305': FundCodeEntry(
        fund_code='G12305',
        sec_code=None,
        fund_name='ＤＣニッセイＪ－ＲＥＩＴインデックスファンドＢ',
        fund_name_yomi='ディーシーニッセイジェイリートインデックスファンドビー',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12306': FundCodeEntry(
        fund_code='G12306',
        sec_code=None,
        fund_name='三井住友ＤＳ・ＤＣターゲットイヤーファンド２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５／２０７０',
        fund_name_yomi='ミツイスミトモディーエスディーシーターゲットイヤーファンドニイゼロサンゴニイゼロヨンゼロニイゼロヨンゴニイゼロゴゼロニイゼロゴゴニイゼロロクゼロニイゼロロクゴニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12307': FundCodeEntry(
        fund_code='G12307',
        sec_code=None,
        fund_name='ダイワ・グローバル金融機関（Ｇ－ＳＩＢｓ）債券ファンド２０１６－１１',
        fund_name_yomi='ダイワグローバルキンユウキカンジーシブズサイケンファンドニセンジュウロクイチイチ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12308': FundCodeEntry(
        fund_code='G12308',
        sec_code='34760',
        fund_name='投資法人みらい',
        fund_name_yomi='トウシホウジンミライ',
        security_type='内国投資証券',
        period_1='10月末日',
        period_2='4月末日',
        edinet_code='E32744',
        issuer_name='投資法人みらい',
    ),
    'G12311': FundCodeEntry(
        fund_code='G12311',
        sec_code=None,
        fund_name='米国バリュー・ストラテジー・ファンド\u3000Ａコース、米国バリュー・ストラテジー・ファンド\u3000Ｂコース',
        fund_name_yomi='ベイコクバリューストラテジーファンドエーコース\u3000ベイコクバリューストラテジーファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12312': FundCodeEntry(
        fund_code='G12312',
        sec_code=None,
        fund_name='ＢＮＹメロン・グローバル好利回りＣＢファンド２０１６－１１（円ヘッジ）（限定追加型）',
        fund_name_yomi='ビーエヌワイメロングローバルコウリマワリシービーファンドニイゼロイチロクイチイチエンヘッジゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月27日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12314': FundCodeEntry(
        fund_code='G12314',
        sec_code=None,
        fund_name='ニッセイＡＩ関連株式ファンド（為替ヘッジあり）／ニッセイＡＩ関連株式ファンド（為替ヘッジなし）',
        fund_name_yomi='ニッセイエーアイカンレンカブシキファンドカワセヘッジアリ\u3000ニッセイエーアイカンレンカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12316': FundCodeEntry(
        fund_code='G12316',
        sec_code=None,
        fund_name='ＵＳテクノロジー・イノベーターズ・ファンド（為替ヘッジあり）',
        fund_name_yomi='ユーエステクノロジーイノベーターズファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12318': FundCodeEntry(
        fund_code='G12318',
        sec_code=None,
        fund_name='りそな・ストラテジック・インカムファンド２０１６－１２（為替ヘッジあり）、りそな・ストラテジック・インカムファンド２０１６－１２（為替ヘッジなし）',
        fund_name_yomi='リソナストラテジックインカムファンドニセンジュウロクノジュウニカワセヘッジアリ\u3000リソナストラテジックインカムファンドニセンジュウロクノジュウニカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12320': FundCodeEntry(
        fund_code='G12320',
        sec_code=None,
        fund_name='ニッセイ日経平均インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイニッケイヘイキンインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12321': FundCodeEntry(
        fund_code='G12321',
        sec_code=None,
        fund_name='新生・ワールドラップ・セレクト',
        fund_name_yomi='シンセイ\u3000ワールドラップ\u3000セレクト',
        security_type='内国投資信託受益証券',
        period_1='8月13日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12322': FundCodeEntry(
        fund_code='G12322',
        sec_code=None,
        fund_name='ベトナム・ロータス・ファンド',
        fund_name_yomi='ベトナムロータスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G12325': FundCodeEntry(
        fund_code='G12325',
        sec_code=None,
        fund_name='フィデリティ世界医療機器関連株ファンド（為替ヘッジあり）\u3000フィデリティ世界医療機器関連株ファンド（為替ヘッジなし）',
        fund_name_yomi='フィデリティセカイイリョウキキカンレンカブファンドカワセヘッジアリ\u3000フィデリティセカイイリョウキキカンレンカブファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12328': FundCodeEntry(
        fund_code='G12328',
        sec_code=None,
        fund_name='世界中小型株式ファンド',
        fund_name_yomi='セカイチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12332': FundCodeEntry(
        fund_code='G12332',
        sec_code=None,
        fund_name='グローバル・ヘルスケア＆バイオ・ファンド（為替ヘッジあり）',
        fund_name_yomi='グローバルヘルスケアアンドバイオファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12333': FundCodeEntry(
        fund_code='G12333',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信ＡＩプラス',
        fund_name_yomi='ペイペイトウシンエーアイプラス',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12334': FundCodeEntry(
        fund_code='G12334',
        sec_code=None,
        fund_name='楽天日本新興市場株ダブル・ブル',
        fund_name_yomi='ラクテンニホンシンコウシジョウカブダブルブル',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12337': FundCodeEntry(
        fund_code='G12337',
        sec_code=None,
        fund_name='グローバル・フィンテック株式ファンド',
        fund_name_yomi='グローバル\u3000フィンテックカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12338': FundCodeEntry(
        fund_code='G12338',
        sec_code=None,
        fund_name='スマート・プロテクター９０（限定追加型）２０１６－１２',
        fund_name_yomi='スマートプロテクターキュウジュウゲンテイツイカガタニセンジュウロクノジュウニ',
        security_type='内国投資信託受益証券',
        period_1='12月28日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12340': FundCodeEntry(
        fund_code='G12340',
        sec_code=None,
        fund_name='ＳＢＩスリランカ短期国債ファンド（毎月決算型）\u3000ＳＢＩスリランカ短期国債ファンド（年２回決算型）',
        fund_name_yomi='エスビーアイ\u3000スリランカ\u3000タンキコクサイファンド\u3000マイツキケッサンガタ\u3000エスビーアイ\u3000スリランカ\u3000タンキコクサイファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12342': FundCodeEntry(
        fund_code='G12342',
        sec_code=None,
        fund_name='外貨建て日系債券ファンド１７－０１（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ガイカダテニッケイサイケンファンドイチナナゼロイチカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12345': FundCodeEntry(
        fund_code='G12345',
        sec_code=None,
        fund_name='ブラックロック・ＢＥＳＴ（為替ヘッジあり／年２回決算型）',
        fund_name_yomi='ブラックロックベスト\u3000カワセヘッジアリ\u3000ネンニカイケッサン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12347': FundCodeEntry(
        fund_code='G12347',
        sec_code=None,
        fund_name='日本厳選中小型株ファンド',
        fund_name_yomi='ニホンゲンセンチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12349': FundCodeEntry(
        fund_code='G12349',
        sec_code=None,
        fund_name='ドイチェ・ＥＴＦアロケーション・ファンド（安定型）／（成長型）',
        fund_name_yomi='ドイチェイーティーエフアロケーションファンドアンテイガタ\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月7日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G12352': FundCodeEntry(
        fund_code='G12352',
        sec_code=None,
        fund_name='次世代米国代表株ファンド（為替ヘッジあり）',
        fund_name_yomi='ジセダイベイコクダイヒョウカブファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12355': FundCodeEntry(
        fund_code='G12355',
        sec_code=None,
        fund_name='ノーロード明治安田日本株式アクティブ',
        fund_name_yomi='ノーロードメイジヤスダニホンカブシキアクティブ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12356': FundCodeEntry(
        fund_code='G12356',
        sec_code=None,
        fund_name='ノーロード明治安田社債アクティブ',
        fund_name_yomi='ノーロードメイジヤスダシャサイアクティブ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12357': FundCodeEntry(
        fund_code='G12357',
        sec_code=None,
        fund_name='ノーロード明治安田Ｊ－ＲＥＩＴアクティブ',
        fund_name_yomi='ノーロードメイジヤスダジェイリートアクティブ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12358': FundCodeEntry(
        fund_code='G12358',
        sec_code=None,
        fund_name='ノーロード明治安田円資産バランス',
        fund_name_yomi='ノーロードメイジヤスダエンシサンバランス',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12359': FundCodeEntry(
        fund_code='G12359',
        sec_code=None,
        fund_name='ノーロード明治安田５資産バランス（安定コース）／（安定成長コース）／（積極コース）',
        fund_name_yomi='ノーロードメイジヤスダゴシサンバランス\u3000アンテイコース\u3000アンテイセイチョウコース\u3000セッキョクコース',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12360': FundCodeEntry(
        fund_code='G12360',
        sec_code=None,
        fund_name='パッシム・トラスト\u3000－\u3000豪ドル建て償還時ターゲット債券ファンド２０１６１２',
        fund_name_yomi='パッシムトラストゴウドルダテショウカンジターゲットサイケンファンドニセンジュウロクジュウニ',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E30829',
        issuer_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
    ),
    'G12361': FundCodeEntry(
        fund_code='G12361',
        sec_code=None,
        fund_name='スイス・グローバル・リーダー・ファンド（為替ヘッジあり）',
        fund_name_yomi='スイスグローバルリーダーファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月4日',
        period_2='12月4日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12362': FundCodeEntry(
        fund_code='G12362',
        sec_code=None,
        fund_name='ニッセイ米国不動産投資法人債ファンド（毎月決算型・為替ヘッジあり）／ニッセイ米国不動産投資法人債ファンド（毎月決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイベイコクフドウサントウシホウジンサイファンドマイツキケッサンガタカワセヘッジアリ\u3000ニッセイベイコクフドウサントウシホウジンサイファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12363': FundCodeEntry(
        fund_code='G12363',
        sec_code=None,
        fund_name='ニッセイ米国不動産投資法人債ファンド（年２回決算型・為替ヘッジあり）／ニッセイ米国不動産投資法人債ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイベイコクフドウサントウシホウジンサイファンドネンニカイケッサンガタカワセヘッジアリ\u3000ニッセイベイコクフドウサントウシホウジンサイファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12364': FundCodeEntry(
        fund_code='G12364',
        sec_code=None,
        fund_name='ＪＰＭ日本ＣＢファンド／ＪＰＭ日本ＣＢファンド（米ドル投資型）',
        fund_name_yomi='ジェイピーエムニホンシービーファンド\u3000ジェイピーエムニホンシービーファンドベイドルトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G12365': FundCodeEntry(
        fund_code='G12365',
        sec_code=None,
        fund_name='ダイワ日本企業外債ファンドＳ（為替ヘッジあり／部分為替ヘッジあり）２０１６‐１２',
        fund_name_yomi='ダイワニホンキギョウガイサイファンドエスカワセヘッジアリブブンカワセヘッジアリニセンジュウロクイチニ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12366': FundCodeEntry(
        fund_code='G12366',
        sec_code=None,
        fund_name='ワールドアセットバランス（基本コース）、ワールドアセットバランス（リスク抑制コース）',
        fund_name_yomi='ワールドアセットバランスキホンコース\u3000ワールドアセットバランスリスクヨクセイコース',
        security_type='内国投資信託受益証券',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12368': FundCodeEntry(
        fund_code='G12368',
        sec_code=None,
        fund_name='債券コア・セレクション',
        fund_name_yomi='サイケンコア\u3000セレクション',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12369': FundCodeEntry(
        fund_code='G12369',
        sec_code=None,
        fund_name='日本再生可能エネルギーインフラ投資法人',
        fund_name_yomi='ニホンサイセイカノウエネルギーインフラトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E32867',
        issuer_name='日本再生可能エネルギーインフラ投資法人',
    ),
    'G12372': FundCodeEntry(
        fund_code='G12372',
        sec_code=None,
        fund_name='森トラスト・ホテルリート投資法人',
        fund_name_yomi='モリトラストホテルリートトウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E13771',
        issuer_name='森トラストリート投資法人',
    ),
    'G12373': FundCodeEntry(
        fund_code='G12373',
        sec_code=None,
        fund_name='ベトナム株ファンド',
        fund_name_yomi='ベトナムカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12376': FundCodeEntry(
        fund_code='G12376',
        sec_code=None,
        fund_name='ＦＷ専用ファンド（スタンダードコース）',
        fund_name_yomi='エフダブリューセンヨウファンド\u3000スタンダードコース',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12377': FundCodeEntry(
        fund_code='G12377',
        sec_code=None,
        fund_name='ＦＷ専用ファンド（プレミアムコース）',
        fund_name_yomi='エフダブリューセンヨウファンド\u3000プレミアムコース',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12378': FundCodeEntry(
        fund_code='G12378',
        sec_code=None,
        fund_name='おまかせ運用グロース・ファンド（世界の株式中心）',
        fund_name_yomi='オマカセウンヨウグロース\u3000ファンド\u3000セカイノカブシキチュウシン',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G12379': FundCodeEntry(
        fund_code='G12379',
        sec_code=None,
        fund_name='おまかせ運用インカム・ファンド（世界の債券中心）',
        fund_name_yomi='オマカセウンヨウインカム\u3000ファンド\u3000セカイノサイケンチュウシン',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G12380': FundCodeEntry(
        fund_code='G12380',
        sec_code=None,
        fund_name='おまかせ運用インフレヘッジ・ファンド（世界の実物資産中心）',
        fund_name_yomi='オマカセウンヨウインフレヘッジ\u3000ファンド\u3000セカイノジツブツシサンチュウシン',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G12381': FundCodeEntry(
        fund_code='G12381',
        sec_code=None,
        fund_name='ピクテ・バイオ医薬品ファンド（１年決算型）為替ヘッジなしコース',
        fund_name_yomi='ピクテバイオイヤクヒンファンドイチネンケッサンガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12382': FundCodeEntry(
        fund_code='G12382',
        sec_code=None,
        fund_name='ＵＳバイオ・ベンチャー（限定追加型）',
        fund_name_yomi='ユーエスバイオベンチャー\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E27736',
        issuer_name='ベイビュー・アセット・マネジメント株式会社',
    ),
    'G12383': FundCodeEntry(
        fund_code='G12383',
        sec_code=None,
        fund_name='ダイワ・グローバル金融機関（Ｇ－ＳＩＢｓ）債券ファンド（為替ヘッジあり）２０１７－０１',
        fund_name_yomi='ダイワグローバルキンユウキカンジーシブズサイケンファンドカワセヘッジアリニセンジュウナナゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12385': FundCodeEntry(
        fund_code='G12385',
        sec_code=None,
        fund_name='野村インデックスファンド・米国株式配当貴族',
        fund_name_yomi='ノムラインデックスファンドベイコクカブシキハイトウキゾク',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12386': FundCodeEntry(
        fund_code='G12386',
        sec_code=None,
        fund_name='野村インデックスファンド・米国株式配当貴族・為替ヘッジ型',
        fund_name_yomi='ノムラインデックスファンドベイコクカブシキハイトウキゾクカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12387': FundCodeEntry(
        fund_code='G12387',
        sec_code=None,
        fund_name='インデックス・ブレンド（タイプⅠ）、インデックス・ブレンド（タイプⅡ）、インデックス・ブレンド（タイプⅢ）、インデックス・ブレンド（タイプⅣ）、インデックス・ブレンド（タイプⅤ）',
        fund_name_yomi='インデックスブレンドタイプワン\u3000インデックスブレンドタイプツー\u3000インデックスブレンドタイプスリー\u3000インデックスブレンドタイプフォー\u3000インデックスブレンドタイプファイブ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12388': FundCodeEntry(
        fund_code='G12388',
        sec_code=None,
        fund_name='ＵＳ株主還元ファンド（為替ヘッジあり・年１回決算型）',
        fund_name_yomi='ユーエスカブヌシカンゲンファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12389': FundCodeEntry(
        fund_code='G12389',
        sec_code=None,
        fund_name='ＵＳ株主還元ファンド（為替ヘッジあり・年４回決算型）',
        fund_name_yomi='ユーエスカブヌシカンゲンファンドカワセヘッジアリネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12391': FundCodeEntry(
        fund_code='G12391',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１７－０２',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチナナノゼロニイ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G12392': FundCodeEntry(
        fund_code='G12392',
        sec_code=None,
        fund_name='アドバンテージ日本株式ファンド',
        fund_name_yomi='アドバンテージニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G12394': FundCodeEntry(
        fund_code='G12394',
        sec_code=None,
        fund_name='ＨＳＢＣインド債券オープン（毎月決算型）',
        fund_name_yomi='エイチエスビーシーインドサイケンオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G12395': FundCodeEntry(
        fund_code='G12395',
        sec_code=None,
        fund_name='ビッグデータ活用\u3000日本中小型株式ファンド',
        fund_name_yomi='ビッグデータカツヨウ\u3000ニホンチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12396': FundCodeEntry(
        fund_code='G12396',
        sec_code=None,
        fund_name='ダイワファンドラップオンライン\u3000インデックス・シリーズ',
        fund_name_yomi='ダイワファンドラップオンラインインデックスシリーズ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12397': FundCodeEntry(
        fund_code='G12397',
        sec_code=None,
        fund_name='オーストラリア・アジアＲＥＩＴファンド\u3000Ａコース（為替ヘッジなし・毎月決算型）／Ｂコース（為替ヘッジあり・毎月決算型）／Ｃコース（為替ヘッジなし・年２回決算型）／Ｄコース（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='オーストラリアアジアリートファンド\u3000エーコース\u3000カワセヘッジナシマイツキケッサンガタ\u3000ビーコース\u3000カワセヘッジアリマイツキケッサンガタ\u3000シーコース\u3000カワセヘッジナシネンニカイケッサンガタ\u3000ディーコース\u3000カワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G12398': FundCodeEntry(
        fund_code='G12398',
        sec_code=None,
        fund_name='グローバル・ロボティクス株式ファンド（為替ヘッジあり・１年決算型）',
        fund_name_yomi='グローバル\u3000ロボティクスカブシキファンド\u3000カワセヘッジアリ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12399': FundCodeEntry(
        fund_code='G12399',
        sec_code=None,
        fund_name='グローバル・ロボティクス株式ファンド（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='グローバル\u3000ロボティクスカブシキファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12400': FundCodeEntry(
        fund_code='G12400',
        sec_code=None,
        fund_name='ヘッジファンドＳＭＴＢセレクション（ＳＭＡ専用）',
        fund_name_yomi='ヘッジファンド\u3000エスエムティービー\u3000セレクション\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12401': FundCodeEntry(
        fund_code='G12401',
        sec_code=None,
        fund_name='ワールド・リート・オープン（毎月決算型）為替ヘッジあり',
        fund_name_yomi='ワールドリートオープンマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12402': FundCodeEntry(
        fund_code='G12402',
        sec_code=None,
        fund_name='スマート・クオリティ・オープン・ゴールド（安定型）、スマート・クオリティ・オープン・ゴールド（安定成長型）、スマート・クオリティ・オープン・ゴールド（成長型）',
        fund_name_yomi='スマートクオリティオープンゴールドアンテイガタスマートクオリティオープンゴールドアンテイセイチョウガタスマートクオリティオープンゴールドセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12404': FundCodeEntry(
        fund_code='G12404',
        sec_code=None,
        fund_name='米国インフラ・ビルダー株式ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ベイコクインフラビルダーカブシキファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2='7月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12406': FundCodeEntry(
        fund_code='G12406',
        sec_code=None,
        fund_name='ステート・ストリート米国社債インデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='ステートストリートベイコクシャサイインデックスオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12407': FundCodeEntry(
        fund_code='G12407',
        sec_code=None,
        fund_name='新・ミューズニッチ米国ＢＤＣファンド（為替ヘッジなし・毎月分配型）、（為替ヘッジなし・年２回決算型）、（為替ヘッジあり・毎月分配型）、（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='シン\u3000ミューズニッチベイコクビーディーシーファンド\u3000カワセヘッジナシ\u3000マイツキブンパイガタ\u3000\u3000\u3000カワセヘッジナシ\u3000ネンニカイケッサンガタ\u3000\u3000\u3000カワセヘッジアリ\u3000マイツキブンパイガタ\u3000\u3000\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12408': FundCodeEntry(
        fund_code='G12408',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000先進国高金利債券ファンド（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイセンシンコクコウキンリサイケンファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12413': FundCodeEntry(
        fund_code='G12413',
        sec_code=None,
        fund_name='外貨建て日系債券ファンド１７－０３（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ガイカダテニッケイサイケンファンドイチナナゼロサンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12415': FundCodeEntry(
        fund_code='G12415',
        sec_code=None,
        fund_name='時間分散型バランスファンド（安定指向）２０１７－０２',
        fund_name_yomi='ジカンブンサンガタバランスファンド\u3000アンテイシコウ\u3000ニーゼロイチナナ\u3000ゼロニ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12417': FundCodeEntry(
        fund_code='G12417',
        sec_code=None,
        fund_name='ＡＩ日本株式オープン（絶対収益追求型）',
        fund_name_yomi='エーアイニホンカブシキオープンゼッタイシュウエキツイキュウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12418': FundCodeEntry(
        fund_code='G12418',
        sec_code=None,
        fund_name='オーストラリアリートファンド（毎月分配型）',
        fund_name_yomi='オーストラリアリートファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G12421': FundCodeEntry(
        fund_code='G12421',
        sec_code=None,
        fund_name='ダイワ高格付日本企業外債ファンド（為替ヘッジあり／部分為替ヘッジあり）２０１７‐０２',
        fund_name_yomi='ダイワコウカクヅケニホンキギョウガイサイファンドカワセヘッジアリブブンカワセヘッジアリニセンジュウナナゼロニ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12422': FundCodeEntry(
        fund_code='G12422',
        sec_code=None,
        fund_name='ＪＰＭグローバル高利回りＣＢファンド（限定追加型・早期償還条項付）２０１７－０３',
        fund_name_yomi='ジェイピーエムグローバルコウリマワリシービーファンドゲンテイツイカガタソウキショウカンジョウコウツキニセンジュウナナノゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G12424': FundCodeEntry(
        fund_code='G12424',
        sec_code=None,
        fund_name='米国インフラ関連株式ファンド＜為替ヘッジあり＞、米国インフラ関連株式ファンド＜為替ヘッジなし＞',
        fund_name_yomi='ベイコクインフラカンレンカブシキファンドカワセヘッジアリ\u3000ベイコクインフラカンレンカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12426': FundCodeEntry(
        fund_code='G12426',
        sec_code=None,
        fund_name='野村グローバルＡＩ関連株式ファンド\u3000Ａコース、野村グローバルＡＩ関連株式ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラグローバルエーアイカンレンカブシキファンドエーコース\u3000ノムラグローバルエーアイカンレンカブシキファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12427': FundCodeEntry(
        fund_code='G12427',
        sec_code='14890',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経平均高配当株５０指数連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイヘイキンコウハイトウカブゴジュウシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12429': FundCodeEntry(
        fund_code='G12429',
        sec_code=None,
        fund_name='東京海上・米国政策関連株式ファンド（為替ヘッジなし）',
        fund_name_yomi='トウキョウカイジョウベイコクセイサクカンレンカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月22日',
        period_2='7月22日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12430': FundCodeEntry(
        fund_code='G12430',
        sec_code=None,
        fund_name='グローバルＡＩファンド（為替ヘッジあり）',
        fund_name_yomi='グローバルエーアイファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12432': FundCodeEntry(
        fund_code='G12432',
        sec_code=None,
        fund_name='いちよし日本好配当株＆Ｊリートファンド\u3000資産成長型',
        fund_name_yomi='イチヨシニホンコウハイトウカブアンドジェイリートファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G12433': FundCodeEntry(
        fund_code='G12433',
        sec_code=None,
        fund_name='いちよし日本好配当株＆Ｊリートファンド\u3000年４回決算型',
        fund_name_yomi='イチヨシニホンコウハイトウカブアンドジェイリートファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G12434': FundCodeEntry(
        fund_code='G12434',
        sec_code=None,
        fund_name='ＧＳグローバル・ビッグデータ投資戦略\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000ビッグデータ\u3000トウシセンリャク\u3000エーコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12435': FundCodeEntry(
        fund_code='G12435',
        sec_code=None,
        fund_name='アモーヴァ\u3000オフショア・ファンズ\u3000ＮＢコーポレート・ハイブリッド証券ファンド',
        fund_name_yomi='アモーヴァオフショアファンズエヌビーコーポレートハイブリッドショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E27078',
        issuer_name='アモーヴァＡＭ・グローバルケイマンリミテッド',
    ),
    'G12437': FundCodeEntry(
        fund_code='G12437',
        sec_code=None,
        fund_name='世界コーポレート・ハイブリッド証券ファンド２０１７－０３',
        fund_name_yomi='セカイコーポレートハイブリッドショウケンファンドニイゼロイチナナゼロサン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12439': FundCodeEntry(
        fund_code='G12439',
        sec_code=None,
        fund_name='米国短期社債戦略ファンド２０１７－０３（為替ヘッジあり）',
        fund_name_yomi='ベイコクタンキシャサイセンリャクファンドニゼロイチナナゼロサンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2='11月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12440': FundCodeEntry(
        fund_code='G12440',
        sec_code=None,
        fund_name='米ドル高利回り社債ファンド２０１７－０３（為替ヘッジあり）\u3000米ドル高利回り社債ファンド２０１７－０３（為替ヘッジなし）',
        fund_name_yomi='ベイドルコウリマワリシャサイファンドニゼロイチナナゼロサンカワセヘッジアリ\u3000ベイドルコウリマワリシャサイファンドニゼロイチナナゼロサンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12443': FundCodeEntry(
        fund_code='G12443',
        sec_code=None,
        fund_name='先進国好配当株式ファンド（３ヵ月決算型）為替ヘッジあり、先進国好配当株式ファンド（年２回決算型）為替ヘッジあり',
        fund_name_yomi='センシンコクコウハイトウカブシキファンドサンカゲツケッサンガタカワセヘッジアリセンシンコクコウハイトウカブシキファンドネンニカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12444': FundCodeEntry(
        fund_code='G12444',
        sec_code=None,
        fund_name='ダイワＴＯＰＩＸインデックス（ダイワＳＭＡ専用）他',
        fund_name_yomi='ダイワトピックスインデックスダイワエスエムエーセンヨウホカ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12449': FundCodeEntry(
        fund_code='G12449',
        sec_code=None,
        fund_name='ブレンドシックス',
        fund_name_yomi='ブレンドシックス',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G12452': FundCodeEntry(
        fund_code='G12452',
        sec_code=None,
        fund_name='世界物価連動債ファンド\u3000為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='セカイブッカレンドウサイファンド\u3000カワセヘッジアリ\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12453': FundCodeEntry(
        fund_code='G12453',
        sec_code=None,
        fund_name='ＮＭＳ\u3000米国地方債ファンド\u3000為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='エヌエムエス\u3000ベイコクチホウサイファンド\u3000カワセヘッジアリ\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12455': FundCodeEntry(
        fund_code='G12455',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－米ドル建て\u3000償還時目標設定型ファンド１７０３',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラストベイドルダテショウカンジモクヒョウセッテイガタファンドイチナナマルサン',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G12458': FundCodeEntry(
        fund_code='G12458',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000国内株式（ＴＯＰＩＸ）',
        fund_name_yomi='イーマクシススリムコクナイカブシキトピックス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12459': FundCodeEntry(
        fund_code='G12459',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000国内債券インデックス',
        fund_name_yomi='イーマクシススリムコクナイサイケンインデクス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12460': FundCodeEntry(
        fund_code='G12460',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000先進国株式インデックス（除く日本）',
        fund_name_yomi='イーマクシススリムセンシンコクカブシキインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12461': FundCodeEntry(
        fund_code='G12461',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000先進国債券インデックス（除く日本）',
        fund_name_yomi='イーマクシススリムセンシンコクサイケンインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12462': FundCodeEntry(
        fund_code='G12462',
        sec_code=None,
        fund_name='クォンティック・トラスト‐米ドル建て償還時ターゲット債券ファンド２０１７０３',
        fund_name_yomi='クォンティックトラストベイドルダテショウカンジターゲットサイケンファンドニマルイチナナマルサン',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G12463': FundCodeEntry(
        fund_code='G12463',
        sec_code=None,
        fund_name='ダイワ円債セレクト',
        fund_name_yomi='ダイワエンサイセレクト',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12464': FundCodeEntry(
        fund_code='G12464',
        sec_code='14900',
        fund_name='上場インデックスファンドＭＳＣＩ日本株高配当低ボラティリティ（βヘッジ）',
        fund_name_yomi='ジョウジョウインデックスファンドエムエスシーアイニホンカブコウハイトウテイボラティリティ\u3000ベータヘッジ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12465': FundCodeEntry(
        fund_code='G12465',
        sec_code=None,
        fund_name='グローバル・スマート・イノベーション・オープン（年２回決算型）為替ヘッジあり',
        fund_name_yomi='グローバルスマートイノベーションオープンネンニカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12466': FundCodeEntry(
        fund_code='G12466',
        sec_code=None,
        fund_name='グローバル・スマート・イノベーション・オープン（年１回決算型）為替ヘッジあり',
        fund_name_yomi='グローバルスマートイノベーションオープンネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12467': FundCodeEntry(
        fund_code='G12467',
        sec_code=None,
        fund_name='日本株＆Ｊリート\u3000好配当フォーカスファンド（年２回決算型）',
        fund_name_yomi='ニホンカブアンドジェイリート\u3000コウハイトウフォーカスファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12468': FundCodeEntry(
        fund_code='G12468',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１７－０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチナナノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G12470': FundCodeEntry(
        fund_code='G12470',
        sec_code=None,
        fund_name='ブラックロックＬｉｆｅＰａｔｈファンド２０２５／２０３０／２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５／２０７０',
        fund_name_yomi='ブラックロックライフパスファンドニイゼロニイゴウニイゼロサンゼロニイゼロサンゴウニイゼロヨンゼロニイゼロヨンゴウニイゼロゴウゼロニイゼロゴウゴウニイゼロロクゼロニイゼロロクゴウニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12472': FundCodeEntry(
        fund_code='G12472',
        sec_code=None,
        fund_name='国内株式セレクション（ラップ向け）',
        fund_name_yomi='コクナイカブシキセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12473': FundCodeEntry(
        fund_code='G12473',
        sec_code=None,
        fund_name='国内債券セレクション（ラップ向け）',
        fund_name_yomi='コクナイサイケンセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12474': FundCodeEntry(
        fund_code='G12474',
        sec_code=None,
        fund_name='オルタナティブ資産セレクション（ラップ向け）',
        fund_name_yomi='オルタナティブシサンセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12476': FundCodeEntry(
        fund_code='G12476',
        sec_code=None,
        fund_name='ＧＳビッグデータ・ストラテジー（米国小型株）Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエスビッグデータストラテジー\u3000エーコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12477': FundCodeEntry(
        fund_code='G12477',
        sec_code=None,
        fund_name='ニッセイＪＰＸ日経中小型株アクティブファンド',
        fund_name_yomi='ニッセイジェイピーエックスニッケイチュウコガタカブアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12483': FundCodeEntry(
        fund_code='G12483',
        sec_code=None,
        fund_name='たわらノーロード\u3000ＮＹダウ',
        fund_name_yomi='タワラノーロードニューヨークダウ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12484': FundCodeEntry(
        fund_code='G12484',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国リート＜為替ヘッジあり＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクリートカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12485': FundCodeEntry(
        fund_code='G12485',
        sec_code=None,
        fund_name='たわらノーロード\u3000ＴＯＰＩＸ',
        fund_name_yomi='タワラノーロード\u3000トピックス',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12487': FundCodeEntry(
        fund_code='G12487',
        sec_code=None,
        fund_name='アモーヴァ\u3000オフショア・ファンズ\u3000ダブルライン・トータル・リターン・ファンド',
        fund_name_yomi='アモーヴァオフショアファンズダブルライントータルリターンファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E27078',
        issuer_name='アモーヴァＡＭ・グローバルケイマンリミテッド',
    ),
    'G12488': FundCodeEntry(
        fund_code='G12488',
        sec_code=None,
        fund_name='ＳＢＩ日本・アジアフィンテック株式ファンド',
        fund_name_yomi='エスビーアイニホンアジアフィンテックカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12489': FundCodeEntry(
        fund_code='G12489',
        sec_code=None,
        fund_name='ヘッジファンドセレクション（ラップ向け）',
        fund_name_yomi='ヘッジファンドセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12490': FundCodeEntry(
        fund_code='G12490',
        sec_code=None,
        fund_name='海外株式セレクション（ラップ向け）',
        fund_name_yomi='カイガイカブシキセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12491': FundCodeEntry(
        fund_code='G12491',
        sec_code=None,
        fund_name='海外債券セレクション（ラップ向け）',
        fund_name_yomi='カイガイサイケンセレクションラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12492': FundCodeEntry(
        fund_code='G12492',
        sec_code=None,
        fund_name='シュローダーＹＥＮターゲット（１年決算型）',
        fund_name_yomi='シュローダーエンターゲット\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G12493': FundCodeEntry(
        fund_code='G12493',
        sec_code=None,
        fund_name='シュローダーＹＥＮターゲット（年２回決算型）',
        fund_name_yomi='シュローダーエンターゲット\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G12494': FundCodeEntry(
        fund_code='G12494',
        sec_code=None,
        fund_name='ＭＡＸＩＳ\u3000ＪＰＸ\u3000日経中小型株指数上場投信',
        fund_name_yomi='マクシスジェーピーエックスニッケイチュウコガタカブシスウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12495': FundCodeEntry(
        fund_code='G12495',
        sec_code=None,
        fund_name='イーストスプリング米国小型厳選バリュー株ファンドＡコース（為替ヘッジあり）\u3000イーストスプリング米国小型厳選バリュー株ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='イーストスプリングベイコクコガタゲンセンバリューカブファンドエイコースカワセヘッジアリ\u3000イーストスプリングベイコクコガタゲンセンバリューカブファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G12496': FundCodeEntry(
        fund_code='G12496',
        sec_code=None,
        fund_name='ダイワ日本企業外債ファンドＳ（為替ヘッジあり／部分為替ヘッジあり）２０１７ー０４',
        fund_name_yomi='ダイワニホンキギョウガイサイファンドエスカワセヘッジアリブブンカワセヘッジアリニセンジュウナナゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12497': FundCodeEntry(
        fund_code='G12497',
        sec_code=None,
        fund_name='グローバル自動運転関連株式ファンド（為替ヘッジあり）、グローバル自動運転関連株式ファンド（為替ヘッジなし）',
        fund_name_yomi='グローバルジドウウンテンカンレンカブシキファンドカワセヘッジアリ\u3000グローバルジドウウンテンカンレンカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12498': FundCodeEntry(
        fund_code='G12498',
        sec_code=None,
        fund_name='スマート・プロテクター９０オープン',
        fund_name_yomi='スマートプロテクターキュウジュウオープン',
        security_type='内国投資信託受益証券',
        period_1='4月28日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12499': FundCodeEntry(
        fund_code='G12499',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信バランスライト',
        fund_name_yomi='ペイペイトウシンバランスライト',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G12501': FundCodeEntry(
        fund_code='G12501',
        sec_code=None,
        fund_name='ダブルライン・シラー・ケープ米国株式プラス＜為替ヘッジあり＞／＜為替ヘッジなし＞',
        fund_name_yomi='ダブルライン\u3000シラー\u3000ケープベイコクカブシキプラス\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12502': FundCodeEntry(
        fund_code='G12502',
        sec_code=None,
        fund_name='トラノコ・ファンドⅠ',
        fund_name_yomi='トラノコファンドワン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E14235',
        issuer_name='ＴＯＲＡＮＯＴＥＣ投信投資顧問株式会社',
    ),
    'G12503': FundCodeEntry(
        fund_code='G12503',
        sec_code=None,
        fund_name='トラノコ・ファンドⅡ',
        fund_name_yomi='トラノコファンドツー',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E14235',
        issuer_name='ＴＯＲＡＮＯＴＥＣ投信投資顧問株式会社',
    ),
    'G12504': FundCodeEntry(
        fund_code='G12504',
        sec_code=None,
        fund_name='トラノコ・ファンドⅢ',
        fund_name_yomi='トラノコファンドスリー',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E14235',
        issuer_name='ＴＯＲＡＮＯＴＥＣ投信投資顧問株式会社',
    ),
    'G12505': FundCodeEntry(
        fund_code='G12505',
        sec_code=None,
        fund_name='ＹＭアセット・優良米国株ファンド',
        fund_name_yomi='ワイエムアセットユウリョウベイコクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E32437',
        issuer_name='ワイエムアセットマネジメント株式会社',
    ),
    'G12506': FundCodeEntry(
        fund_code='G12506',
        sec_code=None,
        fund_name='ニッセイ・ジャパンＡＩ関連株式ファンド',
        fund_name_yomi='ニッセイジャパンエーアイカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12509': FundCodeEntry(
        fund_code='G12509',
        sec_code=None,
        fund_name='ダイワ・グローバルＩｏＴ関連株ファンド\u3000－ＡＩ新時代－（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ダイワグローバルアイオーティーカンレンカブファンドエーアイシンジダイカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12510': FundCodeEntry(
        fund_code='G12510',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔ新興国株式',
        fund_name_yomi='アイトラストシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12511': FundCodeEntry(
        fund_code='G12511',
        sec_code=None,
        fund_name='ＮＹダウ・インデックスファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ニューヨークダウインデックスファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12512': FundCodeEntry(
        fund_code='G12512',
        sec_code=None,
        fund_name='ブラックロック\u3000ｉインカム',
        fund_name_yomi='ブラックロックアイインカム',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12513': FundCodeEntry(
        fund_code='G12513',
        sec_code=None,
        fund_name='ブラックロック・米国小型株式\u3000ビッグデータ戦略ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブラックロックベイコクコガタカブシキビッグデータセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12514': FundCodeEntry(
        fund_code='G12514',
        sec_code=None,
        fund_name='フィデリティ・米国優良株・ファンド（為替ヘッジあり）',
        fund_name_yomi='フィデリティベイコクユウリョウカブファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12515': FundCodeEntry(
        fund_code='G12515',
        sec_code=None,
        fund_name='アムンディ・ストラテジック・インカムファンド',
        fund_name_yomi='アムンディストラテジックインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12517': FundCodeEntry(
        fund_code='G12517',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・米国連続増配株ファンド（年２回決算型）\u3000フランクリン・テンプルトン・米国連続増配株ファンド（３ヵ月決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ベイコクレンゾクゾウハイカブファンド\u3000ネンニカイケッサンガタ\u3000フランクリン\u3000テンプルトン\u3000ベイコクレンゾクゾウハイカブファンド\u3000サンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G12518': FundCodeEntry(
        fund_code='G12518',
        sec_code=None,
        fund_name='スパークス・新・国際優良アジア株ファンド',
        fund_name_yomi='スパークスシンコクサイユウリョウアジアカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12519': FundCodeEntry(
        fund_code='G12519',
        sec_code=None,
        fund_name='米国バンクローンファンド＜為替ヘッジあり＞／＜為替ヘッジなし＞（資産成長型）',
        fund_name_yomi='ベイコクバンクローンファンドカワセヘッジアリカワセヘッジナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12520': FundCodeEntry(
        fund_code='G12520',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000バランス（８資産均等型）',
        fund_name_yomi='イーマクシススリムバランスハチシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12522': FundCodeEntry(
        fund_code='G12522',
        sec_code=None,
        fund_name='ＭＳＣＩジャパン高配当利回りインデックス・ファンド（年２回決算型）',
        fund_name_yomi='エムエスシーアイジャパンコウハイトウリマワリインデックス\u3000ファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12523': FundCodeEntry(
        fund_code='G12523',
        sec_code=None,
        fund_name='ＪＰＭ新興国小型株式ファンド',
        fund_name_yomi='ジェイピーエムシンコウコクコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月11日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G12524': FundCodeEntry(
        fund_code='G12524',
        sec_code=None,
        fund_name='キャピタル・ニューワールド・ファンドＡコース（米ドル売り円買い）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='キャピタルニューワールドファンドエイコースベイドルウリエンガイビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G12527': FundCodeEntry(
        fund_code='G12527',
        sec_code='14930',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000ＪＰＸ日経中小型',
        fund_name_yomi='ワンイーティーエフジェイピーエックスニッケイチュウコガタ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12528': FundCodeEntry(
        fund_code='G12528',
        sec_code='14940',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000高配当日本株',
        fund_name_yomi='ワンイーティーエフコウハイトウニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12531': FundCodeEntry(
        fund_code='G12531',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000グローバルコア株式ファンド',
        fund_name_yomi='プレミアムファンズグローバルコアカブシキファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G12532': FundCodeEntry(
        fund_code='G12532',
        sec_code=None,
        fund_name='ＵＢＳオーストラリア債券オープン（年１回決算型）',
        fund_name_yomi='ユービーエスオーストラリアサイケンオープン\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12533': FundCodeEntry(
        fund_code='G12533',
        sec_code=None,
        fund_name='アムンディ・グローバル・ストラテジー株式ファンド\u3000年２回決算型（為替ヘッジあり）、アムンディ・グローバル・ストラテジー株式ファンド\u3000毎月決算型（為替ヘッジあり）',
        fund_name_yomi='アムンディグローバルストラテジーカブシキファンドネンニカイケッサンガタカワセヘッジアリ\u3000アムンディグローバルストラテジーカブシキファンドマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12535': FundCodeEntry(
        fund_code='G12535',
        sec_code=None,
        fund_name='ピムコ\u3000ショートターム・インカム・ファンド（為替リスク軽減型）',
        fund_name_yomi='ピムコショートタームインカムファンドカワセリスクケイゲンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12536': FundCodeEntry(
        fund_code='G12536',
        sec_code=None,
        fund_name='ピムコ\u3000ショートターム・インカム・ファンド（為替ヘッジなし）',
        fund_name_yomi='ピムコショートタームインカムファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12537': FundCodeEntry(
        fund_code='G12537',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000Ｊリートオープン（毎月決算型）',
        fund_name_yomi='ミツビシユーエフジェージェーリートオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12538': FundCodeEntry(
        fund_code='G12538',
        sec_code=None,
        fund_name='げんせん投信',
        fund_name_yomi='ゲンセントウシン',
        security_type='内国投資信託受益証券',
        period_1='8月31日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12542': FundCodeEntry(
        fund_code='G12542',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＪＰＸ日経中小型株インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ジェイピーエックスニッケイチュウコガタカブインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12543': FundCodeEntry(
        fund_code='G12543',
        sec_code=None,
        fund_name='インデックスファンドＪＰＸ日経中小型株',
        fund_name_yomi='インデックスファンドジェーピーエックスニッケイチュウコガタカブ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12545': FundCodeEntry(
        fund_code='G12545',
        sec_code=None,
        fund_name='米国好配当リバランスオープン（年２回決算型）（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ベイコクコウハイトウリバランスオープンネンニカイケッサンガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12546': FundCodeEntry(
        fund_code='G12546',
        sec_code=None,
        fund_name='グローイング・フロンティア株式ファンド',
        fund_name_yomi='グローイングフロンティアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12547': FundCodeEntry(
        fund_code='G12547',
        sec_code=None,
        fund_name='ＢＮＹメロン・日本中小型株式ダイナミック戦略ファンド',
        fund_name_yomi='ビーエヌワイメロンニッポンチュウコガタカブシキダイナミックセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12548': FundCodeEntry(
        fund_code='G12548',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＪＰＸ日経中小型インデックス',
        fund_name_yomi='イーマクシスジェーピーエックスニッケイチュウコガタインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12549': FundCodeEntry(
        fund_code='G12549',
        sec_code='14950',
        fund_name='上場インデックスファンドアジアリート',
        fund_name_yomi='ジョウジョウインデックスファンドアジアリート',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12550': FundCodeEntry(
        fund_code='G12550',
        sec_code=None,
        fund_name='ＧＳビッグデータ・ストラテジー（日本株）',
        fund_name_yomi='ジーエスビッグデータ\u3000ストラテジー\u3000ニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12551': FundCodeEntry(
        fund_code='G12551',
        sec_code=None,
        fund_name='東京海上・グローバルペット関連株式ファンド',
        fund_name_yomi='トウキョウカイジョウグローバルペットカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12557': FundCodeEntry(
        fund_code='G12557',
        sec_code=None,
        fund_name='投資のソムリエ（ターゲット・イヤー２０４５）、投資のソムリエ（ターゲット・イヤー２０５５）',
        fund_name_yomi='トウシノソムリエターゲットイヤーニイゼロヨンゴウ\u3000トウシノソムリエターゲットイヤーニイゼロゴウゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12558': FundCodeEntry(
        fund_code='G12558',
        sec_code=None,
        fund_name='ＳＭＢＣ・アムンディ\u3000プロテクト＆スイッチファンド',
        fund_name_yomi='エスエムビーシーアムンディ\u3000プロテクトアンドスイッチファンド',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12559': FundCodeEntry(
        fund_code='G12559',
        sec_code=None,
        fund_name='カレラ\u3000米国小型株式アクティブファンド',
        fund_name_yomi='カレラ\u3000ベイコクコガタカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G12560': FundCodeEntry(
        fund_code='G12560',
        sec_code=None,
        fund_name='ニッセイ豪州ハイ・インカム株式ファンド（資産成長型）',
        fund_name_yomi='ニッセイゴウシュウハイインカムカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12561': FundCodeEntry(
        fund_code='G12561',
        sec_code=None,
        fund_name='東京海上・世界資産バランスファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウセカイシサンバランスファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12562': FundCodeEntry(
        fund_code='G12562',
        sec_code=None,
        fund_name='東京海上・世界資産バランスファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウセカイシサンバランスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12563': FundCodeEntry(
        fund_code='G12563',
        sec_code=None,
        fund_name='インド債券オープン（年１回決算型）',
        fund_name_yomi='インドサイケンオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12564': FundCodeEntry(
        fund_code='G12564',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞長期厳選投資\u3000おおぶね',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000チョウキゲンセントウシ\u3000オオブネ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G12565': FundCodeEntry(
        fund_code='G12565',
        sec_code=None,
        fund_name='四国アライアンス\u3000地域創生ファンド（年１回決算型）',
        fund_name_yomi='シコクアライアンスチイキソウセイファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12566': FundCodeEntry(
        fund_code='G12566',
        sec_code=None,
        fund_name='四国アライアンス\u3000地域創生ファンド（年２回決算型）',
        fund_name_yomi='シコクアライアンスチイキソウセイファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12567': FundCodeEntry(
        fund_code='G12567',
        sec_code=None,
        fund_name='米国優先リート１７－０７（為替ヘッジあり）',
        fund_name_yomi='ベイコクユウセンリートイチナナゼロナナカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12568': FundCodeEntry(
        fund_code='G12568',
        sec_code=None,
        fund_name='ＤＣニッセイワールドセレクトファンド（安定型）',
        fund_name_yomi='ディーシーニッセイワールドセレクトファンドアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12569': FundCodeEntry(
        fund_code='G12569',
        sec_code=None,
        fund_name='ＵＢＳ公益・金融社債ファンド（年１回決算型・為替ヘッジなし）',
        fund_name_yomi='ユービーエスコウエキ\u3000キンユウシャサイファンド\u3000ネンイッカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12570': FundCodeEntry(
        fund_code='G12570',
        sec_code=None,
        fund_name='世界好利回りＣＢファンド２０１７－０７（為替ヘッジあり）（限定追加型）世界好利回りＣＢファンド２０１７－０７（為替ヘッジなし）（限定追加型）',
        fund_name_yomi='セカイコウリマワリシービーファンドニセンジュウナナゼロナナカワセヘッジアリゲンテイツイカガタセカイコウリマワリシービーファンドニセンジュウナナゼロナナカワセヘッジナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月29日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12571': FundCodeEntry(
        fund_code='G12571',
        sec_code=None,
        fund_name='ピクテ中短期債券ファンド（毎月決算型）',
        fund_name_yomi='ピクテチュウタンキサイケンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12572': FundCodeEntry(
        fund_code='G12572',
        sec_code=None,
        fund_name='ピクテ中短期債券ファンド（１年決算型）',
        fund_name_yomi='ピクテチュウタンキサイケンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12574': FundCodeEntry(
        fund_code='G12574',
        sec_code=None,
        fund_name='サイバーセキュリティ株式オープン（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='サイバーセキュリティカブシキオープンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12575': FundCodeEntry(
        fund_code='G12575',
        sec_code=None,
        fund_name='ブラックロック・スタイル・アドバンテージ・ポートフォリオ（円／年１回決算コース）',
        fund_name_yomi='ブラックロックスタイルアドバンテージポートフォリオエンネンイッカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12576': FundCodeEntry(
        fund_code='G12576',
        sec_code=None,
        fund_name='アセアン・オーナーズ・ファンド（為替ヘッジなし）',
        fund_name_yomi='アセアンオーナーズファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12577': FundCodeEntry(
        fund_code='G12577',
        sec_code=None,
        fund_name='日本中小型株ファンド',
        fund_name_yomi='ニホンチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G12578': FundCodeEntry(
        fund_code='G12578',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔプレミアム・ブランド',
        fund_name_yomi='アイトラストプレミアムブランド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12579': FundCodeEntry(
        fund_code='G12579',
        sec_code=None,
        fund_name='ピクテ・セキュリティ・ファンド（為替ヘッジあり）',
        fund_name_yomi='ピクテセキュリティファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12583': FundCodeEntry(
        fund_code='G12583',
        sec_code=None,
        fund_name='明治安田生命２０１７基金特定目的会社',
        fund_name_yomi='メイジヤスダセイメイニセンジュウシチキキントクテイモクテキカイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33332',
        issuer_name='明治安田生命２０１７基金特定目的会社',
    ),
    'G12585': FundCodeEntry(
        fund_code='G12585',
        sec_code=None,
        fund_name='米国国債７－１０年ラダーファンド（為替ヘッジあり）（ラップ向け）',
        fund_name_yomi='ベイコクコクサイナナカラジュウネンラダーファンドカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12586': FundCodeEntry(
        fund_code='G12586',
        sec_code=None,
        fund_name='ショートデュレーション円インカムオープン（ラップ向け）',
        fund_name_yomi='ショートデュレーションエンインカムオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12589': FundCodeEntry(
        fund_code='G12589',
        sec_code=None,
        fund_name='パインブリッジ米国ライジングスター好利回り債券ファンド２０１７－０８（為替ヘッジあり・早期償還条項付）',
        fund_name_yomi='パインブリッジベイコクライジングスターコウリマワリサイケンファンドニセンジュウナナノハチカワセヘッジアリソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G12590': FundCodeEntry(
        fund_code='G12590',
        sec_code=None,
        fund_name='オーストラリア好利回りバランス・ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='オーストラリアコウリマワリバランスファンド\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12591': FundCodeEntry(
        fund_code='G12591',
        sec_code=None,
        fund_name='オーストラリア好利回りバランス・ファンド（毎月決算型）',
        fund_name_yomi='オーストラリアコウリマワリバランスファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12592': FundCodeEntry(
        fund_code='G12592',
        sec_code='34810',
        fund_name='三菱地所物流リート投資法人',
        fund_name_yomi='ミツビシジショブツリュウリートトウシホウジン',
        security_type='内国投資証券',
        period_1='8月末日',
        period_2='2月末日',
        edinet_code='E33350',
        issuer_name='三菱地所物流リート投資法人',
    ),
    'G12593': FundCodeEntry(
        fund_code='G12593',
        sec_code=None,
        fund_name='ゴールド・ファンド（為替ヘッジあり）、ゴールド・ファンド（為替ヘッジなし）',
        fund_name_yomi='ゴールド\u3000ファンド\u3000カワセヘッジアリ\u3000\u3000ゴールド\u3000ファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12596': FundCodeEntry(
        fund_code='G12596',
        sec_code=None,
        fund_name='ピムコ\u3000短期戦略プラス・オープン（為替リスク軽減型）',
        fund_name_yomi='ピムコタンキセンリャクプラスオープンカワセリスクケイゲンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12597': FundCodeEntry(
        fund_code='G12597',
        sec_code=None,
        fund_name='ワールド・ビューティー・オープン（為替ヘッジあり）、ワールド・ビューティー・オープン（為替ヘッジなし）',
        fund_name_yomi='ワールドビューティーオープンカワセヘッジアリワールドビューティーオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12598': FundCodeEntry(
        fund_code='G12598',
        sec_code=None,
        fund_name='たわらノーロード\u3000バランス（８資産均等型）',
        fund_name_yomi='タワラノーロードバランスハチシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12599': FundCodeEntry(
        fund_code='G12599',
        sec_code=None,
        fund_name='スパークス・厳選投資ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='スパークス\u3000ゲンセントウシファンド\u3000ノムラ\u3000エスエムエー\u3000イーダブリュー\u3000ムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12600': FundCodeEntry(
        fund_code='G12600',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000新興国株式インデックス',
        fund_name_yomi='イーマクシススリムシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12601': FundCodeEntry(
        fund_code='G12601',
        sec_code=None,
        fund_name='ワールド・バリュー・アロケーション\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ワールドバリューアロケーションエーコースカワセヘッジアリビーコースカワセヘッジナシノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12603': FundCodeEntry(
        fund_code='G12603',
        sec_code=None,
        fund_name='米国投資適格社債１－１０年インデックスファンド（為替ヘッジあり）毎月分配型、米国投資適格社債１－１０年インデックスファンド（為替ヘッジあり）年２回決算型',
        fund_name_yomi='ベイコクトウシテキカクシャサイイチジュウネンインデックスファンドカワセヘッジアリマイツキブンパイガタ\u3000ベイコクトウシテキカクシャサイイチジュウネンインデックスファンドカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12604': FundCodeEntry(
        fund_code='G12604',
        sec_code=None,
        fund_name='ほくよう資産形成応援ファンド',
        fund_name_yomi='ホクヨウシサンケイセイオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G12605': FundCodeEntry(
        fund_code='G12605',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１７‐０９',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチナナノゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G12607': FundCodeEntry(
        fund_code='G12607',
        sec_code=None,
        fund_name='ロシア・ボンド・オープン（年１回決算型）',
        fund_name_yomi='ロシアボンドオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月6日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12608': FundCodeEntry(
        fund_code='G12608',
        sec_code=None,
        fund_name='ロシア・ボンド・オープン（毎月決算型）',
        fund_name_yomi='ロシアボンドオープンマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月6日',
        period_2='8月6日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12609': FundCodeEntry(
        fund_code='G12609',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラピムコセカイインカムセンリャクファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラピムコセカイインカムセンリャクファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12610': FundCodeEntry(
        fund_code='G12610',
        sec_code=None,
        fund_name='野村資産設計ファンド（ＤＣ・つみたてＮＩＳＡ）２０３０',
        fund_name_yomi='ノムラシサンセッケイファンドディーシーツミタテニーサニセンサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12611': FundCodeEntry(
        fund_code='G12611',
        sec_code=None,
        fund_name='野村資産設計ファンド（ＤＣ・つみたてＮＩＳＡ）２０４０',
        fund_name_yomi='ノムラシサンセッケイファンドディーシーツミタテニーサニセンヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12612': FundCodeEntry(
        fund_code='G12612',
        sec_code=None,
        fund_name='野村資産設計ファンド（ＤＣ・つみたてＮＩＳＡ）２０５０',
        fund_name_yomi='ノムラシサンセッケイファンドディーシーツミタテニーサニセンゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12613': FundCodeEntry(
        fund_code='G12613',
        sec_code=None,
        fund_name='野村世界６資産分散投信（ＤＣ）安定コース、野村世界６資産分散投信（ＤＣ）インカムコース、野村世界６資産分散投信（ＤＣ）成長コース',
        fund_name_yomi='ノムラセカイロクシサンブンサントウシンディーシーアンテイコース\u3000ノムラセカイロクシサンブンサントウシンディーシーインカムコース\u3000ノムラセカイロクシサンブンサントウシンディーシーセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12614': FundCodeEntry(
        fund_code='G12614',
        sec_code=None,
        fund_name='ＪＰ４資産バランスファンド（ＤＣ）',
        fund_name_yomi='ジェイピーヨンシサンバランスファンド\u3000ディーシー',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E32151',
        issuer_name='ＪＰ投信株式会社',
    ),
    'G12615': FundCodeEntry(
        fund_code='G12615',
        sec_code=None,
        fund_name='ＪＰ日米バランスファンド（ＤＣ）',
        fund_name_yomi='ジェイピーニチベイバランスファンド\u3000ディーシー',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E32151',
        issuer_name='ＪＰ投信株式会社',
    ),
    'G12616': FundCodeEntry(
        fund_code='G12616',
        sec_code=None,
        fund_name='ラッセル・インベストメントＤＣ国内債券Ｆ（運用会社厳選型）',
        fund_name_yomi='ラッセルインベストメントディーシーコクナイサイケンエフウンヨウガイシャゲンセンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G12617': FundCodeEntry(
        fund_code='G12617',
        sec_code=None,
        fund_name='ラッセル・インベストメントＤＣ外国債券Ｆ（運用会社厳選型）',
        fund_name_yomi='ラッセルインベストメントディーシーガイコクサイケンエフウンヨウガイシャゲンセンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G12618': FundCodeEntry(
        fund_code='G12618',
        sec_code=None,
        fund_name='リスク抑制世界８資産バランスファンド（ＤＣ）',
        fund_name_yomi='リスクヨクセイセカイハチシサンバランスファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12619': FundCodeEntry(
        fund_code='G12619',
        sec_code=None,
        fund_name='ＳＭＴ\u3000世界経済インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000セカイケイザイインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12620': FundCodeEntry(
        fund_code='G12620',
        sec_code=None,
        fund_name='ＳＭＴ\u3000世界経済インデックス・オープン（株式シフト型）',
        fund_name_yomi='エスエムティー\u3000セカイケイザイインデックス\u3000オープン\u3000カブシキシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12621': FundCodeEntry(
        fund_code='G12621',
        sec_code=None,
        fund_name='ＳＭＴ\u3000世界経済インデックス・オープン（債券シフト型）',
        fund_name_yomi='エスエムティー\u3000セカイケイザイインデックス\u3000オープン\u3000サイケンシフトガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12622': FundCodeEntry(
        fund_code='G12622',
        sec_code=None,
        fund_name='ＳＭＴ\u3000８資産インデックスバランス・オープン',
        fund_name_yomi='エスエムティー\u3000ハチシサンインデックスバランス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12623': FundCodeEntry(
        fund_code='G12623',
        sec_code=None,
        fund_name='Ｊリートインデックスファンド（ＤＣ）',
        fund_name_yomi='ジェイリートインデックスファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12624': FundCodeEntry(
        fund_code='G12624',
        sec_code=None,
        fund_name='つみたて日本株式（ＴＯＰＩＸ）',
        fund_name_yomi='ツミタテニホンカブシキトピックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12625': FundCodeEntry(
        fund_code='G12625',
        sec_code=None,
        fund_name='つみたて先進国株式',
        fund_name_yomi='ツミタテセンシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12626': FundCodeEntry(
        fund_code='G12626',
        sec_code=None,
        fund_name='つみたて新興国株式',
        fund_name_yomi='ツミタテシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12627': FundCodeEntry(
        fund_code='G12627',
        sec_code=None,
        fund_name='つみたて８資産均等バランス',
        fund_name_yomi='ツミタテハチシサンキントウバランス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12629': FundCodeEntry(
        fund_code='G12629',
        sec_code=None,
        fund_name='つみたて日本株式（日経平均）',
        fund_name_yomi='ツミタテニホンカブシキニッケイヘイキン',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12630': FundCodeEntry(
        fund_code='G12630',
        sec_code=None,
        fund_name='つみたて先進国株式（為替ヘッジあり）',
        fund_name_yomi='ツミタテセンシンコクカブシキカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12631': FundCodeEntry(
        fund_code='G12631',
        sec_code=None,
        fund_name='つみたて４資産均等バランス',
        fund_name_yomi='ツミタテヨンシサンキントウバランス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12632': FundCodeEntry(
        fund_code='G12632',
        sec_code='14960',
        fund_name='ｉシェアーズ\u3000米ドル建て投資適格社債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイドルダテトウシテキカクシャサイ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12633': FundCodeEntry(
        fund_code='G12633',
        sec_code='14970',
        fund_name='ｉシェアーズ\u3000米ドル建てハイイールド社債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイドルダテハイイールドシャサイ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12634': FundCodeEntry(
        fund_code='G12634',
        sec_code=None,
        fund_name='ダイワＤＢモメンタム戦略ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ダイワディービーモメンタムセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2='8月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12635': FundCodeEntry(
        fund_code='G12635',
        sec_code=None,
        fund_name='フィリピン株式オープン',
        fund_name_yomi='フィリピンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12636': FundCodeEntry(
        fund_code='G12636',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000日経２２５インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000ニッケイニーニーゴーインデックス',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12637': FundCodeEntry(
        fund_code='G12637',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000ＴＯＰＩＸインデックス',
        fund_name_yomi='スマート\u3000アイ\u3000トピックスインデックス',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12638': FundCodeEntry(
        fund_code='G12638',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000先進国債券インデックス（為替ヘッジなし）',
        fund_name_yomi='スマート\u3000アイ\u3000センシンコクサイケンインデックス\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12639': FundCodeEntry(
        fund_code='G12639',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000先進国債券インデックス（為替ヘッジあり）',
        fund_name_yomi='スマート\u3000アイ\u3000センシンコクサイケンインデックス\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12640': FundCodeEntry(
        fund_code='G12640',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000Ｊリートインデックス',
        fund_name_yomi='スマート\u3000アイ\u3000ジェイリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12641': FundCodeEntry(
        fund_code='G12641',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000国内債券インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000コクナイサイケンインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12642': FundCodeEntry(
        fund_code='G12642',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000先進国株式インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000センシンコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12643': FundCodeEntry(
        fund_code='G12643',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000新興国株式インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000シンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12644': FundCodeEntry(
        fund_code='G12644',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000先進国リートインデックス',
        fund_name_yomi='スマート\u3000アイ\u3000センシンコクリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12647': FundCodeEntry(
        fund_code='G12647',
        sec_code=None,
        fund_name='世界ｅコマース関連株式オープン',
        fund_name_yomi='セカイイーコマースカンレンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12649': FundCodeEntry(
        fund_code='G12649',
        sec_code=None,
        fund_name='豪ドル年１回決算型ファンド',
        fund_name_yomi='ゴウドルネンイッカイケッサンガタファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12650': FundCodeEntry(
        fund_code='G12650',
        sec_code=None,
        fund_name='オーストラリア・高配当株ファンド（年１回決算型）',
        fund_name_yomi='オーストラリアコウハイトウカブファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12651': FundCodeEntry(
        fund_code='G12651',
        sec_code=None,
        fund_name='テンプルトン新興国小型株ファンド',
        fund_name_yomi='テンプルトンシンコウコクコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12652': FundCodeEntry(
        fund_code='G12652',
        sec_code=None,
        fund_name='ＹＭアセット・オーストラリア好配当資産ファンド',
        fund_name_yomi='ワイエムアセットオーストラリアコウハイトウシサンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E32437',
        issuer_name='ワイエムアセットマネジメント株式会社',
    ),
    'G12654': FundCodeEntry(
        fund_code='G12654',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－東京海上・ＣＡＴボンド・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリートウキョウカイジョウキャットボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G12656': FundCodeEntry(
        fund_code='G12656',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000Ｓ＆Ｐ５００インデックス',
        fund_name_yomi='アイフリーエスアンドピーゴヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12657': FundCodeEntry(
        fund_code='G12657',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000外国株式インデックス（為替ヘッジあり）',
        fund_name_yomi='アイフリーガイコクカブシキインデックスカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12658': FundCodeEntry(
        fund_code='G12658',
        sec_code=None,
        fund_name='厳選ジャパン',
        fund_name_yomi='ゲンセンジャパン',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12659': FundCodeEntry(
        fund_code='G12659',
        sec_code=None,
        fund_name='新シルクロード経済圏ファンド',
        fund_name_yomi='シンシルクロードケイザイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12662': FundCodeEntry(
        fund_code='G12662',
        sec_code=None,
        fund_name='目標利回り追求型債券ファンド',
        fund_name_yomi='モクヒョウリマワリツイキュウガタサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12663': FundCodeEntry(
        fund_code='G12663',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔエコイノベーション',
        fund_name_yomi='アイトラストエコイノベーション',
        security_type='内国投資信託受益証券',
        period_1='11月26日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12664': FundCodeEntry(
        fund_code='G12664',
        sec_code=None,
        fund_name='いちよし・インベスコ\u3000世界中小型成長株ファンド',
        fund_name_yomi='イチヨシ\u3000インベスコ\u3000セカイチュウコガタセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月28日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G12665': FundCodeEntry(
        fund_code='G12665',
        sec_code=None,
        fund_name='全世界株式インデックス・ファンド',
        fund_name_yomi='ゼンセカイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12669': FundCodeEntry(
        fund_code='G12669',
        sec_code=None,
        fund_name='ＡＩ（人工知能）活用型世界株ファンド',
        fund_name_yomi='エーアイジンコウチノウカツヨウガタセカイカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月23日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12670': FundCodeEntry(
        fund_code='G12670',
        sec_code=None,
        fund_name='ワールド・リート・オープン（資産成長型）為替ヘッジあり',
        fund_name_yomi='ワールドリートオープンシサンセイチョウガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12671': FundCodeEntry(
        fund_code='G12671',
        sec_code=None,
        fund_name='グローバル・フィンテック株式ファンド（為替ヘッジあり）',
        fund_name_yomi='グローバル\u3000フィンテックカブシキファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12672': FundCodeEntry(
        fund_code='G12672',
        sec_code=None,
        fund_name='グローバル・フィンテック株式ファンド（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='グローバル\u3000フィンテックカブシキファンド\u3000カワセヘッジアリ\u3000ネンニカイケツサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12673': FundCodeEntry(
        fund_code='G12673',
        sec_code=None,
        fund_name='グローバル・フィンテック株式ファンド（年２回決算型）',
        fund_name_yomi='グローバル\u3000フィンテックカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12674': FundCodeEntry(
        fund_code='G12674',
        sec_code=None,
        fund_name='ＳＢＩインド・スリランカ・バランス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000インド\u3000スリランカ\u3000バランス\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2='10月5日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12675': FundCodeEntry(
        fund_code='G12675',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－償還時目標設定型ファンド１７１０',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ショウカンジモクヒョウセッテイガタファンドイチナナイチゼロ',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G12676': FundCodeEntry(
        fund_code='G12676',
        sec_code=None,
        fund_name='三井住友・資産最適化ファンド（１安定重視型）、三井住友・資産最適化ファンド（２やや安定型）、三井住友・資産最適化ファンド（３バランス型）、三井住友・資産最適化ファンド（４やや成長型）、三井住友・資産最適化ファンド（５成長重視型）',
        fund_name_yomi='ミツイスミトモシサンサイテキカファンドイチアンテイジュウシガタ\u3000ミツイスミトモシサンサイテキカファンドニヤヤアンテイガタ\u3000ミツイスミトモシサンサイテキカファンドサンバランスガタ\u3000ミツイスミトモシサンサイテキカファンドヨンヤヤセイチョウガタ\u3000ミツイスミトモシサンサイテキカファンドゴセイチョウジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12677': FundCodeEntry(
        fund_code='G12677',
        sec_code=None,
        fund_name='野村６資産均等バランス',
        fund_name_yomi='ノムラロクシサンキントウバランス',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12678': FundCodeEntry(
        fund_code='G12678',
        sec_code='92840',
        fund_name='カナディアン・ソーラー・インフラ投資法人',
        fund_name_yomi='カナディアンソーラーインフラトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E33433',
        issuer_name='カナディアン・ソーラー・インフラ投資法人',
    ),
    'G12679': FundCodeEntry(
        fund_code='G12679',
        sec_code=None,
        fund_name='日本株式・Ｊリートバランスファンド',
        fund_name_yomi='ニホンカブシキジェイリートバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12680': FundCodeEntry(
        fund_code='G12680',
        sec_code=None,
        fund_name='ＪＰＭザ・ジャパン（年４回決算型）',
        fund_name_yomi='ジェイピーエムザジャパンネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G12681': FundCodeEntry(
        fund_code='G12681',
        sec_code='16560',
        fund_name='ｉシェアーズ・コア\u3000米国債７－１０年\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000コア\u3000ベイコクサイナナ\u3000ジュウネン\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12682': FundCodeEntry(
        fund_code='G12682',
        sec_code='16590',
        fund_name='ｉシェアーズ\u3000米国リート\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクリート\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12683': FundCodeEntry(
        fund_code='G12683',
        sec_code='16580',
        fund_name='ｉシェアーズ・コア\u3000ＭＳＣＩ\u3000新興国株\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000コア\u3000エムエスシーアイ\u3000シンコウコクカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12684': FundCodeEntry(
        fund_code='G12684',
        sec_code='16570',
        fund_name='ｉシェアーズ・コア\u3000ＭＳＣＩ\u3000先進国株（除く日本）ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000コア\u3000エムエスシーアイ\u3000センシンコクカブノゾクニホン\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12685': FundCodeEntry(
        fund_code='G12685',
        sec_code='16550',
        fund_name='ｉシェアーズ\u3000Ｓ＆Ｐ\u3000５００\u3000米国株\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エスアンドピー\u3000ゴヒャク\u3000ベイコクカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12686': FundCodeEntry(
        fund_code='G12686',
        sec_code=None,
        fund_name='東京海上・グローバルＭ＆Ａ戦略ファンド',
        fund_name_yomi='トウキョウカイジョウグローバルエムアンドエーセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12687': FundCodeEntry(
        fund_code='G12687',
        sec_code=None,
        fund_name='あいちファンド（為替モメンタム戦略型）',
        fund_name_yomi='アイチファンド\u3000カワセモメンタムセンリャクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月2日',
        period_2='8月2日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12688': FundCodeEntry(
        fund_code='G12688',
        sec_code=None,
        fund_name='米国株式ＬＳファンド（ＳＭＡ専用）',
        fund_name_yomi='ベイコクカブシキエルエスファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12689': FundCodeEntry(
        fund_code='G12689',
        sec_code=None,
        fund_name='ＴＯＲＡＮＯＴＥＣアクティブジャパン',
        fund_name_yomi='トラノテックアクティブジャパン',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E14235',
        issuer_name='ＴＯＲＡＮＯＴＥＣ投信投資顧問株式会社',
    ),
    'G12690': FundCodeEntry(
        fund_code='G12690',
        sec_code=None,
        fund_name='ブラックロック・つみたて・グローバルバランスファンド',
        fund_name_yomi='ブラックロックツミタテグローバルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12692': FundCodeEntry(
        fund_code='G12692',
        sec_code='16510',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸ高配当４０指数',
        fund_name_yomi='アイフリーイーティーエフトピックスコウハイトウヨンジュウシスウ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12693': FundCodeEntry(
        fund_code='G12693',
        sec_code='16540',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＦＴＳＥ\u3000ＪＰＸ\u3000Ｂｌｏｓｓｏｍ\u3000Ｊａｐａｎ\u3000Ｉｎｄｅｘ',
        fund_name_yomi='アイフリーイーティーエフエフティーエスイージェイピーエックスブロッサムジャパンインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12694': FundCodeEntry(
        fund_code='G12694',
        sec_code='16530',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＭＳＣＩジャパンＥＳＧセレクト・リーダーズ指数',
        fund_name_yomi='アイフリーイーティーエフエムエスシーアイジャパンイーエスジーセレクトリーダーズシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12695': FundCodeEntry(
        fund_code='G12695',
        sec_code='16520',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＭＳＣＩ日本株女性活躍指数（ＷＩＮ）',
        fund_name_yomi='アイフリーイーティーエフエムエスシーアイニホンカブジョセイカツヤクシスウウィン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12696': FundCodeEntry(
        fund_code='G12696',
        sec_code=None,
        fund_name='米国株式インデックス・ファンド',
        fund_name_yomi='ベイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G12698': FundCodeEntry(
        fund_code='G12698',
        sec_code=None,
        fund_name='ゴールド・ファンド\u3000為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='ゴールド\u3000ファンド\u3000カワセヘッジアリ\u3000エスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12699': FundCodeEntry(
        fund_code='G12699',
        sec_code=None,
        fund_name='楽天・全世界株式インデックス・ファンド',
        fund_name_yomi='ラクテンゼンセカイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12700': FundCodeEntry(
        fund_code='G12700',
        sec_code=None,
        fund_name='楽天・全米株式インデックス・ファンド',
        fund_name_yomi='ラクテンゼンベイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12701': FundCodeEntry(
        fund_code='G12701',
        sec_code=None,
        fund_name='ＪＰ４資産均等バランス',
        fund_name_yomi='ジェイピーヨンシサンキントウバランス',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E32151',
        issuer_name='ＪＰ投信株式会社',
    ),
    'G12702': FundCodeEntry(
        fund_code='G12702',
        sec_code=None,
        fund_name='野村つみたて日本株投信',
        fund_name_yomi='ノムラツミタテニホンカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12703': FundCodeEntry(
        fund_code='G12703',
        sec_code=None,
        fund_name='野村つみたて外国株投信',
        fund_name_yomi='ノムラツミタテガイコクカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12704': FundCodeEntry(
        fund_code='G12704',
        sec_code=None,
        fund_name='三井住友・ＤＣつみたてＮＩＳＡ・世界分散ファンド',
        fund_name_yomi='ミツイスミトモディーシーツミタテニーサセカイブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12705': FundCodeEntry(
        fund_code='G12705',
        sec_code=None,
        fund_name='つみたてバランスファンド',
        fund_name_yomi='ツミタテバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12707': FundCodeEntry(
        fund_code='G12707',
        sec_code=None,
        fund_name='ピムコ・インカム・ストラテジー・ファンド＜限定為替ヘッジあり＞（毎月決算型）／（年２回決算型）ピムコ・インカム・ストラテジー・ファンド＜為替ヘッジなし＞（毎月決算型）／（年２回決算型）',
        fund_name_yomi='ピムコインカムストラテジーファンドゲンテイカワセヘッジアリマイツキケッサンガタネンニカイケッサンガタピムコインカムストラテジーファンドカワセヘッジナシマイツキケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12708': FundCodeEntry(
        fund_code='G12708',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000マイマネージャー\u3000１９７０ｓ／１９８０ｓ／１９９０ｓ',
        fund_name_yomi='イーマクシスマイマネージャーセブンティーズエイティーズナインティーズ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12710': FundCodeEntry(
        fund_code='G12710',
        sec_code=None,
        fund_name='フィデリティ・オーストラリア配当株投信（資産成長型）',
        fund_name_yomi='フィデリティオーストラリアハイトウカブトウシンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12711': FundCodeEntry(
        fund_code='G12711',
        sec_code=None,
        fund_name='東京海上・円資産インデックスバランスファンド',
        fund_name_yomi='トウキョウカイジョウエンシサンインデックスバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G12714': FundCodeEntry(
        fund_code='G12714',
        sec_code=None,
        fund_name='ダイワ／ジャナス米国中型グロース株ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ダイワジャナスベイコクチュウガタグロースカブファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12715': FundCodeEntry(
        fund_code='G12715',
        sec_code=None,
        fund_name='ニッポン創業経営者ファンド',
        fund_name_yomi='ニッポンソウギョウケイエイシャファンド',
        security_type='内国投資信託受益証券',
        period_1='10月27日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12716': FundCodeEntry(
        fund_code='G12716',
        sec_code='16600',
        fund_name='ＭＡＸＩＳ高利回りＪリート上場投信',
        fund_name_yomi='マクシスコウリマワリジェーリートジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12717': FundCodeEntry(
        fund_code='G12717',
        sec_code=None,
        fund_name='キャピタル・グローバル中期債ファンドＦ（米ドル売り円買い）',
        fund_name_yomi='キャピタルグローバルチュウキサイファンドエフベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G12718': FundCodeEntry(
        fund_code='G12718',
        sec_code=None,
        fund_name='キャピタル・ニューワールド・ファンドＦ（米ドル売り円買い）',
        fund_name_yomi='キャピタルニューワールドファンドエフベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G12719': FundCodeEntry(
        fund_code='G12719',
        sec_code=None,
        fund_name='ニッセイ新興国株式インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイシンコウコクカブシキインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12720': FundCodeEntry(
        fund_code='G12720',
        sec_code=None,
        fund_name='ニッセイ・インデックスバランスファンド（６資産均等型）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイインデックスバランスファンドロクシサンキントウガタコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12721': FundCodeEntry(
        fund_code='G12721',
        sec_code=None,
        fund_name='ニッセイ／コムジェスト新興国成長株ファンド（資産成長型）',
        fund_name_yomi='ニッセイコムジェストシンコウコクセイチョウカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12722': FundCodeEntry(
        fund_code='G12722',
        sec_code=None,
        fund_name='ニッセイ／コムジェスト新興国成長株ファンド（年２回決算型）',
        fund_name_yomi='ニッセイコムジェストシンコウコクセイチョウカブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12723': FundCodeEntry(
        fund_code='G12723',
        sec_code=None,
        fund_name='しんきんノーロード日経２２５',
        fund_name_yomi='シンキンノーロードニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G12725': FundCodeEntry(
        fund_code='G12725',
        sec_code=None,
        fund_name='ロックフェラー米国中小型イノベーターズ・ファンド',
        fund_name_yomi='ロックフェラーベイコクチュウコガタイノベーターズファンド',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12729': FundCodeEntry(
        fund_code='G12729',
        sec_code=None,
        fund_name='日興ＦＷ・日本債券ファンド',
        fund_name_yomi='ニッコウエフダブリューニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12731': FundCodeEntry(
        fund_code='G12731',
        sec_code=None,
        fund_name='日本株ロング・ショート・ストラテジー・ファンド',
        fund_name_yomi='ニホンカブロング\u3000ショート\u3000ストラテジー\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2='7月28日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G12732': FundCodeEntry(
        fund_code='G12732',
        sec_code=None,
        fund_name='フィデリティ・ＵＳハイ・イールド・ファンド（毎月決算型）Ａ（為替ヘッジあり）',
        fund_name_yomi='フィデリティユーエスハイイールドファンドマイツキケッサンガタエーカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12733': FundCodeEntry(
        fund_code='G12733',
        sec_code=None,
        fund_name='フィデリティ・ＵＳハイ・イールド・ファンド（資産成長型）Ｃ（為替ヘッジあり）',
        fund_name_yomi='フィデリティユーエスハイイールドファンドシサンセイチョウガタシーカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12734': FundCodeEntry(
        fund_code='G12734',
        sec_code=None,
        fund_name='ＳＭＴ\u3000欧州株配当貴族インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000オウシュウカブハイトウキゾクインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12735': FundCodeEntry(
        fund_code='G12735',
        sec_code=None,
        fund_name='グローバル経済コア',
        fund_name_yomi='グローバルケイザイコア',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12736': FundCodeEntry(
        fund_code='G12736',
        sec_code=None,
        fund_name='いちよし\u3000ジャパン・ベンチャー・ファンド',
        fund_name_yomi='イチヨシジャパンベンチャーファンド',
        security_type='内国投資信託受益証券',
        period_1='11月29日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12737': FundCodeEntry(
        fund_code='G12737',
        sec_code=None,
        fund_name='パインブリッジ米国ライジングスター好利回り債券ファンド２０１７－１２（限定追加型・為替ヘッジあり・早期償還条項付）',
        fund_name_yomi='パインブリッジベイコクライジングスターコウリマワリサイケンファンドニセンジュウナナノジュウニゲンテイツイカガタカワセヘッジアリソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G12740': FundCodeEntry(
        fund_code='G12740',
        sec_code=None,
        fund_name='楽天・新興国株式インデックス・ファンド',
        fund_name_yomi='ラクテンシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12741': FundCodeEntry(
        fund_code='G12741',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000日経２２５インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ニッケイニーニーゴインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12742': FundCodeEntry(
        fund_code='G12742',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000グローバル株式インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000グローバルカブシキインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12744': FundCodeEntry(
        fund_code='G12744',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ゴールドインデックス・オープン（為替ヘッジあり）',
        fund_name_yomi='エスエムティー\u3000ゴールドインデックス\u3000オープン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12745': FundCodeEntry(
        fund_code='G12745',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ゴールドインデックス・オープン（為替ヘッジなし）',
        fund_name_yomi='エスエムティー\u3000ゴールドインデックス\u3000オープン\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12746': FundCodeEntry(
        fund_code='G12746',
        sec_code=None,
        fund_name='深セン・イノベーション株式ファンド（１年決算型）',
        fund_name_yomi='シンセン\u3000イノベーションカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12747': FundCodeEntry(
        fund_code='G12747',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・インベストメント・ファンズ－フランクリン・オルタナティブ・ストラテジーズ・ファンド',
        fund_name_yomi='フランクリンテンプルトンインベストメントファンズフランクリンオルタナティブストラテジーズファンド',
        security_type='外国投資証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E33576',
        issuer_name='フランクリン・テンプルトン・インベストメント・ファンズ',
    ),
    'G12748': FundCodeEntry(
        fund_code='G12748',
        sec_code=None,
        fund_name='たわらノーロード\u3000バランス（堅実型）、たわらノーロード\u3000バランス（標準型）、たわらノーロード\u3000バランス（積極型）',
        fund_name_yomi='タワラノーロードバランスケンジツガタ\u3000タワラノーロードバランスヒョウジュンガタ\u3000タワラノーロードバランスセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12749': FundCodeEntry(
        fund_code='G12749',
        sec_code=None,
        fund_name='ワールドコーポレート・ハイブリッド証券ファンド１７１２（限定追加型）',
        fund_name_yomi='ワールドコーポレート\u3000ハイブリッドショウケンファンドイチナナイチニ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12752': FundCodeEntry(
        fund_code='G12752',
        sec_code=None,
        fund_name='高成長インド・中型株式ファンド（年１回決算型）',
        fund_name_yomi='コウセイチョウインドチュウガタカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12753': FundCodeEntry(
        fund_code='G12753',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ユーロ・ハイ・イールド債券ファンド（年１回決算型）Ｃコース（円ヘッジあり）／Ｄコース（円ヘッジなし）',
        fund_name_yomi='ディーダブリューエス\u3000ユーロハイイールドサイケンファンドネンイッカイケッサンガタ\u3000シーコースエンヘッジアリ\u3000ディーコースエンヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G12754': FundCodeEntry(
        fund_code='G12754',
        sec_code=None,
        fund_name='ニッセイ・インデックスパッケージ（内外・株式）',
        fund_name_yomi='ニッセイインデックスパッケージナイガイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12755': FundCodeEntry(
        fund_code='G12755',
        sec_code=None,
        fund_name='ニッセイ・インデックスパッケージ（内外・株式／リート）',
        fund_name_yomi='ニッセイインデックスパッケージナイガイカブシキリート',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12756': FundCodeEntry(
        fund_code='G12756',
        sec_code=None,
        fund_name='ニッセイ・インデックスパッケージ（内外・株式／リート／債券）',
        fund_name_yomi='ニッセイインデックスパッケージナイガイカブシキリートサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12757': FundCodeEntry(
        fund_code='G12757',
        sec_code=None,
        fund_name='ニッセイ・インデックスパッケージ（国内・株式／リート／債券）',
        fund_name_yomi='ニッセイインデックスパッケージコクナイカブシキリートサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12760': FundCodeEntry(
        fund_code='G12760',
        sec_code=None,
        fund_name='新興国ハイクオリティ成長株式ファンド',
        fund_name_yomi='シンコウコクハイクオリティセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12763': FundCodeEntry(
        fund_code='G12763',
        sec_code=None,
        fund_name='スカイオーシャン・世界債券戦略ファンド',
        fund_name_yomi='スカイオーシャンセカイサイケンセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G12764': FundCodeEntry(
        fund_code='G12764',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000日本株ダブル・ブルファンド',
        fund_name_yomi='ワン\u3000ニホンカブダブルブルファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12765': FundCodeEntry(
        fund_code='G12765',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000日本株ダブル・ベアファンド',
        fund_name_yomi='ワン\u3000ニホンカブダブルベアファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12766': FundCodeEntry(
        fund_code='G12766',
        sec_code=None,
        fund_name='たわらノーロード\u3000スマートグローバルバランス（保守型）、たわらノーロード\u3000スマートグローバルバランス（安定型）、たわらノーロード\u3000スマートグローバルバランス（安定成長型）、たわらノーロード\u3000スマートグローバルバランス（成長型）、たわらノーロード\u3000スマートグローバルバランス（積極型）',
        fund_name_yomi='タワラノーロードスマートグローバルバランスホシュガタ\u3000タワラノーロードスマートグローバルバランスアンテイガタ\u3000タワラノーロードスマートグローバルバランスアンテイセイチョウガタ\u3000タワラノーロードスマートグローバルバランスセイチョウガタ\u3000タワラノーロードスマートグローバルバランスセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12768': FundCodeEntry(
        fund_code='G12768',
        sec_code=None,
        fund_name='投資のソムリエ（ターゲット・イヤー２０３５）',
        fund_name_yomi='トウシノソムリエターゲットイヤーニイゼロサンゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12769': FundCodeEntry(
        fund_code='G12769',
        sec_code=None,
        fund_name='マニュライフ・米国投資適格債券戦略ファンド\u3000Ａコース（為替ヘッジあり・毎月）／Ｂコース（為替ヘッジなし・毎月）、マニュライフ・米国投資適格債券戦略ファンド\u3000Ｃコース（為替ヘッジあり・年２回）／Ｄコース（為替ヘッジなし・年２回）',
        fund_name_yomi='マニュライフベイコクトウシテキカクサイケンセンリャクファンドエーコースカワセヘッジアリマイツキビーコースカワセヘッジナシマイツキ\u3000マニュライフベイコクトウシテキカクサイケンセンリャクファンドシーコースカワセヘッジアリネンニカイディーコースカワセヘッジナシネンニカイ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G12770': FundCodeEntry(
        fund_code='G12770',
        sec_code='14980',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000ＥＳＧ',
        fund_name_yomi='ワンイーティーエフイーエスジー',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12771': FundCodeEntry(
        fund_code='G12771',
        sec_code=None,
        fund_name='中欧株式ファンド',
        fund_name_yomi='チュウオウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G12772': FundCodeEntry(
        fund_code='G12772',
        sec_code=None,
        fund_name='ＧＳビッグデータ・ストラテジー（外国株式）',
        fund_name_yomi='ジーエス\u3000ビッグデータ\u3000ストラテジー\u3000ガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12773': FundCodeEntry(
        fund_code='G12773',
        sec_code=None,
        fund_name='ＳＢＩ・新興国株式インデックス・ファンド',
        fund_name_yomi='エスビーアイシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12774': FundCodeEntry(
        fund_code='G12774',
        sec_code=None,
        fund_name='ＳＢＩ・全世界株式インデックス・ファンド',
        fund_name_yomi='エスビーアイゼンセカイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12775': FundCodeEntry(
        fund_code='G12775',
        sec_code=None,
        fund_name='次世代通信関連\u3000世界株式戦略ファンド',
        fund_name_yomi='ジセダイツウシンカンレン\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12776': FundCodeEntry(
        fund_code='G12776',
        sec_code=None,
        fund_name='ダイワ／ミレーアセット・インド株式ファンド\u3000－インドの匠－',
        fund_name_yomi='ダイワミレーアセットインドカブシキファンドインドノタクミ',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12777': FundCodeEntry(
        fund_code='G12777',
        sec_code=None,
        fund_name='ドイチェ・ＥＴＦバランス・ファンド',
        fund_name_yomi='ドイチェイーティーエフバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月7日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G12778': FundCodeEntry(
        fund_code='G12778',
        sec_code=None,
        fund_name='パインブリッジ日本企業外貨建て社債ファンド（為替ヘッジあり）（為替ヘッジなし）',
        fund_name_yomi='パインブリッジニホンキギョウガイカダテシャサイファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G12779': FundCodeEntry(
        fund_code='G12779',
        sec_code=None,
        fund_name='ＬＭ・アジア・オセアニア・インカム資産ファンド（毎月分配型／３ヵ月決算型／年２回決算型）',
        fund_name_yomi='エルエム\u3000アジア\u3000オセアニア\u3000インカムシサンファンド\u3000マイツキブンパイガタ\u3000サンカゲツケッサンガタ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月2日',
        period_2='12月2日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G12780': FundCodeEntry(
        fund_code='G12780',
        sec_code='25140',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000外国株式・ＭＳＣＩ－ＫＯＫＵＳＡＩ指数（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズガイコクカブシキエムエスシーアイコクサイシスウカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12781': FundCodeEntry(
        fund_code='G12781',
        sec_code='25130',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000外国株式・ＭＳＣＩ－ＫＯＫＵＳＡＩ指数（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズガイコクカブシキエムエスシーアイコクサイシスウカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12782': FundCodeEntry(
        fund_code='G12782',
        sec_code='25120',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000外国債券・ＦＴＳＥ世界国債インデックス（除く日本・為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズガイコクサイケンフッツィーセカイコクサイインデックスノゾクニホンカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12783': FundCodeEntry(
        fund_code='G12783',
        sec_code='25110',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000外国債券・ＦＴＳＥ世界国債インデックス（除く日本・為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズガイコクサイケンフッツィーセカイコクサイインデックスノゾクニホンカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12784': FundCodeEntry(
        fund_code='G12784',
        sec_code='25150',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000外国ＲＥＩＴ・Ｓ＆Ｐ先進国ＲＥＩＴ指数（除く日本・為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズガイコクリートエスアンドピーセンシンコクリートシスウノゾクニホンカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12785': FundCodeEntry(
        fund_code='G12785',
        sec_code='25100',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000国内債券・ＮＯＭＵＲＡ－ＢＰＩ総合連動型上場投信',
        fund_name_yomi='ネクストファンズコクナイサイケンノムラビーピーアイソウゴウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12786': FundCodeEntry(
        fund_code='G12786',
        sec_code=None,
        fund_name='ＳＢＩ資産設計オープン（つみたてＮＩＳＡ対応型）',
        fund_name_yomi='エスビーアイシサンセッケイオープン\u3000ツミタテニーサタイオウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12789': FundCodeEntry(
        fund_code='G12789',
        sec_code=None,
        fund_name='ＧＳビッグデータ・ストラテジー（エマージング株）',
        fund_name_yomi='ジーエスビッグデータストラテジーエマージングカブ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12790': FundCodeEntry(
        fund_code='G12790',
        sec_code=None,
        fund_name='ＧＳビッグデータ・ストラテジー（欧州株）Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエスビッグデータストラテジーオウシュウカブ\u3000エーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G12791': FundCodeEntry(
        fund_code='G12791',
        sec_code=None,
        fund_name='野村外国株インデックス\u3000Ａコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクカブインデックスエーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12792': FundCodeEntry(
        fund_code='G12792',
        sec_code=None,
        fund_name='野村外国債券インデックス\u3000Ａコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクサイケンインデックスエーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12793': FundCodeEntry(
        fund_code='G12793',
        sec_code=None,
        fund_name='野村世界ＲＥＩＴインデックス\u3000Ａコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラセカイリートインデックスエーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12794': FundCodeEntry(
        fund_code='G12794',
        sec_code=None,
        fund_name='野村外国株（含む新興国）インデックス\u3000Ａコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクカブフクムシンコウコクインデックスエーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12795': FundCodeEntry(
        fund_code='G12795',
        sec_code=None,
        fund_name='野村外国株（含む新興国）インデックス\u3000Ｂコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクカブフクムシンコウコクインデックスビーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12796': FundCodeEntry(
        fund_code='G12796',
        sec_code=None,
        fund_name='野村外国債券（含む新興国）インデックス\u3000Ａコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクサイケンフクムシンコウコクインデックスエーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12797': FundCodeEntry(
        fund_code='G12797',
        sec_code=None,
        fund_name='野村外国債券（含む新興国）インデックス\u3000Ｂコース（野村投資一任口座向け）',
        fund_name_yomi='ノムラガイコクサイケンフクムシンコウコクインデックスビーコースノムラトウシイチニンコウザムケ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12800': FundCodeEntry(
        fund_code='G12800',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金バランス（株式１５）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンバランスカブシキジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12801': FundCodeEntry(
        fund_code='G12801',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金バランス（株式４０）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンバランスカブシキヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12802': FundCodeEntry(
        fund_code='G12802',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金バランス（株式６５）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンバランスカブシキロクジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12803': FundCodeEntry(
        fund_code='G12803',
        sec_code='34870',
        fund_name='ＣＲＥロジスティクスファンド投資法人',
        fund_name_yomi='シーアールイーロジスティクスファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E33664',
        issuer_name='ＣＲＥロジスティクスファンド投資法人',
    ),
    'G12805': FundCodeEntry(
        fund_code='G12805',
        sec_code=None,
        fund_name='ＪＰＭグローバル高利回りＣＢファンド（限定追加型・早期償還条項付）２０１８－０２',
        fund_name_yomi='ジェイピーエムグローバルコウリマワリシービーファンドゲンテイツイカガタソウキショウカンジョウコウツキニセンジュウハチノゼロニ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G12806': FundCodeEntry(
        fund_code='G12806',
        sec_code='14990',
        fund_name='ＭＡＸＩＳ日本株高配当７０マーケットニュートラル上場投信',
        fund_name_yomi='マクシスニホンカブコウハイトウナナジュウマーケットニュートラルジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12807': FundCodeEntry(
        fund_code='G12807',
        sec_code=None,
        fund_name='ターゲット・リターン戦略ファンド',
        fund_name_yomi='ターゲットリターンセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12808': FundCodeEntry(
        fund_code='G12808',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000新興国株式インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000シンコウコクカブシキインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12809': FundCodeEntry(
        fund_code='G12809',
        sec_code=None,
        fund_name='野村ウエスタン・世界債券戦略ファンド\u3000Ａコース、野村ウエスタン・世界債券戦略ファンド\u3000Ｂコース、野村ウエスタン・世界債券戦略ファンド\u3000Ｃコース、野村ウエスタン・世界債券戦略ファンド\u3000Ｄコース',
        fund_name_yomi='ノムラウエスタンセカイサイケンセンリャクファンドエーコース\u3000ノムラウエスタンセカイサイケンセンリャクファンドビーコース\u3000ノムラウエスタンセカイサイケンセンリャクファンドシーコース\u3000ノムラウエスタンセカイサイケンセンリャクファンドディーコース',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12810': FundCodeEntry(
        fund_code='G12810',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞つみたて日本株式\u3000日経２２５',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ツミタテニホンカブシキ\u3000ニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G12811': FundCodeEntry(
        fund_code='G12811',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞つみたて米国株式\u3000Ｓ＆Ｐ５００',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ツミタテベイコクカブシキ\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G12812': FundCodeEntry(
        fund_code='G12812',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000ＴＯＰＩＸインデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000トピックスインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12814': FundCodeEntry(
        fund_code='G12814',
        sec_code=None,
        fund_name='ＳＢＩ\u3000日本株４．３ブル',
        fund_name_yomi='エスビーアイ\u3000ニホンカブヨンテンサン\u3000ブル',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12815': FundCodeEntry(
        fund_code='G12815',
        sec_code=None,
        fund_name='ニッセイＡＩ関連株式ファンド（年２回決算型・為替ヘッジあり）／ニッセイＡＩ関連株式ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイエーアイカンレンカブシキファンドネンニカイケッサンガタカワセヘッジアリ\u3000ニッセイエーアイカンレンカブシキファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12816': FundCodeEntry(
        fund_code='G12816',
        sec_code=None,
        fund_name='ＤＣダイワ・グローバルＲＥＩＴアクティブ・ファンド',
        fund_name_yomi='ディーシーダイワグローバルリートアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12817': FundCodeEntry(
        fund_code='G12817',
        sec_code=None,
        fund_name='くまもと未来応援ファンド',
        fund_name_yomi='クマモトミライオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12818': FundCodeEntry(
        fund_code='G12818',
        sec_code=None,
        fund_name='野村ＤＣ・ＰＩＭＣＯ・世界インカム戦略ファンド（為替ヘッジあり）',
        fund_name_yomi='ノムラディーシーピムコセカイインカムセンリャクファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12819': FundCodeEntry(
        fund_code='G12819',
        sec_code=None,
        fund_name='国際インド債券オープン（年１回決算型）',
        fund_name_yomi='コクサイインドサイケンオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12820': FundCodeEntry(
        fund_code='G12820',
        sec_code=None,
        fund_name='キャピタル・インベストメント・カンパニー・オブ・アメリカ\u3000ＩＣＡ',
        fund_name_yomi='キャピタルインベストメントカンパニーオブアメリカアイシーエイ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G12821': FundCodeEntry(
        fund_code='G12821',
        sec_code=None,
        fund_name='収益追求（資産・運用手法分散）投資ファンド',
        fund_name_yomi='シュウエキツイキュウ\u3000シサン\u3000ウンヨウシュホウブンサン\u3000トウシファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12824': FundCodeEntry(
        fund_code='G12824',
        sec_code='34880',
        fund_name='セントラル・リート投資法人',
        fund_name_yomi='セントラルリートトウシホウジン',
        security_type='内国投資証券',
        period_1='8月末日',
        period_2='2月末日',
        edinet_code='E33700',
        issuer_name='セントラル・リート投資法人',
    ),
    'G12825': FundCodeEntry(
        fund_code='G12825',
        sec_code=None,
        fund_name='ＳＢＩ・先進国株式インデックス・ファンド',
        fund_name_yomi='エスビーアイセンシンコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12827': FundCodeEntry(
        fund_code='G12827',
        sec_code=None,
        fund_name='三井住友・日経アジア３００ｉインデックスファンド',
        fund_name_yomi='ミツイスミトモニッケイアジアサンビャクアイインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12829': FundCodeEntry(
        fund_code='G12829',
        sec_code=None,
        fund_name='ユナイテッド・マルチ・マネージャー・ファンド１',
        fund_name_yomi='ユナイテッドマルチマネージャーファンドイチ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G12830': FundCodeEntry(
        fund_code='G12830',
        sec_code=None,
        fund_name='ユナイテッド・タートルクラブ・ファンド・シリーズ',
        fund_name_yomi='ユナイテッドタートルクラブファンドシリーズ',
        security_type='内国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G12831': FundCodeEntry(
        fund_code='G12831',
        sec_code=None,
        fund_name='ディープリサーチ・チャイナ・ファンド',
        fund_name_yomi='ディープリサーチチャイナファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G12832': FundCodeEntry(
        fund_code='G12832',
        sec_code=None,
        fund_name='ブラックロック・ベストバランス戦略ファンド（年１回決算型）',
        fund_name_yomi='ブラックロックベストバランスセンリャクファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12833': FundCodeEntry(
        fund_code='G12833',
        sec_code=None,
        fund_name='ブラックロック・ベストバランス戦略ファンド（年２回決算型）',
        fund_name_yomi='ブラックロックベストバランスセンリャクファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12835': FundCodeEntry(
        fund_code='G12835',
        sec_code=None,
        fund_name='アムンディ・ジャパン・プラス債券ファンド（年１回決算）',
        fund_name_yomi='アムンディジャパンプラスサイケンファンドネンイチカイケッサン',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G12836': FundCodeEntry(
        fund_code='G12836',
        sec_code=None,
        fund_name='ニッセイ／ＴＣＷ債券戦略ファンド（資産成長型・為替ヘッジあり）／ニッセイ／ＴＣＷ債券戦略ファンド（資産成長型・為替ヘッジなし）',
        fund_name_yomi='ニッセイティーシーダブリューサイケンセンリャクファンドシサンセイチョウガタカワセヘッシ゛アリ\u3000ニッセイティーシーダブリューサイケンセンリャクファンドシサンセイチョウガタカワセヘッシ゛ナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12837': FundCodeEntry(
        fund_code='G12837',
        sec_code=None,
        fund_name='ニッセイ／ＴＣＷ債券戦略ファンド（３ヵ月決算型・為替ヘッジあり）／ニッセイ／ＴＣＷ債券戦略ファンド（３ヵ月決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイティーシーダブリューサイケンセンリャクファンドサンカゲツケッサンガタカワセヘッジアリ\u3000ニッセイティーシーダブリューサイケンセンリャクファンドサンカゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12839': FundCodeEntry(
        fund_code='G12839',
        sec_code=None,
        fund_name='楽天・米国高配当株式インデックス・ファンド',
        fund_name_yomi='ラクテンベイコクコウハイトウカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12840': FundCodeEntry(
        fund_code='G12840',
        sec_code=None,
        fund_name='野村ターゲットインカムファンド（年３％目標分配型）',
        fund_name_yomi='ノムラターゲットインカムファンドネンサンパーセントモクヒョウブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12841': FundCodeEntry(
        fund_code='G12841',
        sec_code=None,
        fund_name='楽天グローバル・プレミア・ファンド（ロボット自動運用型）',
        fund_name_yomi='ラクテングローバルプレミアファンドロボットジドウウンヨウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12842': FundCodeEntry(
        fund_code='G12842',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１８‐０２',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチハチノゼロニイ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G12843': FundCodeEntry(
        fund_code='G12843',
        sec_code=None,
        fund_name='ＵＢＳ新興国株式厳選投資ファンド',
        fund_name_yomi='ユービーエスシンコウコクカブシキゲンセントウシファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12844': FundCodeEntry(
        fund_code='G12844',
        sec_code=None,
        fund_name='シュローダー・ユーロ・エクイティ・ファンド\u3000為替リスク軽減型／為替ヘッジなし',
        fund_name_yomi='シュローダー\u3000ユーロ\u3000エクイティ\u3000ファンド\u3000カワセリスクケイゲンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G12845': FundCodeEntry(
        fund_code='G12845',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000為替ナビ\u3000Ｅコース、野村ＰＩＭＣＯ・世界インカム戦略ファンド\u3000為替ナビ\u3000Ｆコース',
        fund_name_yomi='ノムラピムコセカイインカムセンリャクファンドカワセナビイーコース\u3000ノムラピムコセカイインカムセンリャクファンドカワセナビエフコース',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12846': FundCodeEntry(
        fund_code='G12846',
        sec_code=None,
        fund_name='日経アジア３００インベスタブル・アクティブ・ファンド',
        fund_name_yomi='ニッケイアジアサンビャクインベスタブルアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12847': FundCodeEntry(
        fund_code='G12847',
        sec_code=None,
        fund_name='オーストラリア・インカム・バランス・ファンド（１年決算型）',
        fund_name_yomi='オーストラリア\u3000インカム\u3000バランス\u3000ファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月14日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12848': FundCodeEntry(
        fund_code='G12848',
        sec_code=None,
        fund_name='オーストラリア・インカム・バランス・ファンド（毎月分配型）',
        fund_name_yomi='オーストラリア\u3000インカム\u3000バランス\u3000ファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12849': FundCodeEntry(
        fund_code='G12849',
        sec_code=None,
        fund_name='パインブリッジ・グローバル・テクノロジー・インフラ・ファンド',
        fund_name_yomi='パインブリッジグローバルテクノロジーインフラファンド',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G12850': FundCodeEntry(
        fund_code='G12850',
        sec_code=None,
        fund_name='モビリティ関連\u3000世界株式戦略ファンド',
        fund_name_yomi='モビリティカンレン\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12851': FundCodeEntry(
        fund_code='G12851',
        sec_code=None,
        fund_name='パインブリッジ米国ライジングスター好利回り債券ファンド２０１８－０２（限定追加型・為替ヘッジあり・早期償還条項付）',
        fund_name_yomi='パインブリッジベイコクライジングスターコウリマワリサイケンファンドニセンジュウハチノニゲンテイツイカガタカワセヘッジアリソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G12852': FundCodeEntry(
        fund_code='G12852',
        sec_code=None,
        fund_name='モビリティ・イノベーション・ファンド',
        fund_name_yomi='モビリティイノベーションファンド',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12853': FundCodeEntry(
        fund_code='G12853',
        sec_code=None,
        fund_name='Ｏｎｅフレキシブル戦略日本株ファンド',
        fund_name_yomi='ワンフレキシブルセンリャクニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12856': FundCodeEntry(
        fund_code='G12856',
        sec_code=None,
        fund_name='たわらノーロード\u3000最適化バランス（保守型）、たわらノーロード\u3000最適化バランス（安定型）、たわらノーロード\u3000最適化バランス（安定成長型）、たわらノーロード\u3000最適化バランス（成長型）、たわらノーロード\u3000最適化バランス（積極型）',
        fund_name_yomi='タワラノーロードサイテキカバランスホシュガタ\u3000タワラノーロードサイテキカバランスアンテイガタ\u3000タワラノーロードサイテキカバランスアンテイセイチョウガタ\u3000タワラノーロードサイテキカバランスセイチョウガタ\u3000タワラノーロードサイテキカバランスセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12857': FundCodeEntry(
        fund_code='G12857',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー\u3000グローバル・インフラ債券ファンド＜為替ヘッジあり＞／＜為替ヘッジなし＞（年１回決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーグローバルインフラサイケンファンドカワセヘッジアリカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12858': FundCodeEntry(
        fund_code='G12858',
        sec_code=None,
        fund_name='ＵＢＳ中国新時代株式ファンド（年１回決算型）',
        fund_name_yomi='ユービーエスチュウゴクシンジダイカブシキファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12859': FundCodeEntry(
        fund_code='G12859',
        sec_code=None,
        fund_name='ＵＢＳ中国新時代株式ファンド（年２回決算型）',
        fund_name_yomi='ユービーエスチュウゴクシンジダイカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G12860': FundCodeEntry(
        fund_code='G12860',
        sec_code=None,
        fund_name='グローバル・モビリティ・サービス株式ファンド（１年決算型）',
        fund_name_yomi='グローバル\u3000モビリティ\u3000サービスカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12861': FundCodeEntry(
        fund_code='G12861',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000日経アジア３００インベスタブル・インデックス',
        fund_name_yomi='イーマクシスニッケイアジアサンビャクインベスタブルインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12862': FundCodeEntry(
        fund_code='G12862',
        sec_code='25160',
        fund_name='東証グロース２５０ＥＴＦ',
        fund_name_yomi='トウショウグロースニヒャクゴジュウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G12863': FundCodeEntry(
        fund_code='G12863',
        sec_code=None,
        fund_name='グローバル・メガピース',
        fund_name_yomi='グローバル\u3000メガピース',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G12864': FundCodeEntry(
        fund_code='G12864',
        sec_code=None,
        fund_name='日経アジア３００インベスタブル・インデックス・ファンド',
        fund_name_yomi='ニッケイアジアサンビャクインベスタブルインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12865': FundCodeEntry(
        fund_code='G12865',
        sec_code=None,
        fund_name='ニッセイ日経アジア３００ｉアクティブファンド（年２回決算型）',
        fund_name_yomi='ニッセイニッケイアジアサンビャクアイアクティブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12866': FundCodeEntry(
        fund_code='G12866',
        sec_code=None,
        fund_name='ニッセイ日経アジア３００ｉアクティブファンド（資産成長型）',
        fund_name_yomi='ニッセイニッケイアジアサンビャクアイアクティブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12867': FundCodeEntry(
        fund_code='G12867',
        sec_code=None,
        fund_name='三井住友・日本株式ＥＳＧファンド',
        fund_name_yomi='ミツイスミトモニホンカブシキイーエスジーファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12871': FundCodeEntry(
        fund_code='G12871',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＦＡＮＧ＋インデックス',
        fund_name_yomi='アイフリーネクストファングプラスインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12872': FundCodeEntry(
        fund_code='G12872',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＮＡＳＤＡＱバイオテクノロジー・インデックス',
        fund_name_yomi='アイフリーネクストナスダックバイオテクノロジーインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12873': FundCodeEntry(
        fund_code='G12873',
        sec_code=None,
        fund_name='ｉＦｒｅｅＡｃｔｉｖｅ\u3000ゲーム＆ｅスポーツ',
        fund_name_yomi='アイフリーアクティブゲームアンドイースポーツ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12874': FundCodeEntry(
        fund_code='G12874',
        sec_code=None,
        fund_name='ｉＦｒｅｅＡｃｔｉｖｅ\u3000エドテック',
        fund_name_yomi='アイフリーアクティブエドテック',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12875': FundCodeEntry(
        fund_code='G12875',
        sec_code=None,
        fund_name='ｉＦｒｅｅＡｃｔｉｖｅ\u3000ＥＶ',
        fund_name_yomi='アイフリーアクティブイーブイ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12876': FundCodeEntry(
        fund_code='G12876',
        sec_code=None,
        fund_name='ｉＦｒｅｅＡｃｔｉｖｅ\u3000チャイナⅩ',
        fund_name_yomi='アイフリーアクティブチャイナテン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12877': FundCodeEntry(
        fund_code='G12877',
        sec_code=None,
        fund_name='ＳＭＴ\u3000日経アジア３００インベスタブルインデックス・オープン',
        fund_name_yomi='エスエムティー\u3000ニッケイアジアサンビャクインベスタブルインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12878': FundCodeEntry(
        fund_code='G12878',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000国内株式（日経平均）',
        fund_name_yomi='イーマクシススリムコクナイカブシキニッケイヘイキン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12879': FundCodeEntry(
        fund_code='G12879',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－償還時目標設定型ファンド１８０２',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ショウカンジモクヒョウセッテイガタファンドイチハチゼロニ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G12882': FundCodeEntry(
        fund_code='G12882',
        sec_code=None,
        fund_name='野村日本割安低位株オープン',
        fund_name_yomi='ノムラニホンワリヤステイイカブオープン',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12883': FundCodeEntry(
        fund_code='G12883',
        sec_code=None,
        fund_name='（早期償還条項付）野村日本割安低位株投信１８０２',
        fund_name_yomi='ソウキショウカンジョウコウツキノムラニホンワリヤステイイカブトウシンイチハチゼロニ',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12884': FundCodeEntry(
        fund_code='G12884',
        sec_code=None,
        fund_name='スイス好配当株式ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='スイスコウハイトウカブシキファンド\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12885': FundCodeEntry(
        fund_code='G12885',
        sec_code=None,
        fund_name='ニッセイ・インデックスバランスファンド（８資産均等型）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイインデックスバランスファンドハチシサンキントウガタコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12887': FundCodeEntry(
        fund_code='G12887',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000世界不動産関連債券ファンド（為替ヘッジあり）（毎月決算型）\u3000ＰＩＭＣＯ\u3000世界不動産関連債券ファンド（為替ヘッジなし）（毎月決算型）\u3000ＰＩＭＣＯ\u3000世界不動産関連債券ファンド（為替ヘッジあり）（年２回決算型）\u3000ＰＩＭＣＯ\u3000世界不動産関連債券ファンド（為替ヘッジなし）（年２回決算型）',
        fund_name_yomi='ピムコ\u3000セカイフドウサンカンレンサイケンファンド\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000ピムコ\u3000セカイフドウサンカンレンサイケンファンド\u3000カワセヘッジナシ\u3000マイツキケッサンガタ\u3000ピムコ\u3000セカイフドウサンカンレンサイケンファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ\u3000ピムコ\u3000セカイフドウサンカンレンサイケンファンド\u3000カワセヘッジナシ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12890': FundCodeEntry(
        fund_code='G12890',
        sec_code=None,
        fund_name='野村グローバル・ボンド・アクティブ・ファンド（運用切り替え機能付・限定追加型）',
        fund_name_yomi='ノムラグローバルボンドアクティブファンドウンヨウキリカエキノウツキゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12892': FundCodeEntry(
        fund_code='G12892',
        sec_code=None,
        fund_name='アムンディ\u3000エス・エフ－ＳＭＢＣ・アムンディ\u3000プロテクトファンド\u3000米ドルステップ\u3000２０１８０３',
        fund_name_yomi='アムンディエスエフエスエムビーシーアムンディプロテクトファンドベイドルステップニゼロイチハチゼロサン',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33818',
        issuer_name='アムンディ・ルクセンブルク・エス・エー',
    ),
    'G12893': FundCodeEntry(
        fund_code='G12893',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓジャパンセレクトファンド（資産成長型）',
        fund_name_yomi='ニッセイエスディージーズジャパンセレクトファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12894': FundCodeEntry(
        fund_code='G12894',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓジャパンセレクトファンド（年２回決算型）',
        fund_name_yomi='ニッセイエスディージーズジャパンセレクトファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12896': FundCodeEntry(
        fund_code='G12896',
        sec_code=None,
        fund_name='４資産分散投資・スタンダード＜ＤＣ年金＞',
        fund_name_yomi='ヨンシサンブンサントウシスタンダードディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12897': FundCodeEntry(
        fund_code='G12897',
        sec_code=None,
        fund_name='ブラックロックＬｉｆｅＰａｔｈファンド２０３０／２０４０／２０５０',
        fund_name_yomi='ブラックロックライフパスファンドニイゼロサンゼロニイゼロヨンゼロニイゼロゴゼロ',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12898': FundCodeEntry(
        fund_code='G12898',
        sec_code=None,
        fund_name='オーストラリア好利回り３資産バランス（年２回決算型）',
        fund_name_yomi='オーストラリアコウリマワリサンシサンバランスネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12901': FundCodeEntry(
        fund_code='G12901',
        sec_code=None,
        fund_name='マイターゲット２０３５（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンサンジュウゴカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12902': FundCodeEntry(
        fund_code='G12902',
        sec_code=None,
        fund_name='マイターゲット２０４５（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンヨンジュウゴカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12903': FundCodeEntry(
        fund_code='G12903',
        sec_code=None,
        fund_name='マイターゲット２０５５（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンゴジュウゴカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12904': FundCodeEntry(
        fund_code='G12904',
        sec_code=None,
        fund_name='マイターゲット２０６０（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンロクジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12905': FundCodeEntry(
        fund_code='G12905',
        sec_code=None,
        fund_name='ＦＡＮＧ＋インデックス・オープン',
        fund_name_yomi='ファングプラスインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12908': FundCodeEntry(
        fund_code='G12908',
        sec_code=None,
        fund_name='次世代モビリティオープン（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ジセダイモビリティオープンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12910': FundCodeEntry(
        fund_code='G12910',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１８‐０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチハチノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G12911': FundCodeEntry(
        fund_code='G12911',
        sec_code=None,
        fund_name='未来イノベーション成長株ファンド',
        fund_name_yomi='ミライイノベーションセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12913': FundCodeEntry(
        fund_code='G12913',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞日米６資産分散ファンド（安定運用コース）\u3000（為替ヘッジあり）農林中金＜パートナーズ＞日米６資産分散ファンド（資産形成コース）（為替ヘッジあり）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ニチベイロクシサンブンサンファンド\u3000アンテイウンヨウコース\u3000カワセヘッジアリ\u3000ノウリンチュウキン\u3000パートナーズ\u3000ニチベイロクシサンブンサンファンド\u3000シサンケイセイコース\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G12914': FundCodeEntry(
        fund_code='G12914',
        sec_code=None,
        fund_name='欧州ハイ・イールド債券オープン（１年決算型）円コース／ユーロコース',
        fund_name_yomi='オウシュウハイイールドサイケンオープンイチネンケッサンガタエンコースユーロコース',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12915': FundCodeEntry(
        fund_code='G12915',
        sec_code=None,
        fund_name='ニッセイ・インド厳選株式ファンド（資産成長型）',
        fund_name_yomi='ニッセイインドゲンセンカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12917': FundCodeEntry(
        fund_code='G12917',
        sec_code=None,
        fund_name='次世代モビリティ社会創生株ファンド',
        fund_name_yomi='ジセダイモビリティシャカイソウセイカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12918': FundCodeEntry(
        fund_code='G12918',
        sec_code=None,
        fund_name='イーストスプリング・インド株式オープン（資産成長型）',
        fund_name_yomi='イーストスプリングインドカブシキオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G12920': FundCodeEntry(
        fund_code='G12920',
        sec_code=None,
        fund_name='インド内需関連株式ファンド',
        fund_name_yomi='インドナイジュカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12922': FundCodeEntry(
        fund_code='G12922',
        sec_code=None,
        fund_name='三井住友・豪ドル債ファンド（年１回決算型）',
        fund_name_yomi='ミツイスミトモゴウドルサイファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12923': FundCodeEntry(
        fund_code='G12923',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔインド株式',
        fund_name_yomi='アイトラストインドカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12924': FundCodeEntry(
        fund_code='G12924',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000全世界株式（除く日本）',
        fund_name_yomi='イーマクシススリムゼンセカイカブシキノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12925': FundCodeEntry(
        fund_code='G12925',
        sec_code=None,
        fund_name='ＵＢＳ（Ｉｒｌ）ＥＴＦ\u3000ピーエルシー\u3000－\u3000ＵＢＳ\u3000ＭＳＣＩ\u3000ＡＣＷＩ\u3000ユニバーサル\u3000ＵＣＩＴＳ\u3000ＥＴＦ／ＵＢＳ\u3000ＭＳＣＩ\u3000ＡＣＷＩ\u3000ソーシャリー・レスポンシブル\u3000ＵＣＩＴＳ\u3000ＥＴＦ',
        fund_name_yomi='ユービーエスアイアールエルイーティーエフピーエルシーユービーエスエムエスシーアイエーシーダブリューアイユニバーサルユーシッツイーティーエフユービーエスエムエスシーアイエーシーダブリューアイソーシャリーレスポンシブルユーシッツイーティーエフ',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33922',
        issuer_name='ＵＢＳ（Ｉｒｌ）ＥＴＦ\u3000ピーエルシー',
    ),
    'G12926': FundCodeEntry(
        fund_code='G12926',
        sec_code=None,
        fund_name='日本生命第１回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイイッカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E33912',
        issuer_name='日本生命第１回劣後ローン流動化株式会社',
    ),
    'G12928': FundCodeEntry(
        fund_code='G12928',
        sec_code=None,
        fund_name='日本厳選割安株ファンド２０１８－０４（繰上償還条件付）',
        fund_name_yomi='ニホンゲンセンワリヤスカブファンドニセンジュウハチノゼロヨン\u3000クリアゲショウカンジョウケンツキ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G12929': FundCodeEntry(
        fund_code='G12929',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000８資産バランス\u3000安定型、Ｓｍａｒｔ－ｉ\u3000８資産バランス\u3000安定成長型、Ｓｍａｒｔ－ｉ\u3000８資産バランス\u3000成長型',
        fund_name_yomi='スマートアイ\u3000ハチシサンバランス\u3000アンテイガタ\u3000スマートアイ\u3000ハチシサンバランス\u3000アンテイセイチョウガタ\u3000スマートアイ\u3000ハチシサンバランス\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12930': FundCodeEntry(
        fund_code='G12930',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０３０、りそなターゲット・イヤー・ファンド２０４０、りそなターゲット・イヤー・ファンド２０５０',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロサンゼロ\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロヨンゼロ\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロゴーゼロ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G12933': FundCodeEntry(
        fund_code='G12933',
        sec_code=None,
        fund_name='ＨＳＢＣワールド・セレクション（インカムコース）',
        fund_name_yomi='エイチエスビーシーワールドセレクションインカムコース',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2='8月19日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G12934': FundCodeEntry(
        fund_code='G12934',
        sec_code=None,
        fund_name='フィデリティ・グローバル株式ファンド（為替ヘッジあり）\u3000フィデリティ・グローバル株式ファンド（為替ヘッジなし）',
        fund_name_yomi='フィデリティグローバルカブシキファンドカワセヘッジアリ\u3000フィデリティグローバルカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12935': FundCodeEntry(
        fund_code='G12935',
        sec_code=None,
        fund_name='フィデリティ・ライフベスト戦略ファンド（年１回決算型）（為替ヘッジあり）',
        fund_name_yomi='フィデリティライフベストセンリャクファンドネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12936': FundCodeEntry(
        fund_code='G12936',
        sec_code=None,
        fund_name='キャピタル世界株式ファンドＮＦ／ＮＦ（限定為替ヘッジ）',
        fund_name_yomi='キャピタルセカイカブシキファンドエヌエフエヌエフゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G12937': FundCodeEntry(
        fund_code='G12937',
        sec_code=None,
        fund_name='ファンドラップ（ウエルス・スクエア）債券・安定型プラス',
        fund_name_yomi='ファンドラップウエルススクエアサイケンアンテイガタプラス',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12938': FundCodeEntry(
        fund_code='G12938',
        sec_code=None,
        fund_name='スパークス・厳選株ファンド・ヘッジ型（ダイワ投資一任専用）',
        fund_name_yomi='スパークス\u3000ゲンセンカブファンド\u3000ヘッジガタ\u3000ダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12939': FundCodeEntry(
        fund_code='G12939',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000全世界株式（３地域均等型）',
        fund_name_yomi='イーマクシススリムゼンセカイカブシキサンチイキキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12940': FundCodeEntry(
        fund_code='G12940',
        sec_code=None,
        fund_name='日本中小型成長株発掘ファンド',
        fund_name_yomi='ニホンチュウコガタセイチョウカブハックツファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12941': FundCodeEntry(
        fund_code='G12941',
        sec_code=None,
        fund_name='アジア・スマートロジスティクスファンド',
        fund_name_yomi='アジアスマートロジスティクスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12943': FundCodeEntry(
        fund_code='G12943',
        sec_code=None,
        fund_name='三菱ＵＦＪ国際\u3000インカムバランスファンド（年６回決算型）',
        fund_name_yomi='ミツビシユーエフジェイコクサイインカムバランスファンドネンロッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12944': FundCodeEntry(
        fund_code='G12944',
        sec_code=None,
        fund_name='ブラックロック新興国インフレ連動国債ファンド',
        fund_name_yomi='ブラックロックシンコウコクインフレレンドウコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12945': FundCodeEntry(
        fund_code='G12945',
        sec_code=None,
        fund_name='ＤＩＡＭ世界好配当株式ファンド（毎月決算型）（為替ヘッジあり）',
        fund_name_yomi='ダイアムセカイコウハイトウカブシキファンドマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12947': FundCodeEntry(
        fund_code='G12947',
        sec_code=None,
        fund_name='ＩＰＯリサーチ・オープン',
        fund_name_yomi='アイピーオーリサーチオープン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12948': FundCodeEntry(
        fund_code='G12948',
        sec_code=None,
        fund_name='インフラ関連日本株式ファンド',
        fund_name_yomi='インフラカンレンニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G12949': FundCodeEntry(
        fund_code='G12949',
        sec_code=None,
        fund_name='ニッセイ／コムジェスト新興国成長株ファンド\u3000Ａコース限定為替ヘッジ（野村ＳＭＡ・ＥＷ向け）／ニッセイ／コムジェスト新興国成長株ファンド\u3000Ｂコース為替ヘッジなし（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ニッセイコムジェストシンコウコクセイチョウカブファンドエーコースゲンテイカワセヘッジノムラエスエムエーイーダブリュームケ\u3000ニッセイコムジェストシンコウコクセイチョウカブファンドビーコースカワセヘッジナシノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12950': FundCodeEntry(
        fund_code='G12950',
        sec_code=None,
        fund_name='フィデリティ・米国株式ファンド\u3000Ｃコース（分配重視型・為替ヘッジあり）\u3000フィデリティ・米国株式ファンド\u3000Ｄコース（分配重視型・為替ヘッジなし）',
        fund_name_yomi='フィデリティベイコクカブシキファンドシーコースブンパイジュウシガタカワセヘッジアリ\u3000フィデリティベイコクカブシキファンドディーコースブンパイジュウシガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12951': FundCodeEntry(
        fund_code='G12951',
        sec_code=None,
        fund_name='フィデリティ・米国株式ファンド\u3000Ａコース（資産成長型・為替ヘッジあり）\u3000フィデリティ・米国株式ファンド\u3000Ｂコース（資産成長型・為替ヘッジなし）',
        fund_name_yomi='フィデリティベイコクカブシキファンドエーコースシサンセイチョウガタカワセヘッジアリ\u3000フィデリティベイコクカブシキファンドビーコースシサンセイチョウガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G12952': FundCodeEntry(
        fund_code='G12952',
        sec_code=None,
        fund_name='スパークス・ベスト・ピック・ファンド（ヘッジ型）',
        fund_name_yomi='スパークス\u3000ベスト\u3000ピック\u3000ファンド\u3000ヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G12953': FundCodeEntry(
        fund_code='G12953',
        sec_code=None,
        fund_name='分散名人',
        fund_name_yomi='ブンサンメイジン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G12954': FundCodeEntry(
        fund_code='G12954',
        sec_code=None,
        fund_name='リアル・アセット債券ファンド\u3000円ヘッジありコース\u3000リアル・アセット債券ファンド\u3000円ヘッジなしコース',
        fund_name_yomi='リアルアセットサイケンファンド\u3000エンヘッジアリコース\u3000リアルアセットサイケンファンド\u3000エンヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G12955': FundCodeEntry(
        fund_code='G12955',
        sec_code=None,
        fund_name='世界株式トレンドフォロー戦略ファンド（ロングコース／ロング・ショートコース）',
        fund_name_yomi='セカイカブシキトレンドフォローセンリャクファンドロングコースロングショートコース',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12956': FundCodeEntry(
        fund_code='G12956',
        sec_code=None,
        fund_name='日本健康社会関連株式ファンド',
        fund_name_yomi='ニホンケンコウシャカイカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G12957': FundCodeEntry(
        fund_code='G12957',
        sec_code=None,
        fund_name='企業価値フォーカス・ファンド・ヘッジ型（ダイワ投資一任専用）',
        fund_name_yomi='キギョウカチフォーカスファンドヘッジガタダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12958': FundCodeEntry(
        fund_code='G12958',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000ゴールドインデックス・ファンド（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズゴールドインデックスファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G12959': FundCodeEntry(
        fund_code='G12959',
        sec_code=None,
        fund_name='ＢＮＹメロン・米国株式ダイナミック戦略ファンド',
        fund_name_yomi='ビーエヌワイメロンベイコクカブシキダイナミックセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G12960': FundCodeEntry(
        fund_code='G12960',
        sec_code=None,
        fund_name='ニッセイ・デンマーク・カバード債券ファンド（為替ヘッジあり・３ヵ月決算型）／ニッセイ・デンマーク・カバード債券ファンド（為替ヘッジあり・資産成長型）',
        fund_name_yomi='ニッセイデンマークカバードサイケンファンドカワセヘッジアリサンカゲツケッサンガタ\u3000ニッセイデンマークカバードサイケンファンドカワセヘッジアリシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12962': FundCodeEntry(
        fund_code='G12962',
        sec_code='25170',
        fund_name='ＭＡＸＩＳ\u3000Ｊリート・コア上場投信',
        fund_name_yomi='マクシスジェーリートコアジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12964': FundCodeEntry(
        fund_code='G12964',
        sec_code=None,
        fund_name='ＡＢ新興国分散ファンドＡコース（限定為替ヘッジ）、ＡＢ新興国分散ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='エービーシンコウコクブンサンファンドエーコースゲンテイカワセヘッジ\u3000エービーシンコウコクブンサンファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G12968': FundCodeEntry(
        fund_code='G12968',
        sec_code=None,
        fund_name='ピクテ・ダイナミック・アロケーション・ファンド',
        fund_name_yomi='ピクテダイナミックアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G12969': FundCodeEntry(
        fund_code='G12969',
        sec_code=None,
        fund_name='世界６資産分散ファンド',
        fund_name_yomi='セカイロクシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12970': FundCodeEntry(
        fund_code='G12970',
        sec_code=None,
        fund_name='しずぎん国際分散投資戦略ファンド２０１８－０５',
        fund_name_yomi='シズギンコクサイブンサントウシセンリャクファンドニイゼロイチハチゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12971': FundCodeEntry(
        fund_code='G12971',
        sec_code=None,
        fund_name='マシューズ・アジア株式ファンド',
        fund_name_yomi='マシューズアジアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12973': FundCodeEntry(
        fund_code='G12973',
        sec_code=None,
        fund_name='ニッセイオーストラリア利回り資産ファンド（資産成長型）',
        fund_name_yomi='ニッセイオーストラリアリマワリシサンファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2='11月28日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12974': FundCodeEntry(
        fund_code='G12974',
        sec_code=None,
        fund_name='リスクコントロール世界資産分散ファンド',
        fund_name_yomi='リスクコントロールセカイシサンブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12975': FundCodeEntry(
        fund_code='G12975',
        sec_code='25180',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＭＳＣＩ日本株女性活躍指数（セレクト）連動型上場投信',
        fund_name_yomi='ネクストファンズエムエスシーアイニホンカブジョセイカツヤクシスウセレクトレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G12976': FundCodeEntry(
        fund_code='G12976',
        sec_code=None,
        fund_name='ＳＢＩ日本株３．７ベアⅢ',
        fund_name_yomi='エスビーアイ\u3000ニホンカブサンテンナナ\u3000ベア\u3000スリー',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12978': FundCodeEntry(
        fund_code='G12978',
        sec_code=None,
        fund_name='ライフ・ジャーニー（かしこく育てるコース）、ライフ・ジャーニー（かしこく使うコース）、ライフ・ジャーニー（充実して楽しむコース）',
        fund_name_yomi='ライフジャーニーカシコクソダテルコースライフジャーニーカシコクツカウコースライフジャーニージュウジツシテタノシムコース',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12979': FundCodeEntry(
        fund_code='G12979',
        sec_code=None,
        fund_name='新興企業日本株ファンド（資産成長型）',
        fund_name_yomi='シンコウキギョウニホンカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G12980': FundCodeEntry(
        fund_code='G12980',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000ウェルス・コアポートフォリオ\u3000アドバンス型',
        fund_name_yomi='プレミアムファンズウェルスコアポートフォリオアドバンスガタ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G12982': FundCodeEntry(
        fund_code='G12982',
        sec_code=None,
        fund_name='明治安田日本中小型成長株式ファンド',
        fund_name_yomi='メイジヤスダチュウコガタセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G12984': FundCodeEntry(
        fund_code='G12984',
        sec_code=None,
        fund_name='ＴＨＥＯインカム・ＡＩファンド（世界の債券中心）',
        fund_name_yomi='テオインカム\u3000エーアイファンド\u3000セカイノサイケンチュウシン',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G12985': FundCodeEntry(
        fund_code='G12985',
        sec_code=None,
        fund_name='ＴＨＥＯグロース・ＡＩファンド（世界の株式中心）',
        fund_name_yomi='テオグロース\u3000エーアイファンド\u3000セカイノカブシキチュウシン',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G12987': FundCodeEntry(
        fund_code='G12987',
        sec_code=None,
        fund_name='インベスコ\u3000ジャパン成長株・夢ファンド（年２回決算型）',
        fund_name_yomi='インベスコジャパンセイチョウカブユメファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G12990': FundCodeEntry(
        fund_code='G12990',
        sec_code=None,
        fund_name='欧州ハイイールド債券ファンド（為替ヘッジあり）／（為替ヘッジなし）（年１回決算型）',
        fund_name_yomi='オウシュウハイイールドサイケンファンドカワセヘッジアリカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月13日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G12991': FundCodeEntry(
        fund_code='G12991',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓグローバルセレクトファンド（年２回決算型・為替ヘッジあり）／ニッセイＳＤＧｓグローバルセレクトファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイエスディージーズグローバルセレクトファンドネンニカイケッサンガタカワセヘッジアリ\u3000ニッセイエスディージーズグローバルセレクトファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12992': FundCodeEntry(
        fund_code='G12992',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓグローバルセレクトファンド（資産成長型・為替ヘッジあり）／ニッセイＳＤＧｓグローバルセレクトファンド（資産成長型・為替ヘッジなし）',
        fund_name_yomi='ニッセイエスディージーズグローバルセレクトファンドシサンセイチョウガタカワセヘッシ゛アリ\u3000ニッセイエスディージーズグローバルセレクトファンドシサンセイチョウガタカワセヘッシ゛ナシ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G12994': FundCodeEntry(
        fund_code='G12994',
        sec_code=None,
        fund_name='楽天・インデックス・バランス（ＤＣ年金）',
        fund_name_yomi='ラクテンインデックスバランスディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G12997': FundCodeEntry(
        fund_code='G12997',
        sec_code=None,
        fund_name='ＳＭＡＭベトナム株式ファンド',
        fund_name_yomi='エスエムエイエムベトナムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G12998': FundCodeEntry(
        fund_code='G12998',
        sec_code=None,
        fund_name='オリックス\u3000世界国債ファンド（グローバル・ダイナミック・デュレーション）（為替ヘッジあり）',
        fund_name_yomi='オリックス\u3000セカイコクサイファンド\u3000グローバル\u3000ダイナミック\u3000デュレーション\u3000\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G12999': FundCodeEntry(
        fund_code='G12999',
        sec_code=None,
        fund_name='オリックス\u3000世界社債アクティブファンド（為替ヘッジあり）',
        fund_name_yomi='オリックス\u3000セカイシャサイアクティブファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13000': FundCodeEntry(
        fund_code='G13000',
        sec_code=None,
        fund_name='オリックス\u3000先進国株式マーケット・プラス・ファンド',
        fund_name_yomi='オリックス\u3000センシンコクカブシキマーケット\u3000プラス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13002': FundCodeEntry(
        fund_code='G13002',
        sec_code=None,
        fund_name='ＪＰＭ新興国年１回決算ファンド',
        fund_name_yomi='ジェイピーエムシンコウコクネンイッカイケッサンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13003': FundCodeEntry(
        fund_code='G13003',
        sec_code=None,
        fund_name='ダイワ・ブルベア・ファンドⅤ：ブル３倍日本株ポートフォリオⅤ、ベア２倍日本株ポートフォリオⅤ、ブルベア・マネー・ポートフォリオⅤ',
        fund_name_yomi='ダイワブルベアファンドファイブブルサンバイニホンカブポートフォリオファイブベアニバイニホンカブポートフォリオファイブブルベアマネーポートフォリオファイブ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13005': FundCodeEntry(
        fund_code='G13005',
        sec_code=None,
        fund_name='マルチアセット・ストラテジーファンド',
        fund_name_yomi='マルチアセットストラテジーファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E31744',
        issuer_name='株式会社ＧＣＩアセット・マネジメント',
    ),
    'G13007': FundCodeEntry(
        fund_code='G13007',
        sec_code=None,
        fund_name='ワールド・フィンテック革命ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ワールドフィンテックカクメイファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13008': FundCodeEntry(
        fund_code='G13008',
        sec_code=None,
        fund_name='ハリス世界株ファンド（資産成長型）',
        fund_name_yomi='ハリスセカイカブファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G13009': FundCodeEntry(
        fund_code='G13009',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１８‐０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチハチノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13012': FundCodeEntry(
        fund_code='G13012',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ－システマティック・アロケーション・ポートフォリオ・エクイティ（米ドル）',
        fund_name_yomi='ユービーエスルクスキーセレクションシキャブシステマティックアロケーションポートフォリオエクイティベイドル',
        security_type='外国投資証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15296',
        issuer_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ',
    ),
    'G13014': FundCodeEntry(
        fund_code='G13014',
        sec_code=None,
        fund_name='明治安田クオリティ日本株ファンド（限定追加型・繰上償還条項付）',
        fund_name_yomi='メイジヤスダクオリティニホンカブファンド\u3000ゲンテイツイカガタ\u3000クリアゲショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13015': FundCodeEntry(
        fund_code='G13015',
        sec_code=None,
        fund_name='明治安田クオリティ日本株オープン',
        fund_name_yomi='メイジヤスダクオリティニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13016': FundCodeEntry(
        fund_code='G13016',
        sec_code=None,
        fund_name='東京海上・ベトナム株式ファンド（年４回決算型）',
        fund_name_yomi='トウキョウカイジョウベトナムカブシキファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13017': FundCodeEntry(
        fund_code='G13017',
        sec_code=None,
        fund_name='つみたて椿',
        fund_name_yomi='ツミタテツバキ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13018': FundCodeEntry(
        fund_code='G13018',
        sec_code=None,
        fund_name='いちよしジャパン成長株ファンド',
        fund_name_yomi='イチヨシジャパンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G13019': FundCodeEntry(
        fund_code='G13019',
        sec_code='34920',
        fund_name='ＭＩＲＡＲＴＨ不動産投資法人',
        fund_name_yomi='ミラースフドウサントウシホウジン',
        security_type='内国投資証券',
        period_1='8月末日',
        period_2='2月末日',
        edinet_code='E34083',
        issuer_name='ＭＩＲＡＲＴＨ不動産投資法人',
    ),
    'G13020': FundCodeEntry(
        fund_code='G13020',
        sec_code=None,
        fund_name='北米リート・ファンド',
        fund_name_yomi='ホクベイリートファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13021': FundCodeEntry(
        fund_code='G13021',
        sec_code=None,
        fund_name='フューチャー・バイオテック',
        fund_name_yomi='フューチャーバイオテック',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13022': FundCodeEntry(
        fund_code='G13022',
        sec_code=None,
        fund_name='アモーヴァ\u3000オフショア・ファンズ\u3000ＴＲＰ米国コア・グロース株ファンド',
        fund_name_yomi='アモーヴァオフショアファンズティーアールピーベイコクコアグロースカブファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E27078',
        issuer_name='アモーヴァＡＭ・グローバルケイマンリミテッド',
    ),
    'G13023': FundCodeEntry(
        fund_code='G13023',
        sec_code=None,
        fund_name='ロボット戦略Ⅱ\u3000世界成長ファンド',
        fund_name_yomi='ロボットセンリャクニ\u3000セカイセイチョウファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13025': FundCodeEntry(
        fund_code='G13025',
        sec_code=None,
        fund_name='アムンディ・次世代医療テクノロジー・ファンド（年２回決算型）',
        fund_name_yomi='アムンディジセダイイリョウテクノロジーファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13026': FundCodeEntry(
        fund_code='G13026',
        sec_code=None,
        fund_name='マニュライフ・米国銀行株式ファンド（資産成長型）',
        fund_name_yomi='マニュライフベイコクギンコウカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13027': FundCodeEntry(
        fund_code='G13027',
        sec_code=None,
        fund_name='ＮＮファースト・クラス・トータル・リターン・ファンド（ラップ専用）／ＮＮファースト・クラス・トータル・リターン・ファンド・プレミアム（ラップ専用）',
        fund_name_yomi='エヌエヌファーストクラストータルリターンファンドラップセンヨウエヌエヌファーストクラストータルリターンファンドプレミアムラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G13028': FundCodeEntry(
        fund_code='G13028',
        sec_code=None,
        fund_name='ＪＰＭザ・ジャパン・ベストアイディア',
        fund_name_yomi='ジェイピーエムザジャパンベストアイディア',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13029': FundCodeEntry(
        fund_code='G13029',
        sec_code=None,
        fund_name='きらぼし・デンマーク・インカムファンド（為替ヘッジ型）',
        fund_name_yomi='キラボシデンマークインカムファンドカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13030': FundCodeEntry(
        fund_code='G13030',
        sec_code=None,
        fund_name='イノベーション・インデックス・ＡＩ',
        fund_name_yomi='イノベーションインデックスエーアイ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13031': FundCodeEntry(
        fund_code='G13031',
        sec_code=None,
        fund_name='明治安田日本債券オープン（年１回決算型）',
        fund_name_yomi='メイジヤスダニホンサイケンオープン\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13033': FundCodeEntry(
        fund_code='G13033',
        sec_code=None,
        fund_name='ＵＢＳ中国人民元債券ファンド（毎月決算型）',
        fund_name_yomi='ユービーエスチュウゴクジンミンゲンサイケンファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13034': FundCodeEntry(
        fund_code='G13034',
        sec_code=None,
        fund_name='ＵＢＳ中国人民元債券ファンド（年２回決算型）',
        fund_name_yomi='ユービーエスチュウゴクジンミンゲンサイケンファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13036': FundCodeEntry(
        fund_code='G13036',
        sec_code=None,
        fund_name='日本株式リサーチ・マーケット・ニュートラルファンド（ＳＭＡ専用）',
        fund_name_yomi='ニホンカブシキリサーチ\u3000マーケット\u3000ニュートラルファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13037': FundCodeEntry(
        fund_code='G13037',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000米国株式（Ｓ＆Ｐ５００）',
        fund_name_yomi='イーマクシススリムベイコクカブシキエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13038': FundCodeEntry(
        fund_code='G13038',
        sec_code=None,
        fund_name='きらぼし・みらい応援株式ファンド',
        fund_name_yomi='キラボシミライオウエンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2='9月3日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13039': FundCodeEntry(
        fund_code='G13039',
        sec_code='25200',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ新興国株式・ＭＳＣＩエマージング・マーケット・インデックス（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズシンコウコクカブシキエムエスシーアイエマージングマーケットインデックスカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13040': FundCodeEntry(
        fund_code='G13040',
        sec_code='25190',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000新興国債券・Ｊ．Ｐ．モルガン・エマージング・マーケット・ボンド・インデックス・プラス（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズシンコウコクサイケンジェイピーモルガンエマージングマーケットボンドインデックスプラスカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13041': FundCodeEntry(
        fund_code='G13041',
        sec_code=None,
        fund_name='きらぼし・東京圏応援株式ファンド',
        fund_name_yomi='キラボシトウキョウケンオウエンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13043': FundCodeEntry(
        fund_code='G13043',
        sec_code=None,
        fund_name='野村日本最高益更新企業ファンド',
        fund_name_yomi='ノムラニホンサイコウエキコウシンキギョウファンド',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13047': FundCodeEntry(
        fund_code='G13047',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１８－０７',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチハチゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13048': FundCodeEntry(
        fund_code='G13048',
        sec_code=None,
        fund_name='東京海上・ベトナム株式ファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウベトナムカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月22日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13049': FundCodeEntry(
        fund_code='G13049',
        sec_code=None,
        fund_name='楽天・インカム戦略ポートフォリオ（奇数月決算型）',
        fund_name_yomi='ラクテンインカムセンリャクポートフォリオキスウツキケッサンカタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13050': FundCodeEntry(
        fund_code='G13050',
        sec_code=None,
        fund_name='楽天・インカム戦略ポートフォリオ（偶数月決算型）',
        fund_name_yomi='ラクテンインカムセンリャクポートフォリオグウスウツキケッサンカタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13051': FundCodeEntry(
        fund_code='G13051',
        sec_code=None,
        fund_name='楽天・インカム戦略ポートフォリオ・アルファ（奇数月決算型）',
        fund_name_yomi='ラクテンインカムセンリャクポートフォリオアルファキスウツキケッサンカタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13052': FundCodeEntry(
        fund_code='G13052',
        sec_code=None,
        fund_name='楽天・インデックス・バランス・ファンド（株式重視型）',
        fund_name_yomi='ラクテンインデックスバランスファンドカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13053': FundCodeEntry(
        fund_code='G13053',
        sec_code=None,
        fund_name='楽天・インデックス・バランス・ファンド（均等型）',
        fund_name_yomi='ラクテンインデックスバランスファンドキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13054': FundCodeEntry(
        fund_code='G13054',
        sec_code=None,
        fund_name='楽天・インデックス・バランス・ファンド（債券重視型）',
        fund_name_yomi='ラクテンインデックスバランスファンドサイケンジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13056': FundCodeEntry(
        fund_code='G13056',
        sec_code=None,
        fund_name='グローバル・ハイクオリティ成長株式ファンド（年２回決算型）（限定為替ヘッジ）、グローバル・ハイクオリティ成長株式ファンド（年２回決算型）（為替ヘッジなし）',
        fund_name_yomi='グローバルハイクオリティセイチョウカブシキファンドネンニカイケッサンガタゲンテイカワセヘッジ\u3000グローバルハイクオリティセイチョウカブシキファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13057': FundCodeEntry(
        fund_code='G13057',
        sec_code=None,
        fund_name='明治安田生命２０１８基金特定目的会社',
        fund_name_yomi='メイジヤスダセイメイニセンジュウハチキキントクテイモクテキカイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E34201',
        issuer_name='明治安田生命２０１８基金特定目的会社',
    ),
    'G13058': FundCodeEntry(
        fund_code='G13058',
        sec_code=None,
        fund_name='アドバンス・ロジスティクス投資法人',
        fund_name_yomi='アドバンスロジスティクストウシホウジン',
        security_type='内国投資証券',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E32450',
        issuer_name='三井不動産ロジスティクスパーク投資法人',
    ),
    'G13059': FundCodeEntry(
        fund_code='G13059',
        sec_code=None,
        fund_name='フィデリティ・米国株式ファンド\u3000Ａコース（為替ヘッジあり）（野村ＳＭＡ・ＥＷ向け）\u3000フィデリティ・米国株式ファンド\u3000Ｂコース（為替ヘッジなし）（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='フィデリティベイコクカブシキファンドエーコースカワセヘッジアリノムラエスエムエーイーダブリュームケ\u3000フィデリティベイコクカブシキファンドビーコースカワセヘッジナシノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13060': FundCodeEntry(
        fund_code='G13060',
        sec_code=None,
        fund_name='アムンディ\u3000エス・エフ\u3000ＳＭＢＣ・アムンディ\u3000プロテクトファンド\u3000米ドルステップ\u3000２０１８０９',
        fund_name_yomi='アムンディエスエフエスエムビーシーアムンディプロテクトファンドベイドルステップニゼロイチハチゼロキュウ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33818',
        issuer_name='アムンディ・ルクセンブルク・エス・エー',
    ),
    'G13061': FundCodeEntry(
        fund_code='G13061',
        sec_code='25210',
        fund_name='上場インデックスファンド米国株式（Ｓ＆Ｐ５００）為替ヘッジあり',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキ\u3000エスアンドピーゴヒャク\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13062': FundCodeEntry(
        fund_code='G13062',
        sec_code=None,
        fund_name='ニッセイ日本株ＡＩセレクトファンド（年２回決算型）',
        fund_name_yomi='ニッセイニホンカブエーアイセレクトファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13063': FundCodeEntry(
        fund_code='G13063',
        sec_code=None,
        fund_name='ニッセイ日本株ＡＩセレクトファンド（資産成長型）',
        fund_name_yomi='ニッセイニホンカブエーアイセレクトファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13064': FundCodeEntry(
        fund_code='G13064',
        sec_code=None,
        fund_name='ＳＢＩ世界高配当株プレミアムファンド（為替ヘッジあり）＜資産成長コース＞、ＳＢＩ世界高配当株プレミアムファンド（為替ヘッジあり）＜年７％定率払出しコース＞、ＳＢＩ世界高配当株プレミアムファンド（為替ヘッジあり）＜年１５％定率払出しコース＞',
        fund_name_yomi='エスビーアイセカイコウハイトウカブプレミアムファンドカワセヘッジアリ\u3000シサンセイチョウコース\u3000エスビーアイセカイコウハイトウカブプレミアムファンドカワセヘッジアリ\u3000ネンナナパーセントテイリツハライダシコース\u3000エスビーアイセカイコウハイトウカブプレミアムファンドカワセヘッジアリネンジュウゴパーセントテイリツハライダシコース',
        security_type='内国投資信託受益証券',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13065': FundCodeEntry(
        fund_code='G13065',
        sec_code=None,
        fund_name='人生１００年時代・世界分散ファンド（資産成長型）、人生１００年時代・世界分散ファンド（３％目標受取型）、人生１００年時代・世界分散ファンド（６％目標受取型）',
        fund_name_yomi='ジンセイヒャクネンジダイセカイブンサンファンドシサンセイチョウガタジンセイヒャクネンジダイセカイブンサンファンドサンパーセントモクヒョウウケトリガタジンセイヒャクネンジダイセカイブンサンファンドロクパーセントモクヒョウウケトリガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13066': FundCodeEntry(
        fund_code='G13066',
        sec_code=None,
        fund_name='９資産分散投資・スタンダード＜ＤＣ年金＞',
        fund_name_yomi='キュウシサンブンサントウシスタンダードディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13067': FundCodeEntry(
        fund_code='G13067',
        sec_code=None,
        fund_name='野村ワールドボンド・ファンド',
        fund_name_yomi='ノムラワールドボンドファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13068': FundCodeEntry(
        fund_code='G13068',
        sec_code=None,
        fund_name='ストップライン付き野村ワールドボンド・ファンド',
        fund_name_yomi='ストップラインツキノムラワールドボンドファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13069': FundCodeEntry(
        fund_code='G13069',
        sec_code=None,
        fund_name='米国バリュー・ストラテジー・ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、米国バリュー・ストラテジー・ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ベイコクバリューストラテジーファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ベイコクバリューストラテジーファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13070': FundCodeEntry(
        fund_code='G13070',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000遺伝子工学',
        fund_name_yomi='イーマクシスネオイデンシコウガク',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13071': FundCodeEntry(
        fund_code='G13071',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000ロボット',
        fund_name_yomi='イーマクシスネオロボット',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13072': FundCodeEntry(
        fund_code='G13072',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000宇宙開発',
        fund_name_yomi='イーマクシスネオウチュウカイハツ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13075': FundCodeEntry(
        fund_code='G13075',
        sec_code=None,
        fund_name='グローバル・スペース株式ファンド（１年決算型）',
        fund_name_yomi='グローバル\u3000スペースカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13076': FundCodeEntry(
        fund_code='G13076',
        sec_code=None,
        fund_name='ニッセイ・デンマーク・カバード債券ファンド２０１８－０９（為替ヘッジあり）',
        fund_name_yomi='ニッセイデンマークカバードサイケンファンドニゼロイチハチノゼロク\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13077': FundCodeEntry(
        fund_code='G13077',
        sec_code='92850',
        fund_name='東京インフラ・エネルギー投資法人',
        fund_name_yomi='トウキョウインフラエネルギートウシホウジン',
        security_type='内国投資証券',
        period_1='6月末日',
        period_2='12月末日',
        edinet_code='E34255',
        issuer_name='東京インフラ・エネルギー投資法人',
    ),
    'G13078': FundCodeEntry(
        fund_code='G13078',
        sec_code=None,
        fund_name='ダイワつみたてインデックス日本株式',
        fund_name_yomi='ダイワツミタテインデックスニホンカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13079': FundCodeEntry(
        fund_code='G13079',
        sec_code=None,
        fund_name='ダイワつみたてインデックス日本債券',
        fund_name_yomi='ダイワツミタテインデックスニホンサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13080': FundCodeEntry(
        fund_code='G13080',
        sec_code=None,
        fund_name='ダイワつみたてインデックス外国株式',
        fund_name_yomi='ダイワツミタテインデックスガイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13081': FundCodeEntry(
        fund_code='G13081',
        sec_code=None,
        fund_name='ダイワつみたてインデックス外国債券',
        fund_name_yomi='ダイワツミタテインデックスガイコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13082': FundCodeEntry(
        fund_code='G13082',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－マイスターズ・コレクション',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーマイスターズコレクション',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13084': FundCodeEntry(
        fund_code='G13084',
        sec_code=None,
        fund_name='東京海上・宇宙関連株式ファンド（為替ヘッジなし）',
        fund_name_yomi='トウキョウカイジョウウチュウカンレンカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13085': FundCodeEntry(
        fund_code='G13085',
        sec_code=None,
        fund_name='わたしの未来設計＜安定重視型＞（分配コース）、わたしの未来設計＜安定重視型＞（分配抑制コース）、わたしの未来設計＜成長重視型＞（分配コース）、わたしの未来設計＜成長重視型＞（分配抑制コース）',
        fund_name_yomi='ワタシノミライセッケイアンテイジュウシガタブンパイコースワタシノミライセッケイアンテイジュウシガタブンパイヨクセイコースワタシノミライセッケイセイチョウジュウシガタブンパイコースワタシノミライセッケイセイチョウジュウシガタブンパイヨクセイコース',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13086': FundCodeEntry(
        fund_code='G13086',
        sec_code=None,
        fund_name='ブラックロック・グローバル・ファンズ－ＵＳドル・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ブラックロックグローバルファンズユーエスドルハイイールドボンドファンド',
        security_type='外国投資証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E31398',
        issuer_name='ブラックロック・グローバル・ファンズ',
    ),
    'G13087': FundCodeEntry(
        fund_code='G13087',
        sec_code=None,
        fund_name='ピクテ・エコディスカバリー・アロケーション・ファンド（毎月決算型）為替ヘッジあり',
        fund_name_yomi='ピクテエコディスカバリーアロケーションファンドマイツキケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13088': FundCodeEntry(
        fund_code='G13088',
        sec_code=None,
        fund_name='ピクテ・エコディスカバリー・アロケーション・ファンド（年２回決算型）為替ヘッジあり',
        fund_name_yomi='ピクテエコディスカバリーアロケーションファンドネンニカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13090': FundCodeEntry(
        fund_code='G13090',
        sec_code=None,
        fund_name='日本生命第２回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイニカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E34308',
        issuer_name='日本生命第２回劣後ローン流動化株式会社',
    ),
    'G13091': FundCodeEntry(
        fund_code='G13091',
        sec_code=None,
        fund_name='ステート・ストリート債券タームスプレッド・プレミア戦略オープン',
        fund_name_yomi='ステートストリートサイケンタームスプレッドプレミアサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G13092': FundCodeEntry(
        fund_code='G13092',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－償還時目標設定型ファンド１８０９',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ショウカンジモクヒョウセッテイガタファンドイチハチゼロキュウ',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G13096': FundCodeEntry(
        fund_code='G13096',
        sec_code=None,
        fund_name='ＧＣＩオルタナティブバスケット・ファンドＶ１０（ラップ専用）',
        fund_name_yomi='ジーシーアイオルタナティブバスケットファンドブイテンラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E31744',
        issuer_name='株式会社ＧＣＩアセット・マネジメント',
    ),
    'G13097': FundCodeEntry(
        fund_code='G13097',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000Ｓ＆Ｐ５００',
        fund_name_yomi='アイフリーレバレッジエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='8月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13099': FundCodeEntry(
        fund_code='G13099',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000年金バランス',
        fund_name_yomi='アイフリーネンキンバランス',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13100': FundCodeEntry(
        fund_code='G13100',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＮＡＳＤＡＱ１００インデックス',
        fund_name_yomi='アイフリーネクストナスダックヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='8月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13102': FundCodeEntry(
        fund_code='G13102',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１８‐１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチハチノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13103': FundCodeEntry(
        fund_code='G13103',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１８－０９',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチハチゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13104': FundCodeEntry(
        fund_code='G13104',
        sec_code=None,
        fund_name='フィッシャー・グローバル・スモールキャップ・エクイティ・ファンド',
        fund_name_yomi='フィッシャーグローバルスモールキャップエクイティファンド',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13105': FundCodeEntry(
        fund_code='G13105',
        sec_code=None,
        fund_name='ノムラ・ルクセンブルグ・セレクト－野村短期米国国債ファンド',
        fund_name_yomi='ノムラルクセンブルグセレクトノムラタンキベイコクコクサイファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E14843',
        issuer_name='グローバル・ファンズ・マネジメント・エス・エー',
    ),
    'G13106': FundCodeEntry(
        fund_code='G13106',
        sec_code=None,
        fund_name='りそな日本中小型株式ファンド',
        fund_name_yomi='リソナニホンチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13107': FundCodeEntry(
        fund_code='G13107',
        sec_code=None,
        fund_name='げんき１００年ライフ株式ファンド',
        fund_name_yomi='ゲンキヒャクネンライフカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13109': FundCodeEntry(
        fund_code='G13109',
        sec_code=None,
        fund_name='中国人民元ソブリンオープン',
        fund_name_yomi='チュウゴクジンミンゲンソブリンオープン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13110': FundCodeEntry(
        fund_code='G13110',
        sec_code=None,
        fund_name='中国人民元ソブリンオープン（元高米ドル安戦略）',
        fund_name_yomi='チュウゴクジンミンゲンソブリンオープンゲンダカベイドルヤスセンリャク',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13111': FundCodeEntry(
        fund_code='G13111',
        sec_code=None,
        fund_name='ａｕスマート・ベーシック（安定）／ａｕスマート・ベーシック（安定成長）',
        fund_name_yomi='エーユースマートベーシックアンテイ\u3000エーユースマートベーシックアンテイセイチョウ',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G13112': FundCodeEntry(
        fund_code='G13112',
        sec_code=None,
        fund_name='ａｕスマート・プライム（成長）／ａｕスマート・プライム（高成長）',
        fund_name_yomi='エーユースマートプライムセイチョウ\u3000エーユースマートプライムコウセイチョウ',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G13113': FundCodeEntry(
        fund_code='G13113',
        sec_code=None,
        fund_name='ブラックロック・ガバナンス・フォーカス・ファンド',
        fund_name_yomi='ブラックロックガバナンスフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13114': FundCodeEntry(
        fund_code='G13114',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（アクティブ）２０６０',
        fund_name_yomi='フィデリティターゲットデートファンドアクティブニセンロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13115': FundCodeEntry(
        fund_code='G13115',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０６０',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13116': FundCodeEntry(
        fund_code='G13116',
        sec_code=None,
        fund_name='楽天グローバル中小型バリュー株ファンド',
        fund_name_yomi='ラクテングローバルチュウコガタバリューカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13117': FundCodeEntry(
        fund_code='G13117',
        sec_code=None,
        fund_name='楽天・スタイル・リスク・プレミア戦略ファンド',
        fund_name_yomi='ラクテンスタイルリスクプレミアセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13119': FundCodeEntry(
        fund_code='G13119',
        sec_code=None,
        fund_name='みのりの投信（投資一任専用）',
        fund_name_yomi='ミノリノトウシン\u3000トウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E27426',
        issuer_name='株式会社ポートフォリア',
    ),
    'G13120': FundCodeEntry(
        fund_code='G13120',
        sec_code=None,
        fund_name='Ｏｎｅ世界分散セレクト（Ａコース）、Ｏｎｅ世界分散セレクト（Ｂコース）、Ｏｎｅ世界分散セレクト（Ｃコース）',
        fund_name_yomi='ワンセカイブンサンセレクトエーコース\u3000ワンセカイブンサンセレクトビーコース\u3000ワンセカイブンサンセレクトシーコース',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13121': FundCodeEntry(
        fund_code='G13121',
        sec_code=None,
        fund_name='ＮＷＱグローバル厳選証券ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='エヌダブリューキューグローバルゲンセンショウケンファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13122': FundCodeEntry(
        fund_code='G13122',
        sec_code=None,
        fund_name='ＭＦＳプルーデント・ファンド（米ドル売り円買い）',
        fund_name_yomi='エムエフエスプルーデント\u3000ファンド\u3000ベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E11595',
        issuer_name='ＭＦＳインベストメント・マネジメント株式会社',
    ),
    'G13123': FundCodeEntry(
        fund_code='G13123',
        sec_code=None,
        fund_name='米国株式配当貴族・為替ヘッジあり型（投資一任サービス向け）',
        fund_name_yomi='ベイコクカブシキハイトウキゾクカワセヘッジアリガタトウシイチニンサービスムケ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13124': FundCodeEntry(
        fund_code='G13124',
        sec_code=None,
        fund_name='米国株式配当貴族・為替ヘッジなし型（投資一任サービス向け）',
        fund_name_yomi='ベイコクカブシキハイトウキゾクカワセヘッジナシガタトウシイチニンサービスムケ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13125': FundCodeEntry(
        fund_code='G13125',
        sec_code=None,
        fund_name='システマティック・グローバル・マクロ戦略ファンド（投資一任サービス向け）',
        fund_name_yomi='システマティックグローバルマクロセンリャクファンドトウシイチニンサービスムケ',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13126': FundCodeEntry(
        fund_code='G13126',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000ロボ',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000ロボ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13128': FundCodeEntry(
        fund_code='G13128',
        sec_code=None,
        fund_name='日本厳選割安株ファンド２０１８－１０（繰上償還条件付）',
        fund_name_yomi='ニホンゲンセンワリヤスカブファンドニセンジュウハチノジュウ\u3000クリアゲショウカンジョウケンツキ',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13129': FundCodeEntry(
        fund_code='G13129',
        sec_code=None,
        fund_name='ＳＢＩ‐ＰＩＭＣＯ\u3000世界債券アクティブファンド（ＤＣ）',
        fund_name_yomi='エスビーアイピムコセカイサイケンアクティブファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='10月3日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13130': FundCodeEntry(
        fund_code='G13130',
        sec_code=None,
        fund_name='ＤＷＳ\u3000コモディティ戦略ファンド（年１回決算型）Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ディーダブリューエス\u3000コモディティセンリャクファンドネンイッカイケッサンガタ\u3000エーコースカワセヘッジアリ\u3000ビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G13131': FundCodeEntry(
        fund_code='G13131',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金インデックス（先進国株式）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンインデックスセンシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13132': FundCodeEntry(
        fund_code='G13132',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金インデックス（先進国債券）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンインデックスセンシンコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13133': FundCodeEntry(
        fund_code='G13133',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金インデックス（国内株式）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンインデックスコクナイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13134': FundCodeEntry(
        fund_code='G13134',
        sec_code=None,
        fund_name='ＳＢＩグローバル・バランス・ファンド',
        fund_name_yomi='エスビーアイグローバルバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13135': FundCodeEntry(
        fund_code='G13135',
        sec_code=None,
        fund_name='中国株\u3000ＡＩ運用ファンド',
        fund_name_yomi='チュウゴクカブ\u3000エーアイウンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13136': FundCodeEntry(
        fund_code='G13136',
        sec_code=None,
        fund_name='グローバル３倍３分法ファンド（１年決算型）',
        fund_name_yomi='グローバルサンバイサンブンポウファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月21日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13137': FundCodeEntry(
        fund_code='G13137',
        sec_code=None,
        fund_name='グローバル３倍３分法ファンド（隔月分配型）',
        fund_name_yomi='グローバルサンバイサンブンポウファンド\u3000カクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13138': FundCodeEntry(
        fund_code='G13138',
        sec_code=None,
        fund_name='インベスコ\u3000世界厳選株式オープン（年１回決算型）',
        fund_name_yomi='インベスコセカイゲンセンカブシキオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月23日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13139': FundCodeEntry(
        fund_code='G13139',
        sec_code=None,
        fund_name='イーストスプリング新興国スタープレイヤーズ',
        fund_name_yomi='イーストスプリングシンコウコクスタープレイヤーズ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G13140': FundCodeEntry(
        fund_code='G13140',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１８－１０',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチハチイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13141': FundCodeEntry(
        fund_code='G13141',
        sec_code=None,
        fund_name='ＵＢＳ中国Ａ株ファンド（年４回決算型）',
        fund_name_yomi='ユービーエスチュウゴクエーカブファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13142': FundCodeEntry(
        fund_code='G13142',
        sec_code=None,
        fund_name='スパークス・新・国際優良日本アジア株ファンド',
        fund_name_yomi='スパークスシンコクサイユウリョウニホンアジアカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G13145': FundCodeEntry(
        fund_code='G13145',
        sec_code=None,
        fund_name='野村ＡＣＩ先進医療インパクト投資\u3000Ａコース\u3000為替ヘッジあり\u3000資産成長型、野村ＡＣＩ先進医療インパクト投資\u3000Ｂコース\u3000為替ヘッジなし\u3000資産成長型、野村ＡＣＩ先進医療インパクト投資\u3000Ｃコース\u3000為替ヘッジあり\u3000予想分配金提示型、野村ＡＣＩ先進医療インパクト投資\u3000Ｄコース\u3000為替ヘッジなし\u3000予想分配金提示型',
        fund_name_yomi='ノムラエーシーアイセンシンイリョウインパクトトウシエーコースカワセヘッジアリシサンセイチョウガタ\u3000ノムラエーシーアイセンシンイリョウインパクトトウシビーコースカワセヘッジナシシサンセイチョウガタ\u3000ノムラエーシーアイセンシンイリョウインパクトトウシシーコースカワセヘッジアリヨソウブンパイキンテイジガタ\u3000ノムラエーシーアイセンシンイリョウインパクトトウシディーコースカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2='12月19日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13146': FundCodeEntry(
        fund_code='G13146',
        sec_code=None,
        fund_name='ウエスタン・グローバル債券ファンド（ＳＭＡ専用）',
        fund_name_yomi='ウエスタン\u3000グローバルサイケンファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月9日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G13147': FundCodeEntry(
        fund_code='G13147',
        sec_code=None,
        fund_name='チャイナ・イノベーション・オープン',
        fund_name_yomi='チャイナイノベーションオープン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13148': FundCodeEntry(
        fund_code='G13148',
        sec_code=None,
        fund_name='ニッセイ宇宙関連グローバル株式ファンド（年２回決算型・為替ヘッジあり）／ニッセイ宇宙関連グローバル株式ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイウチュウカンレングローバルカブシキファンドネンニカイケッサンガタカワセヘッジアリ\u3000ニッセイウチュウカンレングローバルカブシキファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13149': FundCodeEntry(
        fund_code='G13149',
        sec_code=None,
        fund_name='ニッセイ宇宙関連グローバル株式ファンド（資産成長型・為替ヘッジあり）／ニッセイ宇宙関連グローバル株式ファンド（資産成長型・為替ヘッジなし）',
        fund_name_yomi='ニッセイウチュウカンレングローバルカブシキファンドシサンセイチョウガタカワセヘッジアリ\u3000ニッセイウチュウカンレングローバルカブシキファンドシサンセイチョウガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13150': FundCodeEntry(
        fund_code='G13150',
        sec_code=None,
        fund_name='コア投資戦略ファンド（積極成長型）',
        fund_name_yomi='コアトウシセンリャクファンド\u3000セッキョクセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13151': FundCodeEntry(
        fund_code='G13151',
        sec_code=None,
        fund_name='コア投資戦略ファンド（切替型ワイド）',
        fund_name_yomi='コアトウシセンリャクファンド\u3000キリカエガタワイド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13153': FundCodeEntry(
        fund_code='G13153',
        sec_code=None,
        fund_name='イノベーション・インデックス・フィンテック',
        fund_name_yomi='イノベーションインデックスフィンテック',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13154': FundCodeEntry(
        fund_code='G13154',
        sec_code=None,
        fund_name='日本株主還元株ファンド・ヘッジ型',
        fund_name_yomi='ニホンカブヌシカンゲンカブファンドヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13156': FundCodeEntry(
        fund_code='G13156',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000ＮＡＳＤＡＱ１００',
        fund_name_yomi='アイフリーレバレッジナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13157': FundCodeEntry(
        fund_code='G13157',
        sec_code=None,
        fund_name='ｉＦｒｅｅＡｃｔｉｖｅ\u3000メディカルデバイス',
        fund_name_yomi='アイフリーアクティブメディカルデバイス',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13159': FundCodeEntry(
        fund_code='G13159',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ジャパンＥＳＧセレクト・リーダーズインデックス',
        fund_name_yomi='イーマクシスジャパンイーエスジーセレクトリーダーズインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13161': FundCodeEntry(
        fund_code='G13161',
        sec_code=None,
        fund_name='しんきん世界好配当利回り株ファンド（１年決算型）',
        fund_name_yomi='シンキンセカイコウハイトウリマワリカブファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G13163': FundCodeEntry(
        fund_code='G13163',
        sec_code=None,
        fund_name='東京海上・ジャパン・レジリエンス株式オープン',
        fund_name_yomi='トウキョウカイジョウジャパンレジリエンスカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13164': FundCodeEntry(
        fund_code='G13164',
        sec_code=None,
        fund_name='ダブル・ブレイン',
        fund_name_yomi='ダブルブレイン',
        security_type='内国投資信託受益証券',
        period_1='11月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13165': FundCodeEntry(
        fund_code='G13165',
        sec_code=None,
        fund_name='オフショア・ストラテジー・ファンド－ＮＫプレミアムＣＡＴボンド・ファンド',
        fund_name_yomi='オフショアストラテジーファンドエヌケープレミアムキャットボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E14984',
        issuer_name='インターナショナル・マネジメント・サービシズ・リミテッド',
    ),
    'G13166': FundCodeEntry(
        fund_code='G13166',
        sec_code=None,
        fund_name='野村リアルグロース・オープン（確定拠出年金向け）',
        fund_name_yomi='ノムラリアルグロースオープンカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13167': FundCodeEntry(
        fund_code='G13167',
        sec_code=None,
        fund_name='日本新興成長企業株ファンド',
        fund_name_yomi='ニホンシンコウセイチョウキギョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13168': FundCodeEntry(
        fund_code='G13168',
        sec_code='25220',
        fund_name='ｉシェアーズ\u3000オートメーション\u3000＆\u3000ロボット\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000オートメーション\u3000アンド\u3000ロボット\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13169': FundCodeEntry(
        fund_code='G13169',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１８－１１',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチハチイチイチ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13170': FundCodeEntry(
        fund_code='G13170',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000全世界株式（オール・カントリー）',
        fund_name_yomi='イーマクシススリムゼンセカイカブシキオールカントリー',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13171': FundCodeEntry(
        fund_code='G13171',
        sec_code=None,
        fund_name='ＮＷＱグローバル厳選証券ファンド（為替ヘッジあり・なし／隔月分配型）（為替ヘッジあり・なし／資産成長型）',
        fund_name_yomi='エヌダブリューキューグローバルゲンセンショウケンファンドカワセヘッジアリナシカクゲツブンパイガタカワセヘッジアリナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13172': FundCodeEntry(
        fund_code='G13172',
        sec_code=None,
        fund_name='ダイワ／バリュー・パートナーズ・チャイナ・イノベーター・ファンド',
        fund_name_yomi='ダイワバリューパートナーズチャイナイノベーターファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13174': FundCodeEntry(
        fund_code='G13174',
        sec_code=None,
        fund_name='キャピタル世界株式ファンド（限定為替ヘッジ）',
        fund_name_yomi='キャピタルセカイカブシキファンドゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G13175': FundCodeEntry(
        fund_code='G13175',
        sec_code=None,
        fund_name='キャピタル世界株式ファンド年２回決算（分配重視）／（分配重視／限定為替ヘッジ）',
        fund_name_yomi='キャピタルセカイカブシキファンドネンニカイケッサンブンパイジュウシブンパイジュウシゲンテイカワセヘッジ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G13176': FundCodeEntry(
        fund_code='G13176',
        sec_code=None,
        fund_name='日経平均高配当利回り株ファンド',
        fund_name_yomi='ニッケイヘイキンコウハイトウリマワリカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13177': FundCodeEntry(
        fund_code='G13177',
        sec_code=None,
        fund_name='モルガン・スタンレー社債／マルチアセット運用戦略ファンド２０１８－１２',
        fund_name_yomi='モルガンスタンレーシャサイ\u3000マルチアセットウンヨウセンリャクファンド\u3000ニゼロイチハチイチニ',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13178': FundCodeEntry(
        fund_code='G13178',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・グローバル・プレミア小型株ファンド（年１回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000グローバル\u3000プレミアコガタカブファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G13179': FundCodeEntry(
        fund_code='G13179',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・グローバル・プレミア小型株ファンド（年２回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000グローバル\u3000プレミアコガタカブファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G13180': FundCodeEntry(
        fund_code='G13180',
        sec_code=None,
        fund_name='米国株式配当貴族（年４回決算型）',
        fund_name_yomi='ベイコクカブシキハイトウキゾクネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13181': FundCodeEntry(
        fund_code='G13181',
        sec_code=None,
        fund_name='オール・マーケット・インカム戦略（資産成長重視コース／奇数月定額分配コース／奇数月定率分配コース／予想分配金提示型コース）',
        fund_name_yomi='オールマーケットインカムセンリャクシサンセイチョウジュウシコースキスウツキテイガクブンパイコースキスウツキテイリツブンパイコースヨソウブンパイキンテイジガタコース',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13182': FundCodeEntry(
        fund_code='G13182',
        sec_code=None,
        fund_name='パッシム・トラスト－シリーズ２０１８\u3000Ｓ＆Ｐ\u3000５００ファンド',
        fund_name_yomi='パッシムトラストシリーズニセンジュウハチエスアンドピーゴヒャクファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E30829',
        issuer_name='Ｊ．Ｐ．モルガン・マンサール・マネジメント・リミテッド',
    ),
    'G13183': FundCodeEntry(
        fund_code='G13183',
        sec_code=None,
        fund_name='これぞ、日本株',
        fund_name_yomi='コレゾニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13185': FundCodeEntry(
        fund_code='G13185',
        sec_code=None,
        fund_name='ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジあり（毎月決算型）\u3000ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジなし（毎月決算型）',
        fund_name_yomi='エヌダブリューキューフレキシブルインカムファンド\u3000カワセヘッジアリ\u3000マイツキケッサンガタ\u3000エヌダブリューキューフレキシブルインカムファンド\u3000カワセヘッジナシ\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13186': FundCodeEntry(
        fund_code='G13186',
        sec_code=None,
        fund_name='ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジあり（年１回決算型）\u3000ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジなし（年１回決算型）',
        fund_name_yomi='エヌダブリューキューフレキシブルインカムファンド\u3000カワセヘッジアリ\u3000ネンイッカイケッサンガタ\u3000エヌダブリューキューフレキシブルインカムファンド\u3000カワセヘッジナシ\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13187': FundCodeEntry(
        fund_code='G13187',
        sec_code=None,
        fund_name='ＳＢＩ地方創生・世界高配当株式ファンド（為替ヘッジあり）＜資産成長コース＞、ＳＢＩ地方創生・世界高配当株式ファンド（為替ヘッジあり）＜年３％定率払出しコース＞＜年５％定率払出しコース＞＜年７％定率払出しコース＞',
        fund_name_yomi='エスビーアイチホウソウセイセカイコウハイトウカブシキファンドカワセヘッジアリシサンセイチョウコース\u3000エスビーアイチホウソウセイセカイコウハイトウカブシキファンドカワセヘッジアリネンサンパーセントテイリツハライダシコース\u3000ネンゴパーセントテイリツハライダシコース\u3000ネンナナパーセントテイリツハライダシコース',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13188': FundCodeEntry(
        fund_code='G13188',
        sec_code=None,
        fund_name='ＡＢ米国不動産好利回り債券ファンド（為替ヘッジなし）',
        fund_name_yomi='エービーベイコクフドウサンコウリマワリサイケンファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G13189': FundCodeEntry(
        fund_code='G13189',
        sec_code='29710',
        fund_name='エスコンジャパンリート投資法人',
        fund_name_yomi='エスコンジャパンリートトウシホウジン',
        security_type='内国投資信託受益証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E34397',
        issuer_name='エスコンジャパンリート投資法人',
    ),
    'G13190': FundCodeEntry(
        fund_code='G13190',
        sec_code=None,
        fund_name='スパークス・韓国株ファンド',
        fund_name_yomi='スパークス\u3000カンコクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G13191': FundCodeEntry(
        fund_code='G13191',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１８－１２',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチハチイチニ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13192': FundCodeEntry(
        fund_code='G13192',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000バーチャルリアリティ',
        fund_name_yomi='イーマクシスネオバーチャルリアリティ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13193': FundCodeEntry(
        fund_code='G13193',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000ドローン',
        fund_name_yomi='イーマクシスネオドローン',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13194': FundCodeEntry(
        fund_code='G13194',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000ナノテクノロジー',
        fund_name_yomi='イーマクシスネオナノテクノロジー',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13195': FundCodeEntry(
        fund_code='G13195',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔセキュリティ',
        fund_name_yomi='アイトラストセキュリティ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13197': FundCodeEntry(
        fund_code='G13197',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１９‐０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチキュウノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13198': FundCodeEntry(
        fund_code='G13198',
        sec_code=None,
        fund_name='ＭＳＶグローバル資産配分ファンドⅠ（保守型）',
        fund_name_yomi='エムエスブイグローバルシサンハイブンファンドイチ\u3000ホシュガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13199': FundCodeEntry(
        fund_code='G13199',
        sec_code=None,
        fund_name='ＭＳＶグローバル資産配分ファンドⅡ（安定型）',
        fund_name_yomi='エムエスブイグローバルシサンハイブンファンドニ\u3000アンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13200': FundCodeEntry(
        fund_code='G13200',
        sec_code=None,
        fund_name='ＭＳＶグローバル資産配分ファンドⅢ（安定成長型）',
        fund_name_yomi='エムエスブイグローバルシサンハイブンファンドサン\u3000アンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13201': FundCodeEntry(
        fund_code='G13201',
        sec_code=None,
        fund_name='ＭＳＶグローバル資産配分ファンドⅣ（成長型）',
        fund_name_yomi='エムエスブイグローバルシサンハイブンファンドヨン\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13202': FundCodeEntry(
        fund_code='G13202',
        sec_code=None,
        fund_name='ＭＳＶグローバル資産配分ファンドⅤ（積極成長型）',
        fund_name_yomi='エムエスブイグローバルシサンハイブンファンドゴ\u3000セッキョクセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13203': FundCodeEntry(
        fund_code='G13203',
        sec_code=None,
        fund_name='ＣＳインベストメント・ファンズ・１２',
        fund_name_yomi='シーエスインベストメントファンズトウェルブ',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E34542',
        issuer_name='クレディ・スイス・ファンド・マネジメント・エスエイ',
    ),
    'G13205': FundCodeEntry(
        fund_code='G13205',
        sec_code=None,
        fund_name='ＤＣニッセイ新興国株式インデックス',
        fund_name_yomi='ディーシーニッセイシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13206': FundCodeEntry(
        fund_code='G13206',
        sec_code=None,
        fund_name='ＤＣニッセイ先進国リートインデックス',
        fund_name_yomi='ディーシーニッセイセンシンコクリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13207': FundCodeEntry(
        fund_code='G13207',
        sec_code=None,
        fund_name='ＤＣニッセイ日本株式ＥＳＧ資産形成ファンド',
        fund_name_yomi='ディーシーニッセイニホンカブシキイーエスジーシサンケイセイファント゛',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13208': FundCodeEntry(
        fund_code='G13208',
        sec_code=None,
        fund_name='ＤＣニッセイマーケットフォローバランス',
        fund_name_yomi='ディーシーニッセイマーケットフォローバランス',
        security_type='内国投資信託受益証券',
        period_1='12月9日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13210': FundCodeEntry(
        fund_code='G13210',
        sec_code=None,
        fund_name='インベスコ・ファンズ－インベスコ・バランスト・リスク・アロケーション・ファンド',
        fund_name_yomi='インベスコファンズインベスコバランストリスクアロケーションファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34575',
        issuer_name='インベスコ・ファンズ',
    ),
    'G13211': FundCodeEntry(
        fund_code='G13211',
        sec_code=None,
        fund_name='ノルデア１・シキャブ－ヨーロピアン・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ノルデアワンシキャブヨーロピアンハイイールドボンドファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E34574',
        issuer_name='ノルデア１・シキャブ',
    ),
    'G13213': FundCodeEntry(
        fund_code='G13213',
        sec_code=None,
        fund_name='社会課題解決応援ファンド',
        fund_name_yomi='シャカイカダイカイケツオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13214': FundCodeEntry(
        fund_code='G13214',
        sec_code=None,
        fund_name='アスパイア',
        fund_name_yomi='アスパイア',
        security_type='外国有価証券投資事業権利等',
        period_1='6月末日',
        period_2=None,
        edinet_code='E34585',
        issuer_name='ハンサード・インターナショナル・リミテッド',
    ),
    'G13215': FundCodeEntry(
        fund_code='G13215',
        sec_code=None,
        fund_name='グローバル全生物ゲノム株式ファンド（１年決算型）',
        fund_name_yomi='グローバルゼンセイブツゲノムカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13216': FundCodeEntry(
        fund_code='G13216',
        sec_code='92860',
        fund_name='エネクス・インフラ投資法人',
        fund_name_yomi='エネクスインフラトウシホウジン',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E34452',
        issuer_name='エネクス・インフラ投資法人',
    ),
    'G13217': FundCodeEntry(
        fund_code='G13217',
        sec_code=None,
        fund_name='ＵＳマイクロキャップ株式ファンド',
        fund_name_yomi='ユーエスマイクロキャップカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E27736',
        issuer_name='ベイビュー・アセット・マネジメント株式会社',
    ),
    'G13218': FundCodeEntry(
        fund_code='G13218',
        sec_code=None,
        fund_name='先進国ハイクオリティ成長株式ファンド（為替ヘッジあり）、先進国ハイクオリティ成長株式ファンド（為替ヘッジなし）',
        fund_name_yomi='センシンコクハイクオリティセイチョウカブシキファンドカワセヘッジアリ\u3000センシンコクハイクオリティセイチョウカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13219': FundCodeEntry(
        fund_code='G13219',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０１',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13220': FundCodeEntry(
        fund_code='G13220',
        sec_code=None,
        fund_name='ステート・ストリート米国社債インデックス・オープン２',
        fund_name_yomi='ステートストリートベイコクシャサイインデックスオープンニ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G13221': FundCodeEntry(
        fund_code='G13221',
        sec_code=None,
        fund_name='分散名人（国内重視型）',
        fund_name_yomi='ブンサンメイジンコクナイジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G13222': FundCodeEntry(
        fund_code='G13222',
        sec_code=None,
        fund_name='次世代金融テクノロジー株式ファンド',
        fund_name_yomi='ジセダイキンユウテクノロジーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13223': FundCodeEntry(
        fund_code='G13223',
        sec_code=None,
        fund_name='国内株式アクティブバリューファンド（ＳＭＡ専用）',
        fund_name_yomi='コクナイカブシキアクティブバリューファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13224': FundCodeEntry(
        fund_code='G13224',
        sec_code=None,
        fund_name='ＨＳＢＣ世界資産選抜育てるコース（資産形成型）／収穫コース（予想分配金提示型）',
        fund_name_yomi='エイチエスビーシーセカイシサンセンバツソダテルコースシサンケイセイガタシュウカクコースヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13226': FundCodeEntry(
        fund_code='G13226',
        sec_code='25230',
        fund_name='ＭＡＸＩＳトピックス（除く金融）上場投信',
        fund_name_yomi='マクシストピックスノゾクキンユウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13227': FundCodeEntry(
        fund_code='G13227',
        sec_code=None,
        fund_name='ベイリー・ギフォード世界長期成長株ファンド',
        fund_name_yomi='ベイリーギフォードセカイチョウキセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13228': FundCodeEntry(
        fund_code='G13228',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・豪州インカム資産ファンド（隔月分配型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ゴウシュウインカムシサンファンド\u3000カクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G13229': FundCodeEntry(
        fund_code='G13229',
        sec_code='25240',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＴＯＰＩＸ',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000トピックス',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13230': FundCodeEntry(
        fund_code='G13230',
        sec_code='25250',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000日経２２５',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13231': FundCodeEntry(
        fund_code='G13231',
        sec_code='25260',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＪＰＸ日経４００',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ジェイピーエックスニッケイヨンヒャク',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13232': FundCodeEntry(
        fund_code='G13232',
        sec_code='25270',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000東証ＲＥＩＴ\u3000Ｃｏｒｅ指数',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000トウショウリート\u3000コアシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13233': FundCodeEntry(
        fund_code='G13233',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞米国株式\u3000Ｓ＆Ｐ５００インデックスファンド',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ベイコクカブシキ\u3000エスアンドピーゴヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13234': FundCodeEntry(
        fund_code='G13234',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞Ｊ－ＲＥＩＴインデックスファンド（年１回決算型）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ジェイリートインデックスファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13235': FundCodeEntry(
        fund_code='G13235',
        sec_code=None,
        fund_name='モルガン・スタンレー社債／マルチアセット運用戦略ファンド２０１９－０３',
        fund_name_yomi='モルガンスタンレーシャサイ\u3000マルチアセットウンヨウセンリャクファンド\u3000ニゼロイチキュウゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13236': FundCodeEntry(
        fund_code='G13236',
        sec_code=None,
        fund_name='国内株式アクティブファンドセレクション（ラップ専用）',
        fund_name_yomi='コクナイカブシキアクティブファンドセレクション\u3000ラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13237': FundCodeEntry(
        fund_code='G13237',
        sec_code=None,
        fund_name='グローバルＳＤＧｓ株式ファンド',
        fund_name_yomi='グローバルエスディージーズカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13241': FundCodeEntry(
        fund_code='G13241',
        sec_code=None,
        fund_name='地方創生日本株ファンド',
        fund_name_yomi='チホウソウセイニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13243': FundCodeEntry(
        fund_code='G13243',
        sec_code=None,
        fund_name='プレミアム・ファンズ－グローバル・コア債券ファンド',
        fund_name_yomi='プレミアムファンズグローバルコアサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G13244': FundCodeEntry(
        fund_code='G13244',
        sec_code=None,
        fund_name='ＵＢＳ\u3000ＭＳＣＩ先進国ＥＳＧ株式インデックス・ファンド',
        fund_name_yomi='ユービーエス\u3000エムエスシーアイセンシンコクイーエスジーカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13247': FundCodeEntry(
        fund_code='G13247',
        sec_code=None,
        fund_name='世界フード関連株式オープン',
        fund_name_yomi='セカイフードカンレンカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13248': FundCodeEntry(
        fund_code='G13248',
        sec_code=None,
        fund_name='ＡＲ国内バリュー株式ファンド（ファンドラップ）',
        fund_name_yomi='エーアールコクナイバリューカブシキファンドファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13249': FundCodeEntry(
        fund_code='G13249',
        sec_code=None,
        fund_name='外国株式アクティブファンドセレクション（ラップ専用）',
        fund_name_yomi='ガイコクカブシキアクティブファンドセレクションラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13250': FundCodeEntry(
        fund_code='G13250',
        sec_code=None,
        fund_name='外国債券アクティブファンドセレクション（ラップ専用）',
        fund_name_yomi='ガイコクサイケンアクティブファンドセレクションラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13251': FundCodeEntry(
        fund_code='G13251',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０２',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロニイ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13252': FundCodeEntry(
        fund_code='G13252',
        sec_code=None,
        fund_name='アクティブ元年・日本株ファンド',
        fund_name_yomi='アクティブガンネンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13253': FundCodeEntry(
        fund_code='G13253',
        sec_code=None,
        fund_name='野村日本小型株セレクト（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニホンコガタカブセレクトノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13255': FundCodeEntry(
        fund_code='G13255',
        sec_code='25280',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000東証ＲＥＩＴ\u3000Ｃｏｒｅ指数',
        fund_name_yomi='アイフリーイーティーエフトウショウリートコアシスウ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13256': FundCodeEntry(
        fund_code='G13256',
        sec_code='29720',
        fund_name='サンケイリアルエステート投資法人',
        fund_name_yomi='サンケイリアルエステートトウシホウジン',
        security_type='内国投資証券',
        period_1='8月末日',
        period_2='2月末日',
        edinet_code='E34684',
        issuer_name='サンケイリアルエステート投資法人',
    ),
    'G13257': FundCodeEntry(
        fund_code='G13257',
        sec_code=None,
        fund_name='楽天・全世界債券インデックス（為替ヘッジ）ファンド',
        fund_name_yomi='ラクテンゼンセカイサイケンインデックスカワセヘッジファンド',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13259': FundCodeEntry(
        fund_code='G13259',
        sec_code=None,
        fund_name='国内株式絶対収益追求型ファンド',
        fund_name_yomi='コクナイカブシキゼッタイシュウエキツイキュウガタファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13261': FundCodeEntry(
        fund_code='G13261',
        sec_code=None,
        fund_name='三井住友ＤＳ日本バリュー株ファンド',
        fund_name_yomi='ミツイスミトモディーエスニホンバリューカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13262': FundCodeEntry(
        fund_code='G13262',
        sec_code=None,
        fund_name='大和住銀日本グロース株ファンド',
        fund_name_yomi='ダイワスミギンニホングロースカブファンド',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13263': FundCodeEntry(
        fund_code='G13263',
        sec_code=None,
        fund_name='エス・ビー・日本株オープン２２５',
        fund_name_yomi='エスビーニホンカブオープンニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13264': FundCodeEntry(
        fund_code='G13264',
        sec_code=None,
        fund_name='三井住友ＤＳ日本債券ファンド',
        fund_name_yomi='ミツイスミトモディーエスニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13265': FundCodeEntry(
        fund_code='G13265',
        sec_code=None,
        fund_name='大和住銀ＤＣ年金設計ファンド３０\u3000大和住銀ＤＣ年金設計ファンド５０\u3000大和住銀ＤＣ年金設計ファンド７０',
        fund_name_yomi='ダイワスミギンディーシーネンキンセッケイファンドサンジュウ\u3000ダイワスミギンディーシーネンキンセッケイファンドゴジュウ\u3000ダイワスミギンディーシーネンキンセッケイファンドナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13266': FundCodeEntry(
        fund_code='G13266',
        sec_code=None,
        fund_name='大和住銀ＤＣ日本株式ファンド',
        fund_name_yomi='ダイワスミギンディーシーニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13267': FundCodeEntry(
        fund_code='G13267',
        sec_code=None,
        fund_name='大和住銀ＤＣ日本債券ファンド',
        fund_name_yomi='ダイワスミギンディーシーニホンサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13268': FundCodeEntry(
        fund_code='G13268',
        sec_code=None,
        fund_name='大和住銀ＤＣ外国株式ファンド',
        fund_name_yomi='ダイワスミギンディーシーガイコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13269': FundCodeEntry(
        fund_code='G13269',
        sec_code=None,
        fund_name='大和住銀ＤＣ外国債券ファンド',
        fund_name_yomi='ダイワスミギンディーシーガイコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13270': FundCodeEntry(
        fund_code='G13270',
        sec_code=None,
        fund_name='大和住銀ＤＣ日本バリュー株ファンド',
        fund_name_yomi='ダイワスミギンディーシーニホンバリューカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13271': FundCodeEntry(
        fund_code='G13271',
        sec_code=None,
        fund_name='大和住銀ジャパン・スペシャルニュートラル・コース（ヘッジあり）／マーケット・コース（ヘッジなし）',
        fund_name_yomi='ダイワスミギンジャパンスペシャル\u3000ニュートラルコースヘッジアリ\u3000マーケットコースヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13272': FundCodeEntry(
        fund_code='G13272',
        sec_code=None,
        fund_name='短期豪ドル債オープン（毎月分配型）',
        fund_name_yomi='タンキゴウドルサイオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13273': FundCodeEntry(
        fund_code='G13273',
        sec_code=None,
        fund_name='エマージング債券ファンド（毎月分配型）',
        fund_name_yomi='エマージングサイケンファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13274': FundCodeEntry(
        fund_code='G13274',
        sec_code=None,
        fund_name='Ｊ－Ｓｔｏｃｋアクティブ・オープン',
        fund_name_yomi='ジェイストック\u3000アクティブオープン',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13275': FundCodeEntry(
        fund_code='G13275',
        sec_code=None,
        fund_name='Ｔ．ロウ・プライスＵＳインカムファンド',
        fund_name_yomi='ティロウプライスユーエスインカムファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13276': FundCodeEntry(
        fund_code='G13276',
        sec_code=None,
        fund_name='チャイナ騰飛（チャイナ・エクイティ・オープン）',
        fund_name_yomi='チャイナトンフェイチャイナエクイティオープン',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13277': FundCodeEntry(
        fund_code='G13277',
        sec_code=None,
        fund_name='大和住銀日本小型株ファンド',
        fund_name_yomi='ダイワスミギンニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13278': FundCodeEntry(
        fund_code='G13278',
        sec_code=None,
        fund_name='グローバル好配当株オープン',
        fund_name_yomi='グローバルコウハイトウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13279': FundCodeEntry(
        fund_code='G13279',
        sec_code=None,
        fund_name='日本好配当株オープン',
        fund_name_yomi='ニホンコウハイトウカブオープン',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13281': FundCodeEntry(
        fund_code='G13281',
        sec_code=None,
        fund_name='グローバル・ベスト・ファンド',
        fund_name_yomi='グローバルベストファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13282': FundCodeEntry(
        fund_code='G13282',
        sec_code=None,
        fund_name='大和住銀ＤＣ国内株式ファンド',
        fund_name_yomi='ダイワスミギンディーシィーコクナイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13283': FundCodeEntry(
        fund_code='G13283',
        sec_code=None,
        fund_name='大和住銀ＤＣ海外株式アクティブファンド',
        fund_name_yomi='ダイワスミギンディーシーカイガイカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13284': FundCodeEntry(
        fund_code='G13284',
        sec_code=None,
        fund_name='ＳＭＢＣファンドラップ・日本バリュー株\u3000ＳＭＢＣファンドラップ・日本グロース株\u3000ＳＭＢＣファンドラップ・日本中小型株\u3000ＳＭＢＣファンドラップ・米国株',
        fund_name_yomi='エスエムビーシーファンドラップニホンバリューカブ\u3000エスエムビーシーファンドラップニホングロースカブ\u3000エスエムビーシーファンドラップニホンチュウコガタカブ\u3000エスエムビーシーファンドラップベイコクカブ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13285': FundCodeEntry(
        fund_code='G13285',
        sec_code=None,
        fund_name='アジア好配当株ファンド',
        fund_name_yomi='アジアコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13286': FundCodeEntry(
        fund_code='G13286',
        sec_code=None,
        fund_name='グローバル資産分散オープン',
        fund_name_yomi='グローバルシサンブンサンオープン',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13287': FundCodeEntry(
        fund_code='G13287',
        sec_code=None,
        fund_name='高金利通貨オープン',
        fund_name_yomi='コウキンリツウカオープン',
        security_type='内国投資信託受益証券',
        period_1='2月14日',
        period_2='8月14日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13288': FundCodeEntry(
        fund_code='G13288',
        sec_code=None,
        fund_name='ＤＣ日本国債プラス',
        fund_name_yomi='ディーシーニホンコクサイプラス',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13290': FundCodeEntry(
        fund_code='G13290',
        sec_code=None,
        fund_name='通貨選択型エマージング・ボンド・ファンド',
        fund_name_yomi='ツウカセンタクガタエマージングボンドファンド',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13291': FundCodeEntry(
        fund_code='G13291',
        sec_code=None,
        fund_name='大和住銀中国株式ファンド\u3000大和住銀中国株式ファンド（マネー・ポートフォリオ）',
        fund_name_yomi='ダイワスミギンチュウゴクカブシキファンド\u3000ダイワスミギンチュウゴクカブシキファンドマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13295': FundCodeEntry(
        fund_code='G13295',
        sec_code=None,
        fund_name='日本株厳選ファンド',
        fund_name_yomi='ニホンカブゲンセンファンド',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13297': FundCodeEntry(
        fund_code='G13297',
        sec_code=None,
        fund_name='日本株２２５・米ドルコース',
        fund_name_yomi='ニホンカブニイニイゴベイドルコース',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13298': FundCodeEntry(
        fund_code='G13298',
        sec_code=None,
        fund_name='グローバルＣＢオープン',
        fund_name_yomi='グローバルシービーオープン',
        security_type='内国投資信託受益証券',
        period_1='5月19日',
        period_2='11月19日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13299': FundCodeEntry(
        fund_code='G13299',
        sec_code=None,
        fund_name='短期豪ドル債オープン（年２回決算型）',
        fund_name_yomi='タンキゴウドルサイオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13300': FundCodeEntry(
        fund_code='G13300',
        sec_code=None,
        fund_name='メキシコ債券オープン（毎月分配型）',
        fund_name_yomi='メキシコサイケンオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13301': FundCodeEntry(
        fund_code='G13301',
        sec_code=None,
        fund_name='オーストラリア高配当株プレミアム（毎月分配型）',
        fund_name_yomi='オーストラリアコウハイトウカブプレミアムマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13302': FundCodeEntry(
        fund_code='G13302',
        sec_code=None,
        fund_name='スマート・ストラテジー・ファンド（毎月決算型）\u3000スマート・ストラテジー・ファンド（年２回決算型）',
        fund_name_yomi='スマートストラテジーファンドマイツキケッサンガタ\u3000スマートストラテジーファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13304': FundCodeEntry(
        fund_code='G13304',
        sec_code=None,
        fund_name='カナダ高配当株ツインα（毎月分配型）',
        fund_name_yomi='カナダコウハイトウカブツインアルファマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13305': FundCodeEntry(
        fund_code='G13305',
        sec_code=None,
        fund_name='北米高配当株ファンド（毎月決算型）\u3000北米高配当株ファンド（年２回決算型）',
        fund_name_yomi='ホクベイコウハイトウカブファンドマイツキケッサンガタ\u3000ホクベイコウハイトウカブファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13306': FundCodeEntry(
        fund_code='G13306',
        sec_code=None,
        fund_name='エマージング・ボンド・ファンド・カナダドルコース（毎月分配型）\u3000エマージング・ボンド・ファンド・メキシコペソコース（毎月分配型）',
        fund_name_yomi='エマージングボンドファンドカナダドルコースマイツキブンパイガタ\u3000エマージングボンドファンドメキシコペソコースマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13307': FundCodeEntry(
        fund_code='G13307',
        sec_code=None,
        fund_name='タフ・アメリカ',
        fund_name_yomi='タフアメリカ',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13308': FundCodeEntry(
        fund_code='G13308',
        sec_code=None,
        fund_name='メキシコ債券オープン（資産成長型）',
        fund_name_yomi='メキシコサイケンオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13309': FundCodeEntry(
        fund_code='G13309',
        sec_code=None,
        fund_name='米国小型株ツインα（毎月分配型）',
        fund_name_yomi='ベイコクコガタカブツインアルファマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13311': FundCodeEntry(
        fund_code='G13311',
        sec_code=None,
        fund_name='カナダ高配当株ファンド',
        fund_name_yomi='カナダコウハイトウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13312': FundCodeEntry(
        fund_code='G13312',
        sec_code=None,
        fund_name='ニッポン中小型株ファンド',
        fund_name_yomi='ニッポンチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月2日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13314': FundCodeEntry(
        fund_code='G13314',
        sec_code=None,
        fund_name='日本株アルファ・カルテット（毎月分配型）',
        fund_name_yomi='ニホンカブアルファカルテットマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月4日',
        period_2='9月4日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13315': FundCodeEntry(
        fund_code='G13315',
        sec_code=None,
        fund_name='短期ＮＺドル債オープン（毎月分配型）\u3000短期ＮＺドル債オープン（資産成長型）',
        fund_name_yomi='タンキニュージーランドドルサイオープンマイツキブンパイガタ\u3000タンキニュージーランドドルサイオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13320': FundCodeEntry(
        fund_code='G13320',
        sec_code=None,
        fund_name='富岡製糸場・絹産業遺産群保護活動応援ファンド',
        fund_name_yomi='トミオカセイシジョウキヌサンギョウイサングンホゴカツドウオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月4日',
        period_2='7月4日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13322': FundCodeEntry(
        fund_code='G13322',
        sec_code=None,
        fund_name='フレキシブル日本株ファンド',
        fund_name_yomi='フレキシブルニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13324': FundCodeEntry(
        fund_code='G13324',
        sec_code=None,
        fund_name='英国国債ファンド－ギルト１０－（為替ヘッジなし）',
        fund_name_yomi='エイコクコクサイファンドギルトテンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月2日',
        period_2='9月2日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13325': FundCodeEntry(
        fund_code='G13325',
        sec_code=None,
        fund_name='米国リバーサル戦略ツインαネオ（毎月分配型）',
        fund_name_yomi='ベイコクリバーサルセンリャクツインアルファネオマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13326': FundCodeEntry(
        fund_code='G13326',
        sec_code=None,
        fund_name='米国リート厳選ファンド（毎月決算型）\u3000米国リート厳選ファンド（資産成長型）',
        fund_name_yomi='ベイコクリートゲンセンファンドマイツキケッサンガタ\u3000ベイコクリートゲンセンファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13328': FundCodeEntry(
        fund_code='G13328',
        sec_code=None,
        fund_name='大和住銀ジャパン・ファンダメンタル・アクティブ・ファンド（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワスミギンジャパンファンダメンタルアクティブファンドダイワエスエムエイセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13334': FundCodeEntry(
        fund_code='G13334',
        sec_code=None,
        fund_name='米国コア・バランス・ファンド',
        fund_name_yomi='ベイコクコアバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13335': FundCodeEntry(
        fund_code='G13335',
        sec_code=None,
        fund_name='ＳＭＢＣ円資産ファンド',
        fund_name_yomi='エスエムビーシーエンシサンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月11日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13338': FundCodeEntry(
        fund_code='G13338',
        sec_code=None,
        fund_name='米国イノベーション・ファンド（年４回決算型）',
        fund_name_yomi='ベイコクイノベーションファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13339': FundCodeEntry(
        fund_code='G13339',
        sec_code=None,
        fund_name='米国イノベーション・ファンド（年１回決算型）',
        fund_name_yomi='ベイコクイノベーションファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13340': FundCodeEntry(
        fund_code='G13340',
        sec_code=None,
        fund_name='ＮＢマルチ戦略ファンド',
        fund_name_yomi='エヌビーマルチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='8月1日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13341': FundCodeEntry(
        fund_code='G13341',
        sec_code=None,
        fund_name='ひとくふう日本株式ファンド',
        fund_name_yomi='ヒトクフウニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13342': FundCodeEntry(
        fund_code='G13342',
        sec_code=None,
        fund_name='日本株アルファ・カルテット（年２回決算型）',
        fund_name_yomi='ニホンカブアルファカルテットネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月4日',
        period_2='9月4日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13343': FundCodeEntry(
        fund_code='G13343',
        sec_code=None,
        fund_name='ひとくふう世界国債ファンド（為替ヘッジあり）',
        fund_name_yomi='ヒトクフウセカイコクサイファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13344': FundCodeEntry(
        fund_code='G13344',
        sec_code=None,
        fund_name='世界国債プラス',
        fund_name_yomi='セカイコクサイプラス',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13345': FundCodeEntry(
        fund_code='G13345',
        sec_code=None,
        fund_name='大和住銀ＤＣ日本株式アクティブファンド',
        fund_name_yomi='ダイワスミギンディーシーニホンカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13346': FundCodeEntry(
        fund_code='G13346',
        sec_code=None,
        fund_name='日本高配当株フォーカス（マイルドジャパン）\u3000日本高配当株フォーカス（プレミアジャパン）',
        fund_name_yomi='ニホンコウハイトウカブフォーカスマイルドジャパン\u3000ニホンコウハイトウカブフォーカスプレミアジャパン',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13347': FundCodeEntry(
        fund_code='G13347',
        sec_code=None,
        fund_name='人生１００年応援ファンド（資産成長コース）、人生１００年応援ファンド（ちょっぴり受取コース）、人生１００年応援ファンド（おもいっきり受取コース）',
        fund_name_yomi='ジンセイヒャクネンオウエンファンドシサンセイチョウコースジンセイヒャクネンオウエンファンドチョッピリウケトリコースジンセイヒャクネンオウエンファンドオモイッキリウケトリコース',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13349': FundCodeEntry(
        fund_code='G13349',
        sec_code=None,
        fund_name='マイ・ウェイ・ジャパン',
        fund_name_yomi='マイウェイジャパン',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13350': FundCodeEntry(
        fund_code='G13350',
        sec_code=None,
        fund_name='ひとくふう新興国株式ファンド',
        fund_name_yomi='ヒトクフウシンコウコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13351': FundCodeEntry(
        fund_code='G13351',
        sec_code=None,
        fund_name='世界インパクト投資ファンド',
        fund_name_yomi='セカイインパクトトウシファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13352': FundCodeEntry(
        fund_code='G13352',
        sec_code=None,
        fund_name='大和住銀／コロンビア米国株リバーサル戦略ファンドＡコース（ダイワ投資一任専用）\u3000大和住銀／コロンビア米国株リバーサル戦略ファンドＢコース（ダイワ投資一任専用）',
        fund_name_yomi='ダイワスミギンコロンビアベイコクカブリバーサルセンリャクファンドエーコースダイワトウシイチニンセンヨウ\u3000ダイワスミギンコロンビアベイコクカブリバーサルセンリャクファンドビーコースダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13353': FundCodeEntry(
        fund_code='G13353',
        sec_code=None,
        fund_name='ひとくふう先進国株式ファンド',
        fund_name_yomi='ヒトクフウセンシンコクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13354': FundCodeEntry(
        fund_code='G13354',
        sec_code=None,
        fund_name='オージー・リート・ファンド（毎月分配型）',
        fund_name_yomi='オージーリートファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13355': FundCodeEntry(
        fund_code='G13355',
        sec_code=None,
        fund_name='ひとくふう先進国リートファンド',
        fund_name_yomi='ヒトクフウセンシンコクリートファンド',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13356': FundCodeEntry(
        fund_code='G13356',
        sec_code=None,
        fund_name='日本成長テーマフォーカス',
        fund_name_yomi='ニホンセイチョウテーマフォーカス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13357': FundCodeEntry(
        fund_code='G13357',
        sec_code=None,
        fund_name='世界リアルアセット・バランス（毎月決算型）\u3000世界リアルアセット・バランス（資産成長型）',
        fund_name_yomi='セカイリアルアセットバランスマイツキケッサンガタ\u3000セカイリアルアセットバランスシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13359': FundCodeEntry(
        fund_code='G13359',
        sec_code=None,
        fund_name='米国中期債運用戦略ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ベイコクチュウキサイウンヨウセンリャクファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13360': FundCodeEntry(
        fund_code='G13360',
        sec_code=None,
        fund_name='グローバルＥＶ関連株ファンド（為替ヘッジあり）\u3000グローバルＥＶ関連株ファンド（為替ヘッジなし）',
        fund_name_yomi='グローバルイーブイカンレンカブファンドカワセヘッジアリ\u3000グローバルイーブイカンレンカブファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13361': FundCodeEntry(
        fund_code='G13361',
        sec_code=None,
        fund_name='大和住銀先進国国債ファンド（リスク抑制型）',
        fund_name_yomi='ダイワスミギンセンシンコクコクサイファンドリスクヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13362': FundCodeEntry(
        fund_code='G13362',
        sec_code=None,
        fund_name='欧州バンクローン・オープン（為替ヘッジあり）\u3000欧州バンクローン・オープン（為替ヘッジなし）',
        fund_name_yomi='オウシュウバンクローンオープンカワセヘッジアリ\u3000オウシュウバンクローンオープンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13363': FundCodeEntry(
        fund_code='G13363',
        sec_code=None,
        fund_name='世界インパクト投資ファンド（資産成長型）',
        fund_name_yomi='セカイインパクトトウシファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13364': FundCodeEntry(
        fund_code='G13364',
        sec_code=None,
        fund_name='＜七十七＞ＥＳＧ日本株オープン',
        fund_name_yomi='シチジュウシチイーエスジーニホンカブオープン',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13365': FundCodeEntry(
        fund_code='G13365',
        sec_code=None,
        fund_name='ひとくふうターゲット・デート・ファンド２０３０／２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５',
        fund_name_yomi='ヒトクフウターゲットデートファンドニゼロサンゼロ\u3000ニゼロサンゴ\u3000ニゼロヨンゼロ\u3000ニゼロヨンゴ\u3000ニゼロゴゼロ\u3000ニゼロゴゴ\u3000ニゼロロクゼロ\u3000ニゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13366': FundCodeEntry(
        fund_code='G13366',
        sec_code=None,
        fund_name='日本中小型クオリティバリュー株ファンド',
        fund_name_yomi='ニホンチュウコガタクオリティバリューカブファンド',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13367': FundCodeEntry(
        fund_code='G13367',
        sec_code=None,
        fund_name='世界小型株厳選ファンド',
        fund_name_yomi='セカイコガタカブゲンセンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13369': FundCodeEntry(
        fund_code='G13369',
        sec_code=None,
        fund_name='世界スタートアップ＆イノベーション株式ファンド',
        fund_name_yomi='セカイスタートアップアンドイノベーションカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13370': FundCodeEntry(
        fund_code='G13370',
        sec_code=None,
        fund_name='デンマーク・カバード債券・インカムファンド２０１９－０３（為替ヘッジあり）',
        fund_name_yomi='デンマークカバードサイケンインカムファンド\u3000ニゼロイチキュウゼロサン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G13371': FundCodeEntry(
        fund_code='G13371',
        sec_code=None,
        fund_name='ソシエテ・ジェネラル\u3000イタリア国債ユーロ円建リパッケージ債券（為替参照利回り変動型）ファンド２０１９－０３',
        fund_name_yomi='ソシエテジェネラル\u3000イタリアコクサイユーロエンダテリパッケージサイケン\u3000カワセサンショウリマワリヘンドウガタ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13372': FundCodeEntry(
        fund_code='G13372',
        sec_code=None,
        fund_name='イノベーション・インデックス・シェアリングエコノミー',
        fund_name_yomi='イノベーションインデックスシェアリングエコノミー',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13373': FundCodeEntry(
        fund_code='G13373',
        sec_code=None,
        fund_name='Ｏｎｅ国内株オープン（年２回決算型）',
        fund_name_yomi='ワンコクナイカブオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月末日',
        period_2='8月29日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13376': FundCodeEntry(
        fund_code='G13376',
        sec_code=None,
        fund_name='おおさか・かんさいアクティブファンド',
        fund_name_yomi='オオサカカンサイアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13377': FundCodeEntry(
        fund_code='G13377',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－償還時目標設定型ファンド１９０３',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ショウカンジモクヒョウセッテイガタファンドイチキュウゼロサン',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G13379': FundCodeEntry(
        fund_code='G13379',
        sec_code=None,
        fund_name='フランス国債７－１０年ラダーファンド（為替ヘッジあり）（ラップ向け）',
        fund_name_yomi='フランスコクサイナナカラジュウネンラダーファンドカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13380': FundCodeEntry(
        fund_code='G13380',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０３',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロサン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13381': FundCodeEntry(
        fund_code='G13381',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ―米ドル建\u3000モルガン・スタンレー\u3000グローバル・プレミアム株式オープン',
        fund_name_yomi='ソフォスケイマントラストツーベイドルダテモルガンスタンレーグローバルプレミアムカブシキオープン',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G13382': FundCodeEntry(
        fund_code='G13382',
        sec_code=None,
        fund_name='グローバル・インカム・フルコース（為替リスク軽減型）／（為替ヘッジなし）',
        fund_name_yomi='グローバルインカムフルコースカワセリスクケイゲンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13383': FundCodeEntry(
        fund_code='G13383',
        sec_code=None,
        fund_name='インターナショナル株式アクティブファンド（ラップ専用）',
        fund_name_yomi='インターナショナルカブシキアクティブファンドラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='12月14日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13384': FundCodeEntry(
        fund_code='G13384',
        sec_code=None,
        fund_name='ＤＣターゲット・イヤーファンド（６資産・運用継続型）',
        fund_name_yomi='ディーシーターゲット\u3000イヤーファンド\u3000ロクシサン\u3000ウンヨウケイゾクガタ',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13386': FundCodeEntry(
        fund_code='G13386',
        sec_code=None,
        fund_name='ＢＮＹメロン・リアル・リターン・ファンド（ＳＭＡ向け）（為替ヘッジなし）',
        fund_name_yomi='ビーエヌワイメロンリアルリターンファンドエスエムエームケカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G13387': FundCodeEntry(
        fund_code='G13387',
        sec_code=None,
        fund_name='楽天日本株トリプル・ベアⅣ',
        fund_name_yomi='ラクテンニホンカブトリプルベアフォー',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13388': FundCodeEntry(
        fund_code='G13388',
        sec_code=None,
        fund_name='グローバル担保付き債券ファンド（為替ヘッジあり）',
        fund_name_yomi='グローバルタンポツキサイケンファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13389': FundCodeEntry(
        fund_code='G13389',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000バイオ・メディカル',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000バイオ\u3000メディカル',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13390': FundCodeEntry(
        fund_code='G13390',
        sec_code=None,
        fund_name='クスリのアオキホールディングス株式ファンド（確定拠出年金向け）',
        fund_name_yomi='クスリノアオキホールディングスカブシキファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='10月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13392': FundCodeEntry(
        fund_code='G13392',
        sec_code=None,
        fund_name='投資のソムリエ（ターゲット・イヤー２０４０）、投資のソムリエ（ターゲット・イヤー２０５０）、投資のソムリエ（ターゲット・イヤー２０６０）',
        fund_name_yomi='トウシノソムリエターゲットイヤーニイゼロヨンゼロ\u3000トウシノソムリエターゲットイヤーニイゼロゴウゼロ\u3000トウシノソムリエターゲットイヤーニイゼロロクゼロ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13393': FundCodeEntry(
        fund_code='G13393',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１９‐０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチキュウノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13394': FundCodeEntry(
        fund_code='G13394',
        sec_code=None,
        fund_name='実績配当型合同運用指定金銭信託（個人用）ベビーファンド\u3000対面型受益権／愛称：投資の一歩\u3000実績配当型合同運用指定金銭信託（個人用）ベビーファンド\u3000非対面型受益権／愛称：クエスト',
        fund_name_yomi='ジッセキハイトウガタゴウドウウンヨウシテイキンセンシンタクコジンヨウベビーファンド\u3000タイメンガタジュエキケンアイショウトウシノイッポ\u3000ジッセキハイトウガタゴウドウウンヨウシテイキンセンシンタクコジンヨウベビーファンド\u3000ヒタイメンガタジュエキケンアイショウクエスト',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13395': FundCodeEntry(
        fund_code='G13395',
        sec_code=None,
        fund_name='野村中国債券ファンド（毎月分配型）、野村中国債券ファンド（年２回決算型）',
        fund_name_yomi='ノムラチュウゴクサイケンファンドマイツキブンパイガタ\u3000ノムラチュウゴクサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13397': FundCodeEntry(
        fund_code='G13397',
        sec_code=None,
        fund_name='日系外債オープン（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ニッケイガイサイオープンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13398': FundCodeEntry(
        fund_code='G13398',
        sec_code=None,
        fund_name='円キャッシュプラス・高金利先進国債券ファンド',
        fund_name_yomi='エンキャッシュプラス\u3000コウキンリセンシンコクサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13399': FundCodeEntry(
        fund_code='G13399',
        sec_code=None,
        fund_name='ラッセル・インベストメント国内株式マルチ・マネージャーＦ',
        fund_name_yomi='ラッセルインベストメントコクナイカブシキマルチマネージャーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2=None,
        edinet_code='E12450',
        issuer_name='ラッセル・インベストメント株式会社',
    ),
    'G13400': FundCodeEntry(
        fund_code='G13400',
        sec_code=None,
        fund_name='マニュライフ・アジア好利回り債券戦略ファンド（３年投資型）２０１９‐０４\u3000為替ヘッジありコース、マニュライフ・アジア好利回り債券戦略ファンド（３年投資型）２０１９‐０４\u3000為替ヘッジなしコース',
        fund_name_yomi='マニュライフアジアコウリマワリサイケンセンリャクファンドサンネントウシガタカワセヘッジアリコース\u3000マニュライフアジアコウリマワリサイケンセンリャクファンドサンネントウシガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13401': FundCodeEntry(
        fund_code='G13401',
        sec_code=None,
        fund_name='日本生命第３回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイサンカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E34852',
        issuer_name='日本生命第３回劣後ローン流動化株式会社',
    ),
    'G13402': FundCodeEntry(
        fund_code='G13402',
        sec_code=None,
        fund_name='マルチ・マネージャー・アクセスＩＩ－エマージング・マーケット・デッド－ＵＳ\u3000マルチ・クレジット－ハイ・イールド',
        fund_name_yomi='マルチマネージャーアクセスツーエマージングマーケットデッドユーエスマルチクレジットハイイールド',
        security_type='外国投資証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E34110',
        issuer_name='マルチ・マネージャー・アクセスⅡ',
    ),
    'G13403': FundCodeEntry(
        fund_code='G13403',
        sec_code=None,
        fund_name='東京海上・宇宙関連株式ファンド（為替ヘッジあり）',
        fund_name_yomi='トウキョウカイジョウウチュウカンレンカブシキファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13404': FundCodeEntry(
        fund_code='G13404',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０４',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13405': FundCodeEntry(
        fund_code='G13405',
        sec_code=None,
        fund_name='ＤＩＡＭケイマン・トラスト－米ドル建てゴールドマン・サックス社債／国際分散投資戦略ファンド（５年）２０１９－０４',
        fund_name_yomi='ダイアムケイマントラストベイドルダテゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドゴネンニゼロイチキュウゼロヨン',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E25766',
        issuer_name='クイーンズゲート',
    ),
    'G13406': FundCodeEntry(
        fund_code='G13406',
        sec_code=None,
        fund_name='あい・パワーファンド',
        fund_name_yomi='アイパワーファンド',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E11776',
        issuer_name='あいグローバル・アセット・マネジメント株式会社',
    ),
    'G13407': FundCodeEntry(
        fund_code='G13407',
        sec_code=None,
        fund_name='ＧＳグローバル・コア株式ファンド（ＤＣ・つみたてＮＩＳＡ専用）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000コア\u3000カブシキ\u3000ファンド\u3000ディーシー\u3000ツミタテ\u3000ニーサ\u3000センヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G13408': FundCodeEntry(
        fund_code='G13408',
        sec_code=None,
        fund_name='＜ＤＣ＞ベイリー・ギフォード世界長期成長株ファンド',
        fund_name_yomi='ディーシーベイリーギフォードセカイチョウキセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13409': FundCodeEntry(
        fund_code='G13409',
        sec_code=None,
        fund_name='ブラックロックＬｉｆｅＰａｔｈファンド２０２５',
        fund_name_yomi='ブラックロックライフパスファンドニイゼロニイゴ',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13410': FundCodeEntry(
        fund_code='G13410',
        sec_code=None,
        fund_name='楽天・ビッグデータ日本株ファンド',
        fund_name_yomi='ラクテンビッグデータニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13411': FundCodeEntry(
        fund_code='G13411',
        sec_code=None,
        fund_name='世界セレクティブ株式オープン',
        fund_name_yomi='セカイセレクティブカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13412': FundCodeEntry(
        fund_code='G13412',
        sec_code=None,
        fund_name='デンマークカバード債券プラス（為替ヘッジあり）２０１９－０５（限定追加型）',
        fund_name_yomi='デンマークカバードサイケンプラスカワセヘッジアリニセンジュウクノゼロゴゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13413': FundCodeEntry(
        fund_code='G13413',
        sec_code=None,
        fund_name='Ｏｎｅ日本の成長力α＜ＤＣ年金＞',
        fund_name_yomi='ワンニホンノセイチョウリョクアルファディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月3日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13414': FundCodeEntry(
        fund_code='G13414',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000先進国株式インデックスファンド',
        fund_name_yomi='ワンディーシーセンシンコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13415': FundCodeEntry(
        fund_code='G13415',
        sec_code='25290',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000野村株主還元７０連動型上場投信',
        fund_name_yomi='ネクストファンズノムラカブヌシカンゲンナナジュウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13416': FundCodeEntry(
        fund_code='G13416',
        sec_code=None,
        fund_name='スーパー\u3000ボンド\u3000ベア\u3000オープン４',
        fund_name_yomi='スーパーボンドベアオープンフォー',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13417': FundCodeEntry(
        fund_code='G13417',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０１９－０６',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロイチキュー\u3000ゼロロク',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13418': FundCodeEntry(
        fund_code='G13418',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０３５、りそなターゲット・イヤー・ファンド２０４５、りそなターゲット・イヤー・ファンド２０５５',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロサンゴー\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロヨンゴー\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロゴーゴー',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13419': FundCodeEntry(
        fund_code='G13419',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０６０',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロロクゼロ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13421': FundCodeEntry(
        fund_code='G13421',
        sec_code=None,
        fund_name='ニッセイ日本株ＥＳＧフォーカスファンド（年２回決算型）',
        fund_name_yomi='ニッセイニホンカブイーエスジーフォーカスファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13422': FundCodeEntry(
        fund_code='G13422',
        sec_code=None,
        fund_name='ニッセイ日本株ＥＳＧフォーカスファンド（資産成長型）',
        fund_name_yomi='ニッセイニホンカブイーエスジーフォーカスファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13423': FundCodeEntry(
        fund_code='G13423',
        sec_code=None,
        fund_name='しんきんフコクＥＳＧ日本株式ファンド',
        fund_name_yomi='シンキンフコクイーエスジーニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G13424': FundCodeEntry(
        fund_code='G13424',
        sec_code=None,
        fund_name='ゲーム＆ｅスポーツ・オープン',
        fund_name_yomi='ゲームアンドイースポーツオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13425': FundCodeEntry(
        fund_code='G13425',
        sec_code=None,
        fund_name='エドテック・オープン',
        fund_name_yomi='エドテックオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13426': FundCodeEntry(
        fund_code='G13426',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000世界厳選成長株式ファンド\u3000＜資産成長型＞（Ａコース・為替ヘッジあり）（Ｂコース・為替ヘッジなし）、＜分配重視型＞（Ｃコース・為替ヘッジあり）（Ｄコース・為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000セカイゲンセンセイチョウカブシキファンド\u3000シサンセイチョウガタ\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ\u3000ブンパイジュウシガタ\u3000シーコース\u3000カワセヘッジアリ\u3000ディーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2='3月15日',
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G13427': FundCodeEntry(
        fund_code='G13427',
        sec_code=None,
        fund_name='マルチ・ストラテジーズ・トラスト－ヌビーン・ダイナミックＵＳエクイティ・ストラテジー',
        fund_name_yomi='マルチストラテジーズトラストヌビーンダイナミックユーエスエクイティストラテジー',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15174',
        issuer_name='ルクセンブルク三菱ＵＦＪインベスターサービス銀行Ｓ．Ａ．',
    ),
    'G13428': FundCodeEntry(
        fund_code='G13428',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０５',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13430': FundCodeEntry(
        fund_code='G13430',
        sec_code=None,
        fund_name='東京海上・ジャパン・マイスター株式オープン',
        fund_name_yomi='トウキョウカイジョウジャパンマイスターカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13431': FundCodeEntry(
        fund_code='G13431',
        sec_code=None,
        fund_name='ＳＢＩグローバル株式債券バランス・ファンド（為替ヘッジあり）、ＳＢＩグローバル株式債券バランス・ファンド（為替ヘッジなし）',
        fund_name_yomi='エスビーアイグローバルカブシキサイケンバランスファンド\u3000カワセヘッジアリ\u3000エスビーアイグローバルカブシキサイケンバランスファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13432': FundCodeEntry(
        fund_code='G13432',
        sec_code=None,
        fund_name='ＨＳＢＣ中国人民元債券オープン（毎月決算型）／（年２回決算型）',
        fund_name_yomi='エイチエスビーシーチュウゴクジンミンゲンサイケンオープンマイツキケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13433': FundCodeEntry(
        fund_code='G13433',
        sec_code=None,
        fund_name='ＳＭＢＣ・アムンディ\u3000クライメート・アクション',
        fund_name_yomi='エスエムビーシーアムンディクライメートアクション',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13434': FundCodeEntry(
        fund_code='G13434',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳコア債券ファンド（為替ヘッジなし、年１回決算型）',
        fund_name_yomi='ジェイピーエムユーエスコアサイケンファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13435': FundCodeEntry(
        fund_code='G13435',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳコア債券ファンド（為替ヘッジなし、隔月決算型）',
        fund_name_yomi='ジェイピーエムユーエスコアサイケンファンドカワセヘッジナシカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13436': FundCodeEntry(
        fund_code='G13436',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳコア債券ファンド（為替ヘッジあり、年１回決算型）',
        fund_name_yomi='ジェイピーエムユーエスコアサイケンファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13437': FundCodeEntry(
        fund_code='G13437',
        sec_code=None,
        fund_name='ＪＰＭ\u3000ＵＳコア債券ファンド（為替ヘッジあり、隔月決算型）',
        fund_name_yomi='ジェイピーエムユーエスコアサイケンファンドカワセヘッジアリカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13439': FundCodeEntry(
        fund_code='G13439',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔインカム株式（為替ヘッジなし）',
        fund_name_yomi='アイトラストインカムカブシキカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13440': FundCodeEntry(
        fund_code='G13440',
        sec_code=None,
        fund_name='にいがた未来応援日本株ファンド',
        fund_name_yomi='ニイガタミライオウエンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13441': FundCodeEntry(
        fund_code='G13441',
        sec_code=None,
        fund_name='世界ＳＤＧｓハイインカム・ファンド（為替ヘッジあり毎月分配型）\u3000世界ＳＤＧｓハイインカム・ファンド（為替ヘッジなし毎月分配型）\u3000世界ＳＤＧｓハイインカム・ファンド（為替ヘッジあり資産成長型）\u3000世界ＳＤＧｓハイインカム・ファンド（為替ヘッジなし資産成長型）',
        fund_name_yomi='セカイエスディージーズハイインカムファンドカワセヘッジアリマイツキブンパイガタ\u3000セカイエスディージーズハイインカムファンドカワセヘッジナシマイツキブンパイガタ\u3000セカイエスディージーズハイインカムファンドカワセヘッジアリシサンセイチョウガタ\u3000セカイエスディージーズハイインカムファンドカワセヘッジナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13442': FundCodeEntry(
        fund_code='G13442',
        sec_code=None,
        fund_name='４資産分散投資・ミドルクラス＜ＤＣ年金＞',
        fund_name_yomi='ヨンシサンブンサントウシミドルクラスディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13443': FundCodeEntry(
        fund_code='G13443',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＮＹダウ・インデックス・ファンド',
        fund_name_yomi='ワンニューヨークダウインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13444': FundCodeEntry(
        fund_code='G13444',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000フィンテック',
        fund_name_yomi='イーマクシスネオフィンテック',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13445': FundCodeEntry(
        fund_code='G13445',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000自動運転',
        fund_name_yomi='イーマクシスネオジドウウンテン',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13446': FundCodeEntry(
        fund_code='G13446',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000ウェアラブル',
        fund_name_yomi='イーマクシスネオウェアラブル',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13447': FundCodeEntry(
        fund_code='G13447',
        sec_code=None,
        fund_name='アジア成長投資戦略ファンド',
        fund_name_yomi='アジアセイチョウトウシセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13448': FundCodeEntry(
        fund_code='G13448',
        sec_code='25520',
        fund_name='上場インデックスファンドＪリート（東証ＲＥＩＴ指数）隔月分配型（ミニ）',
        fund_name_yomi='ジョウジョウインデックスファンドジェイリート\u3000トウショウリートシスウ\u3000カクゲツブンパイガタ\u3000ミニ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13450': FundCodeEntry(
        fund_code='G13450',
        sec_code=None,
        fund_name='じゅうろく\u3000地元応援ファンド',
        fund_name_yomi='ジュウロク\u3000ジモトオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='7月29日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13451': FundCodeEntry(
        fund_code='G13451',
        sec_code=None,
        fund_name='ＧＳグローバル・ビッグデータ投資戦略\u3000隔月決算コース（為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000ビッグデータ\u3000トウシセンリャク\u3000カクゲツケッサンコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G13452': FundCodeEntry(
        fund_code='G13452',
        sec_code=None,
        fund_name='Ｏｎｅグローバル中小型長期成長株ファンド＜ＤＣ年金＞',
        fund_name_yomi='ワングローバルチュウコガタチョウキセイチョウカブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13453': FundCodeEntry(
        fund_code='G13453',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０６',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロロク',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13455': FundCodeEntry(
        fund_code='G13455',
        sec_code=None,
        fund_name='グローバル・プロスペクティブ・ファンド',
        fund_name_yomi='グローバル\u3000プロスペクティブ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13457': FundCodeEntry(
        fund_code='G13457',
        sec_code='25300',
        fund_name='ＭＡＸＩＳ\u3000ＨｕａＡｎ中国株式（上海１８０Ａ株）上場投信',
        fund_name_yomi='マクシスファーアンチュウゴクカブシキシャンハイヒャクハチジュウエーカブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13458': FundCodeEntry(
        fund_code='G13458',
        sec_code='25530',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000南方\u3000中国Ａ株\u3000ＣＳＩ５００',
        fund_name_yomi='ワン\u3000イーティーエフ\u3000ナンポウ\u3000チュウゴクエーカブ\u3000シーエスアイゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13459': FundCodeEntry(
        fund_code='G13459',
        sec_code=None,
        fund_name='ブラックロック・ヘルスサイエンス・ＤＣファンド',
        fund_name_yomi='ブラックロックヘルスサイエンスディーシーファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13460': FundCodeEntry(
        fund_code='G13460',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000上場プライベート・エクイティ・インデックス・ファンド',
        fund_name_yomi='アイシェアーズジョウジョウプライベートエクイティインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13461': FundCodeEntry(
        fund_code='G13461',
        sec_code=None,
        fund_name='世界ツーリズム株式ファンド',
        fund_name_yomi='セカイツーリズムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G13462': FundCodeEntry(
        fund_code='G13462',
        sec_code=None,
        fund_name='住友生命第１回劣後ローン流動化株式会社',
        fund_name_yomi='スミトモセイメイダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E34991',
        issuer_name='住友生命第１回劣後ローン流動化株式会社',
    ),
    'G13464': FundCodeEntry(
        fund_code='G13464',
        sec_code=None,
        fund_name='ダイワつみたてインデックスバランス５０',
        fund_name_yomi='ダイワツミタテインデックスバランスゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13465': FundCodeEntry(
        fund_code='G13465',
        sec_code=None,
        fund_name='ダイワつみたてインデックスバランス３０',
        fund_name_yomi='ダイワツミタテインデックスバランスサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13466': FundCodeEntry(
        fund_code='G13466',
        sec_code=None,
        fund_name='ダイワつみたてインデックスバランス７０',
        fund_name_yomi='ダイワツミタテインデックスバランスナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13467': FundCodeEntry(
        fund_code='G13467',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＰＩＭＣＯ\u3000短期インカム戦略ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーピムコ\u3000タンキインカムセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13468': FundCodeEntry(
        fund_code='G13468',
        sec_code=None,
        fund_name='ベイリー・ギフォード\u3000インパクト投資ファンド',
        fund_name_yomi='ベイリーギフォードインパクトトウシファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13469': FundCodeEntry(
        fund_code='G13469',
        sec_code=None,
        fund_name='ジパング企業債ファンド',
        fund_name_yomi='ジパングキギョウサイファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13471': FundCodeEntry(
        fund_code='G13471',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１９‐０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチキュウノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13472': FundCodeEntry(
        fund_code='G13472',
        sec_code=None,
        fund_name='ニッセイ／シュローダー・グローバルＣＢファンド（年２回決算型・為替ヘッジあり）／ニッセイ／シュローダー・グローバルＣＢファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ニッセイシュローダーグローバルシービーファンドネンニカイケッサンガタカワセヘッジアリ\u3000ニッセイシュローダーグローバルシービーファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13473': FundCodeEntry(
        fund_code='G13473',
        sec_code=None,
        fund_name='ニッセイ／シュローダー・グローバルＣＢファンド（資産成長型・為替ヘッジあり）／ニッセイ／シュローダー・グローバルＣＢファンド（資産成長型・為替ヘッジなし）',
        fund_name_yomi='ニッセイシュローダーグローバルシービーファンドシサンセイチョウガタカワセヘッジアリ\u3000ニッセイシュローダーグローバルシービーファンドシサンセイチョウガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13474': FundCodeEntry(
        fund_code='G13474',
        sec_code=None,
        fund_name='ニッセイ・デンマーク・カバード債券ファンド２０１９－０７（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイデンマークカバードサイケンファンドニゼロイチキュウノゼロナナカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13475': FundCodeEntry(
        fund_code='G13475',
        sec_code='25540',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ米国投資適格社債（１－１０年）インデックス（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグベイコクトウシテキカクシャサイイチジュウネンインデックスカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13476': FundCodeEntry(
        fund_code='G13476',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０７',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13477': FundCodeEntry(
        fund_code='G13477',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000先進国リートインデックスファンド',
        fund_name_yomi='ワンディーシーセンシンコクリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13478': FundCodeEntry(
        fund_code='G13478',
        sec_code=None,
        fund_name='三井住友ＤＳ・国内株式インデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスコクナイカブシキインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13479': FundCodeEntry(
        fund_code='G13479',
        sec_code=None,
        fund_name='三井住友ＤＳ・国内債券インデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスコクナイサイケンインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13480': FundCodeEntry(
        fund_code='G13480',
        sec_code=None,
        fund_name='三井住友ＤＳ・外国債券インデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスガイコクサイケンインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月17日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13481': FundCodeEntry(
        fund_code='G13481',
        sec_code=None,
        fund_name='三井住友ＤＳ・外国株式インデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスガイコクカブシキインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13482': FundCodeEntry(
        fund_code='G13482',
        sec_code=None,
        fund_name='三井住友ＤＳ・年金バランス３０（債券重点型）、三井住友ＤＳ・年金バランス５０（標準型）、三井住友ＤＳ・年金バランス７０（株式重点型）',
        fund_name_yomi='ミツイスミトモディーエスネンキンバランスサンジュウサイケンジュウテンガタ\u3000ミツイスミトモディーエスネンキンバランスゴジュウヒョウジュンガタ\u3000ミツイスミトモディーエスネンキンバランスナナジュウカブシキジュウテンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13483': FundCodeEntry(
        fund_code='G13483',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000先進国債券インデックスファンド',
        fund_name_yomi='ワンディーシーセンシンコクサイケンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13484': FundCodeEntry(
        fund_code='G13484',
        sec_code=None,
        fund_name='債券スマートインカム戦略＜リスク抑制型＞（ファンドラップ）',
        fund_name_yomi='サイケンスマートインカムセンリャクリスクヨクセイガタファンドラップ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13485': FundCodeEntry(
        fund_code='G13485',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000新興国株式インデックスファンド',
        fund_name_yomi='ワンディーシーシンコウコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13486': FundCodeEntry(
        fund_code='G13486',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－０７',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13487': FundCodeEntry(
        fund_code='G13487',
        sec_code=None,
        fund_name='コモディティＬＳアルファ・ファンド（ＳＭＡ専用）',
        fund_name_yomi='コモディティエルエスアルファ\u3000ファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13489': FundCodeEntry(
        fund_code='G13489',
        sec_code=None,
        fund_name='イスラエル株式ファンド',
        fund_name_yomi='イスラエルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13490': FundCodeEntry(
        fund_code='G13490',
        sec_code=None,
        fund_name='ＧＢＣＡファンド（ＳＭＡ専用）',
        fund_name_yomi='ジービーシーエーファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13491': FundCodeEntry(
        fund_code='G13491',
        sec_code=None,
        fund_name='ソシエテ・ジェネラル\u3000イタリア国債ユーロ円建リパッケージ債券（為替参照利回り変動型）ファンド２０１９ー０８',
        fund_name_yomi='ソシエテ\u3000ジェネラル\u3000イタリアコクサイユーロエンダテリパッケージサイケン\u3000カワセサンショウリマワリヘンドウガタファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13492': FundCodeEntry(
        fund_code='G13492',
        sec_code=None,
        fund_name='明治安田生命２０１９基金特定目的会社',
        fund_name_yomi='メイジヤスダセイメイニセンジュウキュウキキントクテイモクテキカイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35030',
        issuer_name='明治安田生命２０１９基金特定目的会社',
    ),
    'G13493': FundCodeEntry(
        fund_code='G13493',
        sec_code='25550',
        fund_name='東証ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='トウショウリート\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G13494': FundCodeEntry(
        fund_code='G13494',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000ｅビジネス',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000イービジネス',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13497': FundCodeEntry(
        fund_code='G13497',
        sec_code=None,
        fund_name='インベスコ\u3000世界ブロックチェーン株式ファンド',
        fund_name_yomi='インベスコセカイブロックチェーンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13498': FundCodeEntry(
        fund_code='G13498',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０１９－０９',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロイチキュウ\u3000ゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13499': FundCodeEntry(
        fund_code='G13499',
        sec_code=None,
        fund_name='グローバル株式ファンド',
        fund_name_yomi='グローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G13500': FundCodeEntry(
        fund_code='G13500',
        sec_code=None,
        fund_name='東京海上・がんとたたかう投信',
        fund_name_yomi='トウキョウカイジョウガントタタカウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月4日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13501': FundCodeEntry(
        fund_code='G13501',
        sec_code=None,
        fund_name='日本生命２０１９基金流動化株式会社',
        fund_name_yomi='ニホンセイメイニセンジュウキュウキキンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E35050',
        issuer_name='日本生命２０１９基金流動化株式会社',
    ),
    'G13502': FundCodeEntry(
        fund_code='G13502',
        sec_code=None,
        fund_name='アムンディ・みらい定期便',
        fund_name_yomi='アムンディミライテイキビン',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13503': FundCodeEntry(
        fund_code='G13503',
        sec_code=None,
        fund_name='ＭＦＳ・グローバル株式ファンド',
        fund_name_yomi='エムエフエスグローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月1日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13504': FundCodeEntry(
        fund_code='G13504',
        sec_code=None,
        fund_name='シュローダー日本株ＥＳＧフォーカス・ファンド',
        fund_name_yomi='シュローダーニホンカブイーエスジーフォーカス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G13505': FundCodeEntry(
        fund_code='G13505',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ピムコ\u3000ショート・ターム\u3000ストラテジー',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーピムコショートタームストラテジー',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13506': FundCodeEntry(
        fund_code='G13506',
        sec_code=None,
        fund_name='たわらノーロード\u3000全世界株式',
        fund_name_yomi='タワラノーロード\u3000ゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13508': FundCodeEntry(
        fund_code='G13508',
        sec_code=None,
        fund_name='しんきんＤＣ日経２２５株式ファンド',
        fund_name_yomi='シンキンディーシーニッケイニーニーゴカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G13509': FundCodeEntry(
        fund_code='G13509',
        sec_code=None,
        fund_name='ＰＩＭＣＯ新興国ハイインカム債券ファンド（毎月分配型）',
        fund_name_yomi='ピムコシンコウコクハイインカムサイケンファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13510': FundCodeEntry(
        fund_code='G13510',
        sec_code=None,
        fund_name='ＰＩＭＣＯ新興国ハイインカム債券ファンド（１年決算型）',
        fund_name_yomi='ピムコシンコウコクハイインカムサイケンファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13511': FundCodeEntry(
        fund_code='G13511',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－０８',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13512': FundCodeEntry(
        fund_code='G13512',
        sec_code=None,
        fund_name='デンマーク・カバード債券・インカムファンド２０１９－０９（為替ヘッジあり）',
        fund_name_yomi='デンマークカバードサイケンインカムファンド\u3000ニゼロイチキュウゼロキュウ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G13513': FundCodeEntry(
        fund_code='G13513',
        sec_code='25560',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000東証ＲＥＩＴ指数',
        fund_name_yomi='ワンイーティーエフトウショウリートシスウ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13514': FundCodeEntry(
        fund_code='G13514',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信ウルトラバランス\u3000世界株式',
        fund_name_yomi='ペイペイトウシンウルトラバランスセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G13517': FundCodeEntry(
        fund_code='G13517',
        sec_code=None,
        fund_name='りそな\u3000つみたてグローバル株式アクティブファンド',
        fund_name_yomi='リソナ\u3000ツミタテグローバルカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13518': FundCodeEntry(
        fund_code='G13518',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金バランス（株式２５）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンバランスカブシキニジューゴ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13519': FundCodeEntry(
        fund_code='G13519',
        sec_code=None,
        fund_name='グローバルＥＴＦ・インカム・バランスファンド（年２回決算型）',
        fund_name_yomi='グローバルイーティーエフ\u3000インカム\u3000バランスファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13520': FundCodeEntry(
        fund_code='G13520',
        sec_code=None,
        fund_name='グローバルＥＴＦ・インカム・バランスファンド（年１回決算型）',
        fund_name_yomi='グローバルイーティーエフ\u3000インカム\u3000バランスファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13521': FundCodeEntry(
        fund_code='G13521',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－０９',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13522': FundCodeEntry(
        fund_code='G13522',
        sec_code=None,
        fund_name='オルトゥ・クールバ・トラスト－償還時目標設定型ファンド１９０９米ドル建て／償還時目標設定型ファンド１９０９豪ドル建て',
        fund_name_yomi='オルトゥクールバトラストショウカンジモクヒョウセッテイガタファンドイチキュウゼロキュウベイドルダテショウカンジモクヒョウセッテイガタファンドイチキュウゼロキュウゴウドルダテ',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15033',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G13523': FundCodeEntry(
        fund_code='G13523',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・Ｓ＆Ｐ５００インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000エスアンドピーゴヒャク\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月14日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13524': FundCodeEntry(
        fund_code='G13524',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－０９',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13525': FundCodeEntry(
        fund_code='G13525',
        sec_code=None,
        fund_name='グローバル医薬品株式ファンド',
        fund_name_yomi='グローバルイヤクヒンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G13526': FundCodeEntry(
        fund_code='G13526',
        sec_code=None,
        fund_name='ＮＷＱグローバル厳選証券（米国株プラス）毎月分配型',
        fund_name_yomi='エヌダブリューキューグローバルゲンセンショウケンベイコクカブプラスマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13529': FundCodeEntry(
        fund_code='G13529',
        sec_code=None,
        fund_name='優良好配当・日本株式ファンド',
        fund_name_yomi='ユウリョウコウハイトウニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13530': FundCodeEntry(
        fund_code='G13530',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０１９‐１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロイチキュウノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13531': FundCodeEntry(
        fund_code='G13531',
        sec_code=None,
        fund_name='ＵＳリート・プラス（為替ヘッジなし／毎月分配型）',
        fund_name_yomi='ユーエスリートプラスカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13532': FundCodeEntry(
        fund_code='G13532',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０１９－１０',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロイチキュウ\u3000ジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13533': FundCodeEntry(
        fund_code='G13533',
        sec_code=None,
        fund_name='東京海上ターゲット・イヤー・ファンド２０３５／２０４５／２０５５／２０６５',
        fund_name_yomi='トウキョウカイジョウターゲットイヤーファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13534': FundCodeEntry(
        fund_code='G13534',
        sec_code=None,
        fund_name='ひふみワールド',
        fund_name_yomi='ヒフミワールド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G13535': FundCodeEntry(
        fund_code='G13535',
        sec_code=None,
        fund_name='ピクテ・ゴールド（為替ヘッジなし）',
        fund_name_yomi='ピクテゴールドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13536': FundCodeEntry(
        fund_code='G13536',
        sec_code=None,
        fund_name='野村資産設計ファンド（ＤＣ・つみたてＮＩＳＡ）２０６０',
        fund_name_yomi='ノムラシサンセッケイファンドディーシーツミタテニーサニセンロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13539': FundCodeEntry(
        fund_code='G13539',
        sec_code=None,
        fund_name='東京海上・スタイルアルファ・グローバルマクロファンド',
        fund_name_yomi='トウキョウカイジョウスタイルアルファグローバルマクロファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13541': FundCodeEntry(
        fund_code='G13541',
        sec_code=None,
        fund_name='東京海上・スタイルアルファ・グローバル債券ファンド',
        fund_name_yomi='トウキョウカイジョウスタイルアルファグローバルサイケンファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13542': FundCodeEntry(
        fund_code='G13542',
        sec_code=None,
        fund_name='しんきんグローバル６資産ファンド（１年決算型）',
        fund_name_yomi='シンキングローバルロクシサンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G13543': FundCodeEntry(
        fund_code='G13543',
        sec_code=None,
        fund_name='しんきん３資産ファンド（１年決算型）',
        fund_name_yomi='シンキンサンシサンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G13544': FundCodeEntry(
        fund_code='G13544',
        sec_code=None,
        fund_name='アムンディ・次世代教育関連ファンド',
        fund_name_yomi='アムンディジセダイキョウイクカンレンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13545': FundCodeEntry(
        fund_code='G13545',
        sec_code=None,
        fund_name='八十二\u3000信州応援日本株ファンド',
        fund_name_yomi='ハチジュウニ\u3000シンシュウオウエンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13546': FundCodeEntry(
        fund_code='G13546',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－１０',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13547': FundCodeEntry(
        fund_code='G13547',
        sec_code=None,
        fund_name='野村ターゲットインカムファンド（資産成長型）、野村ターゲットインカムファンド（年６％目標払出型）',
        fund_name_yomi='ノムラターゲットインカムファンドシサンセイチョウガタ\u3000ノムラターゲットインカムファンドネンロクパーセントモクヒョウハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13549': FundCodeEntry(
        fund_code='G13549',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－１０',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13550': FundCodeEntry(
        fund_code='G13550',
        sec_code=None,
        fund_name='リスク抑制型・４資産バランスファンド',
        fund_name_yomi='リスクヨクセイガタヨンシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13551': FundCodeEntry(
        fund_code='G13551',
        sec_code=None,
        fund_name='ノムラ日本株ベータヘッジ戦略ファンド（ＳＭＡ専用）',
        fund_name_yomi='ノムラニホンカブベータヘッジセンリャクファンドエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13552': FundCodeEntry(
        fund_code='G13552',
        sec_code=None,
        fund_name='スパークス・ベスト・ピック・ファンドⅡ（日本・アジア）マーケットヘッジあり\u3000スパークス・ベスト・ピック・ファンドⅡ（日本・アジア）マーケットヘッジなし',
        fund_name_yomi='スパークスベストピックファンドツー\u3000ニホンアジア\u3000マーケットヘッジアリ\u3000スパークスベストピックファンドツー\u3000ニホンアジア\u3000マーケットヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G13553': FundCodeEntry(
        fund_code='G13553',
        sec_code=None,
        fund_name='日本債券ツイン戦略ファンド（ＳＭＡ専用）',
        fund_name_yomi='ニホンサイケンツインセンリャクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13554': FundCodeEntry(
        fund_code='G13554',
        sec_code=None,
        fund_name='ＵＢＳ合併裁定戦略ファンド（ＳＭＡ専用）',
        fund_name_yomi='ユービーエスガッペイサイテイセンリャクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13556': FundCodeEntry(
        fund_code='G13556',
        sec_code=None,
        fund_name='グローバルＡＩファンド（予想分配金提示型）／グローバルＡＩファンド（為替ヘッジあり予想分配金提示型）',
        fund_name_yomi='グローバルエーアイファンドヨソウブンパイキンテイジガタ\u3000グローバルエーアイファンドカワセヘッジアリヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13558': FundCodeEntry(
        fund_code='G13558',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000エコ',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000エコ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13559': FundCodeEntry(
        fund_code='G13559',
        sec_code=None,
        fund_name='バラック・ファンドＳＰＣリミテッド－バラック・ストラクチャード・トレード・ファイナンス・セグリゲーテッド・ポートフォリオ',
        fund_name_yomi='バラックファンドエスピーシーリミテッドバラックストラクチャードトレードファイナンスセグリゲーテッドポートフォリオ',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35219',
        issuer_name='バラック・ファンドＳＰＣリミテッド',
    ),
    'G13560': FundCodeEntry(
        fund_code='G13560',
        sec_code=None,
        fund_name='日本厳選高配当株ファンド２０１９－１０（繰上償還条件付）',
        fund_name_yomi='ニホンゲンセンコウハイトウカブファンドニセンジュウキュウノジュウ\u3000クリアゲショウカンジョウケンツキ',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13562': FundCodeEntry(
        fund_code='G13562',
        sec_code=None,
        fund_name='ビッグデータ新興国小型株ファンド（１年決算型）',
        fund_name_yomi='ビッグデータシンコウコクコガタカブファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13563': FundCodeEntry(
        fund_code='G13563',
        sec_code=None,
        fund_name='ボンド・ゼロトリプル（予想分配金提示型）',
        fund_name_yomi='ボンドゼロトリプルヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13564': FundCodeEntry(
        fund_code='G13564',
        sec_code=None,
        fund_name='ボンド・ゼロトリプル（資産成長型）',
        fund_name_yomi='ボンドゼロトリプルシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13565': FundCodeEntry(
        fund_code='G13565',
        sec_code=None,
        fund_name='テトラ・エクイティ',
        fund_name_yomi='テトラエクイティ',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13566': FundCodeEntry(
        fund_code='G13566',
        sec_code=None,
        fund_name='米国３倍４資産リスク分散ファンド（隔月決算型）／（年２回決算型）',
        fund_name_yomi='ベイコクサンバイヨンシサンリスクブンサンファンドカクゲツケッサンガタネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13567': FundCodeEntry(
        fund_code='G13567',
        sec_code=None,
        fund_name='米国３倍４資産リスク分散ファンド（毎月決算型）',
        fund_name_yomi='ベイコクサンバイヨンシサンリスクブンサンファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13568': FundCodeEntry(
        fund_code='G13568',
        sec_code=None,
        fund_name='楽天・米国レバレッジバランス・ファンド',
        fund_name_yomi='ラクテン\u3000ベイコクレバレッジバランス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13569': FundCodeEntry(
        fund_code='G13569',
        sec_code=None,
        fund_name='マニュライフ・円ハイブリッド債券インカム・ファンド（３ヵ月決算型）',
        fund_name_yomi='マニュライフエンハイブリッドサイケンインカムファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13570': FundCodeEntry(
        fund_code='G13570',
        sec_code=None,
        fund_name='マニュライフ・円ハイブリッド債券インカム・ファンド（年１回決算型）',
        fund_name_yomi='マニュライフエンハイブリッドサイケンインカムファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13573': FundCodeEntry(
        fund_code='G13573',
        sec_code=None,
        fund_name='第９２回２０２４年９月満期株価指数参照円建信託社債（デジタルクーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイキュウジュウニカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13574': FundCodeEntry(
        fund_code='G13574',
        sec_code=None,
        fund_name='第９３回２０２２年１２月満期株価指数参照円建信託社債（固定クーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイキュウジュウサンカイニセンニジュウニネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13575': FundCodeEntry(
        fund_code='G13575',
        sec_code=None,
        fund_name='ブラックロックおまかせバランス投信',
        fund_name_yomi='ブラックロックオマカセバランストウシン',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13576': FundCodeEntry(
        fund_code='G13576',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000国内株式ＥＳＧインデックス',
        fund_name_yomi='スマート\u3000アイ\u3000コクナイカブシキイーエスジーインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13577': FundCodeEntry(
        fund_code='G13577',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000先進国株式ＥＳＧインデックス',
        fund_name_yomi='スマート\u3000アイ\u3000センシンコクカブシキイーエスジーインデックス',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13578': FundCodeEntry(
        fund_code='G13578',
        sec_code=None,
        fund_name='マニュライフ\u3000日本債券ストラテジックファンド（ＳＭＡ専用）',
        fund_name_yomi='マニュライフニホンサイケンストラテジックファンドエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13579': FundCodeEntry(
        fund_code='G13579',
        sec_code=None,
        fund_name='ＹＭＦＧ\u3000未来共創ファンド',
        fund_name_yomi='ワイエムエフジー\u3000ミライキョウソウファンド',
        security_type='内国投資信託受益証券',
        period_1='10月23日',
        period_2='4月23日',
        edinet_code='E32437',
        issuer_name='ワイエムアセットマネジメント株式会社',
    ),
    'G13580': FundCodeEntry(
        fund_code='G13580',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０１９－１２',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロイチキュウ\u3000ジュウニ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13581': FundCodeEntry(
        fund_code='G13581',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・アメリカ高配当株ファンド（毎月分配型／３ヵ月決算型／年２回決算型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000アメリカコウハイトウカブファンド\u3000マイツキブンパイガタ\u3000サンカゲツケッサンガタ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G13583': FundCodeEntry(
        fund_code='G13583',
        sec_code=None,
        fund_name='米国ＩＰＯニューステージ・ファンド＜為替ヘッジあり＞＜為替ヘッジなし＞（年２回決算型）',
        fund_name_yomi='ベイコクアイピーオーニューステージファンドカワセヘッジアリカワセヘッジナシネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13584': FundCodeEntry(
        fund_code='G13584',
        sec_code=None,
        fund_name='米国ＩＰＯニューステージ・ファンド＜為替ヘッジあり＞＜為替ヘッジなし＞（資産成長型）',
        fund_name_yomi='ベイコクアイピーオーニューステージファンドカワセヘッジアリカワセヘッジナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13585': FundCodeEntry(
        fund_code='G13585',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－１１',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウイチイチ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13586': FundCodeEntry(
        fund_code='G13586',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000先進国リートインデックス（除く日本）',
        fund_name_yomi='イーマクシススリムセンシンコクリートインデックスノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13587': FundCodeEntry(
        fund_code='G13587',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000国内リートインデックス',
        fund_name_yomi='イーマクシススリムコクナイリートインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13588': FundCodeEntry(
        fund_code='G13588',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－１１',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウイチイチ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13589': FundCodeEntry(
        fund_code='G13589',
        sec_code=None,
        fund_name='ノムラ・ケイマン・トラスト－ＰＩＭＣＯインカム・ストラテジー・ファンド（米ドル）／ＰＩＭＣＯインカム・ストラテジー・ファンド（豪ドル）',
        fund_name_yomi='ノムラケイマントラストピムコインカムストラテジーファンドベイドルピムコインカムストラテジーファンドゴウドル',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G13590': FundCodeEntry(
        fund_code='G13590',
        sec_code=None,
        fund_name='グローバル・リート・インデックスファンド（毎月決算型／資産形成型）',
        fund_name_yomi='グローバルリートインデックスファンドマイツキケッサンガタシサンケイセイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13591': FundCodeEntry(
        fund_code='G13591',
        sec_code=None,
        fund_name='マンＡＨＬスマート・レバレッジ戦略ファンド',
        fund_name_yomi='マンエーエイチエルスマートレバレッジセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13592': FundCodeEntry(
        fund_code='G13592',
        sec_code=None,
        fund_name='日本生命第４回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイヨンカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E35282',
        issuer_name='日本生命第４回劣後ローン流動化株式会社',
    ),
    'G13593': FundCodeEntry(
        fund_code='G13593',
        sec_code=None,
        fund_name='米国分散投資戦略ファンド（１倍コース）\u3000米国分散投資戦略ファンド（３倍コース）\u3000米国分散投資戦略ファンド（５倍コース）',
        fund_name_yomi='ベイコクブンサントウシセンリャクファンドイチバイコース\u3000ベイコクブンサントウシセンリャクファンドサンバイコース\u3000ベイコクブンサントウシセンリャクファンドゴバイコース',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13594': FundCodeEntry(
        fund_code='G13594',
        sec_code='29790',
        fund_name='ＳＯＳｉＬＡ物流リート投資法人',
        fund_name_yomi='ソシラブツリュウリートトウシホウジン',
        security_type='内国投資証券',
        period_1='11月末日',
        period_2='5月末日',
        edinet_code='E35254',
        issuer_name='ＳＯＳｉＬＡ物流リート投資法人',
    ),
    'G13595': FundCodeEntry(
        fund_code='G13595',
        sec_code=None,
        fund_name='グローバル超好配当株式ファンド（隔月決算型／資産成長型）',
        fund_name_yomi='グローバルチョウコウハイトウカブシキファンドカクゲツケッサンガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13596': FundCodeEntry(
        fund_code='G13596',
        sec_code=None,
        fund_name='ワールド・アクティブ・ボンド・オープン（為替ヘッジあり）',
        fund_name_yomi='ワールドアクティブボンドオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13597': FundCodeEntry(
        fund_code='G13597',
        sec_code=None,
        fund_name='米国４資産リスク分散ファンド（年２回決算型）',
        fund_name_yomi='ベイコクヨンシサンリスクブンサンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13598': FundCodeEntry(
        fund_code='G13598',
        sec_code=None,
        fund_name='のむラップ・ファンド（普通型）年３％目標分配金受取型、のむラップ・ファンド（普通型）年６％目標分配金受取型',
        fund_name_yomi='ノムラップファンドフツウガタネンサンパーセントモクヒョウブンパイキンウケトリガタ\u3000ノムラップファンドフツウガタネンロクパーセントモクヒョウブンパイキンウケトリガタ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13599': FundCodeEntry(
        fund_code='G13599',
        sec_code=None,
        fund_name='Ｏｎｅ国際分散投資戦略ファンド（目標リスク８％）',
        fund_name_yomi='ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクハチパーセント',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13600': FundCodeEntry(
        fund_code='G13600',
        sec_code=None,
        fund_name='Ｏｎｅ国際分散投資戦略ファンド（目標リスク６％）',
        fund_name_yomi='ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクロクパーセント',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13601': FundCodeEntry(
        fund_code='G13601',
        sec_code=None,
        fund_name='Ｏｎｅ国際分散投資戦略ファンド（目標リスク４％）',
        fund_name_yomi='ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクヨンパーセント',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13602': FundCodeEntry(
        fund_code='G13602',
        sec_code=None,
        fund_name='Ｏｎｅ国際分散投資戦略ファンド（目標リスク２％）',
        fund_name_yomi='ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクニパーセント',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13603': FundCodeEntry(
        fund_code='G13603',
        sec_code=None,
        fund_name='Ｏｎｅ高配当利回り厳選ジャパン',
        fund_name_yomi='ワンコウハイトウリマワリゲンセンジャパン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13604': FundCodeEntry(
        fund_code='G13604',
        sec_code=None,
        fund_name='ＳＢＩ米国小型成長株ファンド',
        fund_name_yomi='エスビーアイベイコクコガタセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13605': FundCodeEntry(
        fund_code='G13605',
        sec_code=None,
        fund_name='米国小型株グロース・ファンド',
        fund_name_yomi='ベイコクコガタカブグロースファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13608': FundCodeEntry(
        fund_code='G13608',
        sec_code=None,
        fund_name='第９６回２０２４年９月満期株価指数参照円建信託社債（デジタルクーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイキュウジュウロクカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13609': FundCodeEntry(
        fund_code='G13609',
        sec_code=None,
        fund_name='第９７回２０２２年１２月満期株価指数参照円建信託社債（固定クーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイキュウジュウナナカイニセンニジュウニネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13610': FundCodeEntry(
        fund_code='G13610',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信ウルトラバランス\u3000高利回り債券（年２回決算型／隔月決算型）',
        fund_name_yomi='ペイペイトウシンウルトラバランス\u3000コウリマワリサイケン\u3000ネンニカイケッサンガタ\u3000カクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G13611': FundCodeEntry(
        fund_code='G13611',
        sec_code=None,
        fund_name='ＵＢＳ中国ハイイールド債券ファンド（毎月決算型・為替ヘッジあり）、ＵＢＳ中国ハイイールド債券ファンド（毎月決算型・為替ヘッジなし）、ＵＢＳ中国ハイイールド債券ファンド（年２回決算型・為替ヘッジあり）、ＵＢＳ中国ハイイールド債券ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='ユービーエスチュウゴクハイイールドサイケンファンド\u3000マイツキケッサンガタ\u3000カワセヘッジアリ\u3000ユービーエスチュウゴクハイイールドサイケンファンド\u3000マイツキケッサンガタ\u3000カワセヘッジナシ\u3000ユービーエスチュウゴクハイイールドサイケンファンド\u3000ネンニカイケッサンガタ\u3000カワセヘッジアリ\u3000ユービーエスチュウゴクハイイールドサイケンファンド\u3000ネンニカイケッサンガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13612': FundCodeEntry(
        fund_code='G13612',
        sec_code=None,
        fund_name='マニュライフ・アジア好利回り債券戦略ファンド（３年投資型）２０１９‐１２\u3000為替ヘッジありコース、マニュライフ・アジア好利回り債券戦略ファンド（３年投資型）２０１９‐１２\u3000為替ヘッジなしコース',
        fund_name_yomi='マニュライフアジアコウリマワリサイケンセンリャクファンドサンネントウシガタカワセヘッジアリコース\u3000マニュライフアジアコウリマワリサイケンセンリャクファンドサンネントウシガタカワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13613': FundCodeEntry(
        fund_code='G13613',
        sec_code=None,
        fund_name='米国株式シグナルチェンジ戦略ファンド（為替ヘッジあり）（為替ヘッジなし）',
        fund_name_yomi='ベイコクカブシキシグナルチェンジセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13616': FundCodeEntry(
        fund_code='G13616',
        sec_code=None,
        fund_name='バリューハント日本株',
        fund_name_yomi='バリューハントニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13617': FundCodeEntry(
        fund_code='G13617',
        sec_code=None,
        fund_name='フューチャートレンド世界株',
        fund_name_yomi='フューチャートレンドセカイカブ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13618': FundCodeEntry(
        fund_code='G13618',
        sec_code=None,
        fund_name='ニッセイ・デンマーク・カバード債券ファンド２０１９－１２（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイデンマークカバードサイケンファンドニゼロイチキュウノイチニカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13619': FundCodeEntry(
        fund_code='G13619',
        sec_code=None,
        fund_name='ジャパン・アクティブ・ボンド・オープン',
        fund_name_yomi='ジャパンアクティブボンドオープン',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13620': FundCodeEntry(
        fund_code='G13620',
        sec_code=None,
        fund_name='ひふみワールド＋',
        fund_name_yomi='ヒフミワールドプラス',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G13621': FundCodeEntry(
        fund_code='G13621',
        sec_code=None,
        fund_name='第４６回\u3000２０２４年１２月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヨンジュウロクカイニセンニジュウヨネンジュウニガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月30日',
        period_2='12月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13622': FundCodeEntry(
        fund_code='G13622',
        sec_code=None,
        fund_name='グローバル・Ｍ＆Ａオポチュニティ・ファンド',
        fund_name_yomi='グローバルエムアンドエーオポチュニティファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14951',
        issuer_name='ＵＢＳオコーナー・エルエルシー',
    ),
    'G13623': FundCodeEntry(
        fund_code='G13623',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国成長株式ファンド',
        fund_name_yomi='ティーロウプライス\u3000ベイコクセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G13624': FundCodeEntry(
        fund_code='G13624',
        sec_code=None,
        fund_name='お金のデザイン・グローバル・リアルアセット・ファンド（世界の実物資産中心）',
        fund_name_yomi='オカネノデザイン\u3000グローバル\u3000リアルアセット\u3000ファンド\u3000セカイノジツブツシサンチュウシン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G13625': FundCodeEntry(
        fund_code='G13625',
        sec_code=None,
        fund_name='早期償還条項付・新興国債券戦略１９１２',
        fund_name_yomi='ソウキショウカンジョウコウツキ\u3000シンコウコクサイケンセンリャクイチキュウイチニ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13626': FundCodeEntry(
        fund_code='G13626',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０１９－１２',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロイチキュウイチニ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13627': FundCodeEntry(
        fund_code='G13627',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０１９－１２',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロイチキュウイチニ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13628': FundCodeEntry(
        fund_code='G13628',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－フレキシベータファンドＶＴ５／ＶＴ１０',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000フレキシベータファンドブイティーファイブブイティーテン',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G13629': FundCodeEntry(
        fund_code='G13629',
        sec_code=None,
        fund_name='アジア大型株長期厳選投資',
        fund_name_yomi='アジアオオガタカブチョウキゲンセントウシ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13630': FundCodeEntry(
        fund_code='G13630',
        sec_code=None,
        fund_name='デンマーク・カバードボンド戦略ファンド２０１９－１２（為替ヘッジあり／限定追加型）',
        fund_name_yomi='デンマークカバードボンドセンリャクファンドニセンジュウキュウジュウニカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13631': FundCodeEntry(
        fund_code='G13631',
        sec_code=None,
        fund_name='バークレイズ社債／インカム戦略ファンド２０１９－１２',
        fund_name_yomi='バークレイズシャサイ\u3000インカムセンリャクファンドニゼロイチキュウイチニ',
        security_type='内国投資信託受益証券',
        period_1='12月28日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13632': FundCodeEntry(
        fund_code='G13632',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000宇宙',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000ウチュウ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13633': FundCodeEntry(
        fund_code='G13633',
        sec_code=None,
        fund_name='第４７回\u3000２０２５年１月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヨンジュウナナカイニセンニジュウゴネンイチガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13634': FundCodeEntry(
        fund_code='G13634',
        sec_code=None,
        fund_name='第４８回\u3000２０２５年１月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヨンジュウハチカイニセンニジュウゴネンイチガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13635': FundCodeEntry(
        fund_code='G13635',
        sec_code=None,
        fund_name='楽天日本株３．８倍ベア',
        fund_name_yomi='ラクテンニホンカブサンテンハチバイベア',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13637': FundCodeEntry(
        fund_code='G13637',
        sec_code=None,
        fund_name='東京海上・円資産バランスファンド（３倍型）（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウエンシサンバランスファンドサンバイガタマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13638': FundCodeEntry(
        fund_code='G13638',
        sec_code=None,
        fund_name='東京海上・円資産バランスファンド（３倍型）（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウエンシサンバランスファンドサンバイガタネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13639': FundCodeEntry(
        fund_code='G13639',
        sec_code='25570',
        fund_name='ＳＭＤＡＭ\u3000トピックス上場投信',
        fund_name_yomi='エスエムディーエーエム\u3000トピックスジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13640': FundCodeEntry(
        fund_code='G13640',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－米ドル建て\u3000シティグループ社債\u3000最大上昇率参照型（グローバル・マルチアセット戦略）ファンド',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ベイドルダテシティグループシャサイサイダイジョウショウリツサンショウガタグローバルマルチアセットセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G13641': FundCodeEntry(
        fund_code='G13641',
        sec_code=None,
        fund_name='国内債券インデックス・オープン（ラップ向け）',
        fund_name_yomi='コクナイサイケンインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13642': FundCodeEntry(
        fund_code='G13642',
        sec_code=None,
        fund_name='国内リートインデックス・オープン（ラップ向け）',
        fund_name_yomi='コクナイリートインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13643': FundCodeEntry(
        fund_code='G13643',
        sec_code=None,
        fund_name='先進国株式インデックス・オープン＜為替ヘッジあり＞（ラップ向け）',
        fund_name_yomi='センシンコクカブシキインデックスオープンカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13644': FundCodeEntry(
        fund_code='G13644',
        sec_code=None,
        fund_name='先進国株式インデックス・オープン＜為替ヘッジなし＞（ラップ向け）',
        fund_name_yomi='センシンコクカブシキインデックスオープンカワセヘッジナシラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13645': FundCodeEntry(
        fund_code='G13645',
        sec_code=None,
        fund_name='先進国債券インデックス・オープン＜為替ヘッジあり＞（ラップ向け）',
        fund_name_yomi='センシンコクサイケンインデックスオープンカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13646': FundCodeEntry(
        fund_code='G13646',
        sec_code=None,
        fund_name='先進国債券インデックス・オープン＜為替ヘッジなし＞（ラップ向け）',
        fund_name_yomi='センシンコクサイケンインデックスオープンカワセヘッジナシラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13647': FundCodeEntry(
        fund_code='G13647',
        sec_code=None,
        fund_name='先進国リートインデックス・オープン＜為替ヘッジあり＞（ラップ向け）',
        fund_name_yomi='センシンコクリートインデックスオープンカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13648': FundCodeEntry(
        fund_code='G13648',
        sec_code=None,
        fund_name='先進国リートインデックス・オープン＜為替ヘッジなし＞（ラップ向け）',
        fund_name_yomi='センシンコクリートインデックスオープンカワセヘッジナシラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13649': FundCodeEntry(
        fund_code='G13649',
        sec_code=None,
        fund_name='新興国債券インデックス・オープン（ラップ向け）',
        fund_name_yomi='シンコウコクサイケンインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13651': FundCodeEntry(
        fund_code='G13651',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２０‐０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイゼロノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13654': FundCodeEntry(
        fund_code='G13654',
        sec_code=None,
        fund_name='第１００回２０２４年９月満期株価指数参照円建信託社債（デジタルクーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイヒャッカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13655': FundCodeEntry(
        fund_code='G13655',
        sec_code=None,
        fund_name='第１０１回２０２３年３月満期株価指数参照円建信託社債（固定クーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイヒャクイッカイニセンニジュウサンネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13656': FundCodeEntry(
        fund_code='G13656',
        sec_code=None,
        fund_name='楽天・ポジティブ・インパクト株式ファンド',
        fund_name_yomi='ラクテン\u3000ポジティブ\u3000インパクトカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13657': FundCodeEntry(
        fund_code='G13657',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞おおぶねＪＡＰＡＮ（日本選抜）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000オオブネジャパン\u3000ニホンセンバツ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E35304',
        issuer_name='農林中金バリューインベストメンツ株式会社',
    ),
    'G13658': FundCodeEntry(
        fund_code='G13658',
        sec_code=None,
        fund_name='国内株式インデックス・オープン（ラップ向け）',
        fund_name_yomi='コクナイカブシキインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13659': FundCodeEntry(
        fund_code='G13659',
        sec_code=None,
        fund_name='新興国株式インデックス・オープン（ラップ向け）',
        fund_name_yomi='シンコウコクカブシキインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13660': FundCodeEntry(
        fund_code='G13660',
        sec_code=None,
        fund_name='先進国株式インデックスファンド（ラップ向け）',
        fund_name_yomi='センシンコクカブシキインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13662': FundCodeEntry(
        fund_code='G13662',
        sec_code=None,
        fund_name='パインブリッジ・グローバル・テクノロジー・インフラ・ファンド（３ヵ月決算型）',
        fund_name_yomi='パインブリッジグローバルテクノロジーインフラファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G13663': FundCodeEntry(
        fund_code='G13663',
        sec_code=None,
        fund_name='パインブリッジ・グローバル・テクノロジー・インフラ・ファンド＜為替ヘッジあり＞',
        fund_name_yomi='パインブリッジグローバルテクノロジーインフラファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G13664': FundCodeEntry(
        fund_code='G13664',
        sec_code=None,
        fund_name='第４９回\u3000２０２５年１月３１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヨンジュウキュウカイニセンニジュウゴネンイチガツサンジュウイチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13665': FundCodeEntry(
        fund_code='G13665',
        sec_code=None,
        fund_name='第５０回\u3000２０２５年１月３１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイゴジュッカイニセンニジュウゴネンイチガツサンジュウイチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13666': FundCodeEntry(
        fund_code='G13666',
        sec_code=None,
        fund_name='クリーンテック株式＆グリーンボンド・ファンド（資産成長型／予想分配金提示型）',
        fund_name_yomi='クリーンテックカブシキアンドグリーンボンドファンドシサンセイチョウガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13667': FundCodeEntry(
        fund_code='G13667',
        sec_code=None,
        fund_name='国債ロング・ショート２．５戦略ファンド（年２回決算型）',
        fund_name_yomi='コクサイロングショートニテンゴセンリャクファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G13668': FundCodeEntry(
        fund_code='G13668',
        sec_code=None,
        fund_name='ＧＳフューチャー・テクノロジー・リーダーズ\u3000Ａコース（限定為替ヘッジ）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000フューチャー\u3000テクノロジー\u3000リーダーズ\u3000エーコース\u3000ゲンテイカワセヘッジ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G13669': FundCodeEntry(
        fund_code='G13669',
        sec_code='92870',
        fund_name='ジャパン・インフラファンド投資法人',
        fund_name_yomi='ジャパン\u3000インフラファンドトウシホウジン',
        security_type='内国投資証券',
        period_1='11月末日',
        period_2='5月末日',
        edinet_code='E35423',
        issuer_name='ジャパン・インフラファンド投資法人',
    ),
    'G13670': FundCodeEntry(
        fund_code='G13670',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０１',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13671': FundCodeEntry(
        fund_code='G13671',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０２０－０１',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロニゼロゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13672': FundCodeEntry(
        fund_code='G13672',
        sec_code=None,
        fund_name='自社株買い企業世界株式オープン（ラップ向け）',
        fund_name_yomi='ジシャカブガイキギョウセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13673': FundCodeEntry(
        fund_code='G13673',
        sec_code=None,
        fund_name='連続増配企業世界株式オープン（ラップ向け）',
        fund_name_yomi='レンゾクゾウハイキギョウセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13674': FundCodeEntry(
        fund_code='G13674',
        sec_code=None,
        fund_name='クオリティ企業先進国株式オープン（ラップ向け）',
        fund_name_yomi='クオリティキギョウセンシンコクカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13675': FundCodeEntry(
        fund_code='G13675',
        sec_code=None,
        fund_name='ＥＳＧ米国株式オープン（ラップ向け）',
        fund_name_yomi='イーエスジーベイコクカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13676': FundCodeEntry(
        fund_code='G13676',
        sec_code=None,
        fund_name='ＥＳＧ欧州株式オープン（ラップ向け）',
        fund_name_yomi='イーエスジーオウシュウカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13677': FundCodeEntry(
        fund_code='G13677',
        sec_code=None,
        fund_name='医療関連世界株式オープン（ラップ向け）',
        fund_name_yomi='イリョウカンレンセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13678': FundCodeEntry(
        fund_code='G13678',
        sec_code=None,
        fund_name='長寿社会世界株式オープン（ラップ向け）',
        fund_name_yomi='チョウジュシャカイセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13679': FundCodeEntry(
        fund_code='G13679',
        sec_code=None,
        fund_name='デジタル社会世界株式オープン（ラップ向け）',
        fund_name_yomi='デジタルシャカイセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13680': FundCodeEntry(
        fund_code='G13680',
        sec_code=None,
        fund_name='ロボティクス世界株式オープン（ラップ向け）',
        fund_name_yomi='ロボティクスセカイカブシキオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月5日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G13681': FundCodeEntry(
        fund_code='G13681',
        sec_code=None,
        fund_name='Ｔ＆Ｄ\u3000ベトナム株式ファンド',
        fund_name_yomi='ティアンドディベトナムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13682': FundCodeEntry(
        fund_code='G13682',
        sec_code=None,
        fund_name='Ｔ＆Ｄダブルブル・ベア・シリーズ７',
        fund_name_yomi='ティアンドディダブルブルベアシリーズナナ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13683': FundCodeEntry(
        fund_code='G13683',
        sec_code=None,
        fund_name='フードテック・オープン',
        fund_name_yomi='フードテックオープン',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13684': FundCodeEntry(
        fund_code='G13684',
        sec_code='25580',
        fund_name='ＭＡＸＩＳ米国株式（Ｓ＆Ｐ５００）上場投信',
        fund_name_yomi='マクシスベイコクカブシキエスアンドピーゴヒャクジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13685': FundCodeEntry(
        fund_code='G13685',
        sec_code='25590',
        fund_name='ＭＡＸＩＳ全世界株式（オール・カントリー）上場投信',
        fund_name_yomi='マクシスゼンセカイカブシキオールカントリージョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13686': FundCodeEntry(
        fund_code='G13686',
        sec_code=None,
        fund_name='たわらノーロード\u3000フォーカス\u3000ＡＩ',
        fund_name_yomi='タワラノーロード\u3000フォーカス\u3000エーアイ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13687': FundCodeEntry(
        fund_code='G13687',
        sec_code=None,
        fund_name='たわらノーロード\u3000フォーカス\u3000ロボット・テクノロジー',
        fund_name_yomi='タワラノーロード\u3000フォーカス\u3000ロボットテクノロジー',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13688': FundCodeEntry(
        fund_code='G13688',
        sec_code=None,
        fund_name='ＨＳＢＣ世界資産選抜充実生活コース（定率払出型）',
        fund_name_yomi='エイチエスビーシーセカイシサンセンバツジュウジツセイカツコーステイリツハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13689': FundCodeEntry(
        fund_code='G13689',
        sec_code=None,
        fund_name='たわらノーロード\u3000フォーカス\u3000フィンテック',
        fund_name_yomi='タワラノーロード\u3000フォーカス\u3000フィンテック',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13690': FundCodeEntry(
        fund_code='G13690',
        sec_code=None,
        fund_name='たわらノーロード\u3000フォーカス\u3000次世代通信',
        fund_name_yomi='タワラノーロード\u3000フォーカス\u3000ジセダイツウシン',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13691': FundCodeEntry(
        fund_code='G13691',
        sec_code=None,
        fund_name='シティグループ社債／円建て償還時ターゲットファンド２０２０－０３',
        fund_name_yomi='シティグループシャサイエンダテショウカンジターゲットファンドニイゼロニイゼロゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13692': FundCodeEntry(
        fund_code='G13692',
        sec_code=None,
        fund_name='Ｏｎｅフォーカス\u3000ミレニアルズ',
        fund_name_yomi='ワンフォーカスミレニアルズ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13693': FundCodeEntry(
        fund_code='G13693',
        sec_code=None,
        fund_name='世界成長スマートファンド',
        fund_name_yomi='セカイセイチョウスマートファンド',
        security_type='内国投資信託受益証券',
        period_1='10月26日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G13694': FundCodeEntry(
        fund_code='G13694',
        sec_code=None,
        fund_name='ブラックロックＬｉｆｅＰａｔｈファンド２０６０／２０６５',
        fund_name_yomi='ブラックロックライフパスファンドニイゼロロクゼロニイゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13695': FundCodeEntry(
        fund_code='G13695',
        sec_code=None,
        fund_name='第５１回\u3000２０２３年２月２７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイゴジュウイッカイニセンニジュウサンネンニガツニジュウナナニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月27日',
        period_2='8月27日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G13696': FundCodeEntry(
        fund_code='G13696',
        sec_code=None,
        fund_name='三井住友ＤＳ・ＤＣターゲットイヤーファンド２０６０',
        fund_name_yomi='ミツイスミトモディーエスディーシーターゲットイヤーファンドニイゼロロクゼロ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13697': FundCodeEntry(
        fund_code='G13697',
        sec_code=None,
        fund_name='カレラ改日本株式ファンド',
        fund_name_yomi='カレラカイニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G13700': FundCodeEntry(
        fund_code='G13700',
        sec_code=None,
        fund_name='第１０４回２０２４年１２月満期株価指数参照円建信託社債（デジタルクーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイヒャクヨンカイニセンニジュウヨネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13701': FundCodeEntry(
        fund_code='G13701',
        sec_code=None,
        fund_name='第１０５回２０２３年３月満期株価指数参照円建信託社債（固定クーポン型・早期償還条項付）（責任財産限定特約付）参照指数：東証銀行業株価指数',
        fund_name_yomi='ダイヒャクゴカイニセンニジュウサンネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウトウショウギンコウギョウカブカシスウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13702': FundCodeEntry(
        fund_code='G13702',
        sec_code=None,
        fund_name='オーストラリア好利回り３資産バランス＜為替ヘッジあり＞（年２回決算型）',
        fund_name_yomi='オーストラリアコウリマワリサンシサンバランスカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13705': FundCodeEntry(
        fund_code='G13705',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０２０－０２',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロニゼロゼロニ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13706': FundCodeEntry(
        fund_code='G13706',
        sec_code=None,
        fund_name='野村未来トレンド発見ファンド\u3000Ｃコース（為替ヘッジあり）予想分配金提示型、野村未来トレンド発見ファンド\u3000Ｄコース（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='ノムラミライトレンドハッケンファンドシーコースカワセヘッジアリヨソウブンパイキンテイジガタ\u3000ノムラミライトレンドハッケンファンドディーコースカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13707': FundCodeEntry(
        fund_code='G13707',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０３',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロサン',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13708': FundCodeEntry(
        fund_code='G13708',
        sec_code=None,
        fund_name='シュローダー・エマージング中小型株式ファンド',
        fund_name_yomi='シュローダー\u3000エマージングチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G13709': FundCodeEntry(
        fund_code='G13709',
        sec_code=None,
        fund_name='未来の光\u3000日本小型株式ファンド',
        fund_name_yomi='ミライノヒカリ\u3000ニホンコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G13710': FundCodeEntry(
        fund_code='G13710',
        sec_code=None,
        fund_name='フード・イノベーション厳選株式ファンド',
        fund_name_yomi='フードイノベーションゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13711': FundCodeEntry(
        fund_code='G13711',
        sec_code=None,
        fund_name='世界セレクティブ株式オープン（年２回決算型）',
        fund_name_yomi='セカイセレクティブカブシキオープンネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13712': FundCodeEntry(
        fund_code='G13712',
        sec_code='25600',
        fund_name='ＭＡＸＩＳカーボン・エフィシェント日本株上場投信',
        fund_name_yomi='マクシスカーボンエフィシェントニホンカブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13714': FundCodeEntry(
        fund_code='G13714',
        sec_code=None,
        fund_name='グローバル５．５倍バランスファンド（１年決算型）',
        fund_name_yomi='グローバルゴウテンゴバイバランスファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13716': FundCodeEntry(
        fund_code='G13716',
        sec_code=None,
        fund_name='次世代通信関連\u3000アジア株式戦略ファンド',
        fund_name_yomi='ジセダイツウシンカンレン\u3000アジアカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13717': FundCodeEntry(
        fund_code='G13717',
        sec_code='25610',
        fund_name='ｉシェアーズ・コア\u3000日本国債\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000コア\u3000ニホンコクサイ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13718': FundCodeEntry(
        fund_code='G13718',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000日経２２５',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13719': FundCodeEntry(
        fund_code='G13719',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000Ｓ＆Ｐ５００',
        fund_name_yomi='エヌザム\u3000ベータ\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13720': FundCodeEntry(
        fund_code='G13720',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000日本２資産（株式＋ＲＥＩＴ）',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ニホンニシサン\u3000カブシキプラスリート',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13721': FundCodeEntry(
        fund_code='G13721',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000米国２資産（株式＋ＲＥＩＴ）',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ベイコクニシサン\u3000カブシキプラスリート',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13722': FundCodeEntry(
        fund_code='G13722',
        sec_code=None,
        fund_name='フィデリティ・世界割安成長株投信\u3000Ａコース（為替ヘッジあり）\u3000フィデリティ・世界割安成長株投信\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティセカイワリヤスセイチョウカブトウシンエーコースカワセヘッジアリ\u3000フィデリティセカイワリヤスセイチョウカブトウシンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13724': FundCodeEntry(
        fund_code='G13724',
        sec_code=None,
        fund_name='ＮＷＱグローバル厳選証券ファンド（為替ヘッジあり・なし／毎月分配型）',
        fund_name_yomi='エヌダブリューキューグローバルゲンセンショウケンファンドカワセヘッジアリナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13725': FundCodeEntry(
        fund_code='G13725',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０２０－０３',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロニイゼロ\u3000ゼロサン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13726': FundCodeEntry(
        fund_code='G13726',
        sec_code=None,
        fund_name='楽天・新経連株価指数ファンド',
        fund_name_yomi='ラクテン\u3000シンケイレンカブカシスウファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13727': FundCodeEntry(
        fund_code='G13727',
        sec_code=None,
        fund_name='次世代ＲＥＩＴオープン＜資産成長型＞（為替ヘッジあり）／＜資産成長型＞（為替ヘッジなし）／＜毎月決算型＞（為替ヘッジあり）予想分配金提示型／＜毎月決算型＞（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='ジセダイリートオープンシサンセイチョウガタカワセヘッジアリシサンセイチョウガタカワセヘッジナシマイツキケッサンガタカワセヘッジアリヨソウブンパイキンテイジガタマイツキケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月13日',
        period_2='8月13日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13728': FundCodeEntry(
        fund_code='G13728',
        sec_code=None,
        fund_name='ジャパンＥＳＧクオリティ２００インデックスファンド',
        fund_name_yomi='ジャパンイーエスジークオリティニヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G13733': FundCodeEntry(
        fund_code='G13733',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000グローバル・サステイン戦略ファンド（為替ヘッジあり）、モルガン・スタンレー\u3000グローバル・サステイン戦略ファンド（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーグローバルサステインセンリャクファンドカワセヘッジアリ\u3000モルガンスタンレーグローバルサステインセンリャクファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13735': FundCodeEntry(
        fund_code='G13735',
        sec_code=None,
        fund_name='ＳＢＩ中国テクノロジー株ファンド',
        fund_name_yomi='エスビーアイチュウゴクテクノロジーカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13736': FundCodeEntry(
        fund_code='G13736',
        sec_code=None,
        fund_name='オルトゥ・クールバ・トラスト－ゴールドマン・サックス社債／償還時目標設定型ファンド２０２０－０３',
        fund_name_yomi='オルトゥクールバトラストゴールドマンサックスシャサイショウカンジモクヒョウセッテイガタファンドニゼロニゼロゼロサン',
        security_type='外国投資信託受益証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E15033',
        issuer_name='ＩＱ\u3000ＥＱマネジメント・バミューダ・リミテッド',
    ),
    'G13737': FundCodeEntry(
        fund_code='G13737',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２０－０３（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニィゼロニィゼロゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13738': FundCodeEntry(
        fund_code='G13738',
        sec_code=None,
        fund_name='クォンティック・トラスト－早期償還目標水準設定型ファンド\u3000スマート・ブレイン２０２０－０３',
        fund_name_yomi='クォンティックトラストソウキショウカンモクヒョウスイジュンセッテイガタファンドスマートブレインニマルニマルマルサン',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G13739': FundCodeEntry(
        fund_code='G13739',
        sec_code=None,
        fund_name='野村日経２２５インデックス（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニッケイニニゴインデックスノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13740': FundCodeEntry(
        fund_code='G13740',
        sec_code=None,
        fund_name='東京海上・世界モノポリー戦略株式ファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウセカイモノポリーセンリャクカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13741': FundCodeEntry(
        fund_code='G13741',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０２０－０３',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロニゼロゼロサン',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13742': FundCodeEntry(
        fund_code='G13742',
        sec_code=None,
        fund_name='リスクコントロール・オープン',
        fund_name_yomi='リスクコントロール\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13743': FundCodeEntry(
        fund_code='G13743',
        sec_code=None,
        fund_name='国内債券インデックスファンド（ラップ向け）',
        fund_name_yomi='コクナイサイケンインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13744': FundCodeEntry(
        fund_code='G13744',
        sec_code=None,
        fund_name='スペイン国債７－１０年ラダーファンド（為替ヘッジあり）（ラップ向け）',
        fund_name_yomi='スペインコクサイナナカラジュウネンラダーファンドカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13745': FundCodeEntry(
        fund_code='G13745',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000日本ＲＥＩＴ',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ニホンリート',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13746': FundCodeEntry(
        fund_code='G13746',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000米国ＲＥＩＴ',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ベイコクリート',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13747': FundCodeEntry(
        fund_code='G13747',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000ＮＹダウ３０',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ニューヨークダウサンジュウ',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13748': FundCodeEntry(
        fund_code='G13748',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000ＮＡＳＤＡＱ１００',
        fund_name_yomi='エヌザム\u3000ベータ\u3000ナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='2月21日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13749': FundCodeEntry(
        fund_code='G13749',
        sec_code=None,
        fund_name='ＮＺＡＭ・レバレッジ\u3000日本株式２倍ブル',
        fund_name_yomi='エヌザム\u3000レバレッジ\u3000ニホンカブシキニバイブル',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13750': FundCodeEntry(
        fund_code='G13750',
        sec_code=None,
        fund_name='ＮＺＡＭ・レバレッジ\u3000米国株式２倍ブル（Ｓ＆Ｐ５００）',
        fund_name_yomi='エヌザム\u3000レバレッジ\u3000ベイコクカブシキニバイブル\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13752': FundCodeEntry(
        fund_code='G13752',
        sec_code=None,
        fund_name='つみたて米国株式（Ｓ＆Ｐ５００）',
        fund_name_yomi='ツミタテベイコクカブシキエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13753': FundCodeEntry(
        fund_code='G13753',
        sec_code=None,
        fund_name='つみたて全世界株式',
        fund_name_yomi='ツミタテゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13754': FundCodeEntry(
        fund_code='G13754',
        sec_code='25620',
        fund_name='上場インデックスファンド米国株式（ダウ平均）為替ヘッジあり',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキ\u3000ダウヘイキン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13755': FundCodeEntry(
        fund_code='G13755',
        sec_code=None,
        fund_name='野村スリーゼロ先進国株式投信',
        fund_name_yomi='ノムラスリーゼロセンシンコクカブシキトウシン',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13756': FundCodeEntry(
        fund_code='G13756',
        sec_code=None,
        fund_name='先進国ロング・ショート戦略ファンド（ラップ向け）',
        fund_name_yomi='センシンコクロングショートセンリャクファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2='8月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13757': FundCodeEntry(
        fund_code='G13757',
        sec_code=None,
        fund_name='ＳＢＩ日本株３．８ベア',
        fund_name_yomi='エスビーアイニホンカブサンテンハチベア',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13758': FundCodeEntry(
        fund_code='G13758',
        sec_code=None,
        fund_name='ＨＳＢＣオルタナティブ・バランス・ファンド',
        fund_name_yomi='エイチエスビーシーオルタナティブバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13759': FundCodeEntry(
        fund_code='G13759',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞おおぶねグローバル（長期厳選）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000オオブネグローバル\u3000チョウキゲンセン',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E35304',
        issuer_name='農林中金バリューインベストメンツ株式会社',
    ),
    'G13765': FundCodeEntry(
        fund_code='G13765',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－外貨建てマンＡＨＬスマート・レバレッジ戦略ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーガイカダテマンエーエイチエルスマートレバレッジセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13766': FundCodeEntry(
        fund_code='G13766',
        sec_code=None,
        fund_name='東京海上・インド・オーナーズ株式オープン',
        fund_name_yomi='トウキョウカイジョウインドオーナーズカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13772': FundCodeEntry(
        fund_code='G13772',
        sec_code=None,
        fund_name='野村ブル・ベア\u3000セレクト８',
        fund_name_yomi='ノムラブルベアセレクトエイト',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13773': FundCodeEntry(
        fund_code='G13773',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ターゲットリターン・ファンド（４％コース）',
        fund_name_yomi='ワンターゲットリターンファンドヨンパーセントコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13774': FundCodeEntry(
        fund_code='G13774',
        sec_code=None,
        fund_name='世界８資産リスク分散バランスファンド（目標払出し型）',
        fund_name_yomi='セカイハチシサンリスクブンサンバランスファンドモクヒョウハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13775': FundCodeEntry(
        fund_code='G13775',
        sec_code=None,
        fund_name='楽天・グロース・ワールド株式ファンド（ラップ向け）',
        fund_name_yomi='ラクテン\u3000グロース\u3000ワールドカブシキファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13776': FundCodeEntry(
        fund_code='G13776',
        sec_code=None,
        fund_name='三菱ＵＦＪ国際\u3000ターゲットリターン・ファンド（２％コース）',
        fund_name_yomi='ミツビシユーエフジェイコクサイターゲットリターンファンドニパーセントコース',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13777': FundCodeEntry(
        fund_code='G13777',
        sec_code=None,
        fund_name='ニュー・ニッチ\u3000日本小型株ファンド',
        fund_name_yomi='ニューニッチ\u3000ニホンコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G13782': FundCodeEntry(
        fund_code='G13782',
        sec_code=None,
        fund_name='ＭＳＩＭグローバル株式コンセントレイト・ファンド（ＳＭＡ専用）',
        fund_name_yomi='エムエスアイエムグローバルカブシキコンセントレイト\u3000ファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13783': FundCodeEntry(
        fund_code='G13783',
        sec_code=None,
        fund_name='ＮＹダウ・トリプル・レバレッジ',
        fund_name_yomi='ニューヨークダウトリプルレバレッジ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13785': FundCodeEntry(
        fund_code='G13785',
        sec_code=None,
        fund_name='ＳＢＩ米国株（ＮＹＳＥ\u3000ＦＡＮＧ＋）トリプル・ベア',
        fund_name_yomi='エスビーアイ\u3000ベイコクカブ\u3000エヌワイエスイー\u3000ファングプラス\u3000トリプルベア',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13786': FundCodeEntry(
        fund_code='G13786',
        sec_code=None,
        fund_name='ＳＢＩ国内ＲＥＩＴ\u3000ダブル・ベア',
        fund_name_yomi='エスビーアイ\u3000コクナイリート\u3000ダブルベア',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13787': FundCodeEntry(
        fund_code='G13787',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２０－Ⅰ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイゼロノイチ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13788': FundCodeEntry(
        fund_code='G13788',
        sec_code=None,
        fund_name='りそな・リスクコントロールファンド２０２０－０６',
        fund_name_yomi='リソナ\u3000リスクコントロールファンドニイゼロニイゼロ\u3000ゼロロク',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13793': FundCodeEntry(
        fund_code='G13793',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０５',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13795': FundCodeEntry(
        fund_code='G13795',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000先進国リートインデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイセンシンコクリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13796': FundCodeEntry(
        fund_code='G13796',
        sec_code=None,
        fund_name='華流国潮イノベーション株式ファンド（１年決算型）',
        fund_name_yomi='カリュウコクチョウイノベーションカブシキファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13797': FundCodeEntry(
        fund_code='G13797',
        sec_code=None,
        fund_name='Ｏｎｅ国際分散投資戦略ファンド（目標リスク８％）＜ＤＣ年金＞、Ｏｎｅ国際分散投資戦略ファンド（目標リスク６％）＜ＤＣ年金＞、Ｏｎｅ国際分散投資戦略ファンド（目標リスク４％）＜ＤＣ年金＞、Ｏｎｅ国際分散投資戦略ファンド（目標リスク２％）＜ＤＣ年金＞',
        fund_name_yomi='ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクハチパーセントディーシーネンキン\u3000ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクロクパーセントディーシーネンキン\u3000ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクヨンパーセントディーシーネンキン\u3000ワンコクサイブンサントウシセンリャクファンドモクヒョウリスクニパーセントディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13798': FundCodeEntry(
        fund_code='G13798',
        sec_code=None,
        fund_name='スパークス・厳選投資ファンド（確定拠出年金向け）',
        fund_name_yomi='スパークス\u3000ゲンセントウシ\u3000ファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G13799': FundCodeEntry(
        fund_code='G13799',
        sec_code=None,
        fund_name='先進国リスクターゲットファンド',
        fund_name_yomi='センシンコクリスクターゲットファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13800': FundCodeEntry(
        fund_code='G13800',
        sec_code=None,
        fund_name='アライアンス・バーンスタインＳＩＣＡＶ－アメリカン・グロース・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインシキャブアメリカングロースポートフォリオ',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E14837',
        issuer_name='アライアンス・バーンスタインＳＩＣＡＶ',
    ),
    'G13801': FundCodeEntry(
        fund_code='G13801',
        sec_code=None,
        fund_name='アルジェブリスＵＣＩＴＳファンズｐｌｃ－アルジェブリス・ファイナンシャル・クレジット・ファンド',
        fund_name_yomi='アルジェブリスユーシッツファンズピーエルシーアルジェブリスファイナンシャルクレジットファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35752',
        issuer_name='アルジェブリスＵＣＩＴＳファンズ\u3000ｐｌｃ',
    ),
    'G13802': FundCodeEntry(
        fund_code='G13802',
        sec_code=None,
        fund_name='りそな\u3000つみたて国内株式アクティブファンド',
        fund_name_yomi='リソナ\u3000ツミタテコクナイカブシキアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13803': FundCodeEntry(
        fund_code='G13803',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＳＢＩ－ピクテ\u3000アジア・ハイテクベンチャー・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーエスビーアイピクテアジアハイテクベンチャーファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13804': FundCodeEntry(
        fund_code='G13804',
        sec_code=None,
        fund_name='ＪＰＭグローバル高利回りＣＢファンド（限定追加型）２０２０－０６',
        fund_name_yomi='ジェイピーエムグローバルコウリマワリシービーファンドゲンテイツイカガタニセンニジュウノゼロロク',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13805': FundCodeEntry(
        fund_code='G13805',
        sec_code=None,
        fund_name='世の中を良くする企業ファンド（野村日本株ＥＳＧ投資）（確定拠出年金向け）',
        fund_name_yomi='ヨノナカヲヨクスルキギョウファンドノムラニホンカブイーエスジートウシカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13806': FundCodeEntry(
        fund_code='G13806',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000世界厳選成長株式ファンド（確定拠出年金向け）',
        fund_name_yomi='ティーロウプライス\u3000セカイゲンセンセイチョウカブシキファンド\u3000カクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G13809': FundCodeEntry(
        fund_code='G13809',
        sec_code=None,
        fund_name='ダイワ・ゴールド・ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ダイワゴールドファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13810': FundCodeEntry(
        fund_code='G13810',
        sec_code=None,
        fund_name='アムンディ・次世代イノベーティブ世界株式ファンド',
        fund_name_yomi='アムンディジセダイイノベーティブセカイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月27日',
        period_2='12月27日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13811': FundCodeEntry(
        fund_code='G13811',
        sec_code=None,
        fund_name='楽天・日本株マイクロキャップ・ファンド',
        fund_name_yomi='ラクテン\u3000ニホンカブマイクロキャップ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13812': FundCodeEntry(
        fund_code='G13812',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０６',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロロク',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13813': FundCodeEntry(
        fund_code='G13813',
        sec_code=None,
        fund_name='マネックス・アクティビスト・ファンド',
        fund_name_yomi='マネックスアクティビストファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G13814': FundCodeEntry(
        fund_code='G13814',
        sec_code=None,
        fund_name='ＳＢＩポストコロナファンド',
        fund_name_yomi='エスビーアイポストコロナファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G13815': FundCodeEntry(
        fund_code='G13815',
        sec_code=None,
        fund_name='ピクテ・ゴールデン・リスクプレミアム・ファンド',
        fund_name_yomi='ピクテゴールデンリスクプレミアムファンド',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G13816': FundCodeEntry(
        fund_code='G13816',
        sec_code=None,
        fund_name='ＯｎｅグローバルＥＳＧ厳選株ファンド＜ＤＣ年金＞',
        fund_name_yomi='ワングローバルイーエスジーゲンセンカブファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13817': FundCodeEntry(
        fund_code='G13817',
        sec_code='25630',
        fund_name='ｉシェアーズ\u3000Ｓ＆Ｐ\u3000５００\u3000米国株\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000エスアンドピー\u3000ゴヒャク\u3000ベイコクカブ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13818': FundCodeEntry(
        fund_code='G13818',
        sec_code=None,
        fund_name='お金のデザイン・リキッド・オルタナティブ・ファンド',
        fund_name_yomi='オカネノデザイン\u3000リキッド\u3000オルタナティブ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G13819': FundCodeEntry(
        fund_code='G13819',
        sec_code=None,
        fund_name='グローバルＥＳＧハイクオリティ成長株式ファンド（為替ヘッジなし）',
        fund_name_yomi='グローバルイーエスジーハイクオリティセイチョウカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13820': FundCodeEntry(
        fund_code='G13820',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２０‐０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイゼロノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13822': FundCodeEntry(
        fund_code='G13822',
        sec_code=None,
        fund_name='ブリオングロード・ブリッジ・ユニット・トラスト－ＤＭＳ償還時目標設定型ファンド２０２０－０７（ゴールドマン・サックス社債投資型）',
        fund_name_yomi='ブリオングロードブリッジユニットトラストディーエムエスショウカンジモクヒョウセッテイガタファンドニマルニマルマルナナゴールドマンサックスシャサイトウシガタ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35772',
        issuer_name='ウェイストーン・マネジメント・カンパニー（ＩＥ）リミテッド',
    ),
    'G13823': FundCodeEntry(
        fund_code='G13823',
        sec_code=None,
        fund_name='ニッセイ世界株式ファンド（ＧＤＰ型バスケット）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイセカイカブシキファンドジーディーピーガタバスケットコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13824': FundCodeEntry(
        fund_code='G13824',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２０－０７（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニィゼロニィゼロゼロナナゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13825': FundCodeEntry(
        fund_code='G13825',
        sec_code=None,
        fund_name='日興ワールド・トラスト－デンマーク・カバード債券ファンド\u3000米ドル建て（米ドルヘッジあり）',
        fund_name_yomi='ニッコウワールドトラストデンマークカバードサイケンファンドベイドルダテベイドルヘッジアリ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G13827': FundCodeEntry(
        fund_code='G13827',
        sec_code=None,
        fund_name='ロボット・テクノロジー関連株ファンド\u3000－ロボテック－（毎月決算／予想分配金提示型）',
        fund_name_yomi='ロボットテクノロジーカンレンカブファンドロボテックマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13830': FundCodeEntry(
        fund_code='G13830',
        sec_code=None,
        fund_name='野村ＡＣＩハイインカムＲＥＩＴファンド（為替ヘッジあり）\u3000毎月分配型',
        fund_name_yomi='ノムラエーシーアイハイインカムリートファンドカワセヘッジアリマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13831': FundCodeEntry(
        fund_code='G13831',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンドＤＤ「華夏」２０２０',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドディーディーカカニゼロニゼロ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G13832': FundCodeEntry(
        fund_code='G13832',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０７',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13833': FundCodeEntry(
        fund_code='G13833',
        sec_code=None,
        fund_name='シュローダー先進国好利回りＣＢファンド２０２０－０７（限定追加型）',
        fund_name_yomi='シュローダーセンシンコクコウリマワリシービーファンドニィゼロニィゼロ\u3000ゼロナナ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月26日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G13834': FundCodeEntry(
        fund_code='G13834',
        sec_code=None,
        fund_name='アムンディＤＣファンド\u3000世界株式・気候変動対応',
        fund_name_yomi='アムンディディーシーファンドセカイカブシキキコウヘンドウタイオウ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13835': FundCodeEntry(
        fund_code='G13835',
        sec_code=None,
        fund_name='アムンディＤＣファンド\u3000世界株式・次世代教育関連',
        fund_name_yomi='アムンディディーシーファンドセカイカブシキジセダイキョウイクカンレン',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13836': FundCodeEntry(
        fund_code='G13836',
        sec_code=None,
        fund_name='ダイワＳｏｃｉｅｔｙ\u3000５．０関連株ファンド（資産成長型／予想分配金提示型）',
        fund_name_yomi='ダイワソサイエティファイブポイントゼロカンレンカブファンドシサンセイチョウガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2='7月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13837': FundCodeEntry(
        fund_code='G13837',
        sec_code=None,
        fund_name='ＪＰＭ債券インカム・ファンド（為替ヘッジなし、年１回決算型）',
        fund_name_yomi='ジェイピーエムサイケンインカムファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13838': FundCodeEntry(
        fund_code='G13838',
        sec_code=None,
        fund_name='ＪＰＭ債券インカム・ファンド（為替ヘッジなし、毎月決算型）',
        fund_name_yomi='ジェイピーエムサイケンインカムファンドカワセヘッジナシマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13839': FundCodeEntry(
        fund_code='G13839',
        sec_code=None,
        fund_name='ＪＰＭ債券インカム・ファンド（為替ヘッジあり、年１回決算型）',
        fund_name_yomi='ジェイピーエムサイケンインカムファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13840': FundCodeEntry(
        fund_code='G13840',
        sec_code=None,
        fund_name='ＪＰＭ債券インカム・ファンド（為替ヘッジあり、毎月決算型）',
        fund_name_yomi='ジェイピーエムサイケンインカムファンドカワセヘッジアリマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13841': FundCodeEntry(
        fund_code='G13841',
        sec_code=None,
        fund_name='クリーンテック株式ファンド（資産成長型）',
        fund_name_yomi='クリーンテックカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13842': FundCodeEntry(
        fund_code='G13842',
        sec_code=None,
        fund_name='デジタル・トランスフォーメーション株式ファンド',
        fund_name_yomi='デジタル\u3000トランスフォーメーションカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13845': FundCodeEntry(
        fund_code='G13845',
        sec_code=None,
        fund_name='ＳＭＢＣ・ＤＣインデックスファンド（ＭＳＣＩコクサイ）',
        fund_name_yomi='エスエムビーシーディーシーインデックスファンドエムエスシーアイコクサイ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13846': FundCodeEntry(
        fund_code='G13846',
        sec_code=None,
        fund_name='ＳＭＢＣ・ＤＣインデックスファンド（日経２２５）',
        fund_name_yomi='エスエムビーシーディーシーインデックスファンドニッケイニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13847': FundCodeEntry(
        fund_code='G13847',
        sec_code=None,
        fund_name='ＳＭＢＣ・ＤＣインデックスファンド（Ｓ＆Ｐ５００）',
        fund_name_yomi='エスエムビーシーディーシーインデックスファンドエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13848': FundCodeEntry(
        fund_code='G13848',
        sec_code=None,
        fund_name='モルガン・スタンレーＵＳハイイールド債券ファンド（毎月決算型）（為替ヘッジあり）、モルガン・スタンレーＵＳハイイールド債券ファンド（毎月決算型）（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーユーエスハイイールドサイケンファンドマイツキケッサンガタカワセヘッジアリ\u3000モルガンスタンレーユーエスハイイールドサイケンファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13849': FundCodeEntry(
        fund_code='G13849',
        sec_code=None,
        fund_name='モルガン・スタンレーＵＳハイイールド債券ファンド（年１回決算型）（為替ヘッジあり）、モルガン・スタンレーＵＳハイイールド債券ファンド（年１回決算型）（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーユーエスハイイールドサイケンファンドネンイッカイケッサンガタカワセヘッジアリ\u3000モルガンスタンレーユーエスハイイールドサイケンファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13850': FundCodeEntry(
        fund_code='G13850',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000Ｓ＆Ｐ５００インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000エスアンドピーゴヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13851': FundCodeEntry(
        fund_code='G13851',
        sec_code=None,
        fund_name='いちよしＳＤＧｓ中小型株ファンド',
        fund_name_yomi='イチヨシエスディジーエスチュウコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G13852': FundCodeEntry(
        fund_code='G13852',
        sec_code=None,
        fund_name='ダイワ高利回りＪ－ＲＥＩＴオープン（毎月分配型）',
        fund_name_yomi='ダイワコウリマワリジェイリートオープンマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13854': FundCodeEntry(
        fund_code='G13854',
        sec_code=None,
        fund_name='世界新時代株式ファンド（資産成長型）',
        fund_name_yomi='セカイシンジダイカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13855': FundCodeEntry(
        fund_code='G13855',
        sec_code=None,
        fund_name='世界新時代株式ファンド（予想分配金提示型）',
        fund_name_yomi='セカイシンジダイカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13856': FundCodeEntry(
        fund_code='G13856',
        sec_code=None,
        fund_name='フィデリティ・世界割安成長株投信\u3000Ａコース（為替ヘッジあり）（野村ＳＭＡ・ＥＷ向け）\u3000フィデリティ・世界割安成長株投信\u3000Ｂコース（為替ヘッジなし）（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='フィデリティセカイワリヤスセイチョウカブトウシンエーコースカワセヘッジアリノムラエスエムエーイーダブリュームケ\u3000フィデリティセカイワリヤスセイチョウカブトウシンビーコースカワセヘッジナシノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13857': FundCodeEntry(
        fund_code='G13857',
        sec_code=None,
        fund_name='ダイワ新生活関連株ファンド',
        fund_name_yomi='ダイワシンセイカツカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13858': FundCodeEntry(
        fund_code='G13858',
        sec_code=None,
        fund_name='東京海上・エンターテインメント・テクノロジー株式ファンド',
        fund_name_yomi='トウキョウカイジョウエンターテインメントテクノロジーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月6日',
        period_2='8月6日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13859': FundCodeEntry(
        fund_code='G13859',
        sec_code=None,
        fund_name='フィデリティ・米国株式ファンド\u3000Ｅコース（毎月決算・予想分配金提示型・為替ヘッジあり）\u3000フィデリティ・米国株式ファンド\u3000Ｆコース（毎月決算・予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='フィデリティベイコクカブシキファンドイーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジアリ\u3000フィデリティベイコクカブシキファンドエフコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13860': FundCodeEntry(
        fund_code='G13860',
        sec_code=None,
        fund_name='世界セレクティブ株式オープン（為替ヘッジあり／年２回決算型）',
        fund_name_yomi='セカイセレクティブカブシキオープンカワセヘッジアリネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13861': FundCodeEntry(
        fund_code='G13861',
        sec_code=None,
        fund_name='世界セレクティブ株式オープン（為替ヘッジあり／年１回決算型）',
        fund_name_yomi='セカイセレクティブカブシキオープンカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13862': FundCodeEntry(
        fund_code='G13862',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国リート（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクリートカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13863': FundCodeEntry(
        fund_code='G13863',
        sec_code=None,
        fund_name='たわらノーロード\u3000先進国リート（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000センシンコクリートカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13864': FundCodeEntry(
        fund_code='G13864',
        sec_code=None,
        fund_name='野村ブラックロック循環経済関連株投信\u3000Ａコース、野村ブラックロック循環経済関連株投信\u3000Ｂコース',
        fund_name_yomi='ノムラブラックロックジュンカンケイザイカンレンカブトウシンエーコース\u3000ノムラブラックロックジュンカンケイザイカンレンカブトウシンビーコース',
        security_type='内国投資信託受益証券',
        period_1='2月6日',
        period_2='8月6日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13865': FundCodeEntry(
        fund_code='G13865',
        sec_code=None,
        fund_name='埼玉りそな・グローバルバランス・プラスＥＳＧ',
        fund_name_yomi='サイタマリソナ\u3000グローバルバランス\u3000プラスイーエスジー',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13866': FundCodeEntry(
        fund_code='G13866',
        sec_code=None,
        fund_name='ＤＣ米国株式インデックス・オープン（Ｓ＆Ｐ５００）',
        fund_name_yomi='ディーシーベイコクカブシキインデックス\u3000オープン\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13867': FundCodeEntry(
        fund_code='G13867',
        sec_code='25670',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000Ｓ＆Ｐ／ＪＰＸカーボン・エフィシェント指数',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000エスアンドピー\u3000ジェイピーエックスカーボン\u3000エフィシェントシスウ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G13870': FundCodeEntry(
        fund_code='G13870',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－０９',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13871': FundCodeEntry(
        fund_code='G13871',
        sec_code=None,
        fund_name='Ｏｎｅグローバル中小型長期成長株ファンド',
        fund_name_yomi='ワングローバルチュウコガタチョウキセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13872': FundCodeEntry(
        fund_code='G13872',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000ＦＡＮＧ＋',
        fund_name_yomi='アイフリーレバレッジファングプラス',
        security_type='内国投資信託受益証券',
        period_1='8月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13873': FundCodeEntry(
        fund_code='G13873',
        sec_code=None,
        fund_name='ＦＡＮＧ＋２倍ブル、ＦＡＮＧ＋２倍ベア、ＦＡＮＧ＋ブルベア・マネーポートフォリオ',
        fund_name_yomi='ファングプラスニバイブルファングプラスニバイベアファングプラスブルベアマネーポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='8月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13875': FundCodeEntry(
        fund_code='G13875',
        sec_code=None,
        fund_name='マニュライフ・厳選日本株ファンド',
        fund_name_yomi='マニュライフゲンセンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G13876': FundCodeEntry(
        fund_code='G13876',
        sec_code='25640',
        fund_name='グローバルＸ\u3000ＭＳＣＩスーパーディビィデンド－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエムエスシーアイスーパーディビィデンドニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G13877': FundCodeEntry(
        fund_code='G13877',
        sec_code='25650',
        fund_name='グローバルＸ\u3000ロジスティクス・Ｊ－ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスロジスティクスジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G13878': FundCodeEntry(
        fund_code='G13878',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・ネクスト（毎月分配型）',
        fund_name_yomi='ダイワユーエスリートネクストマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13879': FundCodeEntry(
        fund_code='G13879',
        sec_code=None,
        fund_name='インデックスファンドＮＡＳＤＡＱ１００（アメリカ株式）',
        fund_name_yomi='インデックスファンドナスダックヒャク\u3000アメリカカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13880': FundCodeEntry(
        fund_code='G13880',
        sec_code='25660',
        fund_name='上場インデックスファンド日経ＥＳＧリート',
        fund_name_yomi='ジョウジョウインデックスファンドニッケイイーエスジーリート',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13881': FundCodeEntry(
        fund_code='G13881',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000グローバル・テクノロジー株式ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000グローバルテクノロジーカブシキファンド\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G13882': FundCodeEntry(
        fund_code='G13882',
        sec_code=None,
        fund_name='ピムコ・バミューダ・トラストＩＩ－ＰＩＭＣＯコア・インカム社債ファンド２０２０－１０',
        fund_name_yomi='ピムコバミューダトラストツーピムココアインカムシャサイファンドニマルニマルジュウ',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G13883': FundCodeEntry(
        fund_code='G13883',
        sec_code=None,
        fund_name='ジャナス・セレクション',
        fund_name_yomi='ジャナスセレクション',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35957',
        issuer_name='ジャナス・ヘンダーソン・インベスターズ・ヨーロッパ・エスエー',
    ),
    'G13884': FundCodeEntry(
        fund_code='G13884',
        sec_code=None,
        fund_name='グローバルＤＸ関連株式ファンド（予想分配金提示型）',
        fund_name_yomi='グローバルディーエックスカンレンカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13885': FundCodeEntry(
        fund_code='G13885',
        sec_code=None,
        fund_name='グローバルＤＸ関連株式ファンド（資産成長型）',
        fund_name_yomi='グローバルディーエックスカンレンカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13886': FundCodeEntry(
        fund_code='G13886',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ日本株ＥＳＧアクティブファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーニホンカブイーエスジーアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13887': FundCodeEntry(
        fund_code='G13887',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣジャパンＥＳＧセレクト・リーダーズインデックス',
        fund_name_yomi='ミツビシユーエフジェイディーシージャパンイーエスジーセレクトリーダーズインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13888': FundCodeEntry(
        fund_code='G13888',
        sec_code=None,
        fund_name='＜ＤＣ＞ベイリー・ギフォード\u3000ＥＳＧ世界株ファンド',
        fund_name_yomi='ディーシーベイリーギフォードイーエスジーセカイカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13889': FundCodeEntry(
        fund_code='G13889',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ－デジタル・トランスフォーメーション・テーマ（米ドル）',
        fund_name_yomi='ユービーエスルクスキーセレクションシキャブデジタルトランスフォーメーションテーマベイドル',
        security_type='外国投資証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E15296',
        issuer_name='ＵＢＳ（Ｌｕｘ）キー・セレクション・シキャブ',
    ),
    'G13890': FundCodeEntry(
        fund_code='G13890',
        sec_code=None,
        fund_name='カレラインフラ・ファンド',
        fund_name_yomi='カレラインフラファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G13893': FundCodeEntry(
        fund_code='G13893',
        sec_code=None,
        fund_name='グローバル全生物ゲノム株式ファンド（年２回決算型）',
        fund_name_yomi='グローバルゼンセイブツゲノムカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13894': FundCodeEntry(
        fund_code='G13894',
        sec_code=None,
        fund_name='日本生命第５回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイゴカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E35980',
        issuer_name='日本生命第５回劣後ローン流動化株式会社',
    ),
    'G13895': FundCodeEntry(
        fund_code='G13895',
        sec_code='25680',
        fund_name='上場インデックスファンド米国株式（ＮＡＳＤＡＱ１００）為替ヘッジなし',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキ\u3000ナスダックヒャク\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13896': FundCodeEntry(
        fund_code='G13896',
        sec_code='25690',
        fund_name='上場インデックスファンド米国株式（ＮＡＳＤＡＱ１００）為替ヘッジあり',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキ\u3000ナスダックヒャク\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13897': FundCodeEntry(
        fund_code='G13897',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０３５',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンサンジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13898': FundCodeEntry(
        fund_code='G13898',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０４５',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンヨンジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13899': FundCodeEntry(
        fund_code='G13899',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０５５',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンゴジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13902': FundCodeEntry(
        fund_code='G13902',
        sec_code=None,
        fund_name='ひとくふうターゲット・デート・ファンド２０３５\u3000ひとくふうターゲット・デート・ファンド２０４５\u3000ひとくふうターゲット・デート・ファンド２０５５\u3000ひとくふうターゲット・デート・ファンド２０６５',
        fund_name_yomi='ヒトクフウターゲットデートファンドニゼロサンゴ\u3000ヒトクフウターゲットデートファンドニゼロヨンゴ\u3000ヒトクフウターゲットデートファンドニゼロゴゴ\u3000ヒトクフウターゲットデートファンドニゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13903': FundCodeEntry(
        fund_code='G13903',
        sec_code=None,
        fund_name='三井住友ＤＳ・国内リートインデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスコクナイリートインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13904': FundCodeEntry(
        fund_code='G13904',
        sec_code=None,
        fund_name='楽天・ＵＳハイイールド社債インデックス（為替ヘッジ）ファンド（ラップ向け）',
        fund_name_yomi='ラクテン\u3000ユーエスハイイールドシャサイインデックス\u3000カワセヘッジ\u3000ファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G13905': FundCodeEntry(
        fund_code='G13905',
        sec_code=None,
        fund_name='三井住友ＤＳ・外国リートインデックス年金ファンド',
        fund_name_yomi='ミツイスミトモディーエスガイコクリートインデックスネンキンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13906': FundCodeEntry(
        fund_code='G13906',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２０‐１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイゼロノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13907': FundCodeEntry(
        fund_code='G13907',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２０－Ⅱ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイゼロノニ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13908': FundCodeEntry(
        fund_code='G13908',
        sec_code=None,
        fund_name='百戦錬磨の名人ファンド',
        fund_name_yomi='ヒャクセンレンマノメイジンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13909': FundCodeEntry(
        fund_code='G13909',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－豪ドル建て短期債券ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーゴウドルダテタンキサイケンファンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G13910': FundCodeEntry(
        fund_code='G13910',
        sec_code=None,
        fund_name='マニュライフ・インベストメンツ・トラスト－ＵＳ・コア・フィクスド・インカム・ファンド',
        fund_name_yomi='マニュライフインベストメンツトラストユーエスコアフィクスドインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36012',
        issuer_name='マニュライフ・インベストメント・マネジメント（ＨＫ）リミテッド',
    ),
    'G13911': FundCodeEntry(
        fund_code='G13911',
        sec_code=None,
        fund_name='ＵＢＳグローバルＤＸ株式ファンド（資産成長型）',
        fund_name_yomi='ユービーエスグローバルディーエックスカブシキファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13912': FundCodeEntry(
        fund_code='G13912',
        sec_code=None,
        fund_name='ＵＢＳグローバルＤＸ株式ファンド（予想分配金提示型）',
        fund_name_yomi='ユービーエスグローバルディーエックスカブシキファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13913': FundCodeEntry(
        fund_code='G13913',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２０－１０',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイゼロイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13915': FundCodeEntry(
        fund_code='G13915',
        sec_code=None,
        fund_name='ニッセイ\u3000国内３資産\u3000高値参照型\u3000バランスファンド（安定型）／ニッセイ\u3000国内３資産\u3000高値参照型\u3000バランスファンド（積極型）',
        fund_name_yomi='ニッセイコクナイサンシサンタカネサンショウガタバランスファンドアンテイガタ\u3000ニッセイコクナイサンシサンタカネサンショウガタバランスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13916': FundCodeEntry(
        fund_code='G13916',
        sec_code=None,
        fund_name='ニッセイ日経２２５高値参照型アロケーションファンド',
        fund_name_yomi='ニッセイニッケイニニゴタカネサンショウガタアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13917': FundCodeEntry(
        fund_code='G13917',
        sec_code=None,
        fund_name='住友生命第２回劣後ローン流動化株式会社',
        fund_name_yomi='スミトモセイメイダイニカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36020',
        issuer_name='住友生命第２回劣後ローン流動化株式会社',
    ),
    'G13919': FundCodeEntry(
        fund_code='G13919',
        sec_code=None,
        fund_name='グローバル中小型株式ファンド',
        fund_name_yomi='グローバルチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G13920': FundCodeEntry(
        fund_code='G13920',
        sec_code=None,
        fund_name='ａｕＡＭ未来都市関連株式ファンド（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='エーユーエーエムミライトシカンレンカブシキファンド\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G13923': FundCodeEntry(
        fund_code='G13923',
        sec_code='26200',
        fund_name='ｉシェアーズ\u3000米国債１－３年\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイイチサンネン\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13924': FundCodeEntry(
        fund_code='G13924',
        sec_code='26210',
        fund_name='ｉシェアーズ\u3000米国債２０年超\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイニジュウネンチョウ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13925': FundCodeEntry(
        fund_code='G13925',
        sec_code='26220',
        fund_name='ｉシェアーズ\u3000米ドル建て新興国債券\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイドルダテシンコウコクサイケン\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13926': FundCodeEntry(
        fund_code='G13926',
        sec_code='26230',
        fund_name='ｉシェアーズ\u3000ユーロ建て投資適格社債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ユーロダテトウシテキカクシャサイ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13927': FundCodeEntry(
        fund_code='G13927',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000ダイナミック・マルチアセット戦略ファンド（年２回決算型）',
        fund_name_yomi='ピムコダイナミックマルチアセットセンリャクファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13928': FundCodeEntry(
        fund_code='G13928',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000ダイナミック・マルチアセット戦略ファンド（資産成長型）',
        fund_name_yomi='ピムコダイナミックマルチアセットセンリャクファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G13929': FundCodeEntry(
        fund_code='G13929',
        sec_code=None,
        fund_name='アクティブ・リート・ニッポン（毎月分配型／資産成長型）',
        fund_name_yomi='アクティブリートニッポンマイツキブンパイガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13930': FundCodeEntry(
        fund_code='G13930',
        sec_code=None,
        fund_name='グローバル・ハイブリッド証券ファンド（為替ヘッジあり）２０２０－１１（限定追加型）',
        fund_name_yomi='グローバルハイブリッドショウケンファンドカワセヘッジアリニセンニジュウノジュウイチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13931': FundCodeEntry(
        fund_code='G13931',
        sec_code=None,
        fund_name='グローバル債券ポートフォリオ（Ｂ）',
        fund_name_yomi='グローバルサイケンポートフォリオ\u3000ビー',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G13932': FundCodeEntry(
        fund_code='G13932',
        sec_code=None,
        fund_name='グローバル資産分散ポートフォリオ（Ｒ）',
        fund_name_yomi='グローバルシサンブンサンポートフォリオ\u3000アール',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G13933': FundCodeEntry(
        fund_code='G13933',
        sec_code=None,
        fund_name='グローバル複合戦略ポートフォリオ（Ｇ）',
        fund_name_yomi='グローバルフクゴウセンリャクポートフォリオ\u3000ジー',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G13934': FundCodeEntry(
        fund_code='G13934',
        sec_code=None,
        fund_name='野村環境リーダーズ戦略ファンド\u3000Ａコース、野村環境リーダーズ戦略ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラカンキョウリーダーズセンリャクファンドエーコース\u3000ノムラカンキョウリーダーズセンリャクファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13935': FundCodeEntry(
        fund_code='G13935',
        sec_code=None,
        fund_name='米国ＡＢＣ戦略ファンド（１倍コース／３倍コース／５倍コース）',
        fund_name_yomi='ベイコクエイビーシーセンリャクファンドイチバイコースサンバイコースゴバイコース',
        security_type='内国投資信託受益証券',
        period_1='4月4日',
        period_2='10月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13938': FundCodeEntry(
        fund_code='G13938',
        sec_code=None,
        fund_name='ＤＣニッセイおまかせバランスファンド（安定）',
        fund_name_yomi='ディーシーニッセイオマカセバランスファンドアンテイ',
        security_type='内国投資信託受益証券',
        period_1='12月24日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G13939': FundCodeEntry(
        fund_code='G13939',
        sec_code=None,
        fund_name='グローバル・モビリティ・サービス株式ファンド（年２回決算型）',
        fund_name_yomi='グローバル\u3000モビリティ\u3000サービスカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G13940': FundCodeEntry(
        fund_code='G13940',
        sec_code=None,
        fund_name='米国株式イントラデイ・トレンド戦略ファンド（ＳＭＡ専用）',
        fund_name_yomi='ベイコクカブシキイントラデイ\u3000トレンドセンリャクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13941': FundCodeEntry(
        fund_code='G13941',
        sec_code=None,
        fund_name='米国株式デイリートレンド戦略ファンド',
        fund_name_yomi='ベイコクカブシキデイリートレンドセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13942': FundCodeEntry(
        fund_code='G13942',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信\u3000米国株式ボラティリティ戦略（為替ヘッジなし）',
        fund_name_yomi='ペイペイトウシン\u3000ベイコクカブシキボラティリティセンリャク\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G13943': FundCodeEntry(
        fund_code='G13943',
        sec_code=None,
        fund_name='ブラックロック・世界株式インパクト投資ファンド（ＤＣ）',
        fund_name_yomi='ブラックロックセカイカブシキインパクトトウシファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G13944': FundCodeEntry(
        fund_code='G13944',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000グローバル・プレミアム株式オープン（為替ヘッジあり）予想分配金提示型／（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='モルガンスタンレーグローバルプレミアムカブシキオープンカワセヘッジアリヨソウブンパイキンテイジガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13945': FundCodeEntry(
        fund_code='G13945',
        sec_code=None,
        fund_name='ビルドアップ型\u3000ＭＳグローバル・プレミアム株式（為替ヘッジなし）２０２０－１１（限定追加型）',
        fund_name_yomi='ビルドアップガタエムエスグローバルプレミアムカブシキカワセヘッジナシニセンニジュウノジュウイチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13946': FundCodeEntry(
        fund_code='G13946',
        sec_code=None,
        fund_name='ＮＡＳＤＡＱ１００\u3000３倍ブル',
        fund_name_yomi='ナスダックヒャクサンバイブル',
        security_type='内国投資信託受益証券',
        period_1='10月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13947': FundCodeEntry(
        fund_code='G13947',
        sec_code=None,
        fund_name='ＮＡＳＤＡＱ１００\u3000３倍ベア',
        fund_name_yomi='ナスダックヒャクサンバイベア',
        security_type='内国投資信託受益証券',
        period_1='10月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13948': FundCodeEntry(
        fund_code='G13948',
        sec_code=None,
        fund_name='ＵＳリート・インデックス・ファンド（為替ヘッジなし／毎月分配型・資産成長型）',
        fund_name_yomi='ユーエスリートインデックスファンドカワセヘッジナシマイツキブンパイガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13949': FundCodeEntry(
        fund_code='G13949',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンド２０２０－１１',
        fund_name_yomi='ワンエンダテサイケンファンドニイゼロニイゼロイチイチ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G13950': FundCodeEntry(
        fund_code='G13950',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２０－１２（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニィゼロニィゼロイチニィゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13952': FundCodeEntry(
        fund_code='G13952',
        sec_code=None,
        fund_name='野村ハイパーブル・ベア８',
        fund_name_yomi='ノムラハイパーブルベアエイト',
        security_type='内国投資信託受益証券',
        period_1='10月13日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13953': FundCodeEntry(
        fund_code='G13953',
        sec_code=None,
        fund_name='ゴールドマン・サックス（ケイマン諸島）ユニット・トラスト－ｎｅｔＷＩＮ\u3000ＧＳテクノロジー株式ファンド',
        fund_name_yomi='ゴールドマンサックスケイマンショトウユニットトラストネットウィンジーエステクノロジーカブシキファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G13954': FundCodeEntry(
        fund_code='G13954',
        sec_code=None,
        fund_name='グローバルＥＳＧバランスファンド',
        fund_name_yomi='グローバルイーエスジーバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13957': FundCodeEntry(
        fund_code='G13957',
        sec_code=None,
        fund_name='メガトレンド・ロング・ショート・ファンド',
        fund_name_yomi='メガトレンドロングショートファンド',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13958': FundCodeEntry(
        fund_code='G13958',
        sec_code=None,
        fund_name='東京海上・厳選資産バランスファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウゲンセンシサンバランスファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13959': FundCodeEntry(
        fund_code='G13959',
        sec_code=None,
        fund_name='東京海上・厳選資産バランスファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウゲンセンシサンバランスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G13960': FundCodeEntry(
        fund_code='G13960',
        sec_code='26250',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＴＯＰＩＸ（年４回決算型）',
        fund_name_yomi='アイフリーイーティーエフトピックスネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13961': FundCodeEntry(
        fund_code='G13961',
        sec_code='26240',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経２２５（年４回決算型）',
        fund_name_yomi='アイフリーイーティーエフニッケイニイニイゴネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13962': FundCodeEntry(
        fund_code='G13962',
        sec_code=None,
        fund_name='ＨＳＢＣＥＳＧ米国株式インデックスファンド',
        fund_name_yomi='エイチエスビーシーイーエスジーベイコクカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G13963': FundCodeEntry(
        fund_code='G13963',
        sec_code=None,
        fund_name='京都企業株式ファンド（資産成長型）',
        fund_name_yomi='キョウトキギョウカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13964': FundCodeEntry(
        fund_code='G13964',
        sec_code=None,
        fund_name='京都企業株式ファンド（予想分配金提示型）',
        fund_name_yomi='キョウトキギョウカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13966': FundCodeEntry(
        fund_code='G13966',
        sec_code=None,
        fund_name='ＭＡＮ\u3000ＡＨＬ\u3000Ｄｉｖｅｒｓｉｆｉｅｄ\u3000リンクファンド（ＳＭＡ専用）',
        fund_name_yomi='エムエーエヌ\u3000エーエイチエル\u3000ダイバーシファイド\u3000リンクファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G13967': FundCodeEntry(
        fund_code='G13967',
        sec_code=None,
        fund_name='明治安田米国中小型成長株式ファンド（毎月決算・予想分配金提示型・為替ヘッジあり）／（毎月決算・予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='メイジヤスダベイコクチュウコガタセイチョウカブシキファンド\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ\u3000カワセヘッジアリ\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2='9月14日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13968': FundCodeEntry(
        fund_code='G13968',
        sec_code=None,
        fund_name='アムンディ・マルチセクター債券ファンド２０２０－１２（限定追加型）',
        fund_name_yomi='アムンディマルチセクターサイケンファンドニセンニジュウジュウニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月12日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G13969': FundCodeEntry(
        fund_code='G13969',
        sec_code=None,
        fund_name='第１２６回２０２５年９月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクニジュウロクカイニセンニジュウゴネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13971': FundCodeEntry(
        fund_code='G13971',
        sec_code=None,
        fund_name='ＵＢＳ\u3000ゴールド・ファンド（為替ヘッジあり）',
        fund_name_yomi='ユービーエス\u3000ゴールド\u3000ファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G13972': FundCodeEntry(
        fund_code='G13972',
        sec_code=None,
        fund_name='新成長株ファンド（隔月決算型・予想分配金提示型）',
        fund_name_yomi='シンセイチョウカブファンド\u3000カクゲツケッサンガタ\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13973': FundCodeEntry(
        fund_code='G13973',
        sec_code=None,
        fund_name='明治安田ＤＣ・ＴＯＰＩＸインデックスファンド',
        fund_name_yomi='メイジヤスダディーシートピックスインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G13974': FundCodeEntry(
        fund_code='G13974',
        sec_code=None,
        fund_name='野村ＤＣ・ＰＩＭＣＯ・世界インカム戦略ファンド（為替ヘッジなし）',
        fund_name_yomi='ノムラディーシーピムコセカイインカムセンリャクファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G13975': FundCodeEntry(
        fund_code='G13975',
        sec_code=None,
        fund_name='ダイワ／バリュー・パートナーズ\u3000チャイナ・ヘルスケア・フォーカス',
        fund_name_yomi='ダイワバリューパートナーズチャイナヘルスケアフォーカス',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13976': FundCodeEntry(
        fund_code='G13976',
        sec_code=None,
        fund_name='日興ワールド・トラスト－グローバル・トレーディング・オポチュニティ・ファンド',
        fund_name_yomi='ニッコウワールドトラストグローバルトレーディングオポチュニティファンド',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G13977': FundCodeEntry(
        fund_code='G13977',
        sec_code=None,
        fund_name='世界インフラ戦略ファンド（為替ヘッジなし／毎月分配型）',
        fund_name_yomi='セカイインフラセンリャクファンドカワセヘッジナシマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13978': FundCodeEntry(
        fund_code='G13978',
        sec_code=None,
        fund_name='世界インフラ戦略ファンド（為替ヘッジなし／資産成長型）',
        fund_name_yomi='セカイインフラセンリャクファンドカワセヘッジナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13979': FundCodeEntry(
        fund_code='G13979',
        sec_code=None,
        fund_name='世界Ｍ＆Ａ戦略株ファンド',
        fund_name_yomi='セカイエムアンドエーセンリャクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月1日',
        period_2='12月1日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13980': FundCodeEntry(
        fund_code='G13980',
        sec_code=None,
        fund_name='フィデリティ・ファンドラップ・シリーズ',
        fund_name_yomi='フィデリティファンドラップシリーズ',
        security_type='内国投資信託受益証券',
        period_1='8月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G13983': FundCodeEntry(
        fund_code='G13983',
        sec_code=None,
        fund_name='シンプレクス謳歌ファンド',
        fund_name_yomi='シンプレクスオウカファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G13984': FundCodeEntry(
        fund_code='G13984',
        sec_code=None,
        fund_name='資産形成応援ファンド',
        fund_name_yomi='シサンケイセイオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G13986': FundCodeEntry(
        fund_code='G13986',
        sec_code=None,
        fund_name='第１２８回２０２５年９月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクニジュウハチカイニセンニジュウゴネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G13988': FundCodeEntry(
        fund_code='G13988',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓ＆Ｐ５００インデックス',
        fund_name_yomi='イーマクシスエスアンドピーゴヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13989': FundCodeEntry(
        fund_code='G13989',
        sec_code=None,
        fund_name='トレンド・キャッチ戦略ファンド',
        fund_name_yomi='トレンドキャッチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G13990': FundCodeEntry(
        fund_code='G13990',
        sec_code=None,
        fund_name='グローバル・リート・アクティブファンド（ラップ向け）',
        fund_name_yomi='グローバルリートアクティブファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G13991': FundCodeEntry(
        fund_code='G13991',
        sec_code=None,
        fund_name='データ戦略分散ファンド',
        fund_name_yomi='データセンリャクブンサンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G13992': FundCodeEntry(
        fund_code='G13992',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・世界ＳＤＧｓ株式ファンド（資産成長型）、アライアンス・バーンスタイン・世界ＳＤＧｓ株式ファンド（予想分配金提示型）',
        fund_name_yomi='アライアンスバーンスタインセカイエスディージーズカブシキファンドシサンセイチョウガタ\u3000アライアンスバーンスタインセカイエスディージーズカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G13993': FundCodeEntry(
        fund_code='G13993',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバルＥＳＧ・社債ファンド２０２１－０２（限定追加型）',
        fund_name_yomi='アライアンスバーンスタイングローバルイーエスジーシャサイファンドニセンニジュウイチレイニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G13994': FundCodeEntry(
        fund_code='G13994',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２１‐０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイイチノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G13995': FundCodeEntry(
        fund_code='G13995',
        sec_code=None,
        fund_name='ブラックロック・グローバル・ファンズ－ＵＳドル・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ブラックロックグローバルファンズユーエスドルハイイールドボンドファンド',
        security_type='外国投資証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E31398',
        issuer_name='ブラックロック・グローバル・ファンズ',
    ),
    'G13996': FundCodeEntry(
        fund_code='G13996',
        sec_code=None,
        fund_name='ミローバ\u3000グローバル・サステナブル株式ファンド',
        fund_name_yomi='ミローバグローバルサステナブルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G13997': FundCodeEntry(
        fund_code='G13997',
        sec_code=None,
        fund_name='ＪＰモルガン・アメリカ成長株ファンド（為替ヘッジなし、年１回決算型）',
        fund_name_yomi='ジェイピーモルガンアメリカセイチョウカブファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13998': FundCodeEntry(
        fund_code='G13998',
        sec_code=None,
        fund_name='ＪＰモルガン・アメリカ成長株ファンド（為替ヘッジなし、毎月決算型）予想分配金提示型',
        fund_name_yomi='ジェイピーモルガンアメリカセイチョウカブファンドカワセヘッジナシマイツキケッサンガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G13999': FundCodeEntry(
        fund_code='G13999',
        sec_code=None,
        fund_name='ＪＰモルガン・アメリカ成長株ファンド（為替ヘッジあり、年１回決算型）',
        fund_name_yomi='ジェイピーモルガンアメリカセイチョウカブファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G14000': FundCodeEntry(
        fund_code='G14000',
        sec_code=None,
        fund_name='ＪＰモルガン・アメリカ成長株ファンド（為替ヘッジあり、毎月決算型）予想分配金提示型',
        fund_name_yomi='ジェイピーモルガンアメリカセイチョウカブファンドカワセヘッジアリマイツキケッサンガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G14001': FundCodeEntry(
        fund_code='G14001',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000エネルギー',
        fund_name_yomi='グランネクストエネルギー',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14002': FundCodeEntry(
        fund_code='G14002',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000テクノロジー',
        fund_name_yomi='グランネクストテクノロジー',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14003': FundCodeEntry(
        fund_code='G14003',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000フード',
        fund_name_yomi='グランネクストフード',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14004': FundCodeEntry(
        fund_code='G14004',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000ヘルスサイエンス',
        fund_name_yomi='グランネクストヘルスサイエンス',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14005': FundCodeEntry(
        fund_code='G14005',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000モビリティ',
        fund_name_yomi='グランネクストモビリティ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14006': FundCodeEntry(
        fund_code='G14006',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000マネープールファンド',
        fund_name_yomi='グランネクストマネープールファンド',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14007': FundCodeEntry(
        fund_code='G14007',
        sec_code=None,
        fund_name='日本超長期国債インデックスファンド（ラップ向け）',
        fund_name_yomi='ニホンチョウチョウキコクサイインデックスファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14008': FundCodeEntry(
        fund_code='G14008',
        sec_code=None,
        fund_name='東洋・中国Ａ株ファンド「創新」２０２１（限定追加型）',
        fund_name_yomi='トウヨウチュウゴクエーカブファンドソウシンニゼロニイチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14009': FundCodeEntry(
        fund_code='G14009',
        sec_code=None,
        fund_name='ＧＳ\u3000日本フォーカス・グロース\u3000マーケット・ニュートラル・コース',
        fund_name_yomi='ジーエス\u3000ニホンフォーカスグロース\u3000マーケットニュートラルコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14010': FundCodeEntry(
        fund_code='G14010',
        sec_code=None,
        fund_name='第６５回\u3000２０２３年２月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイロクジュウゴカイニセンニジュウサンネンニガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14012': FundCodeEntry(
        fund_code='G14012',
        sec_code=None,
        fund_name='ベイリー・ギフォード世界長期成長株ファンド（予想分配金提示型）',
        fund_name_yomi='ベイリーギフォードセカイチョウキセイチョウカブファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14013': FundCodeEntry(
        fund_code='G14013',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－アルジェブリス・フィナンシャル・ハイブリッド証券ファンド',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラストアルジェブリスフィナンシャルハイブリッドショウケンファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G14014': FundCodeEntry(
        fund_code='G14014',
        sec_code=None,
        fund_name='第６６回\u3000２０２６年２月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイロクジュウロクカイニセンニジュウロクネンニガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14015': FundCodeEntry(
        fund_code='G14015',
        sec_code=None,
        fund_name='第１３０回２０２５年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュッカイニセンニジュウゴネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14016': FundCodeEntry(
        fund_code='G14016',
        sec_code=None,
        fund_name='第１３１回２０２４年３月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウイッカイニセンニジュウヨネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14018': FundCodeEntry(
        fund_code='G14018',
        sec_code=None,
        fund_name='テトラ・ネクスト',
        fund_name_yomi='テトラネクスト',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14019': FundCodeEntry(
        fund_code='G14019',
        sec_code=None,
        fund_name='ＤＣニッセイおまかせバランスファンド（安定成長）',
        fund_name_yomi='ディーシーニッセイオマカセバランスファンドアンテイセイチョウ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14020': FundCodeEntry(
        fund_code='G14020',
        sec_code=None,
        fund_name='ＤＣニッセイおまかせバランスファンド（成長）',
        fund_name_yomi='ディーシーニッセイオマカセバランスファンドセイチョウ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14021': FundCodeEntry(
        fund_code='G14021',
        sec_code=None,
        fund_name='サイバーセキュリティ株式オープン（為替ヘッジあり）予想分配金提示型／（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='サイバーセキュリティカブシキオープンカワセヘッジアリヨソウブンパイキンテイジガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14022': FundCodeEntry(
        fund_code='G14022',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＮＡＳＤＡＱ次世代５０',
        fund_name_yomi='アイフリーネクストナスダックジセダイゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14023': FundCodeEntry(
        fund_code='G14023',
        sec_code=None,
        fund_name='野村インデックスファンド先進国ＥＳＧ株式',
        fund_name_yomi='ノムラインデックスファンドセンシンコクイーセスジー',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14024': FundCodeEntry(
        fund_code='G14024',
        sec_code=None,
        fund_name='ＭＦＳ米国中型成長株式ファンド（為替ヘッジあり）、ＭＦＳ米国中型成長株式ファンド（為替ヘッジなし）',
        fund_name_yomi='エムエフエスベイコクチュウガタセイチョウカブシキファンドカワセヘッジアリ\u3000エムエフエスベイコクチュウガタセイチョウカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14025': FundCodeEntry(
        fund_code='G14025',
        sec_code='26260',
        fund_name='グローバルＸ\u3000デジタル・イノベーション－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスデジタルイノベーションニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14026': FundCodeEntry(
        fund_code='G14026',
        sec_code='26270',
        fund_name='グローバルＸ\u3000ｅコマース－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスイーコマースニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14027': FundCodeEntry(
        fund_code='G14027',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000ＮＡＳＤＡＱ１００インデックス',
        fund_name_yomi='イーマクシスナスダックヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14028': FundCodeEntry(
        fund_code='G14028',
        sec_code=None,
        fund_name='ブラジル株式ファンド',
        fund_name_yomi='ブラジルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14029': FundCodeEntry(
        fund_code='G14029',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンド２０２１－０３',
        fund_name_yomi='ワンエンダテサイケンファンドニイゼロニイイチゼロサン',
        security_type='内国投資信託受益証券',
        period_1='12月29日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14030': FundCodeEntry(
        fund_code='G14030',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－インサイト・アルファ',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーインサイトアルファ',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G14031': FundCodeEntry(
        fund_code='G14031',
        sec_code=None,
        fund_name='第６７回\u3000２０２３年３月９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイロクジュウナナカイニセンニジュウサンネンサンガツココノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14032': FundCodeEntry(
        fund_code='G14032',
        sec_code=None,
        fund_name='第６８回\u3000２０２６年３月９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイロクジュウハチカイニセンニジュウロクネンサンガツココノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14033': FundCodeEntry(
        fund_code='G14033',
        sec_code=None,
        fund_name='ＧＳフューチャー・テクノロジー・リーダーズ\u3000Ｃコース（毎月決算・分配条件提示型・限定為替ヘッジ）／Ｄコース（毎月決算・分配条件提示型・為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000フューチャー\u3000テクノロジー\u3000リーダーズ\u3000シーコース\u3000マイツキケッサン\u3000ブンパイジョウケンテイジガタ\u3000ゲンテイカワセヘッジ\u3000ディーコース\u3000マイツキケッサン\u3000ブンパイジョウケンテイジガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14034': FundCodeEntry(
        fund_code='G14034',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000ＮＡＳＤＡＱ次世代５０',
        fund_name_yomi='アイフリーレバレッジナスダックジセダイゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月12日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14035': FundCodeEntry(
        fund_code='G14035',
        sec_code=None,
        fund_name='債券パワード・インカムファンド（毎月分配型）',
        fund_name_yomi='サイケンパワードインカムファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14036': FundCodeEntry(
        fund_code='G14036',
        sec_code=None,
        fund_name='債券パワード・インカムファンド（資産成長型）',
        fund_name_yomi='サイケンパワードインカムファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14037': FundCodeEntry(
        fund_code='G14037',
        sec_code='26290',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000中国グレーターベイエリア・イノベーション１００（ＧＢＡ１００）',
        fund_name_yomi='アイフリーイーティーエフチュウゴクグレーターベイエリアイノベーションヒャクジービーエーワンハンドレッド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14038': FundCodeEntry(
        fund_code='G14038',
        sec_code='26280',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000中国科創板５０（ＳＴＡＲ５０）',
        fund_name_yomi='アイフリーイーティーエフチュウゴクカソウバンゴジュウスターフィフティー',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14039': FundCodeEntry(
        fund_code='G14039',
        sec_code=None,
        fund_name='第１３２回２０２５年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウニカイニセンニジュウゴネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14040': FundCodeEntry(
        fund_code='G14040',
        sec_code=None,
        fund_name='第１３３回２０２４年３月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウサンカイニセンニジュウヨネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14042': FundCodeEntry(
        fund_code='G14042',
        sec_code=None,
        fund_name='第７０回\u3000２０２６年３月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュッカイニセンニジュウロクネンサンガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月30日',
        period_2='9月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14043': FundCodeEntry(
        fund_code='G14043',
        sec_code=None,
        fund_name='ダブル・ブレイン（マイルド）、ダブル・ブレイン（ブル）',
        fund_name_yomi='ダブルブレインマイルド\u3000ダブルブレインブル',
        security_type='内国投資信託受益証券',
        period_1='11月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14044': FundCodeEntry(
        fund_code='G14044',
        sec_code=None,
        fund_name='グローバル・ダイナミックヘッジα',
        fund_name_yomi='グローバル\u3000ダイナミックヘッジアルファ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14045': FundCodeEntry(
        fund_code='G14045',
        sec_code=None,
        fund_name='シュローダー・アジアパシフィックＥＳＧフォーカス・ファンド（予想分配金提示型）',
        fund_name_yomi='シュローダー\u3000アジアパシフィックイーエスジーフォーカス\u3000ファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G14046': FundCodeEntry(
        fund_code='G14046',
        sec_code=None,
        fund_name='インベスコ\u3000世界ブロックチェーン株式ファンド（予想分配金提示型）',
        fund_name_yomi='インベスコセカイブロックチェーンカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G14047': FundCodeEntry(
        fund_code='G14047',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２１ー０３',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウイチゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14048': FundCodeEntry(
        fund_code='G14048',
        sec_code='26320',
        fund_name='ＭＡＸＩＳナスダック１００上場投信（為替ヘッジあり）',
        fund_name_yomi='マクシスナスダックヒャクジョウジョウトウシンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14049': FundCodeEntry(
        fund_code='G14049',
        sec_code='26310',
        fund_name='ＭＡＸＩＳナスダック１００上場投信',
        fund_name_yomi='マクシスナスダックヒャクジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14050': FundCodeEntry(
        fund_code='G14050',
        sec_code='26300',
        fund_name='ＭＡＸＩＳ米国株式（Ｓ＆Ｐ５００）上場投信（為替ヘッジあり）',
        fund_name_yomi='マクシスベイコクカブシキエスアンドピーゴヒャクジョウジョウトウシンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14051': FundCodeEntry(
        fund_code='G14051',
        sec_code=None,
        fund_name='ブリオングロード・ブリッジ・ユニット・トラスト－ＤＭＳ償還時目標設定型ファンド２１０３（ゴールドマン・サックス社債投資型）',
        fund_name_yomi='ブリオングロードブリッジユニットトラストディーエムエスショウカンジモクヒョウセッテイガタファンドニイチマルサンゴールドマンサックスシャサイトウシガタ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35772',
        issuer_name='ウェイストーン・マネジメント・カンパニー（ＩＥ）リミテッド',
    ),
    'G14052': FundCodeEntry(
        fund_code='G14052',
        sec_code=None,
        fund_name='Ｓ＆Ｐ５００インデックスファンド（為替ヘッジあり）（ラップ向け）',
        fund_name_yomi='エスアンドピーゴヒャクインデックスファンドカワセヘッジアリラップムケ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14053': FundCodeEntry(
        fund_code='G14053',
        sec_code=None,
        fund_name='米国国債７―１０年ラダーファンド（為替ヘッジなし）（ラップ向け）',
        fund_name_yomi='ベイコクコクサイナナカラジュウネンラダーファンドカワセヘッジナシラップムケ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14054': FundCodeEntry(
        fund_code='G14054',
        sec_code=None,
        fund_name='ＥＳＧフォーカス\u3000コムジェスト・クオリティグロース・世界株式ファンド',
        fund_name_yomi='イーエスジーフォーカス\u3000コムジェスト\u3000クオリティグロース\u3000セカイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14055': FundCodeEntry(
        fund_code='G14055',
        sec_code=None,
        fund_name='ＥＳＧフォーカス\u3000コムジェスト・クオリティグロース・日本株式ファンド',
        fund_name_yomi='イーエスジーフォーカス\u3000コムジェスト\u3000クオリティグロース\u3000ニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14056': FundCodeEntry(
        fund_code='G14056',
        sec_code=None,
        fund_name='ポーレン米国グロース株式ファンド（資産成長型）',
        fund_name_yomi='ポーレンベイコクグロースカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2='9月28日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14057': FundCodeEntry(
        fund_code='G14057',
        sec_code=None,
        fund_name='第７２回\u3000２０２６年４月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウニカイニセンニジュウロクネンシガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14058': FundCodeEntry(
        fund_code='G14058',
        sec_code=None,
        fund_name='明治安田グローバル・マルチ戦略ファンド',
        fund_name_yomi='メイジヤスダグローバルマルチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14059': FundCodeEntry(
        fund_code='G14059',
        sec_code=None,
        fund_name='第７１回\u3000２０２３年４月１７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウイチカイニセンニジュウサンネンシガツジュウナナニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14060': FundCodeEntry(
        fund_code='G14060',
        sec_code=None,
        fund_name='野村ＤＣ未来トレンド発見ファンド',
        fund_name_yomi='ノムラディーシーミライトレンドハッケンファンド',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14061': FundCodeEntry(
        fund_code='G14061',
        sec_code=None,
        fund_name='マイターゲット２０６５（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンロクジュウゴカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14062': FundCodeEntry(
        fund_code='G14062',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信\u3000日経２２５インデックス',
        fund_name_yomi='ペイペイトウシン\u3000ニッケイニーニーゴインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14063': FundCodeEntry(
        fund_code='G14063',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信\u3000ＮＹダウインデックス',
        fund_name_yomi='ペイペイトウシン\u3000ニューヨークダウインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G14064': FundCodeEntry(
        fund_code='G14064',
        sec_code=None,
        fund_name='明治安田ウエリントン・世界イノベーション株式ファンド',
        fund_name_yomi='メイジヤスダウエリントンセカイイノベーションカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14065': FundCodeEntry(
        fund_code='G14065',
        sec_code=None,
        fund_name='ビルドアップ型\u3000ベイリー・ギフォード\u3000インパクト投資ファンド２０２１－０４（限定追加型）',
        fund_name_yomi='ビルドアップガタベイリーギフォードインパクトトウシファンドニセンニジュウイチゼロヨンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14067': FundCodeEntry(
        fund_code='G14067',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－アメリカン・インカム・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインアメリカンインカムポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G14068': FundCodeEntry(
        fund_code='G14068',
        sec_code=None,
        fund_name='まるごとひふみ１５、まるごとひふみ５０、まるごとひふみ１００',
        fund_name_yomi='マルゴトヒフミジュウゴマルゴトヒフミゴジュウマルゴトヒフミヒャク',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G14069': FundCodeEntry(
        fund_code='G14069',
        sec_code=None,
        fund_name='ひふみらいと',
        fund_name_yomi='ヒフミライト',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G14070': FundCodeEntry(
        fund_code='G14070',
        sec_code=None,
        fund_name='ピムコ・バミューダ・トラストＩＩ－ピムコ・バミューダ・インカム・ファンドＡ',
        fund_name_yomi='ピムコバミューダトラストツーピムコバミューダインカムファンドエー',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G14071': FundCodeEntry(
        fund_code='G14071',
        sec_code=None,
        fund_name='フランクリン・テンプルトン\u3000米国政府証券ファンド',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000ベイコクセイフショウケンファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G14072': FundCodeEntry(
        fund_code='G14072',
        sec_code=None,
        fund_name='テンプルトン・グローバル株式ファンド',
        fund_name_yomi='テンプルトン\u3000グローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G14073': FundCodeEntry(
        fund_code='G14073',
        sec_code=None,
        fund_name='テンプルトン世界債券ファンド\u3000限定為替ヘッジコース\u3000／\u3000テンプルトン世界債券ファンド\u3000為替ヘッジなしコース\u3000／\u3000テンプルトン世界債券ファンド\u3000毎月分配型・為替ヘッジなしコース',
        fund_name_yomi='テンプルトンセカイサイケンファンド\u3000ゲンテイカワセヘッジコース\u3000テンプルトンセカイサイケンファンド\u3000カワセヘッジナシコース\u3000テンプルトンセカイサイケンファンド\u3000マイツキブンパイガタ\u3000カワセヘッジナシコース',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G14074': FundCodeEntry(
        fund_code='G14074',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔティンバー',
        fund_name_yomi='アイトラストティンバー',
        security_type='内国投資信託受益証券',
        period_1='3月30日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14075': FundCodeEntry(
        fund_code='G14075',
        sec_code=None,
        fund_name='ＰＩＭＣＯファンズ：グローバル・インベスターズ・シリーズ・ピーエルシー－ＰＩＭＣＯアジア・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ピムコファンズグローバルインベスターズシリーズピーエルシーピムコアジアハイイールドボンドファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36483',
        issuer_name='ＰＩＭＣＯファンズ：グローバル・インベスターズ・シリーズ・ピーエルシー',
    ),
    'G14076': FundCodeEntry(
        fund_code='G14076',
        sec_code=None,
        fund_name='日本厳選株式ファンド',
        fund_name_yomi='ニホンゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14077': FundCodeEntry(
        fund_code='G14077',
        sec_code=None,
        fund_name='楽天・米国社債１－５年インデックス（為替ヘッジ）ファンド（ラップ向け）',
        fund_name_yomi='ラクテン\u3000ベイコクシャサイイチカラゴネンインデックス\u3000カワセヘッジ\u3000ファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14078': FundCodeEntry(
        fund_code='G14078',
        sec_code=None,
        fund_name='楽天・米国社債５－１０年インデックス（為替ヘッジ）ファンド（ラップ向け）',
        fund_name_yomi='ラクテン\u3000ベイコクシャサイゴカラジュウネンインデックス\u3000カワセヘッジ\u3000ファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14079': FundCodeEntry(
        fund_code='G14079',
        sec_code=None,
        fund_name='楽天・米国株式トレンドプラス・ファンド',
        fund_name_yomi='ラクテン\u3000ベイコクカブシキトレンドプラス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14080': FundCodeEntry(
        fund_code='G14080',
        sec_code=None,
        fund_name='第１３４回２０２５年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウヨンカイニセンニジュウゴネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14081': FundCodeEntry(
        fund_code='G14081',
        sec_code=None,
        fund_name='第１３５回２０２４年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウゴカイニセンニジュウヨネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14082': FundCodeEntry(
        fund_code='G14082',
        sec_code=None,
        fund_name='ＧＳ\u3000日本成長株集中投資ファンド（ＳＭＡ専用）',
        fund_name_yomi='ジーエス\u3000ニホンセイチョウカブシュウチュウトウシファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14083': FundCodeEntry(
        fund_code='G14083',
        sec_code=None,
        fund_name='しんきんＳ＆Ｐ５００インデックスファンド',
        fund_name_yomi='シンキンエスアンドピーゴヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14084': FundCodeEntry(
        fund_code='G14084',
        sec_code=None,
        fund_name='ベイリー・ギフォード\u3000インパクト投資ファンド（予想分配金提示型）',
        fund_name_yomi='ベイリーギフォードインパクトトウシファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14085': FundCodeEntry(
        fund_code='G14085',
        sec_code=None,
        fund_name='第７４回\u3000２０２６年４月２７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウヨンカイニセンニジュウロクネンシガツニジュウナナニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14086': FundCodeEntry(
        fund_code='G14086',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２１‐０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイイチノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14087': FundCodeEntry(
        fund_code='G14087',
        sec_code=None,
        fund_name='第７３回\u3000２０２３年４月２７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウサンカイニセンニジュウサンネンシガツニジュウナナニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国投資信託受益証券',
        period_1='4月27日',
        period_2='10月27日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14088': FundCodeEntry(
        fund_code='G14088',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＡＴＭＸ＋',
        fund_name_yomi='アイフリーネクストエーティーエムエックスプラス',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14089': FundCodeEntry(
        fund_code='G14089',
        sec_code=None,
        fund_name='アムンディ環境・気候変動対策ファンド',
        fund_name_yomi='アムンディカンキョウキコウヘンドウタイサクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G14090': FundCodeEntry(
        fund_code='G14090',
        sec_code='26330',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ\u3000５００\u3000指数（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーゴヒャクシスウカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14091': FundCodeEntry(
        fund_code='G14091',
        sec_code='26340',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ\u3000５００\u3000指数（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーゴヒャクシスウカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14092': FundCodeEntry(
        fund_code='G14092',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ\u3000５００スコアリング＆スクリーニング指数連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーゴヒャクスコアリングアンドスクリーニングシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14093': FundCodeEntry(
        fund_code='G14093',
        sec_code=None,
        fund_name='多資産分散投資ファンド（バランス１０）（確定拠出年金向け）',
        fund_name_yomi='タシサンブンサントウシファンドバランステンカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14094': FundCodeEntry(
        fund_code='G14094',
        sec_code=None,
        fund_name='次世代通信関連\u3000世界株式戦略ファンド（予想分配金提示型）',
        fund_name_yomi='ジセダイツウシンカンレン\u3000セカイカブシキセンリャクファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14095': FundCodeEntry(
        fund_code='G14095',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２１－Ⅰ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイイチノイチ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14096': FundCodeEntry(
        fund_code='G14096',
        sec_code=None,
        fund_name='Ｓ＆Ｐ５００（マルチアイ搭載）',
        fund_name_yomi='エスアンドピーゴヒャクマルチアイトウサイ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14097': FundCodeEntry(
        fund_code='G14097',
        sec_code=None,
        fund_name='ＮＡＳＤＡＱ１００トリプル（マルチアイ搭載）',
        fund_name_yomi='ナスダックヒャクトリプルマルチアイトウサイ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14098': FundCodeEntry(
        fund_code='G14098',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ世界ＥＳＧバランスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーセカイイーエスジーバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14099': FundCodeEntry(
        fund_code='G14099',
        sec_code=None,
        fund_name='知的資本日本株ファンド',
        fund_name_yomi='チテキシホンニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G14100': FundCodeEntry(
        fund_code='G14100',
        sec_code=None,
        fund_name='イノベーティブ・カーボンニュートラル戦略ファンド',
        fund_name_yomi='イノベーティブカーボンニュートラルセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14105': FundCodeEntry(
        fund_code='G14105',
        sec_code='26360',
        fund_name='グローバルＸ\u3000ＭＳＣＩ\u3000ガバナンス・クオリティ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエムエスシーアイガバナンスクオリティニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14106': FundCodeEntry(
        fund_code='G14106',
        sec_code='26370',
        fund_name='グローバルＸ\u3000クリーンテック－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスクリーンテックニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14107': FundCodeEntry(
        fund_code='G14107',
        sec_code=None,
        fund_name='デジタルヘルス株式ファンド',
        fund_name_yomi='デジタルヘルスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14108': FundCodeEntry(
        fund_code='G14108',
        sec_code=None,
        fund_name='ダイワ・ブルベア・ファンド６：ブル３倍日本株ポートフォリオ６、ベア２倍日本株ポートフォリオ６、ブルベア・マネー・ポートフォリオ６',
        fund_name_yomi='ダイワブルベアファンドシックスブルサンバイニホンカブポートフォリオシックスベアニバイニホンカブポートフォリオシックスブルベアマネーポートフォリオシックス',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14109': FundCodeEntry(
        fund_code='G14109',
        sec_code=None,
        fund_name='ＤＣ日本株式ＥＳＧセレクト・リーダーズインデックスファンド',
        fund_name_yomi='ディーシーニホンカブシキイーエスジーセレクト\u3000リーダーズインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14110': FundCodeEntry(
        fund_code='G14110',
        sec_code=None,
        fund_name='第７５回\u3000２０２３年５月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウゴカイニセンニジュウサンネンゴガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14111': FundCodeEntry(
        fund_code='G14111',
        sec_code=None,
        fund_name='第７６回\u3000２０２６年５月１８日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウロクカイニセンニジュウロクネンゴガツジュウハチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14112': FundCodeEntry(
        fund_code='G14112',
        sec_code=None,
        fund_name='グローバル・エクスポネンシャル・イノベーション・ファンド',
        fund_name_yomi='グローバル\u3000エクスポネンシャル\u3000イノベーション\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14113': FundCodeEntry(
        fund_code='G14113',
        sec_code=None,
        fund_name='グローバル・ディスラプター成長株ファンド（予想分配金提示型）',
        fund_name_yomi='グローバルディスラプターセイチョウカブファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14114': FundCodeEntry(
        fund_code='G14114',
        sec_code=None,
        fund_name='グローバル・ディスラプター成長株ファンド（資産成長型）',
        fund_name_yomi='グローバルディスラプターセイチョウカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14115': FundCodeEntry(
        fund_code='G14115',
        sec_code=None,
        fund_name='ニッセイ気候変動関連グローバル株式ファンド（予想分配金提示型）',
        fund_name_yomi='ニッセイキコウヘンドウカンレングローバルカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14116': FundCodeEntry(
        fund_code='G14116',
        sec_code=None,
        fund_name='ニッセイ気候変動関連グローバル株式ファンド（資産成長型）',
        fund_name_yomi='ニッセイキコウヘンドウカンレングローバルカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14117': FundCodeEntry(
        fund_code='G14117',
        sec_code=None,
        fund_name='マニュライフ・インベストメンツ・トラスト－ＵＳ・コア・フィクスド・インカム・ファンドクラスＡ（豪ドル建てヘッジあり）受益証券',
        fund_name_yomi='マニュライフインベストメンツトラストユーエスコアフィクスドインカムファンドクラスエーゴウドルダテヘッジアリジュエキショウケン',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36012',
        issuer_name='マニュライフ・インベストメント・マネジメント（ＨＫ）リミテッド',
    ),
    'G14118': FundCodeEntry(
        fund_code='G14118',
        sec_code=None,
        fund_name='ＳＢＩ国内大小成長株ファンド',
        fund_name_yomi='エスビーアイコクナイダイショウセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14119': FundCodeEntry(
        fund_code='G14119',
        sec_code=None,
        fund_name='日亜厳選ロング・ショート・ファンド',
        fund_name_yomi='ニチアゲンセンロングショートファンド',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14120': FundCodeEntry(
        fund_code='G14120',
        sec_code=None,
        fund_name='マクロテーマ・ロング・ショート・ファンド',
        fund_name_yomi='マクロテーマロングショートファンド',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14121': FundCodeEntry(
        fund_code='G14121',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ＥＶ２倍',
        fund_name_yomi='テーマレバレッジイーブイニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14122': FundCodeEntry(
        fund_code='G14122',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000中国ニューエコノミー２倍',
        fund_name_yomi='テーマレバレッジチュウゴクニューエコノミーニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14123': FundCodeEntry(
        fund_code='G14123',
        sec_code=None,
        fund_name='日本生命第６回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイロクカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E36583',
        issuer_name='日本生命第６回劣後ローン流動化株式会社',
    ),
    'G14124': FundCodeEntry(
        fund_code='G14124',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000国内株式',
        fund_name_yomi='ラップムケインデックスエフコクナイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14125': FundCodeEntry(
        fund_code='G14125',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000国内債券',
        fund_name_yomi='ラップムケインデックスエフコクナイサイケン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14126': FundCodeEntry(
        fund_code='G14126',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000国内リート',
        fund_name_yomi='ラップムケインデックスエフコクナイリート',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14127': FundCodeEntry(
        fund_code='G14127',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国株式',
        fund_name_yomi='ラップムケインデックスエフセンシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14128': FundCodeEntry(
        fund_code='G14128',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国債券',
        fund_name_yomi='ラップムケインデックスエフセンシンコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14129': FundCodeEntry(
        fund_code='G14129',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国リート',
        fund_name_yomi='ラップムケインデックスエフセンシンコクリート',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14130': FundCodeEntry(
        fund_code='G14130',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000新興国株式',
        fund_name_yomi='ラップムケインデックスエフシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14131': FundCodeEntry(
        fund_code='G14131',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000新興国債券',
        fund_name_yomi='ラップムケインデックスエフシンコウコクサイケン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14132': FundCodeEntry(
        fund_code='G14132',
        sec_code=None,
        fund_name='円建グローバル公社債ファンド',
        fund_name_yomi='エンダテグローバルコウシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14133': FundCodeEntry(
        fund_code='G14133',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンド２０２１－０５',
        fund_name_yomi='ワンエンダテサイケンファンドニイゼロニイイチゼロゴウ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14134': FundCodeEntry(
        fund_code='G14134',
        sec_code=None,
        fund_name='ユーロ建てハイブリッド証券ファンド（為替ヘッジあり）２０２１－０５（限定追加型）',
        fund_name_yomi='ユーロダテハイブリッドショウケンファンドカワセヘッジアリニセンニジュウイチノゴゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14135': FundCodeEntry(
        fund_code='G14135',
        sec_code=None,
        fund_name='第１３６回２０２６年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウロッカイニセンニジュウロクネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14136': FundCodeEntry(
        fund_code='G14136',
        sec_code=None,
        fund_name='第１３７回２０２４年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウナナカイニセンニジュウヨネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14137': FundCodeEntry(
        fund_code='G14137',
        sec_code=None,
        fund_name='ニッセイ新興国テクノロジー関連株式ファンド（予想分配金提示型）',
        fund_name_yomi='ニッセイシンコウコクテクノロジーカンレンカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14138': FundCodeEntry(
        fund_code='G14138',
        sec_code=None,
        fund_name='ニッセイ新興国テクノロジー関連株式ファンド（資産成長型）',
        fund_name_yomi='ニッセイシンコウコクテクノロジーカンレンカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14139': FundCodeEntry(
        fund_code='G14139',
        sec_code=None,
        fund_name='第７８回\u3000２０２６年６月３日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウハチカイニセンニジュウロクネンロクガツサンニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月3日',
        period_2='12月3日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14140': FundCodeEntry(
        fund_code='G14140',
        sec_code=None,
        fund_name='第７７回\u3000２０２３年６月５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウナナカイニセンニジュウサンネンロクガツイツカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月5日',
        period_2='12月5日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14141': FundCodeEntry(
        fund_code='G14141',
        sec_code=None,
        fund_name='パーインベスト（ルクセンブルグ）ＳＩＣＡＶ\u3000－\u3000ＣＰＳハーバー米国株式ファンド',
        fund_name_yomi='パーインベストルクセンブルグシキャブシーピーエスハーバーベイコクカブシキファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36502',
        issuer_name='パーインベスト（ルクセンブルグ）ＳＩＣＡＶ',
    ),
    'G14142': FundCodeEntry(
        fund_code='G14142',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000ＡＴＭＸ＋',
        fund_name_yomi='アイフリーレバレッジエーティーエムエックスプラス',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14143': FundCodeEntry(
        fund_code='G14143',
        sec_code=None,
        fund_name='デジタル・トランスフォーメーション株式ファンド（予想分配金提示型）',
        fund_name_yomi='デジタル\u3000トランスフォーメーションカブシキファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14144': FundCodeEntry(
        fund_code='G14144',
        sec_code=None,
        fund_name='脱炭素関連\u3000世界株式戦略ファンド（資産成長型）\u3000脱炭素関連\u3000世界株式戦略ファンド（予想分配金提示型）',
        fund_name_yomi='ダツタンソカンレンセカイカブシキセンリャクファンド\u3000シサンセイチョウガタ\u3000ダツタンソカンレンセカイカブシキセンリャクファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14145': FundCodeEntry(
        fund_code='G14145',
        sec_code=None,
        fund_name='ＰＩＭＣＯ\u3000グローバル・ターゲット戦略債券ファンド２０２１－０６（限定追加型）',
        fund_name_yomi='ピムコグローバルターゲットセンリャクサイケンファンドニイゼロニイイチゼロロクゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14146': FundCodeEntry(
        fund_code='G14146',
        sec_code=None,
        fund_name='第８０回\u3000２０２６年６月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュッカイニセンニジュウロクネンロクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14147': FundCodeEntry(
        fund_code='G14147',
        sec_code=None,
        fund_name='ＭＡＳＡＭＩＴＳＵ日本株戦略ファンド（ＤＣ向け）',
        fund_name_yomi='マサミツニホンカブセンリャクファンド\u3000ディーシームケ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G14148': FundCodeEntry(
        fund_code='G14148',
        sec_code=None,
        fund_name='第７９回\u3000２０２３年６月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイナナジュウキュウカイニセンニジュウサンネンロクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14149': FundCodeEntry(
        fund_code='G14149',
        sec_code='29890',
        fund_name='東海道リート投資法人',
        fund_name_yomi='トウカイドウリートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E36620',
        issuer_name='東海道リート投資法人',
    ),
    'G14150': FundCodeEntry(
        fund_code='G14150',
        sec_code=None,
        fund_name='日本大型株長期厳選投資',
        fund_name_yomi='ニホンオオガタカブチョウキゲンセントウシ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14151': FundCodeEntry(
        fund_code='G14151',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000クリーンテック',
        fund_name_yomi='イーマクシスネオクリーンテック',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14152': FundCodeEntry(
        fund_code='G14152',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000電気自動車',
        fund_name_yomi='イーマクシスネオデンキジドウシャ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14153': FundCodeEntry(
        fund_code='G14153',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔスマートシティ',
        fund_name_yomi='アイトラストスマートシティ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14154': FundCodeEntry(
        fund_code='G14154',
        sec_code=None,
        fund_name='パインブリッジ・デイリー・ミックス・オープン（為替ヘッジあり）（為替ヘッジなし）',
        fund_name_yomi='パインブリッジデイリーミックスオープンカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2='9月29日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G14155': FundCodeEntry(
        fund_code='G14155',
        sec_code=None,
        fund_name='シュローダー・グローバル・リートＥＳＧフォーカス・ファンド（予想分配金提示型）',
        fund_name_yomi='シュローダー\u3000グローバル\u3000リートイーエスジーフォーカス\u3000ファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G14156': FundCodeEntry(
        fund_code='G14156',
        sec_code=None,
        fund_name='シュローダー・グローバル・リートＥＳＧフォーカス・ファンド（資産成長型）',
        fund_name_yomi='シュローダー\u3000グローバル\u3000リートイーエスジーフォーカス\u3000ファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G14157': FundCodeEntry(
        fund_code='G14157',
        sec_code=None,
        fund_name='グローバルＧＸ関連株式ファンド',
        fund_name_yomi='グローバルジーエックスカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14158': FundCodeEntry(
        fund_code='G14158',
        sec_code=None,
        fund_name='ＵＢＳ気候変動関連グローバル成長株式ファンド（年４回決算・予想分配金提示型）',
        fund_name_yomi='ユービーエスキコウヘンドウカンレングローバルセイチョウカブシキファンド\u3000ネンヨンカイケッサン\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G14159': FundCodeEntry(
        fund_code='G14159',
        sec_code=None,
        fund_name='グローバルＡＺファンド\u3000Ａコース／グローバルＡＺファンド\u3000Ｂコース／グローバルＡＺファンド\u3000Ｃコース／グローバルＡＺファンド\u3000Ｄコース／グローバルＡＺファンド\u3000Ｅコース',
        fund_name_yomi='グローバルエーゼットファンド\u3000エーコース\u3000グローバルエーゼットファンド\u3000ビーコース\u3000グローバルエーゼットファンド\u3000シーコース\u3000グローバルエーゼットファンド\u3000ディーコース\u3000グローバルエーゼットファンド\u3000イーコース',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14160': FundCodeEntry(
        fund_code='G14160',
        sec_code=None,
        fund_name='第１３８回２０２６年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウハッカイニセンニジュウロクネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14161': FundCodeEntry(
        fund_code='G14161',
        sec_code=None,
        fund_name='第１３９回２０２４年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクサンジュウキュウカイニセンニジュウヨネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14162': FundCodeEntry(
        fund_code='G14162',
        sec_code=None,
        fund_name='アジアＧＸ関連株式ファンド',
        fund_name_yomi='アジアジーエックスカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月12日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14163': FundCodeEntry(
        fund_code='G14163',
        sec_code=None,
        fund_name='しんきんＵＳバランス・プラスゴールド（１年決算型）',
        fund_name_yomi='シンキンユーエスバランスプラスゴールドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14165': FundCodeEntry(
        fund_code='G14165',
        sec_code=None,
        fund_name='米国株式トレンド・ウォッチ戦略ファンド',
        fund_name_yomi='ベイコクカブシキトレンドウォッチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='5月13日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14166': FundCodeEntry(
        fund_code='G14166',
        sec_code=None,
        fund_name='グリーン・テクノロジー株式ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='グリーンテクノロジーカブシキファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14168': FundCodeEntry(
        fund_code='G14168',
        sec_code=None,
        fund_name='ウォルター・スコット優良成長企業ファンド（資産成長型）',
        fund_name_yomi='ウォルタースコットユウリョウセイチョウキギョウファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14169': FundCodeEntry(
        fund_code='G14169',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ＤＸ２倍',
        fund_name_yomi='テーマレバレッジディーエックスニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14170': FundCodeEntry(
        fund_code='G14170',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ゲーム＆ｅスポーツ２倍',
        fund_name_yomi='テーマレバレッジゲームアンドイースポーツニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14171': FundCodeEntry(
        fund_code='G14171',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ｅコマース２倍',
        fund_name_yomi='テーマレバレッジイーコマースニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14172': FundCodeEntry(
        fund_code='G14172',
        sec_code=None,
        fund_name='第８１回\u3000２０２６年６月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウイチカイニセンニジュウロクネンロクガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月30日',
        period_2='12月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14173': FundCodeEntry(
        fund_code='G14173',
        sec_code=None,
        fund_name='第８２回\u3000２０２６年６月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウニカイニセンニジュウロクネンロクガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月30日',
        period_2='12月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14174': FundCodeEntry(
        fund_code='G14174',
        sec_code=None,
        fund_name='ＭＵＦＧ\u3000ウェルス・インサイト・ファンド（保守型）（標準型）（積極型）（マネープール）',
        fund_name_yomi='エムユーエフジーウェルスインサイトファンドホシュガタヒョウジュンガタセッキョクガタマネープール',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14175': FundCodeEntry(
        fund_code='G14175',
        sec_code=None,
        fund_name='ＵＢＳ\u3000（Ｉｒｌ）\u3000ＥＴＦ\u3000ピーエルシー－ＭＳＣＩ\u3000ＡＣＷＩ\u3000ソーシャリー・レスポンシブル\u3000ＵＣＩＴＳ\u3000ＥＴＦ',
        fund_name_yomi='ユービーエスアイアールエルイーティーエフピーエルシーエムエスシーアイエーシーダブリューアイソーシャリーレスポンシブルユーシッツイーティーエフ',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33922',
        issuer_name='ＵＢＳ（Ｉｒｌ）ＥＴＦ\u3000ピーエルシー',
    ),
    'G14176': FundCodeEntry(
        fund_code='G14176',
        sec_code=None,
        fund_name='フォーカス・シキャブ－ＵＳコーポレート・ボンド・サステナブル・米ドル\u3000クラスＦ－ａｃｃ投資証券\u3000－ワールドバンク・ロング・ターム・ボンド・米ドル\u3000クラスＦ－ａｃｃ投資証券',
        fund_name_yomi='フォーカスシキャブユーエスコーポレートボンドサステナブルベイドルクラスエフエーシーシートウシショウケンワールドバンクロングタームボンドベイドルクラスエフエーシーシートウシショウケン',
        security_type='外国投資証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E32015',
        issuer_name='フォーカス・シキャブ',
    ),
    'G14177': FundCodeEntry(
        fund_code='G14177',
        sec_code=None,
        fund_name='グローバル・オポチュニティーズ・アクセス－サステナブル・ボンド\u3000クラスＦ－ａｃｃ投資証券\u3000－サステナブル・エクイティ\u3000クラスＦ－ａｃｃ投資証券',
        fund_name_yomi='グローバルオポチュニティーズアクセス\u3000サステナブルボンドクラスエフエーシーシートウシショウケン\u3000サステナブルエクイティクラスエフエーシーシートウシショウケン',
        security_type='外国投資証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E32021',
        issuer_name='グローバル・オポチュニティーズ・アクセス',
    ),
    'G14178': FundCodeEntry(
        fund_code='G14178',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・全米株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ゼンベイカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14179': FundCodeEntry(
        fund_code='G14179',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国高配当株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ベイコクコウハイトウカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14180': FundCodeEntry(
        fund_code='G14180',
        sec_code=None,
        fund_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー－フェデレーテッド・ハーミーズ・グローバル・ＳＭＩＤエクイティ・エンゲージメント・ファンド／フェデレーテッド・ハーミーズ・グローバル・ハイ・イールド・クレジット・エンゲージメント・ファンド',
        fund_name_yomi='フェデレーテッドハーミーズインベストメントファンズピーエルシーフェデレーテッドハーミーズグローバルエスエムアイディーエクイティエンゲージメントファンドフェデレーテッドハーミーズグローバルハイイールドクレジットエンゲージメントファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36684',
        issuer_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー',
    ),
    'G14181': FundCodeEntry(
        fund_code='G14181',
        sec_code=None,
        fund_name='第８３回\u3000２０２４年７月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウサンカイニセンニジュウヨネンシチガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14182': FundCodeEntry(
        fund_code='G14182',
        sec_code=None,
        fund_name='東京海上・再生可能エネルギー・インカム戦略ファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウサイセイカノウエネルギーインカムセンリャクファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14183': FundCodeEntry(
        fund_code='G14183',
        sec_code=None,
        fund_name='東京海上・再生可能エネルギー・インカム戦略ファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウサイセイカノウエネルギーインカムセンリャクファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14184': FundCodeEntry(
        fund_code='G14184',
        sec_code=None,
        fund_name='グローバル・スペース株式ファンド（年２回決算型）',
        fund_name_yomi='グローバル\u3000スペースカブシキファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14185': FundCodeEntry(
        fund_code='G14185',
        sec_code=None,
        fund_name='グローバル・スペース株式ファンド（為替ヘッジあり・１年決算型）',
        fund_name_yomi='グローバル\u3000スペースカブシキファンド\u3000カワセヘッジアリ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14186': FundCodeEntry(
        fund_code='G14186',
        sec_code=None,
        fund_name='グローバル・スペース株式ファンド（為替ヘッジあり・年２回決算型）',
        fund_name_yomi='グローバル\u3000スペースカブシキファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14187': FundCodeEntry(
        fund_code='G14187',
        sec_code=None,
        fund_name='日本株式インパクト投資ファンド',
        fund_name_yomi='ニホンカブシキインパクトトウシファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14188': FundCodeEntry(
        fund_code='G14188',
        sec_code=None,
        fund_name='ハリス\u3000グローバル\u3000バリュー株ファンド（資産成長型）',
        fund_name_yomi='ハリスグローバルバリューカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G14189': FundCodeEntry(
        fund_code='G14189',
        sec_code=None,
        fund_name='楽天・資産づくりファンド（のんびりコース）／楽天・資産づくりファンド（じっくりコース）／楽天・資産づくりファンド（なかなかコース）／楽天・資産づくりファンド（しっかりコース）／楽天・資産づくりファンド（がっちりコース）',
        fund_name_yomi='ラクテン\u3000シサンヅクリファンド\u3000ノンビリコース\u3000ラクテン\u3000シサンヅクリファンド\u3000ジックリコース\u3000ラクテン\u3000シサンヅクリファンド\u3000ナカナカコース\u3000ラクテン\u3000シサンヅクリファンド\u3000シッカリコース\u3000ラクテン\u3000シサンヅクリファンド\u3000ガッチリコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14190': FundCodeEntry(
        fund_code='G14190',
        sec_code=None,
        fund_name='第８４回\u3000２０２６年７月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウヨンカイニセンニジュウロクネンナナガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14191': FundCodeEntry(
        fund_code='G14191',
        sec_code='26420',
        fund_name='ＳＭＴ\u3000ＥＴＦカーボン・エフィシェント日本株',
        fund_name_yomi='エスエムティー\u3000イーティーエフカーボン\u3000エフィシェントニホンカブ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14192': FundCodeEntry(
        fund_code='G14192',
        sec_code=None,
        fund_name='みらいコネクトファンド',
        fund_name_yomi='ミライコネクトファンド',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G14193': FundCodeEntry(
        fund_code='G14193',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ－オール・チャイナ（米ドル）',
        fund_name_yomi='ユービーエスルクスエクイティシキャブオールチャイナベイドル',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E30637',
        issuer_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ',
    ),
    'G14194': FundCodeEntry(
        fund_code='G14194',
        sec_code=None,
        fund_name='グローバル５．５倍バランスファンド（予想分配金提示型）',
        fund_name_yomi='グローバルゴウテンゴバイバランスファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14195': FundCodeEntry(
        fund_code='G14195',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２１‐０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイイチノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14196': FundCodeEntry(
        fund_code='G14196',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ヘルステック２倍',
        fund_name_yomi='テーマレバレッジ\u3000ヘルステックニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14197': FundCodeEntry(
        fund_code='G14197',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000クリーンテック２倍',
        fund_name_yomi='テーマレバレッジ\u3000クリーンテックニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14198': FundCodeEntry(
        fund_code='G14198',
        sec_code=None,
        fund_name='テーマレバレッジ\u3000ブロックチェーン２倍',
        fund_name_yomi='テーマレバレッジ\u3000ブロックチェーンニバイ',
        security_type='内国投資信託受益証券',
        period_1='3月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14199': FundCodeEntry(
        fund_code='G14199',
        sec_code=None,
        fund_name='グローバルＥＳＧ株式インデックスファンド',
        fund_name_yomi='グローバルイーエスジーカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G14200': FundCodeEntry(
        fund_code='G14200',
        sec_code='26380',
        fund_name='グローバルＸ\u3000ロボティクス＆ＡＩ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスロボティクスアンドエーアイニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14201': FundCodeEntry(
        fund_code='G14201',
        sec_code='26390',
        fund_name='グローバルＸ\u3000バイオ＆メドテック－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスバイオアンドメドテックニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14202': FundCodeEntry(
        fund_code='G14202',
        sec_code='26400',
        fund_name='グローバルＸ\u3000ゲーム＆アニメ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスゲームアンドアニメニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14203': FundCodeEntry(
        fund_code='G14203',
        sec_code=None,
        fund_name='第１４０回２０２６年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュッカイニセンニジュウロクネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14204': FundCodeEntry(
        fund_code='G14204',
        sec_code=None,
        fund_name='第１４１回２０２４年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウイッカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14205': FundCodeEntry(
        fund_code='G14205',
        sec_code='26410',
        fund_name='グローバルＸ\u3000グローバルリーダーズ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスグローバルリーダーズニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14206': FundCodeEntry(
        fund_code='G14206',
        sec_code=None,
        fund_name='第８６回\u3000２０２６年７月２７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウロクカイニセンニジュウロクネンシチガツニジュウシチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14207': FundCodeEntry(
        fund_code='G14207',
        sec_code=None,
        fund_name='第８５回\u3000２０２３年７月２６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウゴカイニセンニジュウサンネンシチガツニジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14208': FundCodeEntry(
        fund_code='G14208',
        sec_code=None,
        fund_name='ＤＣ外国株式ＥＳＧリーダーズインデックスファンド',
        fund_name_yomi='ディーシーガイコクカブシキイーエスジーリーダーズインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14209': FundCodeEntry(
        fund_code='G14209',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信\u3000ＮＡＳＤＡＱ１００インデックス',
        fund_name_yomi='ペイペイトウシン\u3000ナスダックヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G14210': FundCodeEntry(
        fund_code='G14210',
        sec_code=None,
        fund_name='シュローダー先進国債券ファンド２０２１ー０７（限定追加型）',
        fund_name_yomi='シュローダーセンシンコクサイケンファンドニィゼロニィイチ\u3000ゼロナナ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G14212': FundCodeEntry(
        fund_code='G14212',
        sec_code=None,
        fund_name='ＤＣ世界株式・厳選投資ファンド',
        fund_name_yomi='ディーシーセカイカブシキ\u3000ゲンセントウシファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14213': FundCodeEntry(
        fund_code='G14213',
        sec_code=None,
        fund_name='投資のソムリエ（ターゲット・イヤー２０６５）',
        fund_name_yomi='トウシノソムリエターゲットイヤーニイゼロロクゴウ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14214': FundCodeEntry(
        fund_code='G14214',
        sec_code=None,
        fund_name='第８７回\u3000２０２４年８月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウナナカイニセンニジュウヨネンハチガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14215': FundCodeEntry(
        fund_code='G14215',
        sec_code=None,
        fund_name='東洋ベトナム株式ファンド２０２１',
        fund_name_yomi='トウヨウベトナムカブシキファンドニセンニジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='8月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14216': FundCodeEntry(
        fund_code='G14216',
        sec_code=None,
        fund_name='フィデリティ外国債券アクティブ・セレクト・ファンド（ＳＭＡ専用）',
        fund_name_yomi='フィデリティガイコクサイケンアクティブセレクトファンドエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='4月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14217': FundCodeEntry(
        fund_code='G14217',
        sec_code=None,
        fund_name='脱炭素テクノロジー株式ファンド',
        fund_name_yomi='ダツタンソテクノロジーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14218': FundCodeEntry(
        fund_code='G14218',
        sec_code=None,
        fund_name='明治安田生命第１回劣後ローン流動化株式会社',
        fund_name_yomi='メイジヤスダセイメイダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36775',
        issuer_name='明治安田生命第１回劣後ローン流動化株式会社',
    ),
    'G14220': FundCodeEntry(
        fund_code='G14220',
        sec_code=None,
        fund_name='ＳＢＩ・中国Ａ株インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000チュウゴクエイカブ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14221': FundCodeEntry(
        fund_code='G14221',
        sec_code=None,
        fund_name='第８８回\u3000２０２６年８月１７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウハチカイニセンニジュウロクネンハチガツジュウシチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14222': FundCodeEntry(
        fund_code='G14222',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ムーンショットインデックス',
        fund_name_yomi='アイフリーネクストムーンショットインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14223': FundCodeEntry(
        fund_code='G14223',
        sec_code='26430',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＭＳＣＩジャパンカントリー指数（セレクト）連動型上場投信',
        fund_name_yomi='ネクストファンズエムエスシーアイジャパンカントリーシスウセレクトレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14224': FundCodeEntry(
        fund_code='G14224',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000ゴールドファンド（為替ヘッジなし）、Ｓｍａｒｔ－ｉ\u3000ゴールドファンド（為替ヘッジあり）',
        fund_name_yomi='スマート\u3000アイ\u3000ゴールドファンド\u3000カワセヘッジナシ\u3000スマート\u3000アイ\u3000ゴールドファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14225': FundCodeEntry(
        fund_code='G14225',
        sec_code=None,
        fund_name='りそな日経２２５インデックス',
        fund_name_yomi='リソナニッケイニーニーゴーインデックス',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14226': FundCodeEntry(
        fund_code='G14226',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン渋谷神南（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンシブヤジンナンジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14227': FundCodeEntry(
        fund_code='G14227',
        sec_code=None,
        fund_name='ブラックロック・フィクスド・インカム・ダブリン・ファンズ\u3000ｐｌｃ－ｉシェアーズ・グリーンボンド・インデックス・ファンドクラスＤ米ドルヘッジ投資証券',
        fund_name_yomi='ブラックロックフィクスドインカムダブリンファンズピーエルシーアイシェアーズグリーンボンドインデックスファンドクラスディーベイドルヘッジトウシショウケン',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36699',
        issuer_name='ブラックロック・フィクスド・インカム・ダブリン・ファンズ\u3000ｐｌｃ',
    ),
    'G14228': FundCodeEntry(
        fund_code='G14228',
        sec_code=None,
        fund_name='第１４２回２０２６年６月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウニカイニセンニジュウロクネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14229': FundCodeEntry(
        fund_code='G14229',
        sec_code=None,
        fund_name='第１４３回２０２４年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウサンカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14230': FundCodeEntry(
        fund_code='G14230',
        sec_code=None,
        fund_name='日本生命２０２１基金流動化株式会社',
        fund_name_yomi='ニホンセイメイニセンニジュウイチキキンリュウドウカカブシキカイシャ',
        security_type='内国資産流動化証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E36827',
        issuer_name='日本生命２０２１基金流動化株式会社',
    ),
    'G14231': FundCodeEntry(
        fund_code='G14231',
        sec_code=None,
        fund_name='フィデリティ・アクティブ・グロース・ファンド（確定拠出年金向け）',
        fund_name_yomi='フィデリティアクティブグロースファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14232': FundCodeEntry(
        fund_code='G14232',
        sec_code=None,
        fund_name='フィデリティ・世界割安成長株投信（確定拠出年金向け）',
        fund_name_yomi='フィデリティセカイワリヤスセイチョウカブトウシンカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14233': FundCodeEntry(
        fund_code='G14233',
        sec_code=None,
        fund_name='日興ファンドラップセレクトインデックス・シリーズ',
        fund_name_yomi='ニッコウファンドラップセレクトインデックスシリーズ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14234': FundCodeEntry(
        fund_code='G14234',
        sec_code=None,
        fund_name='日興ＦＷＳ・新興国債インデックス（為替ヘッジあり）／新興国債インデックス（為替ヘッジなし）／ゴールド（為替ヘッジあり）／ゴールド（為替ヘッジなし）',
        fund_name_yomi='ニッコウファンドラップセレクトシンコウコクサイインデックスカワセヘッジアリ\u3000シンコウコクサイインデックスカワセヘッジナシ\u3000ゴールドカワセヘッジアリ\u3000ゴールドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14235': FundCodeEntry(
        fund_code='G14235',
        sec_code=None,
        fund_name='日興ファンドラップセレクトアクティブ・シリーズ',
        fund_name_yomi='ニッコウファンドラップセレクトアクティブシリーズ',
        security_type='内国投資信託受益証券',
        period_1='7月31日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14236': FundCodeEntry(
        fund_code='G14236',
        sec_code=None,
        fund_name='未来フォーカス企業債ファンド（為替ヘッジあり）（年２回決算型）',
        fund_name_yomi='ミライフォーカスキギョウサイファンド\u3000カワセヘッジアリ\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14237': FundCodeEntry(
        fund_code='G14237',
        sec_code=None,
        fund_name='第８９回\u3000２０２３年８月２８日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイハチジュウキュウカイニセンニジュウサンネンハチガツニジュウハチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月28日',
        period_2='8月28日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14238': FundCodeEntry(
        fund_code='G14238',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバルＥＳＧ・社債ファンド２０２１－０９（限定追加型）',
        fund_name_yomi='アライアンスバーンスタイングローバルイーエスジーシャサイファンドニセンニジュウイチレイキューゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14239': FundCodeEntry(
        fund_code='G14239',
        sec_code=None,
        fund_name='第９０回\u3000２０２６年８月２６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウカイニセンニジュウロクネンハチガツニジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14241': FundCodeEntry(
        fund_code='G14241',
        sec_code=None,
        fund_name='グローバル水素株式ファンド',
        fund_name_yomi='グローバルスイソカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月18日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14242': FundCodeEntry(
        fund_code='G14242',
        sec_code=None,
        fund_name='第９１回\u3000２０２４年９月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウイチカイニセンニジュウヨネンクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14243': FundCodeEntry(
        fund_code='G14243',
        sec_code=None,
        fund_name='ＳＭＴＡＭヘッジ付き外国国債・スマートベータ・ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='エスエムティーエーエムヘッジツキガイコクコクサイ\u3000スマートベータ\u3000ファンド\u3000ノムラエスエムエー\u3000イーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14244': FundCodeEntry(
        fund_code='G14244',
        sec_code=None,
        fund_name='ＵＢＳ\u3000（Ｉｒｌ）\u3000ＥＴＦ\u3000ピーエルシー－ＭＳＣＩ\u3000ＡＣＷＩ\u3000ソーシャリー・レスポンシブル\u3000ＵＣＩＴＳ\u3000ＥＴＦ－クラス（日本円ヘッジ）Ａ－ａｃｃ投資証券',
        fund_name_yomi='ユービーエスアイアールエルイーティーエフピーエルシーエムエスシーアイエーシーダブリューアイソーシャリーレスポンシブルユーシッツイーティーエフクラスニホンエンヘッジエーエーシーシートウシショウケン',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E33922',
        issuer_name='ＵＢＳ（Ｉｒｌ）ＥＴＦ\u3000ピーエルシー',
    ),
    'G14245': FundCodeEntry(
        fund_code='G14245',
        sec_code=None,
        fund_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー－フェデレーテッド・ハーミーズ・ＳＤＧエンゲージメント・エクイティ・ファンド－クラスＸ円ヘッジ投資証券',
        fund_name_yomi='フェデレーテッドハーミーズインベストメントファンズピーエルシーフェデレーテッドハーミーズエスディージーエンゲージメントエクイティファンドクラスエックスエンヘッジトウシショウケン',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36684',
        issuer_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー',
    ),
    'G14246': FundCodeEntry(
        fund_code='G14246',
        sec_code=None,
        fund_name='明治安田ＤＣ・ＪーＲＥＩＴアクティブ',
        fund_name_yomi='メイジヤスダディーシージェイリートアクティブ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14247': FundCodeEntry(
        fund_code='G14247',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンド２０２１－０９',
        fund_name_yomi='ワンエンダテサイケンファンドニイゼロニイイチゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='7月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14248': FundCodeEntry(
        fund_code='G14248',
        sec_code=None,
        fund_name='グローバル・オポチュニティーズ・アクセス－サステナブル・ボンド\u3000クラスＦ－ａｃｃ円ヘッジ投資証券\u3000－サステナブル・エクイティ\u3000クラスＦ－ａｃｃ円ヘッジ投資証券',
        fund_name_yomi='グローバルオポチュニティーズアクセスサステナブルボンドクラスエフエーシーシーエンヘッジトウシショウケンサステナブルエクイティクラスエフエーシーシーエンヘッジトウシショウケン',
        security_type='外国投資証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E32021',
        issuer_name='グローバル・オポチュニティーズ・アクセス',
    ),
    'G14249': FundCodeEntry(
        fund_code='G14249',
        sec_code=None,
        fund_name='フォーカス・シキャブ－ＵＳコーポレート・ボンド・サステナブル・米ドル\u3000クラス円ヘッジＦ－ａｃｃ投資証券',
        fund_name_yomi='フォーカスシキャブユーエスコーポレートボンドサステナブルベイドルクラスエンヘッジエフエーシーシートウシショウケン',
        security_type='外国投資証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E32015',
        issuer_name='フォーカス・シキャブ',
    ),
    'G14250': FundCodeEntry(
        fund_code='G14250',
        sec_code=None,
        fund_name='世の中を良くする企業ファンド（野村日本株ＥＳＧ投資）',
        fund_name_yomi='ヨノナカヲヨクスルキギョウファンドノムラニホンカブイーエスジートウシ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14251': FundCodeEntry(
        fund_code='G14251',
        sec_code=None,
        fund_name='ブラックロック・グローバル・ファンズ－ネクスト・ジェネレーション・テクノロジー・ファンド／－ＵＳドル・ハイ・イールド・ボンド・ファンド',
        fund_name_yomi='ブラックロックグローバルファンズネクストジェネレーションテクノロジーファンドユーエスドルハイイールドボンドファンド',
        security_type='外国投資証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E31398',
        issuer_name='ブラックロック・グローバル・ファンズ',
    ),
    'G14252': FundCodeEntry(
        fund_code='G14252',
        sec_code=None,
        fund_name='フィデリティ世界バリュー株式ファンド\u3000Ａコース（年２回決算・為替ヘッジあり）\u3000フィデリティ世界バリュー株式ファンド\u3000Ｂコース（年２回決算・為替ヘッジなし）\u3000フィデリティ世界バリュー株式ファンド\u3000Ｃコース（毎月決算・予想分配金提示型・為替ヘッジあり）\u3000フィデリティ世界バリュー株式ファンド\u3000Ｄコース（毎',
        fund_name_yomi='フィデリティセカイバリューカブシキファンドエーコースネンニカイケッサンカワセヘッジアリ\u3000フィデリティセカイバリューカブシキファンドビーコースネンニカイケッサンカワセヘッジナシ\u3000フィデリティセカイバリューカブシキファンドシーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジアリ\u3000フィデリティセカイバリューカブシキファンドディーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14253': FundCodeEntry(
        fund_code='G14253',
        sec_code=None,
        fund_name='ダイワファンドラップ\u3000債券総合戦略セレクト、ダイワファンドラップ\u3000複合資産戦略セレクト',
        fund_name_yomi='ダイワファンドラップ\u3000サイケンソウゴウセンリャクセレクトダイワファンドラップ\u3000フクゴウシサンセンリャクセレクト',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14254': FundCodeEntry(
        fund_code='G14254',
        sec_code=None,
        fund_name='第９２回\u3000２０２３年９月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウニカイニセンニジュウサンネンクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14255': FundCodeEntry(
        fund_code='G14255',
        sec_code=None,
        fund_name='ＳＢＩ・ＧＳ\u3000ＮｅｘＧｅｎ（代替エネルギー）',
        fund_name_yomi='エスビーアイ\u3000ジーエス\u3000ネクスジェン\u3000ダイタイエネルギー',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14256': FundCodeEntry(
        fund_code='G14256',
        sec_code=None,
        fund_name='ＳＢＩ・ＧＳ\u3000ＮｅｘＧｅｎ（グローバルＥＶ）',
        fund_name_yomi='エスビーアイ\u3000ジーエス\u3000ネクスジェン\u3000グローバルイーブイ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14257': FundCodeEntry(
        fund_code='G14257',
        sec_code=None,
        fund_name='ＳＢＩ・ＧＳ\u3000ＮｅｘＧｅｎ（高成長ＤＸ）',
        fund_name_yomi='エスビーアイ\u3000ジーエス\u3000ネクスジェン\u3000コウセイチョウディーエックス',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14258': FundCodeEntry(
        fund_code='G14258',
        sec_code=None,
        fund_name='ＳＢＩ・ＧＳ\u3000ＮｅｘＧｅｎ（先端医療）',
        fund_name_yomi='エスビーアイ\u3000ジーエス\u3000ネクスジェン\u3000センタンイリョウ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14259': FundCodeEntry(
        fund_code='G14259',
        sec_code=None,
        fund_name='ＳＢＩ・ＧＳ\u3000ＮｅｘＧｅｎ（次世代通信）',
        fund_name_yomi='エスビーアイ\u3000ジーエス\u3000ネクスジェン\u3000ジセダイツウシン',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14260': FundCodeEntry(
        fund_code='G14260',
        sec_code=None,
        fund_name='スパークス・日本アジア厳選株ファンド・ヘッジ型（ダイワ投資一任専用）',
        fund_name_yomi='スパークス\u3000ニホンアジアゲンセンカブファンド\u3000ヘッジガタ\u3000ダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月27日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G14261': FundCodeEntry(
        fund_code='G14261',
        sec_code=None,
        fund_name='ＧＳグローバル環境リーダーズ\u3000年２回決算コース／毎月決算コース（分配条件提示型）',
        fund_name_yomi='ジーエスグローバルカンキョウリーダーズ\u3000ネンニカイケッサンコースマイツキケッサンコースブンパイジョウケンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14262': FundCodeEntry(
        fund_code='G14262',
        sec_code=None,
        fund_name='インサイト・グローバル・クレジット・ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）／Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='インサイトグローバルクレジットファンド\u3000エーコースノムラエスエムエーイーダブリュムケ\u3000ビーコースノムラエスエムエーイーダブリュムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G14263': FundCodeEntry(
        fund_code='G14263',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国割安優良株式ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000ベイコクワリヤスユウリョウカブシキファンド\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G14264': FundCodeEntry(
        fund_code='G14264',
        sec_code=None,
        fund_name='日本連続増配成長株ファンド２１－０９（繰上償還条項付）',
        fund_name_yomi='ニホンレンゾクゾウハイセイチョウカブファンドニイチゼロキュウクリアゲショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14265': FundCodeEntry(
        fund_code='G14265',
        sec_code=None,
        fund_name='三井住友ＤＳ・ポートフォリオ・シリーズ',
        fund_name_yomi='ミツイスミトモディーエスポートフォリオシリーズ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14266': FundCodeEntry(
        fund_code='G14266',
        sec_code=None,
        fund_name='三井住友ＤＳ・新興国債インデックス・ファンド／ゴールドインデックス・ファンド（為替ヘッジあり）',
        fund_name_yomi='ミツイスミトモディーエスシンコウコクサイインデックスファンド\u3000ゴールドインデックスファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14267': FundCodeEntry(
        fund_code='G14267',
        sec_code=None,
        fund_name='ブランディワイン・グローバルバリュー株式ファンド',
        fund_name_yomi='ブランディワイングローバルバリューカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14268': FundCodeEntry(
        fund_code='G14268',
        sec_code=None,
        fund_name='第１４４回２０２６年６月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウヨンカイニセンニジュウロクネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14269': FundCodeEntry(
        fund_code='G14269',
        sec_code=None,
        fund_name='第１４５回２０２４年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウゴカイニセンニジュウヨネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14270': FundCodeEntry(
        fund_code='G14270',
        sec_code=None,
        fund_name='脱炭素ジャパン',
        fund_name_yomi='ダツタンソジャパン',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14271': FundCodeEntry(
        fund_code='G14271',
        sec_code=None,
        fund_name='ダイワ厳選コモディティ・ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ダイワゲンセンコモディティファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14272': FundCodeEntry(
        fund_code='G14272',
        sec_code=None,
        fund_name='ダイワＵＳ－ＲＥＩＴネクスト・ファンド（Ａコース／\u3000Ｂコース）（ダイワ投資一任専用）',
        fund_name_yomi='ダイワユーエスリートネクストファンドエーコースビーコースダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14273': FundCodeEntry(
        fund_code='G14273',
        sec_code=None,
        fund_name='ダイワ・クオンツアクティブＪ－ＲＥＩＴ・ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ダイワクオンツアクティブジェイリートファンドダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14274': FundCodeEntry(
        fund_code='G14274',
        sec_code=None,
        fund_name='第９４回\u3000２０２６年９月２９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウヨンカイニセンニジュウロクネンクガツニジュウクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月29日',
        period_2='9月29日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14275': FundCodeEntry(
        fund_code='G14275',
        sec_code=None,
        fund_name='長期資産形成戦略ファンド',
        fund_name_yomi='チョウキシサンケイセイセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G14276': FundCodeEntry(
        fund_code='G14276',
        sec_code=None,
        fund_name='第９３回\u3000２０２３年９月２７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価、Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウサンカイニセンニジュウサンネンクガツニジュウシチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14277': FundCodeEntry(
        fund_code='G14277',
        sec_code=None,
        fund_name='チャイナ・エネルギー・イノベーション株式ファンド',
        fund_name_yomi='チャイナ\u3000エネルギー\u3000イノベーションカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月13日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14278': FundCodeEntry(
        fund_code='G14278',
        sec_code=None,
        fund_name='ＵＢＳ新興国株式厳選投資ファンド（ダイワ投資一任専用）',
        fund_name_yomi='ユービーエスシンコウコクカブシキゲンセントウシファンド\u3000ダイワトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G14279': FundCodeEntry(
        fund_code='G14279',
        sec_code=None,
        fund_name='第９５回\u3000２０２４年１０月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウゴカイニセンニジュウヨネンジュウガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14280': FundCodeEntry(
        fund_code='G14280',
        sec_code=None,
        fund_name='フード＆テクノロジー関連株式ファンド（資産成長型）',
        fund_name_yomi='フードアンドテクノロジーカンレンカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14281': FundCodeEntry(
        fund_code='G14281',
        sec_code=None,
        fund_name='全共連第１回劣後ローン流動化株式会社',
        fund_name_yomi='ゼンキョウレンダイイッカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36940',
        issuer_name='全共連第１回劣後ローン流動化株式会社',
    ),
    'G14282': FundCodeEntry(
        fund_code='G14282',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－シティグループ社債\u3000償還時目標設定型ファンド',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000シティグループシャサイショウカンジモクヒョウセッテイガタファンド',
        security_type='外国投資信託受益証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G14283': FundCodeEntry(
        fund_code='G14283',
        sec_code=None,
        fund_name='第９６回\u3000２０２４年１０月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウロクカイニセンニジュウヨンネンジュウガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14284': FundCodeEntry(
        fund_code='G14284',
        sec_code=None,
        fund_name='第９７回\u3000２０２６年１０月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウナナカイニセンニジュウロクネンジュウガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14285': FundCodeEntry(
        fund_code='G14285',
        sec_code=None,
        fund_name='アジア\u3000サプライチェーン株式ファンド',
        fund_name_yomi='アジア\u3000サプライチェーーンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14286': FundCodeEntry(
        fund_code='G14286',
        sec_code=None,
        fund_name='第１４６回２０２６年６月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウロッカイニセンニジュウロクネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14287': FundCodeEntry(
        fund_code='G14287',
        sec_code=None,
        fund_name='第１４７回２０２４年１２月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウナナカイニセンニジュウヨネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月13日',
        period_2='10月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14288': FundCodeEntry(
        fund_code='G14288',
        sec_code=None,
        fund_name='東京海上・ジャパン・オーナーズ株式オープン（確定拠出年金）',
        fund_name_yomi='トウキョウカイジョウジャパンオーナーズカブシキオープンカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='7月18日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14289': FundCodeEntry(
        fund_code='G14289',
        sec_code=None,
        fund_name='国内株式ＥＳＧインデックス・オープン',
        fund_name_yomi='コクナイカブシキイーエスジーインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14290': FundCodeEntry(
        fund_code='G14290',
        sec_code=None,
        fund_name='先進国株式ＥＳＧインデックス・オープン',
        fund_name_yomi='センシンコクカブシキイーエスジーインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14291': FundCodeEntry(
        fund_code='G14291',
        sec_code=None,
        fund_name='ひふみワールド年金',
        fund_name_yomi='ヒフミワールドネンキン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G14292': FundCodeEntry(
        fund_code='G14292',
        sec_code=None,
        fund_name='Ｏｎｅグローバルバランス',
        fund_name_yomi='ワングローバルバランス',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14293': FundCodeEntry(
        fund_code='G14293',
        sec_code=None,
        fund_name='ベイリー・ギフォード世界成長企業戦略／ＳＭＴ．ＬＮ外国投資証券ファンド',
        fund_name_yomi='ベイリーギフォードセカイセイチョウキギョウセンリャクエスエムティーエルエヌガイコクトウシショウケンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14294': FundCodeEntry(
        fund_code='G14294',
        sec_code=None,
        fund_name='ＵＢＳ環境ロング・ショート・ファンド（為替ヘッジあり）、ＵＢＳ環境ロング・ショート・ファンド（為替ヘッジなし）',
        fund_name_yomi='ユービーエスカンキョウロング\u3000ショート\u3000ファンド\u3000カワセヘッジアリ\u3000\u3000ユービーエスカンキョウロング\u3000ショート\u3000ファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月2日',
        period_2='8月2日',
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G14295': FundCodeEntry(
        fund_code='G14295',
        sec_code=None,
        fund_name='ＨＦリターン・ターゲット・ファンド・為替ヘッジあり（ＳＭＡ専用）',
        fund_name_yomi='エイチエフリターン\u3000ターゲット\u3000ファンド\u3000カワセヘッジアリ\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14296': FundCodeEntry(
        fund_code='G14296',
        sec_code=None,
        fund_name='第９８回\u3000２０２３年１０月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウハチカイニセンニジュウサンネンジュウガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14297': FundCodeEntry(
        fund_code='G14297',
        sec_code=None,
        fund_name='第９９回\u3000２０２６年１０月２８日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイキュウジュウキュウカイニセンニジュウロクネンジュウガツニジュウハチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月28日',
        period_2='10月28日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14298': FundCodeEntry(
        fund_code='G14298',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２１－Ⅱ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイイチノニ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14299': FundCodeEntry(
        fund_code='G14299',
        sec_code='26440',
        fund_name='グローバルＸ\u3000半導体関連－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスハンドウタイカンレンニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14300': FundCodeEntry(
        fund_code='G14300',
        sec_code='26450',
        fund_name='グローバルＸ\u3000レジャー＆エンターテインメント－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスレジャーアンドエンターテインメントニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14301': FundCodeEntry(
        fund_code='G14301',
        sec_code='26460',
        fund_name='グローバルＸ\u3000メタルビジネス－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスメタルビジネスニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14302': FundCodeEntry(
        fund_code='G14302',
        sec_code=None,
        fund_name='東京海上・気候変動対応株式ファンド',
        fund_name_yomi='トウキョウカイジョウキコウヘンドウタイオウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14303': FundCodeEntry(
        fund_code='G14303',
        sec_code=None,
        fund_name='ＷＣＭ\u3000世界成長株厳選ファンド（資産成長型）',
        fund_name_yomi='ダブリューシーエムセカイセイチョウカブゲンセンファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G14304': FundCodeEntry(
        fund_code='G14304',
        sec_code=None,
        fund_name='ＷＣＭ\u3000世界成長株厳選ファンド（予想分配金提示型）',
        fund_name_yomi='ダブリューシーエムセカイセイチョウカブゲンセンファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G14305': FundCodeEntry(
        fund_code='G14305',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２１‐１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイイチノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14306': FundCodeEntry(
        fund_code='G14306',
        sec_code=None,
        fund_name='ＳＯＭＰＯアルジェブリス・グローバル金融株式ファンド（円ヘッジなし）',
        fund_name_yomi='ソンポアルジェブリスグローバルキンユウカブシキファンドエンヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14307': FundCodeEntry(
        fund_code='G14307',
        sec_code=None,
        fund_name='ＦＤＡ日米バランスファンド（安定型）\u3000ＦＤＡ日米バランスファンド（成長型）\u3000ＦＤＡ日米バランスファンド（積極型）',
        fund_name_yomi='エフディーエーニチベイバランスファンドアンテイガタ\u3000エフディーエーニチベイバランスファンドセイチョウガタ\u3000エフディーエーニチベイバランスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月7日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14308': FundCodeEntry(
        fund_code='G14308',
        sec_code=None,
        fund_name='第１００回\u3000２０２４年１１月１３日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクカイニセンニジュウヨネンジュウイチガツジュウサンニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14309': FundCodeEntry(
        fund_code='G14309',
        sec_code=None,
        fund_name='米国ネクストビジョンファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ベイコクネクストビジョンファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14310': FundCodeEntry(
        fund_code='G14310',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・世界ＳＤＧｓ債券ファンド（年２回決算型・為替ヘッジあり）、アライアンス・バーンスタイン・世界ＳＤＧｓ債券ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='アライアンスバーンスタインセカイエスディージーズサイケンファンドネンニカイケッサンガタカワセヘッジアリ\u3000アライアンスバーンスタインセカイエスディージーズサイケンファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14311': FundCodeEntry(
        fund_code='G14311',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・世界ＳＤＧｓ債券ファンド（毎月決算型・為替ヘッジあり）、アライアンス・バーンスタイン・世界ＳＤＧｓ債券ファンド（毎月決算型・為替ヘッジなし）',
        fund_name_yomi='アライアンスバーンスタインセカイエスディージーズサイケンファンドマイツキケッサンガタカワセヘッジアリ\u3000アライアンスバーンスタインセカイエスディージーズサイケンファンドマイツキケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14312': FundCodeEntry(
        fund_code='G14312',
        sec_code=None,
        fund_name='キャピタル・ニューエコノミー・ファンドＮＦ',
        fund_name_yomi='キャピタルニューエコノミーファンドエヌエフ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G14313': FundCodeEntry(
        fund_code='G14313',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＵＳダイナミック・グロース',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーユーエスダイナミックグロース',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G14314': FundCodeEntry(
        fund_code='G14314',
        sec_code=None,
        fund_name='ＧＳグローバル・ターゲット戦略債券ファンド２０２１－１１（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000ターゲット\u3000センリャクサイケンファンド\u3000ニセンニジュウイチ\u3000ジュウイチ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14315': FundCodeEntry(
        fund_code='G14315',
        sec_code=None,
        fund_name='ブランディワイン・グローバル株式ファンド（ＳＭＡ専用）',
        fund_name_yomi='ブランディワイン\u3000グローバルカブシキファンド\u3000エスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G14316': FundCodeEntry(
        fund_code='G14316',
        sec_code=None,
        fund_name='アクサ世界株式ファンド',
        fund_name_yomi='アクサセカイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E10535',
        issuer_name='アクサ・インベストメント・マネージャーズ株式会社',
    ),
    'G14317': FundCodeEntry(
        fund_code='G14317',
        sec_code=None,
        fund_name='ＨＣインカム～夢のたね',
        fund_name_yomi='エイチシーインカムユメノタネ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E36992',
        issuer_name='ＨＣアセットマネジメント株式会社',
    ),
    'G14318': FundCodeEntry(
        fund_code='G14318',
        sec_code=None,
        fund_name='ピクテ・サステナビリティ・マルチアセット・ファンド',
        fund_name_yomi='ピクテサステナビリティマルチアセットファンド',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14319': FundCodeEntry(
        fund_code='G14319',
        sec_code=None,
        fund_name='ｉＴｒｕｓｔオールメガトレンド',
        fund_name_yomi='アイトラストオールメガトレンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14320': FundCodeEntry(
        fund_code='G14320',
        sec_code=None,
        fund_name='ＧＸＪメガトレンド・ジャパン',
        fund_name_yomi='ジーエックスジェイメガトレンドジャパン',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14321': FundCodeEntry(
        fund_code='G14321',
        sec_code=None,
        fund_name='ダイワ／バリュー・パートナーズ\u3000チャイナ・エネルギー・シフト・フォーカス',
        fund_name_yomi='ダイワバリューパートナーズチャイナエネルギーシフトフォーカス',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2='10月14日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14322': FundCodeEntry(
        fund_code='G14322',
        sec_code=None,
        fund_name='ＭＳスターファンズ',
        fund_name_yomi='エムエススターファンズ',
        security_type='外国投資信託受益証券',
        period_1='3月31日',
        period_2=None,
        edinet_code='E37044',
        issuer_name='三田キャピタル・プライベート・リミテッド',
    ),
    'G14323': FundCodeEntry(
        fund_code='G14323',
        sec_code=None,
        fund_name='第１０２回\u3000２０２６年１１月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニカイニセンニジュウロクネンジュウイチガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14324': FundCodeEntry(
        fund_code='G14324',
        sec_code=None,
        fund_name='第１０１回\u3000２０２４年１１月１８日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクイチカイニセンニジュウヨネンジュウイチガツジュウハチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14325': FundCodeEntry(
        fund_code='G14325',
        sec_code=None,
        fund_name='東京海上・ジャパン・オーナーズ株式オープン（予想分配金提示型）',
        fund_name_yomi='トウキョウカイジョウジャパンオーナーズカブシキオープンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14326': FundCodeEntry(
        fund_code='G14326',
        sec_code=None,
        fund_name='ＳＢＩ\u3000Ｓ＆Ｐ５００パリ協定\u3000インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000エスアンドピーゴヒャクパリキョウテイ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14327': FundCodeEntry(
        fund_code='G14327',
        sec_code=None,
        fund_name='ＳＢＩジェンダー・フリーインデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ジェンダーフリー\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14328': FundCodeEntry(
        fund_code='G14328',
        sec_code=None,
        fund_name='グローバル・ハイクオリティ成長株式ファンド（予想分配金提示型）（限定為替ヘッジ）、グローバル・ハイクオリティ成長株式ファンド（予想分配金提示型）（為替ヘッジなし）',
        fund_name_yomi='グローバルハイクオリティセイチョウカブシキファンドヨソウブンパイキンテイジガタゲンテイカワセヘッジ\u3000グローバルハイクオリティセイチョウカブシキファンドヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14329': FundCodeEntry(
        fund_code='G14329',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ年金バランス（株式８０）',
        fund_name_yomi='ミツビシユーエフジェイディーシーネンキンバランスカブシキハチジュー',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14330': FundCodeEntry(
        fund_code='G14330',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・グローバル・グロース・オポチュニティーズ（予想分配金提示型）',
        fund_name_yomi='アライアンスバーンスタイングローバルグロースオポチュニティーズヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14331': FundCodeEntry(
        fund_code='G14331',
        sec_code=None,
        fund_name='第１４８回２０２６年９月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウハッカイニセンニジュウロクネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14332': FundCodeEntry(
        fund_code='G14332',
        sec_code=None,
        fund_name='第１４９回２０２４年１２月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクヨンジュウキュウカイニセンニジュウヨネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14333': FundCodeEntry(
        fund_code='G14333',
        sec_code=None,
        fund_name='お金のデザイン・グローバル・ソーシャル・デベロップメント・ファンド',
        fund_name_yomi='オカネノデザイン\u3000グローバル\u3000ソーシャル\u3000デベロップメント\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G14334': FundCodeEntry(
        fund_code='G14334',
        sec_code=None,
        fund_name='第１０３回\u3000２０２３年１２月１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンカイニセンニジュウサンネンジュウニガツツイタチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月1日',
        period_2='12月1日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14335': FundCodeEntry(
        fund_code='G14335',
        sec_code=None,
        fund_name='九州ＳＤＧｓ・グローバルバランス',
        fund_name_yomi='キュウシュウエスディージーズ\u3000グローバルバランス',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14336': FundCodeEntry(
        fund_code='G14336',
        sec_code=None,
        fund_name='第１０４回\u3000２０２６年１２月１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクヨンカイニセンニジュウロクネンジュウニガツツイタチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月1日',
        period_2='12月1日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14337': FundCodeEntry(
        fund_code='G14337',
        sec_code='26480',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ米国国債（７－１０年）インデックス（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグベイコクコクサイナナジュウネンインデックスカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14338': FundCodeEntry(
        fund_code='G14338',
        sec_code='26470',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ米国国債（７－１０年）インデックス（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグベイコクコクサイナナジュウネンインデックスカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14339': FundCodeEntry(
        fund_code='G14339',
        sec_code=None,
        fund_name='ＴＨＥＯベスト・バランス・ファンド',
        fund_name_yomi='テオベスト\u3000バランス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月31日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G14340': FundCodeEntry(
        fund_code='G14340',
        sec_code=None,
        fund_name='インベスコ\u3000世界グリーンボンド・ファンド',
        fund_name_yomi='インベスコセカイグリーンボンドファンド',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G14341': FundCodeEntry(
        fund_code='G14341',
        sec_code=None,
        fund_name='ＨＳＢＣ気候パリ協定準拠株式インデックスファンド',
        fund_name_yomi='エイチエスビーシーキコウパリキョウテイジュンキョカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月18日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G14342': FundCodeEntry(
        fund_code='G14342',
        sec_code=None,
        fund_name='第１０５回\u3000２０２４年１２月９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクゴカイニセンニジュウヨネンジュウニガツココノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14343': FundCodeEntry(
        fund_code='G14343',
        sec_code=None,
        fund_name='楽天レバレッジＮＡＳＤＡＱ－１００',
        fund_name_yomi='ラクテンレバレッジナスダック\u3000ヒャク',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14344': FundCodeEntry(
        fund_code='G14344',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ＤＣ先進国株式ＥＳＧリーダーズインデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイディーシーセンシンコクカブシキイーエスジーリーダーズインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14345': FundCodeEntry(
        fund_code='G14345',
        sec_code=None,
        fund_name='みらいバランス・株式１０（富士通企業年金基金ＤＣ向け）',
        fund_name_yomi='ミライバランスカブシキジュウフジツウキギョウネンキンキキンデイーシームケ',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14346': FundCodeEntry(
        fund_code='G14346',
        sec_code=None,
        fund_name='グローバル創薬関連株式ファンド',
        fund_name_yomi='グローバルソウヤクカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14347': FundCodeEntry(
        fund_code='G14347',
        sec_code=None,
        fund_name='ニッセイ先進国株式インデックス（為替ヘッジあり）（ラップ専用）',
        fund_name_yomi='ニッセイセンシンコクカブシキインデックスカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14348': FundCodeEntry(
        fund_code='G14348',
        sec_code=None,
        fund_name='ニッセイ先進国株式インデックス（為替ヘッジなし）（ラップ専用）',
        fund_name_yomi='ニッセイセンシンコクカブシキインデックスカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14349': FundCodeEntry(
        fund_code='G14349',
        sec_code=None,
        fund_name='ニッセイ新興国株式インデックス（ラップ専用）',
        fund_name_yomi='ニッセイシンコウコクカブシキインデックスラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14350': FundCodeEntry(
        fund_code='G14350',
        sec_code=None,
        fund_name='ニッセイ新興国債券インデックス（ラップ専用）',
        fund_name_yomi='ニッセイシンコウコクサイケンインデックスラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14351': FundCodeEntry(
        fund_code='G14351',
        sec_code=None,
        fund_name='ニッセイ海外リートインデックス（為替ヘッジあり）（ラップ専用）',
        fund_name_yomi='ニッセイカイガイリートインデックスカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14352': FundCodeEntry(
        fund_code='G14352',
        sec_code=None,
        fund_name='ニッセイ海外リートインデックス（為替ヘッジなし）（ラップ専用）',
        fund_name_yomi='ニッセイカイガイリートインデックスカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14353': FundCodeEntry(
        fund_code='G14353',
        sec_code=None,
        fund_name='モビリティ・イノベーション・ファンド（予想分配金提示型）',
        fund_name_yomi='モビリティイノベーションファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2='7月21日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G14354': FundCodeEntry(
        fund_code='G14354',
        sec_code=None,
        fund_name='ＢＮＹメロン・米国株式ダイナミック戦略ファンド（予想分配金提示型）',
        fund_name_yomi='ビーエヌワイメロンベイコクカブシキダイナミックセンリャクファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G14355': FundCodeEntry(
        fund_code='G14355',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅡ\u3000２０２１－１２',
        fund_name_yomi='ワンエンダテサイケンファンドツーニイゼロニイイチイチニイ',
        security_type='内国投資信託受益証券',
        period_1='4月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14356': FundCodeEntry(
        fund_code='G14356',
        sec_code=None,
        fund_name='ブラックロック・フィクスド・インカム・ダブリン・ファンズ\u3000ｐｌｃ－ｉシェアーズ・グリーンボンド・インデックス・ファンドクラスＤ円ヘッジ投資証券',
        fund_name_yomi='ブラックロックフィクスドインカムダブリンファンズピーエルシーアイシェアーズグリーンボンドインデックスファンドクラスディーエンヘッジトウシショウケン',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36699',
        issuer_name='ブラックロック・フィクスド・インカム・ダブリン・ファンズ\u3000ｐｌｃ',
    ),
    'G14357': FundCodeEntry(
        fund_code='G14357',
        sec_code=None,
        fund_name='第１０６回\u3000２０２３年１２月１１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクロクカイニセンニジュウサンネンジュウニガツジュウイチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14358': FundCodeEntry(
        fund_code='G14358',
        sec_code=None,
        fund_name='第１０７回\u3000２０２６年１２月１４日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクナナカイニセンニジュウロクネンジュウニガツジュウヨッカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14359': FundCodeEntry(
        fund_code='G14359',
        sec_code=None,
        fund_name='ダイワ・グローバルＲＥＩＴ・オープン（為替ヘッジあり／毎月分配型）',
        fund_name_yomi='ダイワグローバルリートオープンカワセヘッジアリマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14360': FundCodeEntry(
        fund_code='G14360',
        sec_code=None,
        fund_name='ダイワ・グローバルＲＥＩＴ・オープン（為替ヘッジあり・なし／資産成長型）',
        fund_name_yomi='ダイワグローバルリートオープンカワセヘッジアリナシシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14361': FundCodeEntry(
        fund_code='G14361',
        sec_code=None,
        fund_name='Ｔ＆Ｄダブルブル・ベア・シリーズ８',
        fund_name_yomi='ティアンドディダブルブルベアシリーズハチ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14362': FundCodeEntry(
        fund_code='G14362',
        sec_code=None,
        fund_name='トーセイ・プロパティ・ファンド（シリーズ１）',
        fund_name_yomi='トーセイ\u3000プロパティ\u3000ファンド\u3000シリーズワン',
        security_type='内国有価証券投資事業権利等',
        period_1='10月末日',
        period_2=None,
        edinet_code='E37114',
        issuer_name='トークン合同会社',
    ),
    'G14363': FundCodeEntry(
        fund_code='G14363',
        sec_code=None,
        fund_name='楽天グローバルＩＰＯ株式ファンド',
        fund_name_yomi='ラクテングローバルアイピーオーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14364': FundCodeEntry(
        fund_code='G14364',
        sec_code=None,
        fund_name='りそな国内リートインデックス（ラップ専用）',
        fund_name_yomi='リソナコクナイリートインデックス\u3000ラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14365': FundCodeEntry(
        fund_code='G14365',
        sec_code=None,
        fund_name='グローバル・デジタルヘルスケア株式ファンド（年１回決算型・為替ヘッジあり）／グローバル・デジタルヘルスケア株式ファンド（年１回決算型・為替ヘッジなし）',
        fund_name_yomi='グローバルデジタルヘルスケアカブシキファンドネンイッカイケッサンガタカワセヘッジアリ\u3000グローバルデジタルヘルスケアカブシキファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月18日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14366': FundCodeEntry(
        fund_code='G14366',
        sec_code=None,
        fund_name='グローバル・デジタルヘルスケア株式ファンド（年２回決算型・為替ヘッジあり）／グローバル・デジタルヘルスケア株式ファンド（年２回決算型・為替ヘッジなし）',
        fund_name_yomi='グローバルデジタルヘルスケアカブシキファンドネンニカイケッサンガタカワセヘッジアリ\u3000グローバルデジタルヘルスケアカブシキファンドネンニカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月18日',
        period_2='11月18日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14367': FundCodeEntry(
        fund_code='G14367',
        sec_code=None,
        fund_name='ダイワ国内株式インデックス（ラップ専用）',
        fund_name_yomi='ダイワコクナイカブシキインデックスラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14368': FundCodeEntry(
        fund_code='G14368',
        sec_code=None,
        fund_name='ダイワ国内債券インデックス（ラップ専用）',
        fund_name_yomi='ダイワコクナイサイケンインデックスラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14369': FundCodeEntry(
        fund_code='G14369',
        sec_code=None,
        fund_name='ダイワ先進国債券インデックス（為替ヘッジあり・なし）（ラップ専用）',
        fund_name_yomi='ダイワセンシンコクサイケンインデックスカワセヘッジアリナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14370': FundCodeEntry(
        fund_code='G14370',
        sec_code=None,
        fund_name='インフラ関連グローバル株式ファンド',
        fund_name_yomi='インフラカンレングローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14371': FundCodeEntry(
        fund_code='G14371',
        sec_code=None,
        fund_name='不動産のデジタル証券～神戸六甲アイランドＤＣ～（譲渡制限付）',
        fund_name_yomi='フドウサンノデジタルショウケンコウベロッコウアイランドディーシージョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14372': FundCodeEntry(
        fund_code='G14372',
        sec_code=None,
        fund_name='楽天Ｊ－ＲＥＩＴ・オルタナティブデータ・ファンド',
        fund_name_yomi='ラクテンジェイ\u3000リート\u3000オルタナティブデータ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14373': FundCodeEntry(
        fund_code='G14373',
        sec_code=None,
        fund_name='第１０９回\u3000２０２６年１２月３０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクキュウカイニセンニジュウロクネンジュウニガツサンジュウニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月30日',
        period_2='12月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14374': FundCodeEntry(
        fund_code='G14374',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－プレミアム・キャリー戦略ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリープレミアムキャリーセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G14375': FundCodeEntry(
        fund_code='G14375',
        sec_code=None,
        fund_name='第１０８回\u3000２０２３年１２月２９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクハチカイニセンニジュウサンネンジュウニガツニジュウクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月29日',
        period_2='12月29日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14376': FundCodeEntry(
        fund_code='G14376',
        sec_code=None,
        fund_name='フィデリティ・世界割安成長株投信\u3000Ｃコース（毎月決算・予想分配金提示型・為替ヘッジあり）\u3000フィデリティ・世界割安成長株投信\u3000Ｄコース（毎月決算・予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='フィデリティセカイワリヤスセイチョウカブトウシンシーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジアリ\u3000フィデリティセカイワリヤスセイチョウカブトウシンディーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14377': FundCodeEntry(
        fund_code='G14377',
        sec_code=None,
        fund_name='第１５０回２０２６年９月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュッカイニセンニジュウロクネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14378': FundCodeEntry(
        fund_code='G14378',
        sec_code=None,
        fund_name='第１５１回２０２４年１２月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウイッカイニセンニジュウヨネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14379': FundCodeEntry(
        fund_code='G14379',
        sec_code=None,
        fund_name='第１１０回\u3000２０２５年１月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュッカイニセンニジュウゴネンイチガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14381': FundCodeEntry(
        fund_code='G14381',
        sec_code=None,
        fund_name='ソフトバンクグループ＆日本企業厳選債券ファンド２０２１－１２',
        fund_name_yomi='ソフトバンクグループ\u3000アンド\u3000ニホンキギョウゲンセンサイケンファンド\u3000ニゼロニイチ\u3000イチニ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14382': FundCodeEntry(
        fund_code='G14382',
        sec_code=None,
        fund_name='ダイナミックアロケーションファンド（ラップ向け）',
        fund_name_yomi='ダイナミックアロケーションファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14383': FundCodeEntry(
        fund_code='G14383',
        sec_code=None,
        fund_name='ファンドラップ専用ファンド',
        fund_name_yomi='ファンドラップセンヨウファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14384': FundCodeEntry(
        fund_code='G14384',
        sec_code=None,
        fund_name='ポーレン米国グロース株式ファンド（予想分配金提示型）',
        fund_name_yomi='ポーレンベイコクグロースカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2='9月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14385': FundCodeEntry(
        fund_code='G14385',
        sec_code=None,
        fund_name='第１１２回\u3000２０２７年１月１８日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウニカイニセンニジュウシチネンイチガツジュウハチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月18日',
        period_2='7月18日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14386': FundCodeEntry(
        fund_code='G14386',
        sec_code=None,
        fund_name='ＦＷニッセイ先進国脱炭素株インデックス',
        fund_name_yomi='エフダブリュニッセイセンシンコクダツタンソカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14387': FundCodeEntry(
        fund_code='G14387',
        sec_code=None,
        fund_name='第１１１回\u3000２０２４年１月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウイチカイニセンニジュウヨネンイチガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14388': FundCodeEntry(
        fund_code='G14388',
        sec_code=None,
        fund_name='次世代消費関連株式ファンド（資産成長型・予想分配金提示型）',
        fund_name_yomi='ジセダイショウヒカンレンカブシキファンドシサンセイチョウガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14389': FundCodeEntry(
        fund_code='G14389',
        sec_code='28360',
        fund_name='グローバルＸ\u3000フィンテック－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスフィンテックニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14390': FundCodeEntry(
        fund_code='G14390',
        sec_code='28370',
        fund_name='グローバルＸ\u3000中小型リーダーズ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチュウコガタリーダーズニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14391': FundCodeEntry(
        fund_code='G14391',
        sec_code='28390',
        fund_name='ＭＡＸＩＳ米国国債７―１０年上場投信（為替ヘッジあり）',
        fund_name_yomi='マクシスベイコクコクサイナナカラジュウネンジョウジョウトウシンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14392': FundCodeEntry(
        fund_code='G14392',
        sec_code='28380',
        fund_name='ＭＡＸＩＳ米国国債７―１０年上場投信（為替ヘッジなし）',
        fund_name_yomi='マクシスベイコクコクサイナナカラジュウネンジョウジョウトウシンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14393': FundCodeEntry(
        fund_code='G14393',
        sec_code=None,
        fund_name='ＳＯＭＰＯ１２３\u3000先進国株式',
        fund_name_yomi='ソンポワンツースリー\u3000センシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14394': FundCodeEntry(
        fund_code='G14394',
        sec_code=None,
        fund_name='コモディティ・アルファ戦略ファンド',
        fund_name_yomi='コモディティアルファセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14395': FundCodeEntry(
        fund_code='G14395',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000グローバル２倍株（地球コンプリート）',
        fund_name_yomi='トレイサーズ\u3000グローバルニバイカブ\u3000チキュウコンプリート',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14396': FundCodeEntry(
        fund_code='G14396',
        sec_code=None,
        fund_name='グローバルインパクト投資ファンド（気候変動）',
        fund_name_yomi='グローバルインパクトトウシファンド\u3000キコウヘンドウ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14397': FundCodeEntry(
        fund_code='G14397',
        sec_code=None,
        fund_name='ファンドスミス・グローバル・エクイティ・ファンド',
        fund_name_yomi='ファンドスミスグローバルエクイティファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14398': FundCodeEntry(
        fund_code='G14398',
        sec_code=None,
        fund_name='オーケストラ\u3000ファンド（安定コース）\u3000オーケストラ\u3000ファンド（成長コース）',
        fund_name_yomi='オーケストラ\u3000ファンドアンテイコース\u3000オーケストラ\u3000ファンドセイチョウコース',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G14399': FundCodeEntry(
        fund_code='G14399',
        sec_code=None,
        fund_name='みらいのサイフ（エントリーコース）、みらいのサイフ（ベーシックコース）、みらいのサイフ（アドバンスコース）',
        fund_name_yomi='ミライノサイフエントリーコース\u3000ミライノサイフベーシックコース\u3000ミライノサイフアドバンスコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14400': FundCodeEntry(
        fund_code='G14400',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓインカムファンド（資産成長型・為替ヘッジあり）／ニッセイＳＤＧｓインカムファンド（資産成長型・為替ヘッジなし）',
        fund_name_yomi='ニッセイエスディージーズインカムファンドシサンセイチョウガタカワセヘッジアリ\u3000ニッセイエスディージーズインカムファンドシサンセイチョウガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14401': FundCodeEntry(
        fund_code='G14401',
        sec_code=None,
        fund_name='ニッセイＳＤＧｓインカムファンド（予想分配金提示型・為替ヘッジあり）／ニッセイＳＤＧｓインカムファンド（予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='ニッセイエスディージーズインカムファンドヨソウブンパイキンテイジガタカワセヘッジアリ\u3000ニッセイエスディージーズインカムファンドヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14402': FundCodeEntry(
        fund_code='G14402',
        sec_code=None,
        fund_name='ニュー・チャイナ・ファンド（資産成長型）',
        fund_name_yomi='ニューチャイナファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14403': FundCodeEntry(
        fund_code='G14403',
        sec_code=None,
        fund_name='ニュー・チャイナ・ファンド（予想分配金提示型）',
        fund_name_yomi='ニューチャイナファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14404': FundCodeEntry(
        fund_code='G14404',
        sec_code=None,
        fund_name='インサイト・グローバル・クレジット・ファンド\u3000Ａコース（為替ヘッジあり\u3000年２回決算型）／Ｂコース（為替ヘッジなし\u3000年２回決算型）',
        fund_name_yomi='インサイトグローバルクレジットファンド\u3000エーコースカワセヘッジアリネンニカイケッサンカタ\u3000ビーコースカワセヘッジナシネンニカイケッサンカタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G14405': FundCodeEntry(
        fund_code='G14405',
        sec_code=None,
        fund_name='第１１４回\u3000２０２７年２月２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウヨンカイニセンニジュウシチネンニガツフツカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月2日',
        period_2='8月2日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14406': FundCodeEntry(
        fund_code='G14406',
        sec_code=None,
        fund_name='第１１３回\u3000２０２４年２月２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウサンカイニセンニジュウヨネンニガツフツカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月2日',
        period_2='8月2日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14407': FundCodeEntry(
        fund_code='G14407',
        sec_code=None,
        fund_name='ＤＣニッセイグローバルＥＳＧフォーカスファンド',
        fund_name_yomi='ディーシーニッセイグローバルイーエスジーフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14408': FundCodeEntry(
        fund_code='G14408',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２２－０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイニイノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14409': FundCodeEntry(
        fund_code='G14409',
        sec_code=None,
        fund_name='第１５２回２０２６年９月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウニカイニセンニジュウロクネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14410': FundCodeEntry(
        fund_code='G14410',
        sec_code=None,
        fund_name='第１５３回２０２５年３月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウサンカイニセンニジュウゴネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14411': FundCodeEntry(
        fund_code='G14411',
        sec_code=None,
        fund_name='第１１５回\u3000２０２５年２月１３日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウゴカイニセンニジュウゴネンニガツジュウサンニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月13日',
        period_2='8月13日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14413': FundCodeEntry(
        fund_code='G14413',
        sec_code=None,
        fund_name='日本株式エクセレント・フォーカスファンド',
        fund_name_yomi='ニホンカブシキエクセレント\u3000フォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14414': FundCodeEntry(
        fund_code='G14414',
        sec_code=None,
        fund_name='ゴールドマン・サックス（ケイマン諸島）ユニット・トラスト－ｎｅｘｔＷＩＮ\u3000ＧＳフューチャー・テクノロジー・リーダーズ',
        fund_name_yomi='ゴールドマンサックスケイマンショトウユニットトラストネクストウィンジーエスフューチャーテクノロジーリーダーズ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G14415': FundCodeEntry(
        fund_code='G14415',
        sec_code=None,
        fund_name='第１１７回\u3000２０２７年２月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウナナカイニセンニジュウシチネンニガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14416': FundCodeEntry(
        fund_code='G14416',
        sec_code='26490',
        fund_name='ｉシェアーズ\u3000米国政府系機関ジニーメイＭＢＳ\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイコクセイフケイキカンジニーメイエムビーエス\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14417': FundCodeEntry(
        fund_code='G14417',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・全世界株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ゼンセカイカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14418': FundCodeEntry(
        fund_code='G14418',
        sec_code=None,
        fund_name='グローバル・サブスクリプション・サービス関連株式ファンド',
        fund_name_yomi='グローバルサブスクリプションサービスカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14419': FundCodeEntry(
        fund_code='G14419',
        sec_code=None,
        fund_name='グローバル厳選バランスファンド',
        fund_name_yomi='グローバルゲンセンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G14420': FundCodeEntry(
        fund_code='G14420',
        sec_code=None,
        fund_name='第１１６回\u3000２０２４年２月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウロクカイニセンニジュウヨネンニガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月16日',
        period_2='8月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14421': FundCodeEntry(
        fund_code='G14421',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000米ドル建て新興国債券（為替ヘッジあり）',
        fund_name_yomi='ラップムケインデックスエフベイドルダテシンコウコクサイケンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14422': FundCodeEntry(
        fund_code='G14422',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国リート（為替ヘッジあり）',
        fund_name_yomi='ラップムケインデックスエフセンシンコクリートカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14423': FundCodeEntry(
        fund_code='G14423',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国債券（為替ヘッジあり）',
        fund_name_yomi='ラップムケインデックスエフセンシンコクサイケンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14424': FundCodeEntry(
        fund_code='G14424',
        sec_code=None,
        fund_name='ラップ向けインデックスｆ\u3000先進国株式（為替ヘッジあり）',
        fund_name_yomi='ラップムケインデックスエフセンシンコクカブシキカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14425': FundCodeEntry(
        fund_code='G14425',
        sec_code=None,
        fund_name='セゾン共創日本ファンド',
        fund_name_yomi='セゾンキョウソウニッポンファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E14561',
        issuer_name='セゾン投信株式会社',
    ),
    'G14426': FundCodeEntry(
        fund_code='G14426',
        sec_code=None,
        fund_name='ピクテ・ヒューマン・ファンド',
        fund_name_yomi='ピクテヒューマンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14427': FundCodeEntry(
        fund_code='G14427',
        sec_code=None,
        fund_name='ジパング・オーナー企業株式ファンド',
        fund_name_yomi='ジパング\u3000オーナーキギョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14428': FundCodeEntry(
        fund_code='G14428',
        sec_code=None,
        fund_name='ブラックロック・イノベーター株式・ヘッジファンド（限定為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブラックロックイノベーターカブシキヘッジファンドゲンテイカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14429': FundCodeEntry(
        fund_code='G14429',
        sec_code=None,
        fund_name='第１２１回\u3000２０２５年３月７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウイチカイニセンニジュウゴネンサンガツナノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14430': FundCodeEntry(
        fund_code='G14430',
        sec_code=None,
        fund_name='第１１９回\u3000２０２７年３月９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウキュウカイニセンニジュウシチネンサンガツココノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月9日',
        period_2='9月9日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14431': FundCodeEntry(
        fund_code='G14431',
        sec_code=None,
        fund_name='第１２０回\u3000２０２３年３月７日満期\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウカイニセンニジュウサンネンサンガツナノカマンキソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14432': FundCodeEntry(
        fund_code='G14432',
        sec_code=None,
        fund_name='第１１８回\u3000２０２４年３月１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクジュウハチカイニセンニジュウヨネンサンガツツイタチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月1日',
        period_2='9月1日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14433': FundCodeEntry(
        fund_code='G14433',
        sec_code=None,
        fund_name='第１５４回２０２６年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウヨンカイニセンニジュウロクネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14434': FundCodeEntry(
        fund_code='G14434',
        sec_code=None,
        fund_name='第１５５回２０２５年３月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウゴカイニセンニジュウゴネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14436': FundCodeEntry(
        fund_code='G14436',
        sec_code=None,
        fund_name='ラップ向けダイナミックアロケーションファンド',
        fund_name_yomi='ラップムケダイナミックアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14437': FundCodeEntry(
        fund_code='G14437',
        sec_code=None,
        fund_name='つみたて日経２２５インデックスファンド',
        fund_name_yomi='ツミタテニッケイニーニーゴインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G14438': FundCodeEntry(
        fund_code='G14438',
        sec_code=None,
        fund_name='ラップ向け日本超長期国債インデックスファンドⅡ',
        fund_name_yomi='ラップムケニホンチョウチョウキコクサイインデックスファンドツー',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14439': FundCodeEntry(
        fund_code='G14439',
        sec_code=None,
        fund_name='ヘッジ付先進国株式インデックス・オープン（ラップ向け）',
        fund_name_yomi='ヘッジツキセンシンコクカブシキインデックスオープンラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14440': FundCodeEntry(
        fund_code='G14440',
        sec_code=None,
        fund_name='ラップ向けアクティブアロケーションファンド',
        fund_name_yomi='ラップムケアクティブアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14441': FundCodeEntry(
        fund_code='G14441',
        sec_code=None,
        fund_name='ラップ向け先進国高格付国債ファンドⅡ',
        fund_name_yomi='ラップムケセンシンコクコウカクヅケコクサイファンドツー',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14442': FundCodeEntry(
        fund_code='G14442',
        sec_code=None,
        fund_name='カレラＢＥＶ関連株ファンド',
        fund_name_yomi='カレラビーイーヴィーカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14443': FundCodeEntry(
        fund_code='G14443',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅡ\u3000２０２２－０３',
        fund_name_yomi='ワンエンダテサイケンファンドツーニイゼロニイニイゼロサン',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14444': FundCodeEntry(
        fund_code='G14444',
        sec_code='28410',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＮＡＳＤＡＱ１００（為替ヘッジあり）',
        fund_name_yomi='アイフリーイーティーエフナスダックヒャクカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14445': FundCodeEntry(
        fund_code='G14445',
        sec_code='28400',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＮＡＳＤＡＱ１００（為替ヘッジなし）',
        fund_name_yomi='アイフリーイーティーエフナスダックヒャクカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14446': FundCodeEntry(
        fund_code='G14446',
        sec_code='28420',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＮＡＳＤＡＱ１００インバース',
        fund_name_yomi='アイフリーイーティーエフナスダックヒャクインバース',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14447': FundCodeEntry(
        fund_code='G14447',
        sec_code=None,
        fund_name='三井住友ＤＳ\u3000グローバル・ターゲット戦略債券ファンド２０２２－０３（限定追加型）',
        fund_name_yomi='ミツイスミトモディーエスグローバルターゲットセンリャクサイケンファンドニイゼロニイニイゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14448': FundCodeEntry(
        fund_code='G14448',
        sec_code=None,
        fund_name='インベスコ\u3000世界消費関連成長株ファンド',
        fund_name_yomi='インベスコセカイショウヒカンレンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G14449': FundCodeEntry(
        fund_code='G14449',
        sec_code=None,
        fund_name='第１２２回\u3000２０２４年３月１１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウニカイニセンニジュウヨネンサンガツジュウイチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月11日',
        period_2='9月11日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14450': FundCodeEntry(
        fund_code='G14450',
        sec_code=None,
        fund_name='キャピタル日本株式ファンド（ＤＣ年金用）',
        fund_name_yomi='キャピタルニホンカブシキファンドディーシーネンキンヨウ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G14451': FundCodeEntry(
        fund_code='G14451',
        sec_code='28430',
        fund_name='上場インデックスファンド豪州国債（為替ヘッジあり）',
        fund_name_yomi='ジョウジョウインデックスファンドゴウシュウコクサイ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14452': FundCodeEntry(
        fund_code='G14452',
        sec_code='28440',
        fund_name='上場インデックスファンド豪州国債（為替ヘッジなし）',
        fund_name_yomi='ジョウジョウインデックスファンドゴウシュウコクサイ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14453': FundCodeEntry(
        fund_code='G14453',
        sec_code=None,
        fund_name='Ｓ＆Ｐ５００・４倍ブル型ファンド',
        fund_name_yomi='エスアンドピイゴヒャクヨンバイブルガタファンド',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14454': FundCodeEntry(
        fund_code='G14454',
        sec_code=None,
        fund_name='しんきん国内株式インデックス（投資一任用）',
        fund_name_yomi='シンキンコクナイカブシキインデックストウシイチニンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14455': FundCodeEntry(
        fund_code='G14455',
        sec_code=None,
        fund_name='しんきん国内債券インデックス（投資一任用）',
        fund_name_yomi='シンキンコクナイサイケンインデックストウシイチニンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14456': FundCodeEntry(
        fund_code='G14456',
        sec_code=None,
        fund_name='しんきん先進国債券インデックス（為替ヘッジあり）（投資一任用）／（為替ヘッジなし）（投資一任用）',
        fund_name_yomi='シンキンセンシンコクサイケンインデックスカワセヘッジアリトウシイチニンヨウカワセヘッジナシトウシイチニンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14457': FundCodeEntry(
        fund_code='G14457',
        sec_code=None,
        fund_name='ダイワ先進国株式インデックス（為替ヘッジあり・なし）（投資一任専用）',
        fund_name_yomi='ダイワセンシンコクカブシキインデックスカワセヘッジアリナシトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14458': FundCodeEntry(
        fund_code='G14458',
        sec_code=None,
        fund_name='ダイワ新興国株式インデックス（為替ヘッジなし）（投資一任専用）',
        fund_name_yomi='ダイワシンコウコクカブシキインデックスカワセヘッジナシトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14459': FundCodeEntry(
        fund_code='G14459',
        sec_code=None,
        fund_name='ダイワ新興国債券インデックス（為替ヘッジなし）（投資一任専用）',
        fund_name_yomi='ダイワシンコウコクサイケンインデックスカワセヘッジナシトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14460': FundCodeEntry(
        fund_code='G14460',
        sec_code=None,
        fund_name='ダイワ海外ＲＥＩＴインデックス（為替ヘッジあり・なし）（投資一任専用）',
        fund_name_yomi='ダイワカイガイリートインデックスカワセヘッジアリナシトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14461': FundCodeEntry(
        fund_code='G14461',
        sec_code=None,
        fund_name='ダイワ国内ＲＥＩＴインデックス（投資一任専用）',
        fund_name_yomi='ダイワコクナイリートインデックストウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14462': FundCodeEntry(
        fund_code='G14462',
        sec_code=None,
        fund_name='第１５６回２０２６年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウロッカイニセンニジュウロクネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14463': FundCodeEntry(
        fund_code='G14463',
        sec_code=None,
        fund_name='第１５７回２０２５年３月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウナナカイニセンニジュウゴネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14464': FundCodeEntry(
        fund_code='G14464',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ－アクティブ・クライメート・アウェア（米ドル）',
        fund_name_yomi='ユービーエスルクスエクイティシキャブアクティブクライメートアウェアベイドル',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E30637',
        issuer_name='ＵＢＳ（Ｌｕｘ）エクイティ・シキャブ',
    ),
    'G14465': FundCodeEntry(
        fund_code='G14465',
        sec_code=None,
        fund_name='第１２３回\u3000２０２４年４月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウサンカイニセンニジュウヨネンシガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14466': FundCodeEntry(
        fund_code='G14466',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国バランス（２資産均等型）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクバランス\u3000ニシサンキントウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14467': FundCodeEntry(
        fund_code='G14467',
        sec_code=None,
        fund_name='野村グローバル・クレジット・ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村グローバル・クレジット・ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラグローバルクレジットファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラグローバルクレジットファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14468': FundCodeEntry(
        fund_code='G14468',
        sec_code=None,
        fund_name='野村為替ヘッジ付き世界債券ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラカワセヘッジツキセカイサイケンファンドノムラエスエムエーイーダブルムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14469': FundCodeEntry(
        fund_code='G14469',
        sec_code=None,
        fund_name='野村ブラックロック世界ＲＥＩＴファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村ブラックロック世界ＲＥＩＴファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラブラックロックセカイリートファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラブラックロックセカイリートファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14471': FundCodeEntry(
        fund_code='G14471',
        sec_code=None,
        fund_name='グローバル仮想世界株式戦略ファンド',
        fund_name_yomi='グローバルカソウセカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14472': FundCodeEntry(
        fund_code='G14472',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン赤羽志茂（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンアカバネシモジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14473': FundCodeEntry(
        fund_code='G14473',
        sec_code=None,
        fund_name='米国株式マーケット・キャッチ戦略ファンド',
        fund_name_yomi='ベイコクカブシキマーケットキャッチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月8日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14474': FundCodeEntry(
        fund_code='G14474',
        sec_code=None,
        fund_name='第１２４回\u3000２０２５年４月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウヨンカイニセンニジュウゴネンシガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14475': FundCodeEntry(
        fund_code='G14475',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０７０',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14476': FundCodeEntry(
        fund_code='G14476',
        sec_code=None,
        fund_name='フィデリティ・ターゲット・デート・ファンド（ベーシック）２０６５',
        fund_name_yomi='フィデリティターゲットデートファンドベーシックニセンロクジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14477': FundCodeEntry(
        fund_code='G14477',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－シティグループ社債\u3000償還時目標設定型ファンド２２０３',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000シティグループシャサイショウカンジモクヒョウセッテイガタファンドニニゼロサン',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G14478': FundCodeEntry(
        fund_code='G14478',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・オープン（為替ヘッジなし／予想分配金提示型）',
        fund_name_yomi='ダイワユーエスリートオープンカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14479': FundCodeEntry(
        fund_code='G14479',
        sec_code=None,
        fund_name='（ラップ専用）ＳＢＩ・米国株式、（ラップ専用）ＳＢＩ・先進国株式、（ラップ専用）ＳＢＩ・新興国株式、（ラップ専用）ＳＢＩ・米国債券、（ラップ専用）ＳＢＩ・米国ハイイールド債券、（ラップ専用）ＳＢＩ・新興国債券、（ラップ専用）ＳＢＩ・米国不動産、（ラップ専用）ＳＢＩ・ゴールド',
        fund_name_yomi='ラップセンヨウ\u3000エスビーアイ\u3000ベイコクカブシキ\u3000ラップセンヨウ\u3000エスビーアイ\u3000センシンコクカブシキ\u3000ラップセンヨウ\u3000エスビーアイ\u3000シンコウコクカブシキ\u3000ラップセンヨウ\u3000エスビーアイ\u3000ベイコクサイケン\u3000ラップセンヨウ\u3000エスビーアイ\u3000ベイコクハイイールドサイケン\u3000ラップセンヨウ\u3000エスビーアイ\u3000シンコウコクサイケン\u3000ラップセンヨウ\u3000エスビーアイ\u3000ベイコクフドウサン\u3000ラップセンヨウ\u3000エスビーアイ\u3000ゴールド',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14480': FundCodeEntry(
        fund_code='G14480',
        sec_code=None,
        fund_name='日興ワールド・トラスト－ブリッジウォーター・マクロ戦略ファンド',
        fund_name_yomi='ニッコウワールドトラストブリッジウォーターマクロセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G14481': FundCodeEntry(
        fund_code='G14481',
        sec_code=None,
        fund_name='不動産のデジタル証券～草津温泉\u3000湯宿季の庭・お宿木の葉～（譲渡制限付）',
        fund_name_yomi='フドウサンノデジタルショウケンクサツオンセンユヤドトキノニワオヤドコノハジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14482': FundCodeEntry(
        fund_code='G14482',
        sec_code=None,
        fund_name='ＩＣＪ\u3000ＧＯＬＤ',
        fund_name_yomi='アイシージェイ\u3000ゴールド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G14483': FundCodeEntry(
        fund_code='G14483',
        sec_code=None,
        fund_name='楽天日本株３．８倍ベアⅡ',
        fund_name_yomi='ラクテンニホンカブサンテンハチバイベアツー',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14484': FundCodeEntry(
        fund_code='G14484',
        sec_code=None,
        fund_name='楽天日本株トリプル・ベアⅤ',
        fund_name_yomi='ラクテンニホンカブトリプル\u3000ベアファイブ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14485': FundCodeEntry(
        fund_code='G14485',
        sec_code=None,
        fund_name='グローバル・ストラテジーズ・トラスト－債券パワード・インカムファンド',
        fund_name_yomi='グローバルストラテジーズトラスト\u3000サイケンパワードインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E27921',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G14486': FundCodeEntry(
        fund_code='G14486',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000コミュニケーションＤＸ',
        fund_name_yomi='イーマクシスネオコミュニケーションディーエックス',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14487': FundCodeEntry(
        fund_code='G14487',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000水素エコノミー',
        fund_name_yomi='イーマクシスネオスイソエコノミー',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14488': FundCodeEntry(
        fund_code='G14488',
        sec_code='28460',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ダウ・ジョーンズ工業株３０種平均株価（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズダウジョーンズコウギョウカブサンジュウシュヘイキンカブカカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14489': FundCodeEntry(
        fund_code='G14489',
        sec_code='28450',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＮＡＳＤＡＱ－１００（Ｒ）（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズナスダックヒャクアールカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14490': FundCodeEntry(
        fund_code='G14490',
        sec_code=None,
        fund_name='パインブリッジ厳選インド株式ファンド',
        fund_name_yomi='パインブリッジゲンセンインドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G14491': FundCodeEntry(
        fund_code='G14491',
        sec_code=None,
        fund_name='グローバル・ダイナミック・ボンド・ファンド\u3000Ａコース、グローバル・ダイナミック・ボンド・ファンド\u3000Ｂコース',
        fund_name_yomi='グローバルダイナミックボンドファンドエーコース\u3000グローバルダイナミックボンドファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14492': FundCodeEntry(
        fund_code='G14492',
        sec_code=None,
        fund_name='ＳＯＭＰＯターゲットイヤー・ファンド２０６５',
        fund_name_yomi='ソンポターゲットイヤーファンドニゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='11月2日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14493': FundCodeEntry(
        fund_code='G14493',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投信\u3000米国株式インデックス',
        fund_name_yomi='ペイペイトウシン\u3000ベイコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E14601',
        issuer_name='ＰａｙＰａｙアセットマネジメント株式会社',
    ),
    'G14494': FundCodeEntry(
        fund_code='G14494',
        sec_code=None,
        fund_name='明治安田Ｎｅｘｔグローバル・リート（予想分配金提示型）\u3000明治安田Ｎｅｘｔグローバル・リート（資産成長型）',
        fund_name_yomi='メイジヤスダネクストグローバルリートヨソウブンパイキンテイジガタ\u3000メイジヤスダネクストグローバルリートシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2='8月18日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14496': FundCodeEntry(
        fund_code='G14496',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000ダウ・ジョーンズ・インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ダウ\u3000ジョーンズ\u3000インデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14497': FundCodeEntry(
        fund_code='G14497',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000Ｓ＆Ｐ５００インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000エスアンドピーゴヒャクインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14499': FundCodeEntry(
        fund_code='G14499',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000新興国債券インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000シンコウコクサイケンインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14502': FundCodeEntry(
        fund_code='G14502',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000国内債券インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000コクナイサイケンインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14503': FundCodeEntry(
        fund_code='G14503',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000グローバル債券インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000グローバルサイケンインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14504': FundCodeEntry(
        fund_code='G14504',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000Ｊ－ＲＥＩＴインデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ジェイリートインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14505': FundCodeEntry(
        fund_code='G14505',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000グローバルＲＥＩＴインデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000グローバルリートインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14506': FundCodeEntry(
        fund_code='G14506',
        sec_code=None,
        fund_name='グローバル・メタバース株式ファンド',
        fund_name_yomi='グローバル\u3000メタバースカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14507': FundCodeEntry(
        fund_code='G14507',
        sec_code=None,
        fund_name='ＳＯＭＰＯエイゴン・グローバル・サステナブル株式ファンド',
        fund_name_yomi='ソンポエイゴングローバルサステナブルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14508': FundCodeEntry(
        fund_code='G14508',
        sec_code=None,
        fund_name='ニッセイ・メタバースワールド（資産成長型）',
        fund_name_yomi='ニッセイメタバースワールドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14509': FundCodeEntry(
        fund_code='G14509',
        sec_code=None,
        fund_name='ニッセイ・メタバースワールド（予想分配金提示型）',
        fund_name_yomi='ニッセイメタバースワールドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14510': FundCodeEntry(
        fund_code='G14510',
        sec_code=None,
        fund_name='楽天・世界債券コア（為替ヘッジ付）ファンド＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000セカイサイケンコア\u3000カワセヘッジツキ\u3000ファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14511': FundCodeEntry(
        fund_code='G14511',
        sec_code=None,
        fund_name='楽天・先進国低ボラティリティ株式ファンド（為替ヘッジあり）＜ラップ向け＞、楽天・先進国低ボラティリティ株式ファンド（為替ヘッジなし）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000センシンコクテイボラティリティカブシキファンド\u3000カワセヘッジアリ\u3000\u3000ラップムケ\u3000\u3000ラクテン\u3000センシンコクテイボラティリティカブシキファンド\u3000カワセヘッジナシ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14512': FundCodeEntry(
        fund_code='G14512',
        sec_code='28470',
        fund_name='グローバルＸ\u3000新成長インフラ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスシンセイチョウインフラニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14513': FundCodeEntry(
        fund_code='G14513',
        sec_code='28480',
        fund_name='グローバルＸ\u3000ＭＳＣＩ\u3000気候変動対応－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエムエスシーアイキコウヘンドウタイオウニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14514': FundCodeEntry(
        fund_code='G14514',
        sec_code='28490',
        fund_name='グローバルＸ\u3000Ｍｏｒｎｉｎｇｓｔａｒ\u3000高配当\u3000ＥＳＧ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスモーニングスターコウハイトウイーエスジーニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14515': FundCodeEntry(
        fund_code='G14515',
        sec_code=None,
        fund_name='第１５８回２０２６年１２月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウハチカイニセンニジュウロクネンジュウニガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14516': FundCodeEntry(
        fund_code='G14516',
        sec_code=None,
        fund_name='第１５９回２０２５年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクゴジュウキュウカイニセンニジュウゴネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14517': FundCodeEntry(
        fund_code='G14517',
        sec_code=None,
        fund_name='第１２５回\u3000２０２４年５月１４日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウゴカイニセンニジュウヨネンゴガツジュウヨッカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14519': FundCodeEntry(
        fund_code='G14519',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２２－０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイニイノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14520': FundCodeEntry(
        fund_code='G14520',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２２－Ⅰ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイニイノイチ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14521': FundCodeEntry(
        fund_code='G14521',
        sec_code=None,
        fund_name='ＥＳＧ海洋関連株式ファンド',
        fund_name_yomi='イーエスジーカイヨウカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14522': FundCodeEntry(
        fund_code='G14522',
        sec_code=None,
        fund_name='第１２６回\u3000２０２５年５月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウロッカイニセンニジュウゴネンゴガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月12日',
        period_2='11月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14523': FundCodeEntry(
        fund_code='G14523',
        sec_code=None,
        fund_name='日本次世代経営者ファンド',
        fund_name_yomi='ニホンジセダイケイエイシャファンド',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14524': FundCodeEntry(
        fund_code='G14524',
        sec_code=None,
        fund_name='バロン・グローバル・フューチャー戦略ファンド（資産成長型）\u3000バロン・グローバル・フューチャー戦略ファンド（予想分配金提示型）',
        fund_name_yomi='バロングローバルフューチャーセンリャクファンドシサンセイチョウガタ\u3000バロングローバルフューチャーセンリャクファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14525': FundCodeEntry(
        fund_code='G14525',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＳｏｌａｃｔｉｖｅジャパンＥＳＧコア指数連動型上場投信',
        fund_name_yomi='ネクストファンズソラクティブジャパンイーエスジーコアシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14526': FundCodeEntry(
        fund_code='G14526',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ＭＩＲＡＩｎｄｅｘ\u3000総合',
        fund_name_yomi='エスエムティー\u3000ミラインデックス\u3000ソウゴウ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14527': FundCodeEntry(
        fund_code='G14527',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ブラックストーン・リアルエステート・インカム・トラスト・ファンド',
        fund_name_yomi='ノムラファンドセレクトブラックストーンリアルエステートインカムトラストファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G14528': FundCodeEntry(
        fund_code='G14528',
        sec_code=None,
        fund_name='脱炭素テクノロジー株式ファンド（予想分配金提示型）',
        fund_name_yomi='ダツタンソテクノロジーカブシキファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14529': FundCodeEntry(
        fund_code='G14529',
        sec_code=None,
        fund_name='ＤＣ次世代通信関連\u3000世界株式戦略ファンド',
        fund_name_yomi='ディーシージセダイツウシンカンレン\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14530': FundCodeEntry(
        fund_code='G14530',
        sec_code=None,
        fund_name='ＤＣ脱炭素関連\u3000世界株式戦略ファンド',
        fund_name_yomi='ディーシーダツタンソカンレン\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14531': FundCodeEntry(
        fund_code='G14531',
        sec_code=None,
        fund_name='日本インフラ投信ファンド',
        fund_name_yomi='ニホンインフラトウシンファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14532': FundCodeEntry(
        fund_code='G14532',
        sec_code=None,
        fund_name='ＤＣダイワＳ＆Ｐ５００インデックス',
        fund_name_yomi='ディーシーダイワエスアンドピーゴヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14533': FundCodeEntry(
        fund_code='G14533',
        sec_code=None,
        fund_name='ダブル・ブレイン・コア（マイルド）、ダブル・ブレイン・コア（スタンダード）、ダブル・ブレイン・コア（ブル）',
        fund_name_yomi='ダブルブレインコアマイルド\u3000ダブルブレインコアスタンダード\u3000ダブルブレインコアブル',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14534': FundCodeEntry(
        fund_code='G14534',
        sec_code=None,
        fund_name='中国Ａ株再生可能エネルギー関連プレミアムα',
        fund_name_yomi='チュウゴクエイカブサイセイカノウエネルギーカンレンプレミアムアルファ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14535': FundCodeEntry(
        fund_code='G14535',
        sec_code=None,
        fund_name='日本生命第７回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイナナカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E37634',
        issuer_name='日本生命第７回劣後ローン流動化株式会社',
    ),
    'G14536': FundCodeEntry(
        fund_code='G14536',
        sec_code=None,
        fund_name='ブラックロック・リスク抑制分散投資ファンド（満期償還時\u3000上値限定・元本確保契約付）２０２２－０７',
        fund_name_yomi='ブラックロックリスクヨクセイブンサントウシファンドマンキショウカンジウワネゲンテイガンポンカクホケイヤクツキニイゼロニイニイゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14537': FundCodeEntry(
        fund_code='G14537',
        sec_code=None,
        fund_name='ステート・ストリート世界厳選成長株ファンド',
        fund_name_yomi='ステートストリートセカイゲンセンセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G14538': FundCodeEntry(
        fund_code='G14538',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット２０２２－０６（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウニ\u3000ゼロロク\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14539': FundCodeEntry(
        fund_code='G14539',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000オールカントリー（全世界株式）ＥＳＧインデックス',
        fund_name_yomi='アイフリーオールカントリーゼンセカイカブシキイーエスジーインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14540': FundCodeEntry(
        fund_code='G14540',
        sec_code=None,
        fund_name='クライメート・ソリューション・ファンド',
        fund_name_yomi='クライメートソリューションファンド',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14541': FundCodeEntry(
        fund_code='G14541',
        sec_code=None,
        fund_name='マルチ・マネージャー・アクセス－グリーン・ソーシャル・アンド・サステナブル・ボンド',
        fund_name_yomi='マルチマネージャーアクセスグリーンソーシャルアンドサステナブルボンド',
        security_type='外国投資証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E32029',
        issuer_name='マルチ・マネージャー・アクセス',
    ),
    'G14542': FundCodeEntry(
        fund_code='G14542',
        sec_code=None,
        fund_name='第１２７回\u3000２０２４年６月１０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウナナカイニセンニジュウヨネンロクガツトオカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14543': FundCodeEntry(
        fund_code='G14543',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000Ｓｅｌｅｃｔ\u3000全世界株式インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000セレクト\u3000ゼンセカイカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14544': FundCodeEntry(
        fund_code='G14544',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000Ｓｅｌｅｃｔ\u3000全世界株式インデックス（除く日本）',
        fund_name_yomi='スマート\u3000アイ\u3000セレクト\u3000ゼンセカイカブシキインデックス\u3000ノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14545': FundCodeEntry(
        fund_code='G14545',
        sec_code='28530',
        fund_name='ｉシェアーズ\u3000気候リスク調整世界国債\u3000ＥＴＦ（除く日本・為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000キコウリスクチョウセイセカイコクサイ\u3000イーティーエフ\u3000ノゾクニホン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14546': FundCodeEntry(
        fund_code='G14546',
        sec_code='28520',
        fund_name='ｉシェアーズ\u3000グリーンＪリート\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000グリーンジェイリート\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14547': FundCodeEntry(
        fund_code='G14547',
        sec_code='28510',
        fund_name='ｉシェアーズ\u3000ＭＳＣＩ\u3000ジャパンＳＲＩ\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エムエスシーアイ\u3000ジャパンエスアールアイ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14548': FundCodeEntry(
        fund_code='G14548',
        sec_code=None,
        fund_name='第１６０回２０２７年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュッカイニセンニジュウナナネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14549': FundCodeEntry(
        fund_code='G14549',
        sec_code=None,
        fund_name='第１６１回２０２５年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウイッカイニセンニジュウゴネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月11日',
        period_2='11月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14551': FundCodeEntry(
        fund_code='G14551',
        sec_code=None,
        fund_name='第１２８回\u3000２０２５年６月１１日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウハチカイニセンニジュウゴネンロクガツジュウイチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14552': FundCodeEntry(
        fund_code='G14552',
        sec_code=None,
        fund_name='ゴールベースラップ・ファンド',
        fund_name_yomi='ゴールベースラップファンド',
        security_type='内国投資信託受益証券',
        period_1='3月29日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14553': FundCodeEntry(
        fund_code='G14553',
        sec_code=None,
        fund_name='あおぞら・徹底分散グローバル・サステナビリティ株式ファンド',
        fund_name_yomi='アオゾラテッテイブンサングローバルサステナビリティカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14554': FundCodeEntry(
        fund_code='G14554',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／国際分散投資戦略ファンド２０２２－０５',
        fund_name_yomi='ゴールドマンサックスシャサイコクサイブンサントウシセンリャクファンドニイゼロニイニイゼロゴウ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14555': FundCodeEntry(
        fund_code='G14555',
        sec_code=None,
        fund_name='ＳＯＭＰＯスイッチ\u3000ＮＡＳＤＡＱ１００\u3000レバレッジ２．５倍',
        fund_name_yomi='ソンポスイッチ\u3000ナスダックヒャク\u3000レバレッジニテンゴバイ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14556': FundCodeEntry(
        fund_code='G14556',
        sec_code=None,
        fund_name='ＥＳＧ\u3000ＧＯＬＤ',
        fund_name_yomi='イーエスジー\u3000ゴールド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G14557': FundCodeEntry(
        fund_code='G14557',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅡ\u3000２０２２－０６',
        fund_name_yomi='ワンエンダテサイケンファンドツーニイゼロニイニイゼロロク',
        security_type='内国投資信託受益証券',
        period_1='10月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14558': FundCodeEntry(
        fund_code='G14558',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ダイワ・ＷｉＬ３号ベンチャーキャピタル・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーダイワウィルサンゴウベンチャーキャピタルファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G14559': FundCodeEntry(
        fund_code='G14559',
        sec_code=None,
        fund_name='１０資産分散投資ファンド',
        fund_name_yomi='ジュウシサンブンサントウシファンド',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14560': FundCodeEntry(
        fund_code='G14560',
        sec_code=None,
        fund_name='不動産のデジタル証券～ＡＬＴＥＲＮＡレジデンス新宿中落合・経堂・門前仲町～（譲渡制限付）',
        fund_name_yomi='フドウサンノデジタルショウケンオルタナレジデンスシンジュクナカオチアイキョウドウモンゼンナカチョウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14561': FundCodeEntry(
        fund_code='G14561',
        sec_code=None,
        fund_name='第１６２回２０２７年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウニカイニセンニジュウナナネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14562': FundCodeEntry(
        fund_code='G14562',
        sec_code=None,
        fund_name='第１６３回２０２５年６月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウサンカイニセンニジュウゴネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月11日',
        period_2='12月11日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14563': FundCodeEntry(
        fund_code='G14563',
        sec_code=None,
        fund_name='第１２９回\u3000２０２４年７月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクニジュウキュウカイニセンニジュウヨネンシチガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月16日',
        period_2='7月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14564': FundCodeEntry(
        fund_code='G14564',
        sec_code=None,
        fund_name='第１３０回\u3000２０２５年７月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウカイニセンニジュウゴネンシチガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14565': FundCodeEntry(
        fund_code='G14565',
        sec_code=None,
        fund_name='みずほグローバル・ターゲット利回り債券ファンド２０２２－０６（限定追加型）',
        fund_name_yomi='ミズホグローバルターゲットリマワリサイケンファンドニイゼロニイニイゼロロクゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14566': FundCodeEntry(
        fund_code='G14566',
        sec_code=None,
        fund_name='野村ＤＣバランスファンド（年金運用戦略タイプ）',
        fund_name_yomi='ノムラディーシーバランスファンドネンキンウンヨウセンリャクタイプ',
        security_type='内国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14567': FundCodeEntry(
        fund_code='G14567',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・アメリカ地方債ファンド（為替ヘッジあり）\u3000フランクリン・テンプルトン・アメリカ地方債ファンド（為替ヘッジなし）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000アメリカチホウサイファンド\u3000カワセヘッジアリ\u3000フランクリン\u3000テンプルトン\u3000アメリカチホウサイファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G14568': FundCodeEntry(
        fund_code='G14568',
        sec_code=None,
        fund_name='ステート・ストリート世界厳選成長株ファンド（ＦＷ専用）',
        fund_name_yomi='ステートストリートセカイゲンセンセイチョウカブファンドファンドラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G14569': FundCodeEntry(
        fund_code='G14569',
        sec_code=None,
        fund_name='ソフトバンクグループ＆日本企業厳選債券ファンド２０２２－０６',
        fund_name_yomi='ソフトバンクグループ\u3000アンド\u3000ニホンキギョウゲンセンサイケンファンド\u3000ニゼロニニ\u3000ゼロロク',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14570': FundCodeEntry(
        fund_code='G14570',
        sec_code=None,
        fund_name='マニュライフ・中国債券インカム・ファンドＡコース（米ドル売り円買い）、マニュライフ・中国債券インカム・ファンドＢコース（為替ヘッジなし）',
        fund_name_yomi='マニュライフチュウゴクサイケンインカムファンドエーコースベイドルウリエンガイ\u3000マニュライフチュウゴクサイケンインカムファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G14571': FundCodeEntry(
        fund_code='G14571',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000米国株式（Ｓ＆Ｐ５００）インデックス・ファンド（ＤＣ）',
        fund_name_yomi='アイシェアーズベイコクカブシキエスアンドピーゴヒャクインデックスファンドディーシー',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14572': FundCodeEntry(
        fund_code='G14572',
        sec_code=None,
        fund_name='ジュエル・ボックス・ファンド',
        fund_name_yomi='ジュエルボックスファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E37705',
        issuer_name='エマージング・アセット・マネジメント・リミテッド',
    ),
    'G14573': FundCodeEntry(
        fund_code='G14573',
        sec_code=None,
        fund_name='第１６４回２０２７年３月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウヨンカイニセンニジュウナナネンサンガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14574': FundCodeEntry(
        fund_code='G14574',
        sec_code=None,
        fund_name='第１６５回２０２５年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウゴカイニセンニジュウゴネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月12日',
        period_2='7月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14575': FundCodeEntry(
        fund_code='G14575',
        sec_code='28540',
        fund_name='グローバルＸ\u3000テック・トップ２０ー日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックステックトップニジュウニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14576': FundCodeEntry(
        fund_code='G14576',
        sec_code='28550',
        fund_name='グローバルＸ\u3000グリーン・Ｊ－ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスグリーンジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14578': FundCodeEntry(
        fund_code='G14578',
        sec_code=None,
        fund_name='グローバル・オルタナティブ戦略ファンド',
        fund_name_yomi='グローバルオルタナティブセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E37705',
        issuer_name='エマージング・アセット・マネジメント・リミテッド',
    ),
    'G14579': FundCodeEntry(
        fund_code='G14579',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２２－０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイニイノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14580': FundCodeEntry(
        fund_code='G14580',
        sec_code=None,
        fund_name='第１３１回\u3000２０２５年８月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウイチカイニセンニジュウゴネンハチガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14581': FundCodeEntry(
        fund_code='G14581',
        sec_code=None,
        fund_name='楽天・先進国債券アルファ戦略ファンド（為替ヘッジあり）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000センシンコクサイケンアルファセンリャクファンド\u3000カワセヘッジアリ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14582': FundCodeEntry(
        fund_code='G14582',
        sec_code=None,
        fund_name='いちよし・グローバル株式ファンド',
        fund_name_yomi='イチヨシグローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14583': FundCodeEntry(
        fund_code='G14583',
        sec_code=None,
        fund_name='第１３２回\u3000２０２５年８月１３日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウニカイニセンニジュウゴネンハチガツジュウサンニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月13日',
        period_2='8月13日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14584': FundCodeEntry(
        fund_code='G14584',
        sec_code=None,
        fund_name='野村ハイパーブル・ベア９',
        fund_name_yomi='ノムラハイパーブルベアナイン',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14585': FundCodeEntry(
        fund_code='G14585',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000インフラ株式ファンド（為替ヘッジあり・なし／資産成長型）（為替ヘッジあり・なし／予想分配金提示型）',
        fund_name_yomi='モルガンスタンレーインフラカブシキファンドカワセヘッジアリナシシサンセイチョウガタカワセヘッジアリナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14586': FundCodeEntry(
        fund_code='G14586',
        sec_code=None,
        fund_name='明治安田生命第２回劣後ローン流動化株式会社',
        fund_name_yomi='メイジヤスダセイメイダイニカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E37827',
        issuer_name='明治安田生命第２回劣後ローン流動化株式会社',
    ),
    'G14587': FundCodeEntry(
        fund_code='G14587',
        sec_code=None,
        fund_name='Ｊプレミアム・インカムファンド（年１回決算型）',
        fund_name_yomi='ジェイプレミアムインカムファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月28日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14588': FundCodeEntry(
        fund_code='G14588',
        sec_code=None,
        fund_name='Ｊプレミアム・インカムファンド（年４回決算型）',
        fund_name_yomi='ジェイプレミアムインカムファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月28日',
        period_2='10月28日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14589': FundCodeEntry(
        fund_code='G14589',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・Ｍ＆Ａプレミアム（為替ヘッジあり）、アライアンス・バーンスタイン・Ｍ＆Ａプレミアム（為替ヘッジなし）',
        fund_name_yomi='アライアンスバーンスタインエムアンドエープレミアムカワセヘッジアリ\u3000アライアンスバーンスタインエムアンドエープレミアムカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14590': FundCodeEntry(
        fund_code='G14590',
        sec_code=None,
        fund_name='イーストスプリング・インド・コア株式ファンド',
        fund_name_yomi='イーストスプリングインドコアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G14591': FundCodeEntry(
        fund_code='G14591',
        sec_code=None,
        fund_name='イーストスプリング・ベトナム株式ファンド',
        fund_name_yomi='イーストスプリングベトナムカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G14592': FundCodeEntry(
        fund_code='G14592',
        sec_code=None,
        fund_name='ＪＰＭグローバル高利回りＣＢファンド（為替ヘッジなし、限定追加型）２０２２ー０８／ＪＰＭグローバル高利回りＣＢファンド（為替ヘッジあり、限定追加型）２０２２ー０８',
        fund_name_yomi='ジェイピーエムグローバルコウリマワリシービーファンドカワセヘッジナシゲンテイツイカガタニセンニジュウニノゼロハチ\u3000ジェイピーエムグローバルコウリマワリシービーファンドカワセヘッジアリゲンテイツイカガタニセンニジュウニノゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='8月9日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G14593': FundCodeEntry(
        fund_code='G14593',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークンロンコプロフィットマート厚木Ⅰ（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンロンコプロフィットマートアツギワンジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14594': FundCodeEntry(
        fund_code='G14594',
        sec_code=None,
        fund_name='野村サステナブルセレクト',
        fund_name_yomi='ノムラサステナブルセレクト',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14595': FundCodeEntry(
        fund_code='G14595',
        sec_code='28560',
        fund_name='ｉシェアーズ\u3000米国債３－７年\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイサンナナネン\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14596': FundCodeEntry(
        fund_code='G14596',
        sec_code='28570',
        fund_name='ｉシェアーズ\u3000ドイツ国債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ドイツコクサイ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14597': FundCodeEntry(
        fund_code='G14597',
        sec_code=None,
        fund_name='ＳＢＩ－ＰＩＭＣＯ\u3000ジャパン・ベターインカム・ファンド（愛称：ベタイン）',
        fund_name_yomi='エスビーアイ\u3000ピムコ\u3000ジャパン\u3000ベターインカム\u3000ファンド\u3000アイショウ\u3000ベタイン',
        security_type='内国投資信託受益証券',
        period_1='6月29日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14598': FundCodeEntry(
        fund_code='G14598',
        sec_code=None,
        fund_name='ＳＢＩ－ＰＩＭＣＯ\u3000世界債券アクティブファンド（ＤＣ）',
        fund_name_yomi='エスビーアイ\u3000ピムコ\u3000セカイサイケン\u3000アクティブファンド\u3000ディーシー',
        security_type='内国投資信託受益証券',
        period_1='10月3日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14599': FundCodeEntry(
        fund_code='G14599',
        sec_code=None,
        fund_name='ＳＢＩ地方創生・世界高配当株式ファンド（為替ヘッジあり）＜資産成長コース＞、ＳＢＩ地方創生・世界高配当株式ファンド（為替ヘッジあり）＜年３％定率払出しコース＞＜年５％定率払出しコース＞＜年７％定率払出しコース＞',
        fund_name_yomi='エスビーアイ\u3000チホウソウセイ\u3000セカイコウハイトウカブシキファンド\u3000カワセヘッジアリ\u3000シサンセイチョウコース\u3000エスビーアイ\u3000チホウソウセイ\u3000セカイコウハイトウカブシキファンド\u3000カワセヘッジアリ\u3000ネン\u3000サンパーセントテイリツハライダシコース\u3000ネン\u3000ゴパーセントテイリツハライダシコース\u3000ネン\u3000ナナパーセントテイリツハライダシコース',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14600': FundCodeEntry(
        fund_code='G14600',
        sec_code=None,
        fund_name='ａｕＡＭレバレッジＮＡＳＤＡＱ１００',
        fund_name_yomi='エーユーエーエムレバレッジナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G14601': FundCodeEntry(
        fund_code='G14601',
        sec_code=None,
        fund_name='第１６６回２０２７年６月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウロッカイニセンニジュウナナネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14602': FundCodeEntry(
        fund_code='G14602',
        sec_code=None,
        fund_name='第１６７回２０２５年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウナナカイニセンニジュウゴネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14603': FundCodeEntry(
        fund_code='G14603',
        sec_code=None,
        fund_name='第１３３回\u3000２０２４年９月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウサンカイニセンニジュウヨネンクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14604': FundCodeEntry(
        fund_code='G14604',
        sec_code=None,
        fund_name='第１３４回\u3000２０２５年９月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウヨンカイニセンニジュウゴネンクガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14605': FundCodeEntry(
        fund_code='G14605',
        sec_code=None,
        fund_name='グローバル・アグリカルチャー＆フード株式ファンド',
        fund_name_yomi='グローバル\u3000アグリカルチャーアンドフードカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14606': FundCodeEntry(
        fund_code='G14606',
        sec_code='28580',
        fund_name='グローバルＸ\u3000日経２２５\u3000カバード・コール\u3000ＥＴＦ（プレミアム再投資型）',
        fund_name_yomi='グローバルエックスニッケイニヒャクニジュウゴカバードコールイーティーエフ\u3000プレミアムサイトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14609': FundCodeEntry(
        fund_code='G14609',
        sec_code=None,
        fund_name='楽天・資産づくりファンドぷらす＋（のんびりコース）／楽天・資産づくりファンドぷらす＋（じっくりコース）／楽天・資産づくりファンドぷらす＋（なかなかコース）／楽天・資産づくりファンドぷらす＋（しっかりコース）／楽天・資産づくりファンドぷらす＋（がっちりコース）',
        fund_name_yomi='ラクテン\u3000シサンヅクリファンドプラス\u3000ノンビリコース\u3000ラクテン\u3000シサンヅクリファンドプラス\u3000ジックリコース\u3000ラクテン\u3000シサンヅクリファンドプラス\u3000ナカナカコース\u3000ラクテン\u3000シサンヅクリファンドプラス\u3000シッカリコース\u3000ラクテン\u3000シサンヅクリファンドプラス\u3000ガッチリコース',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14610': FundCodeEntry(
        fund_code='G14610',
        sec_code=None,
        fund_name='カレラ成長日本列島株式ファンド',
        fund_name_yomi='カレラセイチョウニッポンレットウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14611': FundCodeEntry(
        fund_code='G14611',
        sec_code=None,
        fund_name='第１３５回\u3000２０２５年９月１０日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウゴカイニセンニジュウゴネンクガツトオカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14612': FundCodeEntry(
        fund_code='G14612',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅡ\u3000２０２２－０９',
        fund_name_yomi='ワンエンダテサイケンファンドツーニイゼロニイニイゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='1月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14613': FundCodeEntry(
        fund_code='G14613',
        sec_code=None,
        fund_name='ＬＧＴ上場プライベート・エクイティ戦略ファンド',
        fund_name_yomi='エルジーティージョウジョウプライベートエクイティセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='8月24日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14614': FundCodeEntry(
        fund_code='G14614',
        sec_code='28620',
        fund_name='上場インデックスファンドフランス国債（為替ヘッジあり）',
        fund_name_yomi='ジョウジョウインデックスファンドフランスコクサイ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14615': FundCodeEntry(
        fund_code='G14615',
        sec_code='28610',
        fund_name='上場インデックスファンドフランス国債（為替ヘッジなし）',
        fund_name_yomi='ジョウジョウインデックスファンドフランスコクサイ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14616': FundCodeEntry(
        fund_code='G14616',
        sec_code=None,
        fund_name='不動産のデジタル証券～ＡＬＴＥＲＮＡレジデンス\u3000銀座・代官山～（譲渡制限付）',
        fund_name_yomi='フドウサンノデジタルショウケンオルタナレジデンスギンザダイカンヤマジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14617': FundCodeEntry(
        fund_code='G14617',
        sec_code=None,
        fund_name='マイライフエール',
        fund_name_yomi='マイライフエール',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14619': FundCodeEntry(
        fund_code='G14619',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２２－０９（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニニゼロキュウゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G14620': FundCodeEntry(
        fund_code='G14620',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／マクロアロケーター戦略ファンド２０２２－０９',
        fund_name_yomi='ゴールドマンサックスシャサイマクロアロケーターセンリャクファンドニイゼロニイニイゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14621': FundCodeEntry(
        fund_code='G14621',
        sec_code=None,
        fund_name='第１６８回２０２７年６月満期株価指数参照円建信託社債（デジタルクーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウハチカイニセンニジュウナナネンロクガツマンキカブカシスウサンショウエンダテシンタクシャサイデジタルクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14622': FundCodeEntry(
        fund_code='G14622',
        sec_code=None,
        fund_name='第１６９回２０２５年９月満期株価指数参照円建信託社債（固定クーポン型・トリガー価格逓減早期償還条項付）（責任財産限定特約付）参照指数：日経平均株価',
        fund_name_yomi='ダイヒャクロクジュウキュウカイニセンニジュウゴネンクガツマンキカブカシスウサンショウエンダテシンタクシャサイコテイクーポンガタトリガーカカクテイゲンソウキショウカンジョウコウツキセキニンザイサンゲンテイトクヤクツキサンショウシスウニッケイヘイキンカブカ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14623': FundCodeEntry(
        fund_code='G14623',
        sec_code=None,
        fund_name='Ｏｎｅ日本企業米ドル建て債券ファンド２０２２－０９',
        fund_name_yomi='ワンニホンキギョウベイドルダテサイケンファンドニイゼロニイニイゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='9月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14624': FundCodeEntry(
        fund_code='G14624',
        sec_code=None,
        fund_name='野村ＤＣ世界分散投資戦略ファンド',
        fund_name_yomi='ノムラディーシーセカイブンサントウシセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月21日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14625': FundCodeEntry(
        fund_code='G14625',
        sec_code=None,
        fund_name='フィデリティ・脱炭素日本株・ファンド',
        fund_name_yomi='フィデリティダツタンソニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14626': FundCodeEntry(
        fund_code='G14626',
        sec_code=None,
        fund_name='ＧＳ・日本株ファンドＤＣ',
        fund_name_yomi='ジーエス\u3000ニホンカブ\u3000ファンド\u3000ディーシー',
        security_type='内国投資信託受益証券',
        period_1='12月27日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14627': FundCodeEntry(
        fund_code='G14627',
        sec_code=None,
        fund_name='第１３６回\u3000２０２４年１０月１６日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウロクカイニセンニジュウヨネンジュウガツジュウロクニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月16日',
        period_2='10月16日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14628': FundCodeEntry(
        fund_code='G14628',
        sec_code=None,
        fund_name='ピクテ・為替ヘッジ付き・ゴールドファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ピクテカワセヘッジツキゴールドファンドノムラエスエムエイイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14629': FundCodeEntry(
        fund_code='G14629',
        sec_code=None,
        fund_name='野村フランチャイズ・パートナーズ・世界株式ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村フランチャイズ・パートナーズ・世界株式ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラフランチャイズパートナーズセカイカブシファンドエーコースノムラエスエムエーイーダブルムケ\u3000ノムラフランチャイズパートナーズセカイカブシファンドビーコースノムラエスエムエーイーダブルムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14630': FundCodeEntry(
        fund_code='G14630',
        sec_code=None,
        fund_name='岡三フィデリティ・グローバル・コア株式ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='オカサンフィデリティグローバルコアカブシキファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14631': FundCodeEntry(
        fund_code='G14631',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国割安優良株式ファンド\u3000Ｃコース（毎月決算・予想分配金提示型・為替ヘッジあり）／Ｄコース（毎月決算・予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000ベイコクワリヤスユウリョウカブシキファンド\u3000シーコース\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ\u3000カワセヘッジアリ\u3000ディーコース\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2='6月15日',
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G14632': FundCodeEntry(
        fund_code='G14632',
        sec_code='28600',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ドイツ株式・ＤＡＸ（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズドイツカブシキダックスカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14633': FundCodeEntry(
        fund_code='G14633',
        sec_code='28590',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ユーロ・ストックス５０指数（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズユーロストックスゴジュウシスウカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14634': FundCodeEntry(
        fund_code='G14634',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000日本株ダブル・ブルファンド２',
        fund_name_yomi='ワン\u3000ニホンカブダブルブルファンドツー',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14635': FundCodeEntry(
        fund_code='G14635',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000日本株ダブル・ベアファンド２',
        fund_name_yomi='ワン\u3000ニホンカブダブルベアファンドツー',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14636': FundCodeEntry(
        fund_code='G14636',
        sec_code=None,
        fund_name='第１３７回\u3000２０２５年１０月１５日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウナナカイニセンニジュウゴネンジュウガツジュウゴニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14637': FundCodeEntry(
        fund_code='G14637',
        sec_code=None,
        fund_name='ゆたか観光立国日本株式ファンド',
        fund_name_yomi='ユタカカンコウリッコクニッポンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14638': FundCodeEntry(
        fund_code='G14638',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000Ｓ＆Ｐ５００ゴールドプラス',
        fund_name_yomi='トレイサーズ\u3000エスアンドピーゴヒャクゴールドプラス',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14639': FundCodeEntry(
        fund_code='G14639',
        sec_code=None,
        fund_name='インデックスファンドＳ＆Ｐ５００（アメリカ株式）',
        fund_name_yomi='インデックスファンドエスアンドピーゴヒャク\u3000アメリカカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月8日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14641': FundCodeEntry(
        fund_code='G14641',
        sec_code=None,
        fund_name='ＧＳグローバル・リアルアセット・ファンド（限定為替ヘッジ）／（為替ヘッジなし）',
        fund_name_yomi='ジーエスグローバルリアルアセットファンド\u3000ゲンテイカワセヘッジ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14642': FundCodeEntry(
        fund_code='G14642',
        sec_code=None,
        fund_name='モルガン・スタンレー社債（早期償還条項付）／ＢＡＳＩＣ戦略ファンド２０２２－０９',
        fund_name_yomi='モルガンスタンレーシャサイソウキショウカンジョウコウツキベーシックセンリャクファンドニゼロニニゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='10月16日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14643': FundCodeEntry(
        fund_code='G14643',
        sec_code=None,
        fund_name='日本生命第８回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイハチカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E37958',
        issuer_name='日本生命第８回劣後ローン流動化株式会社',
    ),
    'G14644': FundCodeEntry(
        fund_code='G14644',
        sec_code=None,
        fund_name='お金のデザイン・エッセンシャル・プロダクツ・ファンド',
        fund_name_yomi='オカネノデザイン\u3000エッセンシャル\u3000プロダクツ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G14645': FundCodeEntry(
        fund_code='G14645',
        sec_code=None,
        fund_name='東洋ベトナム株式オープン',
        fund_name_yomi='トウヨウベトナムカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='8月18日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14646': FundCodeEntry(
        fund_code='G14646',
        sec_code=None,
        fund_name='ＳＢＩ日本株３．８ベアⅡ',
        fund_name_yomi='エスビーアイ\u3000ニホンカブ\u3000サンテンハチベア\u3000ツー',
        security_type='内国投資信託受益証券',
        period_1='9月21日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14647': FundCodeEntry(
        fund_code='G14647',
        sec_code=None,
        fund_name='キャピタル・インベストメント・カンパニー・オブ・アメリカ\u3000ＩＣＡ年２回決算（分配重視）',
        fund_name_yomi='キャピタルインベストメントカンパニーオブアメリカアイシーエイネンニカイケッサンブンパイジュウシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G14648': FundCodeEntry(
        fund_code='G14648',
        sec_code=None,
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ米国株式・債券バランス保守型指数（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーベイコクカブシキサイケンバランスホシュガタシスウカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月7日',
        period_2='12月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14649': FundCodeEntry(
        fund_code='G14649',
        sec_code=None,
        fund_name='全共連第２回劣後ローン流動化株式会社',
        fund_name_yomi='ゼンキョウレンダイニカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E37994',
        issuer_name='全共連第２回劣後ローン流動化株式会社',
    ),
    'G14650': FundCodeEntry(
        fund_code='G14650',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－グローバル・セレクト・キャリー戦略ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーグローバルセレクトキャリーセンリャクファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G14651': FundCodeEntry(
        fund_code='G14651',
        sec_code=None,
        fund_name='第１３８回\u3000２０２５年１１月１７日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウハチカイニセンニジュウゴネンジュウイチガツジュウシチニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14652': FundCodeEntry(
        fund_code='G14652',
        sec_code=None,
        fund_name='しんきん米国ウォーターファンド',
        fund_name_yomi='シンキンベイコクウォーターファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14653': FundCodeEntry(
        fund_code='G14653',
        sec_code=None,
        fund_name='しんきん全世界株式インデックスファンド',
        fund_name_yomi='シンキンゼンセカイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14654': FundCodeEntry(
        fund_code='G14654',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２２－１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイニイノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14655': FundCodeEntry(
        fund_code='G14655',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２２－Ⅱ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイニイノニ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14658': FundCodeEntry(
        fund_code='G14658',
        sec_code='28640',
        fund_name='グローバルＸ\u3000ロジスティクス・ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスロジスティクスリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14659': FundCodeEntry(
        fund_code='G14659',
        sec_code=None,
        fund_name='第１３９回\u3000２０２５年１１月１３日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日欧２指数（日経平均株価、ユーロ・ストックス５０指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクサンジュウキュウカイニセンニジュウゴネンジュウイチガツジュウサンニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチオウニシスウニッケイヘイキンカブカユーロストックスゴジュウシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月13日',
        period_2='11月13日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14660': FundCodeEntry(
        fund_code='G14660',
        sec_code=None,
        fund_name='つみたて日本大型株長期厳選投資',
        fund_name_yomi='ツミタテニホンオオガタカブチョウキゲンセントウシ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14661': FundCodeEntry(
        fund_code='G14661',
        sec_code=None,
        fund_name='アクティブアロケーションファンド（ラップ向け）',
        fund_name_yomi='アクティブアロケーションファンドラップムケ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14662': FundCodeEntry(
        fund_code='G14662',
        sec_code='28660',
        fund_name='グローバルＸ\u3000米国優先証券\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスベイコクユウセンショウケンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14663': FundCodeEntry(
        fund_code='G14663',
        sec_code='28650',
        fund_name='グローバルＸ\u3000ＮＡＳＤＡＱ１００・カバード・コール\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスナスダックヒャクカバードコールイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14664': FundCodeEntry(
        fund_code='G14664',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000国内リートインデックスファンド',
        fund_name_yomi='ミツビシユーエフジェイコクナイリートインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14665': FundCodeEntry(
        fund_code='G14665',
        sec_code=None,
        fund_name='米国株式インデックス（Ｓ＆Ｐ５００）',
        fund_name_yomi='ベイコクカブシキインデックスエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14666': FundCodeEntry(
        fund_code='G14666',
        sec_code=None,
        fund_name='東京海上・世界モノポリー戦略株式ファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウセカイモノポリーセンリャクカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14667': FundCodeEntry(
        fund_code='G14667',
        sec_code=None,
        fund_name='ＵＢＳサステナブル向上・コアバリュー株式ファンド',
        fund_name_yomi='ユービーエスサステナブルコウジョウ\u3000コアバリューカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G14668': FundCodeEntry(
        fund_code='G14668',
        sec_code=None,
        fund_name='ラップ型ファンド・プラスＥＳＧ（安定型）\u3000ラップ型ファンド・プラスＥＳＧ（安定成長型）\u3000ラップ型ファンド・プラスＥＳＧ（成長型）',
        fund_name_yomi='ラップガタファンド\u3000プラスイーエスジー\u3000アンテイガタ\u3000ラップガタファンド\u3000プラスイーエスジー\u3000アンテイセイチョウガタ\u3000ラップガタファンド\u3000プラスイーエスジー\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14669': FundCodeEntry(
        fund_code='G14669',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２２－１１',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウニジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14671': FundCodeEntry(
        fund_code='G14671',
        sec_code=None,
        fund_name='第１４０回\u3000２０２４年１２月１２日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクヨンジュウカイニセンニジュウヨネンジュウニガツジュウニニチマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14673': FundCodeEntry(
        fund_code='G14673',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット２０２２－１２（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウニ\u3000ジュウニ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14674': FundCodeEntry(
        fund_code='G14674',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000世界株式気候変動インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000セカイカブシキキコウヘンドウインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14675': FundCodeEntry(
        fund_code='G14675',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000Ｓ＆Ｐ５００配当貴族インデックス（米国株式）',
        fund_name_yomi='トレイサーズ\u3000エスアンドピーゴヒャクハイトウキゾクインデックス\u3000ベイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14676': FundCodeEntry(
        fund_code='G14676',
        sec_code=None,
        fund_name='第１４１回\u3000２０２５年１２月９日満期\u3000早期償還判定水準逓減型\u3000早期償還条項付\u3000ノックイン型日米２指数（日経平均株価・Ｓ＆Ｐ５００指数）参照デジタル・クーポン円建信託社債（責任財産限定特約付）',
        fund_name_yomi='ダイヒャクヨンジュウイチカイニセンニジュウゴネンジュウニガツココノカマンキソウキショウカンハンテイスイジュンテイゲンガタソウキショウカンジョウコウツキノックインガタニチベイニシスウニッケイヘイキンカブカスタンダードアンドプアーズゴヒャクシスウサンショウデジタルクーポンエンダテシンタクシャサイセキニンザイサンゲンテイトクヤクツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月9日',
        period_2='12月9日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14677': FundCodeEntry(
        fund_code='G14677',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国オールキャップ株式ファンド',
        fund_name_yomi='ティーロウプライス\u3000ベイコクオールキャップカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G14678': FundCodeEntry(
        fund_code='G14678',
        sec_code=None,
        fund_name='＜ＤＣ＞次世代ＲＥＩＴオープン',
        fund_name_yomi='ディーシージセダイリートオープン',
        security_type='内国投資信託受益証券',
        period_1='2月13日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14679': FundCodeEntry(
        fund_code='G14679',
        sec_code=None,
        fund_name='明治安田ＮＢコーポレート・ハイブリッド証券ファンド２０２２－１２（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマンコーポレートハイブリッドショウケンファンドニセンニジュウニノジュウニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14680': FundCodeEntry(
        fund_code='G14680',
        sec_code=None,
        fund_name='限定追加型・繰上償還条項付\u3000ニッセイ世界リカバリー株式厳選ファンド（為替ヘッジあり）',
        fund_name_yomi='ゲンテイツイカガタ\u3000クリアゲショウカンジョウコウツキ\u3000ニッセイセカイリカバリーカブシキゲンセンファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14681': FundCodeEntry(
        fund_code='G14681',
        sec_code='28670',
        fund_name='グローバルＸ\u3000自動運転＆ＥＶ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスジドウウンテンアンドイーブイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14682': FundCodeEntry(
        fund_code='G14682',
        sec_code='28680',
        fund_name='グローバルＸ\u3000Ｓ＆Ｐ５００・カバード・コール\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエスアンドピーゴヒャクカバードコールイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14683': FundCodeEntry(
        fund_code='G14683',
        sec_code=None,
        fund_name='シュローダー・ツーシグマ・ダイバーシファイド・ファンド',
        fund_name_yomi='シュローダーツーシグマダイバーシファイドファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12586',
        issuer_name='シュローダー・インベストメント・マネジメント株式会社',
    ),
    'G14684': FundCodeEntry(
        fund_code='G14684',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２２－１２（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニニイチニ\u3000カワセヘッジアリ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14685': FundCodeEntry(
        fund_code='G14685',
        sec_code=None,
        fund_name='シンガポールＲＥＩＴファンド（毎月分配型）／（資産成長型）',
        fund_name_yomi='シンガポールリートファンドマイツキブンパイガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14686': FundCodeEntry(
        fund_code='G14686',
        sec_code=None,
        fund_name='イノベーション・インサイト\u3000世界株式戦略ファンド（資産成長型）\u3000イノベーション・インサイト\u3000世界株式戦略ファンド（予想分配金提示型）',
        fund_name_yomi='イノベーション\u3000インサイト\u3000セカイカブシキセンリャクファンド\u3000シサンセイチョウガタ\u3000イノベーション\u3000インサイト\u3000セカイカブシキセンリャクファンド\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14687': FundCodeEntry(
        fund_code='G14687',
        sec_code='28700',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＮＡＳＤＡＱ１００ダブルインバース',
        fund_name_yomi='アイフリーイーティーエフナスダックヒャクダブルインバース',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14688': FundCodeEntry(
        fund_code='G14688',
        sec_code='28690',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＮＡＳＤＡＱ１００レバレッジ',
        fund_name_yomi='アイフリーイーティーエフナスダックヒャクレバレッジ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14689': FundCodeEntry(
        fund_code='G14689',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅡ\u3000２０２３－０１',
        fund_name_yomi='ワンエンダテサイケンファンドツーニイゼロニイサンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14690': FundCodeEntry(
        fund_code='G14690',
        sec_code=None,
        fund_name='東京海上・物価対応バランスファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウブッカタイオウバランスファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14691': FundCodeEntry(
        fund_code='G14691',
        sec_code=None,
        fund_name='東京海上・物価対応バランスファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウブッカタイオウバランスファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14692': FundCodeEntry(
        fund_code='G14692',
        sec_code=None,
        fund_name='いちご・レジデンス・トークン－麻布・白金・日本橋－（譲渡制限付）',
        fund_name_yomi='イチゴレジデンストークンアザブシロガネニホンバシジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14693': FundCodeEntry(
        fund_code='G14693',
        sec_code=None,
        fund_name='Ｏｎｅ国内株式ＥＳＧフォーカスファンド＜ＤＣ年金＞',
        fund_name_yomi='ワンコクナイカブシキイーエスジーフォーカスファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14694': FundCodeEntry(
        fund_code='G14694',
        sec_code=None,
        fund_name='モルガン・スタンレー社債（早期償還条項付）／ＢＡＳＩＣ戦略ファンド２０２３－０１',
        fund_name_yomi='モルガンスンタレーシャサイソウキショウカンジョウコウツキベーシックセンリャクファンドニゼロニサンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14695': FundCodeEntry(
        fund_code='G14695',
        sec_code=None,
        fund_name='インド株式ファンド',
        fund_name_yomi='インドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14696': FundCodeEntry(
        fund_code='G14696',
        sec_code=None,
        fund_name='せとうち応援株式ファンド',
        fund_name_yomi='セトウチオウエンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G14697': FundCodeEntry(
        fund_code='G14697',
        sec_code=None,
        fund_name='キャピタル・グローバル・ハイインカム債券ファンドＡコース（成長型／米ドル売り円買い）／Ｂコース（成長型／為替ヘッジなし）／Ｃコース（分配型年６回決算／米ドル売り円買い）／Ｄコース（分配型年６回決算／為替ヘッジなし）',
        fund_name_yomi='キャピタルグローバルハイインカムサイケンファンドエイコースセイチョウガタベイドルウリエンガイビーコースセイチョウガタカワセヘッジナシシーコースブンパイガタネンロッカイケッサンベイドルウリエンガイディーコースブンパイガタネンロッカイケッサンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G14698': FundCodeEntry(
        fund_code='G14698',
        sec_code=None,
        fund_name='リアルアセット関連証券ファンド（毎月決算型）\u3000リアルアセット関連証券ファンド（年２回決算型）',
        fund_name_yomi='リアルアセットカンレンショウケンファンド\u3000マイツキケッサンガタ\u3000リアルアセットカンレンショウケンファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14699': FundCodeEntry(
        fund_code='G14699',
        sec_code=None,
        fund_name='シティグループ社債／ダブル・アクセス戦略ファンド２０２２－１２',
        fund_name_yomi='シティグループシャサイダブルアクセスセンリャクファンドニイゼロニイニイイチニイ',
        security_type='内国投資信託受益証券',
        period_1='1月13日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14700': FundCodeEntry(
        fund_code='G14700',
        sec_code=None,
        fund_name='日本厳選価値向上株式ファンド',
        fund_name_yomi='ニホンゲンセンカチコウジョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14701': FundCodeEntry(
        fund_code='G14701',
        sec_code=None,
        fund_name='マクロアロケーター戦略指数参照型ゴールドマン・サックス社債ファンド２０２２－１２',
        fund_name_yomi='マクロアロケーターセンリャクシスウサンショウガタゴールドマンサックスシャサイファンドニイゼロニイニイイチニイ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14702': FundCodeEntry(
        fund_code='G14702',
        sec_code=None,
        fund_name='みずほグローバル・ターゲット利回り債券ファンド２０２３－０１（限定追加型）',
        fund_name_yomi='ミズホグローバルターゲットリマワリサイケンファンドニイゼロニイサンゼロイチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14703': FundCodeEntry(
        fund_code='G14703',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン湯けむりの宿\u3000雪の花（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンユケムリノヤドユキノハナジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月末日',
        period_2='9月末日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G14704': FundCodeEntry(
        fund_code='G14704',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・トレンド戦略ファンド\u3000Ａコース、野村ＰＩＭＣＯ・トレンド戦略ファンド\u3000Ｂコース',
        fund_name_yomi='ノムラピムコトレンドセンリャクファンドエーコース\u3000ノムラピムコトレンドセンリャクファンドビーコース',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14705': FundCodeEntry(
        fund_code='G14705',
        sec_code='22350',
        fund_name='上場インデックスファンド米国株式（ダウ平均）為替ヘッジなし',
        fund_name_yomi='ジョウジョウインデックスファンドベイコクカブシキ\u3000ダウヘイキン\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14706': FundCodeEntry(
        fund_code='G14706',
        sec_code=None,
        fund_name='ＳＯＭＰＯ世界分散ファンド（安定型）／（安定成長型）／（成長型）＜ＤＣ年金＞',
        fund_name_yomi='ソンポセカイブンサンファンドアンテイガタアンテイセイチョウガタセイチョウガタディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14707': FundCodeEntry(
        fund_code='G14707',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴリサーチ・アクティブファンド',
        fund_name_yomi='ジェイ\u3000リートリサーチ\u3000アクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14708': FundCodeEntry(
        fund_code='G14708',
        sec_code=None,
        fund_name='楽天・全世界株式（除く米国）インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000ゼンセカイカブシキ\u3000ノゾクベイコク\u3000インデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14709': FundCodeEntry(
        fund_code='G14709',
        sec_code=None,
        fund_name='ａｕＡＭかんたん投資専用ファンド（株式重視型）／ａｕＡＭかんたん投資専用ファンド（株式シフト型）／ａｕＡＭかんたん投資専用ファンド（債券シフト型）／ａｕＡＭかんたん投資専用ファンド（債券重視型）',
        fund_name_yomi='エーユーエーエムカンタントウシセンヨウファンドカブシキジュウシガタ\u3000エーユーエーエムカンタントウシセンヨウファンドカブシキシフトガタ\u3000エーユーエーエムカンタントウシセンヨウファンドサイケンシフトガタ\u3000エーユーエーエムカンタントウシセンヨウファンドサイケンジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G14710': FundCodeEntry(
        fund_code='G14710',
        sec_code=None,
        fund_name='住友生命第３回劣後ローン流動化株式会社',
        fund_name_yomi='スミトモセイメイダイサンカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E38247',
        issuer_name='住友生命第３回劣後ローン流動化株式会社',
    ),
    'G14711': FundCodeEntry(
        fund_code='G14711',
        sec_code=None,
        fund_name='野村ブル・ベア\u3000セレクト９',
        fund_name_yomi='ノムラブルベアセレクトナイン',
        security_type='内国投資信託受益証券',
        period_1='1月16日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14712': FundCodeEntry(
        fund_code='G14712',
        sec_code=None,
        fund_name='りそな\u3000つみたてラップ型ファンド（安定型）\u3000りそな\u3000つみたてラップ型ファンド（安定成長型）\u3000りそな\u3000つみたてラップ型ファンド（成長型）',
        fund_name_yomi='リソナ\u3000ツミタテラップガタファンド\u3000アンテイガタ\u3000リソナ\u3000ツミタテラップガタファンド\u3000アンテイセイチョウガタ\u3000リソナ\u3000ツミタテラップガタファンド\u3000セイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14713': FundCodeEntry(
        fund_code='G14713',
        sec_code=None,
        fund_name='北陸みらい応援ファンド',
        fund_name_yomi='ホクリクミライオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14714': FundCodeEntry(
        fund_code='G14714',
        sec_code=None,
        fund_name='バランスポートフォリオ',
        fund_name_yomi='バランスポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14715': FundCodeEntry(
        fund_code='G14715',
        sec_code=None,
        fund_name='ドラッカー研究所米国株ファンド（資産成長型）',
        fund_name_yomi='ドラッカーケンキュウジョベイコクカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2='12月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14716': FundCodeEntry(
        fund_code='G14716',
        sec_code=None,
        fund_name='レバレッジ・ドラッカー研究所米国株ファンド',
        fund_name_yomi='レバレッジドラッカーケンキュウジョベイコクカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14717': FundCodeEntry(
        fund_code='G14717',
        sec_code=None,
        fund_name='りそな\u3000つみたてリスクコントロールファンド',
        fund_name_yomi='リソナ\u3000ツミタテリスクコントロールファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14718': FundCodeEntry(
        fund_code='G14718',
        sec_code=None,
        fund_name='日本債券コア・アクティブファンド',
        fund_name_yomi='ニホンサイケンコア\u3000アクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14719': FundCodeEntry(
        fund_code='G14719',
        sec_code=None,
        fund_name='ＳＭＴＡＭ\u3000Ｓ＆Ｐ５００戦略ファンド（株価水準レバレッジ比率調整型）',
        fund_name_yomi='エスエムティーエーエム\u3000エスアンドピーゴヒャクセンリャクファンド\u3000カブカスイジュンレバレッジヒリツチョウセイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14720': FundCodeEntry(
        fund_code='G14720',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２３－０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイサンノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14721': FundCodeEntry(
        fund_code='G14721',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ－ショート・ターム米ドルコーポレート（米ドル）',
        fund_name_yomi='ユービーエスルクスボンドシキャブショートタームベイドルコーポレートベイドル',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E22239',
        issuer_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ',
    ),
    'G14722': FundCodeEntry(
        fund_code='G14722',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000ＤＣ\u3000米国株式（Ｓ＆Ｐ５００）インデックスファンド',
        fund_name_yomi='ワンディーシーベイコクカブシキエスアンドピーゴヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14723': FundCodeEntry(
        fund_code='G14723',
        sec_code=None,
        fund_name='日米連続好配当株式ファンド',
        fund_name_yomi='ニチベイレンゾクコウハイトウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月5日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G14724': FundCodeEntry(
        fund_code='G14724',
        sec_code=None,
        fund_name='明治安田ＮＢグローバル好利回り社債ファンド２０２３－０２（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマンコウリマワリシャサイファンドニセンニジュウサンノニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14725': FundCodeEntry(
        fund_code='G14725',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２３－０２（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニサンゼロニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G14726': FundCodeEntry(
        fund_code='G14726',
        sec_code='22360',
        fund_name='グローバルＸ\u3000Ｓ＆Ｐ５００配当貴族ＥＴＦ',
        fund_name_yomi='グローバルエックスエスアンドピーゴヒャクハイトウキゾクイーティエフ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14728': FundCodeEntry(
        fund_code='G14728',
        sec_code=None,
        fund_name='マネーフォワード全世界株式インデックスファンド',
        fund_name_yomi='マネーフォワードゼンセカイカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G14729': FundCodeEntry(
        fund_code='G14729',
        sec_code=None,
        fund_name='（早期償還条項付）リオープン・ジャパン２３０１',
        fund_name_yomi='ソウキショウカンジョウコウツキリオープンジャパンニーサンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14730': FundCodeEntry(
        fund_code='G14730',
        sec_code=None,
        fund_name='三井住友ＤＳ・ＤＣターゲットイヤーファンド２０３５／２０４０／２０４５／２０５５／２０６５',
        fund_name_yomi='ミツイスミトモディーエスディーシーターゲットイヤーファンドニイゼロサンゴ\u3000ニイゼロヨンゼロ\u3000ニイゼロヨンゴ\u3000ニイゼロゴゴ\u3000ニイゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14731': FundCodeEntry(
        fund_code='G14731',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓ＆Ｐ５００クオリティ高配当インデックス',
        fund_name_yomi='イーマクシスエスアンドピーゴヒャククオリティコウハイトウインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14732': FundCodeEntry(
        fund_code='G14732',
        sec_code=None,
        fund_name='ビルドアップ型\u3000ＭＳグローバル・プレミアム株式（為替ヘッジなし）２０２３－０２（限定追加型）',
        fund_name_yomi='ビルドアップガタエムエスグローバルプレミアムカブシキカワセヘッジナシニセンニジュウサンゼロニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14733': FundCodeEntry(
        fund_code='G14733',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２３－０２',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウサンゼロニ',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14734': FundCodeEntry(
        fund_code='G14734',
        sec_code=None,
        fund_name='トーセイ・プロパティ・ファンド（シリーズ２）',
        fund_name_yomi='トーセイ\u3000プロパティ\u3000ファンド\u3000シリーズツー',
        security_type='内国有価証券投資事業権利等',
        period_1='2月末日',
        period_2=None,
        edinet_code='E38342',
        issuer_name='トークン・ツー合同会社',
    ),
    'G14735': FundCodeEntry(
        fund_code='G14735',
        sec_code=None,
        fund_name='グローバル資産分散投資ファンド\u3000Ａコース（安定）、Ｂコース（やや安定）、Ｃコース（標準）、Ｄコース（やや積極）、Ｅコース（積極）',
        fund_name_yomi='グローバルシサンブンサントウシファンド\u3000エーコースアンテイ\u3000ビーコースヤヤアンテイ\u3000シーコースヒョウジュン\u3000ディーコースヤヤセッキョク\u3000イーコースセッキョク',
        security_type='内国投資信託受益証券',
        period_1='2月6日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14736': FundCodeEntry(
        fund_code='G14736',
        sec_code='22390',
        fund_name='上場インデックスファンドＳ＆Ｐ５００先物レバレッジ２倍',
        fund_name_yomi='ジョウジョウインデックスファンドエスアンドピーゴヒャクサキモノレバレッジニバイ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14737': FundCodeEntry(
        fund_code='G14737',
        sec_code='22400',
        fund_name='上場インデックスファンドＳ＆Ｐ５００先物インバース',
        fund_name_yomi='ジョウジョウインデックスファンドエスアンドピーゴヒャクサキモノインバース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14738': FundCodeEntry(
        fund_code='G14738',
        sec_code=None,
        fund_name='米国大型株長期厳選投資',
        fund_name_yomi='ベイコクオオガタカブチョウキゲンセントウシ',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14739': FundCodeEntry(
        fund_code='G14739',
        sec_code='22370',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000Ｓ＆Ｐ５００レバレッジ',
        fund_name_yomi='アイフリーイーティーエフエスアンドピーゴヒャクレバレッジ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14740': FundCodeEntry(
        fund_code='G14740',
        sec_code='22380',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000Ｓ＆Ｐ５００インバース',
        fund_name_yomi='アイフリーイーティーエフエスアンドピーゴヒャクインバース',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14741': FundCodeEntry(
        fund_code='G14741',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２３－０２（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニサンゼロニ\u3000カワセヘッジアリ\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14742': FundCodeEntry(
        fund_code='G14742',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ－ショート・ターム米ドルコーポレート・サステナブル（米ドル）－クラスＰ－ａｃｃ投資証券およびクラスＰ－ｍｄｉｓｔ投資証券',
        fund_name_yomi='ユービーエスルクスボンドシキャブショートタームベイドルコーポレートサステナブルベイドルクラスピーエーシーシートウシショウケンオヨビクラスピーエムディーアイエスティートウシショウケン',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E22239',
        issuer_name='ＵＢＳ（Ｌｕｘ）ボンド・シキャブ',
    ),
    'G14743': FundCodeEntry(
        fund_code='G14743',
        sec_code=None,
        fund_name='シュローダー・サステナブル・世界株ファンド（限定為替ヘッジ）、シュローダー・サステナブル・世界株ファンド（為替ヘッジなし）',
        fund_name_yomi='シュローダーサステナブルセカイカブファンドゲンテイカワセヘッジ\u3000シュローダーサステナブルセカイカブファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14744': FundCodeEntry(
        fund_code='G14744',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000グローバル３分法（おとなのバランス）',
        fund_name_yomi='トレイサーズ\u3000グローバルサンブンポウ\u3000オトナノバランス',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14745': FundCodeEntry(
        fund_code='G14745',
        sec_code=None,
        fund_name='たわらノーロード\u3000新興国現地通貨建債券＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000シンコウコクゲンチツウカダテサイケンラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14746': FundCodeEntry(
        fund_code='G14746',
        sec_code=None,
        fund_name='Ｏｎｅゴールド・ファンド（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='ワンゴールドファンドカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14747': FundCodeEntry(
        fund_code='G14747',
        sec_code=None,
        fund_name='米国株式自動配分戦略ファンド',
        fund_name_yomi='ベイコクカブシキジドウハイブンセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14748': FundCodeEntry(
        fund_code='G14748',
        sec_code=None,
        fund_name='ＦＤＡ日米バランスファンド（積極型）',
        fund_name_yomi='エフディーエーニチベイバランスファンドセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='10月7日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14749': FundCodeEntry(
        fund_code='G14749',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２３－０３',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイサンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14750': FundCodeEntry(
        fund_code='G14750',
        sec_code=None,
        fund_name='先進国好利回りＣＢファンド２０２３‐０３（為替ヘッジあり）（限定追加型）／（為替ヘッジなし）（限定追加型）',
        fund_name_yomi='センシンコクコウリマワリシービーファンドニセンニジュウサンゼロサンカワセヘッジアリゲンテイツイカガタカワセヘッジナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月9日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14751': FundCodeEntry(
        fund_code='G14751',
        sec_code=None,
        fund_name='三井住友ＤＳ\u3000グローバル・ターゲット債券ファンド２０２３ー０３（限定追加型）',
        fund_name_yomi='ミツイスミトモディーエスグローバルターゲットサイケンファンドニイゼロニイサンゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14753': FundCodeEntry(
        fund_code='G14753',
        sec_code=None,
        fund_name='モルガン・スタンレー社債（早期償還条項付）／ＢＡＳＩＣ戦略ファンド２０２３－０３',
        fund_name_yomi='モルガンスタンレーシャサイソウキショウカンジョウコウツキベーシックセンリャクファンドニゼロニサンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14754': FundCodeEntry(
        fund_code='G14754',
        sec_code=None,
        fund_name='ＶＴＸ\u3000ＤＣダイナミックバランスファンド（安定型）\u3000ＶＴＸ\u3000ＤＣダイナミックバランスファンド（安定成長型）\u3000ＶＴＸ\u3000ＤＣダイナミックバランスファンド（成長型）\u3000ＶＴＸ\u3000ＤＣダイナミックバランスファンド（積極成長型）',
        fund_name_yomi='ブイティーエックス\u3000ディーシーダイナミックバランスファンド\u3000アンテイガタ\u3000ブイティーエックス\u3000ディーシーダイナミックバランスファンド\u3000アンテイセイチョウガタ\u3000ブイティーエックス\u3000ディーシーダイナミックバランスファンド\u3000セイチョウガタ\u3000ブイティーエックス\u3000ディーシーダイナミックバランスファンド\u3000セッキョクセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E38423',
        issuer_name='バーテックス・インベストメント・ソリューションズ株式会社',
    ),
    'G14755': FundCodeEntry(
        fund_code='G14755',
        sec_code=None,
        fund_name='マクロアロケーター戦略指数参照型ゴールドマン・サックス社債ファンド２０２３－０３',
        fund_name_yomi='マクロアロケーターセンリャクシスウサンショウガタゴールドマンサックスシャサイファンドニイゼロニイサンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14756': FundCodeEntry(
        fund_code='G14756',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国中小型株式ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000ベイコクチュウコガタカブシキファンド\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G14758': FundCodeEntry(
        fund_code='G14758',
        sec_code=None,
        fund_name='フィデリティ・グロース・オポチュニティ・ファンド\u3000Ａコース（為替ヘッジあり）\u3000フィデリティ・グロース・オポチュニティ・ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティグロースオポチュニティファンドエーコースカワセヘッジアリ\u3000フィデリティグロースオポチュニティファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14759': FundCodeEntry(
        fund_code='G14759',
        sec_code=None,
        fund_name='フィデリティ・グロース・オポチュニティ・ファンド\u3000Ｃコース（毎月決算・予想分配金提示型・為替ヘッジあり）\u3000フィデリティ・グロース・オポチュニティ・ファンド\u3000Ｄコース（毎月決算・予想分配金提示型・為替ヘッジなし）',
        fund_name_yomi='フィデリティグロースオポチュニティファンドシーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジアリ\u3000フィデリティグロースオポチュニティファンドディーコースマイツキケッサンヨソウブンパイキンテイジガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14760': FundCodeEntry(
        fund_code='G14760',
        sec_code=None,
        fund_name='東洋・中国Ａ株オープン「創新」',
        fund_name_yomi='トウヨウチュウゴクエーカブオープンソウシン',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14761': FundCodeEntry(
        fund_code='G14761',
        sec_code=None,
        fund_name='ファイブスター日経２２５ニュートラルファンド',
        fund_name_yomi='ファイブスターニッケイニーニーゴニュートラルファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G14762': FundCodeEntry(
        fund_code='G14762',
        sec_code=None,
        fund_name='ＡＬＡＭＣＯ\u3000ＥＴＦバランスファンド\u3000積極型、ＡＬＡＭＣＯ\u3000ＥＴＦバランスファンド\u3000やや積極型、ＡＬＡＭＣＯ\u3000ＥＴＦバランスファンド\u3000中立型、ＡＬＡＭＣＯ\u3000ＥＴＦバランスファンド\u3000やや安定型、ＡＬＡＭＣＯ\u3000ＥＴＦバランスファンド\u3000安定型',
        fund_name_yomi='アラムコイーティーエフバランスファンドセッキョクガタアラムコイーティーエフバランスファンドヤヤセッキョクガタアラムコイーティーエフバランスファンドチュウリツガタアラムコイーティーエフバランスファンドヤヤアンテイガタアラムコイーティーエフバランスファンドアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G14763': FundCodeEntry(
        fund_code='G14763',
        sec_code=None,
        fund_name='東京海上・米国短期国債ファンド（毎月決算型）',
        fund_name_yomi='トウキョウカイジョウベイコクタンキコクサイファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14764': FundCodeEntry(
        fund_code='G14764',
        sec_code=None,
        fund_name='東京海上・米国短期国債ファンド（年１回決算型）',
        fund_name_yomi='トウキョウカイジョウベイコクタンキコクサイファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14765': FundCodeEntry(
        fund_code='G14765',
        sec_code='22410',
        fund_name='ＭＡＸＩＳ\u3000ＮＹダウ上場投信',
        fund_name_yomi='マクシスニューヨークダウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14766': FundCodeEntry(
        fund_code='G14766',
        sec_code='22420',
        fund_name='ＭＡＸＩＳ\u3000ＮＹダウ上場投信（為替ヘッジあり）',
        fund_name_yomi='マクシスニューヨークダウジョウジョウトウシンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月26日',
        period_2='11月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14767': FundCodeEntry(
        fund_code='G14767',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－シティグループ社債／満期時目標設定型ファンド',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000シティグループシャサイマンキジモクヒョウセッテイガタファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G14768': FundCodeEntry(
        fund_code='G14768',
        sec_code=None,
        fund_name='ターゲットリターンバランスファンド（目標２％）\u3000ターゲットリターンバランスファンド（目標３％）\u3000ターゲットリターンバランスファンド（目標４％）\u3000ターゲットリターンバランスファンド（目標５％）\u3000ターゲットリターンバランスファンド（目標６％）',
        fund_name_yomi='ターゲットリターンバランスファンド\u3000モクヒョウニパーセント\u3000ターゲットリターンバランスファンド\u3000モクヒョウサンパーセント\u3000ターゲットリターンバランスファンド\u3000モクヒョウヨンパーセント\u3000ターゲットリターンバランスファンド\u3000モクヒョウゴパーセント\u3000ターゲットリターンバランスファンド\u3000モクヒョウロクパーセント',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14769': FundCodeEntry(
        fund_code='G14769',
        sec_code=None,
        fund_name='米国超長期プライム社債ファンド（１年決算型）',
        fund_name_yomi='ベイコクチョウチョウキプライムシャサイファンド\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14770': FundCodeEntry(
        fund_code='G14770',
        sec_code=None,
        fund_name='米国超長期プライム社債ファンド（奇数月分配型）',
        fund_name_yomi='ベイコクチョウチョウキプライムシャサイファンド\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14771': FundCodeEntry(
        fund_code='G14771',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000インド株インデックス',
        fund_name_yomi='アイフリーネクストインドカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14772': FundCodeEntry(
        fund_code='G14772',
        sec_code=None,
        fund_name='Ｏｎｅグローバル最適化バランス（安定型）＜ラップ向け＞、Ｏｎｅグローバル最適化バランス（成長型）＜ラップ向け＞',
        fund_name_yomi='ワングローバルサイテキカバランスアンテイガタラップムケ\u3000ワングローバルサイテキカバランスセイチョウガタラップムケ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14773': FundCodeEntry(
        fund_code='G14773',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000先進国株式',
        fund_name_yomi='エヌザム\u3000ベータ\u3000センシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14774': FundCodeEntry(
        fund_code='G14774',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000先進国ＲＥＩＴ',
        fund_name_yomi='エヌザム\u3000ベータ\u3000センシンコクリート',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14775': FundCodeEntry(
        fund_code='G14775',
        sec_code=None,
        fund_name='ＮＺＡＭ・ベータ\u3000先進国２資産（株式＋ＲＥＩＴ）',
        fund_name_yomi='エヌザム\u3000ベータ\u3000センシンコクニシサン\u3000カブシキプラスリート',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14776': FundCodeEntry(
        fund_code='G14776',
        sec_code=None,
        fund_name='ＮＺＡＭ・レバレッジ\u3000米国株式２倍ブル（ＮＡＳＤＡＱ１００）',
        fund_name_yomi='エヌザム\u3000レバレッジ\u3000ベイコクカブシキニバイブル\u3000ナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14777': FundCodeEntry(
        fund_code='G14777',
        sec_code=None,
        fund_name='ＮＺＡＭ・レバレッジ\u3000中国株式２倍ブル',
        fund_name_yomi='エヌザム\u3000レバレッジ\u3000チュウゴクカブシキニバイブル',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14778': FundCodeEntry(
        fund_code='G14778',
        sec_code=None,
        fund_name='ＮＺＡＭ・レバレッジ\u3000インド株式２倍ブル',
        fund_name_yomi='エヌザム\u3000レバレッジ\u3000インドカブシキニバイブル',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14779': FundCodeEntry(
        fund_code='G14779',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投資信託インデックス\u3000アメリカ株式',
        fund_name_yomi='ペイペイトウシシンタクインデックスアメリカカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14780': FundCodeEntry(
        fund_code='G14780',
        sec_code=None,
        fund_name='グローバル食料株ファンド',
        fund_name_yomi='グローバルショクリョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G14781': FundCodeEntry(
        fund_code='G14781',
        sec_code=None,
        fund_name='三井住友ＤＳ・ＦＷ専用ポートフォリオ',
        fund_name_yomi='ミツイスミトモディーエスエフダブリューセンヨウポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14782': FundCodeEntry(
        fund_code='G14782',
        sec_code=None,
        fund_name='ニッセイＮＡＳＤＡＱ１００インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイナスダックヒャクインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14783': FundCodeEntry(
        fund_code='G14783',
        sec_code=None,
        fund_name='ニッセイＳＯＸ指数インデックスファンド（米国半導体株）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイソックスシスウインデックスファンドベイコクハンドウタイカブコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14784': FundCodeEntry(
        fund_code='G14784',
        sec_code=None,
        fund_name='エマージング・カレンシー・債券ファンド（毎月分配型）',
        fund_name_yomi='エマージング\u3000カレンシー\u3000サイケンファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14785': FundCodeEntry(
        fund_code='G14785',
        sec_code=None,
        fund_name='ＳＢＩ・ＵＴＩインドファンド',
        fund_name_yomi='エスビーアイ\u3000ユーティアイインドファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14786': FundCodeEntry(
        fund_code='G14786',
        sec_code=None,
        fund_name='アメリカン・ドリーム・ファンド',
        fund_name_yomi='アメリカン\u3000ドリーム\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14787': FundCodeEntry(
        fund_code='G14787',
        sec_code=None,
        fund_name='ＳＢＩ・フラトンＶＰＩＣファンド',
        fund_name_yomi='エスビーアイ\u3000フラトンブイピックファンド',
        security_type='内国投資信託受益証券',
        period_1='8月26日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14788': FundCodeEntry(
        fund_code='G14788',
        sec_code=None,
        fund_name='ＳＢＩ・ＵＴＩインドインフラ関連株式ファンド',
        fund_name_yomi='エスビーアイ\u3000ユーティアイインドインフラカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14789': FundCodeEntry(
        fund_code='G14789',
        sec_code=None,
        fund_name='米国好配当株プレミアム戦略ファンド（毎月分配型）株式コース\u3000米国好配当株プレミアム戦略ファンド（毎月分配型）株式＆通貨コース',
        fund_name_yomi='ベイコクコウハイトウカブプレミアムセンリャクファンド\u3000マイツキブンパイガタ\u3000カブシキコース\u3000ベイコクコウハイトウカブプレミアムセンリャクファンド\u3000マイツキブンパイガタ\u3000カブシキアンドツウカコース',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14790': FundCodeEntry(
        fund_code='G14790',
        sec_code=None,
        fund_name='ＳＢＩワールドラップ・セレクト',
        fund_name_yomi='エスビーアイ\u3000ワールドラップ\u3000セレクト',
        security_type='内国投資信託受益証券',
        period_1='8月13日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14791': FundCodeEntry(
        fund_code='G14791',
        sec_code=None,
        fund_name='オリックス\u3000世界国債ファンド（グローバル・ダイナミック・デュレーション）（為替ヘッジあり）',
        fund_name_yomi='オリックス\u3000セカイコクサイファンド\u3000グローバル\u3000ダイナミック\u3000デュレーション\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14792': FundCodeEntry(
        fund_code='G14792',
        sec_code=None,
        fund_name='オリックス\u3000世界社債アクティブファンド（為替ヘッジあり）',
        fund_name_yomi='オリックス\u3000セカイシャサイアクティブファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14793': FundCodeEntry(
        fund_code='G14793',
        sec_code=None,
        fund_name='オリックス\u3000先進国株式マーケット・プラス・ファンド',
        fund_name_yomi='オリックス\u3000センシンコクカブシキマーケット\u3000プラス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14794': FundCodeEntry(
        fund_code='G14794',
        sec_code=None,
        fund_name='ＳＢＩ・コムジェスト・クオリティグロース・世界株式ファンド',
        fund_name_yomi='エスビーアイ\u3000コムジェスト\u3000クオリティグロース\u3000セカイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14795': FundCodeEntry(
        fund_code='G14795',
        sec_code=None,
        fund_name='ＳＢＩ・コムジェスト・クオリティグロース・日本株式ファンド',
        fund_name_yomi='エスビーアイ\u3000コムジェスト\u3000クオリティグロース\u3000ニホンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14798': FundCodeEntry(
        fund_code='G14798',
        sec_code=None,
        fund_name='楽天・オルタナティブ・マルチキャリー戦略ファンド＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000オルタナティブ\u3000マルチキャリーセンリャクファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G14799': FundCodeEntry(
        fund_code='G14799',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット２０２３－０６（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウサン\u3000ゼロロク\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14800': FundCodeEntry(
        fund_code='G14800',
        sec_code=None,
        fund_name='たわらノーロード\u3000Ｓ＆Ｐ５００',
        fund_name_yomi='タワラノーロード\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14801': FundCodeEntry(
        fund_code='G14801',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２３－０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイサンノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14802': FundCodeEntry(
        fund_code='G14802',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２３－Ⅰ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイサンノイチ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14804': FundCodeEntry(
        fund_code='G14804',
        sec_code=None,
        fund_name='世界水資源関連株式ファンド',
        fund_name_yomi='セカイミズシゲンカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月2日',
        period_2='10月2日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14805': FundCodeEntry(
        fund_code='G14805',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２３－０５',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウサンゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14806': FundCodeEntry(
        fund_code='G14806',
        sec_code=None,
        fund_name='スパークス・企業価値創造日本株ファンド',
        fund_name_yomi='スパークスキギョウカチソウゾウニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G14807': FundCodeEntry(
        fund_code='G14807',
        sec_code=None,
        fund_name='ＧＳグローバル・リアルアセット・ファンド（毎月決算・分配条件提示型・為替ヘッジなし）',
        fund_name_yomi='ジーエスグローバル\u3000リアルアセット\u3000ファンド\u3000マイツキケッサン\u3000ブンパイジョウケンテイジガタ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14808': FundCodeEntry(
        fund_code='G14808',
        sec_code=None,
        fund_name='ダイワ・ワールド・ファンド・シリーズ－ダイワ・ブラックストーン・プライベート・クレジット・ファンド',
        fund_name_yomi='ダイワワールドファンドシリーズダイワブラックストーンプライベートクレジットファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E38530',
        issuer_name='ＩＱ\u3000ＥＱファンド・マネジメント（アイルランド）リミテッド',
    ),
    'G14809': FundCodeEntry(
        fund_code='G14809',
        sec_code=None,
        fund_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー－フェデレーテッド・ハーミーズ・ＳＤＧエンゲージメント・ハイ・イールド・クレジット・ファンド',
        fund_name_yomi='フェデレーテッドハーミーズインベストメントファンズピーエルシーフェデレーテッドハーミーズエスディージーエンゲージメントハイイールドクレジットファンド',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E36684',
        issuer_name='フェデレーテッド・ハーミーズ・インベストメント・ファンズ・ピーエルシー',
    ),
    'G14810': FundCodeEntry(
        fund_code='G14810',
        sec_code='22430',
        fund_name='グローバルＸ\u3000半導体\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスハンドウタイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14811': FundCodeEntry(
        fund_code='G14811',
        sec_code='22440',
        fund_name='グローバルＸ\u3000ＵＳ\u3000テック・トップ２０\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスユーエステックトップニジュウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14812': FundCodeEntry(
        fund_code='G14812',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークンＯＮＳＥＮＲＹＯＫＡＮ由縁札幌（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンオンセンリョカンユエンサッポロジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14813': FundCodeEntry(
        fund_code='G14813',
        sec_code='22450',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ・ドイツ国債（７－１０年）インデックス（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグドイツコクサイナナジュウネンインデックスカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14814': FundCodeEntry(
        fund_code='G14814',
        sec_code='22460',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ・フランス国債（７－１０年）インデックス（為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグフランスコクサイナナジュウネンインデックスカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14815': FundCodeEntry(
        fund_code='G14815',
        sec_code=None,
        fund_name='ピクテ・グローイング新興国株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ピクテグローイングシンコウコクカブシキファンドマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14816': FundCodeEntry(
        fund_code='G14816',
        sec_code=None,
        fund_name='ピクテ・グローイング新興国株式ファンド（１年決算型）',
        fund_name_yomi='ピクテグローイングシンコウコクカブシキファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14817': FundCodeEntry(
        fund_code='G14817',
        sec_code=None,
        fund_name='円建てニッポン社債ファンド２０２３－０５',
        fund_name_yomi='エンダテニッポンシャサイファンドニセンニジュウサンゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='6月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14818': FundCodeEntry(
        fund_code='G14818',
        sec_code=None,
        fund_name='アクセラレーション・ジャパン２０２３－０５（限定追加型・早期償還条項付）',
        fund_name_yomi='アクセラレーションジャパンニイゼロニイサンゼロゴゲンテイツイカガタソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='12月28日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14819': FundCodeEntry(
        fund_code='G14819',
        sec_code=None,
        fund_name='インデックスファンドＭＳＣＩオール・カントリー（全世界株式）',
        fund_name_yomi='インデックスファンドエムエスシーアイオール\u3000カントリー\u3000ゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14820': FundCodeEntry(
        fund_code='G14820',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000ＭＳＣＩオール・カントリー・インデックス（全世界株式）',
        fund_name_yomi='トレイサーズ\u3000エムエスシーアイオール\u3000カントリー\u3000インデックス\u3000ゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14821': FundCodeEntry(
        fund_code='G14821',
        sec_code=None,
        fund_name='フォーリン・エンジェル・ＵＳハイイールド・ファンド',
        fund_name_yomi='フォーリンエンジェルユーエスハイイールドファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G14822': FundCodeEntry(
        fund_code='G14822',
        sec_code=None,
        fund_name='ＰＩＭＣＯストラテジック・インカム・ファンド（為替ヘッジあり）、ＰＩＭＣＯストラテジック・インカム・ファンド（為替ヘッジなし）',
        fund_name_yomi='ピムコストラテジックインカムファンドカワセヘッジアリ\u3000ピムコストラテジックインカムファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14823': FundCodeEntry(
        fund_code='G14823',
        sec_code=None,
        fund_name='米国ヘルスケア関連株ファンド',
        fund_name_yomi='ベイコクヘルスケアカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14824': FundCodeEntry(
        fund_code='G14824',
        sec_code=None,
        fund_name='米国インフレ連動国債ファンド',
        fund_name_yomi='ベイコクインフレレンドウコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14825': FundCodeEntry(
        fund_code='G14825',
        sec_code=None,
        fund_name='日本株アクティブファンド（実績報酬型）',
        fund_name_yomi='ニホンカブアクティブファンドジッセキホウシュウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月17日',
        period_2='10月17日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14826': FundCodeEntry(
        fund_code='G14826',
        sec_code=None,
        fund_name='明治安田ＮＢグローバル好利回り社債ファンド２０２３－０６（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマンコウリマワリシャサイファンドニセンニジュウサンノロクゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14828': FundCodeEntry(
        fund_code='G14828',
        sec_code=None,
        fund_name='グローバル・ダイナミックチェンジ',
        fund_name_yomi='グローバルダイナミックチェンジ',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2='11月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14829': FundCodeEntry(
        fund_code='G14829',
        sec_code='22470',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000Ｓ＆Ｐ５００（為替ヘッジなし）',
        fund_name_yomi='アイフリーイーティーエフエスアンドピーゴヒャクカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14830': FundCodeEntry(
        fund_code='G14830',
        sec_code='22480',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000Ｓ＆Ｐ５００（為替ヘッジあり）',
        fund_name_yomi='アイフリーイーティーエフエスアンドピーゴヒャクカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14831': FundCodeEntry(
        fund_code='G14831',
        sec_code='22490',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000Ｓ＆Ｐ５００ダブルインバース',
        fund_name_yomi='アイフリーイーティーエフエスアンドピーゴヒャクダブルインバース',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14832': FundCodeEntry(
        fund_code='G14832',
        sec_code='22500',
        fund_name='ｉシェアーズ\u3000ＭＳＣＩ\u3000ジャパン気候変動アクション\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エムエスシーアイ\u3000ジャパンキコウヘンドウアクション\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G14834': FundCodeEntry(
        fund_code='G14834',
        sec_code=None,
        fund_name='ＧＳワールド・シフト株式ファンドＡコース（限定為替ヘッジ）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ジーエスワールドシフトカブシキファンド\u3000エーコース\u3000ゲンテイカワセヘッジ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14835': FundCodeEntry(
        fund_code='G14835',
        sec_code=None,
        fund_name='世界バイオ医薬株式ファンド',
        fund_name_yomi='セカイバイオイヤクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2='10月26日',
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G14836': FundCodeEntry(
        fund_code='G14836',
        sec_code=None,
        fund_name='三井住友・ＮＹダウ・ジョーンズ・インデックスファンド（為替ヘッジ型）',
        fund_name_yomi='ミツイスミトモニューヨークダウジョーンズインデックスファンドカワセヘッジガタ',
        security_type='内国投資信託受益証券',
        period_1='11月5日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14837': FundCodeEntry(
        fund_code='G14837',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国増配株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ベイコクゾウハイカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14838': FundCodeEntry(
        fund_code='G14838',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・先進国株式（除く米国）インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000センシンコクカブシキ\u3000ノゾクベイコク\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14839': FundCodeEntry(
        fund_code='G14839',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・世界小型株式（除く米国）インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000セカイコガタカブシキ\u3000ノゾクベイコク\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14840': FundCodeEntry(
        fund_code='G14840',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国小型株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ベイコクコガタカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14841': FundCodeEntry(
        fund_code='G14841',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・新興国株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000シンコウコクカブシキ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14842': FundCodeEntry(
        fund_code='G14842',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国総合債券インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクソウゴウサイケン\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14843': FundCodeEntry(
        fund_code='G14843',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国投資適格社債（１－５年）インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクトウシテキカクシャサイ\u3000イチカラゴネン\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14844': FundCodeEntry(
        fund_code='G14844',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国ハイイールド債券インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクハイイールドサイケン\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14845': FundCodeEntry(
        fund_code='G14845',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・ゴールドファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ゴールドファンド\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14846': FundCodeEntry(
        fund_code='G14846',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国短期国債ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクタンキコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14847': FundCodeEntry(
        fund_code='G14847',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２３－０７',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイサンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14848': FundCodeEntry(
        fund_code='G14848',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークングランドニッコー東京ベイ舞浜（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークングランドニッコートウキョウベイマイハマジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14849': FundCodeEntry(
        fund_code='G14849',
        sec_code=None,
        fund_name='三井物産のデジタル証券～日本橋・人形町～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンニホンバシニンギョウチョウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14850': FundCodeEntry(
        fund_code='G14850',
        sec_code=None,
        fund_name='ＳＯＭＰＯ好利回りＣＢファンド２０２３－０６（為替ヘッジあり／なし・限定追加型）',
        fund_name_yomi='ソンポコウリマワリシービーファンドニゼロニサンゼロロクカワセヘッジアリナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月27日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14851': FundCodeEntry(
        fund_code='G14851',
        sec_code=None,
        fund_name='ｉＦｒｅｅＰｌｕｓ\u3000米国配当王（資産成長型）',
        fund_name_yomi='アイフリープラスベイコクハイトウオウシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14852': FundCodeEntry(
        fund_code='G14852',
        sec_code=None,
        fund_name='ｉＦｒｅｅＰｌｕｓ\u3000米国配当王（年４回決算型）',
        fund_name_yomi='アイフリープラスベイコクハイトウオウネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月23日',
        period_2='11月23日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14853': FundCodeEntry(
        fund_code='G14853',
        sec_code=None,
        fund_name='ＭＦシェア駒込レジデンス（譲渡制限付）',
        fund_name_yomi='エムエフシェアコマゴメレジデンスジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14854': FundCodeEntry(
        fund_code='G14854',
        sec_code=None,
        fund_name='Ｏｎｅグローバル・ターゲット利回り債券ファンド２０２３－０６（限定追加型）',
        fund_name_yomi='ワングローバルターゲットリマワリサイケンファンドニイゼロニイサンゼロロクゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14855': FundCodeEntry(
        fund_code='G14855',
        sec_code=None,
        fund_name='ＤＣダイワ・ターゲットイヤー２０６０',
        fund_name_yomi='ディーシーダイワターゲットイヤーニセンロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14856': FundCodeEntry(
        fund_code='G14856',
        sec_code=None,
        fund_name='モルガン・スタンレー社債（早期償還条項付）／ＢＡＳＩＣ戦略ファンド２０２３－０６',
        fund_name_yomi='モルガンスタンレーシャサイソウキショウカンジョウコウツキベーシックセンリャクファンドニゼロニサンゼロロク',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14857': FundCodeEntry(
        fund_code='G14857',
        sec_code=None,
        fund_name='ブラジル国債ファンド',
        fund_name_yomi='ブラジルコクサイファンド',
        security_type='内国投資信託受益証券',
        period_1='6月14日',
        period_2='12月14日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14858': FundCodeEntry(
        fund_code='G14858',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－シティグループ社債／償還時指数連動型ファンド',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000シティグループシャサイショウカンジシスウレンドウガタファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G14859': FundCodeEntry(
        fund_code='G14859',
        sec_code=None,
        fund_name='グローバル・ストラテジーズ・トラスト－ボンド・プラス７．０',
        fund_name_yomi='グローバルストラテジーズトラスト\u3000ボンドプラスナナ',
        security_type='外国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E27921',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G14860': FundCodeEntry(
        fund_code='G14860',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・米国割安株投信（年２回決算型）／（隔月決算・予想分配金提示型）',
        fund_name_yomi='アライアンスバーンスタインベイコクワリヤスカブトウシンネンニカイケッサンガタ\u3000カクゲツケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14861': FundCodeEntry(
        fund_code='G14861',
        sec_code=None,
        fund_name='明治安田ＮＢ世界好利回り事業債ファンド２０２３－０７（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマンセカイコウリマワリジギョウサイファンドニセンニジュウサンノゼロナナゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='7月9日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14862': FundCodeEntry(
        fund_code='G14862',
        sec_code=None,
        fund_name='不動産デジタル証券・渋谷神宮前イノベーションオフィス',
        fund_name_yomi='フドウサンデジタルショウケン\u3000シブヤジングウマエイノベーションオフィス',
        security_type='内国有価証券投資事業権利等',
        period_1='1月末日',
        period_2=None,
        edinet_code='E38717',
        issuer_name='合同会社渋谷神宮前ＩＯ',
    ),
    'G14863': FundCodeEntry(
        fund_code='G14863',
        sec_code='22510',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸ国債先物ダブルインバース指数連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエックスコクサイサキモノダブルインバースシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14864': FundCodeEntry(
        fund_code='G14864',
        sec_code=None,
        fund_name='限定追加型・繰上償還条項付\u3000ニッセイ世界リカバリー株式厳選ファンド２０２３－０７（為替ヘッジあり）',
        fund_name_yomi='ゲンテイツイカガタ\u3000クリアゲショウカンジョウコウツキ\u3000ニッセイセカイリカバリーカブシキゲンセンファンドニゼロニサンゼロナナ\u3000カワヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14865': FundCodeEntry(
        fund_code='G14865',
        sec_code=None,
        fund_name='Ｎｉつみインデックスラップ世界１０指数（均等型）',
        fund_name_yomi='ニーツミインデックスラップセカイジュウシスウ\u3000キントウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14866': FundCodeEntry(
        fund_code='G14866',
        sec_code=None,
        fund_name='Ｎｉつみインデックスラップ世界１０指数（安定成長型）',
        fund_name_yomi='ニーツミインデックスラップセカイジュウシスウ\u3000アンテイセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14867': FundCodeEntry(
        fund_code='G14867',
        sec_code=None,
        fund_name='バークレイズ社債／インカム戦略ファンド２０２３－０７',
        fund_name_yomi='バークレイズシャサイ\u3000インカムセンリャクファンドニゼロニサンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14868': FundCodeEntry(
        fund_code='G14868',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２３－０７',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウサンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14869': FundCodeEntry(
        fund_code='G14869',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投資信託インデックス\u3000先進国株式',
        fund_name_yomi='ペイペイトウシシンタクインデックス\u3000センシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14870': FundCodeEntry(
        fund_code='G14870',
        sec_code=None,
        fund_name='ＰａｙＰａｙ投資信託インデックス\u3000世界株式',
        fund_name_yomi='ペイペイトウシシンタクインデックス\u3000セカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14871': FundCodeEntry(
        fund_code='G14871',
        sec_code=None,
        fund_name='フィデリティ・ＵＳリート・ファンド（隔月決算型）（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスリートファンドカクゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14872': FundCodeEntry(
        fund_code='G14872',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークンＳＴ所沢物流センター（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンエスティートコロザワブツリュウセンタージョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14873': FundCodeEntry(
        fund_code='G14873',
        sec_code=None,
        fund_name='グローバル・ライフ株式ファンド（資産成長型／予想分配金提示型）',
        fund_name_yomi='グローバルライフカブシキファンドシサンセイチョウガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月21日',
        period_2='12月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14874': FundCodeEntry(
        fund_code='G14874',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２３－０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイサンノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14875': FundCodeEntry(
        fund_code='G14875',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・ＴＯＰＩＸインデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000トピックス\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14876': FundCodeEntry(
        fund_code='G14876',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・日経２２５インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ニッケイニニゴ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14877': FundCodeEntry(
        fund_code='G14877',
        sec_code=None,
        fund_name='ラップ専用・日本株式アクティブ（セレクト・オポチュニティ）',
        fund_name_yomi='ラップセンヨウニホンカブシキアクティブセレクトオポチュニティ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14878': FundCodeEntry(
        fund_code='G14878',
        sec_code=None,
        fund_name='ラップ専用・世界株式アクティブ（グローバル・マルチテーマ）',
        fund_name_yomi='ラップセンヨウセカイカブシキアクティブグローバルマルチテーマ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14879': FundCodeEntry(
        fund_code='G14879',
        sec_code=None,
        fund_name='ラップ専用・世界株式アクティブ（グローバル・バリュー）',
        fund_name_yomi='ラップセンヨウセカイカブシキアクティブグローバルバリュー',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14880': FundCodeEntry(
        fund_code='G14880',
        sec_code=None,
        fund_name='ラップ専用・Ｊ－ＲＥＩＴアクティブ',
        fund_name_yomi='ラップセンヨウジェイリートアクティブ',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14881': FundCodeEntry(
        fund_code='G14881',
        sec_code=None,
        fund_name='ラップ専用・グローバルＲＥＩＴアクティブ',
        fund_name_yomi='ラップセンヨウグローバルリートアクティブ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14882': FundCodeEntry(
        fund_code='G14882',
        sec_code=None,
        fund_name='ラップ専用・日本債券アクティブ（クレジット戦略型）',
        fund_name_yomi='ラップセンヨウニホンサイケンアクティブクレジットセンリャクガタ',
        security_type='内国投資信託受益証券',
        period_1='8月27日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14883': FundCodeEntry(
        fund_code='G14883',
        sec_code=None,
        fund_name='ラップ専用・外国債券アクティブ',
        fund_name_yomi='ラップセンヨウガイコクサイケンアクティブ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14884': FundCodeEntry(
        fund_code='G14884',
        sec_code=None,
        fund_name='ラップ専用・外国国債アクティブ（為替ヘッジあり）',
        fund_name_yomi='ラップセンヨウガイコクコクサイアクティブカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14885': FundCodeEntry(
        fund_code='G14885',
        sec_code=None,
        fund_name='ラップ専用・米国ハイ・イールド債券アクティブ',
        fund_name_yomi='ラップセンヨウベイコクハイイールドサイケンアクティブ',
        security_type='内国投資信託受益証券',
        period_1='7月5日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14886': FundCodeEntry(
        fund_code='G14886',
        sec_code=None,
        fund_name='米国株カバードコール戦略ファンド／ＪＰモルガン・米国株式・プレミアム・インカムＥＴＦ',
        fund_name_yomi='ベイコクカブカバードコールセンリャクファンドジェイピーモルガンベイコクカブシキプレミアムインカムイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14887': FundCodeEntry(
        fund_code='G14887',
        sec_code=None,
        fund_name='世界株式インデックス戦略ファンド（資産成長型）２０２３－０７',
        fund_name_yomi='セカイカブシキインデックスセンリャクファンドシサンセイチョウガタニゼロニサンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14888': FundCodeEntry(
        fund_code='G14888',
        sec_code=None,
        fund_name='世界株式インデックス戦略ファンド（償還条項付）２０２３－０７',
        fund_name_yomi='セカイカブシキインデックスセンリャクファンドショウカンジョウコウツキニゼロニサンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14889': FundCodeEntry(
        fund_code='G14889',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０６５',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロロクゴ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14890': FundCodeEntry(
        fund_code='G14890',
        sec_code=None,
        fund_name='日本中小型成長株ファンド（実績報酬型）',
        fund_name_yomi='ニホンチュウコガタセイチョウカブファンドジッセキホウシュウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14891': FundCodeEntry(
        fund_code='G14891',
        sec_code=None,
        fund_name='半導体関連\u3000世界株式戦略ファンド',
        fund_name_yomi='ハンドウタイカンレン\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='7月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14892': FundCodeEntry(
        fund_code='G14892',
        sec_code=None,
        fund_name='財産３分法ファンド（不動産・債券・株式）奇数月分配型',
        fund_name_yomi='ザイサンサンブンポウファンド\u3000フドウサン\u3000サイケン\u3000カブシキ\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14893': FundCodeEntry(
        fund_code='G14893',
        sec_code=None,
        fund_name='いちご・レジデンス・トークン－中目黒・神楽坂・明大前・代々木・三軒茶屋－（譲渡制限付）',
        fund_name_yomi='イチゴレジデンストークンナカメグロカグラザカメイダイマエヨヨギサンゲンヂャヤジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14894': FundCodeEntry(
        fund_code='G14894',
        sec_code=None,
        fund_name='はじめてのＮＩＳＡ・米国株式インデックス（Ｓ＆Ｐ５００）',
        fund_name_yomi='ハジメテノニーサベイコクカブシキインデックスエスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14895': FundCodeEntry(
        fund_code='G14895',
        sec_code=None,
        fund_name='はじめてのＮＩＳＡ・全世界株式インデックス（オール・カントリー）',
        fund_name_yomi='ハジメテノニーサゼンセカイカブシキインデックスオールカントリー',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14896': FundCodeEntry(
        fund_code='G14896',
        sec_code=None,
        fund_name='はじめてのＮＩＳＡ・日本株式インデックス（日経２２５）',
        fund_name_yomi='ハジメテノニーサニホンカブシキインデックスニッケイニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14897': FundCodeEntry(
        fund_code='G14897',
        sec_code=None,
        fund_name='はじめてのＮＩＳＡ・日本株式インデックス（ＴＯＰＩＸ）',
        fund_name_yomi='ハジメテノニーサニホンカブシキインデックストピックス',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14898': FundCodeEntry(
        fund_code='G14898',
        sec_code=None,
        fund_name='はじめてのＮＩＳＡ・新興国株式インデックス',
        fund_name_yomi='ハジメテノニーサシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14899': FundCodeEntry(
        fund_code='G14899',
        sec_code=None,
        fund_name='ニッセイ・マルチアセット・インカム戦略ファンド（資産成長型）',
        fund_name_yomi='ニッセイマルチアセットインカムセンリャクファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月17日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14900': FundCodeEntry(
        fund_code='G14900',
        sec_code=None,
        fund_name='ニッセイ・マルチアセット・インカム戦略ファンド（毎月決算型）',
        fund_name_yomi='ニッセイマルチアセットインカムセンリャクファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14901': FundCodeEntry(
        fund_code='G14901',
        sec_code=None,
        fund_name='にいがた未来応援グローバル株式ファンド',
        fund_name_yomi='ニイガタミライオウエングローバルカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14902': FundCodeEntry(
        fund_code='G14902',
        sec_code='22520',
        fund_name='グローバルＸ\u3000Ｍｏｒｎｉｎｇｓｔａｒ\u3000米国中小型\u3000Ｍｏａｔ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスモーニングスターベイコクチュウコガタモートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14903': FundCodeEntry(
        fund_code='G14903',
        sec_code='22530',
        fund_name='グローバルＸ\u3000スーパーディビィデンド－ＵＳ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックススーパーディビィデンドユーエスイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14904': FundCodeEntry(
        fund_code='G14904',
        sec_code='22540',
        fund_name='グローバルＸ\u3000チャイナＥＶ＆バッテリー\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチャイナイーブイアンドバッテリーイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G14905': FundCodeEntry(
        fund_code='G14905',
        sec_code=None,
        fund_name='イーストスプリング・インドネシア株式ファンド（資産成長型）',
        fund_name_yomi='イーストスプリングインドネシアカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G14906': FundCodeEntry(
        fund_code='G14906',
        sec_code=None,
        fund_name='ソシエテ・ジェネラル社債／国際分散投資戦略ファンド２０２３－０９',
        fund_name_yomi='ソシエテ\u3000ジェネラルシャサイ\u3000コクサイブンサントウシセンリャクファンドニセンニジュウサンノゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14907': FundCodeEntry(
        fund_code='G14907',
        sec_code=None,
        fund_name='米国Ｓ＆Ｐ５００フレックス戦略ファンド',
        fund_name_yomi='ベイコクエスアンドピーゴヒャクフレックスセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14908': FundCodeEntry(
        fund_code='G14908',
        sec_code=None,
        fund_name='住友生命２０２３基金流動化株式会社',
        fund_name_yomi='スミトモセイメイニセンニジュウサンキキンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E38830',
        issuer_name='住友生命２０２３基金流動化株式会社',
    ),
    'G14909': FundCodeEntry(
        fund_code='G14909',
        sec_code=None,
        fund_name='投資用マンションローン債権セキュリティトークン（２０２３年第１号）',
        fund_name_yomi='トウシヨウマンションローンサイケンセキュリティトークンニセンニジュウサンネンダイイチゴウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='8月30日',
        period_2=None,
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G14910': FundCodeEntry(
        fund_code='G14910',
        sec_code=None,
        fund_name='フィデリティ・Ｊリート・アクティブ・ファンド（隔月決算型）',
        fund_name_yomi='フィデリティジェイリートアクティブファンドカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月6日',
        period_2='11月6日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14911': FundCodeEntry(
        fund_code='G14911',
        sec_code=None,
        fund_name='米国厳選優良株ファンド（実績報酬型）',
        fund_name_yomi='ベイコクゲンセンユウリョウカブファンドジッセキホウシュウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14912': FundCodeEntry(
        fund_code='G14912',
        sec_code=None,
        fund_name='三井物産のデジタル証券～京都・三条～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンキョウトサンジョウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G14913': FundCodeEntry(
        fund_code='G14913',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000月島－リバーシティ２１イーストタワーズⅡ（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンツキシマリバーシティニジュウイチイーストタワーズツージョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G14914': FundCodeEntry(
        fund_code='G14914',
        sec_code=None,
        fund_name='キャピタル・ラップ専用ファンド・２０２３シリーズ',
        fund_name_yomi='キャピタルラップセンヨウファンドニセンニジュウサンシリーズ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G14915': FundCodeEntry(
        fund_code='G14915',
        sec_code=None,
        fund_name='ＧＳ米ドル建て社債ターゲット２０２３－０９（為替ヘッジなし・限定追加型・早期償還条項付）',
        fund_name_yomi='ジーエス\u3000ベイドルダテ\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウサン\u3000ゼロキュー\u3000カワセヘッジナシ\u3000ゲンテイツイカガタ\u3000ソウキショウカンジョウコウツキ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G14916': FundCodeEntry(
        fund_code='G14916',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２３－０９',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイサンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14917': FundCodeEntry(
        fund_code='G14917',
        sec_code=None,
        fund_name='ＳＯＭＰＯ好利回りＣＢファンド２０２３－０９（為替ヘッジあり／なし・限定追加型）',
        fund_name_yomi='ソンポコウリマワリシービーファンドニゼロニサンゼロキュウカワセヘッジアリナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月19日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14918': FundCodeEntry(
        fund_code='G14918',
        sec_code=None,
        fund_name='ＵＳショートデュレーション戦略ファンド／ＪＰモルガン・ウルトラショート・インカムＥＴＦ',
        fund_name_yomi='ユーエスショートデュレーションセンリャクファンドジェイピーモルガンウルトラショートインカムイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14919': FundCodeEntry(
        fund_code='G14919',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム債券ファンド（１年決算型）',
        fund_name_yomi='ピクテグローバルインカムサイケンファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14920': FundCodeEntry(
        fund_code='G14920',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム債券ファンド（隔月決算型）',
        fund_name_yomi='ピクテグローバルインカムサイケンファンドカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14921': FundCodeEntry(
        fund_code='G14921',
        sec_code=None,
        fund_name='フィデリティ・グローバル社債・ファンド\u3000２０２３－０９（限定追加型・為替ヘッジあり）\u3000フィデリティ・グローバル社債・ファンド\u3000２０２３－０９（限定追加型・為替ヘッジなし）',
        fund_name_yomi='フィデリティグローバルシャサイファンドニセンニジュウサンゼロキュウゲンテイツイカガタカワセヘッジアリ\u3000フィデリティグローバルシャサイファンドニセンニジュウサンゼロキュウゲンテイツイカガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14922': FundCodeEntry(
        fund_code='G14922',
        sec_code=None,
        fund_name='フィデリティ・ロイヤル・コア・ファンド',
        fund_name_yomi='フィデリティロイヤルコアファンド',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14923': FundCodeEntry(
        fund_code='G14923',
        sec_code=None,
        fund_name='ラサール・グローバルＲＥＩＴファンド（奇数月分配型）',
        fund_name_yomi='ラサール\u3000グローバルリートファンド\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月5日',
        period_2='7月5日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14924': FundCodeEntry(
        fund_code='G14924',
        sec_code=None,
        fund_name='ウエリントン・企業価値共創世界株ファンド\u3000Ａコース／Ｂコース',
        fund_name_yomi='ウエリントンキギョウカチキョウソウセカイカブファンド\u3000エーコースビーコース',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14925': FundCodeEntry(
        fund_code='G14925',
        sec_code=None,
        fund_name='ピクテ・プレミアム・アセット・アロケーション・ファンド',
        fund_name_yomi='ピクテプレミアムアセットアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14926': FundCodeEntry(
        fund_code='G14926',
        sec_code=None,
        fund_name='グローバル株式厳選ファンド',
        fund_name_yomi='グローバルカブシキゲンセンファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14927': FundCodeEntry(
        fund_code='G14927',
        sec_code=None,
        fund_name='ＳＢＩ・インベスコＱＱＱ・ＮＡＳＤＡＱ１００インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000インベスコキューキューキュー\u3000ナスダックヒャクインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='8月22日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14928': FundCodeEntry(
        fund_code='G14928',
        sec_code=None,
        fund_name='東京海上・米国リカバリー・ポテンシャル戦略株式ファンド',
        fund_name_yomi='トウキョウカイジョウベイコクリカバリーポテンシャルセンリャクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14929': FundCodeEntry(
        fund_code='G14929',
        sec_code=None,
        fund_name='Ｔ＆Ｄダブルブル・ベア・シリーズ９',
        fund_name_yomi='ティアンドディダブルブルベアシリーズキュウ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G14930': FundCodeEntry(
        fund_code='G14930',
        sec_code=None,
        fund_name='ａｕＡＭ\u3000Ｎｉｆｔｙ５０インド株ファンド',
        fund_name_yomi='エーユーエーエムニフティゴジュウインドカブファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G14931': FundCodeEntry(
        fund_code='G14931',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２３－０９',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウサンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14932': FundCodeEntry(
        fund_code='G14932',
        sec_code=None,
        fund_name='ＴＴＩ・エマージング厳選株式ファンド',
        fund_name_yomi='ティーティーアイエマージングゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14933': FundCodeEntry(
        fund_code='G14933',
        sec_code=None,
        fund_name='フィデリティ・ＵＳハイ・イールド・ファンド（隔月決算型）（為替ヘッジなし）',
        fund_name_yomi='フィデリティユーエスハイイールドファンドカクゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14934': FundCodeEntry(
        fund_code='G14934',
        sec_code=None,
        fund_name='Ｓ＆Ｐ５００\u3000３倍ベア',
        fund_name_yomi='エスアンドピーゴヒャクサンバイベア',
        security_type='内国投資信託受益証券',
        period_1='8月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14935': FundCodeEntry(
        fund_code='G14935',
        sec_code=None,
        fund_name='Ｓ＆Ｐ５００\u3000３倍ブル',
        fund_name_yomi='エスアンドピーゴヒャクサンバイブル',
        security_type='内国投資信託受益証券',
        period_1='8月13日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14936': FundCodeEntry(
        fund_code='G14936',
        sec_code=None,
        fund_name='野村ＰＩＭＣＯ・トレンド戦略ファンド（米ドル売り円買い）（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラピムコトレンドセンリャクファンドベイドルウリエンガイノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14937': FundCodeEntry(
        fund_code='G14937',
        sec_code=None,
        fund_name='みずほ日本オールキャップ株式ファンド',
        fund_name_yomi='ミズホニホンオールキャップカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14938': FundCodeEntry(
        fund_code='G14938',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000ターゲット・イヤー・ファンド２０７０（確定拠出年金）',
        fund_name_yomi='ミツビシユーエフジェイターゲットイヤーファンドニセンナナジュウカクテイキョシュツネンキン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14939': FundCodeEntry(
        fund_code='G14939',
        sec_code=None,
        fund_name='東京海上・先進国好利回りＣＢファンド２０２３－０９',
        fund_name_yomi='トウキョウカイジョウセンシンコクコウリマワリシービーファンドニセンニジュウサンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='11月24日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14940': FundCodeEntry(
        fund_code='G14940',
        sec_code=None,
        fund_name='フィデリティ・日本バリューアップ・ファンド',
        fund_name_yomi='フィデリティニホンバリューアップファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G14941': FundCodeEntry(
        fund_code='G14941',
        sec_code=None,
        fund_name='世界半導体関連フォーカスファンド',
        fund_name_yomi='セカイハンドウタイカンレンフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='3月16日',
        period_2='9月16日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14942': FundCodeEntry(
        fund_code='G14942',
        sec_code=None,
        fund_name='三井住友ＤＳ\u3000ワールド・ボンド・フォーカス２０２３－０９（限定追加型）',
        fund_name_yomi='ミツイスミトモディーエスワールドボンドフォーカスニイゼロニイサンゼロキュウゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G14943': FundCodeEntry(
        fund_code='G14943',
        sec_code=None,
        fund_name='野村米国株式Ｓ＆Ｐ５００インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラベイコクカブシキエスアンドピーゴヒャクインデックスファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14944': FundCodeEntry(
        fund_code='G14944',
        sec_code=None,
        fund_name='ブリオングロード・ブリッジ・ユニット・トラスト―Ｏｎｅ―Ｄａｙ・プレミアム',
        fund_name_yomi='ブリオングロードブリッジユニットトラストワンデイプレミアム',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35772',
        issuer_name='ウェイストーン・マネジメント・カンパニー（ＩＥ）リミテッド',
    ),
    'G14945': FundCodeEntry(
        fund_code='G14945',
        sec_code=None,
        fund_name='構造改革ジャパン',
        fund_name_yomi='コウゾウカイカクジャパン',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14946': FundCodeEntry(
        fund_code='G14946',
        sec_code=None,
        fund_name='アセアン・ギガトレンド株式ファンド',
        fund_name_yomi='アセアン\u3000ギガトレンドカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14947': FundCodeEntry(
        fund_code='G14947',
        sec_code='20860',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000Ｓ＆Ｐ５００（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000エスアンドピーゴヒャク\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14948': FundCodeEntry(
        fund_code='G14948',
        sec_code='20870',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＮＡＳＤＡＱ１００（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ナスダックヒャク\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14949': FundCodeEntry(
        fund_code='G14949',
        sec_code='20880',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＮＹダウ３０（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ニューヨークダウサンジュウ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14950': FundCodeEntry(
        fund_code='G14950',
        sec_code='20890',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ＤＡＸ（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ダックス\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14951': FundCodeEntry(
        fund_code='G14951',
        sec_code='20900',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000米国国債７－１０年（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ベイコクコクサイナナカラジュウネン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14952': FundCodeEntry(
        fund_code='G14952',
        sec_code='20910',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000ドイツ国債７－１０年（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000ドイツコクサイナナカラジュウネン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14953': FundCodeEntry(
        fund_code='G14953',
        sec_code='20920',
        fund_name='ＮＺＡＭ\u3000上場投信\u3000フランス国債７－１０年（為替ヘッジあり）',
        fund_name_yomi='エヌザム\u3000ジョウジョウトウシン\u3000フランスコクサイナナカラジュウネン\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G14954': FundCodeEntry(
        fund_code='G14954',
        sec_code=None,
        fund_name='明治安田米国レベニュー債オープン（為替ヘッジなし）',
        fund_name_yomi='メイジヤスダベイコクレベニューサイオープン\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G14955': FundCodeEntry(
        fund_code='G14955',
        sec_code='20830',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日本成長株アクティブ上場投信',
        fund_name_yomi='ネクストファンズニホンセイチョウカブアクティブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14956': FundCodeEntry(
        fund_code='G14956',
        sec_code='20840',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日本高配当株アクティブ上場投信',
        fund_name_yomi='ネクストファンズニホンコウハイトウカブアクティブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14957': FundCodeEntry(
        fund_code='G14957',
        sec_code=None,
        fund_name='ニッセイ／サンダース・グローバルバリュー株式ファンド（資産成長型）',
        fund_name_yomi='ニッセイサンダースグローバルバリューカブシキファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14958': FundCodeEntry(
        fund_code='G14958',
        sec_code=None,
        fund_name='ニッセイ／サンダース・グローバルバリュー株式ファンド（隔月予想分配金提示型）',
        fund_name_yomi='ニッセイサンダースグローバルバリューカブシキファンド\u3000カクゲツヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14959': FundCodeEntry(
        fund_code='G14959',
        sec_code=None,
        fund_name='ＤＣニッセイ／サンダース・グローバルバリュー株式ファンド',
        fund_name_yomi='ディーシーニッセイサンダースグローバルバリューカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14960': FundCodeEntry(
        fund_code='G14960',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・インド株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000インドカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G14961': FundCodeEntry(
        fund_code='G14961',
        sec_code='20800',
        fund_name='ＰＢＲ１倍割れ解消推進ＥＴＦ',
        fund_name_yomi='ピービーアールイチバイワレカイショウスイシンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G14962': FundCodeEntry(
        fund_code='G14962',
        sec_code='20810',
        fund_name='政策保有解消推進ＥＴＦ',
        fund_name_yomi='セイサクホユウカイショウスイシンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G14963': FundCodeEntry(
        fund_code='G14963',
        sec_code='20820',
        fund_name='投資家経営者一心同体ＥＴＦ',
        fund_name_yomi='トウシカケイエイシャイッシンドウタイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G14964': FundCodeEntry(
        fund_code='G14964',
        sec_code=None,
        fund_name='りそなＪリートインデックス（年１回決算型）',
        fund_name_yomi='リソナジェイリートインデックス\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14965': FundCodeEntry(
        fund_code='G14965',
        sec_code=None,
        fund_name='りそなＪリートインデックス（年４回決算型）',
        fund_name_yomi='リソナジェイリートインデックス\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14966': FundCodeEntry(
        fund_code='G14966',
        sec_code=None,
        fund_name='りそなＳ＆Ｐ５００インデックス',
        fund_name_yomi='リソナエスアンドピーゴヒャクインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14967': FundCodeEntry(
        fund_code='G14967',
        sec_code=None,
        fund_name='米国株アクティブ・グロース戦略ファンド／ＪＰモルガン・米国グロース株式・アクティブＥＴＦ',
        fund_name_yomi='ベイコクカブアクティブグロースセンリャクファンドジェイピーモルガンベイコクグロースカブシキアクティブイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14968': FundCodeEntry(
        fund_code='G14968',
        sec_code=None,
        fund_name='グローバル１０資産バランスファンド',
        fund_name_yomi='グローバルジュウシサンバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14969': FundCodeEntry(
        fund_code='G14969',
        sec_code='20850',
        fund_name='ＭＡＸＩＳ高配当日本株アクティブ上場投信',
        fund_name_yomi='マクシスコウハイトウニホンカブアクティブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14970': FundCodeEntry(
        fund_code='G14970',
        sec_code=None,
        fund_name='米国株式アグレッシブ・ポートフォリオ',
        fund_name_yomi='ベイコクカブシキアグレッシブポートフォリオ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G14971': FundCodeEntry(
        fund_code='G14971',
        sec_code=None,
        fund_name='ファイン・ブレンド（奇数月分配型）',
        fund_name_yomi='ファイン\u3000ブレンド\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14972': FundCodeEntry(
        fund_code='G14972',
        sec_code=None,
        fund_name='米国地方債ファンド\u3000為替ヘッジあり（奇数月決算型）\u3000米国地方債ファンド\u3000為替ヘッジなし（奇数月決算型）',
        fund_name_yomi='ベイコクチホウサイファンド\u3000カワセヘッジアリ\u3000キスウヅキケッサンガタ\u3000ベイコクチホウサイファンド\u3000カワセヘッジナシ\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14973': FundCodeEntry(
        fund_code='G14973',
        sec_code=None,
        fund_name='しんきんＪリートオープン（隔月決算型）',
        fund_name_yomi='シンキンジェイリートオープンカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G14974': FundCodeEntry(
        fund_code='G14974',
        sec_code=None,
        fund_name='高成長ＡＳＥＡＮ小型株式ファンド',
        fund_name_yomi='コウセイチョウアセアンコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月26日',
        period_2='2月26日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G14975': FundCodeEntry(
        fund_code='G14975',
        sec_code=None,
        fund_name='日本企業ＰＢＲ向上ファンド',
        fund_name_yomi='ニホンキギョウピービーアールコウジョウファンド',
        security_type='内国投資信託受益証券',
        period_1='3月22日',
        period_2='9月22日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14976': FundCodeEntry(
        fund_code='G14976',
        sec_code=None,
        fund_name='ＤＣニッセイ全世界株式インデックスコレクト',
        fund_name_yomi='ディーシーニッセイゼンセカイカブシキインデックスコレクト',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G14978': FundCodeEntry(
        fund_code='G14978',
        sec_code=None,
        fund_name='Ｊ－ＲＥＩＴ・リサーチ・オープン（奇数月決算型）',
        fund_name_yomi='ジェイリート\u3000リサーチ\u3000オープン\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G14979': FundCodeEntry(
        fund_code='G14979',
        sec_code=None,
        fund_name='インベスコ\u3000世界厳選株式オープン（奇数月決算型）',
        fund_name_yomi='インベスコセカイゲンセンカブシキオープンキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G14980': FundCodeEntry(
        fund_code='G14980',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000全米株式',
        fund_name_yomi='イーマクシススリムゼンベイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G14981': FundCodeEntry(
        fund_code='G14981',
        sec_code=None,
        fund_name='インデックスファンドＳＯＸ指数（米国上場半導体株式）',
        fund_name_yomi='インデックスファンドソックスシスウ\u3000ベイコクジョウジョウハンドウタイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14982': FundCodeEntry(
        fund_code='G14982',
        sec_code=None,
        fund_name='ＤＣ低リスク運用・先進国バランスファンド（円キャッシュプラス）',
        fund_name_yomi='ディーシーテイリスクウンヨウ\u3000センシンコクバランスファンド\u3000エンキャッシュプラス',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14983': FundCodeEntry(
        fund_code='G14983',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000ＤＣ\u3000全世界株式インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000ディーシー\u3000ゼンセカイカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14984': FundCodeEntry(
        fund_code='G14984',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000ＤＣ\u3000全世界株式インデックス（除く日本）',
        fund_name_yomi='スマート\u3000アイ\u3000ディーシー\u3000ゼンセカイカブシキインデックス\u3000ノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G14985': FundCodeEntry(
        fund_code='G14985',
        sec_code=None,
        fund_name='ピクテ新興国ゴールデン・リスクプレミアム・ファンド',
        fund_name_yomi='ピクテシンコウコクゴールデンリスクプレミアムファンド',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G14987': FundCodeEntry(
        fund_code='G14987',
        sec_code=None,
        fund_name='ダイワＪ－ＲＥＩＴオープン（奇数月決算型）',
        fund_name_yomi='ダイワジェイリートオープンキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14988': FundCodeEntry(
        fund_code='G14988',
        sec_code=None,
        fund_name='ダイワ・グローバルＲＥＩＴ・オープン（為替ヘッジなし／奇数月決算型）',
        fund_name_yomi='ダイワグローバルリートオープンカワセヘッジナシキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G14991': FundCodeEntry(
        fund_code='G14991',
        sec_code=None,
        fund_name='新光\u3000ＵＳ－ＲＥＩＴ\u3000オープン（隔月決算型）',
        fund_name_yomi='シンコウ\u3000ユーエスリート\u3000オープン\u3000カクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G14992': FundCodeEntry(
        fund_code='G14992',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２３－１０',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイサンノイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14993': FundCodeEntry(
        fund_code='G14993',
        sec_code=None,
        fund_name='あおぞら・新グローバル・コア・ファンド（限定追加型）２０２３－Ⅱ',
        fund_name_yomi='アオゾラシングローバルコアファンドゲンテイツイカガタニイゼロニイサンノニ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G14994': FundCodeEntry(
        fund_code='G14994',
        sec_code=None,
        fund_name='３県未来ファンド',
        fund_name_yomi='サンケンミライファンド',
        security_type='内国投資信託受益証券',
        period_1='6月11日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G14995': FundCodeEntry(
        fund_code='G14995',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・米国成長株投信Ｅコース隔月決算型（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='アライアンスバーンスタインベイコクセイチョウカブトウシンイーコースカクゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G14996': FundCodeEntry(
        fund_code='G14996',
        sec_code=None,
        fund_name='バークレイズ社債／インカム戦略ファンド２０２３－１０',
        fund_name_yomi='バークレイズシャサイインカムセンリャクファンドニゼロニサンイチゼロ',
        security_type='内国投資信託受益証券',
        period_1='10月27日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G14997': FundCodeEntry(
        fund_code='G14997',
        sec_code='20930',
        fund_name='上場Ｔｒａｃｅｒｓ\u3000米国債０－２年ラダー（為替ヘッジなし）',
        fund_name_yomi='ジョウジョウトレイサーズ\u3000ベイコクサイゼロニネンラダー\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G14998': FundCodeEntry(
        fund_code='G14998',
        sec_code=None,
        fund_name='東京海上・世界モノポリー戦略株式ファンド（年６回決算型）',
        fund_name_yomi='トウキョウカイジョウセカイモノポリーセンリャクカブシキファンドネンロッカイケッサンカタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G14999': FundCodeEntry(
        fund_code='G14999',
        sec_code=None,
        fund_name='ダイワ・ＵＳ－ＲＥＩＴ・オープン（為替ヘッジなし／奇数月決算型）',
        fund_name_yomi='ダイワユーエスリートオープンカワセヘッジナシキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月17日',
        period_2='9月17日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15000': FundCodeEntry(
        fund_code='G15000',
        sec_code=None,
        fund_name='米国国債ファンド\u3000為替ヘッジなし（奇数月決算型）',
        fund_name_yomi='ベイコクコクサイファンドカワセヘッジナシキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15001': FundCodeEntry(
        fund_code='G15001',
        sec_code=None,
        fund_name='ＤＩＡＭ世界リートインデックスファンド（隔月分配型）',
        fund_name_yomi='ダイアムセカイリートインデックスファンドカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月13日',
        period_2='12月13日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15002': FundCodeEntry(
        fund_code='G15002',
        sec_code=None,
        fund_name='ピクテ・グローバル・インカム株式ファンド（隔月分配型）',
        fund_name_yomi='ピクテグローバルインカムカブシキファンドカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G15003': FundCodeEntry(
        fund_code='G15003',
        sec_code=None,
        fund_name='ＥＸＥ－ｉ\u3000グローバルサウス株式ファンド',
        fund_name_yomi='エグゼアイ\u3000グローバルサウスカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15004': FundCodeEntry(
        fund_code='G15004',
        sec_code=None,
        fund_name='ドナルド・スミス米国ディープバリュー株式ファンド\u3000Ａコース（為替ヘッジあり）\u3000ドナルド・スミス米国ディープバリュー株式ファンド\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ドナルドスミスベイコクディープバリューカブシキファンドエーコースカワセヘッジアリ\u3000ドナルドスミスベイコクディープバリューカブシキファンドビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月24日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15005': FundCodeEntry(
        fund_code='G15005',
        sec_code=None,
        fund_name='ＡＭＯ\u3000Ｊリートアクティブファンド（隔月決算型）',
        fund_name_yomi='エーエムオージェイリートアクティブファンドカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月5日',
        period_2='11月5日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15006': FundCodeEntry(
        fund_code='G15006',
        sec_code='20940',
        fund_name='東証ＲＥＩＴインバースＥＴＦ',
        fund_name_yomi='トウショウリートインバースイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15007': FundCodeEntry(
        fund_code='G15007',
        sec_code=None,
        fund_name='しんきんＧ７外国債券インデックスファンド（３ヵ月決算型）',
        fund_name_yomi='シンキンジーセブンガイコクサイケンインデックスファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G15008': FundCodeEntry(
        fund_code='G15008',
        sec_code=None,
        fund_name='しんきんみんなの日本株ファンド',
        fund_name_yomi='シンキンミンナノニホンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2='10月22日',
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G15009': FundCodeEntry(
        fund_code='G15009',
        sec_code=None,
        fund_name='ＪＰＭグローバル高利回りＣＢファンド（為替ヘッジなし、限定追加型）２０２３ー１１／ＪＰＭグローバル高利回りＣＢファンド（為替ヘッジあり、限定追加型）２０２３ー１１',
        fund_name_yomi='ジェイピーエムグローバルコウリマワリシービーファンドカワセヘッジナシゲンテイツイカガタニセンニジュウサンノジュウイチ\u3000ジェイピーエムグローバルコウリマワリシービーファンドカワセヘッジアリゲンテイツイカガタニセンニジュウサンノジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='11月6日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15010': FundCodeEntry(
        fund_code='G15010',
        sec_code=None,
        fund_name='ＧＳグローバル・パーシャルヘッジ社債ファンド',
        fund_name_yomi='ジーエスグローバルパーシャルヘッジシャサイファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15011': FundCodeEntry(
        fund_code='G15011',
        sec_code=None,
        fund_name='グローバル好配当株オープン（年１回決算型）',
        fund_name_yomi='グローバルコウハイトウカブオープンネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15012': FundCodeEntry(
        fund_code='G15012',
        sec_code=None,
        fund_name='三井物産のデジタル証券～熱海温泉～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンアタミオンセンジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15013': FundCodeEntry(
        fund_code='G15013',
        sec_code=None,
        fund_name='りそな米国株式配当貴族インデックス（年１回決算型）',
        fund_name_yomi='リソナベイコクカブシキハイトウキゾクインデックス\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15014': FundCodeEntry(
        fund_code='G15014',
        sec_code=None,
        fund_name='りそな米国株式配当貴族インデックス（年４回決算型）',
        fund_name_yomi='リソナベイコクカブシキハイトウキゾクインデックス\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15015': FundCodeEntry(
        fund_code='G15015',
        sec_code=None,
        fund_name='限定追加型\u3000ニッセイ米ドル建て社債ファンド２０２３－１１（為替ヘッジあり）',
        fund_name_yomi='ゲンテイツイカガタ\u3000ニッセイベイドルダテシャサイファンド\u3000ニゼロニサンイチイチカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15016': FundCodeEntry(
        fund_code='G15016',
        sec_code=None,
        fund_name='米国好配当リバランスオープン（資産成長型）',
        fund_name_yomi='ベイコクコウハイトウリバランスオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15017': FundCodeEntry(
        fund_code='G15017',
        sec_code=None,
        fund_name='米国好配当リバランスオープン（年４回決算型）',
        fund_name_yomi='ベイコクコウハイトウリバランスオープンネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15018': FundCodeEntry(
        fund_code='G15018',
        sec_code=None,
        fund_name='全共連第３回劣後ローン流動化株式会社',
        fund_name_yomi='ゼンキョウレンダイサンカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E39058',
        issuer_name='全共連第３回劣後ローン流動化株式会社',
    ),
    'G15019': FundCodeEntry(
        fund_code='G15019',
        sec_code=None,
        fund_name='フランクリン・テンプルトン・アメリカ地方債ファンド（為替ヘッジなし）（隔月分配型）',
        fund_name_yomi='フランクリン\u3000テンプルトン\u3000アメリカチホウサイファンド\u3000カワセヘッジナシ\u3000カクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12425',
        issuer_name='フランクリン・テンプルトン・ジャパン株式会社',
    ),
    'G15020': FundCodeEntry(
        fund_code='G15020',
        sec_code=None,
        fund_name='スパークス・日本株Ｌ＆Ｓファンド（野村ＳМＡ・ＥＷ向け）',
        fund_name_yomi='スパークス\u3000ニホンカブ\u3000エルアンドエス\u3000ファンド\u3000ノムラ\u3000エスエムエー\u3000イーダブリュー\u3000ムケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E11161',
        issuer_name='スパークス・アセット・マネジメント株式会社',
    ),
    'G15021': FundCodeEntry(
        fund_code='G15021',
        sec_code=None,
        fund_name='明治安田ＮＢグローバル好利回り社債ファンド２０２３－１２（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマングローバルコウリマワリシャサイファンドニセンニジュウサンノジュウニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15022': FundCodeEntry(
        fund_code='G15022',
        sec_code=None,
        fund_name='Ｏｎｅグローバル・ターゲット利回り投資適格債券ファンド２０２３－１２（限定追加型）',
        fund_name_yomi='ワングローバルターゲットリマワリトウシテキカクサイケンファンドニイゼロニイサンイチニイゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15023': FundCodeEntry(
        fund_code='G15023',
        sec_code=None,
        fund_name='ニッセイ・Ｓ米国株式５００インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイエスベイコクカブシキゴヒャクインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15024': FundCodeEntry(
        fund_code='G15024',
        sec_code=None,
        fund_name='楽天・プラス・Ｓ＆Ｐ５００インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000エスアンドピーゴヒャクインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15025': FundCodeEntry(
        fund_code='G15025',
        sec_code=None,
        fund_name='楽天・プラス・オールカントリー株式インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000オールカントリーカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15026': FundCodeEntry(
        fund_code='G15026',
        sec_code='20980',
        fund_name='グローバルＸ\u3000ホテル＆リテール・Ｊ－ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスホテルアンドリテールジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15027': FundCodeEntry(
        fund_code='G15027',
        sec_code='20970',
        fund_name='グローバルＸ\u3000レジデンシャル・Ｊ－ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスレジデンシャルジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15028': FundCodeEntry(
        fund_code='G15028',
        sec_code='20960',
        fund_name='グローバルＸ\u3000オフィス・Ｊ－ＲＥＩＴ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスオフィスジェイリートイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15029': FundCodeEntry(
        fund_code='G15029',
        sec_code='20950',
        fund_name='グローバルＸ\u3000Ｓ＆Ｐ５００配当貴族\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='グローバルエックスエスアンドピーゴヒャクハイトウキゾクイーティエフカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月24日',
        period_2='11月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15030': FundCodeEntry(
        fund_code='G15030',
        sec_code=None,
        fund_name='米ドル建シティグループ社債／国際分散投資戦略ファンド２０２３－１１',
        fund_name_yomi='ベイドルダテシティグループシャサイ\u3000コクサイブンサントウシセンリャクファンドニセンニジュウサンノジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='12月19日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15031': FundCodeEntry(
        fund_code='G15031',
        sec_code=None,
        fund_name='ＶＴＸ\u3000生涯設計プラス６０／４０（資産成長型）',
        fund_name_yomi='ブイティーエックス\u3000ショウガイセッケイプラスロクジュウ\u3000ヨンジュウ\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E38423',
        issuer_name='バーテックス・インベストメント・ソリューションズ株式会社',
    ),
    'G15032': FundCodeEntry(
        fund_code='G15032',
        sec_code=None,
        fund_name='Ｏｎｅグローバル・ターゲット利回り債券ファンド２０２３－１２（限定追加型）',
        fund_name_yomi='ワングローバルターゲットリマワリサイケンファンドニイゼロニイサンイチニイゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15033': FundCodeEntry(
        fund_code='G15033',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２３－１２',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウサンジュウニ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15035': FundCodeEntry(
        fund_code='G15035',
        sec_code=None,
        fund_name='つみたてｉシェアーズ\u3000米国株式（Ｓ＆Ｐ５００）インデックス・ファンド',
        fund_name_yomi='ツミタテアイシェアーズベイコクカブシキエスアンドピーゴヒャクインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15036': FundCodeEntry(
        fund_code='G15036',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ｉＰｌｕｓ\u3000全世界株式',
        fund_name_yomi='エスエムティー\u3000アイプラス\u3000ゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15037': FundCodeEntry(
        fund_code='G15037',
        sec_code=None,
        fund_name='ＳＭＴ\u3000ｉＰｌｕｓ\u3000米国株式',
        fund_name_yomi='エスエムティー\u3000アイプラス\u3000ベイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月8日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15038': FundCodeEntry(
        fund_code='G15038',
        sec_code=None,
        fund_name='野村アバンティス世界株式ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村アバンティス世界株式ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラアバンティスセカイカブシキファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラアバンティスセカイカブシキファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15039': FundCodeEntry(
        fund_code='G15039',
        sec_code=None,
        fund_name='野村アバンティス米国小型株ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村アバンティス米国小型株ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラアバンティスベイコクコガタカブファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラアバンティスベイコクコガタカブファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15040': FundCodeEntry(
        fund_code='G15040',
        sec_code=None,
        fund_name='野村アバンティス新興国株ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）、野村アバンティス新興国株ファンド\u3000Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラアバンティスシンコウコクカブファンドエーコースノムラエスエムエーイーダブリュームケ\u3000ノムラアバンティスシンコウコクカブファンドビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15041': FundCodeEntry(
        fund_code='G15041',
        sec_code=None,
        fund_name='ＤＣ世界経済インデックスファンド（株式特化型）',
        fund_name_yomi='ディーシーセカイケイザイインデックスファンド\u3000カブシキトッカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15042': FundCodeEntry(
        fund_code='G15042',
        sec_code=None,
        fund_name='ＳＢＩ日本国債（分配）ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ニホンコクサイ\u3000ブンパイ\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15044': FundCodeEntry(
        fund_code='G15044',
        sec_code='22570',
        fund_name='ｉシェアーズ\u3000米ドル建て投資適格社債\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイドルダテトウシテキカクシャサイ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15045': FundCodeEntry(
        fund_code='G15045',
        sec_code='22580',
        fund_name='ｉシェアーズ\u3000米ドル建てハイイールド社債\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイドルダテハイイールドシャサイ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15046': FundCodeEntry(
        fund_code='G15046',
        sec_code='22560',
        fund_name='ｉシェアーズ\u3000米国総合債券\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクソウゴウサイケン\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15047': FundCodeEntry(
        fund_code='G15047',
        sec_code='22550',
        fund_name='ｉシェアーズ\u3000米国債２０年超\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイニジュウネンチョウ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15048': FundCodeEntry(
        fund_code='G15048',
        sec_code='22590',
        fund_name='ｉシェアーズ\u3000フランス国債７－１０年\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000フランスコクサイナナジュウネン\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15049': FundCodeEntry(
        fund_code='G15049',
        sec_code=None,
        fund_name='三井物産のデジタル証券～横浜～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンヨコハマジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15050': FundCodeEntry(
        fund_code='G15050',
        sec_code=None,
        fund_name='Ｏｎｅ\u3000Ｊ－ＲＥＩＴインデックスファンド（隔月決算型）',
        fund_name_yomi='ワンジェイリートインデックスファンドカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15051': FundCodeEntry(
        fund_code='G15051',
        sec_code=None,
        fund_name='ＵＳプレミアム・インカムファンド（年１回決算型）',
        fund_name_yomi='ユーエスプレミアムインカムファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15053': FundCodeEntry(
        fund_code='G15053',
        sec_code=None,
        fund_name='ＵＳプレミアム・インカムファンド（年４回決算型）',
        fund_name_yomi='ユーエスプレミアムインカムファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15054': FundCodeEntry(
        fund_code='G15054',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000ドーミーイン神戸元町（デジタル名義書換方式）',
        fund_name_yomi='ケネディクス\u3000リアルティ\u3000トークン\u3000ドーミーインコウベモトマチ\u3000デジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E30037',
        issuer_name='株式会社ＳＭＢＣ信託銀行',
    ),
    'G15055': FundCodeEntry(
        fund_code='G15055',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000ニュー・ホライズン・ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000ニューホライズンファンド\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15056': FundCodeEntry(
        fund_code='G15056',
        sec_code=None,
        fund_name='インサイト・ハイ・イールド社債ファンド２０２３－１２（限定追加型）',
        fund_name_yomi='インサイトハイイールドシャサイファンドニイゼロニイサンイチニイゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='12月22日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15057': FundCodeEntry(
        fund_code='G15057',
        sec_code=None,
        fund_name='オーストラリア公社債ファンド（奇数月決算型）',
        fund_name_yomi='オーストラリアコウシャサイファンド\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15058': FundCodeEntry(
        fund_code='G15058',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000日経連続増配株指数（資産成長型／年４回決算型）',
        fund_name_yomi='アイフリーネクストニッケイレンゾクゾウハイカブシスウシサンセイチョウガタネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月21日',
        period_2='10月21日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15059': FundCodeEntry(
        fund_code='G15059',
        sec_code=None,
        fund_name='Ｏｎｅ／フィデリティ・ブルーチップ・グロース株式ファンド（成長型）、Ｏｎｅ／フィデリティ・ブルーチップ・グロース株式ファンド（隔月決算・予想分配金提示型）',
        fund_name_yomi='ワンフィデリティブルーチップグロースカブシキファンドセイチョウガタ\u3000ワンフィデリティブルーチップグロースカブシキファンドカクゲツケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15060': FundCodeEntry(
        fund_code='G15060',
        sec_code='20110',
        fund_name='ＳＭＤＡＭ\u3000Ａｃｔｉｖｅ\u3000ＥＴＦ\u3000日本高配当株式',
        fund_name_yomi='エスエムディーエーエムアクティブイーティーエフニホンコウハイトウカブシキ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15061': FundCodeEntry(
        fund_code='G15061',
        sec_code=None,
        fund_name='ＶＴＸ\u3000生涯設計プラス３０／７０（年３％目標払出型）',
        fund_name_yomi='ブイティーエックス\u3000ショウガイセッケイプラスサンジュウ\u3000ナナジュウ\u3000ネンサンパーセントモクヒョウハライダシガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E38423',
        issuer_name='バーテックス・インベストメント・ソリューションズ株式会社',
    ),
    'G15062': FundCodeEntry(
        fund_code='G15062',
        sec_code=None,
        fund_name='米国製造業株式ファンド（年４回決算型）',
        fund_name_yomi='ベイコクセイゾウギョウカブシキファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G15063': FundCodeEntry(
        fund_code='G15063',
        sec_code=None,
        fund_name='米国株式プレミアムキャリー戦略ファンド',
        fund_name_yomi='ベイコクカブシキプレミアムキャリーセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月21日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15064': FundCodeEntry(
        fund_code='G15064',
        sec_code=None,
        fund_name='マイターゲット２０７０（確定拠出年金向け）',
        fund_name_yomi='マイターゲットニセンナナジュウカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15065': FundCodeEntry(
        fund_code='G15065',
        sec_code=None,
        fund_name='いちご・レジデンス・トークンー芝公園・東新宿・都立大学・門前仲町・高井戸・新小岩－（デジタル名義書換方式）',
        fund_name_yomi='イチゴレジデンストークンシバコウエンヒガシシンジュクトリツダイガクモンゼンナカチョウタカイドシンコイワデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15066': FundCodeEntry(
        fund_code='G15066',
        sec_code=None,
        fund_name='ＲＯＢＯＰＲＯファンド',
        fund_name_yomi='ロボプロファンド',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2='12月19日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15067': FundCodeEntry(
        fund_code='G15067',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000グローバル・プレミアム株式オープン＜隔月決算型＞（為替ヘッジあり）予想分配金提示型／＜隔月決算型＞（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='モルガンスタンレーグローバルプレミアムカブシキオープンカクゲツケッサンガタカワセヘッジアリヨソウブンパイキンテイジガタカクゲツケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月23日',
        period_2='9月23日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15068': FundCodeEntry(
        fund_code='G15068',
        sec_code=None,
        fund_name='三菱ＵＦＪ／マッコーリー\u3000グローバル・インフラ債券ファンド＜為替ヘッジなし＞（隔月決算型）',
        fund_name_yomi='ミツビシユーエフジェイマッコーリーグローバルインフラサイケンファンドカワセヘッジナシカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15069': FundCodeEntry(
        fund_code='G15069',
        sec_code=None,
        fund_name='ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジあり（奇数月決算型）\u3000ＮＷＱフレキシブル・インカムファンド\u3000為替ヘッジなし（奇数月決算型）',
        fund_name_yomi='エヌダブリューキューフレキシブル\u3000インカムファンド\u3000カワセヘッジアリ\u3000キスウヅキケッサンガタ\u3000エヌダブリューキューフレキシブル\u3000インカムファンド\u3000カワセヘッジナシ\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15070': FundCodeEntry(
        fund_code='G15070',
        sec_code=None,
        fund_name='ＳＢＩ日本高配当株式（分配）ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ニホンコウハイトウカブシキ\u3000ブンパイ\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15071': FundCodeEntry(
        fund_code='G15071',
        sec_code=None,
        fund_name='楽天・日本株式バリュー・ファンド＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000ニホンカブシキバリュー\u3000ファンド\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15072': FundCodeEntry(
        fund_code='G15072',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞先進国債券ファンド（部分為替ヘッジあり）\u3000農林中金＜パートナーズ＞先進国債券ファンド（為替ヘッジなし）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000センシンコクサイケンファンド\u3000ブブンカワセヘッジアリ\u3000ノウリンチュウキン\u3000パートナーズ\u3000センシンコクサイケンファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15073': FundCodeEntry(
        fund_code='G15073',
        sec_code=None,
        fund_name='シン・インド割安成長株ファンド',
        fund_name_yomi='シンインドワリヤスセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月22日',
        period_2='12月22日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15074': FundCodeEntry(
        fund_code='G15074',
        sec_code=None,
        fund_name='ＳＭＴＡＭインド株式インデックス・オープン',
        fund_name_yomi='エスエムティーエーエムインドカブシキインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15075': FundCodeEntry(
        fund_code='G15075',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000Ｎ\u3000内外株式',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000エヌ\u3000ナイガイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G15076': FundCodeEntry(
        fund_code='G15076',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000Ｎ\u3000内外債券',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000エヌ\u3000ナイガイサイケン',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G15077': FundCodeEntry(
        fund_code='G15077',
        sec_code=None,
        fund_name='いちよしファンドラップ専用投資信託\u3000Ｎ\u3000オルタナティブ',
        fund_name_yomi='イチヨシファンドラップセンヨウトウシシンタク\u3000エヌ\u3000オルタナティブ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E30994',
        issuer_name='いちよしアセットマネジメント株式会社',
    ),
    'G15078': FundCodeEntry(
        fund_code='G15078',
        sec_code=None,
        fund_name='スタイル９（４資産分散・保守型／バランス型／積極型）（６資産分散・保守型／バランス型／積極型）（８資産分散・保守型／バランス型／積極型）',
        fund_name_yomi='スタイルナインヨンシサンブンサンホシュガタバランスガタセッキョクガタロクシサンブンサンホシュガタバランスガタセッキョクガタハチシサンブンサンホシュガタバランスガタセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15079': FundCodeEntry(
        fund_code='G15079',
        sec_code=None,
        fund_name='ジャパン半導体株式ファンド',
        fund_name_yomi='ジャパンハンドウタイカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15080': FundCodeEntry(
        fund_code='G15080',
        sec_code=None,
        fund_name='ニッセイ・Ｓ米国連続増配株式インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイエスベイコクレンゾクゾウハイカブシキインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15081': FundCodeEntry(
        fund_code='G15081',
        sec_code=None,
        fund_name='ＨＳＢＣ世界資産選抜種まきコース（安定運用型）',
        fund_name_yomi='エイチエスビーシーセカイシサンセンバツタネマキコースアンテイウンヨウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15082': FundCodeEntry(
        fund_code='G15082',
        sec_code=None,
        fund_name='ベストポート５（保守型／やや保守型／バランス型／やや積極型／積極型）',
        fund_name_yomi='ベストポートファイブホシュガタヤヤホシュガタバランスガタヤヤセッキョクガタセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15083': FundCodeEntry(
        fund_code='G15083',
        sec_code=None,
        fund_name='インデックスファンドＪリート（東証ＲＥＩＴ指数）偶数月分配型',
        fund_name_yomi='インデックスファンドジェイリート\u3000トウショウリートシスウ\u3000グウスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15084': FundCodeEntry(
        fund_code='G15084',
        sec_code=None,
        fund_name='楽天・プラス・日経２２５インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000ニッケイニイニイゴインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15085': FundCodeEntry(
        fund_code='G15085',
        sec_code=None,
        fund_name='楽天・プラス・先進国株式（除く日本）インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000センシンコクカブシキ\u3000ノゾクニホン\u3000インデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15086': FundCodeEntry(
        fund_code='G15086',
        sec_code=None,
        fund_name='三井物産のデジタル証券～日本橋～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンニホンバシジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15087': FundCodeEntry(
        fund_code='G15087',
        sec_code=None,
        fund_name='ハリス日本株ファンド（資産成長型）',
        fund_name_yomi='ハリスニホンカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G15088': FundCodeEntry(
        fund_code='G15088',
        sec_code=None,
        fund_name='ハリス日本株ファンド（年４回決算型）',
        fund_name_yomi='ハリスニホンカブファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G15089': FundCodeEntry(
        fund_code='G15089',
        sec_code=None,
        fund_name='ＤＣターゲット・イヤーファンド（ライフステージ対応型）',
        fund_name_yomi='ディーシーターゲット\u3000イヤーファンド\u3000ライフステージタイオウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15090': FundCodeEntry(
        fund_code='G15090',
        sec_code=None,
        fund_name='フィデリティ・日本割安成長株投信',
        fund_name_yomi='フィデリティニホンワリヤスセイチョウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G15091': FundCodeEntry(
        fund_code='G15091',
        sec_code=None,
        fund_name='たわらノーロード\u3000Ｓ＆Ｐ５００配当貴族',
        fund_name_yomi='タワラノーロードエスアンドピーゴヒャクハイトウキゾク',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15092': FundCodeEntry(
        fund_code='G15092',
        sec_code=None,
        fund_name='たわらノーロード\u3000ＮＡＳＤＡＱ１００',
        fund_name_yomi='タワラノーロード\u3000ナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15093': FundCodeEntry(
        fund_code='G15093',
        sec_code=None,
        fund_name='野村ホールディングス社債／システマティック・グローバル・マクロ戦略ファンド２４０１',
        fund_name_yomi='ノムラホールディングスシャサイ\u3000システマティックグローバルマクロセンリャクファンド\u3000ニヨンゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='1月29日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15094': FundCodeEntry(
        fund_code='G15094',
        sec_code='20130',
        fund_name='ｉシェアーズ\u3000米国高配当株\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクコウハイトウカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15095': FundCodeEntry(
        fund_code='G15095',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２４－０１',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイヨンノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15096': FundCodeEntry(
        fund_code='G15096',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド（当初漸増期間付、限定追加型）２０２４－０１',
        fund_name_yomi='アオゾラシングローバルプレミアムファンドトウショゼンゾウキカンツキゲンテイツイカガタニイゼロニイヨンノゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15097': FundCodeEntry(
        fund_code='G15097',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド',
        fund_name_yomi='アオゾラシングローバルプレミアムファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15098': FundCodeEntry(
        fund_code='G15098',
        sec_code=None,
        fund_name='三井住友ＤＳインカムバランスＮＩＳＡファンド（成長投資型）',
        fund_name_yomi='ミツイスミトモディーエスインカムバランスニーサファンドセイチョウトウシガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15099': FundCodeEntry(
        fund_code='G15099',
        sec_code=None,
        fund_name='三井住友ＤＳインカムバランスＮＩＳＡファンド（予想分配金提示型）',
        fund_name_yomi='ミツイスミトモディーエスインカムバランスニーサファンドヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15100': FundCodeEntry(
        fund_code='G15100',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２４－０１（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニヨンゼロイチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15101': FundCodeEntry(
        fund_code='G15101',
        sec_code='20140',
        fund_name='ｉシェアーズ\u3000米国連続増配株\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクレンゾクゾウハイカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15102': FundCodeEntry(
        fund_code='G15102',
        sec_code='20120',
        fund_name='ｉシェアーズ\u3000米国債０－３ヶ月\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイゼロサンカゲツ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15103': FundCodeEntry(
        fund_code='G15103',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国高配当株式インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ヴィ\u3000ベイコクコウハイトウカブシキインデックス\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15104': FundCodeEntry(
        fund_code='G15104',
        sec_code=None,
        fund_name='ＳＢＩ・ＳＰＤＲ・Ｓ＆Ｐ５００高配当株式インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000エスピーディーアール\u3000\u3000エスアンドピーゴヒャクコウハイトウカブシキインデックス\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15105': FundCodeEntry(
        fund_code='G15105',
        sec_code=None,
        fund_name='ＵＳベーシックバランス',
        fund_name_yomi='ユーエスベーシックバランス',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G15106': FundCodeEntry(
        fund_code='G15106',
        sec_code=None,
        fund_name='半導体関連\u3000日本株式戦略ファンド',
        fund_name_yomi='ハンドウタイカンレン\u3000ニホンカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15107': FundCodeEntry(
        fund_code='G15107',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット２０２４－０３（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウヨン\u3000ゼロサン\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15108': FundCodeEntry(
        fund_code='G15108',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット追加型２０２４－０３',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ツイカガタ\u3000ニセンニジュウヨン\u3000ゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15110': FundCodeEntry(
        fund_code='G15110',
        sec_code=None,
        fund_name='岐阜・愛知地域応援ファンド',
        fund_name_yomi='ギフアイチチイキオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='12月12日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15111': FundCodeEntry(
        fund_code='G15111',
        sec_code=None,
        fund_name='ステート・ストリートＴＯＰＩＸインデックス・オープン',
        fund_name_yomi='ステートストリートトピックスインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15112': FundCodeEntry(
        fund_code='G15112',
        sec_code=None,
        fund_name='ステート・ストリート・グローバル株式インデックス・オープン',
        fund_name_yomi='ステートストリートグローバルカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15113': FundCodeEntry(
        fund_code='G15113',
        sec_code=None,
        fund_name='ステート・ストリート全世界株式インデックス・オープン',
        fund_name_yomi='ステートストリートゼンセカイカブシキインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月末日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15114': FundCodeEntry(
        fund_code='G15114',
        sec_code=None,
        fund_name='ステート・ストリートＳ＆Ｐ５００インデックス・オープン',
        fund_name_yomi='ステートストリートエスアンドピーゴヒャクインデックスオープン',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15115': FundCodeEntry(
        fund_code='G15115',
        sec_code=None,
        fund_name='ステート・ストリート国内債券インデックス・オープン（隔月分配型）',
        fund_name_yomi='ステートストリートコクナイサイケンインデックスオープンカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15116': FundCodeEntry(
        fund_code='G15116',
        sec_code=None,
        fund_name='ステート・ストリート・グローバル債券インデックス・オープン（隔月分配型）',
        fund_name_yomi='ステートストリートグローバルサイケンインデックスオープンカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15117': FundCodeEntry(
        fund_code='G15117',
        sec_code=None,
        fund_name='ステート・ストリート米国投資適格社債インデックス・オープン（隔月分配型）',
        fund_name_yomi='ステートストリートベイコクトウシテキカクシャサイインデックスオープンカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15118': FundCodeEntry(
        fund_code='G15118',
        sec_code=None,
        fund_name='楽天・資産アロケーション・ファンド（標準型）／楽天・資産アロケーション・ファンド（成長型）／楽天・資産アロケーション・ファンド（積極成長型）',
        fund_name_yomi='ラクテン\u3000シサンアロケーション\u3000ファンド\u3000ヒョウジュンガタ\u3000\u3000ラクテン\u3000シサンアロケーション\u3000ファンド\u3000セイチョウガタ\u3000\u3000ラクテン\u3000シサンアロケーション\u3000ファンド\u3000セッキョクセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15119': FundCodeEntry(
        fund_code='G15119',
        sec_code=None,
        fund_name='パインブリッジ割安優良債券ファンド（奇数月決算型）（資産成長型）',
        fund_name_yomi='パインブリッジワリヤスユウリョウサイケンファンドキスウヅキケッサンガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G15120': FundCodeEntry(
        fund_code='G15120',
        sec_code=None,
        fund_name='ルーミス米国投資適格債券ファンド［年２回決算型］',
        fund_name_yomi='ルーミスベイコクトウシテキカクサイケンファンドネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15121': FundCodeEntry(
        fund_code='G15121',
        sec_code='20150',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米国国債７－１０年（為替ヘッジなし）',
        fund_name_yomi='アイフリーイーティーエフベイコクコクサイナナジュウネンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15122': FundCodeEntry(
        fund_code='G15122',
        sec_code='20160',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米国国債７－１０年（為替ヘッジあり）',
        fund_name_yomi='アイフリーイーティーエフベイコクコクサイナナジュウネンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15123': FundCodeEntry(
        fund_code='G15123',
        sec_code='20170',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＪＰＸプライム１５０',
        fund_name_yomi='アイフリーイーティーエフジェイピーエックスプライムヒャクゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15124': FundCodeEntry(
        fund_code='G15124',
        sec_code=None,
        fund_name='ＤＲＥＡＭ・リアルティ・トークン－Ｒｅｓｉｄｅｎｃｅ１－（デジタル名義書換方式）',
        fund_name_yomi='ドリームリアルティトークンレジデンスワンデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15125': FundCodeEntry(
        fund_code='G15125',
        sec_code='20180',
        fund_name='グローバルＸ\u3000ＵＳ\u3000ＲＥＩＴ・トップ２０\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスユーエスリートトップニジュウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月24日',
        period_2='12月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15127': FundCodeEntry(
        fund_code='G15127',
        sec_code='133A0',
        fund_name='グローバルＸ\u3000超短期米国債\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチョウタンキベイコクサイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15128': FundCodeEntry(
        fund_code='G15128',
        sec_code=None,
        fund_name='イノベーション・インサイト\u3000世界株式戦略ファンド（予想分配金提示型・奇数月決算型）',
        fund_name_yomi='イノベーション\u3000インサイト\u3000セカイカブシキセンリャクファンド\u3000ヨソウブンパイキンテイジガタ\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15129': FundCodeEntry(
        fund_code='G15129',
        sec_code=None,
        fund_name='ブランディワイン米国債券戦略ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ブランディワインベイコクサイケンセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月28日',
        period_2='7月28日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15130': FundCodeEntry(
        fund_code='G15130',
        sec_code=None,
        fund_name='インデックスファンド日経平均高配当株５０（奇数月分配型）',
        fund_name_yomi='インデックスファンドニッケイヘイキンコウハイトウカブゴジュウ\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15131': FundCodeEntry(
        fund_code='G15131',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000日経平均高配当株５０インデックス（奇数月分配型）',
        fund_name_yomi='トレイサーズ\u3000ニッケイヘイキンコウハイトウカブゴジュウインデックス\u3000キスウヅキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2='11月30日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15132': FundCodeEntry(
        fund_code='G15132',
        sec_code='20190',
        fund_name='グローバルＸ\u3000米国優先証券\u3000ＥＴＦ（隔月分配型）',
        fund_name_yomi='グローバルエックスベイコクユウセンショウケンイーティーエフカクゲツブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15133': FundCodeEntry(
        fund_code='G15133',
        sec_code=None,
        fund_name='楽天・モーニングスター・ワイド・モート・フォーカス・インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000モーニングスター\u3000ワイド\u3000モート\u3000フォーカス\u3000インデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15134': FundCodeEntry(
        fund_code='G15134',
        sec_code=None,
        fund_name='楽天・プラス・ＮＡＳＤＡＱ－１００インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000ナスダック\u3000ヒャクインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15135': FundCodeEntry(
        fund_code='G15135',
        sec_code=None,
        fund_name='楽天・プラス・ＳＯＸインデックス・ファンド',
        fund_name_yomi='ラクテン\u3000プラス\u3000ソックスインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15136': FundCodeEntry(
        fund_code='G15136',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２４－０３',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイヨンゼロサン',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15137': FundCodeEntry(
        fund_code='G15137',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国増配株式インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ベイコクゾウハイカブシキ\u3000インデックスファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15141': FundCodeEntry(
        fund_code='G15141',
        sec_code=None,
        fund_name='不動産のデジタル証券～那須・アウトレットモール～（譲渡制限付）',
        fund_name_yomi='フドウサンノデジタルショウケンナスアウトレットモールジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G15142': FundCodeEntry(
        fund_code='G15142',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000ＪＰＸプライム１５０',
        fund_name_yomi='アイフリージェイピーエックスプライムヒャクゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15144': FundCodeEntry(
        fund_code='G15144',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ブラックストーン・プライベート・エクイティ・ストラテジーズ・ファンド',
        fund_name_yomi='ノムラファンドセレクトブラックストーンプライベートエクイティストラテジーズファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G15145': FundCodeEntry(
        fund_code='G15145',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国投資適格社債（１－５年）インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクトウシテキカクシャサイ\u3000イチカラゴネン\u3000インデックスファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15146': FundCodeEntry(
        fund_code='G15146',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国総合債券インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクソウゴウサイケン\u3000インデックスファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15147': FundCodeEntry(
        fund_code='G15147',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・米国ハイイールド債券インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ベイコクハイイールドサイケン\u3000インデックスファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15148': FundCodeEntry(
        fund_code='G15148',
        sec_code=None,
        fund_name='航空宇宙戦略グローバルファンド',
        fund_name_yomi='コウクウウチュウセンリャクグローバルファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G15149': FundCodeEntry(
        fund_code='G15149',
        sec_code=None,
        fund_name='東京海上・先進国好利回りＣＢファンド２０２４ー０３',
        fund_name_yomi='トウキョウカイジョウセンシンコクコウリマワリシービーファンド',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G15152': FundCodeEntry(
        fund_code='G15152',
        sec_code=None,
        fund_name='ＳＢＩ欧州高配当株式（分配）ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000オウシュウコウハイトウカブシキ\u3000ブンパイ\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15153': FundCodeEntry(
        fund_code='G15153',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・米国成長株投信Ａコース（野村ＳＭＡ・ＥＷ向け）／Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='アライアンスバーンスタインベイコクセイチョウカブトウシンエーコースノムラエスエムエーイーダブリュームケ\u3000ビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G15154': FundCodeEntry(
        fund_code='G15154',
        sec_code=None,
        fund_name='りそな先進国株式インデックス',
        fund_name_yomi='リソナセンシンコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15155': FundCodeEntry(
        fund_code='G15155',
        sec_code=None,
        fund_name='りそなＴＯＰＩＸインデックス',
        fund_name_yomi='リソナトピックスインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15156': FundCodeEntry(
        fund_code='G15156',
        sec_code=None,
        fund_name='りそな新興国株式インデックス',
        fund_name_yomi='リソナシンコウコクカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15157': FundCodeEntry(
        fund_code='G15157',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２４－０３（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニヨンゼロサンカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15158': FundCodeEntry(
        fund_code='G15158',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークングランドニッコー東京ベイ舞浜－２（デジタル名義書換方式）',
        fund_name_yomi='ケネディクスリアルティトークングランドニッコートウキョウベイマイハマツーデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15159': FundCodeEntry(
        fund_code='G15159',
        sec_code=None,
        fund_name='明治安田ＮＢグローバル好利回り社債ファンド２０２４－０３（限定追加型）',
        fund_name_yomi='メイジヤスダニューバーガーバーマングローバルコウリマワリシャサイファンドニセンニジュウヨンノサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月11日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15160': FundCodeEntry(
        fund_code='G15160',
        sec_code=None,
        fund_name='野村日本国債部分ラダーファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラニホンコクサイブブンラダーファンドノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15161': FundCodeEntry(
        fund_code='G15161',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークンＫＤＸ名古屋栄ビル（デジタル名義書換方式）',
        fund_name_yomi='ケネディクスリアルティトークンケイディーエックスナゴヤサカエビルデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15162': FundCodeEntry(
        fund_code='G15162',
        sec_code=None,
        fund_name='日興ワールド・トラスト－ブルックフィールド不動産インカム・トラスト・ファンド',
        fund_name_yomi='ニッコウワールドトラストブルックフィールドフドウサンインカムトラストファンド',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G15163': FundCodeEntry(
        fund_code='G15163',
        sec_code=None,
        fund_name='ひふみマイクロスコープｐｒｏ',
        fund_name_yomi='ヒフミマイクロスコーププロ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G15164': FundCodeEntry(
        fund_code='G15164',
        sec_code=None,
        fund_name='インド小型厳選株式ファンド',
        fund_name_yomi='インドコガタゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15165': FundCodeEntry(
        fund_code='G15165',
        sec_code=None,
        fund_name='日本好配当リバランスオープンⅡ',
        fund_name_yomi='ニホンコウハイトウリバランスオープンツー',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15166': FundCodeEntry(
        fund_code='G15166',
        sec_code=None,
        fund_name='米国株式これ１本（Ｓ＆Ｐ５００・ＮＹダウ・ナスダック１００）',
        fund_name_yomi='ベイコクカブシキコレイッポンエスアンドピーゴヒャクニューヨークダウナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='3月3日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15167': FundCodeEntry(
        fund_code='G15167',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000インド株式インデックス',
        fund_name_yomi='イーマクシスインドカブシキインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15168': FundCodeEntry(
        fund_code='G15168',
        sec_code='170A0',
        fund_name='ＳＭＴ\u3000ＥＴＦ日本好配当株アクティブ',
        fund_name_yomi='エスエムティー\u3000イーティーエフニホンコウハイトウカブアクティブ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15169': FundCodeEntry(
        fund_code='G15169',
        sec_code=None,
        fund_name='インベスコ\u3000米国株式ダイナミック・マルチファクター・ファンド',
        fund_name_yomi='インベスコベイコクカブシキダイナミックマルチファクターファンド',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15170': FundCodeEntry(
        fund_code='G15170',
        sec_code=None,
        fund_name='みずほグローバル・セレクト・不動産戦略ファンド（年１回決算型）（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ミズホグローバルセレクトフドウサンセンリャクファンドネンイッカイケッサンガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15171': FundCodeEntry(
        fund_code='G15171',
        sec_code=None,
        fund_name='みずほグローバル・セレクト・不動産戦略ファンド（年４回決算型）（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ミズホグローバルセレクトフドウサンセンリャクファンドネンヨンカイケッサンガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15173': FundCodeEntry(
        fund_code='G15173',
        sec_code='140A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米国１０年国債先物インバース',
        fund_name_yomi='アイフリーイーティーエフベイコクジュウネンコクサイサキモノインバース',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15174': FundCodeEntry(
        fund_code='G15174',
        sec_code=None,
        fund_name='ホテルトークン\u3000悠洛・京都三条（譲渡制限付）',
        fund_name_yomi='ホテルトークン\u3000ユラキョウトサンジョウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E03538',
        issuer_name='株式会社りそな銀行',
    ),
    'G15175': FundCodeEntry(
        fund_code='G15175',
        sec_code=None,
        fund_name='野村ハイパーブル・ベア１０',
        fund_name_yomi='ノムラハイパーブルベアテン',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15176': FundCodeEntry(
        fund_code='G15176',
        sec_code=None,
        fund_name='三井物産のデジタル証券～浅草～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンアサクサジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月31日',
        period_2='9月30日',
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G15177': FundCodeEntry(
        fund_code='G15177',
        sec_code=None,
        fund_name='インド株インデックス',
        fund_name_yomi='インドカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15179': FundCodeEntry(
        fund_code='G15179',
        sec_code='159A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＪＰＸプライム１５０指数連動型上場投信',
        fund_name_yomi='ネクストファンズジェイピーエックスプライムヒャクゴジュウシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15180': FundCodeEntry(
        fund_code='G15180',
        sec_code=None,
        fund_name='一歩先いく\u3000ＵＳ\u3000テック・トップ２０インデックス',
        fund_name_yomi='イッポサキイクユーエステックトップニジュウインデックス',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15181': FundCodeEntry(
        fund_code='G15181',
        sec_code=None,
        fund_name='ａｕＡＭ\u3000Ｑｕａｎｔｉｔａｔｉｖｅ－ＣｏｎｔｒｏｌレバレッジＮＡＳＤＡＱ１００',
        fund_name_yomi='エーユーエーエム\u3000クォンティティヴーコントロールレバレッジナスダックヒャク',
        security_type='内国投資信託受益証券',
        period_1='2月22日',
        period_2='8月22日',
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15182': FundCodeEntry(
        fund_code='G15182',
        sec_code=None,
        fund_name='米国大型テクノロジー株式ファンド',
        fund_name_yomi='ベイコクオオガタテクノロジーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15184': FundCodeEntry(
        fund_code='G15184',
        sec_code=None,
        fund_name='米ドル建てグリーンファイナンスセキュリティトークン（２０２４年第１号）',
        fund_name_yomi='ベイドルダテグリーンファイナンスセキュリティトークンニセンニジュウヨネンダイイチゴウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='6月3日',
        period_2=None,
        edinet_code='E03627',
        issuer_name='三井住友信託銀行株式会社',
    ),
    'G15185': FundCodeEntry(
        fund_code='G15185',
        sec_code=None,
        fund_name='フィデリティ・新興国中小型成長株投信',
        fund_name_yomi='フィデリティシンコウコクチュウコガタセイチョウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G15186': FundCodeEntry(
        fund_code='G15186',
        sec_code=None,
        fund_name='一歩先いく\u3000ＮＡＳＤＡＱ－１００\u3000毎月カバコ戦略（ＱＹＬＤ）',
        fund_name_yomi='イッポサキイクナスダックヒャクマイツキカバコセンリャクキューワイエルディ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15187': FundCodeEntry(
        fund_code='G15187',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２４－０４',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイヨンノゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15188': FundCodeEntry(
        fund_code='G15188',
        sec_code=None,
        fund_name='楽天・インド株Ｎｉｆｔｙ５０インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000インドカブニフティゴジュウインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15189': FundCodeEntry(
        fund_code='G15189',
        sec_code=None,
        fund_name='ｉＦｒｅｅＨＯＬＤ\u3000米国国債（Ｔ－Ｚｅｒｏ２０４４）',
        fund_name_yomi='アイフリーホールドベイコクコクサイティーゼロニゼロヨンヨン',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15190': FundCodeEntry(
        fund_code='G15190',
        sec_code=None,
        fund_name='サイバーセキュリティ株式オープン＜隔月決算型＞（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='サイバーセキュリティカブシキオープンカクゲツケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月6日',
        period_2='7月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15191': FundCodeEntry(
        fund_code='G15191',
        sec_code=None,
        fund_name='バークレイズ社債／インカム戦略ファンド２０２４－０４',
        fund_name_yomi='バークレイズシャサイインカムセンリャクファンドニゼロニヨンゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15192': FundCodeEntry(
        fund_code='G15192',
        sec_code=None,
        fund_name='ノーザン・トラスト・ユニット・トラスト\u3000ノーザン・トラスト・米ドル・リクイディティ・ファンド',
        fund_name_yomi='ノーザントラストユニットトラストノーザントラストベイドルリクイディティファンド',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G15193': FundCodeEntry(
        fund_code='G15193',
        sec_code=None,
        fund_name='アルジェブリスＵＣＩＴＳファンズｐｌｃ－アルジェブリス・ファイナンシャル・クレジット・ファンド－クラスＷユーロ投資証券およびクラスＷｄユーロ投資証券',
        fund_name_yomi='アルジェブリスユーシッツファンズピーエルシーアルジェブリスファイナンシャルクレジットファンドクラスダブリューユーロトウシショウケンオヨビクラスダブリューディーユーロトウシショウケン',
        security_type='外国投資証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E35752',
        issuer_name='アルジェブリスＵＣＩＴＳファンズ\u3000ｐｌｃ',
    ),
    'G15195': FundCodeEntry(
        fund_code='G15195',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－東海東京\u3000ヌビーン\u3000チャーチル\u3000プライベート・キャピタル\u3000ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリートウカイトウキョウヌビーンチャーチルプライベートキャピタルファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G15196': FundCodeEntry(
        fund_code='G15196',
        sec_code=None,
        fund_name='日本株厳選バリュー投資',
        fund_name_yomi='ニホンカブゲンセンバリュートウシ',
        security_type='内国投資信託受益証券',
        period_1='4月3日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15197': FundCodeEntry(
        fund_code='G15197',
        sec_code='178A0',
        fund_name='グローバルＸ\u3000革新的優良企業\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスカクシンテキユウリョウキギョウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15198': FundCodeEntry(
        fund_code='G15198',
        sec_code='179A0',
        fund_name='グローバルＸ\u3000超長期米国債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='グローバルエックスチョウチョウキベイコクサイイーティーエフカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15199': FundCodeEntry(
        fund_code='G15199',
        sec_code='180A0',
        fund_name='グローバルＸ\u3000超長期米国債\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチョウチョウキベイコクサイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15200': FundCodeEntry(
        fund_code='G15200',
        sec_code=None,
        fund_name='三井物産のデジタル証券～浅草・まちなか旅館～（譲渡制限付）',
        fund_name_yomi='ミツイブッサンノデジタルショウケンアサクサマチナカリョカンジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15201': FundCodeEntry(
        fund_code='G15201',
        sec_code=None,
        fund_name='みずほサステナブルファンドシリーズ\u3000－\u3000ＬＯ・サーキュラー・エコノミー',
        fund_name_yomi='ミズホサステナブルファンドシリーズ\u3000エルオーサーキュラーエコノミー',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15202': FundCodeEntry(
        fund_code='G15202',
        sec_code=None,
        fund_name='ｉＦｒｅｅＷａｌｌｅｔ\u3000米ドル（ＵＳＤ）',
        fund_name_yomi='アイフリーウォレットベイドルユーエスディー',
        security_type='内国投資信託受益証券',
        period_1='10月11日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15203': FundCodeEntry(
        fund_code='G15203',
        sec_code=None,
        fund_name='ニッセイゴールドファンド（為替ヘッジあり）＜購入・換金手数料なし＞／ニッセイゴールドファンド（為替ヘッジなし）＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイゴールドファンドカワセヘッジアリコウニュウカンキンテスウリョウナシ\u3000ニッセイゴールドファンドカワセヘッジナシコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15204': FundCodeEntry(
        fund_code='G15204',
        sec_code=None,
        fund_name='ＤＣニッセイターゲットデートファンド２０７０',
        fund_name_yomi='ディーシーニッセイターゲットデートファンドニゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15205': FundCodeEntry(
        fund_code='G15205',
        sec_code=None,
        fund_name='ＦＷニッセイ国内期待インフレターゲットファンド',
        fund_name_yomi='エフダブリューニッセイコクナイキタイインフレターゲットファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15206': FundCodeEntry(
        fund_code='G15206',
        sec_code=None,
        fund_name='ウェルスナビ×Ｒ（リスク許容度１）／ウェルスナビ×Ｒ（リスク許容度２）／ウェルスナビ×Ｒ（リスク許容度３）／ウェルスナビ×Ｒ（リスク許容度４）／ウェルスナビ×Ｒ（リスク許容度５）',
        fund_name_yomi='ウェルスナビ\u3000アール\u3000リスクキョヨウドイチ\u3000\u3000ウェルスナビ\u3000アール\u3000リスクキョヨウドニ\u3000\u3000ウェルスナビ\u3000アール\u3000リスクキョヨウドサン\u3000\u3000ウェルスナビ\u3000アール\u3000リスクキョヨウドヨン\u3000\u3000ウェルスナビ\u3000アール\u3000リスクキョヨウドゴ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15207': FundCodeEntry(
        fund_code='G15207',
        sec_code=None,
        fund_name='三井住友ＤＳ\u3000ワールド・ボンド・フォーカス２０２４－０５（限定追加型）',
        fund_name_yomi='ミツイスミトモディーエスワールドボンドフォーカスニイゼロニイヨンゼロゴゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15208': FundCodeEntry(
        fund_code='G15208',
        sec_code=None,
        fund_name='なかの世界成長ファンド',
        fund_name_yomi='ナカノセカイセイチョウファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E39468',
        issuer_name='なかのアセットマネジメント株式会社',
    ),
    'G15209': FundCodeEntry(
        fund_code='G15209',
        sec_code=None,
        fund_name='なかの日本成長ファンド',
        fund_name_yomi='ナカノニホンセイチョウファンド',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2=None,
        edinet_code='E39468',
        issuer_name='なかのアセットマネジメント株式会社',
    ),
    'G15210': FundCodeEntry(
        fund_code='G15210',
        sec_code=None,
        fund_name='ＳＢＩ・Ｊ－ＲＥＩＴ（分配）ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ジェイリート\u3000ブンパイ\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15211': FundCodeEntry(
        fund_code='G15211',
        sec_code=None,
        fund_name='トーセイ・プロパティ・ファンド（シリーズ３）市ヶ谷（デジタル名義書換方式）',
        fund_name_yomi='トーセイプロパティファンドシリーズスリーイチガヤデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15212': FundCodeEntry(
        fund_code='G15212',
        sec_code=None,
        fund_name='ＧＲＡＮ\u3000ＮＥＸＴ\u3000フィナンシャルズ',
        fund_name_yomi='グランネクストフィナンシャルズ',
        security_type='内国投資信託受益証券',
        period_1='1月19日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15213': FundCodeEntry(
        fund_code='G15213',
        sec_code='182A0',
        fund_name='ＭＡＸＩＳ米国国債２０年超上場投信（為替ヘッジなし）',
        fund_name_yomi='マクシスベイコクコクサイニジュウネンチョウジョウジョウトウシンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15214': FundCodeEntry(
        fund_code='G15214',
        sec_code='183A0',
        fund_name='ＭＡＸＩＳ米国国債２０年超上場投信（為替ヘッジあり）',
        fund_name_yomi='マクシスベイコクコクサイニジュウネンチョウジョウジョウトウシンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15215': FundCodeEntry(
        fund_code='G15215',
        sec_code='181A0',
        fund_name='ＭＡＸＩＳ米国国債１－３年上場投信（為替ヘッジなし）',
        fund_name_yomi='マクシスベイコクコクサイイチカラサンネンジョウジョウトウシンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15216': FundCodeEntry(
        fund_code='G15216',
        sec_code=None,
        fund_name='スマート・コントロール\u3000世界株式戦略ファンド',
        fund_name_yomi='スマート\u3000コントロール\u3000セカイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15217': FundCodeEntry(
        fund_code='G15217',
        sec_code=None,
        fund_name='いちご・レジデンス・トークン－西麻布・代々木・八丁堀・上野・門前仲町・阿佐ヶ谷・金町－（デジタル名義書換方式）',
        fund_name_yomi='イチゴレジデンストークンニシアザブヨヨギハッチョウボリウエノモンゼンナカチョウアサガヤカナマチデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15218': FundCodeEntry(
        fund_code='G15218',
        sec_code=None,
        fund_name='ＤＣマイセレクションＳ５０（２０２４－２０２６リスク抑制型）',
        fund_name_yomi='ディーシーマイセレクションエスゴジュウ\u3000ニセンニジュウヨン\u3000ニセンニジュウロクリスクヨクセイガタ',
        security_type='内国投資信託受益証券',
        period_1='9月30日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15219': FundCodeEntry(
        fund_code='G15219',
        sec_code=None,
        fund_name='ゴールドマン・サックス（ケイマン諸島）ユニット・トラスト－ＧＳ米ドル建てコーポレート・ターゲット・ボンド・サブ・トラスト２０２４－０５',
        fund_name_yomi='ゴールドマンサックスケイマンショトウユニットトラストジーエスベイドルダテコーポレートターゲットボンドサブトラストニセンニジュウヨンゼロゴ',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E24426',
        issuer_name='シーエス（ケイマン）リミテッド',
    ),
    'G15220': FundCodeEntry(
        fund_code='G15220',
        sec_code=None,
        fund_name='東洋・インドネシア株式ファンド',
        fund_name_yomi='トウヨウインドネシアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15221': FundCodeEntry(
        fund_code='G15221',
        sec_code=None,
        fund_name='ピクテ・ディバーシファイド・リスクプレミアム戦略ファンド',
        fund_name_yomi='ピクテディバーシファイドリスクプレミアムセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G15222': FundCodeEntry(
        fund_code='G15222',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000Ｓ＆Ｐ５００トップ１０インデックス（米国株式）',
        fund_name_yomi='トレイサーズ\u3000エスアンドピーゴヒャクトップテンインデックス\u3000ベイコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15223': FundCodeEntry(
        fund_code='G15223',
        sec_code=None,
        fund_name='ＭＵＦＧ\u3000ウェルス・インサイト・ファンド・アネックス（為替リスク軽減型）コンサバティブコース／スタンダードコース',
        fund_name_yomi='エムユーエフジーウェルスインサイトファンドアネックスカワセリスクケイゲンガタコンサバティブコーススタンダードコース',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15224': FundCodeEntry(
        fund_code='G15224',
        sec_code=None,
        fund_name='全世界超分散株式ファンド',
        fund_name_yomi='ゼンセカイチョウブンサンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15225': FundCodeEntry(
        fund_code='G15225',
        sec_code=None,
        fund_name='ジャナス・ヘンダーソン・バランス・ファンド（為替ヘッジなし・あり／資産成長型）（為替ヘッジなし・あり／年４回決算型）',
        fund_name_yomi='ジャナスヘンダーソンバランスファンドカワセヘッジナシアリシサンセイチョウガタカワセヘッジナシアリネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15226': FundCodeEntry(
        fund_code='G15226',
        sec_code=None,
        fund_name='ａｕＡＭレバレッジＮｉｆｔｙ５０インド株ファンド',
        fund_name_yomi='エーユーエーエムレバレッジニフティゴジュウインドカブファンド',
        security_type='内国投資信託受益証券',
        period_1='5月30日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15227': FundCodeEntry(
        fund_code='G15227',
        sec_code='188A0',
        fund_name='グローバルＸ\u3000インド・トップ１０＋\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスインドトップテンプラスイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15228': FundCodeEntry(
        fund_code='G15228',
        sec_code=None,
        fund_name='インベスコ\u3000Ｓ＆Ｐ\u3000５００イコール・ウェイト・ファンド',
        fund_name_yomi='インベスコエスアンドピーゴヒャクイコールウェイトファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15229': FundCodeEntry(
        fund_code='G15229',
        sec_code=None,
        fund_name='ＳＢＩ岡三\u3000ＮＡＳＤＡＱ\u3000ＡＩアクティブファンド',
        fund_name_yomi='エスビーアイオカサンナスダックエーアイアクティブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15230': FundCodeEntry(
        fund_code='G15230',
        sec_code=None,
        fund_name='オルトゥ・クールバ・トラストⅡ－グローバル株式セクター厳選ファンド',
        fund_name_yomi='オルトゥクールバトラストツーグローバルカブシキセクターゲンセンファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E38530',
        issuer_name='ＩＱ\u3000ＥＱファンド・マネジメント（アイルランド）リミテッド',
    ),
    'G15231': FundCodeEntry(
        fund_code='G15231',
        sec_code='201A0',
        fund_name='ｉシェアーズ\u3000Ｎｉｆｔｙ\u3000５０\u3000インド株\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ニフティゴジュウインドカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15233': FundCodeEntry(
        fund_code='G15233',
        sec_code='200A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000日経半導体株指数連動型上場投信',
        fund_name_yomi='ネクストファンズニッケイハンドウタイカブシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15234': FundCodeEntry(
        fund_code='G15234',
        sec_code=None,
        fund_name='バークレイズ社債／ダウンサイド・プロテクト型世界株式戦略ファンド（早期償還条項付）２０２４－０６',
        fund_name_yomi='バークレイズシャサイダウンサイドプロテクトガタセカイカブシキセンリャクファンドソウキショウカンジョウコウツキニゼロニヨンゼロロク',
        security_type='内国投資信託受益証券',
        period_1='8月3日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15235': FundCodeEntry(
        fund_code='G15235',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ストラテジー・ファンド－バランス（米ドル）',
        fund_name_yomi='ユービーエスルクスストラテジーファンドバランスベイドル',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G15236': FundCodeEntry(
        fund_code='G15236',
        sec_code=None,
        fund_name='いちよし・グローバル好配当戦略ファンド（年６回決算型）',
        fund_name_yomi='イチヨシグローバルコウハイトウセンリャクファンドネンロッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G15237': FundCodeEntry(
        fund_code='G15237',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２４－０７',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイヨンゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15238': FundCodeEntry(
        fund_code='G15238',
        sec_code=None,
        fund_name='ＵＢＳグローバル株式ロング・ショート・ファンド',
        fund_name_yomi='ユービーエスグローバルカブシキロング\u3000ショート\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='6月5日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G15239': FundCodeEntry(
        fund_code='G15239',
        sec_code=None,
        fund_name='ＢＮＹ米国エクセレント・バリュー・ファンド',
        fund_name_yomi='ビーエヌワイベイコクエクセレントバリューファンド',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G15240': FundCodeEntry(
        fund_code='G15240',
        sec_code=None,
        fund_name='ＳＭＴ\u3000グローバルサウス株式インデックス・オープン',
        fund_name_yomi='エスエムティー\u3000グローバルサウスカブシキインデックス\u3000オープン',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15241': FundCodeEntry(
        fund_code='G15241',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン－アメリカン・インカム・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインアメリカンインカムポートフォリオ',
        security_type='外国投資信託受益証券',
        period_1='8月末日',
        period_2=None,
        edinet_code='E14866',
        issuer_name='アライアンス・バーンスタイン・ルクセンブルグ・エス・エイ・アール・エル',
    ),
    'G15242': FundCodeEntry(
        fund_code='G15242',
        sec_code=None,
        fund_name='住友生命第４回劣後ローン流動化株式会社',
        fund_name_yomi='スミトモセイメイダイヨンカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E39749',
        issuer_name='住友生命第４回劣後ローン流動化株式会社',
    ),
    'G15243': FundCodeEntry(
        fund_code='G15243',
        sec_code=None,
        fund_name='２０５０年満期米国国債ファンド（年４回分配型）',
        fund_name_yomi='ニセンゴジュウネンマンキベイコクコクサイファンド\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15244': FundCodeEntry(
        fund_code='G15244',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000Ｋｏｌｅｔ－１（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンコレットワンジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E30037',
        issuer_name='株式会社ＳＭＢＣ信託銀行',
    ),
    'G15245': FundCodeEntry(
        fund_code='G15245',
        sec_code='210A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日経高利回りＲＥＩＴ指数',
        fund_name_yomi='アイフリーイーティーエフニッケイコウリマワリリートシスウ',
        security_type='内国投資信託受益証券',
        period_1='6月4日',
        period_2='12月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15246': FundCodeEntry(
        fund_code='G15246',
        sec_code=None,
        fund_name='野村全世界株式インデックスファンド（確定拠出年金向け）',
        fund_name_yomi='ノムラゼンセカイカブシキインデックスファンドカクテイキョシュツネンキンムケ',
        security_type='内国投資信託受益証券',
        period_1='6月3日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15247': FundCodeEntry(
        fund_code='G15247',
        sec_code=None,
        fund_name='ドラッカー研究所日本株ファンド（資産成長型）',
        fund_name_yomi='ドラッカーケンキュウジョニホンカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月19日',
        period_2='12月19日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15248': FundCodeEntry(
        fund_code='G15248',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）オールカントリー・大型成長株',
        fund_name_yomi='アムンディインデックスシリーズオールカントリーオオガタセイチョウカブ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15249': FundCodeEntry(
        fund_code='G15249',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）オールカントリー・高配当株',
        fund_name_yomi='アムンディインデックスシリーズオールカントリーコウハイトウカブ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15250': FundCodeEntry(
        fund_code='G15250',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）インド株',
        fund_name_yomi='アムンディインデックスシリーズインドカブ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15251': FundCodeEntry(
        fund_code='G15251',
        sec_code=None,
        fund_name='三井住友ＤＳ・ジャパン・ハイ・コンビクション・ストラテジー',
        fund_name_yomi='ミツイスミトモディーエスジャパンハイコンビクションストラテジー',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15252': FundCodeEntry(
        fund_code='G15252',
        sec_code=None,
        fund_name='アップストリーム',
        fund_name_yomi='アップストリーム',
        security_type='外国有価証券投資事業権利等',
        period_1='6月末日',
        period_2=None,
        edinet_code='E34585',
        issuer_name='ハンサード・インターナショナル・リミテッド',
    ),
    'G15253': FundCodeEntry(
        fund_code='G15253',
        sec_code=None,
        fund_name='グローバル・アクセス',
        fund_name_yomi='グローバルアクセス',
        security_type='外国有価証券投資事業権利等',
        period_1='6月末日',
        period_2=None,
        edinet_code='E34585',
        issuer_name='ハンサード・インターナショナル・リミテッド',
    ),
    'G15254': FundCodeEntry(
        fund_code='G15254',
        sec_code=None,
        fund_name='アジア半導体関連フォーカスファンド',
        fund_name_yomi='アジアハンドウタイカンレンフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='1月17日',
        period_2='7月17日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15255': FundCodeEntry(
        fund_code='G15255',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２４－０７',
        fund_name_yomi='アオゾラシングローバルブンサンファンドゲンテイツイカガタニイゼロニイヨンノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15256': FundCodeEntry(
        fund_code='G15256',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド（当初漸増期間付、限定追加型）２０２４－０７',
        fund_name_yomi='アオゾラシングローバルプレミアムファンドトウショゼンゾウキカンツキゲンテイツイカガタニイゼロニイヨンノゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15257': FundCodeEntry(
        fund_code='G15257',
        sec_code=None,
        fund_name='ＳＢＩ・ｉシェアーズ・全世界債券インデックス・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000アイシェアーズ\u3000ゼンセカイサイケンインデックス\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15258': FundCodeEntry(
        fund_code='G15258',
        sec_code=None,
        fund_name='日本株好配当ファンド（奇数月決算型）',
        fund_name_yomi='ニホンカブコウハイトウファンドキスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E31678',
        issuer_name='ちばぎんアセットマネジメント株式会社',
    ),
    'G15259': FundCodeEntry(
        fund_code='G15259',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ベトナム株インデックス',
        fund_name_yomi='アイフリーネクストベトナムカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15260': FundCodeEntry(
        fund_code='G15260',
        sec_code=None,
        fund_name='グローバル・Ｍ＆Ａオポチュニティ・ファンド',
        fund_name_yomi='グローバルエムアンドエーオポチュニティファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E39669',
        issuer_name='ＵＢＳファンド・マネジメント（アイルランド）リミテッド',
    ),
    'G15261': FundCodeEntry(
        fund_code='G15261',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２４－０８（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニヨンゼロハチゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15262': FundCodeEntry(
        fund_code='G15262',
        sec_code='213A0',
        fund_name='上場インデックスファンド日経半導体株',
        fund_name_yomi='ジョウジョウインデックスファンドニッケイハンドウタイカブ',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15263': FundCodeEntry(
        fund_code='G15263',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２４－０７（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニヨンゼロナナゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15264': FundCodeEntry(
        fund_code='G15264',
        sec_code=None,
        fund_name='ＣＬＯインカムファンド（為替ヘッジなし）、ＣＬＯインカムファンド（為替ヘッジあり）',
        fund_name_yomi='シーエルオーインカムファンドカワセヘッジナシ\u3000シーエルオーインカムファンドカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15265': FundCodeEntry(
        fund_code='G15265',
        sec_code=None,
        fund_name='カナダ株式ファンド',
        fund_name_yomi='カナダカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G15266': FundCodeEntry(
        fund_code='G15266',
        sec_code=None,
        fund_name='ａｕＡＭレバレッジＮＡＳＤＡＱ１００為替ヘッジ無し',
        fund_name_yomi='エーユーエーエムレバレッジナスダックヒャクカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='7月27日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15267': FundCodeEntry(
        fund_code='G15267',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット追加型２０２４－０９',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ツイカガタ\u3000ニセンニジュウヨン\u3000ゼロキュー',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15268': FundCodeEntry(
        fund_code='G15268',
        sec_code=None,
        fund_name='ＧＳグローバル社債ターゲット２０２４－０９（限定追加型）',
        fund_name_yomi='ジーエス\u3000グローバル\u3000シャサイ\u3000ターゲット\u3000ニセンニジュウヨン\u3000ゼロキュー\u3000ゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15269': FundCodeEntry(
        fund_code='G15269',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000日経半導体株インデックス',
        fund_name_yomi='イーマクシスニッケイハンドウタイカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15270': FundCodeEntry(
        fund_code='G15270',
        sec_code=None,
        fund_name='ＮＡＳＤＡＱ１００\u3000２倍ベア',
        fund_name_yomi='ナスダックヒャクニバイベア',
        security_type='内国投資信託受益証券',
        period_1='10月22日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15272': FundCodeEntry(
        fund_code='G15272',
        sec_code=None,
        fund_name='日本生命第９回劣後ローン流動化株式会社',
        fund_name_yomi='ニホンセイメイダイキュウカイレツゴローンリュウドウカカブシキカイシャ',
        security_type='内国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E39840',
        issuer_name='日本生命第９回劣後ローン流動化株式会社',
    ),
    'G15273': FundCodeEntry(
        fund_code='G15273',
        sec_code='221A0',
        fund_name='ＭＡＸＩＳ日経半導体株上場投信',
        fund_name_yomi='マクシスニッケイハンドウタイカブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15274': FundCodeEntry(
        fund_code='G15274',
        sec_code='223A0',
        fund_name='グローバルＸ\u3000ＡＩ＆ビッグデータ\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエーアイアンドビッグデータイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15275': FundCodeEntry(
        fund_code='G15275',
        sec_code='224A0',
        fund_name='グローバルＸ\u3000ウラニウムビジネス\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスウラニウムビジネスイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月24日',
        period_2='7月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15276': FundCodeEntry(
        fund_code='G15276',
        sec_code=None,
        fund_name='マスターズ・マルチアセット・ファンド（安定型）／（バランス型）／（積極型）',
        fund_name_yomi='マスターズマルチアセットファンドアンテイガタバランスガタセッキョクガタ',
        security_type='内国投資信託受益証券',
        period_1='6月28日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15277': FundCodeEntry(
        fund_code='G15277',
        sec_code=None,
        fund_name='ＳＢＩ－Ｍａｎ\u3000リキッド・トレンド・ファンド',
        fund_name_yomi='エスビーアイ\u3000マン\u3000リキッド\u3000トレンド\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15278': FundCodeEntry(
        fund_code='G15278',
        sec_code=None,
        fund_name='米ドル建ゴールドマン・サックス社債／米国テクノロジー株式指数ファンド（早期償還条項付）２０２４－０８',
        fund_name_yomi='ベイドルダテゴールドマンサックスシャサイ\u3000ベイコクテクノロジーカブシキシスウファンド\u3000ソウキショウカンジョウコウツキ\u3000ニゼロニヨンゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15279': FundCodeEntry(
        fund_code='G15279',
        sec_code=None,
        fund_name='映画デジタル証券・フィルムメーカーズプロジェクト１－ＨＥＲＯ’Ｓ\u3000ＩＳＬＡＮＤ',
        fund_name_yomi='エイガデジタルショウケン\u3000フィルムメーカーズプロジェクトワン\u3000ヒーローズアイランド',
        security_type='内国有価証券投資事業権利等',
        period_1='5月末日',
        period_2=None,
        edinet_code='E39844',
        issuer_name='合同会社ＣＰＦフィルムファンド',
    ),
    'G15280': FundCodeEntry(
        fund_code='G15280',
        sec_code=None,
        fund_name='ＴＴＩ・グローバル中小型厳選株式ファンド',
        fund_name_yomi='ティーティーアイグローバルチュウコガタゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15281': FundCodeEntry(
        fund_code='G15281',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000世界厳選成長株式ファンド\u3000Ａコース（野村ＳＭＡ・ＥＷ向け）／Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ティーロウプライス\u3000セカイゲンセンセイチョウカブシキファンド\u3000エイコース\u3000ノムラエスエムエーイーダブリュームケ\u3000ビーコース\u3000ノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15282': FundCodeEntry(
        fund_code='G15282',
        sec_code='233A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000インドＮｉｆｔｙ５０',
        fund_name_yomi='アイフリーイーティーエフインドニフティゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='3月4日',
        period_2='9月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15283': FundCodeEntry(
        fund_code='G15283',
        sec_code=None,
        fund_name='一歩先いく\u3000グローバル・イノベーション企業インデックス',
        fund_name_yomi='イッポサキイクグローバルイノベーションキギョウインデックス',
        security_type='内国投資信託受益証券',
        period_1='8月8日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15284': FundCodeEntry(
        fund_code='G15284',
        sec_code=None,
        fund_name='ブラックロック・フレキシブル・インカム・ファンド／ＢＩＮＣ',
        fund_name_yomi='ブラックロック\u3000フレキシブル\u3000インカム\u3000ファンド\u3000ビンク',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2='10月15日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15285': FundCodeEntry(
        fund_code='G15285',
        sec_code='236A0',
        fund_name='ｉシェアーズ\u3000日本国債７―１０年\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ニホンコクサイナナジュウネン\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15286': FundCodeEntry(
        fund_code='G15286',
        sec_code='237A0',
        fund_name='ｉシェアーズ\u3000米国債２５年超\u3000ロングデュレーション\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイニジュウゴネンチョウ\u3000ロングデュレーション\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15287': FundCodeEntry(
        fund_code='G15287',
        sec_code='238A0',
        fund_name='ｉシェアーズ\u3000米国債２５年超\u3000ロングデュレーション\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイニジュウゴネンチョウ\u3000ロングデュレーション\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15288': FundCodeEntry(
        fund_code='G15288',
        sec_code=None,
        fund_name='ピクテ・為替ヘッジなし・ゴールドファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ピクテカワセヘッジナシゴールドファンドノムラエスエムエイイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G15289': FundCodeEntry(
        fund_code='G15289',
        sec_code='235A0',
        fund_name='グローバルＸ\u3000高配当３０－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスコウハイトウサンジュウニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15290': FundCodeEntry(
        fund_code='G15290',
        sec_code='234A0',
        fund_name='グローバルＸ\u3000ＭＳＣＩ\u3000キャッシュフローキング－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエムエスシーアイキャッシュフローキングニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15291': FundCodeEntry(
        fund_code='G15291',
        sec_code=None,
        fund_name='新・ミューズニッチ米国ＢＤＣファンド（為替ヘッジなし・年４回分配型）',
        fund_name_yomi='シン\u3000ミューズニッチベイコクビーディーシーファンド\u3000カワセヘッジナシ\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15292': FundCodeEntry(
        fund_code='G15292',
        sec_code=None,
        fund_name='ニッセイ・円建てグローバル社債／バランスファンド２０２４－０９',
        fund_name_yomi='ニッセイエンダテグローバルシャサイバランスファンドニゼロニヨンゼロキュウ',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15293': FundCodeEntry(
        fund_code='G15293',
        sec_code=None,
        fund_name='日本好配当株投信（ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ニホンコウハイトウカブトウシンエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15294': FundCodeEntry(
        fund_code='G15294',
        sec_code=None,
        fund_name='野村未来トレンド発見ファンド\u3000ＡコースＢコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラミライトレンドハッケンファンド\u3000エーコースビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15295': FundCodeEntry(
        fund_code='G15295',
        sec_code=None,
        fund_name='ウエリントン・企業価値共創世界株ファンド\u3000ＡコースＢコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ウエリントンキギョウカチキョウソウセカイカブファンド\u3000エーコースビーコースノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15297': FundCodeEntry(
        fund_code='G15297',
        sec_code=None,
        fund_name='野村日本新鋭成長株ファンド',
        fund_name_yomi='ノムラニホンシンエイセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15298': FundCodeEntry(
        fund_code='G15298',
        sec_code=None,
        fund_name='ＤＣ全世界株式インデックスファンド（オール・カントリー）',
        fund_name_yomi='ディーシーゼンセカイカブシキインデックスファンド\u3000オール\u3000カントリー',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15300': FundCodeEntry(
        fund_code='G15300',
        sec_code=None,
        fund_name='ニッセイ・Ｓ日本半導体株式インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイエスニッポンハンドウタイカブシキインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15301': FundCodeEntry(
        fund_code='G15301',
        sec_code=None,
        fund_name='日本企業社債ファンド２０２４－１０',
        fund_name_yomi='ニホンキギョウシャサイファンドニセンニジュウヨンジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月25日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15302': FundCodeEntry(
        fund_code='G15302',
        sec_code=None,
        fund_name='フィデリティ・ワールド・ファンズ\u3000世界割安成長株ファンド',
        fund_name_yomi='フィデリティワールドファンズ\u3000セカイワリヤスセイチョウカブファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E31084',
        issuer_name='ＦＩＬ・インベストメント・マネジメント（ルクセンブルグ）エス・エイ・アール・エル',
    ),
    'G15303': FundCodeEntry(
        fund_code='G15303',
        sec_code=None,
        fund_name='ひふみクロスオーバーｐｒｏ',
        fund_name_yomi='ヒフミクロスオーバープロ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E21671',
        issuer_name='レオス・キャピタルワークス株式会社',
    ),
    'G15304': FundCodeEntry(
        fund_code='G15304',
        sec_code=None,
        fund_name='投資のソムリエ（ターゲット・イヤー２０７０）',
        fund_name_yomi='トウシノソムリエターゲットイヤーニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15305': FundCodeEntry(
        fund_code='G15305',
        sec_code=None,
        fund_name='フィデリティ・マゼラン・米国成長株ファンド',
        fund_name_yomi='フィデリティマゼランベイコクセイチョウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G15308': FundCodeEntry(
        fund_code='G15308',
        sec_code=None,
        fund_name='オール・カントリー好配当リバランスオープン（資産成長型）',
        fund_name_yomi='オールカントリーコウハイトウリバランスオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='7月23日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15309': FundCodeEntry(
        fund_code='G15309',
        sec_code=None,
        fund_name='オール・カントリー好配当リバランスオープン（年４回決算型）',
        fund_name_yomi='オールカントリーコウハイトウリバランスオープンネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月23日',
        period_2='7月23日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15310': FundCodeEntry(
        fund_code='G15310',
        sec_code=None,
        fund_name='ジュエル・ボックス・ファンド',
        fund_name_yomi='ジュエルボックスファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E40001',
        issuer_name='エマージング・アセット・マネジメント・リミテッド',
    ),
    'G15311': FundCodeEntry(
        fund_code='G15311',
        sec_code=None,
        fund_name='グローバル・サプライチェーン・ファンド（為替ヘッジあり）\u3000グローバル・サプライチェーン・ファンド（為替ヘッジなし）',
        fund_name_yomi='グローバルサプライチェーンファンドカワセヘッジアリ\u3000グローバルサプライチェーンファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E27736',
        issuer_name='ベイビュー・アセット・マネジメント株式会社',
    ),
    'G15312': FundCodeEntry(
        fund_code='G15312',
        sec_code=None,
        fund_name='楽天・日本株３．８倍ベアⅢ',
        fund_name_yomi='ラクテン\u3000ニホンカブサンテンハチバイベアスリー',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15313': FundCodeEntry(
        fund_code='G15313',
        sec_code=None,
        fund_name='ＳＢＩ全世界高配当株式ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイゼンセカイコウハイトウカブシキファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15314': FundCodeEntry(
        fund_code='G15314',
        sec_code=None,
        fund_name='岡三・ＵＢＳ・ファンドラップ・シリーズ',
        fund_name_yomi='オカサン\u3000ユービーエス\u3000ファンドラップ\u3000シリーズ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12473',
        issuer_name='ＵＢＳアセット・マネジメント株式会社',
    ),
    'G15315': FundCodeEntry(
        fund_code='G15315',
        sec_code=None,
        fund_name='米国５０社厳選株式ファンド',
        fund_name_yomi='ベイコクゴジュウシャゲンセンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G15316': FundCodeEntry(
        fund_code='G15316',
        sec_code='257A0',
        fund_name='ＳＭＴ\u3000ＥＴＦ日本株厳選投資アクティブ',
        fund_name_yomi='エスエムティー\u3000イーティーエフニホンカブゲンセントウシアクティブ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15317': FundCodeEntry(
        fund_code='G15317',
        sec_code=None,
        fund_name='楽天・シュワブ・高配当株式・米国ファンド（四半期決算型）',
        fund_name_yomi='ラクテン\u3000シュワブ\u3000コウハイトウカブシキ\u3000ベイコクファンド\u3000シハンキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2='8月25日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15318': FundCodeEntry(
        fund_code='G15318',
        sec_code=None,
        fund_name='グローバル・オポチュニティ・パートナーズ・ファンド',
        fund_name_yomi='グローバルオポチュニティパートナーズファンド',
        security_type='内国投資信託受益証券',
        period_1='3月6日',
        period_2='9月6日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15319': FundCodeEntry(
        fund_code='G15319',
        sec_code=None,
        fund_name='野村ブラックロック世界優良企業厳選ファンド\u3000ＡコースＢコース',
        fund_name_yomi='ノムラブラックロックセカイユウリョウキギョウゲンセンファンド\u3000エーコースビーコース',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15320': FundCodeEntry(
        fund_code='G15320',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２４－１１',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイヨンイチイチ',
        security_type='内国投資信託受益証券',
        period_1='3月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15321': FundCodeEntry(
        fund_code='G15321',
        sec_code=None,
        fund_name='日本株クオンタメンタル投資ファンド',
        fund_name_yomi='ニホンカブクオンタメンタルトウシファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15322': FundCodeEntry(
        fund_code='G15322',
        sec_code='258A0',
        fund_name='ＳＭＴ\u3000ＥＴＦ国内リート厳選投資アクティブ',
        fund_name_yomi='エスエムティー\u3000イーティーエフコクナイリートゲンセントウシアクティブ',
        security_type='内国投資信託受益証券',
        period_1='1月11日',
        period_2='7月11日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15323': FundCodeEntry(
        fund_code='G15323',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・世界高成長株投信（年２回決算型）／（隔月決算・予想分配金提示型）',
        fund_name_yomi='アライアンスバーンスタインセカイコウセイチョウカブトウシンネンニカイケッサンガタ\u3000カクゲツケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G15324': FundCodeEntry(
        fund_code='G15324',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｎｅｏ\u3000ＡＩテクノロジー',
        fund_name_yomi='イーマクシスネオエイアイテクノロジー',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15325': FundCodeEntry(
        fund_code='G15325',
        sec_code=None,
        fund_name='先進国米ドル建て債券ファンド２０２４－１０（限定追加型）',
        fund_name_yomi='センシンコクベイドルダテサイケンファンドニゼロニヨンイチゼロゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15326': FundCodeEntry(
        fund_code='G15326',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ／ＰａｙＰａｙ証券\u3000全世界バランス',
        fund_name_yomi='イーマクシスペイペイショウケンゼンセカイバランス',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15327': FundCodeEntry(
        fund_code='G15327',
        sec_code=None,
        fund_name='まあるい未来共創ファンド\u3000ｃｏｔｏｃｏｔｏ',
        fund_name_yomi='マアルイミライキョウソウファンド\u3000コトコト',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E22096',
        issuer_name='コモンズ投信株式会社',
    ),
    'G15328': FundCodeEntry(
        fund_code='G15328',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２４－１０',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイヨン\u3000イチゼロ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15329': FundCodeEntry(
        fund_code='G15329',
        sec_code=None,
        fund_name='ニッセイＳ＆Ｐ５００リカバリー戦略株式ファンド',
        fund_name_yomi='ニッセイエスアンドピーゴヒャクリカバリーセンリャクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月18日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15330': FundCodeEntry(
        fund_code='G15330',
        sec_code=None,
        fund_name='ＳＢＩ全世界高配当株式ファンド（年１回決算型）',
        fund_name_yomi='エスビーアイ\u3000ゼンセカイコウハイトウカブシキ\u3000ファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15331': FundCodeEntry(
        fund_code='G15331',
        sec_code=None,
        fund_name='いちご・レジデンス・トークン－市谷仲之町・文京小日向・駒場東大前・西新宿・清澄白河・浅草橋・三ノ輪－（デジタル名義書換方式）',
        fund_name_yomi='イチゴ\u3000レジデンス\u3000トークン\u3000イチガヤナカノチョウ\u3000ブンキョウコヒナタ\u3000コマバトウダイマエ\u3000ニシシンジュク\u3000キヨスミシラカワ\u3000アサクサバシ\u3000ミノワ\u3000デジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E30037',
        issuer_name='株式会社ＳＭＢＣ信託銀行',
    ),
    'G15332': FundCodeEntry(
        fund_code='G15332',
        sec_code=None,
        fund_name='インデックスファンドＮｉｆｔｙ５０（インド株式）',
        fund_name_yomi='インデックスファンドニフティゴジュウ\u3000インドカブシキ',
        security_type='内国投資信託受益証券',
        period_1='9月26日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15334': FundCodeEntry(
        fund_code='G15334',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）ストラテジー・ファンド－フィクスト・インカム（米ドル）',
        fund_name_yomi='ユービーエスルクスストラテジーファンドフィクストインカムベイドル',
        security_type='外国投資信託受益証券',
        period_1='1月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G15335': FundCodeEntry(
        fund_code='G15335',
        sec_code=None,
        fund_name='野村インデックスファンド・日経半導体株',
        fund_name_yomi='ノムラインデックスファンドニッケイハンドウタイカブ',
        security_type='内国投資信託受益証券',
        period_1='9月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15336': FundCodeEntry(
        fund_code='G15336',
        sec_code=None,
        fund_name='ＳＢＩ－フランクリン・テンプルトン・インド株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000フランクリン\u3000テンプルトン\u3000インド\u3000カブシキ\u3000インデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='10月21日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15337': FundCodeEntry(
        fund_code='G15337',
        sec_code=None,
        fund_name='アレス・グローバル・ハイイールド債券ファンド（為替ヘッジなし／年１回決算型）',
        fund_name_yomi='アレスグローバルハイイールドサイケンファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15338': FundCodeEntry(
        fund_code='G15338',
        sec_code=None,
        fund_name='アレス・グローバル・ハイイールド債券ファンド（為替ヘッジなし／年４回決算型）',
        fund_name_yomi='アレスグローバルハイイールドサイケンファンドカワセヘッジナシネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15339': FundCodeEntry(
        fund_code='G15339',
        sec_code=None,
        fund_name='ニュートン・パワー・イノベーション・ファンド（為替ヘッジあり）\u3000ニュートン・パワー・イノベーション・ファンド（為替ヘッジなし）',
        fund_name_yomi='ニュートンパワーイノベーションファンドカワセヘッジアリ\u3000ニュートンパワーイノベーションファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月21日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15340': FundCodeEntry(
        fund_code='G15340',
        sec_code=None,
        fund_name='ダイワ国内株式インデックス（投資一任専用）',
        fund_name_yomi='ダイワコクナイカブシキインデックストウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15341': FundCodeEntry(
        fund_code='G15341',
        sec_code=None,
        fund_name='ダイワ国内債券インデックス（投資一任専用）',
        fund_name_yomi='ダイワコクナイサイケンインデックストウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15342': FundCodeEntry(
        fund_code='G15342',
        sec_code=None,
        fund_name='ダイワ先進国債券インデックス（為替ヘッジあり・なし）（投資一任専用）',
        fund_name_yomi='ダイワセンシンコクサイケンインデックスカワセヘッジアリナシトウシイチニンセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15343': FundCodeEntry(
        fund_code='G15343',
        sec_code=None,
        fund_name='米国ハイイールド社債エンハンスト戦略ファンド（毎月分配型）／（資産成長型）',
        fund_name_yomi='ベイコクハイイールドシャサイエンハンストセンリャクファンドマイツキブンパイガタシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15344': FundCodeEntry(
        fund_code='G15344',
        sec_code=None,
        fund_name='ダイワ・バリュー株・フォーカス・ファンド',
        fund_name_yomi='ダイワバリューカブフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月16日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15345': FundCodeEntry(
        fund_code='G15345',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０３５／２０４０／２０４５／２０５０／２０５５／２０６０／２０６５（運用継続型）',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロサンゴー\u3000ニイゼロヨンゼロ\u3000ニイゼロヨンゴー\u3000ニイゼロゴーゼロ\u3000ニイゼロゴーゴー\u3000ニイゼロロクゼロ\u3000ニイゼロロクゴー\u3000ウンヨウケイゾクガタ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15346': FundCodeEntry(
        fund_code='G15346',
        sec_code=None,
        fund_name='ニッセイ・インデックス・ＳＯＸ（米国半導体株）',
        fund_name_yomi='ニッセイインデックスソックス\u3000ベイコクハンドウタイカブ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15347': FundCodeEntry(
        fund_code='G15347',
        sec_code=None,
        fund_name='ＤＣ日本株人材活躍企業応援ファンド',
        fund_name_yomi='ディーシーニホンカブジンザイカツヤクキギョウオウエンファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15348': FundCodeEntry(
        fund_code='G15348',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000Ｓ＆Ｐ１０００インデックス（米国中小型株式）',
        fund_name_yomi='トレイサーズ\u3000エスアンドピーセンインデックス\u3000ベイコクチュウコガタカブシキ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15349': FundCodeEntry(
        fund_code='G15349',
        sec_code='273A0',
        fund_name='ＳＢＩ\u3000サウジアラビア株式上場投信',
        fund_name_yomi='エスビーアイ\u3000サウジアラビアカブシキ\u3000ジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2='9月24日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15350': FundCodeEntry(
        fund_code='G15350',
        sec_code=None,
        fund_name='ブラックロックＬｉｆｅＰａｔｈファンド２０７０',
        fund_name_yomi='ブラックロックライフパスファンドニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='8月2日',
        period_2=None,
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15351': FundCodeEntry(
        fund_code='G15351',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～三重・イオンタウン鈴鹿～（デジタル名義書換方式）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンミエイオンタウンスズカデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G15352': FundCodeEntry(
        fund_code='G15352',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000先進国株式（含む日本）＜オール先進国＞',
        fund_name_yomi='イーマクシススリムセンシンコクカブシキフクムニホンオールセンシンコク',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15353': FundCodeEntry(
        fund_code='G15353',
        sec_code=None,
        fund_name='ＪＰＸプライム１５０ファンド',
        fund_name_yomi='ジェイピーエックスプライムヒャクゴジュウファンド',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15354': FundCodeEntry(
        fund_code='G15354',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅢ\u3000２０２４－１２',
        fund_name_yomi='ワンエンダテサイケンファンドスリーニイゼロニイヨンイチニイ',
        security_type='内国投資信託受益証券',
        period_1='4月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15355': FundCodeEntry(
        fund_code='G15355',
        sec_code=None,
        fund_name='あおぞら・日本株式アラインメント・ファンド',
        fund_name_yomi='アオゾラ\u3000ニホンカブシキアラインメント\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15356': FundCodeEntry(
        fund_code='G15356',
        sec_code=None,
        fund_name='プレミアム・ファンズ\u3000バークレイズ社債\u3000ＵＳキャピタル・プラス２４１１',
        fund_name_yomi='プレミアムファンズ\u3000バークレイズシャサイ\u3000ユーエスキャピタルプラス',
        security_type='外国投資信託受益証券',
        period_1='7月末日',
        period_2=None,
        edinet_code='E40148',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G15357': FundCodeEntry(
        fund_code='G15357',
        sec_code=None,
        fund_name='ウエリントン・トータル・リターン債券ファンド（年１回決算型）（為替ヘッジなし）',
        fund_name_yomi='ウエリントントータルリターンサイケンファンドネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15358': FundCodeEntry(
        fund_code='G15358',
        sec_code=None,
        fund_name='ウエリントン・トータル・リターン債券ファンド（年４回決算型）（為替ヘッジなし）',
        fund_name_yomi='ウエリントントータルリターンサイケンファンドネンヨンカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15359': FundCodeEntry(
        fund_code='G15359',
        sec_code=None,
        fund_name='フォントベル・世界割安債券ファンド（為替ヘッジあり／年１回決算型）\u3000フォントベル・世界割安債券ファンド（為替ヘッジなし／年１回決算型）',
        fund_name_yomi='フォントベルセカイワリヤスサイケンファンドカワセヘッジアリネンイッカイケッサンガタ\u3000フォントベルセカイワリヤスサイケンファンドカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月22日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15360': FundCodeEntry(
        fund_code='G15360',
        sec_code=None,
        fund_name='フォントベル・世界割安債券ファンド（為替ヘッジあり／年４回決算型）\u3000フォントベル・世界割安債券ファンド（為替ヘッジなし／年４回決算型）',
        fund_name_yomi='フォントベルセカイワリヤスサイケンファンドカワセヘッジアリネンヨンカイケッサンガタ\u3000フォントベルセカイワリヤスサイケンファンドカワセヘッジナシネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月22日',
        period_2='11月22日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15361': FundCodeEntry(
        fund_code='G15361',
        sec_code=None,
        fund_name='先進国株式リバウンドキャッチ戦略ファンド',
        fund_name_yomi='センシンコクカブシキリバウンドキャッチセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G15362': FundCodeEntry(
        fund_code='G15362',
        sec_code=None,
        fund_name='ケイマン籍パトナム・ディバーシファイド・インカム・トラスト',
        fund_name_yomi='ケイマンセキパトナムディバーシファイドインカムトラスト',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E40158',
        issuer_name='フランクリン・アドバイザーズ・インク',
    ),
    'G15363': FundCodeEntry(
        fund_code='G15363',
        sec_code=None,
        fund_name='米国株式・研究開発リバランスファンド',
        fund_name_yomi='ベイコクカブシキケンキュウカイハツリバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月26日',
        period_2=None,
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15364': FundCodeEntry(
        fund_code='G15364',
        sec_code=None,
        fund_name='ダルトン・ジャパン・パートナー戦略ファンド',
        fund_name_yomi='ダルトン\u3000ジャパン\u3000パートナーセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15365': FundCodeEntry(
        fund_code='G15365',
        sec_code=None,
        fund_name='ＨＳＢＣインド小型株式オープン',
        fund_name_yomi='エイチエスビーシーインドコガタカブシキオープン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2='10月25日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15366': FundCodeEntry(
        fund_code='G15366',
        sec_code=None,
        fund_name='ＳＢＩ岡三・グローバル・ファンド・シリーズ－ＵＳドル・マネー・マーケット・ファンド',
        fund_name_yomi='エスビーアイオカサングローバルファンドシリーズユーエスドルマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E40134',
        issuer_name='クイーンズゲート',
    ),
    'G15367': FundCodeEntry(
        fund_code='G15367',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－ゴールドマン・サックス・プライベート・クレジット・コープ／オルタナティブスＳＩＣＡＶヨーロピアン・クレジット・ファンド',
        fund_name_yomi='ノムラファンドセレクトゴールドマンサックスプライベートクレジットコープオルタナティブスシキャブヨーロピアンクレジットファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G15368': FundCodeEntry(
        fund_code='G15368',
        sec_code='282A0',
        fund_name='グローバルＸ\u3000半導体・トップ１０－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスハンドウタイトップテンニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15369': FundCodeEntry(
        fund_code='G15369',
        sec_code='283A0',
        fund_name='グローバルＸ\u3000ＵＳ\u3000テック・配当貴族\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスユーエステックハイトウキゾクイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15370': FundCodeEntry(
        fund_code='G15370',
        sec_code=None,
        fund_name='グローバルＣｏＣｏ債ファンド（為替ヘッジなし・１年決算型）、グローバルＣｏＣｏ債ファンド（為替ヘッジあり・１年決算型）',
        fund_name_yomi='グローバルココサイファンド\u3000カワセヘッジナシ\u3000イチネンケッサンガタ\u3000\u3000グローバルココサイファンド\u3000カワセヘッジアリ\u3000イチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月17日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15371': FundCodeEntry(
        fund_code='G15371',
        sec_code=None,
        fund_name='グローバルＣｏＣｏ債ファンド（為替ヘッジなし・年４回分配型）、グローバルＣｏＣｏ債ファンド（為替ヘッジあり・年４回分配型）',
        fund_name_yomi='グローバルココサイファンド\u3000カワセヘッジナシ\u3000ネンヨンカイブンパイガタ\u3000\u3000グローバルココサイファンド\u3000カワセヘッジアリ\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='2月17日',
        period_2='8月17日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15372': FundCodeEntry(
        fund_code='G15372',
        sec_code=None,
        fund_name='ニッセイ・インド中小型株式ファンド',
        fund_name_yomi='ニッセイインドチュウコガタカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月23日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15373': FundCodeEntry(
        fund_code='G15373',
        sec_code=None,
        fund_name='ｉＦｒｅｅＨＯＬＤ\u3000メキシコ国債（ＭＢＯＮＯ２０４７）',
        fund_name_yomi='アイフリーホールドメキシココクサイエムボノニゼロヨンナナ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15374': FundCodeEntry(
        fund_code='G15374',
        sec_code=None,
        fund_name='ｉＦｒｅｅＷａｌｌｅｔ\u3000メキシコペソ（ＭＸＮ）',
        fund_name_yomi='アイフリーウォレットメキシコペソエムエックスエヌ',
        security_type='内国投資信託受益証券',
        period_1='11月19日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15375': FundCodeEntry(
        fund_code='G15375',
        sec_code=None,
        fund_name='明治安田ゴールド／オール・カントリー株式戦略ファンド',
        fund_name_yomi='メイジヤスダゴールド\u3000オール\u3000カントリーカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15376': FundCodeEntry(
        fund_code='G15376',
        sec_code=None,
        fund_name='インド・イノベーション・フォーカスファンド',
        fund_name_yomi='インドイノベーションフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15377': FundCodeEntry(
        fund_code='G15377',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＬＧＴグローバル・プライベート・クレジット・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーエルジーティーグローバルプライベートクレジットファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G15378': FundCodeEntry(
        fund_code='G15378',
        sec_code=None,
        fund_name='シティグループ米ドル社債／欧米マルチアセット戦略ファンド２０２４－１２',
        fund_name_yomi='シティグループベイドルシャサイオウベイマルチアセットセンリャクファンドニイゼロニイヨンイチニイ',
        security_type='内国投資信託受益証券',
        period_1='1月18日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15379': FundCodeEntry(
        fund_code='G15379',
        sec_code=None,
        fund_name='日本高株主還元ファンド（年１回決算型）',
        fund_name_yomi='ニホンコウカブヌシカンゲンファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15380': FundCodeEntry(
        fund_code='G15380',
        sec_code=None,
        fund_name='日本高株主還元ファンド（年４回決算型）',
        fund_name_yomi='ニホンコウカブヌシカンゲンファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15381': FundCodeEntry(
        fund_code='G15381',
        sec_code=None,
        fund_name='先進国高利益成長ファンド（年１回決算型）',
        fund_name_yomi='センシンコクコウリエキセイチョウファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15382': FundCodeEntry(
        fund_code='G15382',
        sec_code=None,
        fund_name='先進国高利益成長ファンド（年４回決算・予想分配金提示型）',
        fund_name_yomi='センシンコクコウリエキセイチョウファンド\u3000ネンヨンカイケッサン\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15383': FundCodeEntry(
        fund_code='G15383',
        sec_code=None,
        fund_name='ｆｕｎｄｎｏｔｅＩＰＯクロスオーバーファンド',
        fund_name_yomi='ファンドノートアイピーオークロスオーバーファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E40155',
        issuer_name='ｆｕｎｄｎｏｔｅ株式会社',
    ),
    'G15384': FundCodeEntry(
        fund_code='G15384',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～ホテル・イビス大阪梅田～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンホテルイビスオオサカウメダジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15385': FundCodeEntry(
        fund_code='G15385',
        sec_code=None,
        fund_name='ＨＳＢＣインドテック株式インデックスファンド',
        fund_name_yomi='エイチエスビーシーインドテックカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15386': FundCodeEntry(
        fund_code='G15386',
        sec_code=None,
        fund_name='日経平均高配当利回り株ファンドⅡ',
        fund_name_yomi='ニッケイヘイキンコウハイトウリマワリカブファンドツー',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2='9月5日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15387': FundCodeEntry(
        fund_code='G15387',
        sec_code='294A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＭＳＣＩジャパン気候変動指数（セレクト）連動型上場投信',
        fund_name_yomi='ネクストファンズ\u3000エムエスシーアイジャパンキコウヘンドウシスウセレクトレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2='7月8日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15388': FundCodeEntry(
        fund_code='G15388',
        sec_code=None,
        fund_name='ピムコ・バミューダ・トラストＩＩ－ＰＩＭＣＯ短期インカム・ファンド',
        fund_name_yomi='ピムコバミューダトラストツーピムコタンキインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E15034',
        issuer_name='パシフィック・インベストメント・マネジメント・カンパニー・エルエルシー',
    ),
    'G15389': FundCodeEntry(
        fund_code='G15389',
        sec_code='295A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000ＦＴＳＥ・サウジアラビア・インデックス',
        fund_name_yomi='ワンイーティーエフエフティーエスイーサウジアラビアインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月8日',
        period_2='10月8日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15390': FundCodeEntry(
        fund_code='G15390',
        sec_code=None,
        fund_name='ＳＢＩ・Ｓ・米国高配当株式ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000エス\u3000ベイコクコウハイトウカブシキファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15391': FundCodeEntry(
        fund_code='G15391',
        sec_code=None,
        fund_name='インド中小型成長株式ファンド',
        fund_name_yomi='インドチュウコガタセイチョウカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15392': FundCodeEntry(
        fund_code='G15392',
        sec_code=None,
        fund_name='ジャパン・コア・アルファ',
        fund_name_yomi='ジャパン\u3000コア\u3000アルファ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15393': FundCodeEntry(
        fund_code='G15393',
        sec_code=None,
        fund_name='たわらノーロード\u3000インド株式Ｎｉｆｔｙ５０',
        fund_name_yomi='タワラノーロード\u3000インドカブシキニフティゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15394': FundCodeEntry(
        fund_code='G15394',
        sec_code=None,
        fund_name='アメリカ国家戦略関連株ファンド',
        fund_name_yomi='アメリカコッカセンリャクカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15395': FundCodeEntry(
        fund_code='G15395',
        sec_code=None,
        fund_name='ｉＦｒｅｅＰｌｕｓ\u3000世界トレンド・テクノロジー株（Ｚテック２０）',
        fund_name_yomi='アイフリープラスセカイトレンドテクノロジーカブゼットテックニジュウ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15396': FundCodeEntry(
        fund_code='G15396',
        sec_code=None,
        fund_name='楽天・ＭＦＳ外国株低ボラティリティ運用ファンド（為替ヘッジあり）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000エムエフエスガイコクカブテイボラティリティウンヨウファンド\u3000カワセヘッジアリ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15397': FundCodeEntry(
        fund_code='G15397',
        sec_code=None,
        fund_name='楽天・ＭＦＳ外国株低ボラティリティ運用ファンド（為替ヘッジなし）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000エムエフエスガイコクカブテイボラティリティウンヨウファンド\u3000カワセヘッジナシ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15398': FundCodeEntry(
        fund_code='G15398',
        sec_code=None,
        fund_name='楽天・グローバル・インカム・ファンド（為替ヘッジあり）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000グローバル\u3000インカム\u3000ファンド\u3000カワセヘッジアリ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15399': FundCodeEntry(
        fund_code='G15399',
        sec_code=None,
        fund_name='楽天・グローバル株式ファンド（為替ヘッジあり）＜ラップ向け＞',
        fund_name_yomi='ラクテン\u3000グローバルカブシキファンド\u3000カワセヘッジアリ\u3000\u3000ラップムケ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15400': FundCodeEntry(
        fund_code='G15400',
        sec_code=None,
        fund_name='一歩先いく\u3000華麗なるインド・トップ１０＋インデックス',
        fund_name_yomi='イッポサキイクカレイナルインドトップテンプラスインデックス',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15401': FundCodeEntry(
        fund_code='G15401',
        sec_code=None,
        fund_name='ゴールド・インカムプラス',
        fund_name_yomi='ゴールドインカムプラス',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15402': FundCodeEntry(
        fund_code='G15402',
        sec_code=None,
        fund_name='東海東京ヌビーン・リタイアメントファンド（年５１０円目標取崩し型）／（年５％目標取崩し型）',
        fund_name_yomi='トウカイトウキョウヌビーンリタイアメントファンドネンゴヒャクジュウエンモクヒョウトリクズシガタネンゴパーセントモクヒョウトリクズシガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2='3月10日',
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G15403': FundCodeEntry(
        fund_code='G15403',
        sec_code=None,
        fund_name='東海東京ヌビーン・リタイアメントファンド（資産安定型）',
        fund_name_yomi='トウカイトウキョウヌビーンリタイアメントファンドシサンアンテイガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E32909',
        issuer_name='株式会社お金のデザイン',
    ),
    'G15404': FundCodeEntry(
        fund_code='G15404',
        sec_code=None,
        fund_name='東京海上・上場オルタナティブ・アセット・マネージャーズ戦略ファンド',
        fund_name_yomi='トウキョウカイジョウジョウジョウオルタナティブアセットマネージャーズセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G15405': FundCodeEntry(
        fund_code='G15405',
        sec_code='314A0',
        fund_name='ｉシェアーズ\u3000ゴールド\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ゴールド\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15406': FundCodeEntry(
        fund_code='G15406',
        sec_code='313A0',
        fund_name='ｉシェアーズ\u3000Ｓ＆Ｐ\u3000５００\u3000トップ\u3000２０\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エスアンドピー\u3000ゴヒャク\u3000トップ\u3000ニジュウ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15407': FundCodeEntry(
        fund_code='G15407',
        sec_code=None,
        fund_name='資本効率向上ファンド',
        fund_name_yomi='シホンコウリツコウジョウファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G15408': FundCodeEntry(
        fund_code='G15408',
        sec_code='315A0',
        fund_name='グローバルＸ\u3000銀行\u3000高配当－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスギンコウコウハイトウニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月24日',
        period_2='10月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15409': FundCodeEntry(
        fund_code='G15409',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２５－０２（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニゴゼロニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15410': FundCodeEntry(
        fund_code='G15410',
        sec_code=None,
        fund_name='ＳＢＩサウジアラビア株式インデックス・ファンド',
        fund_name_yomi='エスビーアイ\u3000サウジアラビアカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15411': FundCodeEntry(
        fund_code='G15411',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000ラッセル１０００米国株式インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ラッセルセンベイコクカブシキインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15412': FundCodeEntry(
        fund_code='G15412',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド（当初漸増期間付、限定追加型）２０２５－０１',
        fund_name_yomi='アオゾラ\u3000シングローバル\u3000プレミアム\u3000ファンド\u3000トウショゼンゾウキカンツキ\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15413': FundCodeEntry(
        fund_code='G15413',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２５－０１',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15414': FundCodeEntry(
        fund_code='G15414',
        sec_code=None,
        fund_name='ＭＦシェア福岡アイランドシティロジ（譲渡制限付）',
        fund_name_yomi='エムエフシェアフクオカアイランドシティロジジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15415': FundCodeEntry(
        fund_code='G15415',
        sec_code=None,
        fund_name='ｆｕｎｄｎｏｔｅ日本株Ｋａｉｈｏｕファンド',
        fund_name_yomi='ファンドノートニホンカブカイホウファンド',
        security_type='内国投資信託受益証券',
        period_1='1月8日',
        period_2=None,
        edinet_code='E40155',
        issuer_name='ｆｕｎｄｎｏｔｅ株式会社',
    ),
    'G15416': FundCodeEntry(
        fund_code='G15416',
        sec_code='316A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ＦＡＮＧ＋',
        fund_name_yomi='アイフリーイーティーエフファングプラス',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15417': FundCodeEntry(
        fund_code='G15417',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000ＮＡＳＤＡＱ１００ゴールドプラス',
        fund_name_yomi='トレイサーズ\u3000ナスダックヒャクゴールドプラス',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15418': FundCodeEntry(
        fund_code='G15418',
        sec_code='318A0',
        fund_name='ＶＩＸ短期先物指数ＥＴＦ',
        fund_name_yomi='ブイアイエックスタンキサキモノシスウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15419': FundCodeEntry(
        fund_code='G15419',
        sec_code=None,
        fund_name='楽天・ＧＣＩシステマティック・グローバル・アルファ・ファンド',
        fund_name_yomi='ラクテン\u3000ジーシーアイシステマティック\u3000グローバル\u3000アルファ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15420': FundCodeEntry(
        fund_code='G15420',
        sec_code=None,
        fund_name='ａｕＡＭ米国債スーパーロング・ブル３倍・米ドルプラスコース／ａｕＡＭ米国債スーパーロング・ブル３倍・円コース',
        fund_name_yomi='エーユーエーエムベイコクサイスーパーロングブルサンバイベイドルプラスコース\u3000エーユーエーエムベイコクサイスーパーロングブルサンバイエンコース',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15421': FundCodeEntry(
        fund_code='G15421',
        sec_code=None,
        fund_name='ベトナム成長株ファンド（年１回決算型）',
        fund_name_yomi='ベトナムセイチョウカブファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E14714',
        issuer_name='キャピタル\u3000アセットマネジメント株式会社',
    ),
    'G15422': FundCodeEntry(
        fund_code='G15422',
        sec_code=None,
        fund_name='ニッセイ・インド株式ファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイインドカブシキファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='8月23日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15423': FundCodeEntry(
        fund_code='G15423',
        sec_code=None,
        fund_name='マルチアセット戦略ファンド・シングル／トリプル（ラップ専用）、マネーファンド（ラップ専用）',
        fund_name_yomi='マルチアセットセンリャクファンドシングルトリプルラップセンヨウマネーファンドラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15424': FundCodeEntry(
        fund_code='G15424',
        sec_code=None,
        fund_name='ダイワ・アンビット・インド小型株ファンド',
        fund_name_yomi='ダイワアンビットインドコガタカブファンド',
        security_type='内国投資信託受益証券',
        period_1='6月16日',
        period_2='12月16日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15425': FundCodeEntry(
        fund_code='G15425',
        sec_code=None,
        fund_name='三井住友ＤＳ・ＤＣターゲットイヤーファンド２０７０',
        fund_name_yomi='ミツイスミトモディーエスディーシーターゲットイヤーファンドニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='4月26日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15426': FundCodeEntry(
        fund_code='G15426',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅣ\u3000２０２５－０３',
        fund_name_yomi='ワンエンダテサイケンファンドフォーニイゼロニイゴウゼロサン',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15427': FundCodeEntry(
        fund_code='G15427',
        sec_code=None,
        fund_name='楽天・高配当株式・日本ファンド（四半期決算型）',
        fund_name_yomi='ラクテン\u3000コウハイトウカブシキ\u3000ニホンファンド\u3000シハンキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2='12月25日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15428': FundCodeEntry(
        fund_code='G15428',
        sec_code=None,
        fund_name='ピクテ・ウォーター・ファンド',
        fund_name_yomi='ピクテウォーターファンド',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E10439',
        issuer_name='ピクテ・ジャパン株式会社',
    ),
    'G15429': FundCodeEntry(
        fund_code='G15429',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２５－０３（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニゴゼロサンカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15430': FundCodeEntry(
        fund_code='G15430',
        sec_code=None,
        fund_name='ニッセイ・パワーテクノロジー株式ファンド',
        fund_name_yomi='ニッセイパワーテクノロジーカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15431': FundCodeEntry(
        fund_code='G15431',
        sec_code=None,
        fund_name='ニッセイ・円建てグローバル社債／バランスファンド２０２５－０３',
        fund_name_yomi='ニッセイエンダテグローバルシャサイバランスファンドニゼロニゴゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15432': FundCodeEntry(
        fund_code='G15432',
        sec_code=None,
        fund_name='ダイワ・ワールド・ファンド・シリーズ－ダイワ・ブラックストーン・インフラストラクチャー・ファンド',
        fund_name_yomi='ダイワワールドファンドシリーズダイワブラックストーンインフラストラクチャーファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E38530',
        issuer_name='ＩＱ\u3000ＥＱファンド・マネジメント（アイルランド）リミテッド',
    ),
    'G15433': FundCodeEntry(
        fund_code='G15433',
        sec_code=None,
        fund_name='プロテクト水準毎年設定型・米国株式ファンド２０２５－０３（限定追加型）',
        fund_name_yomi='プロテクトスイジュンマイトシセッテイガタベイコクカブシキファンドニゼロニゴゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15434': FundCodeEntry(
        fund_code='G15434',
        sec_code=None,
        fund_name='イーストスプリング・インド国債ファンド（３ヵ月決算型）\u3000イーストスプリング・インド国債ファンド（年２回決算型）',
        fund_name_yomi='イーストスプリング\u3000インドコクサイファンド\u3000サンカゲツケッサンガタ\u3000イーストスプリング\u3000インドコクサイファンド\u3000ネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E12566',
        issuer_name='イーストスプリング・インベストメンツ株式会社',
    ),
    'G15435': FundCodeEntry(
        fund_code='G15435',
        sec_code=None,
        fund_name='みずほサステナブルファンドシリーズ\u3000－\u3000ロベコ・スマート・エネルギー',
        fund_name_yomi='ミズホサステナブルファンドシリーズ\u3000ロベコスマートエネルギー',
        security_type='内国投資信託受益証券',
        period_1='11月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15436': FundCodeEntry(
        fund_code='G15436',
        sec_code=None,
        fund_name='野村マッコーリー・プライベート・インフラ・ファンド',
        fund_name_yomi='ノムラマッコーリープライベートインフラファンド',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2='7月30日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15437': FundCodeEntry(
        fund_code='G15437',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～学芸大学・中野・浅草橋・大塚～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンガクゲイダイガクナカノアサクサバシオオツカジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E39750',
        issuer_name='新生信託銀行株式会社',
    ),
    'G15438': FundCodeEntry(
        fund_code='G15438',
        sec_code=None,
        fund_name='ダイワＳ＆Ｐ５００インデックス（為替ヘッジあり／為替ヘッジなし）（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワエスアンドピーゴヒャクインデックスカワセヘッジアリナシダイワエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='9月7日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15439': FundCodeEntry(
        fund_code='G15439',
        sec_code=None,
        fund_name='キャピタル・インカム・ビルダー・ファンド／（米ドル売り円買い）',
        fund_name_yomi='キャピタルインカムビルダーファンドベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G15440': FundCodeEntry(
        fund_code='G15440',
        sec_code=None,
        fund_name='キャピタル・インカム・ビルダー・ファンド年２回決算（分配重視）／（分配重視／米ドル売り円買い）',
        fund_name_yomi='キャピタルインカムビルダーファンドネンニカイケッサンブンパイジュウシブンパイジュウシベイドルウリエンガイ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E14703',
        issuer_name='キャピタル・インターナショナル株式会社',
    ),
    'G15441': FundCodeEntry(
        fund_code='G15441',
        sec_code=None,
        fund_name='農林中金＜パートナーズ＞日米６資産分散ファンド（安定運用コース）（為替ヘッジなし）\u3000農林中金＜パートナーズ＞日米６資産分散ファンド（資産形成コース）（為替ヘッジなし）',
        fund_name_yomi='ノウリンチュウキン\u3000パートナーズ\u3000ニチベイロクシサンブンサンファンド\u3000アンテイウンヨウコース\u3000カワセヘッジナシ\u3000ノウリンチュウキン\u3000パートナーズ\u3000ニチベイロクシサンブンサンファンド\u3000シサンケイセイコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15442': FundCodeEntry(
        fund_code='G15442',
        sec_code=None,
        fund_name='ＭＵＦＧリアルティ・トークン自由が丘（デジタル名義書換方式）',
        fund_name_yomi='エムユーエフジーリアルティトークンジユウガオカデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15443': FundCodeEntry(
        fund_code='G15443',
        sec_code='328A0',
        fund_name='グローバルＸ\u3000プライシングパワー・リーダーズ－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスプライシングパワーリーダーズニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15444': FundCodeEntry(
        fund_code='G15444',
        sec_code=None,
        fund_name='アムンディ・米国コア株式ファンド',
        fund_name_yomi='アムンディベイコクコアカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15445': FundCodeEntry(
        fund_code='G15445',
        sec_code=None,
        fund_name='ダイワＮＡＳＤＡＱ１００インデックス（為替ヘッジなし）（ダイワＳＭＡ専用）',
        fund_name_yomi='ダイワナスダックヒャクインデックスカワセヘッジナシダイワエスエムエーセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='8月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15446': FundCodeEntry(
        fund_code='G15446',
        sec_code=None,
        fund_name='米国マイクロキャップ株式ファンド',
        fund_name_yomi='ベイコクマイクロキャップカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月18日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15447': FundCodeEntry(
        fund_code='G15447',
        sec_code=None,
        fund_name='明治安田日本企業好利回り社債ファンド（限定追加型）２０２５－０３',
        fund_name_yomi='メイジヤスダニホンキギョウコウリマワリシャサイファンドゲンテイツイカガタニセンニジュウゴノゼロサン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15448': FundCodeEntry(
        fund_code='G15448',
        sec_code=None,
        fund_name='サイバーセキュリティ株式オープン＜３ヵ月決算型＞（為替ヘッジなし）',
        fund_name_yomi='サイバーセキュリティカブシキオープンサンカゲツケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月6日',
        period_2='12月6日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15449': FundCodeEntry(
        fund_code='G15449',
        sec_code=None,
        fund_name='野村ＪＰＭグローバルセレクト株式\u3000Ａコース／Ｂコース（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラジェイピーエムグローバルセレクトカブシキ\u3000エーコースビーコース\u3000ノムラエスエムエーイーダブリュームケ',
        security_type='内国投資信託受益証券',
        period_1='12月6日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15450': FundCodeEntry(
        fund_code='G15450',
        sec_code=None,
        fund_name='楽天・高配当株式・米国ＶＹＭファンド（四半期決算型）',
        fund_name_yomi='ラクテン\u3000コウハイトウカブシキ\u3000ベイコクブイワイエムファンド\u3000シハンキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15451': FundCodeEntry(
        fund_code='G15451',
        sec_code=None,
        fund_name='三井住友ＤＳ・バランスファンド（保守コース）\u3000三井住友ＤＳ・バランスファンド（安定コース）\u3000三井住友ＤＳ・バランスファンド（標準コース）\u3000三井住友ＤＳ・バランスファンド（成長コース）\u3000三井住友ＤＳ・バランスファンド（積極コース）',
        fund_name_yomi='ミツイスミトモディーエスバランスファンドホシュコース\u3000ミツイスミトモディーエスバランスファンドアンテイコース\u3000ミツイスミトモディーエスバランスファンドヒョウジュンコース\u3000ミツイスミトモディーエスバランスファンドセイチョウコース\u3000ミツイスミトモディーエスバランスファンドセッキョクコース',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15452': FundCodeEntry(
        fund_code='G15452',
        sec_code=None,
        fund_name='しんきん日米半導体株ファンド',
        fund_name_yomi='シンキンニチベイハンドウタイカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G15453': FundCodeEntry(
        fund_code='G15453',
        sec_code=None,
        fund_name='ウエリントン・トータル・リターン債券ファンド（年１回決算型）（為替ヘッジあり）',
        fund_name_yomi='ウエリントントータルリターンサイケンファンドネンイッカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15454': FundCodeEntry(
        fund_code='G15454',
        sec_code=None,
        fund_name='ウエリントン・トータル・リターン債券ファンド（年４回決算型）（為替ヘッジあり）',
        fund_name_yomi='ウエリントントータルリターンサイケンファンドネンヨンカイケッサンガタカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月14日',
        period_2='11月14日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15455': FundCodeEntry(
        fund_code='G15455',
        sec_code=None,
        fund_name='Ｏｎｅ／フィデリティ・ブルーチップ・グロース株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ワンフィデリティブルーチップグロースカブシキファンドマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15456': FundCodeEntry(
        fund_code='G15456',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～ザ\u3000ロイヤルパークホテル\u3000東京汐留～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンザロイヤルパークホテルトウキョウシオドメジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月30日',
        period_2='10月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15457': FundCodeEntry(
        fund_code='G15457',
        sec_code=None,
        fund_name='インベスコ\u3000エマージング厳選株式ファンド（年１回決算型）',
        fund_name_yomi='インベスコエマージングゲンセンカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15458': FundCodeEntry(
        fund_code='G15458',
        sec_code=None,
        fund_name='インベスコ\u3000エマージング厳選株式ファンド（毎月決算型）',
        fund_name_yomi='インベスコエマージングゲンセンカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15459': FundCodeEntry(
        fund_code='G15459',
        sec_code=None,
        fund_name='インベスコ\u3000インド株式ファンド（年１回決算型）',
        fund_name_yomi='インベスコインドカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15460': FundCodeEntry(
        fund_code='G15460',
        sec_code=None,
        fund_name='インベスコ\u3000インド株式ファンド（毎月決算型）',
        fund_name_yomi='インベスコインドカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15461': FundCodeEntry(
        fund_code='G15461',
        sec_code=None,
        fund_name='インベスコ\u3000米国株式ファンド（年１回決算型）',
        fund_name_yomi='インベスコベイコクカブシキファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15462': FundCodeEntry(
        fund_code='G15462',
        sec_code=None,
        fund_name='インベスコ\u3000米国株式ファンド（毎月決算型）',
        fund_name_yomi='インベスコベイコクカブシキファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15463': FundCodeEntry(
        fund_code='G15463',
        sec_code=None,
        fund_name='楽天・日本株トリプル・ベアⅥ',
        fund_name_yomi='ラクテン\u3000ニホンカブトリプル\u3000ベアシックス',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15465': FundCodeEntry(
        fund_code='G15465',
        sec_code='346A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ\u3000５００\u3000半導体・半導体製造装置３５％キャップ指数連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーゴヒャクハンドウタイハンドウタイセイゾウソウチサンジュウゴパーセントキャップシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15466': FundCodeEntry(
        fund_code='G15466',
        sec_code=None,
        fund_name='ひとくふうターゲット・デート・ファンド２０７０',
        fund_name_yomi='ヒトクフウターゲットデートファンドニイゼロナナゼロ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15467': FundCodeEntry(
        fund_code='G15467',
        sec_code=None,
        fund_name='Ｏｎｅ／フェルマット・ＣＡＴ債券ファンド（年４回決算型）（為替ヘッジなし）',
        fund_name_yomi='ワンフェルマットキャットサイケンファンドネンヨンカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15468': FundCodeEntry(
        fund_code='G15468',
        sec_code=None,
        fund_name='ニッセイ日本株バリュー戦略ファンド',
        fund_name_yomi='ニッセイニホンカブバリューセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='7月14日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15469': FundCodeEntry(
        fund_code='G15469',
        sec_code=None,
        fund_name='ｅＭＡＸＩＳ\u3000Ｓｌｉｍ\u3000国内株式（読売３３３）',
        fund_name_yomi='イーマクシススリムコクナイカブシキヨミウリサンサンサン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15470': FundCodeEntry(
        fund_code='G15470',
        sec_code='348A0',
        fund_name='ＭＡＸＩＳ読売３３３日本株上場投信',
        fund_name_yomi='マクシスヨミウリサンサンサンニホンカブジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2='7月26日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15471': FundCodeEntry(
        fund_code='G15471',
        sec_code='349A0',
        fund_name='ＳＭＤＡＭ\u3000Ａｃｔｉｖｅ\u3000ＥＴＦ\u3000日本グロース株式',
        fund_name_yomi='エスエムディーエーエムアクティブイーティーエフニホングロースカブシキ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15472': FundCodeEntry(
        fund_code='G15472',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２５ー０４',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ゼロヨン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15473': FundCodeEntry(
        fund_code='G15473',
        sec_code=None,
        fund_name='未来のわたし（ターゲット・イヤー／～１９７２年生まれ向け、１９７３～１９７７年生まれ向け、１９７８～１９８２年生まれ向け、１９８３～１９８７年生まれ向け、１９８８～１９９２年生まれ向け、１９９３～１９９７年生まれ向け、１９９８～２００２年生まれ向け、２００３～２００７年生まれ向け）',
        fund_name_yomi='ミライノワタシ\u3000ターゲットイヤー\u3000カラセンキュウヒャクナナジュウニネンウマレムケ\u3000センキュウヒャクナナジュウサンカラセンキュウヒャクナナジュウナナネンウマレムケ\u3000センキュウヒャクナナジュウハチカラセンキュウヒャクハチジュウニネンウマレムケ\u3000センキュウヒャクハチジュウサンカラセンキュウヒャクハチジュウナナネンウマレムケ\u3000センキュウヒャクハチジュウハチカラセンキュウヒャクキュウジュウニネンウマレムケ\u3000センキュウヒャクキュウジュウサンカラセンキュウヒャクキュウジュウナナネンウマレムケ\u3000センキュウヒャクキュウジュウハチカラニセンニネンウマレムケ\u3000ニセンサンカラニセンナナネンウマレムケ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15474': FundCodeEntry(
        fund_code='G15474',
        sec_code=None,
        fund_name='フィデリティ・欧州割安成長株投信\u3000Ａコース（為替ヘッジあり）\u3000フィデリティ・欧州割安成長株投信\u3000Ｂコース（為替ヘッジなし）',
        fund_name_yomi='フィデリティオウシュウワリヤスセイチョウカブトウシンエーコースカワセヘッジアリ\u3000フィデリティオウシュウワリヤスセイチョウカブトウシンビーコースカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G15475': FundCodeEntry(
        fund_code='G15475',
        sec_code='356A0',
        fund_name='グローバルＸ\u3000Ｓ＆Ｐ５００\u3000キャッシュフロー・トップ１００\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスエスアンドピーゴヒャクキャッシュフロートップヒャクイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15476': FundCodeEntry(
        fund_code='G15476',
        sec_code=None,
        fund_name='ＪＰＭ日本株式ハイ・インカム・ファンド（毎月決算型）',
        fund_name_yomi='ジェイピーエムニホンカブシキハイインカムファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15477': FundCodeEntry(
        fund_code='G15477',
        sec_code=None,
        fund_name='ＪＰＭ日本株式ハイ・インカム・ファンド（隔月決算型）',
        fund_name_yomi='ジェイピーエムニホンカブシキハイインカムファンドカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15478': FundCodeEntry(
        fund_code='G15478',
        sec_code=None,
        fund_name='ＪＰＭ日本株式ハイ・インカム・ファンド（３ヵ月決算型）',
        fund_name_yomi='ジェイピーエムニホンカブシキハイインカムファンドサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2='9月13日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15479': FundCodeEntry(
        fund_code='G15479',
        sec_code=None,
        fund_name='ＪＰＭ日本株式ハイ・インカム・ファンド（年１回決算型）',
        fund_name_yomi='ジェイピーエムニホンカブシキハイインカムファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月13日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15480': FundCodeEntry(
        fund_code='G15480',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＫＫＲプライベート・マーケッツ・エクイティ・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーケーケーアールプライベートマーケッツエクイティファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G15481': FundCodeEntry(
        fund_code='G15481',
        sec_code=None,
        fund_name='レッド・アーク・グローバル・インベストメンツ（ケイマン）トラスト－米国マーケット・ストラテジー',
        fund_name_yomi='レッドアークグローバルインベストメンツケイマントラスト\u3000ベイコクマーケットストラテジー',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E22200',
        issuer_name='シティグループ・ファースト・インベストメント・マネジメント・リミテッド',
    ),
    'G15482': FundCodeEntry(
        fund_code='G15482',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）日本・高配当株',
        fund_name_yomi='アムンディインデックスシリーズニホンコウハイトウカブ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15483': FundCodeEntry(
        fund_code='G15483',
        sec_code='354A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000ブルームバーグ日本株高配当５０指数',
        fund_name_yomi='アイフリーイーティーエフブルームバーグニホンカブコウハイトウゴジュウシスウ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15484': FundCodeEntry(
        fund_code='G15484',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／ＦＯＬＩＯ・ＡＩマルチアセット戦略ファンド２０２５－０５',
        fund_name_yomi='ゴールドマンサックスシャサイフォリオエーアイマルチアセットセンリャクファンドニイゼロニイゴゼロゴ',
        security_type='内国投資信託受益証券',
        period_1='5月27日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15485': FundCodeEntry(
        fund_code='G15485',
        sec_code=None,
        fund_name='東京海上ターゲット・イヤー・ファンド２０４０／２０５０／２０６０／２０７０',
        fund_name_yomi='トウキョウカイジョウターゲットイヤーファンドニセンヨンジュウニセンゴジュウニセンロクジュウニセンナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2=None,
        edinet_code='E06433',
        issuer_name='東京海上アセットマネジメント株式会社',
    ),
    'G15487': FundCodeEntry(
        fund_code='G15487',
        sec_code=None,
        fund_name='つみたて日本株式（読売３３３）',
        fund_name_yomi='ツミタテニホンカブシキヨミウリサンサンサン',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15488': FundCodeEntry(
        fund_code='G15488',
        sec_code=None,
        fund_name='グローバル・ロボティクス株式ファンド（予想分配金提示型）、グローバル・ロボティクス株式ファンド（為替ヘッジあり・予想分配金提示型）',
        fund_name_yomi='グローバル\u3000ロボティクスカブシキファンド\u3000ヨソウブンパイキンテイジガタ\u3000グローバル\u3000ロボティクスカブシキファンド\u3000カワセヘッジアリ\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月15日',
        period_2='7月15日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15489': FundCodeEntry(
        fund_code='G15489',
        sec_code=None,
        fund_name='ＪＰモルガン・グランド・アセット・アロケーション',
        fund_name_yomi='ジェイピーモルガングランドアセットアロケーション',
        security_type='内国投資信託受益証券',
        period_1='5月28日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15491': FundCodeEntry(
        fund_code='G15491',
        sec_code=None,
        fund_name='ＪＰモルガン・スマート・インカム（為替ヘッジなし、年１回決算型）',
        fund_name_yomi='ジェイピーモルガンスマートインカムカワセヘッジナシネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15492': FundCodeEntry(
        fund_code='G15492',
        sec_code=None,
        fund_name='ＪＰモルガン・スマート・インカム（為替ヘッジなし、隔月決算型）',
        fund_name_yomi='ジェイピーモルガンスマートインカムカワセヘッジナシカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15493': FundCodeEntry(
        fund_code='G15493',
        sec_code=None,
        fund_name='ＪＰモルガン・スマート・インカム（為替ヘッジあり、年１回決算型）',
        fund_name_yomi='ジェイピーモルガンスマートインカムカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15494': FundCodeEntry(
        fund_code='G15494',
        sec_code=None,
        fund_name='ＪＰモルガン・スマート・インカム（為替ヘッジあり、隔月決算型）',
        fund_name_yomi='ジェイピーモルガンスマートインカムカワセヘッジアリカクゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月19日',
        period_2='9月19日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15495': FundCodeEntry(
        fund_code='G15495',
        sec_code=None,
        fund_name='ＵＳグローシリーズ',
        fund_name_yomi='ユーエスグローシリーズ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E31533',
        issuer_name='スカイオーシャン・アセットマネジメント株式会社',
    ),
    'G15496': FundCodeEntry(
        fund_code='G15496',
        sec_code=None,
        fund_name='オーイー・キャナル・アンブレラ・トラスト－ゴラブ・キャピタル・プライベート・クレジット・ファンド',
        fund_name_yomi='オーイーキャナルアンブレラトラストゴラブキャピタルプライベートクレジットファンド',
        security_type='外国投資信託受益証券',
        period_1='9月末日',
        period_2=None,
        edinet_code='E40001',
        issuer_name='エマージング・アセット・マネジメント・リミテッド',
    ),
    'G15497': FundCodeEntry(
        fund_code='G15497',
        sec_code=None,
        fund_name='セゾンのスマート不動産投資－神楽坂・早稲田・西早稲田・巣鴨・大森・大森町－（譲渡制限付）',
        fund_name_yomi='セゾンノスマートフドウサントウシカグラザカワセダニシワセダスガモオオモリオオモリマチジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月末日',
        period_2=None,
        edinet_code='E03041',
        issuer_name='株式会社クレディセゾン',
    ),
    'G15498': FundCodeEntry(
        fund_code='G15498',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２５－０５（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニゴゼロゴゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15499': FundCodeEntry(
        fund_code='G15499',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・エクイティ・ストラテジーズ・ファンド（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルエクイティストラテジーズファンドエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15500': FundCodeEntry(
        fund_code='G15500',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・フィクストインカム・ストラテジーズ・ファンド（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルフィクストインカムストラテジーズファンドエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15501': FundCodeEntry(
        fund_code='G15501',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・オルタナティブ・ストラテジーズ・ファンド（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルオルタナティブストラテジーズファンドエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15502': FundCodeEntry(
        fund_code='G15502',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・エクイティ・ストラテジーズ・ファンド・プレミアム（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルエクイティストラテジーズファンドプレミアムエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15503': FundCodeEntry(
        fund_code='G15503',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・フィクストインカム・ストラテジーズ・ファンド・プレミアム（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルフィクストインカムストラテジーズファンドプレミアムエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15504': FundCodeEntry(
        fund_code='G15504',
        sec_code=None,
        fund_name='ソフォス・ケイマン・トラストⅡ－グローバル・オルタナティブ・ストラテジーズ・ファンド・プレミアム（ＳＭＡ）',
        fund_name_yomi='ソフォスケイマントラストツーグローバルオルタナティブストラテジーズファンドプレミアムエスエムエー',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E34767',
        issuer_name='ファンドロジック（ジャージー）リミテッド',
    ),
    'G15505': FundCodeEntry(
        fund_code='G15505',
        sec_code=None,
        fund_name='グローバル株式インカム（３ヵ月決算型）予想分配金提示型',
        fund_name_yomi='グローバルカブシキインカムサンカゲツケッサンガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15506': FundCodeEntry(
        fund_code='G15506',
        sec_code=None,
        fund_name='グローバル株式インカム（年１回決算型）',
        fund_name_yomi='グローバルカブシキインカムネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月7日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15507': FundCodeEntry(
        fund_code='G15507',
        sec_code=None,
        fund_name='グローバル株式・プレミアム・セレクション（ＳＭＡ）',
        fund_name_yomi='グローバルカブシキプレミアムセレクションエスエムエー',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15508': FundCodeEntry(
        fund_code='G15508',
        sec_code=None,
        fund_name='グローバル債券・プレミアム・セレクション（ＳＭＡ）',
        fund_name_yomi='グローバルサイケンプレミアムセレクションエスエムエー',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15509': FundCodeEntry(
        fund_code='G15509',
        sec_code=None,
        fund_name='グローバルオルタナティブ・プレミアム・セレクション（ＳＭＡ）',
        fund_name_yomi='グローバルオルタナティブプレミアムセレクションエスエムエー',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15510': FundCodeEntry(
        fund_code='G15510',
        sec_code=None,
        fund_name='ＮＡＳＤＡＱ１００ゴールドプラス',
        fund_name_yomi='ナスダックヒャクゴールドプラス',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15511': FundCodeEntry(
        fund_code='G15511',
        sec_code=None,
        fund_name='ＤＣターゲット・イヤー\u3000ファンド２０６５',
        fund_name_yomi='ディーシーターゲット\u3000イヤー\u3000ファンドニセンロクジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15512': FundCodeEntry(
        fund_code='G15512',
        sec_code='360A0',
        fund_name='東証ＲＥＩＴ\u3000Ｃｏｒｅ\u3000ＥＴＦ',
        fund_name_yomi='トウショウリート\u3000コア\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15513': FundCodeEntry(
        fund_code='G15513',
        sec_code=None,
        fund_name='次世代ＡＩ株式戦略ファンド',
        fund_name_yomi='ジセダイエーアイカブシキセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='5月9日',
        period_2='11月9日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15514': FundCodeEntry(
        fund_code='G15514',
        sec_code=None,
        fund_name='九州未来ファンド',
        fund_name_yomi='キュウシュウミライファンド',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15515': FundCodeEntry(
        fund_code='G15515',
        sec_code=None,
        fund_name='明治安田グローバル債券／バイ・ザ・ディップ戦略ファンド２０２５－０６',
        fund_name_yomi='メイジヤスダグローバルサイケン\u3000バイ\u3000ザ\u3000ディップセンリャクファンドニセンニジュウゴノゼロロク',
        security_type='内国投資信託受益証券',
        period_1='10月21日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15516': FundCodeEntry(
        fund_code='G15516',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000ＤＪ\u3000ＵＳディビデンド１００（米国高配当株式）年４回分配型',
        fund_name_yomi='トレイサーズ\u3000ディージェー\u3000ユーエスディビデンドヒャク\u3000ベイコクコウハイトウカブシキ\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='4月4日',
        period_2='10月4日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15517': FundCodeEntry(
        fund_code='G15517',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000物流センター\u3000－厚木・八千代・野田－（譲渡制限付）',
        fund_name_yomi='ケネディクスリアルティトークンブツリュウセンターアツギヤチヨノダジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G15518': FundCodeEntry(
        fund_code='G15518',
        sec_code=None,
        fund_name='楽天・マネーファンド',
        fund_name_yomi='ラクテン\u3000マネーファンド',
        security_type='内国投資信託受益証券',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15519': FundCodeEntry(
        fund_code='G15519',
        sec_code=None,
        fund_name='たわらノーロード\u3000インド株式ＮｉｆｔｙＭｉｄｃａｐ５０',
        fund_name_yomi='タワラノーロード\u3000インドカブシキニフティミッドキャップゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15520': FundCodeEntry(
        fund_code='G15520',
        sec_code=None,
        fund_name='スターツ・アセット・トークン～両国・千鳥町～（譲渡制限付）',
        fund_name_yomi='スターツアセットトークン\u3000リョウゴクチドリチョウ\u3000ジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E40638',
        issuer_name='スターツ信託株式会社',
    ),
    'G15521': FundCodeEntry(
        fund_code='G15521',
        sec_code='363A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000英国ＦＴＳＥ１００',
        fund_name_yomi='アイフリーイーティーエフ\u3000エイコクフッツィーヒャク',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15522': FundCodeEntry(
        fund_code='G15522',
        sec_code=None,
        fund_name='ｓｕｓｔｅｎ新興国インカム・インデックスファンド（年４回決算型）',
        fund_name_yomi='サステンシンコウコクインカムインデックスファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月25日',
        period_2='7月25日',
        edinet_code='E36006',
        issuer_name='株式会社ｓｕｓｔｅｎキャピタル・マネジメント',
    ),
    'G15523': FundCodeEntry(
        fund_code='G15523',
        sec_code=None,
        fund_name='ニッセイ・円建てグローバル社債／バランスファンド２０２５－０６',
        fund_name_yomi='ニッセイエンダテグローバルシャサイバランスファンドニゼロニゴゼロロク',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15524': FundCodeEntry(
        fund_code='G15524',
        sec_code=None,
        fund_name='全世界株式インデックス・ファンド（オール・カントリー）',
        fund_name_yomi='ゼンセカイカブシキインデックスファンドオールカントリー',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15525': FundCodeEntry(
        fund_code='G15525',
        sec_code=None,
        fund_name='ＳＭＤ－ＡＭユニバーサル・トラスト－ＥＱＴネクサス・ＥＮＸＦ\u3000ＳＩＣＡＶファンド',
        fund_name_yomi='エスエムディーエーエムユニバーサルトラストイーキューティーネクサスイーエヌエックスエフシキャブファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E40672',
        issuer_name='セレス・ファンド・マネジメント（ケイマン）リミテッド',
    ),
    'G15526': FundCodeEntry(
        fund_code='G15526',
        sec_code=None,
        fund_name='Ｆ．ｂｉｔ航空機小口化商品第１号（譲渡制限付・為替ヘッジなし）',
        fund_name_yomi='エフビットコウクウキコグチカショウヒンダイイチゴウ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月末日',
        period_2=None,
        edinet_code='E38599',
        issuer_name='株式会社ＦＰＧ信託',
    ),
    'G15527': FundCodeEntry(
        fund_code='G15527',
        sec_code=None,
        fund_name='インデックスコレクション（日経２２５）',
        fund_name_yomi='インデックスコレクション\u3000ニッケイニーニーゴ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15528': FundCodeEntry(
        fund_code='G15528',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国株式リサーチファンド',
        fund_name_yomi='ティーロウプライス\u3000ベイコクカブシキリサーチファンド',
        security_type='内国投資信託受益証券',
        period_1='10月24日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15529': FundCodeEntry(
        fund_code='G15529',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000住宅ポートフォリオ\u3000－\u3000バリューアッド戦略\u3000－（デジタル名義書換方式）',
        fund_name_yomi='ケネディクスリアルティトークン\u3000ジュウタクポートフォリオ\u3000バリューアッドセンリャク\u3000デジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E30037',
        issuer_name='株式会社ＳＭＢＣ信託銀行',
    ),
    'G15530': FundCodeEntry(
        fund_code='G15530',
        sec_code='364A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000Ｓ＆Ｐ\u3000５００\u3000配当貴族指数連動型上場投信',
        fund_name_yomi='ネクストファンズエスアンドピーゴヒャクハイトウキゾクシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='3月7日',
        period_2='9月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15531': FundCodeEntry(
        fund_code='G15531',
        sec_code=None,
        fund_name='ＳＢＩ日本株３．８ベアⅢ',
        fund_name_yomi='エスビーアイ\u3000ニホンカブサンテンハチ\u3000ベア\u3000スリー',
        security_type='内国投資信託受益証券',
        period_1='5月21日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15532': FundCodeEntry(
        fund_code='G15532',
        sec_code=None,
        fund_name='Ｓｍａｒｔ－ｉ\u3000米国株式配当貴族インデックス',
        fund_name_yomi='スマート\u3000アイ\u3000ベイコクカブシキハイトウキゾクインデックス',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15533': FundCodeEntry(
        fund_code='G15533',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・米国ＲＥＩＴファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ブイ\u3000ベイコクリートファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15534': FundCodeEntry(
        fund_code='G15534',
        sec_code=None,
        fund_name='ベトナム＆アジア成長国ファンド',
        fund_name_yomi='ベトナムアンドアジアセイチョウコクファンド',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E27917',
        issuer_name='ファイブスター投信投資顧問株式会社',
    ),
    'G15535': FundCodeEntry(
        fund_code='G15535',
        sec_code='401A0',
        fund_name='霞ヶ関ホテルリート投資法人',
        fund_name_yomi='カスミガセキホテルリートトウシホウジン',
        security_type='内国投資証券',
        period_1='1月末日',
        period_2='7月末日',
        edinet_code='E40695',
        issuer_name='霞ヶ関ホテルリート投資法人',
    ),
    'G15536': FundCodeEntry(
        fund_code='G15536',
        sec_code=None,
        fund_name='カレラ日本好配当ファンド（毎月分配型）',
        fund_name_yomi='カレラニホンコウハイトウファンド\u3000マイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G15537': FundCodeEntry(
        fund_code='G15537',
        sec_code=None,
        fund_name='ブラックストーン・プライベート・クレジット・ＪＰＹファンド（毎月分配型）',
        fund_name_yomi='ブラックストーンプライベートクレジットジェーピーワイファンドマイツキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月27日',
        period_2='9月27日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15538': FundCodeEntry(
        fund_code='G15538',
        sec_code='376A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ブルームバーグ米国国債（７－１０年）インデックス（７５％為替ヘッジあり）連動型上場投信',
        fund_name_yomi='ネクストファンズブルームバーグベイコクコクサイナナネンジュウネンインデックスナナジュウゴパーセントカワセヘッジアリレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='5月7日',
        period_2='11月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15539': FundCodeEntry(
        fund_code='G15539',
        sec_code=None,
        fund_name='ヌビーン・ＣＭＢＳインカムファンド２０２５－０７（為替ヘッジあり）（限定追加型）\u3000ヌビーン・ＣＭＢＳインカムファンド２０２５－０７（為替ヘッジなし）（限定追加型）',
        fund_name_yomi='ヌビーンシーエムビーエスインカムファンドニイゼロニイゴゼロナナカワセヘッジアリゲンテイツイカガタ\u3000ヌビーンシーエムビーエスインカムファンドニイゼロニイゴゼロナナカワセヘッジナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='8月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15540': FundCodeEntry(
        fund_code='G15540',
        sec_code=None,
        fund_name='のむラップ・ファンド（保守型）年３％目標分配金受取型、のむラップ・ファンド（積極型）年３％目標分配金受取型、のむラップ・ファンド（積極型）年６％目標分配金受取型',
        fund_name_yomi='ノムラップファンドホシュガタネンサンパーセントモクヒョウブンパイキンウケトリガタ\u3000ノムラップファンドセッキョクガタネンサンパーセントモクヒョウブンパイキンウケトリガタ\u3000ノムラップファンドセッキョクガタネンロクパーセントモクヒョウブンパイキンウケトリガタ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2='9月18日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15541': FundCodeEntry(
        fund_code='G15541',
        sec_code='380A0',
        fund_name='グローバルＸ\u3000チャイナテック\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチャイナテックイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15542': FundCodeEntry(
        fund_code='G15542',
        sec_code=None,
        fund_name='（早期償還条項付）野村ハイベータ日本株２５０６',
        fund_name_yomi='ソウキショウカンジョウコウツキノムラハイベータニホンカブニイゴゼロロク',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15543': FundCodeEntry(
        fund_code='G15543',
        sec_code='379A0',
        fund_name='グローバルＸ\u3000Ｓ＆Ｐ５００\u3000ＥＴＦ（ダイナミック・プロテクション）',
        fund_name_yomi='グローバルエックスエスアンドピーゴヒャクイーティーエフダイナミックプロテクション',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15544': FundCodeEntry(
        fund_code='G15544',
        sec_code=None,
        fund_name='ラップ向け２資産アロケーションファンドⅠ（米国株式・世界債券）、ラップ向け２資産アロケーションファンドⅡ（米国株式・世界債券）、ラップ向け２資産アロケーションファンドⅢ（米国株式・世界債券）、ラップ向け２資産アロケーションファンドⅣ（米国株式・世界債券）',
        fund_name_yomi='ラップムケニシサンアロケーションファンドワンベイコクカブシキセカイサイケンラップムケニシサンアロケーションファンドツーベイコクカブシキセカイサイケンラップムケニシサンアロケーションファンドスリーベイコクカブシキセカイサイケンラップムケニシサンアロケーションファンドフォーベイコクカブシキセカイサイケン',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15545': FundCodeEntry(
        fund_code='G15545',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅤ\u3000２０２５－０７',
        fund_name_yomi='ワンエンダテサイケンファンドファイブニイゼロニイゴウゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='11月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15546': FundCodeEntry(
        fund_code='G15546',
        sec_code='381A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米国国債３－５年（為替ヘッジなし）',
        fund_name_yomi='アイフリーイーティーエフベイコクコクサイサンゴネンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15547': FundCodeEntry(
        fund_code='G15547',
        sec_code='382A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米国国債３－５年（為替ヘッジあり）',
        fund_name_yomi='アイフリーイーティーエフベイコクコクサイサンゴネンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15548': FundCodeEntry(
        fund_code='G15548',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０７０（運用継続型）、りそなターゲット・イヤー・ファンド２０７５（運用継続型）',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロナナゼロ\u3000ウンヨウケイゾクガタ\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロナナゴー\u3000ウンヨウケイゾクガタ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15549': FundCodeEntry(
        fund_code='G15549',
        sec_code=None,
        fund_name='りそなターゲット・イヤー・ファンド２０７０、りそなターゲット・イヤー・ファンド２０７５',
        fund_name_yomi='リソナターゲット\u3000イヤー\u3000ファンドニイゼロナナゼロ\u3000リソナターゲット\u3000イヤー\u3000ファンドニイゼロナナゴー',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15552': FundCodeEntry(
        fund_code='G15552',
        sec_code=None,
        fund_name='ＳＢＩネクスト・フロンティア高配当株式ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000ネクスト\u3000フロンティア\u3000コウハイトウカブシキ\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15553': FundCodeEntry(
        fund_code='G15553',
        sec_code=None,
        fund_name='インベスコＱＱＱ\u3000メガ・ファンド',
        fund_name_yomi='インベスコキューキューキューメガファンド',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15554': FundCodeEntry(
        fund_code='G15554',
        sec_code=None,
        fund_name='ｉＦｒｅｅレバレッジ\u3000Ｚテック２０・２倍ブル',
        fund_name_yomi='アイフリーレバレッジゼットテックニジュウニバイブル',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15555': FundCodeEntry(
        fund_code='G15555',
        sec_code=None,
        fund_name='ニッセイ高株主還元日本株ファンド（毎月決算型）',
        fund_name_yomi='ニッセイコウカブヌシカンゲンニホンカブファンドマイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15556': FundCodeEntry(
        fund_code='G15556',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２５－０７',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15557': FundCodeEntry(
        fund_code='G15557',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド（当初漸増期間付、限定追加型）２０２５－０７',
        fund_name_yomi='アオゾラ\u3000シングローバル\u3000プレミアム\u3000ファンド\u3000トウショゼンゾウキカンツキ\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ゼロナナ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15558': FundCodeEntry(
        fund_code='G15558',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～銀座～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンギンザジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15559': FundCodeEntry(
        fund_code='G15559',
        sec_code='383A0',
        fund_name='ＭＡＸＩＳ\u3000Ｓ＆Ｐ５００均等ウェイト上場投信',
        fund_name_yomi='マクシスエスアンドピーゴヒャクキントウウェイトジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15560': FundCodeEntry(
        fund_code='G15560',
        sec_code=None,
        fund_name='ＬＯＳＡ長期保有型国際分散インデックスファンド',
        fund_name_yomi='ローサチョウキホユウガタコクサイブンサンインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15561': FundCodeEntry(
        fund_code='G15561',
        sec_code=None,
        fund_name='ＡＩプラスファンド',
        fund_name_yomi='エーアイプラスファンド',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15562': FundCodeEntry(
        fund_code='G15562',
        sec_code=None,
        fund_name='インデックスオープン・日経２２５',
        fund_name_yomi='インデックスオープンニッケイニニゴ',
        security_type='内国投資信託受益証券',
        period_1='3月5日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15563': FundCodeEntry(
        fund_code='G15563',
        sec_code=None,
        fund_name='インデックスオープン・アメリカ株式',
        fund_name_yomi='インデックスオープンアメリカカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15564': FundCodeEntry(
        fund_code='G15564',
        sec_code=None,
        fund_name='インデックスオープン・世界株式',
        fund_name_yomi='インデックスオープンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15565': FundCodeEntry(
        fund_code='G15565',
        sec_code=None,
        fund_name='インデックスオープン・先進国株式',
        fund_name_yomi='インデックスオープンセンシンコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15566': FundCodeEntry(
        fund_code='G15566',
        sec_code=None,
        fund_name='日興ワールド・トラスト－アレス・ストラテジック・インカム・ファンド',
        fund_name_yomi='ニッコウワールドトラストアレスストラテジックインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='2月末日',
        period_2=None,
        edinet_code='E14853',
        issuer_name='ＳＭＢＣ日興インベストメント・ファンド・マネジメント・カンパニー・エス・エイ',
    ),
    'G15567': FundCodeEntry(
        fund_code='G15567',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000資産配分最適化バランス（Ｒ１）／（Ｒ２）／（Ｒ３）／（Ｒ４）／（Ｒ５）',
        fund_name_yomi='ミツビシユーエフジェイシサンハイブンサイテキカバランスアールイチアールニアールサンアールヨンアールゴ',
        security_type='内国投資信託受益証券',
        period_1='1月26日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15568': FundCodeEntry(
        fund_code='G15568',
        sec_code='392A0',
        fund_name='ｉシェアーズ\u3000ＮＡＳＤＡＱ\u3000トップ\u3000３０\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ナスダック\u3000トップ\u3000サンジュウ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15570': FundCodeEntry(
        fund_code='G15570',
        sec_code=None,
        fund_name='ＧＳ\u3000Ｐｌｕｓ全世界株式（オ―ル・カントリー）',
        fund_name_yomi='ジーエス\u3000プラス\u3000ゼンセカイカブシキ\u3000オールカントリー',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15571': FundCodeEntry(
        fund_code='G15571',
        sec_code=None,
        fund_name='楽天・ターゲットイヤー２０５５／楽天・ターゲットイヤー２０６０',
        fund_name_yomi='ラクテン\u3000ターゲットイヤーニセンゴジュウゴ\u3000ラクテン\u3000ターゲットイヤーニセンロクジュウ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15572': FundCodeEntry(
        fund_code='G15572',
        sec_code=None,
        fund_name='ニッセイ投資適格社債ファンド２０２５－０８（為替ヘッジあり・４年投資型）',
        fund_name_yomi='ニッセイトウシテキカクシャサイファンドニゼロニゴゼロハチカワセヘッジアリヨネントウシガタ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15573': FundCodeEntry(
        fund_code='G15573',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000ラッセル２０００米国中小型株式インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ラッセルニセンベイコクチュウコガタカブシキインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15574': FundCodeEntry(
        fund_code='G15574',
        sec_code=None,
        fund_name='ＦＷニッセイゴールドファンド',
        fund_name_yomi='エフダブリュニッセイゴールドファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15575': FundCodeEntry(
        fund_code='G15575',
        sec_code=None,
        fund_name='Ｍｙ\u3000ＳＭＴ\u3000ラッセル３０００全米株式インデックス（ノーロード）',
        fund_name_yomi='マイ\u3000エスエムティー\u3000ラッセルサンゼンゼンベイカブシキインデックス\u3000ノーロード',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15576': FundCodeEntry(
        fund_code='G15576',
        sec_code=None,
        fund_name='暗号資産関連株式ファンド',
        fund_name_yomi='アンゴウシサンカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15578': FundCodeEntry(
        fund_code='G15578',
        sec_code='394A0',
        fund_name='業界改革厳選ＥＴＦテレビ業界',
        fund_name_yomi='ギョウカイカイカクゲンセンイーティーエフテレビギョウカイ',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15579': FundCodeEntry(
        fund_code='G15579',
        sec_code='395A0',
        fund_name='業界改革厳選ＥＴＦ地銀',
        fund_name_yomi='ギョウカイカイカクゲンセンイーティーエフチギン',
        security_type='内国投資信託受益証券',
        period_1='7月12日',
        period_2=None,
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15580': FundCodeEntry(
        fund_code='G15580',
        sec_code='396A0',
        fund_name='業界改革厳選ＥＴＦ\u3000ＲＥＩＴイベント・ドリブン',
        fund_name_yomi='ギョウカイカイカクゲンセンイーティーエフ\u3000リートイベント\u3000ドリブン',
        security_type='内国投資信託受益証券',
        period_1='4月12日',
        period_2='10月12日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15581': FundCodeEntry(
        fund_code='G15581',
        sec_code=None,
        fund_name='楽天・高配当株式・日本ファンド（資産成長型）',
        fund_name_yomi='ラクテン\u3000コウハイトウカブシキ\u3000ニホンファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='6月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15582': FundCodeEntry(
        fund_code='G15582',
        sec_code=None,
        fund_name='楽天・オールカントリー株式（除く日本）インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000オールカントリーカブシキ\u3000ノゾクニホン\u3000インデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15583': FundCodeEntry(
        fund_code='G15583',
        sec_code=None,
        fund_name='楽天・エマージング株式インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000エマージングカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15584': FundCodeEntry(
        fund_code='G15584',
        sec_code=None,
        fund_name='楽天・シュワブ・高配当株式・米国ファンド（資産成長型）',
        fund_name_yomi='ラクテン\u3000シュワブ\u3000コウハイトウカブシキ\u3000ベイコクファンド\u3000シサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月25日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15585': FundCodeEntry(
        fund_code='G15585',
        sec_code=None,
        fund_name='Ｏｎｅ／ウエリントン・コントラリアン・バリュー・ファンド',
        fund_name_yomi='ワンウエリントンコントラリアンバリューファンド',
        security_type='内国投資信託受益証券',
        period_1='8月1日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15586': FundCodeEntry(
        fund_code='G15586',
        sec_code=None,
        fund_name='ＳＢＩ・Ｖ・全世界株式（除く米国）ファンド',
        fund_name_yomi='エスビーアイ\u3000ヴィ\u3000ゼンセカイカブシキ\u3000ノゾクベイコク\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='7月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15587': FundCodeEntry(
        fund_code='G15587',
        sec_code=None,
        fund_name='ＪＡバンクよりそいノーロード日本株式\u3000日経２２５',
        fund_name_yomi='ジェイエイバンクヨリソイノーロードニホンカブシキ\u3000ニッケイニイニイゴ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15588': FundCodeEntry(
        fund_code='G15588',
        sec_code=None,
        fund_name='ＪＡバンクよりそいノーロード米国株式\u3000Ｓ＆Ｐ５００',
        fund_name_yomi='ジェイエイバンクヨリソイノーロードベイコクカブシキ\u3000エスアンドピーゴヒャク',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15589': FundCodeEntry(
        fund_code='G15589',
        sec_code=None,
        fund_name='ＪＡバンクよりそいノーロード全世界株式',
        fund_name_yomi='ジェイエイバンクヨリソイノーロードゼンセカイカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15590': FundCodeEntry(
        fund_code='G15590',
        sec_code=None,
        fund_name='ＪＡバンクよりそいノーロード先進国株式（除く日本）',
        fund_name_yomi='ジェイエイバンクヨリソイノーロードセンシンコクカブシキ\u3000ノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15591': FundCodeEntry(
        fund_code='G15591',
        sec_code=None,
        fund_name='ＪＡバンクよりそいノーロード新興国株式',
        fund_name_yomi='ジェイエイバンクヨリソイノーロードシンコウコクカブシキ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15592': FundCodeEntry(
        fund_code='G15592',
        sec_code='399A0',
        fund_name='上場インデックスファンド日経平均高配当株５０',
        fund_name_yomi='ジョウジョウインデックスファンドニッケイヘイキンコウハイトウカブゴジュウ',
        security_type='内国投資信託受益証券',
        period_1='4月4日',
        period_2='10月4日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15593': FundCodeEntry(
        fund_code='G15593',
        sec_code=None,
        fund_name='にいがた未来応援アジア・パシフィック株式ファンド',
        fund_name_yomi='ニイガタミライオウエンアジアパシフィックカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15594': FundCodeEntry(
        fund_code='G15594',
        sec_code=None,
        fund_name='ＧＳグローバル（除く米国）割安高配当株式ファンド\u3000年４回決算コース',
        fund_name_yomi='ジーエスグローバルノゾクベイコクワリヤスコウハイトウカブシキファンドネンヨンカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15595': FundCodeEntry(
        fund_code='G15595',
        sec_code=None,
        fund_name='ＧＳグローバル（除く米国）割安高配当株式ファンド\u3000年１回決算コース',
        fund_name_yomi='ジーエスグローバルノゾクベイコクワリヤスコウハイトウカブシキファンドネンイッカイケッサンコース',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15596': FundCodeEntry(
        fund_code='G15596',
        sec_code=None,
        fund_name='ａｕＡＭレバレッジ・ハンセン・中国ファンド（香港ドルコース）／ａｕＡＭレバレッジ・ハンセン・中国ファンド（円コース）',
        fund_name_yomi='エーユーエーエムレバレッジハンセンチュウゴクファンドホンコンドルコース\u3000エーユーエーエムレバレッジハンセンチュウゴクファンドエンコース',
        security_type='内国投資信託受益証券',
        period_1='8月21日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15597': FundCodeEntry(
        fund_code='G15597',
        sec_code=None,
        fund_name='米ドル建ＨＳＢＣ社債／欧州株式戦略ファンド（早期償還条項付）２０２５－０８',
        fund_name_yomi='ベイドルダテエイチエスビーシーシャサイオウシュウカブシキセンリャクファンドソウキショウカンジョウコウツキニゼロニゴゼロハチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15598': FundCodeEntry(
        fund_code='G15598',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000全世界半導体株インデックス',
        fund_name_yomi='アイフリーネクストゼンセカイハンドウタイカブインデックス',
        security_type='内国投資信託受益証券',
        period_1='7月28日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15599': FundCodeEntry(
        fund_code='G15599',
        sec_code=None,
        fund_name='ステート・ストリート・ゴールド・オープン（為替ヘッジなし）／ステート・ストリート・ゴールド・オープン（為替ヘッジあり）',
        fund_name_yomi='ステートストリートゴールドオープンカワセヘッジナシ\u3000ステートストリートゴールドオープンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15600': FundCodeEntry(
        fund_code='G15600',
        sec_code=None,
        fund_name='ＤＣターゲット・イヤーファンド（ライフステージ対応型）２０７０\u3000ＤＣターゲット・イヤーファンド（ライフステージ対応型）２０７５',
        fund_name_yomi='ディーシーターゲット\u3000イヤーファンド\u3000ライフステージタイオウガタ\u3000ニセンナナジュウ\u3000ディーシーターゲット\u3000イヤーファンド\u3000ライフステージタイオウガタ\u3000ニセンナナジュウゴ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15601': FundCodeEntry(
        fund_code='G15601',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000米国株式インサイト戦略ファンド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーベイコクカブシキインサイトセンリャクファンドカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15602': FundCodeEntry(
        fund_code='G15602',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～川崎・商業～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンカワサキショウギョウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E40784',
        issuer_name='オルタナ信託株式会社',
    ),
    'G15603': FundCodeEntry(
        fund_code='G15603',
        sec_code=None,
        fund_name='楽天・欧州株式インデックス・ファンド',
        fund_name_yomi='ラクテン\u3000オウシュウカブシキインデックス\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='4月22日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15604': FundCodeEntry(
        fund_code='G15604',
        sec_code=None,
        fund_name='楽天・米国成長株式・プレミアム・インカム・ファンド（毎月決算型）',
        fund_name_yomi='ラクテン\u3000ベイコクセイチョウカブシキ\u3000プレミアム\u3000インカム\u3000ファンド\u3000マイツキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='6月15日',
        period_2='12月15日',
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15605': FundCodeEntry(
        fund_code='G15605',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000Ｗ\u3000ＯＳＡＫＡ（デジタル名義書換方式）',
        fund_name_yomi='ケネディクスリアルティトークンダブリューオオサカデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='1月31日',
        period_2='7月31日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15606': FundCodeEntry(
        fund_code='G15606',
        sec_code=None,
        fund_name='ニューバーガー・インド成長株ファンド（資産成長型）',
        fund_name_yomi='ニューバーガーインドセイチョウカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2=None,
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G15607': FundCodeEntry(
        fund_code='G15607',
        sec_code=None,
        fund_name='ニューバーガー・インド成長株ファンド（年４回決算型）',
        fund_name_yomi='ニューバーガーインドセイチョウカブファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月9日',
        period_2='7月9日',
        edinet_code='E12447',
        issuer_name='朝日ライフ\u3000アセットマネジメント株式会社',
    ),
    'G15608': FundCodeEntry(
        fund_code='G15608',
        sec_code=None,
        fund_name='日本株式・ゴールドアロケーションファンド',
        fund_name_yomi='ニホンカブシキ\u3000ゴールドアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15609': FundCodeEntry(
        fund_code='G15609',
        sec_code=None,
        fund_name='全世界株式・ゴールドアロケーションファンド',
        fund_name_yomi='ゼンセカイカブシキ\u3000ゴールドアロケーションファンド',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15610': FundCodeEntry(
        fund_code='G15610',
        sec_code=None,
        fund_name='ニッセイ・インド株式オープン（資産成長型）',
        fund_name_yomi='ニッセイインドカブシキオープンシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='8月23日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15611': FundCodeEntry(
        fund_code='G15611',
        sec_code=None,
        fund_name='ニッセイ・インド株式オープン（３ヵ月決算型）',
        fund_name_yomi='ニッセイインドカブシキオープンサンカゲツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月23日',
        period_2='8月23日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15612': FundCodeEntry(
        fund_code='G15612',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２５－０９（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニゴゼロキュウカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15613': FundCodeEntry(
        fund_code='G15613',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２５－０９（為替ヘッジなし・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニゴゼロキュウカワセヘッジナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15614': FundCodeEntry(
        fund_code='G15614',
        sec_code=None,
        fund_name='プロテクト水準毎年設定型・米国株式ファンド２０２５－０９（限定追加型）',
        fund_name_yomi='プロテクトスイジュンマイトシセッテイガタベイコクカブシキファンドニゼロニゴゼロキュウゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15615': FundCodeEntry(
        fund_code='G15615',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国成長株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ティーロウプライス\u3000ベイコクセイチョウカブシキファンド\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2='5月15日',
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15616': FundCodeEntry(
        fund_code='G15616',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000米国オールキャップ株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ティーロウプライス\u3000ベイコクオールキャップカブシキファンド\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2='5月15日',
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15617': FundCodeEntry(
        fund_code='G15617',
        sec_code=None,
        fund_name='野村グローバル高配当株プレミアム（米ドルコース）毎月分配型、野村グローバル高配当株プレミアム（米ドルコース）年２回決算型',
        fund_name_yomi='ノムラグローバルコウハイトウカブプレミアムベイドルコースマイツキブンパイガタ\u3000ノムラグローバルコウハイトウカブプレミアムネンニカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15618': FundCodeEntry(
        fund_code='G15618',
        sec_code=None,
        fund_name='ＳＢＩオルタナティブ・ハイインカム・セレクト・ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイ\u3000オルタナティブ\u3000ハイインカム\u3000セレクト\u3000ファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2='7月20日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15619': FundCodeEntry(
        fund_code='G15619',
        sec_code='404A0',
        fund_name='グローバルＸ\u3000チャイナテック・トップ１０\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチャイナテックトップテンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15620': FundCodeEntry(
        fund_code='G15620',
        sec_code=None,
        fund_name='カレラ英連邦３国ファンド',
        fund_name_yomi='カレラエイレンポウサンゴクファンド',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E26704',
        issuer_name='カレラアセットマネジメント株式会社',
    ),
    'G15621': FundCodeEntry(
        fund_code='G15621',
        sec_code=None,
        fund_name='ｉＦｒｅｅＨＯＬＤ\u3000日本国債（ＪＧＢ２０５６）',
        fund_name_yomi='アイフリーホールドニホンコクサイジェージービーニゼロゴロク',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15622': FundCodeEntry(
        fund_code='G15622',
        sec_code='408A0',
        fund_name='ｉシェアーズ\u3000ＡＩ\u3000グローバル・イノベーション\u3000アクティブ\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エーアイ\u3000グローバルイノベーション\u3000アクティブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15623': FundCodeEntry(
        fund_code='G15623',
        sec_code=None,
        fund_name='ドナルド・スミス\u3000グローバル・ディープバリュー戦略株式ファンド',
        fund_name_yomi='ドナルドスミスグローバルディープバリューセンリャクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15624': FundCodeEntry(
        fund_code='G15624',
        sec_code=None,
        fund_name='Ｏｎｅグローバル債券ファンド２０２５－１０（限定追加型）（為替ヘッジあり／為替ヘッジなし）',
        fund_name_yomi='ワングローバルサイケンファンドニイゼロニイゴウイチゼロゲンテイツイカガタカワセヘッジアリカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月18日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15625': FundCodeEntry(
        fund_code='G15625',
        sec_code=None,
        fund_name='ジャパン・クリエイティブコンテンツ関連株ファンド',
        fund_name_yomi='ジャパンクリエイティブコンテンツカンレンカブファンド',
        security_type='内国投資信託受益証券',
        period_1='2月12日',
        period_2='8月12日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15626': FundCodeEntry(
        fund_code='G15626',
        sec_code=None,
        fund_name='ＳＢＩ・Ｓ・米国高配当株式ファンド（年１回決算型）',
        fund_name_yomi='エスビーアイ\u3000エス\u3000ベイコクコウハイトウカブシキファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='9月28日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15627': FundCodeEntry(
        fund_code='G15627',
        sec_code=None,
        fund_name='ＳＢＩ日本高配当株式ファンド（年１回決算型）',
        fund_name_yomi='エスビーアイ\u3000ニホンコウハイトウカブシキファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15628': FundCodeEntry(
        fund_code='G15628',
        sec_code=None,
        fund_name='ゴールデントリオ（米国株・インド株・ゴールド）（資産成長型／予想分配金提示型）',
        fund_name_yomi='ゴールデントリオベイコクカブインドカブゴールドシサンセイチョウガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月12日',
        period_2='12月12日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15629': FundCodeEntry(
        fund_code='G15629',
        sec_code=None,
        fund_name='ニッセイ・Ｓ欧州株式５００インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイエスオウシュウカブシキゴヒャクインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='7月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15631': FundCodeEntry(
        fund_code='G15631',
        sec_code=None,
        fund_name='アライアンス・バーンスタインＳＩＣＡＶ－セレクトＵＳエクイティ・ポートフォリオ',
        fund_name_yomi='アライアンスバーンスタインシキャブセレクトユーエスエクイティポートフォリオ',
        security_type='外国投資証券',
        period_1='5月末日',
        period_2=None,
        edinet_code='E14837',
        issuer_name='アライアンス・バーンスタインＳＩＣＡＶ',
    ),
    'G15632': FundCodeEntry(
        fund_code='G15632',
        sec_code=None,
        fund_name='全共連第４回劣後ローン流動化株式会社',
        fund_name_yomi='ゼンキョウレンダイヨンカイレツゴローンリュウドウカカブシキガイシャ',
        security_type='内国資産流動化証券',
        period_1='6月末日',
        period_2=None,
        edinet_code='E40947',
        issuer_name='全共連第４回劣後ローン流動化株式会社',
    ),
    'G15633': FundCodeEntry(
        fund_code='G15633',
        sec_code='426A0',
        fund_name='ニッセイＥＴＦ\u3000Ｓ＆Ｐ５００イコール・ウェイト（為替ヘッジなし）',
        fund_name_yomi='ニッセイイーティーエフエスアンドピーゴヒャクイコールウェイトカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='1月27日',
        period_2='7月27日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15634': FundCodeEntry(
        fund_code='G15634',
        sec_code=None,
        fund_name='ＳＢＩ\u3000次世代テクノロジー戦略ファンド',
        fund_name_yomi='エスビーアイ\u3000ジセダイ\u3000テクノロジー\u3000センリャク\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月16日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15637': FundCodeEntry(
        fund_code='G15637',
        sec_code=None,
        fund_name='フィデリティ・アクティブ・ラップファンド（スタンダード）\u3000フィデリティ・アクティブ・ラップファンド（グロース）\u3000フィデリティ・アクティブ・ラップファンド（アグレッシブ）',
        fund_name_yomi='フィデリティアクティブラップファンドスタンダード\u3000フィデリティアクティブラップファンドグロース\u3000フィデリティアクティブラップファンドアグレッシブ',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E12481',
        issuer_name='フィデリティ投信株式会社',
    ),
    'G15638': FundCodeEntry(
        fund_code='G15638',
        sec_code=None,
        fund_name='ＨＳＢＣインド・インフラ株式オープン（毎月決算・予想分配金提示型）',
        fund_name_yomi='エイチエスビーシーインドインフラカブシキオープンマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月17日',
        period_2='12月17日',
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15639': FundCodeEntry(
        fund_code='G15639',
        sec_code='412A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＴＩＰ\u3000ＦａｃｔＳｅｔ\u3000台湾イノベイティブ・テクノロジー５０指数連動型上場投信',
        fund_name_yomi='ネクストファンズティーアイピーファクトセットタイワンイノベイティブテクノロジーゴジュウシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15640': FundCodeEntry(
        fund_code='G15640',
        sec_code=None,
        fund_name='野村ＤＣ日本好配当株投信',
        fund_name_yomi='ノムラディーシーニホンコウハイトウカブトウシン',
        security_type='内国投資信託受益証券',
        period_1='10月10日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15641': FundCodeEntry(
        fund_code='G15641',
        sec_code=None,
        fund_name='野村ＤＣグローバルＡＩ関連株式ファンド',
        fund_name_yomi='ノムラディーシーグローバルエイアイカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='11月14日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15642': FundCodeEntry(
        fund_code='G15642',
        sec_code=None,
        fund_name='野村ＤＣグローバル・プライベート・エクイティ関連株式ファンド',
        fund_name_yomi='ノムラディーシーグローバルプライベートエクイティカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='6月4日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15643': FundCodeEntry(
        fund_code='G15643',
        sec_code=None,
        fund_name='好利回り円債・短期戦略ファンド（年４回決算型）',
        fund_name_yomi='コウキンリエンサイタンキセンリャクファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G15644': FundCodeEntry(
        fund_code='G15644',
        sec_code=None,
        fund_name='好利回り円債・短期戦略ファンド（年１回決算型）',
        fund_name_yomi='コウキンリエンサイタンキセンリャクファンドネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月15日',
        period_2=None,
        edinet_code='E30703',
        issuer_name='マニュライフ・インベストメント・マネジメント株式会社',
    ),
    'G15645': FundCodeEntry(
        fund_code='G15645',
        sec_code='413A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000キャセイ台湾テックリーダー指数',
        fund_name_yomi='アイフリーイーティーエフキャセイタイワンテックリーダーシスウ',
        security_type='内国投資信託受益証券',
        period_1='4月7日',
        period_2='10月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15646': FundCodeEntry(
        fund_code='G15646',
        sec_code=None,
        fund_name='ＫＪＲＭ・リアルティ・トークン汐留シティセンター（デジタル名義書換方式）',
        fund_name_yomi='ケージェーアールエムリアルティトークンシオドメシティセンターデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月1日',
        period_2='11月1日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15647': FundCodeEntry(
        fund_code='G15647',
        sec_code=None,
        fund_name='ＭＵＦＧリアルティ・トークン渋谷神泉・両国森下（デジタル名義書換方式）',
        fund_name_yomi='エムユーエフジーリアルティトークンシブヤシンセンリョウゴクモリシタデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月1日',
        period_2='11月1日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15648': FundCodeEntry(
        fund_code='G15648',
        sec_code='424A0',
        fund_name='グローバルＸ\u3000ゴールド\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='グローバルエックスゴールドイーティーエフカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15649': FundCodeEntry(
        fund_code='G15649',
        sec_code='425A0',
        fund_name='グローバルＸ\u3000ゴールド\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスゴールドイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2='9月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15650': FundCodeEntry(
        fund_code='G15650',
        sec_code=None,
        fund_name='たわらノーロード\u3000ゴールド',
        fund_name_yomi='タワラノーロード\u3000ゴールド',
        security_type='内国投資信託受益証券',
        period_1='10月12日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15651': FundCodeEntry(
        fund_code='G15651',
        sec_code=None,
        fund_name='Ｕ．Ｓ．ランド・ファンド（ケイマン）－ＧＲＴランド・インカム・アンド・グロース・ファンド',
        fund_name_yomi='ユーエスランドファンドケイマンジーアールティーランドインカムアンドグロースファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E40908',
        issuer_name='ＧＲＴキャピタル・マネジメント・リミテッド',
    ),
    'G15652': FundCodeEntry(
        fund_code='G15652',
        sec_code=None,
        fund_name='明治安田日本企業好利回り社債ファンド（限定追加型）２０２５－１１',
        fund_name_yomi='メイジヤスダニホンキギョウコウリマワリシャサイファンドゲンテイツイカガタニセンニジュウゴノジュウイチ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15653': FundCodeEntry(
        fund_code='G15653',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２５ー１０',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴ\u3000ジュウ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15654': FundCodeEntry(
        fund_code='G15654',
        sec_code='435A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000日本株配当ローテーション戦略',
        fund_name_yomi='アイフリーイーティーエフニホンカブハイトウローテーションセンリャク',
        security_type='内国投資信託受益証券',
        period_1='1月7日',
        period_2='7月7日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15655': FundCodeEntry(
        fund_code='G15655',
        sec_code=None,
        fund_name='デジタル証券「ｒｅｎｇａ」第１号～レジデンス（北品川）～',
        fund_name_yomi='デジタルショウケンレンガダイイチゴウレジデンスキタシナガワ',
        security_type='内国有価証券投資事業権利等',
        period_1='4月末日',
        period_2='10月末日',
        edinet_code='E41002',
        issuer_name='ｒｅｎｇａ第１号合同会社',
    ),
    'G15656': FundCodeEntry(
        fund_code='G15656',
        sec_code=None,
        fund_name='パリミキ・ファミリーオフィス・ファンド',
        fund_name_yomi='パリミキファミリーオフィスファンド',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E15786',
        issuer_name='株式会社パリミキアセットマネジメント',
    ),
    'G15658': FundCodeEntry(
        fund_code='G15658',
        sec_code=None,
        fund_name='野村日本バリュー厳選投資',
        fund_name_yomi='ノムラニホンバリューゲンセントウシ',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15659': FundCodeEntry(
        fund_code='G15659',
        sec_code=None,
        fund_name='東京海上・日本プライベートエクイティ戦略ファンドＳＴ２０２６ー１号（デジタル名義書換方式）',
        fund_name_yomi='トウキョウカイジョウ\u3000ニッポンプライベートエクイティセンリャクファンドエスティーニセンニジュウロク\u3000イチゴウ\u3000デジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月1日',
        period_2=None,
        edinet_code='E39750',
        issuer_name='新生信託銀行株式会社',
    ),
    'G15660': FundCodeEntry(
        fund_code='G15660',
        sec_code=None,
        fund_name='ＳＭＴ\u3000米国高配当＆自社株買いファンド（年４回決算型）',
        fund_name_yomi='エスエムティー\u3000ベイコクコウハイトウアンドジシャカブガイファンド\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15661': FundCodeEntry(
        fund_code='G15661',
        sec_code=None,
        fund_name='米国上場プライベートアセット（ＢＤＣ）ファンド（年４回分配型）',
        fund_name_yomi='ベイコクジョウジョウプライベートアセット\u3000ビーディーシー\u3000ファンド\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='5月20日',
        period_2='11月20日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15662': FundCodeEntry(
        fund_code='G15662',
        sec_code='443A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000東証ＲＥＩＴ指数（２・５・８・１１月決算型）',
        fund_name_yomi='アイフリーイーティーエフトウショウリートシスウニゴハチジュウイチガツケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='2月4日',
        period_2='8月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15663': FundCodeEntry(
        fund_code='G15663',
        sec_code=None,
        fund_name='ティー・ロウ・プライス\u3000キャピタル・アプリシエーション・ファンド\u3000Ａコース（為替ヘッジあり）／Ｂコース（為替ヘッジなし）',
        fund_name_yomi='ティーロウプライス\u3000キャピタルアプリシエーションファンド\u3000エイコース\u3000カワセヘッジアリ\u3000ビーコース\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月24日',
        period_2=None,
        edinet_code='E33958',
        issuer_name='ティー・ロウ・プライス・ジャパン株式会社',
    ),
    'G15664': FundCodeEntry(
        fund_code='G15664',
        sec_code=None,
        fund_name='ＳＢＩネクスト・フロンティア高配当株式ファンド（年１回決算型）',
        fund_name_yomi='エスビーアイ\u3000ネクスト\u3000フロンティア\u3000コウハイトウカブシキ\u3000ファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15665': FundCodeEntry(
        fund_code='G15665',
        sec_code=None,
        fund_name='コモンズ・グローバル３０ファンド',
        fund_name_yomi='コモンズグローバルサーティファンド',
        security_type='内国投資信託受益証券',
        period_1='9月18日',
        period_2=None,
        edinet_code='E22096',
        issuer_name='コモンズ投信株式会社',
    ),
    'G15666': FundCodeEntry(
        fund_code='G15666',
        sec_code=None,
        fund_name='円建グローバル公社債ファンド（限定追加型）２０２５－１１',
        fund_name_yomi='エンダテグローバルコウシャサイファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイゴー\u3000イチイチ',
        security_type='内国投資信託受益証券',
        period_1='3月18日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15667': FundCodeEntry(
        fund_code='G15667',
        sec_code=None,
        fund_name='ｆｕｎｄｎｏｔｅＴＯＢ企業価値ジャッジファンド',
        fund_name_yomi='ファンドノートティーオービーキギョウカチジャッジファンド',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E40155',
        issuer_name='ｆｕｎｄｎｏｔｅ株式会社',
    ),
    'G15668': FundCodeEntry(
        fund_code='G15668',
        sec_code=None,
        fund_name='世界株式・クオンツ・ロングショートファンド（為替ヘッジなし／年４回決算型）\u3000世界株式・クオンツ・ロングショートファンド（為替ヘッジあり／年４回決算型）',
        fund_name_yomi='セカイカブシキクオンツロングショートファンドカワセヘッジナシネンヨンカイケッサンガタ\u3000セカイカブシキクオンツロングショートファンドカワセヘッジアリネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2='11月16日',
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15669': FundCodeEntry(
        fund_code='G15669',
        sec_code=None,
        fund_name='世界株式・クオンツ・ロングショートファンド（為替ヘッジなし／年１回決算型）\u3000世界株式・クオンツ・ロングショートファンド（為替ヘッジあり／年１回決算型）',
        fund_name_yomi='セカイカブシキクオンツロングショートファンドカワセヘッジナシネンイッカイケッサンガタ\u3000セカイカブシキクオンツロングショートファンドカワセヘッジアリネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='11月16日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15670': FundCodeEntry(
        fund_code='G15670',
        sec_code='447A0',
        fund_name='ステート・ストリート・スパイダー\u3000ゴールド\u3000ＥＴＦ（為替ヘッジなし）',
        fund_name_yomi='ステート\u3000ストリート\u3000スパイダー\u3000ゴールド\u3000イーティーエフ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15671': FundCodeEntry(
        fund_code='G15671',
        sec_code='448A0',
        fund_name='ステート・ストリート・スパイダー\u3000ゴールド\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='ステート\u3000ストリート\u3000スパイダー\u3000ゴールド\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15672': FundCodeEntry(
        fund_code='G15672',
        sec_code='449A0',
        fund_name='ステート・ストリート・スパイダー\u3000Ｓ＆Ｐ５００\u3000ＥＴＦ（為替ヘッジなし）',
        fund_name_yomi='ステート\u3000ストリート\u3000スパイダー\u3000エスアンドピーゴヒャク\u3000イーティーエフ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15673': FundCodeEntry(
        fund_code='G15673',
        sec_code='450A0',
        fund_name='ステート・ストリート・スパイダー\u3000Ｓ＆Ｐ５００\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='ステート\u3000ストリート\u3000スパイダー\u3000エスアンドピーゴヒャク\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15674': FundCodeEntry(
        fund_code='G15674',
        sec_code='451A0',
        fund_name='ステート・ストリート・スパイダー\u3000Ｓ＆Ｐ５００高配当株\u3000ＥＴＦ',
        fund_name_yomi='ステート\u3000ストリート\u3000スパイダー\u3000エスアンドピーゴヒャク\u3000コウハイトウカブ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12963',
        issuer_name='ステート・ストリート・グローバル・アドバイザーズ株式会社',
    ),
    'G15675': FundCodeEntry(
        fund_code='G15675',
        sec_code='452A0',
        fund_name='ｉシェアーズ\u3000Ｓ＆Ｐ\u3000５００\u3000プレミアムインカム\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エスアンドピー\u3000ゴヒャク\u3000プレミアムインカム\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15676': FundCodeEntry(
        fund_code='G15676',
        sec_code='453A0',
        fund_name='ｉシェアーズ\u3000米国債２０年超\u3000プレミアムインカム\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000ベイコクサイニジュウネンチョウ\u3000プレミアムインカム\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月18日',
        period_2='10月18日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15677': FundCodeEntry(
        fund_code='G15677',
        sec_code=None,
        fund_name='ブランデス欧州株ファンド',
        fund_name_yomi='ブランデスオウシュウカブファンド',
        security_type='内国投資信託受益証券',
        period_1='12月7日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15678': FundCodeEntry(
        fund_code='G15678',
        sec_code=None,
        fund_name='明治安田グローバル債券／バイ・ザ・ディップ戦略ファンド２０２５－１２',
        fund_name_yomi='メイジヤスダグローバルサイケン\u3000バイ\u3000ザ\u3000ディップセンリャクファンドニセンニジュウゴノジュウニ',
        security_type='内国投資信託受益証券',
        period_1='12月11日',
        period_2=None,
        edinet_code='E12448',
        issuer_name='明治安田アセットマネジメント株式会社',
    ),
    'G15679': FundCodeEntry(
        fund_code='G15679',
        sec_code=None,
        fund_name='ｉＦｒｅｅ\u3000全世界株式インデックス（オール・カントリー）',
        fund_name_yomi='アイフリーゼンセカイカブシキインデックスオールカントリー',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15680': FundCodeEntry(
        fund_code='G15680',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／Ｏｎｅ米国株式戦略ファンド２０２５－１２',
        fund_name_yomi='ゴールドマンサックスシャサイワンベイコクカブシキセンリャクファンドニイゼロニイゴウイチニイ',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15681': FundCodeEntry(
        fund_code='G15681',
        sec_code=None,
        fund_name='ニッセイ・Ｓ米国グロース株式メガ１０インデックスファンド＜購入・換金手数料なし＞',
        fund_name_yomi='ニッセイエスベイコクグロースカブシキメガテンインデックスファンドコウニュウカンキンテスウリョウナシ',
        security_type='内国投資信託受益証券',
        period_1='9月20日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15683': FundCodeEntry(
        fund_code='G15683',
        sec_code='459A0',
        fund_name='野村高利回りＪリート指数ＥＴＦ',
        fund_name_yomi='ノムラコウリマワリジェイリートシスウイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='3月12日',
        period_2='9月12日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15684': FundCodeEntry(
        fund_code='G15684',
        sec_code=None,
        fund_name='りそなゴールドファンド（為替ヘッジなし）、りそなゴールドファンド（為替ヘッジあり）',
        fund_name_yomi='リソナゴールドファンド\u3000カワセヘッジナシ\u3000リソナゴールドファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='7月25日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15685': FundCodeEntry(
        fund_code='G15685',
        sec_code=None,
        fund_name='たわらノーロード\u3000米国物価連動国債（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイコクブッカレンドウコクサイカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15686': FundCodeEntry(
        fund_code='G15686',
        sec_code=None,
        fund_name='たわらノーロード\u3000米国物価連動国債（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイコクブッカレンドウコクサイカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15687': FundCodeEntry(
        fund_code='G15687',
        sec_code=None,
        fund_name='たわらノーロード\u3000フォーカス\u3000防衛・航空宇宙',
        fund_name_yomi='タワラノーロード\u3000フォーカス\u3000ボウエイコウクウウチュウ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15688': FundCodeEntry(
        fund_code='G15688',
        sec_code=None,
        fund_name='京都二条城ホテルマザーファンド匿名組合',
        fund_name_yomi='キョウトニジョウジョウホテルマザーファンドトクメイクミアイ',
        security_type='内国有価証券投資事業権利等',
        period_1='8月末日',
        period_2=None,
        edinet_code='E41101',
        issuer_name='合同会社オーナーズブック・スリー',
    ),
    'G15689': FundCodeEntry(
        fund_code='G15689',
        sec_code=None,
        fund_name='ＧＳ\u3000Ｐｌｕｓゴールド（為替ヘッジあり）／（為替ヘッジなし）',
        fund_name_yomi='ジーエス\u3000プラス\u3000ゴールド\u3000カワセヘッジアリ\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E12457',
        issuer_name='ゴールドマン・サックス・アセット・マネジメント株式会社',
    ),
    'G15691': FundCodeEntry(
        fund_code='G15691',
        sec_code='461A0',
        fund_name='ＭＡＸＩＳ日本株高配当ＳＭＡＲＴ５０上場投信',
        fund_name_yomi='マクシスニホンカブコウハイトウスマートゴジュウジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15692': FundCodeEntry(
        fund_code='G15692',
        sec_code=None,
        fund_name='たわらノーロード\u3000米ドル建て社債（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイドルダテシャサイカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15693': FundCodeEntry(
        fund_code='G15693',
        sec_code=None,
        fund_name='たわらノーロード\u3000米ドル建て社債（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイドルダテシャサイカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15694': FundCodeEntry(
        fund_code='G15694',
        sec_code=None,
        fund_name='たわらノーロード\u3000米ドル建てハイイールド債券（為替ヘッジあり）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイドルダテハイイールドサイケンカワセヘッジアリラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15695': FundCodeEntry(
        fund_code='G15695',
        sec_code=None,
        fund_name='たわらノーロード\u3000米ドル建てハイイールド債券（為替ヘッジなし）＜ラップ専用＞',
        fund_name_yomi='タワラノーロード\u3000ベイドルダテハイイールドサイケンカワセヘッジナシラップセンヨウ',
        security_type='内国投資信託受益証券',
        period_1='5月8日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15696': FundCodeEntry(
        fund_code='G15696',
        sec_code=None,
        fund_name='ＤＣターゲット・イヤーファンド（６資産・運用継続型）２０７０',
        fund_name_yomi='ディーシーターゲット\u3000イヤーファンド\u3000ロクシサン\u3000ウンヨウケイゾクガタ\u3000ニセンナナジュウ',
        security_type='内国投資信託受益証券',
        period_1='8月28日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15697': FundCodeEntry(
        fund_code='G15697',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２５－１２（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニゴイチニゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15698': FundCodeEntry(
        fund_code='G15698',
        sec_code=None,
        fund_name='アモーヴァ／ＢＳマネージャーセレクトファンド（為替ヘッジあり）',
        fund_name_yomi='アモーヴァ\u3000ビーエスマネージャーセレクトファンド\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15699': FundCodeEntry(
        fund_code='G15699',
        sec_code=None,
        fund_name='アモーヴァ／ＢＳマネージャーセレクトファンド（為替ヘッジなし）',
        fund_name_yomi='アモーヴァ\u3000ビーエスマネージャーセレクトファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15700': FundCodeEntry(
        fund_code='G15700',
        sec_code=None,
        fund_name='しんきん円建て債券ファンド２０２５－１２（限定追加型）',
        fund_name_yomi='シンキンエンダテサイケンファンドニーゼロニーゴーイチニーゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月25日',
        period_2=None,
        edinet_code='E12422',
        issuer_name='しんきんアセットマネジメント投信株式会社',
    ),
    'G15701': FundCodeEntry(
        fund_code='G15701',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～名古屋・プライムオフィス～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンナゴヤプライムオフィスジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月1日',
        period_2='8月1日',
        edinet_code='E40784',
        issuer_name='オルタナ信託株式会社',
    ),
    'G15702': FundCodeEntry(
        fund_code='G15702',
        sec_code=None,
        fund_name='マネックス・ゴールド・ファンド',
        fund_name_yomi='マネックスゴールドファンド',
        security_type='内国投資信託受益証券',
        period_1='11月30日',
        period_2=None,
        edinet_code='E32444',
        issuer_name='マネックス・アセットマネジメント株式会社',
    ),
    'G15703': FundCodeEntry(
        fund_code='G15703',
        sec_code=None,
        fund_name='ＳＢＩ\u3000欧州高配当株式ファンド（年１回決算型）',
        fund_name_yomi='エスビーアイ\u3000オウシュウ\u3000コウハイトウカブシキファンド\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15704': FundCodeEntry(
        fund_code='G15704',
        sec_code=None,
        fund_name='欧州防衛・航空宇宙株式インデックスファンド',
        fund_name_yomi='オウシュウボウエイコウクウウチュウカブシキインデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='11月17日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15705': FundCodeEntry(
        fund_code='G15705',
        sec_code=None,
        fund_name='スマート・ファイブ（年３．６％目標分配プラス・奇数月決算型）',
        fund_name_yomi='スマート\u3000ファイブ\u3000ネンサンテンロクパーモクヒョウブンパイプラス\u3000キスウヅキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月8日',
        period_2='9月8日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15706': FundCodeEntry(
        fund_code='G15706',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000日本国債ウルトラロング（３０年平均）年４回分配型',
        fund_name_yomi='トレイサーズ\u3000ニホンコクサイウルトラロング\u3000サンジュウネンヘイキン\u3000ネンヨンカイブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15707': FundCodeEntry(
        fund_code='G15707',
        sec_code='465A0',
        fund_name='グローバルＸ\u3000日経平均株主還元４０－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスニッケイヘイキンカブヌシカンゲンヨンジュウニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月10日',
        period_2='10月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15708': FundCodeEntry(
        fund_code='G15708',
        sec_code='466A0',
        fund_name='グローバルＸ\u3000防衛テック\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスボウエイテックイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='6月10日',
        period_2='12月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15709': FundCodeEntry(
        fund_code='G15709',
        sec_code='467A0',
        fund_name='グローバルＸ\u3000米ドル建て投資適格社債\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='グローバルエックスベイドルダテトウシテキカクシャサイイーティーエフカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15710': FundCodeEntry(
        fund_code='G15710',
        sec_code='468A0',
        fund_name='グローバルＸ\u3000米ドル建て投資適格社債\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスベイドルダテトウシテキカクシャサイイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='5月10日',
        period_2='11月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15711': FundCodeEntry(
        fund_code='G15711',
        sec_code='473A0',
        fund_name='ニッセイＥＴＦ\u3000日経２２５インデックス',
        fund_name_yomi='ニッセイイーティーエフニッケイニニゴインデックス',
        security_type='内国投資信託受益証券',
        period_1='4月20日',
        period_2='10月20日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15712': FundCodeEntry(
        fund_code='G15712',
        sec_code=None,
        fund_name='パインブリッジ全世界厳選プレミア株式ファンド（資産成長型）',
        fund_name_yomi='パインブリッジゼンセカイゲンセンプレミアカブシキファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G15713': FundCodeEntry(
        fund_code='G15713',
        sec_code=None,
        fund_name='パインブリッジ全世界厳選プレミア株式ファンド（四半期決算型）',
        fund_name_yomi='パインブリッジゼンセカイゲンセンプレミアカブシキファンドシハンキケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G15714': FundCodeEntry(
        fund_code='G15714',
        sec_code=None,
        fund_name='パインブリッジ全世界厳選プレミア株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='パインブリッジゼンセカイゲンセンプレミアカブシキファンドマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='3月15日',
        period_2='9月15日',
        edinet_code='E12437',
        issuer_name='パインブリッジ・インベストメンツ株式会社',
    ),
    'G15715': FundCodeEntry(
        fund_code='G15715',
        sec_code=None,
        fund_name='ＭＳジャパンファンズ',
        fund_name_yomi='エムエスジャパンファンズ',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E37044',
        issuer_name='三田キャピタル・プライベート・リミテッド',
    ),
    'G15716': FundCodeEntry(
        fund_code='G15716',
        sec_code=None,
        fund_name='資本効率化フォーカス・ジャパン',
        fund_name_yomi='シホンコウリツカフォーカスジャパン',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15717': FundCodeEntry(
        fund_code='G15717',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／ＲＯＢＯＰＲＯ戦略ファンド２０２５－１２',
        fund_name_yomi='ゴールドマンサックスシャサイロボプロセンリャクファンドニセンニジュウゴジュウニ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15718': FundCodeEntry(
        fund_code='G15718',
        sec_code=None,
        fund_name='ＤＷＳ\u3000ＡＩニューリーダーズ株式ファンド',
        fund_name_yomi='ディーダブリューエス\u3000エーアイニューリーダーズカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='9月10日',
        period_2=None,
        edinet_code='E06458',
        issuer_name='ドイチェ・アセット・マネジメント株式会社',
    ),
    'G15719': FundCodeEntry(
        fund_code='G15719',
        sec_code=None,
        fund_name='ちゅうぎん４資産バランスファンド＜債券重視型＞／ちゅうぎん４資産バランスファンド＜株式重視型＞',
        fund_name_yomi='チュウギンヨンシサンバランスファンドサイケンジュウシガタ\u3000チュウギンヨンシサンバランスファンドカブシキジュウシガタ',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E26491',
        issuer_name='中銀アセットマネジメント株式会社',
    ),
    'G15720': FundCodeEntry(
        fund_code='G15720',
        sec_code=None,
        fund_name='Ｏｎｅグローバル株式\u3000セレクト・スタイルローテーションファンド＜ＤＣ年金＞',
        fund_name_yomi='ワングローバルカブシキ\u3000セレクトスタイルローテーションファンドディーシーネンキン',
        security_type='内国投資信託受益証券',
        period_1='10月25日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15721': FundCodeEntry(
        fund_code='G15721',
        sec_code=None,
        fund_name='ＳＭＴ\u3000日本株式モメンタムファンド',
        fund_name_yomi='エスエムティー\u3000ニホンカブシキモメンタムファンド',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15722': FundCodeEntry(
        fund_code='G15722',
        sec_code=None,
        fund_name='ケネディクス・リアルティ・トークン\u3000大阪レジデンス\u3000－東西都市開発エリア－（デジタル名義書換方式）',
        fund_name_yomi='ケネディクスリアルティトークンオオサカレジデンストウザイトシカイハツエリアデジタルメイギカキカエホウシキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='2月末日',
        period_2='8月末日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G15723': FundCodeEntry(
        fund_code='G15723',
        sec_code=None,
        fund_name='ＳＭＴ\u3000米国株式モメンタムファンド',
        fund_name_yomi='エスエムティー\u3000ベイコクカブシキモメンタムファンド',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15724': FundCodeEntry(
        fund_code='G15724',
        sec_code='488A0',
        fund_name='ｉシェアーズ\u3000円高フォーカス\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000エンダカフォーカス\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15725': FundCodeEntry(
        fund_code='G15725',
        sec_code=None,
        fund_name='ａｕＡＭレバレッジ・オールカントリー',
        fund_name_yomi='エーユーエーエムレバレッジオールカントリー',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E34254',
        issuer_name='ａｕアセットマネジメント株式会社',
    ),
    'G15726': FundCodeEntry(
        fund_code='G15726',
        sec_code=None,
        fund_name='ＳＢＩ\u3000ダルトン日本アジア・アクティビストファンド',
        fund_name_yomi='エスビーアイ\u3000ダルトン\u3000ニホンアジア\u3000アクティビスト\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15727': FundCodeEntry(
        fund_code='G15727',
        sec_code=None,
        fund_name='グローバル・Ｍ＆Ａオポチュニティ・ファンド',
        fund_name_yomi='グローバルエムアンドエーオポチュニティファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E41178',
        issuer_name='カーン・グローバル・ファンド・マネージャーズ（アイルランド）リミテッド',
    ),
    'G15728': FundCodeEntry(
        fund_code='G15728',
        sec_code=None,
        fund_name='ＳＭＴ\u3000欧州株式モメンタムファンド',
        fund_name_yomi='エスエムティー\u3000オウシュウカブシキモメンタムファンド',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15729': FundCodeEntry(
        fund_code='G15729',
        sec_code=None,
        fund_name='ＳＭＴ\u3000中国株式モメンタムファンド',
        fund_name_yomi='エスエムティー\u3000チュウゴクカブシキモメンタムファンド',
        security_type='内国投資信託受益証券',
        period_1='9月17日',
        period_2=None,
        edinet_code='E12444',
        issuer_name='三井住友トラスト・アセットマネジメント株式会社',
    ),
    'G15730': FundCodeEntry(
        fund_code='G15730',
        sec_code=None,
        fund_name='外貨建マネー・マーケット・ファンド',
        fund_name_yomi='ガイカダテマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E41205',
        issuer_name='カーン・グローバル・ファンド・マネージャーズ（ルクセンブルグ）エス・エイ',
    ),
    'G15731': FundCodeEntry(
        fund_code='G15731',
        sec_code='487A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ドイツ株式・ＤＡＸ（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズドイツカブシキダックスカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15732': FundCodeEntry(
        fund_code='G15732',
        sec_code='486A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ユーロ・ストックス５０指数（為替ヘッジなし）連動型上場投信',
        fund_name_yomi='ネクストファンズユーロストックスゴジュウシスウカワセヘッジナシレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='6月8日',
        period_2='12月8日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15733': FundCodeEntry(
        fund_code='G15733',
        sec_code=None,
        fund_name='ｉＦｒｅｅＮＥＸＴ\u3000ＦＡＮＧ＋インデックス（毎月決算／予想分配金提示型）',
        fund_name_yomi='アイフリーネクストファングプラスインデックスマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月20日',
        period_2='8月20日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15734': FundCodeEntry(
        fund_code='G15734',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－アポロ・プライベート・マーケッツＳＩＣＡＶアポロ・アラインド・オルタナティブス・ファンド',
        fund_name_yomi='ノムラファンドセレクトアポロプライベートマーケッツシキャブアポロアイランドオルタナティブスファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G15735': FundCodeEntry(
        fund_code='G15735',
        sec_code=None,
        fund_name='ニューバーガー・プライベート・エクイティ・ファンド',
        fund_name_yomi='ニューバーガー\u3000プライベート\u3000エクイティ\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月1日',
        period_2=None,
        edinet_code='E35209',
        issuer_name='ニューバーガー・バーマン株式会社',
    ),
    'G15736': FundCodeEntry(
        fund_code='G15736',
        sec_code=None,
        fund_name='ラップ専用・三井住友ＤＳ・米国株式セクター戦略ファンド',
        fund_name_yomi='ラップセンヨウミツイスミトモディーエスベイコクカブシキセクターセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15737': FundCodeEntry(
        fund_code='G15737',
        sec_code=None,
        fund_name='ラップ専用・三井住友ＤＳ・米国株式ファクター戦略ファンド',
        fund_name_yomi='ラップセンヨウミツイスミトモディーエスベイコクカブシキファクターセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15738': FundCodeEntry(
        fund_code='G15738',
        sec_code=None,
        fund_name='ラップ専用・三井住友ＤＳ・グローバル株式（除く米国）戦略ファンド',
        fund_name_yomi='ラップセンヨウミツイスミトモディーエスグローバルカブシキノゾクベイコクセンリャクファンド',
        security_type='内国投資信託受益証券',
        period_1='12月10日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15739': FundCodeEntry(
        fund_code='G15739',
        sec_code=None,
        fund_name='野村マッコーリー・プライベート・インフラ・ファンド（野村ＳＭＡ・ＥＷ向け）',
        fund_name_yomi='ノムラマッコーリープライベートインフラファンドノムラエスエムエーイーダブリュウムケ',
        security_type='内国投資信託受益証券',
        period_1='1月30日',
        period_2=None,
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15740': FundCodeEntry(
        fund_code='G15740',
        sec_code='489A0',
        fund_name='東証ＲＥＩＴ物流フォーカスＥＴＦ',
        fund_name_yomi='トウショウリートブツリュウフォーカスイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='5月15日',
        period_2='11月15日',
        edinet_code='E14415',
        issuer_name='シンプレクス・アセット・マネジメント株式会社',
    ),
    'G15741': FundCodeEntry(
        fund_code='G15741',
        sec_code=None,
        fund_name='インベスコ\u3000世界厳選株式オープン（予想分配金提示型）',
        fund_name_yomi='インベスコセカイゲンセンカブシキオープンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月23日',
        period_2='12月23日',
        edinet_code='E06479',
        issuer_name='インベスコ・アセット・マネジメント株式会社',
    ),
    'G15742': FundCodeEntry(
        fund_code='G15742',
        sec_code=None,
        fund_name='ＨＳＢＣユーロランド・バリュー株式ファンド（１年決算型）',
        fund_name_yomi='エイチエスビーシーユーロランドバリューカブシキファンドイチネンケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月20日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15743': FundCodeEntry(
        fund_code='G15743',
        sec_code=None,
        fund_name='Ｏｎｅ円建て債券ファンドⅤ\u3000２０２６－０２',
        fund_name_yomi='ワンエンダテサイケンファンドファイブニイゼロニイロクゼロニイ',
        security_type='内国投資信託受益証券',
        period_1='7月24日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15744': FundCodeEntry(
        fund_code='G15744',
        sec_code=None,
        fund_name='ダイワ金融新時代ファンド（資産成長型）',
        fund_name_yomi='ダイワキンユウシンジダイファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='5月16日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15745': FundCodeEntry(
        fund_code='G15745',
        sec_code=None,
        fund_name='ニッセイ米国株式ブースト戦略ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ニッセイベイコクカブシキブーストセンリャクファンドマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15746': FundCodeEntry(
        fund_code='G15746',
        sec_code=None,
        fund_name='ニッセイ米国株式ブースト戦略ファンド＜為替リスク限定型＞（毎月決算・予想分配金提示型）',
        fund_name_yomi='ニッセイベイコクカブシキブーストセンリャクファンドカワセリスクゲンテイガタマイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15747': FundCodeEntry(
        fund_code='G15747',
        sec_code=None,
        fund_name='ダイワ・ダイナミック・インド株ファンド（資産成長型）',
        fund_name_yomi='ダイワダイナミックインドカブファンドシサンセイチョウガタ',
        security_type='内国投資信託受益証券',
        period_1='12月16日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15748': FundCodeEntry(
        fund_code='G15748',
        sec_code=None,
        fund_name='インターナショナル・オポチュニティ・ファンド（為替ヘッジなし）',
        fund_name_yomi='インターナショナルオポチュニティファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月9日',
        period_2=None,
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15749': FundCodeEntry(
        fund_code='G15749',
        sec_code='491A0',
        fund_name='ｉシェアーズ\u3000Ｓ＆Ｐ\u3000５００\u3000除く金融\u3000ＥＴＦ（為替ヘッジあり）',
        fund_name_yomi='アイシェアーズ\u3000エスアンドピー\u3000ゴヒャク\u3000ノゾクキンユウ\u3000イーティーエフ\u3000カワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='2月9日',
        period_2='8月9日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15750': FundCodeEntry(
        fund_code='G15750',
        sec_code=None,
        fund_name='ゴール・サポート・ファンド',
        fund_name_yomi='ゴール\u3000サポート\u3000ファンド',
        security_type='内国投資信託受益証券',
        period_1='9月25日',
        period_2=None,
        edinet_code='E12882',
        issuer_name='農林中金全共連アセットマネジメント株式会社',
    ),
    'G15751': FundCodeEntry(
        fund_code='G15751',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／ゴールド・エクイティ・バランス戦略ファンド２０２６－０２',
        fund_name_yomi='ゴールドマンサックスシャサイゴールドエクイティバランスセンリャクファンドニセンニジュウロクゼロニ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15752': FundCodeEntry(
        fund_code='G15752',
        sec_code=None,
        fund_name='あおぞら・新グローバル分散ファンド（限定追加型）２０２６－０１',
        fund_name_yomi='アオゾラ\u3000シングローバルブンサンファンド\u3000ゲンテイツイカガタ\u3000ニイゼロニイロク\u3000ゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15753': FundCodeEntry(
        fund_code='G15753',
        sec_code=None,
        fund_name='あおぞら・新グローバル・プレミアム・ファンド（当初漸増期間付、限定追加型）２０２６－０１',
        fund_name_yomi='アオゾラ\u3000シングローバル\u3000プレミアム\u3000ファンド\u3000トウショゼンゾウキカンツキ\u3000ゲンテイツイカガタ\u3000ニイゼロニイロク\u3000ゼロイチ',
        security_type='内国投資信託受益証券',
        period_1='10月20日',
        period_2=None,
        edinet_code='E30689',
        issuer_name='あおぞら投信株式会社',
    ),
    'G15754': FundCodeEntry(
        fund_code='G15754',
        sec_code=None,
        fund_name='ニッセイ投資適格社債ファンド２０２６－０２（為替ヘッジあり・４年投資型）',
        fund_name_yomi='ニッセイトウシテキカクシャサイファンドニゼロニロクゼロニカワセヘッジアリヨネントウシガタ',
        security_type='内国投資信託受益証券',
        period_1='12月5日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15755': FundCodeEntry(
        fund_code='G15755',
        sec_code=None,
        fund_name='三井物産グループのデジタル証券～千代田区・レジデンス～（譲渡制限付）',
        fund_name_yomi='ミツイブッサングループノデジタルショウケンチヨダクレジデンスジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='4月1日',
        period_2='10月1日',
        edinet_code='E40784',
        issuer_name='オルタナ信託株式会社',
    ),
    'G15756': FundCodeEntry(
        fund_code='G15756',
        sec_code=None,
        fund_name='アライアンス・バーンスタイン・世界（除く米国）優良株投信（年２回決算型）／（毎月決算・予想分配金提示型）',
        fund_name_yomi='アライアンスバーンスタインセカイノゾクベイコクユウリョウカブトウシンネンニカイケッサンガタ\u3000マイツキケッサンヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E12480',
        issuer_name='アライアンス・バーンスタイン株式会社',
    ),
    'G15757': FundCodeEntry(
        fund_code='G15757',
        sec_code=None,
        fund_name='ＤＣ米国株式（高配当）インデックスファンド',
        fund_name_yomi='ディーシーベイコクカブシキ\u3000コウハイトウ\u3000インデックスファンド',
        security_type='内国投資信託受益証券',
        period_1='10月4日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15758': FundCodeEntry(
        fund_code='G15758',
        sec_code=None,
        fund_name='楽天・ゴールド・ファンド（為替ヘッジあり）／楽天・ゴールド・ファンド（為替ヘッジなし）',
        fund_name_yomi='ラクテン\u3000ゴールド\u3000ファンド\u3000カワセヘッジアリ\u3000\u3000ラクテン\u3000ゴールド\u3000ファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15759': FundCodeEntry(
        fund_code='G15759',
        sec_code=None,
        fund_name='楽天・プラチナ・ファンド（為替ヘッジなし）',
        fund_name_yomi='ラクテン\u3000プラチナ\u3000ファンド\u3000カワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月15日',
        period_2=None,
        edinet_code='E15787',
        issuer_name='楽天投信投資顧問株式会社',
    ),
    'G15760': FundCodeEntry(
        fund_code='G15760',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・ターゲット利回り債券ファンド２０２６－０３（限定追加型）',
        fund_name_yomi='エイチエスビーシーグローバルターゲットリマワリサイケンファンドニゼロニロクゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='4月15日',
        period_2=None,
        edinet_code='E12492',
        issuer_name='ＨＳＢＣアセットマネジメント株式会社',
    ),
    'G15761': FundCodeEntry(
        fund_code='G15761',
        sec_code=None,
        fund_name='ｉＦｒｅｅＨＯＬＤ\u3000日本国債２０４５（３・９月定期分配型）',
        fund_name_yomi='アイフリーホールドニホンコクサイニゼロヨンゴサンクガツテイキブンパイガタ',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2='9月25日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15762': FundCodeEntry(
        fund_code='G15762',
        sec_code=None,
        fund_name='ニッセイ／ＦＯＬＩＯねらってそなえる日経２２５',
        fund_name_yomi='ニッセイフォリオネラッテソナエルニッケイニニゴ',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15763': FundCodeEntry(
        fund_code='G15763',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000新興国債券オポチュニティ・ファンド＜３ヵ月決算型＞（為替リスク軽減型）予想分配金提示型／＜３ヵ月決算型＞（為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='モルガンスタンレーシンコウコクサイケンオポチュニティファンドサンカゲツケッサンガタカワセリスクケイゲンガタヨソウブンパイキンテイジガタサンカゲツケッサンガタカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2='8月7日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15764': FundCodeEntry(
        fund_code='G15764',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000新興国債券オポチュニティ・ファンド＜年１回決算型＞（為替リスク軽減型）／＜年１回決算型＞（為替ヘッジなし）',
        fund_name_yomi='モルガンスタンレーシンコウコクサイケンオポチュニティファンドネンイッカイケッサンガタカワセリスクケイゲンガタネンイッカイケッサンガタカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='8月7日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15765': FundCodeEntry(
        fund_code='G15765',
        sec_code=None,
        fund_name='ＪＰモルガン・米国ハイ・イールド債券ファンド（年１回決算・為替ヘッジなし）',
        fund_name_yomi='ジェイピーモルガンベイコクハイイールドサイケンファンドネンイッカイケッサンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15766': FundCodeEntry(
        fund_code='G15766',
        sec_code=None,
        fund_name='ＪＰモルガン・米国ハイ・イールド債券ファンド（年４回決算・為替ヘッジなし）',
        fund_name_yomi='ジェイピーモルガンベイコクハイイールドサイケンファンドネンヨンカイケッサンカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15767': FundCodeEntry(
        fund_code='G15767',
        sec_code=None,
        fund_name='ＪＰモルガン・米国ハイ・イールド債券ファンド（年１回決算・為替ヘッジあり）',
        fund_name_yomi='ジェイピーモルガンベイコクハイイールドサイケンファンドネンイッカイケッサンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='12月18日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15768': FundCodeEntry(
        fund_code='G15768',
        sec_code=None,
        fund_name='ＪＰモルガン・米国ハイ・イールド債券ファンド（年４回決算・為替ヘッジあり）',
        fund_name_yomi='ジェイピーモルガンベイコクハイイールドサイケンファンドネンヨンカイケッサンカワセヘッジアリ',
        security_type='内国投資信託受益証券',
        period_1='6月18日',
        period_2='12月18日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15769': FundCodeEntry(
        fund_code='G15769',
        sec_code='493A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日本国債\u3000１－３年',
        fund_name_yomi='ワンイーティーエフニホンコクサイイチカラサンネン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15770': FundCodeEntry(
        fund_code='G15770',
        sec_code='494A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日本国債\u3000３－７年',
        fund_name_yomi='ワンイーティーエフニホンコクサイサンカラナナネン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15771': FundCodeEntry(
        fund_code='G15771',
        sec_code='495A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日本国債\u3000７－１０年',
        fund_name_yomi='ワンイーティーエフニホンコクサイナナカラジュウネン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15772': FundCodeEntry(
        fund_code='G15772',
        sec_code='496A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日本国債\u3000１７－２０年',
        fund_name_yomi='ワンイーティーエフニホンコクサイジュウナナカラニジュウネン',
        security_type='内国投資信託受益証券',
        period_1='3月20日',
        period_2='9月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15773': FundCodeEntry(
        fund_code='G15773',
        sec_code=None,
        fund_name='ＨＳＢＣグローバル・インベストメント・ファンド－グローバル・インベストメント・グレード・セキュリタイズド・クレジット・ボンド',
        fund_name_yomi='エイチエスビーシーグローバルインベストメントファンドグローバルインベストメントグレードセキュリタイズドクレジットボンド',
        security_type='外国投資証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E40920',
        issuer_name='ＨＳＢＣグローバル・インベストメント・ファンド',
    ),
    'G15774': FundCodeEntry(
        fund_code='G15774',
        sec_code='502A0',
        fund_name='グローバルＸ\u3000超短期円建て債券\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスチョウタンキエンダテサイケンイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15775': FundCodeEntry(
        fund_code='G15775',
        sec_code='492A0',
        fund_name='Ｏｎｅ\u3000ＥＴＦ\u3000日本国債\u3000高クーポン（平均残存１０年未満）',
        fund_name_yomi='ワンイーティーエフニホンコクサイコウクーポンヘイキンザンゾンジュウネンミマン',
        security_type='内国投資信託受益証券',
        period_1='6月20日',
        period_2='12月20日',
        edinet_code='E10677',
        issuer_name='アセットマネジメントＯｎｅ株式会社',
    ),
    'G15776': FundCodeEntry(
        fund_code='G15776',
        sec_code=None,
        fund_name='ハイベータ日本株フォーカス・ファンド',
        fund_name_yomi='ハイベータニホンカブフォーカスファンド',
        security_type='内国投資信託受益証券',
        period_1='8月20日',
        period_2=None,
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15777': FundCodeEntry(
        fund_code='G15777',
        sec_code=None,
        fund_name='中央日本土地建物グループのデジタル証券～バウスクロス東海大学前・仙台川内～（譲渡制限付）',
        fund_name_yomi='チュウオウニホントチタテモノグループノデジタルショウケンバウスクロストウカイダイガクマエセンダイカワウチジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月1日',
        period_2='11月1日',
        edinet_code='E03628',
        issuer_name='みずほ信託銀行株式会社',
    ),
    'G15779': FundCodeEntry(
        fund_code='G15779',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）欧州株',
        fund_name_yomi='アムンディインデックスシリーズオウシュウカブ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15780': FundCodeEntry(
        fund_code='G15780',
        sec_code=None,
        fund_name='（アムンディ・インデックスシリーズ）欧州・戦略的自律株',
        fund_name_yomi='アムンディインデックスシリーズオウシュウセンリャクテキジリツカブ',
        security_type='内国投資信託受益証券',
        period_1='2月25日',
        period_2=None,
        edinet_code='E09666',
        issuer_name='アムンディ・ジャパン株式会社',
    ),
    'G15781': FundCodeEntry(
        fund_code='G15781',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）ＩＩＩ－Ｍａｎダイナミック・インカム・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーマンダイナミックインカムファンド',
        security_type='外国投資信託受益証券',
        period_1='4月末日',
        period_2=None,
        edinet_code='E41334',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G15782': FundCodeEntry(
        fund_code='G15782',
        sec_code=None,
        fund_name='ＭＵＦＧリアルティ・トークン大阪堂島浜タワー（譲渡制限付）',
        fund_name_yomi='エムユーエフジーリアルティトークンオオサカドウジマハマタワージョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='5月1日',
        period_2='11月1日',
        edinet_code='E03626',
        issuer_name='三菱ＵＦＪ信託銀行株式会社',
    ),
    'G15783': FundCodeEntry(
        fund_code='G15783',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２６－０３（為替ヘッジあり・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニロクゼロサンカワセヘッジアリゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15784': FundCodeEntry(
        fund_code='G15784',
        sec_code=None,
        fund_name='ニッセイ／シュローダー好利回りＣＢファンド２０２６－０３（為替ヘッジなし・限定追加型）',
        fund_name_yomi='ニッセイシュローダーコウリマワリシービーファンドニゼロニロクゼロサンカワセヘッジナシゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15785': FundCodeEntry(
        fund_code='G15785',
        sec_code=None,
        fund_name='ニッセイ・円建てグローバル社債／バランスファンド２０２６－０３',
        fund_name_yomi='ニッセイエンダテグローバルシャサイバランスファンドニゼロニロクゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月21日',
        period_2=None,
        edinet_code='E12453',
        issuer_name='ニッセイアセットマネジメント株式会社',
    ),
    'G15786': FundCodeEntry(
        fund_code='G15786',
        sec_code=None,
        fund_name='ノムラ・ファンド・セレクト－カーライル・プライベート・エクイティ・パートナーズ・ファンド',
        fund_name_yomi='ノムラファンドセレクトカーライルプライベートエクイティパートナーズファンド',
        security_type='外国投資信託受益証券',
        period_1='3月末日',
        period_2=None,
        edinet_code='E26746',
        issuer_name='グローバル・ファンズ・トラスト・カンパニー',
    ),
    'G15787': FundCodeEntry(
        fund_code='G15787',
        sec_code=None,
        fund_name='ニュートン・量子技術関連株式ファンド',
        fund_name_yomi='ニュートンリョウシギジュツカンレンカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月26日',
        period_2='8月26日',
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15788': FundCodeEntry(
        fund_code='G15788',
        sec_code=None,
        fund_name='ＳＯＭＰＯ円建て債券ファンド（限定追加型）２０２６－０３',
        fund_name_yomi='ソンポエンダテサイケンファンドゲンテイツイカガタニゼロニロクゼロサン',
        security_type='内国投資信託受益証券',
        period_1='3月25日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15789': FundCodeEntry(
        fund_code='G15789',
        sec_code=None,
        fund_name='Ｔ＆Ｄインド中小型株ファンド（毎月決算型・予想分配金提示型）',
        fund_name_yomi='ティアンドディインドチュウコガタカブファンド\u3000マイツキケッサンガタヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='2月10日',
        period_2='8月10日',
        edinet_code='E11764',
        issuer_name='Ｔ＆Ｄアセットマネジメント株式会社',
    ),
    'G15790': FundCodeEntry(
        fund_code='G15790',
        sec_code=None,
        fund_name='米国製造業株式ファンド（毎月決算・予想分配金提示型）',
        fund_name_yomi='ベイコクセイゾウギョウカブシキファンド\u3000マイツキケッサン\u3000ヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月17日',
        period_2='11月17日',
        edinet_code='E13343',
        issuer_name='ＢＮＹメロン・インベストメント・マネジメント・ジャパン株式会社',
    ),
    'G15791': FundCodeEntry(
        fund_code='G15791',
        sec_code=None,
        fund_name='グリーンライト・再エネインフラ投資法人',
        fund_name_yomi='グリーンライトサイエネインフラトウシホウジン',
        security_type='内国投資証券',
        period_1='5月末日',
        period_2='11月末日',
        edinet_code='E41225',
        issuer_name='グリーンライト・再エネインフラ投資法人',
    ),
    'G15792': FundCodeEntry(
        fund_code='G15792',
        sec_code=None,
        fund_name='三菱ＵＦＪ\u3000日本短期債券オープン',
        fund_name_yomi='ミツビシユーエフジェイニホンタンキサイケンオープン',
        security_type='内国投資信託受益証券',
        period_1='7月22日',
        period_2=None,
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15793': FundCodeEntry(
        fund_code='G15793',
        sec_code=None,
        fund_name='プロテクト水準毎年設定型・米国テクノロジー株式ファンド２０２６－０３（限定追加型）',
        fund_name_yomi='プロテクトスイジュンマイトシセッテイガタベイコクテクノロジーカブシキファンドニゼロニロクゼロサンゲンテイツイカガタ',
        security_type='内国投資信託受益証券',
        period_1='3月10日',
        period_2=None,
        edinet_code='E12434',
        issuer_name='ＳＯＭＰＯアセットマネジメント株式会社',
    ),
    'G15794': FundCodeEntry(
        fund_code='G15794',
        sec_code=None,
        fund_name='イオンモール新利府・デジタル証券～仙台近郊～（譲渡制限付）',
        fund_name_yomi='イオンモールシンリフデジタルショウケンセンダイキンコウジョウトセイゲンツキ',
        security_type='内国信託受益証券・信託受益権',
        period_1='3月1日',
        period_2='9月1日',
        edinet_code='E40784',
        issuer_name='オルタナ信託株式会社',
    ),
    'G15795': FundCodeEntry(
        fund_code='G15795',
        sec_code=None,
        fund_name='ｉシェアーズ\u3000高格付け日本円社債\u3000ＥＴＦ',
        fund_name_yomi='アイシェアーズ\u3000コウカクヅケニホンエンシャサイ\u3000イーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='4月11日',
        period_2='10月11日',
        edinet_code='E09096',
        issuer_name='ブラックロック・ジャパン株式会社',
    ),
    'G15796': FundCodeEntry(
        fund_code='G15796',
        sec_code=None,
        fund_name='モルガン・スタンレー\u3000米国株式インサイト戦略ファンド＜毎月決算型＞（為替ヘッジあり／為替ヘッジなし）予想分配金提示型',
        fund_name_yomi='モルガンスタンレーベイコクカブシキインサイトセンリャクファンドマイツキケッサンガタカワセヘッジアリカワセヘッジナシヨソウブンパイキンテイジガタ',
        security_type='内国投資信託受益証券',
        period_1='5月25日',
        period_2='11月25日',
        edinet_code='E11518',
        issuer_name='三菱ＵＦＪアセットマネジメント株式会社',
    ),
    'G15797': FundCodeEntry(
        fund_code='G15797',
        sec_code=None,
        fund_name='ＵＢＳ（Ｌｕｘ）マネー・マーケット・ファンド',
        fund_name_yomi='ユービーエスエルユーエックスマネーマーケットファンド',
        security_type='外国投資信託受益証券',
        period_1='10月末日',
        period_2=None,
        edinet_code='E14900',
        issuer_name='ＵＢＳアセット・マネジメント（ヨーロッパ）エス・エイ',
    ),
    'G15798': FundCodeEntry(
        fund_code='G15798',
        sec_code=None,
        fund_name='ジャパン・コンテンツＩＰ戦略株式ファンド',
        fund_name_yomi='ジャパンコンテンツアイピーセンリャクカブシキファンド',
        security_type='内国投資信託受益証券',
        period_1='2月19日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15799': FundCodeEntry(
        fund_code='G15799',
        sec_code=None,
        fund_name='グローバルＸ\u3000ステーブルコイン＆トークンビジネス\u3000ＥＴＦ（除く日本）',
        fund_name_yomi='グローバルエックスステーブルコインアンドトークンビジネスイーティーエフノゾクニホン',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15800': FundCodeEntry(
        fund_code='G15800',
        sec_code=None,
        fund_name='グローバルＸ\u3000防衛テック－日本株式\u3000ＥＴＦ',
        fund_name_yomi='グローバルエックスボウエイテックニホンカブシキイーティーエフ',
        security_type='内国投資信託受益証券',
        period_1='2月24日',
        period_2='8月24日',
        edinet_code='E35933',
        issuer_name='Ｇｌｏｂａｌ\u3000Ｘ\u3000Ｊａｐａｎ株式会社',
    ),
    'G15801': FundCodeEntry(
        fund_code='G15801',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）Ⅲ－ＫＫＲインフラストラクチャー・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリーケーケーアールインフラストラクチャーファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E15389',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
    'G15802': FundCodeEntry(
        fund_code='G15802',
        sec_code=None,
        fund_name='Ｔｒａｃｅｒｓ\u3000ＭＳＣＩオール・カントリー・ゴールドプラス',
        fund_name_yomi='トレイサーズ\u3000エムエスシーアイオール\u3000カントリー\u3000ゴールドプラス',
        security_type='内国投資信託受益証券',
        period_1='2月7日',
        period_2=None,
        edinet_code='E12430',
        issuer_name='アモーヴァ・アセットマネジメント株式会社',
    ),
    'G15803': FundCodeEntry(
        fund_code='G15803',
        sec_code='516A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米ドル・ブル（１倍）',
        fund_name_yomi='アイフリーイーティーエフベイドルブルイチバイ',
        security_type='内国投資信託受益証券',
        period_1='2月4日',
        period_2='8月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15804': FundCodeEntry(
        fund_code='G15804',
        sec_code='517A0',
        fund_name='ｉＦｒｅｅＥＴＦ\u3000米ドル・ベア（１倍）',
        fund_name_yomi='アイフリーイーティーエフベイドルベアイチバイ',
        security_type='内国投資信託受益証券',
        period_1='2月4日',
        period_2='8月4日',
        edinet_code='E06748',
        issuer_name='大和アセットマネジメント株式会社',
    ),
    'G15805': FundCodeEntry(
        fund_code='G15805',
        sec_code=None,
        fund_name='りそな\u3000つみたてインカムバランスファンド',
        fund_name_yomi='リソナ\u3000ツミタテインカムバランスファンド',
        security_type='内国投資信託受益証券',
        period_1='12月20日',
        period_2=None,
        edinet_code='E32011',
        issuer_name='りそなアセットマネジメント株式会社',
    ),
    'G15806': FundCodeEntry(
        fund_code='G15806',
        sec_code=None,
        fund_name='ゴールドマン・サックス社債／ＲＯＢＯＰＲＯ戦略ファンド２０２６－０３',
        fund_name_yomi='ゴールドマンサックスシャサイロボプロセンリャクファンドニセンニジュウロクゼロサン',
        security_type='内国投資信託受益証券',
        period_1='4月19日',
        period_2=None,
        edinet_code='E12441',
        issuer_name='ＳＢＩ岡三アセットマネジメント株式会社',
    ),
    'G15807': FundCodeEntry(
        fund_code='G15807',
        sec_code=None,
        fund_name='ＪＰモルガン・グローバル・セレクト株式ファンド（為替ヘッジなし、年１回決算型）',
        fund_name_yomi='ジェーピーモルガングローバルセレクトカブシキファンド\u3000カワセヘッジナシ\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15808': FundCodeEntry(
        fund_code='G15808',
        sec_code=None,
        fund_name='ＪＰモルガン・グローバル・セレクト株式ファンド（為替ヘッジあり、年１回決算型）',
        fund_name_yomi='ジェーピーモルガングローバルセレクトカブシキファンド\u3000カワセヘッジアリ\u3000ネンイッカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2=None,
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15809': FundCodeEntry(
        fund_code='G15809',
        sec_code=None,
        fund_name='ＪＰモルガン・グローバル・セレクト株式ファンド（為替ヘッジなし、年４回決算型）',
        fund_name_yomi='ジェーピーモルガングローバルセレクトカブシキファンド\u3000カワセヘッジナシ\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15810': FundCodeEntry(
        fund_code='G15810',
        sec_code=None,
        fund_name='ＪＰモルガン・グローバル・セレクト株式ファンド（為替ヘッジあり、年４回決算型）',
        fund_name_yomi='ジェーピーモルガングローバルセレクトカブシキファンド\u3000カワセヘッジアリ\u3000ネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='3月26日',
        period_2='9月26日',
        edinet_code='E06264',
        issuer_name='ＪＰモルガン・アセット・マネジメント株式会社',
    ),
    'G15811': FundCodeEntry(
        fund_code='G15811',
        sec_code=None,
        fund_name='マテリアル・イノベーション戦略株式ファンド（為替ヘッジあり）\u3000マテリアル・イノベーション戦略株式ファンド（為替ヘッジなし）',
        fund_name_yomi='マテリアルイノベーションセンリャクカブシキファンドカワセヘッジアリ\u3000マテリアルイノベーションセンリャクカブシキファンドカワセヘッジナシ',
        security_type='内国投資信託受益証券',
        period_1='3月1日',
        period_2=None,
        edinet_code='E08957',
        issuer_name='三井住友ＤＳアセットマネジメント株式会社',
    ),
    'G15812': FundCodeEntry(
        fund_code='G15812',
        sec_code='518A0',
        fund_name='ＮＥＸＴ\u3000ＦＵＮＤＳ\u3000ＦＴＳＥ日本株高配当キャッシュフロー５０指数連動型上場投信',
        fund_name_yomi='ネクストファンズエフティエスイーニホンカブコウハイトウキャッシュフローゴジュウシスウレンドウガタジョウジョウトウシン',
        security_type='内国投資信託受益証券',
        period_1='2月15日',
        period_2='8月15日',
        edinet_code='E12460',
        issuer_name='野村アセットマネジメント株式会社',
    ),
    'G15814': FundCodeEntry(
        fund_code='G15814',
        sec_code=None,
        fund_name='ＳＢＩエネルギー・電力株式ファンド（年４回決算型）',
        fund_name_yomi='エスビーアイエネルギーデンリョクカブシキファンドネンヨンカイケッサンガタ',
        security_type='内国投資信託受益証券',
        period_1='1月10日',
        period_2='7月10日',
        edinet_code='E13447',
        issuer_name='ＳＢＩアセットマネジメント株式会社',
    ),
    'G15821': FundCodeEntry(
        fund_code='G15821',
        sec_code=None,
        fund_name='ＵＢＳユニバーサル・トラスト（ケイマン）ＩＩＩ－東海東京\u3000ハミルトン・レーン・グローバル・プライベート・アセット・ファンド',
        fund_name_yomi='ユービーエスユニバーサルトラストケイマンスリートウカイトウキョウハミルトンレーングローバルプライベートアセットファンド',
        security_type='外国投資信託受益証券',
        period_1='12月末日',
        period_2=None,
        edinet_code='E41334',
        issuer_name='ＵＢＳマネジメント（ケイマン）リミテッド',
    ),
}

FUND_CODE_RECORD_COUNT = len(_FUND_CODE_TABLE)

_warned_unknown_fund_codes: set[str] = set()


def get_fund_code(code: str) -> FundCodeEntry | None:
    """ファンドコードから FundCodeEntry を返す。"""
    entry = _FUND_CODE_TABLE.get(code)
    if entry is None and code not in _warned_unknown_fund_codes:
        _warned_unknown_fund_codes.add(code)
        warnings.warn(
            f"Unknown fundCode: {code!r}.",
            category=EdinetWarning,
            stacklevel=2,
        )
    return entry


def all_fund_codes() -> list[FundCodeEntry]:
    """全ファンドコードの一覧を返す。"""
    return list(_FUND_CODE_TABLE.values())


def _reset_warning_state() -> None:
    """テスト用。"""
    _warned_unknown_fund_codes.clear()
